PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE "django_geo_db_location" ("location_id" integer NOT NULL PRIMARY KEY AUTOINCREMENT, "name" varchar(30) NULL, "generated_name" varchar(50) NULL, "city_id" integer NULL REFERENCES "django_geo_db_city" ("city_id"), "country_id" integer NOT NULL REFERENCES "django_geo_db_country" ("country_id"), "geocoordinate_id" integer NULL REFERENCES "django_geo_db_geocoordinate" ("geocoordinate_id"), "state_id" integer NULL REFERENCES "django_geo_db_state" ("state_id"), "zipcode_id" integer NULL REFERENCES "django_geo_db_zipcode" ("zipcode_id"), "is_private" bool NOT NULL, UNIQUE ("country_id", "state_id", "city_id", "zipcode_id", "geocoordinate_id"));
INSERT INTO "django_geo_db_location" VALUES(1,NULL,'Afghanistan',NULL,1,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2,NULL,'Åland Islands',NULL,2,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3,NULL,'Albania',NULL,3,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4,NULL,'Algeria',NULL,4,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5,NULL,'American Samoa',NULL,5,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6,NULL,'Andorra',NULL,6,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7,NULL,'Angola',NULL,7,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8,NULL,'Anguilla',NULL,8,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9,NULL,'Antigua and Barbuda',NULL,9,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10,NULL,'Argentina',NULL,10,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11,NULL,'Armenia',NULL,11,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12,NULL,'Aruba',NULL,12,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13,NULL,'Australia',NULL,13,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14,NULL,'Austria',NULL,14,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15,NULL,'Azerbaijan',NULL,15,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16,NULL,'Bahamas',NULL,16,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17,NULL,'Bahrain',NULL,17,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18,NULL,'Bangladesh',NULL,18,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19,NULL,'Barbados',NULL,19,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20,NULL,'Belarus',NULL,20,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21,NULL,'Belgium',NULL,21,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22,NULL,'Belize',NULL,22,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23,NULL,'Benin',NULL,23,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24,NULL,'Bermuda',NULL,24,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25,NULL,'Bhutan',NULL,25,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26,NULL,'Bolivia (Plurinational State of)',NULL,26,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27,NULL,'Bosnia and Herzegovina',NULL,27,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28,NULL,'Botswana',NULL,28,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29,NULL,'Brazil',NULL,29,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30,NULL,'Brunei Darussalam',NULL,30,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31,NULL,'Bulgaria',NULL,31,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32,NULL,'Burkina Faso',NULL,32,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33,NULL,'Burundi',NULL,33,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34,NULL,'Cabo Verde',NULL,34,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35,NULL,'Cambodia',NULL,35,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36,NULL,'Cameroon',NULL,36,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37,NULL,'Canada',NULL,37,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38,NULL,'Cayman Islands',NULL,38,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39,NULL,'Central African Republic',NULL,39,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40,NULL,'Chad',NULL,40,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41,NULL,'Chile',NULL,41,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42,NULL,'China',NULL,42,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43,NULL,'Colombia',NULL,43,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44,NULL,'Comoros',NULL,44,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45,NULL,'Congo',NULL,45,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46,NULL,'Congo (Democratic Republic of the)',NULL,46,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47,NULL,'Cook Islands',NULL,47,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48,NULL,'Costa Rica',NULL,48,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49,NULL,'Côte d''Ivoire',NULL,49,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50,NULL,'Croatia',NULL,50,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51,NULL,'Cuba',NULL,51,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52,NULL,'Cyprus',NULL,52,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53,NULL,'Czech Republic',NULL,53,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54,NULL,'Denmark',NULL,54,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55,NULL,'Djibouti',NULL,55,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56,NULL,'Dominica',NULL,56,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57,NULL,'Dominican Republic',NULL,57,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58,NULL,'Ecuador',NULL,58,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59,NULL,'Egypt',NULL,59,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60,NULL,'El Salvador',NULL,60,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61,NULL,'Equatorial Guinea',NULL,61,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62,NULL,'Eritrea',NULL,62,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63,NULL,'Estonia',NULL,63,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64,NULL,'Ethiopia',NULL,64,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65,NULL,'Falkland Islands (Malvinas)',NULL,65,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66,NULL,'Faroe Islands',NULL,66,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67,NULL,'Fiji',NULL,67,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68,NULL,'Finland',NULL,68,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69,NULL,'France',NULL,69,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70,NULL,'French Guiana',NULL,70,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71,NULL,'French Polynesia',NULL,71,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72,NULL,'Gabon',NULL,72,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73,NULL,'Gambia',NULL,73,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(74,NULL,'Georgia',NULL,74,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(75,NULL,'Germany',NULL,75,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(76,NULL,'Ghana',NULL,76,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(77,NULL,'Gibraltar',NULL,77,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(78,NULL,'Greece',NULL,78,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(79,NULL,'Greenland',NULL,79,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(80,NULL,'Grenada',NULL,80,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(81,NULL,'Guadeloupe',NULL,81,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(82,NULL,'Guam',NULL,82,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(83,NULL,'Guatemala',NULL,83,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(84,NULL,'Guernsey',NULL,84,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(85,NULL,'Guinea',NULL,85,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(86,NULL,'Guinea-Bissau',NULL,86,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(87,NULL,'Guyana',NULL,87,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(88,NULL,'Haiti',NULL,88,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(89,NULL,'Holy See',NULL,89,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(90,NULL,'Honduras',NULL,90,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(91,NULL,'Hong Kong',NULL,91,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(92,NULL,'Hungary',NULL,92,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(93,NULL,'Iceland',NULL,93,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(94,NULL,'India',NULL,94,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(95,NULL,'Indonesia',NULL,95,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(96,NULL,'Iran (Islamic Republic of)',NULL,96,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(97,NULL,'Iraq',NULL,97,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(98,NULL,'Ireland',NULL,98,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(99,NULL,'Isle of Man',NULL,99,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(100,NULL,'Israel',NULL,100,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(101,NULL,'Italy',NULL,101,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(102,NULL,'Jamaica',NULL,102,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(103,NULL,'Japan',NULL,103,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(104,NULL,'Jersey',NULL,104,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(105,NULL,'Jordan',NULL,105,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(106,NULL,'Kazakhstan',NULL,106,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(107,NULL,'Kenya',NULL,107,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(108,NULL,'Kiribati',NULL,108,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(109,NULL,'Korea (Democratic People''s Republic of)',NULL,109,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(110,NULL,'Korea (Republic of)',NULL,110,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(111,NULL,'Kuwait',NULL,111,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(112,NULL,'Kyrgyzstan',NULL,112,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(113,NULL,'Lao People''s Democratic Republic',NULL,113,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(114,NULL,'Latvia',NULL,114,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(115,NULL,'Lebanon',NULL,115,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(116,NULL,'Lesotho',NULL,116,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(117,NULL,'Liberia',NULL,117,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(118,NULL,'Libya',NULL,118,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(119,NULL,'Liechtenstein',NULL,119,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(120,NULL,'Lithuania',NULL,120,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(121,NULL,'Luxembourg',NULL,121,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(122,NULL,'Macao',NULL,122,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(123,NULL,'Macedonia (the former Yugoslav Republic of)',NULL,123,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(124,NULL,'Madagascar',NULL,124,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(125,NULL,'Malawi',NULL,125,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(126,NULL,'Malaysia',NULL,126,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(127,NULL,'Maldives',NULL,127,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(128,NULL,'Mali',NULL,128,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(129,NULL,'Malta',NULL,129,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(130,NULL,'Marshall Islands',NULL,130,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(131,NULL,'Martinique',NULL,131,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(132,NULL,'Mauritania',NULL,132,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(133,NULL,'Mauritius',NULL,133,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(134,NULL,'Mayotte',NULL,134,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(135,NULL,'Mexico',NULL,135,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(136,NULL,'Micronesia (Federated States of)',NULL,136,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(137,NULL,'Moldova (Republic of)',NULL,137,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(138,NULL,'Monaco',NULL,138,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(139,NULL,'Mongolia',NULL,139,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(140,NULL,'Montenegro',NULL,140,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(141,NULL,'Montserrat',NULL,141,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(142,NULL,'Morocco',NULL,142,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(143,NULL,'Mozambique',NULL,143,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(144,NULL,'Myanmar',NULL,144,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(145,NULL,'Namibia',NULL,145,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(146,NULL,'Nauru',NULL,146,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(147,NULL,'Nepal',NULL,147,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(148,NULL,'Netherlands',NULL,148,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(149,NULL,'New Caledonia',NULL,149,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(150,NULL,'New Zealand',NULL,150,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(151,NULL,'Nicaragua',NULL,151,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(152,NULL,'Niger',NULL,152,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(153,NULL,'Nigeria',NULL,153,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(154,NULL,'Niue',NULL,154,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(155,NULL,'Norfolk Island',NULL,155,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(156,NULL,'Northern Mariana Islands',NULL,156,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(157,NULL,'Norway',NULL,157,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(158,NULL,'Oman',NULL,158,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(159,NULL,'Pakistan',NULL,159,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(160,NULL,'Palau',NULL,160,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(161,NULL,'Palestine, State of',NULL,161,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(162,NULL,'Panama',NULL,162,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(163,NULL,'Papua New Guinea',NULL,163,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(164,NULL,'Paraguay',NULL,164,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(165,NULL,'Peru',NULL,165,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(166,NULL,'Philippines',NULL,166,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(167,NULL,'Pitcairn',NULL,167,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(168,NULL,'Poland',NULL,168,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(169,NULL,'Portugal',NULL,169,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(170,NULL,'Puerto Rico',NULL,170,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(171,NULL,'Qatar',NULL,171,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(172,NULL,'Réunion',NULL,172,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(173,NULL,'Romania',NULL,173,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(174,NULL,'Russian Federation',NULL,174,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(175,NULL,'Rwanda',NULL,175,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(176,NULL,'Saint Helena, Ascension and Tristan da Cunha',NULL,176,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(177,NULL,'Saint Kitts and Nevis',NULL,177,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(178,NULL,'Saint Lucia',NULL,178,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(179,NULL,'Saint Pierre and Miquelon',NULL,179,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(180,NULL,'Saint Vincent and the Grenadines',NULL,180,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(181,NULL,'Samoa',NULL,181,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(182,NULL,'San Marino',NULL,182,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(183,NULL,'Sao Tome and Principe',NULL,183,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(184,NULL,'Saudi Arabia',NULL,184,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(185,NULL,'Senegal',NULL,185,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(186,NULL,'Serbia',NULL,186,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(187,NULL,'Seychelles',NULL,187,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(188,NULL,'Sierra Leone',NULL,188,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(189,NULL,'Singapore',NULL,189,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(190,NULL,'Slovakia',NULL,190,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(191,NULL,'Slovenia',NULL,191,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(192,NULL,'Solomon Islands',NULL,192,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(193,NULL,'Somalia',NULL,193,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(194,NULL,'South Africa',NULL,194,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(195,NULL,'Spain',NULL,195,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(196,NULL,'Sri Lanka',NULL,196,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(197,NULL,'Sudan',NULL,197,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(198,NULL,'Suriname',NULL,198,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(199,NULL,'Svalbard and Jan Mayen',NULL,199,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(200,NULL,'Swaziland',NULL,200,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(201,NULL,'Sweden',NULL,201,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(202,NULL,'Switzerland',NULL,202,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(203,NULL,'Syrian Arab Republic',NULL,203,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(204,NULL,'Taiwan, Province of China',NULL,204,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(205,NULL,'Tajikistan',NULL,205,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(206,NULL,'Tanzania, United Republic of',NULL,206,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(207,NULL,'Thailand',NULL,207,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(208,NULL,'Timor-Leste',NULL,208,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(209,NULL,'Togo',NULL,209,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(210,NULL,'Tokelau',NULL,210,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(211,NULL,'Tonga',NULL,211,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(212,NULL,'Trinidad and Tobago',NULL,212,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(213,NULL,'Tunisia',NULL,213,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(214,NULL,'Turkey',NULL,214,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(215,NULL,'Turkmenistan',NULL,215,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(216,NULL,'Turks and Caicos Islands',NULL,216,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(217,NULL,'Tuvalu',NULL,217,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(218,NULL,'Uganda',NULL,218,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(219,NULL,'Ukraine',NULL,219,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(220,NULL,'United Arab Emirates',NULL,220,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(221,NULL,'United Kingdom of Great Britain and Northern Ireland',NULL,221,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(222,NULL,'United States of America',NULL,222,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(223,NULL,'Uruguay',NULL,223,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(224,NULL,'Uzbekistan',NULL,224,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(225,NULL,'Vanuatu',NULL,225,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(226,NULL,'Venezuela (Bolivarian Republic of)',NULL,226,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(227,NULL,'Viet Nam',NULL,227,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(228,NULL,'Virgin Islands (British)',NULL,228,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(229,NULL,'Virgin Islands (U.S.)',NULL,229,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(230,NULL,'Wallis and Futuna',NULL,230,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(231,NULL,'Western Sahara',NULL,231,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(232,NULL,'Yemen',NULL,232,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(233,NULL,'Zambia',NULL,233,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(234,NULL,'Zimbabwe',NULL,234,NULL,NULL,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(235,NULL,NULL,NULL,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(236,NULL,NULL,NULL,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(237,NULL,NULL,NULL,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(238,NULL,NULL,NULL,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(239,NULL,NULL,NULL,222,NULL,5,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(240,NULL,NULL,NULL,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(241,NULL,NULL,NULL,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(242,NULL,NULL,NULL,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(243,NULL,NULL,NULL,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(244,NULL,NULL,NULL,222,NULL,10,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(245,NULL,NULL,NULL,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(246,NULL,NULL,NULL,222,NULL,12,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(247,NULL,NULL,NULL,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(248,NULL,NULL,NULL,222,NULL,14,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(249,NULL,NULL,NULL,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(250,NULL,NULL,NULL,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(251,NULL,NULL,NULL,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(252,NULL,NULL,NULL,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(253,NULL,NULL,NULL,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(254,NULL,NULL,NULL,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(255,NULL,NULL,NULL,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(256,NULL,NULL,NULL,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(257,NULL,NULL,NULL,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(258,NULL,NULL,NULL,222,NULL,24,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(259,NULL,NULL,NULL,222,NULL,25,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(260,NULL,NULL,NULL,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(261,NULL,NULL,NULL,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(262,NULL,NULL,NULL,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(263,NULL,NULL,NULL,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(264,NULL,NULL,NULL,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(265,NULL,NULL,NULL,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(266,NULL,NULL,NULL,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(267,NULL,NULL,NULL,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(268,NULL,NULL,NULL,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(269,NULL,NULL,NULL,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(270,NULL,NULL,NULL,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(271,NULL,NULL,NULL,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(272,NULL,NULL,NULL,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(273,NULL,NULL,NULL,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(274,NULL,NULL,NULL,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(275,NULL,NULL,NULL,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(276,NULL,NULL,NULL,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(277,NULL,NULL,NULL,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(278,NULL,NULL,NULL,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(279,NULL,NULL,NULL,222,NULL,45,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(280,NULL,NULL,NULL,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(281,NULL,NULL,NULL,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(282,NULL,NULL,NULL,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(283,NULL,NULL,NULL,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(284,NULL,NULL,NULL,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(285,NULL,NULL,NULL,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(286,NULL,NULL,NULL,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(287,NULL,NULL,NULL,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(288,NULL,NULL,NULL,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(289,NULL,NULL,NULL,222,NULL,55,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(290,NULL,NULL,NULL,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(291,NULL,NULL,NULL,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(292,NULL,NULL,NULL,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(293,NULL,NULL,NULL,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(294,NULL,'Portsmouth, NH',1,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(295,NULL,'Portsmouth, NH 210',1,222,NULL,29,1,0);
INSERT INTO "django_geo_db_location" VALUES(296,NULL,'Portsmouth, NH 211',1,222,NULL,29,2,0);
INSERT INTO "django_geo_db_location" VALUES(297,NULL,'Portsmouth, NH 212',1,222,NULL,29,3,0);
INSERT INTO "django_geo_db_location" VALUES(298,NULL,'Portsmouth, NH 213',1,222,NULL,29,4,0);
INSERT INTO "django_geo_db_location" VALUES(299,NULL,'Portsmouth, NH 214',1,222,NULL,29,5,0);
INSERT INTO "django_geo_db_location" VALUES(300,NULL,'Portsmouth, NH 215',1,222,NULL,29,6,0);
INSERT INTO "django_geo_db_location" VALUES(301,NULL,'Holtsville, NY',2,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(302,NULL,'Holtsville, NY 501',2,222,NULL,32,7,0);
INSERT INTO "django_geo_db_location" VALUES(303,NULL,'Holtsville, NY 544',2,222,NULL,32,8,0);
INSERT INTO "django_geo_db_location" VALUES(304,NULL,'Adjuntas, PR',3,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(305,NULL,'Adjuntas, PR 601',3,222,NULL,47,9,0);
INSERT INTO "django_geo_db_location" VALUES(306,NULL,'Aguada, PR',4,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(307,NULL,'Aguada, PR 602',4,222,NULL,47,10,0);
INSERT INTO "django_geo_db_location" VALUES(308,NULL,'Aguadilla, PR',5,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(309,NULL,'Aguadilla, PR 603',5,222,NULL,47,11,0);
INSERT INTO "django_geo_db_location" VALUES(310,NULL,'Aguadilla, PR 604',5,222,NULL,47,12,0);
INSERT INTO "django_geo_db_location" VALUES(311,NULL,'Aguadilla, PR 605',5,222,NULL,47,13,0);
INSERT INTO "django_geo_db_location" VALUES(312,NULL,'Maricao, PR',6,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(313,NULL,'Maricao, PR 606',6,222,NULL,47,14,0);
INSERT INTO "django_geo_db_location" VALUES(314,NULL,'Aguas Buenas, PR',7,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(315,NULL,'Aguas Buenas, PR 607',7,222,NULL,47,15,0);
INSERT INTO "django_geo_db_location" VALUES(316,NULL,'Aibonito, PR',8,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(317,NULL,'Aibonito, PR 609',8,222,NULL,47,16,0);
INSERT INTO "django_geo_db_location" VALUES(318,NULL,'Anasco, PR',9,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(319,NULL,'Anasco, PR 610',9,222,NULL,47,17,0);
INSERT INTO "django_geo_db_location" VALUES(320,NULL,'Angeles, PR',10,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(321,NULL,'Angeles, PR 611',10,222,NULL,47,18,0);
INSERT INTO "django_geo_db_location" VALUES(322,NULL,'Arecibo, PR',11,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(323,NULL,'Arecibo, PR 612',11,222,NULL,47,19,0);
INSERT INTO "django_geo_db_location" VALUES(324,NULL,'Arecibo, PR 613',11,222,NULL,47,20,0);
INSERT INTO "django_geo_db_location" VALUES(325,NULL,'Arecibo, PR 614',11,222,NULL,47,21,0);
INSERT INTO "django_geo_db_location" VALUES(326,NULL,'Arroyo, PR',12,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(327,NULL,'Arroyo, PR 615',12,222,NULL,47,22,0);
INSERT INTO "django_geo_db_location" VALUES(328,NULL,'Bajadero, PR',13,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(329,NULL,'Bajadero, PR 616',13,222,NULL,47,23,0);
INSERT INTO "django_geo_db_location" VALUES(330,NULL,'Barceloneta, PR',14,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(331,NULL,'Barceloneta, PR 617',14,222,NULL,47,24,0);
INSERT INTO "django_geo_db_location" VALUES(332,NULL,'Barranquitas, PR',15,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(333,NULL,'Barranquitas, PR 618',15,222,NULL,47,25,0);
INSERT INTO "django_geo_db_location" VALUES(334,NULL,'Boqueron, PR',16,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(335,NULL,'Boqueron, PR 622',16,222,NULL,47,26,0);
INSERT INTO "django_geo_db_location" VALUES(336,NULL,'Cabo Rojo, PR',17,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(337,NULL,'Cabo Rojo, PR 623',17,222,NULL,47,27,0);
INSERT INTO "django_geo_db_location" VALUES(338,NULL,'Penuelas, PR',18,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(339,NULL,'Penuelas, PR 624',18,222,NULL,47,28,0);
INSERT INTO "django_geo_db_location" VALUES(340,NULL,'Caguas, PR',19,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(341,NULL,'Caguas, PR 625',19,222,NULL,47,29,0);
INSERT INTO "django_geo_db_location" VALUES(342,NULL,'Caguas, PR 626',19,222,NULL,47,30,0);
INSERT INTO "django_geo_db_location" VALUES(343,NULL,'Camuy, PR',20,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(344,NULL,'Camuy, PR 627',20,222,NULL,47,31,0);
INSERT INTO "django_geo_db_location" VALUES(345,NULL,'Castaner, PR',21,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(346,NULL,'Castaner, PR 631',21,222,NULL,47,32,0);
INSERT INTO "django_geo_db_location" VALUES(347,NULL,'Cayey, PR',22,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(348,NULL,'Cayey, PR 633',22,222,NULL,47,33,0);
INSERT INTO "django_geo_db_location" VALUES(349,NULL,'Cayey, PR 634',22,222,NULL,47,34,0);
INSERT INTO "django_geo_db_location" VALUES(350,NULL,'Ceiba, PR',23,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(351,NULL,'Ceiba, PR 635',23,222,NULL,47,35,0);
INSERT INTO "django_geo_db_location" VALUES(352,NULL,'Rosario, PR',24,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(353,NULL,'Rosario, PR 636',24,222,NULL,47,36,0);
INSERT INTO "django_geo_db_location" VALUES(354,NULL,'Sabana Grande, PR',25,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(355,NULL,'Sabana Grande, PR 637',25,222,NULL,47,37,0);
INSERT INTO "django_geo_db_location" VALUES(356,NULL,'Ciales, PR',26,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(357,NULL,'Ciales, PR 638',26,222,NULL,47,38,0);
INSERT INTO "django_geo_db_location" VALUES(358,NULL,'Cidra, PR',27,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(359,NULL,'Cidra, PR 639',27,222,NULL,47,39,0);
INSERT INTO "django_geo_db_location" VALUES(360,NULL,'Coamo, PR',28,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(361,NULL,'Coamo, PR 640',28,222,NULL,47,40,0);
INSERT INTO "django_geo_db_location" VALUES(362,NULL,'Utuado, PR',29,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(363,NULL,'Utuado, PR 641',29,222,NULL,47,41,0);
INSERT INTO "django_geo_db_location" VALUES(364,NULL,'Corozal, PR',30,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(365,NULL,'Corozal, PR 643',30,222,NULL,47,42,0);
INSERT INTO "django_geo_db_location" VALUES(366,NULL,'Coto Laurel, PR',31,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(367,NULL,'Coto Laurel, PR 644',31,222,NULL,47,43,0);
INSERT INTO "django_geo_db_location" VALUES(368,NULL,'Culebra, PR',32,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(369,NULL,'Culebra, PR 645',32,222,NULL,47,44,0);
INSERT INTO "django_geo_db_location" VALUES(370,NULL,'Dorado, PR',33,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(371,NULL,'Dorado, PR 646',33,222,NULL,47,45,0);
INSERT INTO "django_geo_db_location" VALUES(372,NULL,'Ensenada, PR',34,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(373,NULL,'Ensenada, PR 647',34,222,NULL,47,46,0);
INSERT INTO "django_geo_db_location" VALUES(374,NULL,'Fajardo, PR',35,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(375,NULL,'Fajardo, PR 648',35,222,NULL,47,47,0);
INSERT INTO "django_geo_db_location" VALUES(376,NULL,'Florida, PR',36,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(377,NULL,'Florida, PR 650',36,222,NULL,47,48,0);
INSERT INTO "django_geo_db_location" VALUES(378,NULL,'Garrochales, PR',37,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(379,NULL,'Garrochales, PR 652',37,222,NULL,47,49,0);
INSERT INTO "django_geo_db_location" VALUES(380,NULL,'Guanica, PR',38,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(381,NULL,'Guanica, PR 653',38,222,NULL,47,50,0);
INSERT INTO "django_geo_db_location" VALUES(382,NULL,'Jobos, PR',39,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(383,NULL,'Jobos, PR 654',39,222,NULL,47,51,0);
INSERT INTO "django_geo_db_location" VALUES(384,NULL,'Olimpo, PR',40,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(385,NULL,'Olimpo, PR 655',40,222,NULL,47,52,0);
INSERT INTO "django_geo_db_location" VALUES(386,NULL,'Guayanilla, PR',41,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(387,NULL,'Guayanilla, PR 656',41,222,NULL,47,53,0);
INSERT INTO "django_geo_db_location" VALUES(388,NULL,'Gurabo, PR',42,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(389,NULL,'Gurabo, PR 658',42,222,NULL,47,54,0);
INSERT INTO "django_geo_db_location" VALUES(390,NULL,'Hatillo, PR',43,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(391,NULL,'Hatillo, PR 659',43,222,NULL,47,55,0);
INSERT INTO "django_geo_db_location" VALUES(392,NULL,'Hormigueros, PR',44,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(393,NULL,'Hormigueros, PR 660',44,222,NULL,47,56,0);
INSERT INTO "django_geo_db_location" VALUES(394,NULL,'Humacao, PR',45,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(395,NULL,'Humacao, PR 661',45,222,NULL,47,57,0);
INSERT INTO "django_geo_db_location" VALUES(396,NULL,'Isabela, PR',46,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(397,NULL,'Isabela, PR 662',46,222,NULL,47,58,0);
INSERT INTO "django_geo_db_location" VALUES(398,NULL,'Jayuya, PR',47,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(399,NULL,'Jayuya, PR 664',47,222,NULL,47,59,0);
INSERT INTO "django_geo_db_location" VALUES(400,NULL,'Ponce, PR',48,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(401,NULL,'Ponce, PR 665',48,222,NULL,47,60,0);
INSERT INTO "django_geo_db_location" VALUES(402,NULL,'Juncos, PR',49,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(403,NULL,'Juncos, PR 666',49,222,NULL,47,61,0);
INSERT INTO "django_geo_db_location" VALUES(404,NULL,'Lajas, PR',50,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(405,NULL,'Lajas, PR 667',50,222,NULL,47,62,0);
INSERT INTO "django_geo_db_location" VALUES(406,NULL,'Lares, PR',51,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(407,NULL,'Lares, PR 669',51,222,NULL,47,63,0);
INSERT INTO "django_geo_db_location" VALUES(408,NULL,'Las Marias, PR',52,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(409,NULL,'Las Marias, PR 670',52,222,NULL,47,64,0);
INSERT INTO "django_geo_db_location" VALUES(410,NULL,'Las Piedras, PR',53,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(411,NULL,'Las Piedras, PR 671',53,222,NULL,47,65,0);
INSERT INTO "django_geo_db_location" VALUES(412,NULL,'Manati, PR',54,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(413,NULL,'Manati, PR 674',54,222,NULL,47,66,0);
INSERT INTO "django_geo_db_location" VALUES(414,NULL,'Moca, PR',55,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(415,NULL,'Moca, PR 676',55,222,NULL,47,67,0);
INSERT INTO "django_geo_db_location" VALUES(416,NULL,'Rincon, PR',56,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(417,NULL,'Rincon, PR 677',56,222,NULL,47,68,0);
INSERT INTO "django_geo_db_location" VALUES(418,NULL,'Quebradillas, PR',57,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(419,NULL,'Quebradillas, PR 678',57,222,NULL,47,69,0);
INSERT INTO "django_geo_db_location" VALUES(420,NULL,'Mayaguez, PR',58,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(421,NULL,'Mayaguez, PR 680',58,222,NULL,47,70,0);
INSERT INTO "django_geo_db_location" VALUES(422,NULL,'Mayaguez, PR 681',58,222,NULL,47,71,0);
INSERT INTO "django_geo_db_location" VALUES(423,NULL,'Mayaguez, PR 682',58,222,NULL,47,72,0);
INSERT INTO "django_geo_db_location" VALUES(424,NULL,'San German, PR',59,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(425,NULL,'San German, PR 683',59,222,NULL,47,73,0);
INSERT INTO "django_geo_db_location" VALUES(426,NULL,'San Sebastian, PR',60,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(427,NULL,'San Sebastian, PR 685',60,222,NULL,47,74,0);
INSERT INTO "django_geo_db_location" VALUES(428,NULL,'Morovis, PR',61,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(429,NULL,'Morovis, PR 687',61,222,NULL,47,75,0);
INSERT INTO "django_geo_db_location" VALUES(430,NULL,'Sabana Hoyos, PR',62,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(431,NULL,'Sabana Hoyos, PR 688',62,222,NULL,47,76,0);
INSERT INTO "django_geo_db_location" VALUES(432,NULL,'San Antonio, PR',63,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(433,NULL,'San Antonio, PR 690',63,222,NULL,47,77,0);
INSERT INTO "django_geo_db_location" VALUES(434,NULL,'Vega Alta, PR',64,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(435,NULL,'Vega Alta, PR 692',64,222,NULL,47,78,0);
INSERT INTO "django_geo_db_location" VALUES(436,NULL,'Vega Baja, PR',65,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(437,NULL,'Vega Baja, PR 693',65,222,NULL,47,79,0);
INSERT INTO "django_geo_db_location" VALUES(438,NULL,'Vega Baja, PR 694',65,222,NULL,47,80,0);
INSERT INTO "django_geo_db_location" VALUES(439,NULL,'Yauco, PR',66,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(440,NULL,'Yauco, PR 698',66,222,NULL,47,81,0);
INSERT INTO "django_geo_db_location" VALUES(441,NULL,'Aguas Buenas, PR 703',7,222,NULL,47,82,0);
INSERT INTO "django_geo_db_location" VALUES(442,NULL,'Aguirre, PR',67,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(443,NULL,'Aguirre, PR 704',67,222,NULL,47,83,0);
INSERT INTO "django_geo_db_location" VALUES(444,NULL,'Aibonito, PR 705',8,222,NULL,47,84,0);
INSERT INTO "django_geo_db_location" VALUES(445,NULL,'Maunabo, PR',68,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(446,NULL,'Maunabo, PR 707',68,222,NULL,47,85,0);
INSERT INTO "django_geo_db_location" VALUES(447,NULL,'Arroyo, PR 714',12,222,NULL,47,86,0);
INSERT INTO "django_geo_db_location" VALUES(448,NULL,'Mercedita, PR',69,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(449,NULL,'Mercedita, PR 715',69,222,NULL,47,87,0);
INSERT INTO "django_geo_db_location" VALUES(450,NULL,'Ponce, PR 716',48,222,NULL,47,88,0);
INSERT INTO "django_geo_db_location" VALUES(451,NULL,'Ponce, PR 717',48,222,NULL,47,89,0);
INSERT INTO "django_geo_db_location" VALUES(452,NULL,'Naguabo, PR',70,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(453,NULL,'Naguabo, PR 718',70,222,NULL,47,90,0);
INSERT INTO "django_geo_db_location" VALUES(454,NULL,'Naranjito, PR',71,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(455,NULL,'Naranjito, PR 719',71,222,NULL,47,91,0);
INSERT INTO "django_geo_db_location" VALUES(456,NULL,'Orocovis, PR',72,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(457,NULL,'Orocovis, PR 720',72,222,NULL,47,92,0);
INSERT INTO "django_geo_db_location" VALUES(458,NULL,'Palmer, PR',73,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(459,NULL,'Palmer, PR 721',73,222,NULL,47,93,0);
INSERT INTO "django_geo_db_location" VALUES(460,NULL,'Patillas, PR',74,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(461,NULL,'Patillas, PR 723',74,222,NULL,47,94,0);
INSERT INTO "django_geo_db_location" VALUES(462,NULL,'Caguas, PR 725',19,222,NULL,47,95,0);
INSERT INTO "django_geo_db_location" VALUES(463,NULL,'Caguas, PR 726',19,222,NULL,47,96,0);
INSERT INTO "django_geo_db_location" VALUES(464,NULL,'Ponce, PR 728',48,222,NULL,47,97,0);
INSERT INTO "django_geo_db_location" VALUES(465,NULL,'Canovanas, PR',75,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(466,NULL,'Canovanas, PR 729',75,222,NULL,47,98,0);
INSERT INTO "django_geo_db_location" VALUES(467,NULL,'Ponce, PR 730',48,222,NULL,47,99,0);
INSERT INTO "django_geo_db_location" VALUES(468,NULL,'Ponce, PR 731',48,222,NULL,47,100,0);
INSERT INTO "django_geo_db_location" VALUES(469,NULL,'Ponce, PR 732',48,222,NULL,47,101,0);
INSERT INTO "django_geo_db_location" VALUES(470,NULL,'Ponce, PR 733',48,222,NULL,47,102,0);
INSERT INTO "django_geo_db_location" VALUES(471,NULL,'Ponce, PR 734',48,222,NULL,47,103,0);
INSERT INTO "django_geo_db_location" VALUES(472,NULL,'Ceiba, PR 735',23,222,NULL,47,104,0);
INSERT INTO "django_geo_db_location" VALUES(473,NULL,'Cayey, PR 736',22,222,NULL,47,105,0);
INSERT INTO "django_geo_db_location" VALUES(474,NULL,'Cayey, PR 737',22,222,NULL,47,106,0);
INSERT INTO "django_geo_db_location" VALUES(475,NULL,'Fajardo, PR 738',35,222,NULL,47,107,0);
INSERT INTO "django_geo_db_location" VALUES(476,NULL,'Cidra, PR 739',27,222,NULL,47,108,0);
INSERT INTO "django_geo_db_location" VALUES(477,NULL,'Puerto Real, PR',76,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(478,NULL,'Puerto Real, PR 740',76,222,NULL,47,109,0);
INSERT INTO "django_geo_db_location" VALUES(479,NULL,'Punta Santiago, PR',77,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(480,NULL,'Punta Santiago, PR 741',77,222,NULL,47,110,0);
INSERT INTO "django_geo_db_location" VALUES(481,NULL,'Roosevelt Roads, PR',78,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(482,NULL,'Roosevelt Roads, PR 742',78,222,NULL,47,111,0);
INSERT INTO "django_geo_db_location" VALUES(483,NULL,'Rio Blanco, PR',79,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(484,NULL,'Rio Blanco, PR 744',79,222,NULL,47,112,0);
INSERT INTO "django_geo_db_location" VALUES(485,NULL,'Rio Grande, PR',80,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(486,NULL,'Rio Grande, PR 745',80,222,NULL,47,113,0);
INSERT INTO "django_geo_db_location" VALUES(487,NULL,'Lluveras, PR',81,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(488,NULL,'Lluveras, PR 747',81,222,NULL,47,114,0);
INSERT INTO "django_geo_db_location" VALUES(489,NULL,'Fajardo, PR 748',35,222,NULL,47,115,0);
INSERT INTO "django_geo_db_location" VALUES(490,NULL,'Salinas, PR',82,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(491,NULL,'Salinas, PR 751',82,222,NULL,47,116,0);
INSERT INTO "django_geo_db_location" VALUES(492,NULL,'San Antonio, PR 752',63,222,NULL,47,117,0);
INSERT INTO "django_geo_db_location" VALUES(493,NULL,'San Lorenzo, PR',83,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(494,NULL,'San Lorenzo, PR 754',83,222,NULL,47,118,0);
INSERT INTO "django_geo_db_location" VALUES(495,NULL,'Santa Isabel, PR',84,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(496,NULL,'Santa Isabel, PR 757',84,222,NULL,47,119,0);
INSERT INTO "django_geo_db_location" VALUES(497,NULL,'Utuado, PR 761',29,222,NULL,47,120,0);
INSERT INTO "django_geo_db_location" VALUES(498,NULL,'Vega Alta, PR 762',64,222,NULL,47,121,0);
INSERT INTO "django_geo_db_location" VALUES(499,NULL,'Monserrate, PR',85,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(500,NULL,'Monserrate, PR 763',85,222,NULL,47,122,0);
INSERT INTO "django_geo_db_location" VALUES(501,NULL,'Vega Baja, PR 764',65,222,NULL,47,123,0);
INSERT INTO "django_geo_db_location" VALUES(502,NULL,'Vieques, PR',86,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(503,NULL,'Vieques, PR 765',86,222,NULL,47,124,0);
INSERT INTO "django_geo_db_location" VALUES(504,NULL,'Villalba, PR',87,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(505,NULL,'Villalba, PR 766',87,222,NULL,47,125,0);
INSERT INTO "django_geo_db_location" VALUES(506,NULL,'Yabucoa, PR',88,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(507,NULL,'Yabucoa, PR 767',88,222,NULL,47,126,0);
INSERT INTO "django_geo_db_location" VALUES(508,NULL,'Yauco, PR 768',66,222,NULL,47,127,0);
INSERT INTO "django_geo_db_location" VALUES(509,NULL,'Coamo, PR 769',28,222,NULL,47,128,0);
INSERT INTO "django_geo_db_location" VALUES(510,NULL,'Las Piedras, PR 771',53,222,NULL,47,129,0);
INSERT INTO "django_geo_db_location" VALUES(511,NULL,'Loiza, PR',89,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(512,NULL,'Loiza, PR 772',89,222,NULL,47,130,0);
INSERT INTO "django_geo_db_location" VALUES(513,NULL,'Luquillo, PR',90,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(514,NULL,'Luquillo, PR 773',90,222,NULL,47,131,0);
INSERT INTO "django_geo_db_location" VALUES(515,NULL,'Culebra, PR 775',32,222,NULL,47,132,0);
INSERT INTO "django_geo_db_location" VALUES(516,NULL,'Juncos, PR 777',49,222,NULL,47,133,0);
INSERT INTO "django_geo_db_location" VALUES(517,NULL,'Gurabo, PR 778',42,222,NULL,47,134,0);
INSERT INTO "django_geo_db_location" VALUES(518,NULL,'Coto Laurel, PR 780',31,222,NULL,47,135,0);
INSERT INTO "django_geo_db_location" VALUES(519,NULL,'Comerio, PR',91,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(520,NULL,'Comerio, PR 782',91,222,NULL,47,136,0);
INSERT INTO "django_geo_db_location" VALUES(521,NULL,'Corozal, PR 783',30,222,NULL,47,137,0);
INSERT INTO "django_geo_db_location" VALUES(522,NULL,'Guayama, PR',92,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(523,NULL,'Guayama, PR 784',92,222,NULL,47,138,0);
INSERT INTO "django_geo_db_location" VALUES(524,NULL,'Guayama, PR 785',92,222,NULL,47,139,0);
INSERT INTO "django_geo_db_location" VALUES(525,NULL,'La Plata, PR',93,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(526,NULL,'La Plata, PR 786',93,222,NULL,47,140,0);
INSERT INTO "django_geo_db_location" VALUES(527,NULL,'Humacao, PR 791',45,222,NULL,47,141,0);
INSERT INTO "django_geo_db_location" VALUES(528,NULL,'Humacao, PR 792',45,222,NULL,47,142,0);
INSERT INTO "django_geo_db_location" VALUES(529,NULL,'Barranquitas, PR 794',15,222,NULL,47,143,0);
INSERT INTO "django_geo_db_location" VALUES(530,NULL,'Juana Diaz, PR',94,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(531,NULL,'Juana Diaz, PR 795',94,222,NULL,47,144,0);
INSERT INTO "django_geo_db_location" VALUES(532,NULL,'St Thomas, VI',95,222,NULL,55,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(533,NULL,'St Thomas, VI 801',95,222,NULL,55,145,0);
INSERT INTO "django_geo_db_location" VALUES(534,NULL,'St Thomas, VI 802',95,222,NULL,55,146,0);
INSERT INTO "django_geo_db_location" VALUES(535,NULL,'St Thomas, VI 803',95,222,NULL,55,147,0);
INSERT INTO "django_geo_db_location" VALUES(536,NULL,'St Thomas, VI 804',95,222,NULL,55,148,0);
INSERT INTO "django_geo_db_location" VALUES(537,NULL,'St Thomas, VI 805',95,222,NULL,55,149,0);
INSERT INTO "django_geo_db_location" VALUES(538,NULL,'Christiansted, VI',96,222,NULL,55,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(539,NULL,'Christiansted, VI 820',96,222,NULL,55,150,0);
INSERT INTO "django_geo_db_location" VALUES(540,NULL,'Christiansted, VI 821',96,222,NULL,55,151,0);
INSERT INTO "django_geo_db_location" VALUES(541,NULL,'Christiansted, VI 822',96,222,NULL,55,152,0);
INSERT INTO "django_geo_db_location" VALUES(542,NULL,'Christiansted, VI 823',96,222,NULL,55,153,0);
INSERT INTO "django_geo_db_location" VALUES(543,NULL,'Christiansted, VI 824',96,222,NULL,55,154,0);
INSERT INTO "django_geo_db_location" VALUES(544,NULL,'St John, VI',97,222,NULL,55,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(545,NULL,'St John, VI 830',97,222,NULL,55,155,0);
INSERT INTO "django_geo_db_location" VALUES(546,NULL,'St John, VI 831',97,222,NULL,55,156,0);
INSERT INTO "django_geo_db_location" VALUES(547,NULL,'Frederiksted, VI',98,222,NULL,55,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(548,NULL,'Frederiksted, VI 840',98,222,NULL,55,157,0);
INSERT INTO "django_geo_db_location" VALUES(549,NULL,'Frederiksted, VI 841',98,222,NULL,55,158,0);
INSERT INTO "django_geo_db_location" VALUES(550,NULL,'Kingshill, VI',99,222,NULL,55,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(551,NULL,'Kingshill, VI 850',99,222,NULL,55,159,0);
INSERT INTO "django_geo_db_location" VALUES(552,NULL,'Kingshill, VI 851',99,222,NULL,55,160,0);
INSERT INTO "django_geo_db_location" VALUES(553,NULL,'San Juan, PR',100,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(554,NULL,'San Juan, PR 901',100,222,NULL,47,161,0);
INSERT INTO "django_geo_db_location" VALUES(555,NULL,'San Juan, PR 902',100,222,NULL,47,162,0);
INSERT INTO "django_geo_db_location" VALUES(556,NULL,'San Juan, PR 906',100,222,NULL,47,163,0);
INSERT INTO "django_geo_db_location" VALUES(557,NULL,'San Juan, PR 907',100,222,NULL,47,164,0);
INSERT INTO "django_geo_db_location" VALUES(558,NULL,'San Juan, PR 908',100,222,NULL,47,165,0);
INSERT INTO "django_geo_db_location" VALUES(559,NULL,'San Juan, PR 909',100,222,NULL,47,166,0);
INSERT INTO "django_geo_db_location" VALUES(560,NULL,'San Juan, PR 910',100,222,NULL,47,167,0);
INSERT INTO "django_geo_db_location" VALUES(561,NULL,'San Juan, PR 911',100,222,NULL,47,168,0);
INSERT INTO "django_geo_db_location" VALUES(562,NULL,'San Juan, PR 912',100,222,NULL,47,169,0);
INSERT INTO "django_geo_db_location" VALUES(563,NULL,'San Juan, PR 913',100,222,NULL,47,170,0);
INSERT INTO "django_geo_db_location" VALUES(564,NULL,'San Juan, PR 914',100,222,NULL,47,171,0);
INSERT INTO "django_geo_db_location" VALUES(565,NULL,'San Juan, PR 915',100,222,NULL,47,172,0);
INSERT INTO "django_geo_db_location" VALUES(566,NULL,'San Juan, PR 916',100,222,NULL,47,173,0);
INSERT INTO "django_geo_db_location" VALUES(567,NULL,'San Juan, PR 917',100,222,NULL,47,174,0);
INSERT INTO "django_geo_db_location" VALUES(568,NULL,'San Juan, PR 918',100,222,NULL,47,175,0);
INSERT INTO "django_geo_db_location" VALUES(569,NULL,'San Juan, PR 919',100,222,NULL,47,176,0);
INSERT INTO "django_geo_db_location" VALUES(570,NULL,'San Juan, PR 920',100,222,NULL,47,177,0);
INSERT INTO "django_geo_db_location" VALUES(571,NULL,'San Juan, PR 921',100,222,NULL,47,178,0);
INSERT INTO "django_geo_db_location" VALUES(572,NULL,'San Juan, PR 922',100,222,NULL,47,179,0);
INSERT INTO "django_geo_db_location" VALUES(573,NULL,'San Juan, PR 923',100,222,NULL,47,180,0);
INSERT INTO "django_geo_db_location" VALUES(574,NULL,'San Juan, PR 924',100,222,NULL,47,181,0);
INSERT INTO "django_geo_db_location" VALUES(575,NULL,'San Juan, PR 925',100,222,NULL,47,182,0);
INSERT INTO "django_geo_db_location" VALUES(576,NULL,'San Juan, PR 926',100,222,NULL,47,183,0);
INSERT INTO "django_geo_db_location" VALUES(577,NULL,'San Juan, PR 927',100,222,NULL,47,184,0);
INSERT INTO "django_geo_db_location" VALUES(578,NULL,'San Juan, PR 928',100,222,NULL,47,185,0);
INSERT INTO "django_geo_db_location" VALUES(579,NULL,'San Juan, PR 929',100,222,NULL,47,186,0);
INSERT INTO "django_geo_db_location" VALUES(580,NULL,'San Juan, PR 930',100,222,NULL,47,187,0);
INSERT INTO "django_geo_db_location" VALUES(581,NULL,'San Juan, PR 931',100,222,NULL,47,188,0);
INSERT INTO "django_geo_db_location" VALUES(582,NULL,'San Juan, PR 933',100,222,NULL,47,189,0);
INSERT INTO "django_geo_db_location" VALUES(583,NULL,'Fort Buchanan, PR',101,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(584,NULL,'Fort Buchanan, PR 934',101,222,NULL,47,190,0);
INSERT INTO "django_geo_db_location" VALUES(585,NULL,'San Juan, PR 935',100,222,NULL,47,191,0);
INSERT INTO "django_geo_db_location" VALUES(586,NULL,'San Juan, PR 936',100,222,NULL,47,192,0);
INSERT INTO "django_geo_db_location" VALUES(587,NULL,'San Juan, PR 937',100,222,NULL,47,193,0);
INSERT INTO "django_geo_db_location" VALUES(588,NULL,'San Juan, PR 938',100,222,NULL,47,194,0);
INSERT INTO "django_geo_db_location" VALUES(589,NULL,'San Juan, PR 939',100,222,NULL,47,195,0);
INSERT INTO "django_geo_db_location" VALUES(590,NULL,'San Juan, PR 940',100,222,NULL,47,196,0);
INSERT INTO "django_geo_db_location" VALUES(591,NULL,'Toa Baja, PR',102,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(592,NULL,'Toa Baja, PR 949',102,222,NULL,47,197,0);
INSERT INTO "django_geo_db_location" VALUES(593,NULL,'Toa Baja, PR 950',102,222,NULL,47,198,0);
INSERT INTO "django_geo_db_location" VALUES(594,NULL,'Toa Baja, PR 951',102,222,NULL,47,199,0);
INSERT INTO "django_geo_db_location" VALUES(595,NULL,'Sabana Seca, PR',103,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(596,NULL,'Sabana Seca, PR 952',103,222,NULL,47,200,0);
INSERT INTO "django_geo_db_location" VALUES(597,NULL,'Toa Alta, PR',104,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(598,NULL,'Toa Alta, PR 953',104,222,NULL,47,201,0);
INSERT INTO "django_geo_db_location" VALUES(599,NULL,'Toa Alta, PR 954',104,222,NULL,47,202,0);
INSERT INTO "django_geo_db_location" VALUES(600,NULL,'San Juan, PR 955',100,222,NULL,47,203,0);
INSERT INTO "django_geo_db_location" VALUES(601,NULL,'Bayamon, PR',105,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(602,NULL,'Bayamon, PR 956',105,222,NULL,47,204,0);
INSERT INTO "django_geo_db_location" VALUES(603,NULL,'Bayamon, PR 957',105,222,NULL,47,205,0);
INSERT INTO "django_geo_db_location" VALUES(604,NULL,'Bayamon, PR 958',105,222,NULL,47,206,0);
INSERT INTO "django_geo_db_location" VALUES(605,NULL,'Bayamon, PR 959',105,222,NULL,47,207,0);
INSERT INTO "django_geo_db_location" VALUES(606,NULL,'Bayamon, PR 960',105,222,NULL,47,208,0);
INSERT INTO "django_geo_db_location" VALUES(607,NULL,'Bayamon, PR 961',105,222,NULL,47,209,0);
INSERT INTO "django_geo_db_location" VALUES(608,NULL,'Catano, PR',106,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(609,NULL,'Catano, PR 962',106,222,NULL,47,210,0);
INSERT INTO "django_geo_db_location" VALUES(610,NULL,'Catano, PR 963',106,222,NULL,47,211,0);
INSERT INTO "django_geo_db_location" VALUES(611,NULL,'Guaynabo, PR',107,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(612,NULL,'Guaynabo, PR 965',107,222,NULL,47,212,0);
INSERT INTO "django_geo_db_location" VALUES(613,NULL,'Guaynabo, PR 966',107,222,NULL,47,213,0);
INSERT INTO "django_geo_db_location" VALUES(614,NULL,'Guaynabo, PR 968',107,222,NULL,47,214,0);
INSERT INTO "django_geo_db_location" VALUES(615,NULL,'Guaynabo, PR 969',107,222,NULL,47,215,0);
INSERT INTO "django_geo_db_location" VALUES(616,NULL,'Guaynabo, PR 970',107,222,NULL,47,216,0);
INSERT INTO "django_geo_db_location" VALUES(617,NULL,'Guaynabo, PR 971',107,222,NULL,47,217,0);
INSERT INTO "django_geo_db_location" VALUES(618,NULL,'San Juan, PR 975',100,222,NULL,47,218,0);
INSERT INTO "django_geo_db_location" VALUES(619,NULL,'Trujillo Alto, PR',108,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(620,NULL,'Trujillo Alto, PR 976',108,222,NULL,47,219,0);
INSERT INTO "django_geo_db_location" VALUES(621,NULL,'Trujillo Alto, PR 977',108,222,NULL,47,220,0);
INSERT INTO "django_geo_db_location" VALUES(622,NULL,'St Just, PR',109,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(623,NULL,'St Just, PR 978',109,222,NULL,47,221,0);
INSERT INTO "django_geo_db_location" VALUES(624,NULL,'Carolina, PR',110,222,NULL,47,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(625,NULL,'Carolina, PR 979',110,222,NULL,47,222,0);
INSERT INTO "django_geo_db_location" VALUES(626,NULL,'Carolina, PR 981',110,222,NULL,47,223,0);
INSERT INTO "django_geo_db_location" VALUES(627,NULL,'Carolina, PR 982',110,222,NULL,47,224,0);
INSERT INTO "django_geo_db_location" VALUES(628,NULL,'Carolina, PR 983',110,222,NULL,47,225,0);
INSERT INTO "django_geo_db_location" VALUES(629,NULL,'Carolina, PR 984',110,222,NULL,47,226,0);
INSERT INTO "django_geo_db_location" VALUES(630,NULL,'Carolina, PR 985',110,222,NULL,47,227,0);
INSERT INTO "django_geo_db_location" VALUES(631,NULL,'Carolina, PR 986',110,222,NULL,47,228,0);
INSERT INTO "django_geo_db_location" VALUES(632,NULL,'Carolina, PR 987',110,222,NULL,47,229,0);
INSERT INTO "django_geo_db_location" VALUES(633,NULL,'Carolina, PR 988',110,222,NULL,47,230,0);
INSERT INTO "django_geo_db_location" VALUES(634,NULL,'Agawam, MA',111,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(635,NULL,'Agawam, MA 1001',111,222,NULL,39,231,0);
INSERT INTO "django_geo_db_location" VALUES(636,NULL,'Amherst, MA',112,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(637,NULL,'Amherst, MA 1002',112,222,NULL,39,232,0);
INSERT INTO "django_geo_db_location" VALUES(638,NULL,'Amherst, MA 1003',112,222,NULL,39,233,0);
INSERT INTO "django_geo_db_location" VALUES(639,NULL,'Amherst, MA 1004',112,222,NULL,39,234,0);
INSERT INTO "django_geo_db_location" VALUES(640,NULL,'Barre, MA',113,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(641,NULL,'Barre, MA 1005',113,222,NULL,39,235,0);
INSERT INTO "django_geo_db_location" VALUES(642,NULL,'Belchertown, MA',114,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(643,NULL,'Belchertown, MA 1007',114,222,NULL,39,236,0);
INSERT INTO "django_geo_db_location" VALUES(644,NULL,'Blandford, MA',115,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(645,NULL,'Blandford, MA 1008',115,222,NULL,39,237,0);
INSERT INTO "django_geo_db_location" VALUES(646,NULL,'Bondsville, MA',116,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(647,NULL,'Bondsville, MA 1009',116,222,NULL,39,238,0);
INSERT INTO "django_geo_db_location" VALUES(648,NULL,'Brimfield, MA',117,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(649,NULL,'Brimfield, MA 1010',117,222,NULL,39,239,0);
INSERT INTO "django_geo_db_location" VALUES(650,NULL,'Chester, MA',118,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(651,NULL,'Chester, MA 1011',118,222,NULL,39,240,0);
INSERT INTO "django_geo_db_location" VALUES(652,NULL,'Chesterfield, MA',119,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(653,NULL,'Chesterfield, MA 1012',119,222,NULL,39,241,0);
INSERT INTO "django_geo_db_location" VALUES(654,NULL,'Chicopee, MA',120,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(655,NULL,'Chicopee, MA 1013',120,222,NULL,39,242,0);
INSERT INTO "django_geo_db_location" VALUES(656,NULL,'Chicopee, MA 1014',120,222,NULL,39,243,0);
INSERT INTO "django_geo_db_location" VALUES(657,NULL,'Chicopee, MA 1020',120,222,NULL,39,244,0);
INSERT INTO "django_geo_db_location" VALUES(658,NULL,'Chicopee, MA 1021',120,222,NULL,39,245,0);
INSERT INTO "django_geo_db_location" VALUES(659,NULL,'Chicopee, MA 1022',120,222,NULL,39,246,0);
INSERT INTO "django_geo_db_location" VALUES(660,NULL,'Cummington, MA',121,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(661,NULL,'Cummington, MA 1026',121,222,NULL,39,247,0);
INSERT INTO "django_geo_db_location" VALUES(662,NULL,'Easthampton, MA',122,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(663,NULL,'Easthampton, MA 1027',122,222,NULL,39,248,0);
INSERT INTO "django_geo_db_location" VALUES(664,NULL,'East Longmeadow, MA',123,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(665,NULL,'East Longmeadow, MA 1028',123,222,NULL,39,249,0);
INSERT INTO "django_geo_db_location" VALUES(666,NULL,'East Otis, MA',124,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(667,NULL,'East Otis, MA 1029',124,222,NULL,39,250,0);
INSERT INTO "django_geo_db_location" VALUES(668,NULL,'Feeding Hills, MA',125,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(669,NULL,'Feeding Hills, MA 1030',125,222,NULL,39,251,0);
INSERT INTO "django_geo_db_location" VALUES(670,NULL,'Gilbertville, MA',126,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(671,NULL,'Gilbertville, MA 1031',126,222,NULL,39,252,0);
INSERT INTO "django_geo_db_location" VALUES(672,NULL,'Goshen, MA',127,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(673,NULL,'Goshen, MA 1032',127,222,NULL,39,253,0);
INSERT INTO "django_geo_db_location" VALUES(674,NULL,'Granby, MA',128,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(675,NULL,'Granby, MA 1033',128,222,NULL,39,254,0);
INSERT INTO "django_geo_db_location" VALUES(676,NULL,'Granville, MA',129,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(677,NULL,'Granville, MA 1034',129,222,NULL,39,255,0);
INSERT INTO "django_geo_db_location" VALUES(678,NULL,'Hadley, MA',130,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(679,NULL,'Hadley, MA 1035',130,222,NULL,39,256,0);
INSERT INTO "django_geo_db_location" VALUES(680,NULL,'Hampden, MA',131,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(681,NULL,'Hampden, MA 1036',131,222,NULL,39,257,0);
INSERT INTO "django_geo_db_location" VALUES(682,NULL,'Hardwick, MA',132,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(683,NULL,'Hardwick, MA 1037',132,222,NULL,39,258,0);
INSERT INTO "django_geo_db_location" VALUES(684,NULL,'Hatfield, MA',133,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(685,NULL,'Hatfield, MA 1038',133,222,NULL,39,259,0);
INSERT INTO "django_geo_db_location" VALUES(686,NULL,'Haydenville, MA',134,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(687,NULL,'Haydenville, MA 1039',134,222,NULL,39,260,0);
INSERT INTO "django_geo_db_location" VALUES(688,NULL,'Holyoke, MA',135,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(689,NULL,'Holyoke, MA 1040',135,222,NULL,39,261,0);
INSERT INTO "django_geo_db_location" VALUES(690,NULL,'Holyoke, MA 1041',135,222,NULL,39,262,0);
INSERT INTO "django_geo_db_location" VALUES(691,NULL,'Huntington, MA',136,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(692,NULL,'Huntington, MA 1050',136,222,NULL,39,263,0);
INSERT INTO "django_geo_db_location" VALUES(693,NULL,'Leeds, MA',137,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(694,NULL,'Leeds, MA 1053',137,222,NULL,39,264,0);
INSERT INTO "django_geo_db_location" VALUES(695,NULL,'Leverett, MA',138,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(696,NULL,'Leverett, MA 1054',138,222,NULL,39,265,0);
INSERT INTO "django_geo_db_location" VALUES(697,NULL,'Ludlow, MA',139,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(698,NULL,'Ludlow, MA 1056',139,222,NULL,39,266,0);
INSERT INTO "django_geo_db_location" VALUES(699,NULL,'Monson, MA',140,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(700,NULL,'Monson, MA 1057',140,222,NULL,39,267,0);
INSERT INTO "django_geo_db_location" VALUES(701,NULL,'North Amherst, MA',141,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(702,NULL,'North Amherst, MA 1059',141,222,NULL,39,268,0);
INSERT INTO "django_geo_db_location" VALUES(703,NULL,'Northampton, MA',142,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(704,NULL,'Northampton, MA 1060',142,222,NULL,39,269,0);
INSERT INTO "django_geo_db_location" VALUES(705,NULL,'Northampton, MA 1061',142,222,NULL,39,270,0);
INSERT INTO "django_geo_db_location" VALUES(706,NULL,'Florence, MA',143,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(707,NULL,'Florence, MA 1062',143,222,NULL,39,271,0);
INSERT INTO "django_geo_db_location" VALUES(708,NULL,'Northampton, MA 1063',142,222,NULL,39,272,0);
INSERT INTO "django_geo_db_location" VALUES(709,NULL,'North Hatfield, MA',144,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(710,NULL,'North Hatfield, MA 1066',144,222,NULL,39,273,0);
INSERT INTO "django_geo_db_location" VALUES(711,NULL,'Oakham, MA',145,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(712,NULL,'Oakham, MA 1068',145,222,NULL,39,274,0);
INSERT INTO "django_geo_db_location" VALUES(713,NULL,'Palmer, MA',146,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(714,NULL,'Palmer, MA 1069',146,222,NULL,39,275,0);
INSERT INTO "django_geo_db_location" VALUES(715,NULL,'Plainfield, MA',147,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(716,NULL,'Plainfield, MA 1070',147,222,NULL,39,276,0);
INSERT INTO "django_geo_db_location" VALUES(717,NULL,'Russell, MA',148,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(718,NULL,'Russell, MA 1071',148,222,NULL,39,277,0);
INSERT INTO "django_geo_db_location" VALUES(719,NULL,'Shutesbury, MA',149,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(720,NULL,'Shutesbury, MA 1072',149,222,NULL,39,278,0);
INSERT INTO "django_geo_db_location" VALUES(721,NULL,'Southampton, MA',150,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(722,NULL,'Southampton, MA 1073',150,222,NULL,39,279,0);
INSERT INTO "django_geo_db_location" VALUES(723,NULL,'South Barre, MA',151,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(724,NULL,'South Barre, MA 1074',151,222,NULL,39,280,0);
INSERT INTO "django_geo_db_location" VALUES(725,NULL,'South Hadley, MA',152,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(726,NULL,'South Hadley, MA 1075',152,222,NULL,39,281,0);
INSERT INTO "django_geo_db_location" VALUES(727,NULL,'Southwick, MA',153,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(728,NULL,'Southwick, MA 1077',153,222,NULL,39,282,0);
INSERT INTO "django_geo_db_location" VALUES(729,NULL,'Thorndike, MA',154,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(730,NULL,'Thorndike, MA 1079',154,222,NULL,39,283,0);
INSERT INTO "django_geo_db_location" VALUES(731,NULL,'Three Rivers, MA',155,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(732,NULL,'Three Rivers, MA 1080',155,222,NULL,39,284,0);
INSERT INTO "django_geo_db_location" VALUES(733,NULL,'Wales, MA',156,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(734,NULL,'Wales, MA 1081',156,222,NULL,39,285,0);
INSERT INTO "django_geo_db_location" VALUES(735,NULL,'Ware, MA',157,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(736,NULL,'Ware, MA 1082',157,222,NULL,39,286,0);
INSERT INTO "django_geo_db_location" VALUES(737,NULL,'Warren, MA',158,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(738,NULL,'Warren, MA 1083',158,222,NULL,39,287,0);
INSERT INTO "django_geo_db_location" VALUES(739,NULL,'West Chesterfield, MA',159,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(740,NULL,'West Chesterfield, MA 1084',159,222,NULL,39,288,0);
INSERT INTO "django_geo_db_location" VALUES(741,NULL,'Westfield, MA',160,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(742,NULL,'Westfield, MA 1085',160,222,NULL,39,289,0);
INSERT INTO "django_geo_db_location" VALUES(743,NULL,'Westfield, MA 1086',160,222,NULL,39,290,0);
INSERT INTO "django_geo_db_location" VALUES(744,NULL,'West Hatfield, MA',161,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(745,NULL,'West Hatfield, MA 1088',161,222,NULL,39,291,0);
INSERT INTO "django_geo_db_location" VALUES(746,NULL,'West Springfield, MA',162,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(747,NULL,'West Springfield, MA 1089',162,222,NULL,39,292,0);
INSERT INTO "django_geo_db_location" VALUES(748,NULL,'West Springfield, MA 1090',162,222,NULL,39,293,0);
INSERT INTO "django_geo_db_location" VALUES(749,NULL,'West Warren, MA',163,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(750,NULL,'West Warren, MA 1092',163,222,NULL,39,294,0);
INSERT INTO "django_geo_db_location" VALUES(751,NULL,'Whately, MA',164,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(752,NULL,'Whately, MA 1093',164,222,NULL,39,295,0);
INSERT INTO "django_geo_db_location" VALUES(753,NULL,'Wheelwright, MA',165,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(754,NULL,'Wheelwright, MA 1094',165,222,NULL,39,296,0);
INSERT INTO "django_geo_db_location" VALUES(755,NULL,'Wilbraham, MA',166,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(756,NULL,'Wilbraham, MA 1095',166,222,NULL,39,297,0);
INSERT INTO "django_geo_db_location" VALUES(757,NULL,'Williamsburg, MA',167,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(758,NULL,'Williamsburg, MA 1096',167,222,NULL,39,298,0);
INSERT INTO "django_geo_db_location" VALUES(759,NULL,'Woronoco, MA',168,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(760,NULL,'Woronoco, MA 1097',168,222,NULL,39,299,0);
INSERT INTO "django_geo_db_location" VALUES(761,NULL,'Worthington, MA',169,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(762,NULL,'Worthington, MA 1098',169,222,NULL,39,300,0);
INSERT INTO "django_geo_db_location" VALUES(763,NULL,'Springfield, MA',170,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(764,NULL,'Springfield, MA 1101',170,222,NULL,39,301,0);
INSERT INTO "django_geo_db_location" VALUES(765,NULL,'Springfield, MA 1102',170,222,NULL,39,302,0);
INSERT INTO "django_geo_db_location" VALUES(766,NULL,'Springfield, MA 1103',170,222,NULL,39,303,0);
INSERT INTO "django_geo_db_location" VALUES(767,NULL,'Springfield, MA 1104',170,222,NULL,39,304,0);
INSERT INTO "django_geo_db_location" VALUES(768,NULL,'Springfield, MA 1105',170,222,NULL,39,305,0);
INSERT INTO "django_geo_db_location" VALUES(769,NULL,'Longmeadow, MA',171,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(770,NULL,'Longmeadow, MA 1106',171,222,NULL,39,306,0);
INSERT INTO "django_geo_db_location" VALUES(771,NULL,'Springfield, MA 1107',170,222,NULL,39,307,0);
INSERT INTO "django_geo_db_location" VALUES(772,NULL,'Springfield, MA 1108',170,222,NULL,39,308,0);
INSERT INTO "django_geo_db_location" VALUES(773,NULL,'Springfield, MA 1109',170,222,NULL,39,309,0);
INSERT INTO "django_geo_db_location" VALUES(774,NULL,'Springfield, MA 1111',170,222,NULL,39,310,0);
INSERT INTO "django_geo_db_location" VALUES(775,NULL,'Springfield, MA 1114',170,222,NULL,39,311,0);
INSERT INTO "django_geo_db_location" VALUES(776,NULL,'Springfield, MA 1115',170,222,NULL,39,312,0);
INSERT INTO "django_geo_db_location" VALUES(777,NULL,'Longmeadow, MA 1116',171,222,NULL,39,313,0);
INSERT INTO "django_geo_db_location" VALUES(778,NULL,'Springfield, MA 1118',170,222,NULL,39,314,0);
INSERT INTO "django_geo_db_location" VALUES(779,NULL,'Springfield, MA 1119',170,222,NULL,39,315,0);
INSERT INTO "django_geo_db_location" VALUES(780,NULL,'Springfield, MA 1128',170,222,NULL,39,316,0);
INSERT INTO "django_geo_db_location" VALUES(781,NULL,'Springfield, MA 1129',170,222,NULL,39,317,0);
INSERT INTO "django_geo_db_location" VALUES(782,NULL,'Springfield, MA 1133',170,222,NULL,39,318,0);
INSERT INTO "django_geo_db_location" VALUES(783,NULL,'Springfield, MA 1138',170,222,NULL,39,319,0);
INSERT INTO "django_geo_db_location" VALUES(784,NULL,'Springfield, MA 1139',170,222,NULL,39,320,0);
INSERT INTO "django_geo_db_location" VALUES(785,NULL,'Springfield, MA 1144',170,222,NULL,39,321,0);
INSERT INTO "django_geo_db_location" VALUES(786,NULL,'Indian Orchard, MA',172,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(787,NULL,'Indian Orchard, MA 1151',172,222,NULL,39,322,0);
INSERT INTO "django_geo_db_location" VALUES(788,NULL,'Springfield, MA 1152',170,222,NULL,39,323,0);
INSERT INTO "django_geo_db_location" VALUES(789,NULL,'Springfield, MA 1199',170,222,NULL,39,324,0);
INSERT INTO "django_geo_db_location" VALUES(790,NULL,'Pittsfield, MA',173,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(791,NULL,'Pittsfield, MA 1201',173,222,NULL,39,325,0);
INSERT INTO "django_geo_db_location" VALUES(792,NULL,'Pittsfield, MA 1202',173,222,NULL,39,326,0);
INSERT INTO "django_geo_db_location" VALUES(793,NULL,'Pittsfield, MA 1203',173,222,NULL,39,327,0);
INSERT INTO "django_geo_db_location" VALUES(794,NULL,'Adams, MA',174,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(795,NULL,'Adams, MA 1220',174,222,NULL,39,328,0);
INSERT INTO "django_geo_db_location" VALUES(796,NULL,'Ashley Falls, MA',175,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(797,NULL,'Ashley Falls, MA 1222',175,222,NULL,39,329,0);
INSERT INTO "django_geo_db_location" VALUES(798,NULL,'Becket, MA',176,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(799,NULL,'Becket, MA 1223',176,222,NULL,39,330,0);
INSERT INTO "django_geo_db_location" VALUES(800,NULL,'Berkshire, MA',177,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(801,NULL,'Berkshire, MA 1224',177,222,NULL,39,331,0);
INSERT INTO "django_geo_db_location" VALUES(802,NULL,'Cheshire, MA',178,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(803,NULL,'Cheshire, MA 1225',178,222,NULL,39,332,0);
INSERT INTO "django_geo_db_location" VALUES(804,NULL,'Dalton, MA',179,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(805,NULL,'Dalton, MA 1226',179,222,NULL,39,333,0);
INSERT INTO "django_geo_db_location" VALUES(806,NULL,'Dalton, MA 1227',179,222,NULL,39,334,0);
INSERT INTO "django_geo_db_location" VALUES(807,NULL,'Glendale, MA',180,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(808,NULL,'Glendale, MA 1229',180,222,NULL,39,335,0);
INSERT INTO "django_geo_db_location" VALUES(809,NULL,'Great Barrington, MA',181,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(810,NULL,'Great Barrington, MA 1230',181,222,NULL,39,336,0);
INSERT INTO "django_geo_db_location" VALUES(811,NULL,'Sheffield, MA',182,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(812,NULL,'Sheffield, MA 1231',182,222,NULL,39,337,0);
INSERT INTO "django_geo_db_location" VALUES(813,NULL,'Hinsdale, MA',183,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(814,NULL,'Hinsdale, MA 1235',183,222,NULL,39,338,0);
INSERT INTO "django_geo_db_location" VALUES(815,NULL,'Housatonic, MA',184,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(816,NULL,'Housatonic, MA 1236',184,222,NULL,39,339,0);
INSERT INTO "django_geo_db_location" VALUES(817,NULL,'Lanesboro, MA',185,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(818,NULL,'Lanesboro, MA 1237',185,222,NULL,39,340,0);
INSERT INTO "django_geo_db_location" VALUES(819,NULL,'Lee, MA',186,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(820,NULL,'Lee, MA 1238',186,222,NULL,39,341,0);
INSERT INTO "django_geo_db_location" VALUES(821,NULL,'Lenox, MA',187,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(822,NULL,'Lenox, MA 1240',187,222,NULL,39,342,0);
INSERT INTO "django_geo_db_location" VALUES(823,NULL,'Lenox Dale, MA',188,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(824,NULL,'Lenox Dale, MA 1242',188,222,NULL,39,343,0);
INSERT INTO "django_geo_db_location" VALUES(825,NULL,'Middlefield, MA',189,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(826,NULL,'Middlefield, MA 1243',189,222,NULL,39,344,0);
INSERT INTO "django_geo_db_location" VALUES(827,NULL,'Mill River, MA',190,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(828,NULL,'Mill River, MA 1244',190,222,NULL,39,345,0);
INSERT INTO "django_geo_db_location" VALUES(829,NULL,'Monterey, MA',191,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(830,NULL,'Monterey, MA 1245',191,222,NULL,39,346,0);
INSERT INTO "django_geo_db_location" VALUES(831,NULL,'North Adams, MA',192,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(832,NULL,'North Adams, MA 1247',192,222,NULL,39,347,0);
INSERT INTO "django_geo_db_location" VALUES(833,NULL,'North Egremont, MA',193,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(834,NULL,'North Egremont, MA 1252',193,222,NULL,39,348,0);
INSERT INTO "django_geo_db_location" VALUES(835,NULL,'Otis, MA',194,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(836,NULL,'Otis, MA 1253',194,222,NULL,39,349,0);
INSERT INTO "django_geo_db_location" VALUES(837,NULL,'Richmond, MA',195,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(838,NULL,'Richmond, MA 1254',195,222,NULL,39,350,0);
INSERT INTO "django_geo_db_location" VALUES(839,NULL,'Sandisfield, MA',196,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(840,NULL,'Sandisfield, MA 1255',196,222,NULL,39,351,0);
INSERT INTO "django_geo_db_location" VALUES(841,NULL,'Savoy, MA',197,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(842,NULL,'Savoy, MA 1256',197,222,NULL,39,352,0);
INSERT INTO "django_geo_db_location" VALUES(843,NULL,'Sheffield, MA 1257',182,222,NULL,39,353,0);
INSERT INTO "django_geo_db_location" VALUES(844,NULL,'South Egremont, MA',198,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(845,NULL,'South Egremont, MA 1258',198,222,NULL,39,354,0);
INSERT INTO "django_geo_db_location" VALUES(846,NULL,'Southfield, MA',199,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(847,NULL,'Southfield, MA 1259',199,222,NULL,39,355,0);
INSERT INTO "django_geo_db_location" VALUES(848,NULL,'South Lee, MA',200,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(849,NULL,'South Lee, MA 1260',200,222,NULL,39,356,0);
INSERT INTO "django_geo_db_location" VALUES(850,NULL,'Stockbridge, MA',201,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(851,NULL,'Stockbridge, MA 1262',201,222,NULL,39,357,0);
INSERT INTO "django_geo_db_location" VALUES(852,NULL,'Stockbridge, MA 1263',201,222,NULL,39,358,0);
INSERT INTO "django_geo_db_location" VALUES(853,NULL,'Tyringham, MA',202,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(854,NULL,'Tyringham, MA 1264',202,222,NULL,39,359,0);
INSERT INTO "django_geo_db_location" VALUES(855,NULL,'West Stockbridge, MA',203,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(856,NULL,'West Stockbridge, MA 1266',203,222,NULL,39,360,0);
INSERT INTO "django_geo_db_location" VALUES(857,NULL,'Williamstown, MA',204,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(858,NULL,'Williamstown, MA 1267',204,222,NULL,39,361,0);
INSERT INTO "django_geo_db_location" VALUES(859,NULL,'Windsor, MA',205,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(860,NULL,'Windsor, MA 1270',205,222,NULL,39,362,0);
INSERT INTO "django_geo_db_location" VALUES(861,NULL,'Greenfield, MA',206,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(862,NULL,'Greenfield, MA 1301',206,222,NULL,39,363,0);
INSERT INTO "django_geo_db_location" VALUES(863,NULL,'Greenfield, MA 1302',206,222,NULL,39,364,0);
INSERT INTO "django_geo_db_location" VALUES(864,NULL,'Ashfield, MA',207,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(865,NULL,'Ashfield, MA 1330',207,222,NULL,39,365,0);
INSERT INTO "django_geo_db_location" VALUES(866,NULL,'Athol, MA',208,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(867,NULL,'Athol, MA 1331',208,222,NULL,39,366,0);
INSERT INTO "django_geo_db_location" VALUES(868,NULL,'Bernardston, MA',209,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(869,NULL,'Bernardston, MA 1337',209,222,NULL,39,367,0);
INSERT INTO "django_geo_db_location" VALUES(870,NULL,'Buckland, MA',210,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(871,NULL,'Buckland, MA 1338',210,222,NULL,39,368,0);
INSERT INTO "django_geo_db_location" VALUES(872,NULL,'Charlemont, MA',211,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(873,NULL,'Charlemont, MA 1339',211,222,NULL,39,369,0);
INSERT INTO "django_geo_db_location" VALUES(874,NULL,'Colrain, MA',212,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(875,NULL,'Colrain, MA 1340',212,222,NULL,39,370,0);
INSERT INTO "django_geo_db_location" VALUES(876,NULL,'Conway, MA',213,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(877,NULL,'Conway, MA 1341',213,222,NULL,39,371,0);
INSERT INTO "django_geo_db_location" VALUES(878,NULL,'Deerfield, MA',214,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(879,NULL,'Deerfield, MA 1342',214,222,NULL,39,372,0);
INSERT INTO "django_geo_db_location" VALUES(880,NULL,'Drury, MA',215,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(881,NULL,'Drury, MA 1343',215,222,NULL,39,373,0);
INSERT INTO "django_geo_db_location" VALUES(882,NULL,'Erving, MA',216,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(883,NULL,'Erving, MA 1344',216,222,NULL,39,374,0);
INSERT INTO "django_geo_db_location" VALUES(884,NULL,'Heath, MA',217,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(885,NULL,'Heath, MA 1346',217,222,NULL,39,375,0);
INSERT INTO "django_geo_db_location" VALUES(886,NULL,'Lake Pleasant, MA',218,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(887,NULL,'Lake Pleasant, MA 1347',218,222,NULL,39,376,0);
INSERT INTO "django_geo_db_location" VALUES(888,NULL,'Turners Falls, MA',219,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(889,NULL,'Turners Falls, MA 1349',219,222,NULL,39,377,0);
INSERT INTO "django_geo_db_location" VALUES(890,NULL,'Monroe Bridge, MA',220,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(891,NULL,'Monroe Bridge, MA 1350',220,222,NULL,39,378,0);
INSERT INTO "django_geo_db_location" VALUES(892,NULL,'Montague, MA',221,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(893,NULL,'Montague, MA 1351',221,222,NULL,39,379,0);
INSERT INTO "django_geo_db_location" VALUES(894,NULL,'Northfield, MA',222,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(895,NULL,'Northfield, MA 1354',222,222,NULL,39,380,0);
INSERT INTO "django_geo_db_location" VALUES(896,NULL,'New Salem, MA',223,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(897,NULL,'New Salem, MA 1355',223,222,NULL,39,381,0);
INSERT INTO "django_geo_db_location" VALUES(898,NULL,'Northfield, MA 1360',222,222,NULL,39,382,0);
INSERT INTO "django_geo_db_location" VALUES(899,NULL,'Orange, MA',224,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(900,NULL,'Orange, MA 1364',224,222,NULL,39,383,0);
INSERT INTO "django_geo_db_location" VALUES(901,NULL,'Petersham, MA',225,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(902,NULL,'Petersham, MA 1366',225,222,NULL,39,384,0);
INSERT INTO "django_geo_db_location" VALUES(903,NULL,'Rowe, MA',226,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(904,NULL,'Rowe, MA 1367',226,222,NULL,39,385,0);
INSERT INTO "django_geo_db_location" VALUES(905,NULL,'Royalston, MA',227,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(906,NULL,'Royalston, MA 1368',227,222,NULL,39,386,0);
INSERT INTO "django_geo_db_location" VALUES(907,NULL,'Shattuckville, MA',228,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(908,NULL,'Shattuckville, MA 1369',228,222,NULL,39,387,0);
INSERT INTO "django_geo_db_location" VALUES(909,NULL,'Shelburne Falls, MA',229,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(910,NULL,'Shelburne Falls, MA 1370',229,222,NULL,39,388,0);
INSERT INTO "django_geo_db_location" VALUES(911,NULL,'South Deerfield, MA',230,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(912,NULL,'South Deerfield, MA 1373',230,222,NULL,39,389,0);
INSERT INTO "django_geo_db_location" VALUES(913,NULL,'Charlemont, MA 1374',211,222,NULL,39,390,0);
INSERT INTO "django_geo_db_location" VALUES(914,NULL,'Sunderland, MA',231,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(915,NULL,'Sunderland, MA 1375',231,222,NULL,39,391,0);
INSERT INTO "django_geo_db_location" VALUES(916,NULL,'Turners Falls, MA 1376',219,222,NULL,39,392,0);
INSERT INTO "django_geo_db_location" VALUES(917,NULL,'Warwick, MA',232,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(918,NULL,'Warwick, MA 1378',232,222,NULL,39,393,0);
INSERT INTO "django_geo_db_location" VALUES(919,NULL,'Wendell, MA',233,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(920,NULL,'Wendell, MA 1379',233,222,NULL,39,394,0);
INSERT INTO "django_geo_db_location" VALUES(921,NULL,'Wendell Depot, MA',234,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(922,NULL,'Wendell Depot, MA 1380',234,222,NULL,39,395,0);
INSERT INTO "django_geo_db_location" VALUES(923,NULL,'Whately, MA 1393',164,222,NULL,39,396,0);
INSERT INTO "django_geo_db_location" VALUES(924,NULL,'Fitchburg, MA',235,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(925,NULL,'Fitchburg, MA 1420',235,222,NULL,39,397,0);
INSERT INTO "django_geo_db_location" VALUES(926,NULL,'Westborough, MA',236,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(927,NULL,'Westborough, MA 1427',236,222,NULL,39,398,0);
INSERT INTO "django_geo_db_location" VALUES(928,NULL,'Ashburnham, MA',237,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(929,NULL,'Ashburnham, MA 1430',237,222,NULL,39,399,0);
INSERT INTO "django_geo_db_location" VALUES(930,NULL,'Ashby, MA',238,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(931,NULL,'Ashby, MA 1431',238,222,NULL,39,400,0);
INSERT INTO "django_geo_db_location" VALUES(932,NULL,'Ayer, MA',239,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(933,NULL,'Ayer, MA 1432',239,222,NULL,39,401,0);
INSERT INTO "django_geo_db_location" VALUES(934,NULL,'Baldwinville, MA',240,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(935,NULL,'Baldwinville, MA 1436',240,222,NULL,39,402,0);
INSERT INTO "django_geo_db_location" VALUES(936,NULL,'East Templeton, MA',241,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(937,NULL,'East Templeton, MA 1438',241,222,NULL,39,403,0);
INSERT INTO "django_geo_db_location" VALUES(938,NULL,'Gardner, MA',242,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(939,NULL,'Gardner, MA 1440',242,222,NULL,39,404,0);
INSERT INTO "django_geo_db_location" VALUES(940,NULL,'Gardner, MA 1441',242,222,NULL,39,405,0);
INSERT INTO "django_geo_db_location" VALUES(941,NULL,'Groton, MA',243,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(942,NULL,'Groton, MA 1450',243,222,NULL,39,406,0);
INSERT INTO "django_geo_db_location" VALUES(943,NULL,'Harvard, MA',244,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(944,NULL,'Harvard, MA 1451',244,222,NULL,39,407,0);
INSERT INTO "django_geo_db_location" VALUES(945,NULL,'Hubbardston, MA',245,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(946,NULL,'Hubbardston, MA 1452',245,222,NULL,39,408,0);
INSERT INTO "django_geo_db_location" VALUES(947,NULL,'Leominster, MA',246,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(948,NULL,'Leominster, MA 1453',246,222,NULL,39,409,0);
INSERT INTO "django_geo_db_location" VALUES(949,NULL,'Littleton, MA',247,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(950,NULL,'Littleton, MA 1460',247,222,NULL,39,410,0);
INSERT INTO "django_geo_db_location" VALUES(951,NULL,'Lunenburg, MA',248,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(952,NULL,'Lunenburg, MA 1462',248,222,NULL,39,411,0);
INSERT INTO "django_geo_db_location" VALUES(953,NULL,'Pepperell, MA',249,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(954,NULL,'Pepperell, MA 1463',249,222,NULL,39,412,0);
INSERT INTO "django_geo_db_location" VALUES(955,NULL,'Shirley, MA',250,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(956,NULL,'Shirley, MA 1464',250,222,NULL,39,413,0);
INSERT INTO "django_geo_db_location" VALUES(957,NULL,'Still River, MA',251,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(958,NULL,'Still River, MA 1467',251,222,NULL,39,414,0);
INSERT INTO "django_geo_db_location" VALUES(959,NULL,'Templeton, MA',252,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(960,NULL,'Templeton, MA 1468',252,222,NULL,39,415,0);
INSERT INTO "django_geo_db_location" VALUES(961,NULL,'Townsend, MA',253,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(962,NULL,'Townsend, MA 1469',253,222,NULL,39,416,0);
INSERT INTO "django_geo_db_location" VALUES(963,NULL,'Groton, MA 1470',243,222,NULL,39,417,0);
INSERT INTO "django_geo_db_location" VALUES(964,NULL,'Groton, MA 1471',243,222,NULL,39,418,0);
INSERT INTO "django_geo_db_location" VALUES(965,NULL,'West Groton, MA',254,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(966,NULL,'West Groton, MA 1472',254,222,NULL,39,419,0);
INSERT INTO "django_geo_db_location" VALUES(967,NULL,'Westminster, MA',255,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(968,NULL,'Westminster, MA 1473',255,222,NULL,39,420,0);
INSERT INTO "django_geo_db_location" VALUES(969,NULL,'West Townsend, MA',256,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(970,NULL,'West Townsend, MA 1474',256,222,NULL,39,421,0);
INSERT INTO "django_geo_db_location" VALUES(971,NULL,'Winchendon, MA',257,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(972,NULL,'Winchendon, MA 1475',257,222,NULL,39,422,0);
INSERT INTO "django_geo_db_location" VALUES(973,NULL,'Winchendon Springs, MA',258,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(974,NULL,'Winchendon Springs, MA 1477',258,222,NULL,39,423,0);
INSERT INTO "django_geo_db_location" VALUES(975,NULL,'Auburn, MA',259,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(976,NULL,'Auburn, MA 1501',259,222,NULL,39,424,0);
INSERT INTO "django_geo_db_location" VALUES(977,NULL,'Berlin, MA',260,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(978,NULL,'Berlin, MA 1503',260,222,NULL,39,425,0);
INSERT INTO "django_geo_db_location" VALUES(979,NULL,'Blackstone, MA',261,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(980,NULL,'Blackstone, MA 1504',261,222,NULL,39,426,0);
INSERT INTO "django_geo_db_location" VALUES(981,NULL,'Boylston, MA',262,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(982,NULL,'Boylston, MA 1505',262,222,NULL,39,427,0);
INSERT INTO "django_geo_db_location" VALUES(983,NULL,'Brookfield, MA',263,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(984,NULL,'Brookfield, MA 1506',263,222,NULL,39,428,0);
INSERT INTO "django_geo_db_location" VALUES(985,NULL,'Charlton, MA',264,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(986,NULL,'Charlton, MA 1507',264,222,NULL,39,429,0);
INSERT INTO "django_geo_db_location" VALUES(987,NULL,'Charlton City, MA',265,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(988,NULL,'Charlton City, MA 1508',265,222,NULL,39,430,0);
INSERT INTO "django_geo_db_location" VALUES(989,NULL,'Charlton Depot, MA',266,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(990,NULL,'Charlton Depot, MA 1509',266,222,NULL,39,431,0);
INSERT INTO "django_geo_db_location" VALUES(991,NULL,'Clinton, MA',267,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(992,NULL,'Clinton, MA 1510',267,222,NULL,39,432,0);
INSERT INTO "django_geo_db_location" VALUES(993,NULL,'East Brookfield, MA',268,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(994,NULL,'East Brookfield, MA 1515',268,222,NULL,39,433,0);
INSERT INTO "django_geo_db_location" VALUES(995,NULL,'Douglas, MA',269,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(996,NULL,'Douglas, MA 1516',269,222,NULL,39,434,0);
INSERT INTO "django_geo_db_location" VALUES(997,NULL,'East Princeton, MA',270,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(998,NULL,'East Princeton, MA 1517',270,222,NULL,39,435,0);
INSERT INTO "django_geo_db_location" VALUES(999,NULL,'Fiskdale, MA',271,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1000,NULL,'Fiskdale, MA 1518',271,222,NULL,39,436,0);
INSERT INTO "django_geo_db_location" VALUES(1001,NULL,'Grafton, MA',272,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1002,NULL,'Grafton, MA 1519',272,222,NULL,39,437,0);
INSERT INTO "django_geo_db_location" VALUES(1003,NULL,'Holden, MA',273,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1004,NULL,'Holden, MA 1520',273,222,NULL,39,438,0);
INSERT INTO "django_geo_db_location" VALUES(1005,NULL,'Holland, MA',274,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1006,NULL,'Holland, MA 1521',274,222,NULL,39,439,0);
INSERT INTO "django_geo_db_location" VALUES(1007,NULL,'Jefferson, MA',275,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1008,NULL,'Jefferson, MA 1522',275,222,NULL,39,440,0);
INSERT INTO "django_geo_db_location" VALUES(1009,NULL,'Lancaster, MA',276,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1010,NULL,'Lancaster, MA 1523',276,222,NULL,39,441,0);
INSERT INTO "django_geo_db_location" VALUES(1011,NULL,'Leicester, MA',277,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1012,NULL,'Leicester, MA 1524',277,222,NULL,39,442,0);
INSERT INTO "django_geo_db_location" VALUES(1013,NULL,'Linwood, MA',278,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1014,NULL,'Linwood, MA 1525',278,222,NULL,39,443,0);
INSERT INTO "django_geo_db_location" VALUES(1015,NULL,'Manchaug, MA',279,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1016,NULL,'Manchaug, MA 1526',279,222,NULL,39,444,0);
INSERT INTO "django_geo_db_location" VALUES(1017,NULL,'Millbury, MA',280,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1018,NULL,'Millbury, MA 1527',280,222,NULL,39,445,0);
INSERT INTO "django_geo_db_location" VALUES(1019,NULL,'Millville, MA',281,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1020,NULL,'Millville, MA 1529',281,222,NULL,39,446,0);
INSERT INTO "django_geo_db_location" VALUES(1021,NULL,'New Braintree, MA',282,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1022,NULL,'New Braintree, MA 1531',282,222,NULL,39,447,0);
INSERT INTO "django_geo_db_location" VALUES(1023,NULL,'Northborough, MA',283,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1024,NULL,'Northborough, MA 1532',283,222,NULL,39,448,0);
INSERT INTO "django_geo_db_location" VALUES(1025,NULL,'Northbridge, MA',284,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1026,NULL,'Northbridge, MA 1534',284,222,NULL,39,449,0);
INSERT INTO "django_geo_db_location" VALUES(1027,NULL,'North Brookfield, MA',285,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1028,NULL,'North Brookfield, MA 1535',285,222,NULL,39,450,0);
INSERT INTO "django_geo_db_location" VALUES(1029,NULL,'North Grafton, MA',286,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1030,NULL,'North Grafton, MA 1536',286,222,NULL,39,451,0);
INSERT INTO "django_geo_db_location" VALUES(1031,NULL,'North Oxford, MA',287,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1032,NULL,'North Oxford, MA 1537',287,222,NULL,39,452,0);
INSERT INTO "django_geo_db_location" VALUES(1033,NULL,'North Uxbridge, MA',288,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1034,NULL,'North Uxbridge, MA 1538',288,222,NULL,39,453,0);
INSERT INTO "django_geo_db_location" VALUES(1035,NULL,'Oxford, MA',289,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1036,NULL,'Oxford, MA 1540',289,222,NULL,39,454,0);
INSERT INTO "django_geo_db_location" VALUES(1037,NULL,'Princeton, MA',290,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1038,NULL,'Princeton, MA 1541',290,222,NULL,39,455,0);
INSERT INTO "django_geo_db_location" VALUES(1039,NULL,'Rochdale, MA',291,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1040,NULL,'Rochdale, MA 1542',291,222,NULL,39,456,0);
INSERT INTO "django_geo_db_location" VALUES(1041,NULL,'Rutland, MA',292,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1042,NULL,'Rutland, MA 1543',292,222,NULL,39,457,0);
INSERT INTO "django_geo_db_location" VALUES(1043,NULL,'Shrewsbury, MA',293,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1044,NULL,'Shrewsbury, MA 1545',293,222,NULL,39,458,0);
INSERT INTO "django_geo_db_location" VALUES(1045,NULL,'Shrewsbury, MA 1546',293,222,NULL,39,459,0);
INSERT INTO "django_geo_db_location" VALUES(1046,NULL,'Southbridge, MA',294,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1047,NULL,'Southbridge, MA 1550',294,222,NULL,39,460,0);
INSERT INTO "django_geo_db_location" VALUES(1048,NULL,'South Grafton, MA',295,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1049,NULL,'South Grafton, MA 1560',295,222,NULL,39,461,0);
INSERT INTO "django_geo_db_location" VALUES(1050,NULL,'South Lancaster, MA',296,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1051,NULL,'South Lancaster, MA 1561',296,222,NULL,39,462,0);
INSERT INTO "django_geo_db_location" VALUES(1052,NULL,'Spencer, MA',297,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1053,NULL,'Spencer, MA 1562',297,222,NULL,39,463,0);
INSERT INTO "django_geo_db_location" VALUES(1054,NULL,'Sterling, MA',298,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1055,NULL,'Sterling, MA 1564',298,222,NULL,39,464,0);
INSERT INTO "django_geo_db_location" VALUES(1056,NULL,'Sturbridge, MA',299,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1057,NULL,'Sturbridge, MA 1566',299,222,NULL,39,465,0);
INSERT INTO "django_geo_db_location" VALUES(1058,NULL,'Upton, MA',300,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1059,NULL,'Upton, MA 1568',300,222,NULL,39,466,0);
INSERT INTO "django_geo_db_location" VALUES(1060,NULL,'Uxbridge, MA',301,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1061,NULL,'Uxbridge, MA 1569',301,222,NULL,39,467,0);
INSERT INTO "django_geo_db_location" VALUES(1062,NULL,'Webster, MA',302,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1063,NULL,'Webster, MA 1570',302,222,NULL,39,468,0);
INSERT INTO "django_geo_db_location" VALUES(1064,NULL,'Dudley, MA',303,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1065,NULL,'Dudley, MA 1571',303,222,NULL,39,469,0);
INSERT INTO "django_geo_db_location" VALUES(1066,NULL,'Westborough, MA 1580',236,222,NULL,39,470,0);
INSERT INTO "django_geo_db_location" VALUES(1067,NULL,'Westborough, MA 1581',236,222,NULL,39,471,0);
INSERT INTO "django_geo_db_location" VALUES(1068,NULL,'Westborough, MA 1582',236,222,NULL,39,472,0);
INSERT INTO "django_geo_db_location" VALUES(1069,NULL,'West Boylston, MA',304,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1070,NULL,'West Boylston, MA 1583',304,222,NULL,39,473,0);
INSERT INTO "django_geo_db_location" VALUES(1071,NULL,'West Brookfield, MA',305,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1072,NULL,'West Brookfield, MA 1585',305,222,NULL,39,474,0);
INSERT INTO "django_geo_db_location" VALUES(1073,NULL,'West Millbury, MA',306,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1074,NULL,'West Millbury, MA 1586',306,222,NULL,39,475,0);
INSERT INTO "django_geo_db_location" VALUES(1075,NULL,'Whitinsville, MA',307,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1076,NULL,'Whitinsville, MA 1588',307,222,NULL,39,476,0);
INSERT INTO "django_geo_db_location" VALUES(1077,NULL,'Sutton, MA',308,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1078,NULL,'Sutton, MA 1590',308,222,NULL,39,477,0);
INSERT INTO "django_geo_db_location" VALUES(1079,NULL,'Worcester, MA',309,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1080,NULL,'Worcester, MA 1601',309,222,NULL,39,478,0);
INSERT INTO "django_geo_db_location" VALUES(1081,NULL,'Worcester, MA 1602',309,222,NULL,39,479,0);
INSERT INTO "django_geo_db_location" VALUES(1082,NULL,'Worcester, MA 1603',309,222,NULL,39,480,0);
INSERT INTO "django_geo_db_location" VALUES(1083,NULL,'Worcester, MA 1604',309,222,NULL,39,481,0);
INSERT INTO "django_geo_db_location" VALUES(1084,NULL,'Worcester, MA 1605',309,222,NULL,39,482,0);
INSERT INTO "django_geo_db_location" VALUES(1085,NULL,'Worcester, MA 1606',309,222,NULL,39,483,0);
INSERT INTO "django_geo_db_location" VALUES(1086,NULL,'Worcester, MA 1607',309,222,NULL,39,484,0);
INSERT INTO "django_geo_db_location" VALUES(1087,NULL,'Worcester, MA 1608',309,222,NULL,39,485,0);
INSERT INTO "django_geo_db_location" VALUES(1088,NULL,'Worcester, MA 1609',309,222,NULL,39,486,0);
INSERT INTO "django_geo_db_location" VALUES(1089,NULL,'Worcester, MA 1610',309,222,NULL,39,487,0);
INSERT INTO "django_geo_db_location" VALUES(1090,NULL,'Cherry Valley, MA',310,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1091,NULL,'Cherry Valley, MA 1611',310,222,NULL,39,488,0);
INSERT INTO "django_geo_db_location" VALUES(1092,NULL,'Paxton, MA',311,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1093,NULL,'Paxton, MA 1612',311,222,NULL,39,489,0);
INSERT INTO "django_geo_db_location" VALUES(1094,NULL,'Worcester, MA 1613',309,222,NULL,39,490,0);
INSERT INTO "django_geo_db_location" VALUES(1095,NULL,'Worcester, MA 1614',309,222,NULL,39,491,0);
INSERT INTO "django_geo_db_location" VALUES(1096,NULL,'Worcester, MA 1615',309,222,NULL,39,492,0);
INSERT INTO "django_geo_db_location" VALUES(1097,NULL,'Tolland, MA',312,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1098,NULL,'Tolland, MA 1634',312,222,NULL,39,493,0);
INSERT INTO "django_geo_db_location" VALUES(1099,NULL,'Worcester, MA 1653',309,222,NULL,39,494,0);
INSERT INTO "django_geo_db_location" VALUES(1100,NULL,'Worcester, MA 1654',309,222,NULL,39,495,0);
INSERT INTO "django_geo_db_location" VALUES(1101,NULL,'Worcester, MA 1655',309,222,NULL,39,496,0);
INSERT INTO "django_geo_db_location" VALUES(1102,NULL,'Framingham, MA',313,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1103,NULL,'Framingham, MA 1701',313,222,NULL,39,497,0);
INSERT INTO "django_geo_db_location" VALUES(1104,NULL,'Framingham, MA 1702',313,222,NULL,39,498,0);
INSERT INTO "django_geo_db_location" VALUES(1105,NULL,'Framingham, MA 1703',313,222,NULL,39,499,0);
INSERT INTO "django_geo_db_location" VALUES(1106,NULL,'Framingham, MA 1704',313,222,NULL,39,500,0);
INSERT INTO "django_geo_db_location" VALUES(1107,NULL,'Framingham, MA 1705',313,222,NULL,39,501,0);
INSERT INTO "django_geo_db_location" VALUES(1108,NULL,'Village Of Nagog Woods, MA',314,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1109,NULL,'Village Of Nagog Woods, MA 1718',314,222,NULL,39,502,0);
INSERT INTO "django_geo_db_location" VALUES(1110,NULL,'Boxborough, MA',315,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1111,NULL,'Boxborough, MA 1719',315,222,NULL,39,503,0);
INSERT INTO "django_geo_db_location" VALUES(1112,NULL,'Acton, MA',316,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1113,NULL,'Acton, MA 1720',316,222,NULL,39,504,0);
INSERT INTO "django_geo_db_location" VALUES(1114,NULL,'Ashland, MA',317,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1115,NULL,'Ashland, MA 1721',317,222,NULL,39,505,0);
INSERT INTO "django_geo_db_location" VALUES(1116,NULL,'Bedford, MA',318,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1117,NULL,'Bedford, MA 1730',318,222,NULL,39,506,0);
INSERT INTO "django_geo_db_location" VALUES(1118,NULL,'Hanscom AFB, MA',319,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1119,NULL,'Hanscom AFB, MA 1731',319,222,NULL,39,507,0);
INSERT INTO "django_geo_db_location" VALUES(1120,NULL,'Bolton, MA',320,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1121,NULL,'Bolton, MA 1740',320,222,NULL,39,508,0);
INSERT INTO "django_geo_db_location" VALUES(1122,NULL,'Carlisle, MA',321,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1123,NULL,'Carlisle, MA 1741',321,222,NULL,39,509,0);
INSERT INTO "django_geo_db_location" VALUES(1124,NULL,'Concord, MA',322,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1125,NULL,'Concord, MA 1742',322,222,NULL,39,510,0);
INSERT INTO "django_geo_db_location" VALUES(1126,NULL,'Fayville, MA',323,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1127,NULL,'Fayville, MA 1745',323,222,NULL,39,511,0);
INSERT INTO "django_geo_db_location" VALUES(1128,NULL,'Holliston, MA',324,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1129,NULL,'Holliston, MA 1746',324,222,NULL,39,512,0);
INSERT INTO "django_geo_db_location" VALUES(1130,NULL,'Hopedale, MA',325,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1131,NULL,'Hopedale, MA 1747',325,222,NULL,39,513,0);
INSERT INTO "django_geo_db_location" VALUES(1132,NULL,'Hopkinton, MA',326,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1133,NULL,'Hopkinton, MA 1748',326,222,NULL,39,514,0);
INSERT INTO "django_geo_db_location" VALUES(1134,NULL,'Hudson, MA',327,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1135,NULL,'Hudson, MA 1749',327,222,NULL,39,515,0);
INSERT INTO "django_geo_db_location" VALUES(1136,NULL,'Natick, MA',328,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1137,NULL,'Natick, MA 1750',328,222,NULL,39,516,0);
INSERT INTO "django_geo_db_location" VALUES(1138,NULL,'Marlborough, MA',329,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1139,NULL,'Marlborough, MA 1752',329,222,NULL,39,517,0);
INSERT INTO "django_geo_db_location" VALUES(1140,NULL,'Maynard, MA',330,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1141,NULL,'Maynard, MA 1754',330,222,NULL,39,518,0);
INSERT INTO "django_geo_db_location" VALUES(1142,NULL,'Mendon, MA',331,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1143,NULL,'Mendon, MA 1756',331,222,NULL,39,519,0);
INSERT INTO "django_geo_db_location" VALUES(1144,NULL,'Milford, MA',332,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1145,NULL,'Milford, MA 1757',332,222,NULL,39,520,0);
INSERT INTO "django_geo_db_location" VALUES(1146,NULL,'Natick, MA 1760',328,222,NULL,39,521,0);
INSERT INTO "django_geo_db_location" VALUES(1147,NULL,'Sherborn, MA',333,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1148,NULL,'Sherborn, MA 1770',333,222,NULL,39,522,0);
INSERT INTO "django_geo_db_location" VALUES(1149,NULL,'Southborough, MA',334,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1150,NULL,'Southborough, MA 1772',334,222,NULL,39,523,0);
INSERT INTO "django_geo_db_location" VALUES(1151,NULL,'Lincoln, MA',335,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1152,NULL,'Lincoln, MA 1773',335,222,NULL,39,524,0);
INSERT INTO "django_geo_db_location" VALUES(1153,NULL,'Stow, MA',336,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1154,NULL,'Stow, MA 1775',336,222,NULL,39,525,0);
INSERT INTO "django_geo_db_location" VALUES(1155,NULL,'Sudbury, MA',337,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1156,NULL,'Sudbury, MA 1776',337,222,NULL,39,526,0);
INSERT INTO "django_geo_db_location" VALUES(1157,NULL,'Wayland, MA',338,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1158,NULL,'Wayland, MA 1778',338,222,NULL,39,527,0);
INSERT INTO "django_geo_db_location" VALUES(1159,NULL,'Woodville, MA',339,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1160,NULL,'Woodville, MA 1784',339,222,NULL,39,528,0);
INSERT INTO "django_geo_db_location" VALUES(1161,NULL,'Woburn, MA',340,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1162,NULL,'Woburn, MA 1801',340,222,NULL,39,529,0);
INSERT INTO "django_geo_db_location" VALUES(1163,NULL,'Burlington, MA',341,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1164,NULL,'Burlington, MA 1803',341,222,NULL,39,530,0);
INSERT INTO "django_geo_db_location" VALUES(1165,NULL,'Burlington, MA 1805',341,222,NULL,39,531,0);
INSERT INTO "django_geo_db_location" VALUES(1166,NULL,'Woburn, MA 1806',340,222,NULL,39,532,0);
INSERT INTO "django_geo_db_location" VALUES(1167,NULL,'Woburn, MA 1807',340,222,NULL,39,533,0);
INSERT INTO "django_geo_db_location" VALUES(1168,NULL,'Woburn, MA 1808',340,222,NULL,39,534,0);
INSERT INTO "django_geo_db_location" VALUES(1169,NULL,'Andover, MA',342,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1170,NULL,'Andover, MA 1810',342,222,NULL,39,535,0);
INSERT INTO "django_geo_db_location" VALUES(1171,NULL,'Andover, MA 1812',342,222,NULL,39,536,0);
INSERT INTO "django_geo_db_location" VALUES(1172,NULL,'Woburn, MA 1813',340,222,NULL,39,537,0);
INSERT INTO "django_geo_db_location" VALUES(1173,NULL,'Woburn, MA 1815',340,222,NULL,39,538,0);
INSERT INTO "django_geo_db_location" VALUES(1174,NULL,'Pinehurst, MA',343,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1175,NULL,'Pinehurst, MA 1820',343,222,NULL,39,539,0);
INSERT INTO "django_geo_db_location" VALUES(1176,NULL,'Billerica, MA',344,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1177,NULL,'Billerica, MA 1821',344,222,NULL,39,540,0);
INSERT INTO "django_geo_db_location" VALUES(1178,NULL,'Billerica, MA 1822',344,222,NULL,39,541,0);
INSERT INTO "django_geo_db_location" VALUES(1179,NULL,'Haverhill, MA',345,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1180,NULL,'Haverhill, MA 1823',345,222,NULL,39,542,0);
INSERT INTO "django_geo_db_location" VALUES(1181,NULL,'Chelmsford, MA',346,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1182,NULL,'Chelmsford, MA 1824',346,222,NULL,39,543,0);
INSERT INTO "django_geo_db_location" VALUES(1183,NULL,'Dracut, MA',347,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1184,NULL,'Dracut, MA 1826',347,222,NULL,39,544,0);
INSERT INTO "django_geo_db_location" VALUES(1185,NULL,'Dunstable, MA',348,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1186,NULL,'Dunstable, MA 1827',348,222,NULL,39,545,0);
INSERT INTO "django_geo_db_location" VALUES(1187,NULL,'Haverhill, MA 1830',345,222,NULL,39,546,0);
INSERT INTO "django_geo_db_location" VALUES(1188,NULL,'Haverhill, MA 1831',345,222,NULL,39,547,0);
INSERT INTO "django_geo_db_location" VALUES(1189,NULL,'Haverhill, MA 1832',345,222,NULL,39,548,0);
INSERT INTO "django_geo_db_location" VALUES(1190,NULL,'Georgetown, MA',349,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1191,NULL,'Georgetown, MA 1833',349,222,NULL,39,549,0);
INSERT INTO "django_geo_db_location" VALUES(1192,NULL,'Groveland, MA',350,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1193,NULL,'Groveland, MA 1834',350,222,NULL,39,550,0);
INSERT INTO "django_geo_db_location" VALUES(1194,NULL,'Haverhill, MA 1835',345,222,NULL,39,551,0);
INSERT INTO "django_geo_db_location" VALUES(1195,NULL,'Lawrence, MA',351,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1196,NULL,'Lawrence, MA 1840',351,222,NULL,39,552,0);
INSERT INTO "django_geo_db_location" VALUES(1197,NULL,'Lawrence, MA 1841',351,222,NULL,39,553,0);
INSERT INTO "django_geo_db_location" VALUES(1198,NULL,'Lawrence, MA 1842',351,222,NULL,39,554,0);
INSERT INTO "django_geo_db_location" VALUES(1199,NULL,'Lawrence, MA 1843',351,222,NULL,39,555,0);
INSERT INTO "django_geo_db_location" VALUES(1200,NULL,'Methuen, MA',352,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1201,NULL,'Methuen, MA 1844',352,222,NULL,39,556,0);
INSERT INTO "django_geo_db_location" VALUES(1202,NULL,'North Andover, MA',353,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1203,NULL,'North Andover, MA 1845',353,222,NULL,39,557,0);
INSERT INTO "django_geo_db_location" VALUES(1204,NULL,'Lowell, MA',354,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1205,NULL,'Lowell, MA 1850',354,222,NULL,39,558,0);
INSERT INTO "django_geo_db_location" VALUES(1206,NULL,'Lowell, MA 1851',354,222,NULL,39,559,0);
INSERT INTO "django_geo_db_location" VALUES(1207,NULL,'Lowell, MA 1852',354,222,NULL,39,560,0);
INSERT INTO "django_geo_db_location" VALUES(1208,NULL,'Lowell, MA 1853',354,222,NULL,39,561,0);
INSERT INTO "django_geo_db_location" VALUES(1209,NULL,'Lowell, MA 1854',354,222,NULL,39,562,0);
INSERT INTO "django_geo_db_location" VALUES(1210,NULL,'Lowell, MA 1856',354,222,NULL,39,563,0);
INSERT INTO "django_geo_db_location" VALUES(1211,NULL,'Merrimac, MA',355,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1212,NULL,'Merrimac, MA 1860',355,222,NULL,39,564,0);
INSERT INTO "django_geo_db_location" VALUES(1213,NULL,'North Billerica, MA',356,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1214,NULL,'North Billerica, MA 1862',356,222,NULL,39,565,0);
INSERT INTO "django_geo_db_location" VALUES(1215,NULL,'North Chelmsford, MA',357,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1216,NULL,'North Chelmsford, MA 1863',357,222,NULL,39,566,0);
INSERT INTO "django_geo_db_location" VALUES(1217,NULL,'North Reading, MA',358,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1218,NULL,'North Reading, MA 1864',358,222,NULL,39,567,0);
INSERT INTO "django_geo_db_location" VALUES(1219,NULL,'Nutting Lake, MA',359,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1220,NULL,'Nutting Lake, MA 1865',359,222,NULL,39,568,0);
INSERT INTO "django_geo_db_location" VALUES(1221,NULL,'Pinehurst, MA 1866',343,222,NULL,39,569,0);
INSERT INTO "django_geo_db_location" VALUES(1222,NULL,'Reading, MA',360,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1223,NULL,'Reading, MA 1867',360,222,NULL,39,570,0);
INSERT INTO "django_geo_db_location" VALUES(1224,NULL,'Tewksbury, MA',361,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1225,NULL,'Tewksbury, MA 1876',361,222,NULL,39,571,0);
INSERT INTO "django_geo_db_location" VALUES(1226,NULL,'Tyngsboro, MA',362,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1227,NULL,'Tyngsboro, MA 1879',362,222,NULL,39,572,0);
INSERT INTO "django_geo_db_location" VALUES(1228,NULL,'Wakefield, MA',363,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1229,NULL,'Wakefield, MA 1880',363,222,NULL,39,573,0);
INSERT INTO "django_geo_db_location" VALUES(1230,NULL,'West Boxford, MA',364,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1231,NULL,'West Boxford, MA 1885',364,222,NULL,39,574,0);
INSERT INTO "django_geo_db_location" VALUES(1232,NULL,'Westford, MA',365,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1233,NULL,'Westford, MA 1886',365,222,NULL,39,575,0);
INSERT INTO "django_geo_db_location" VALUES(1234,NULL,'Wilmington, MA',366,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1235,NULL,'Wilmington, MA 1887',366,222,NULL,39,576,0);
INSERT INTO "django_geo_db_location" VALUES(1236,NULL,'Woburn, MA 1888',340,222,NULL,39,577,0);
INSERT INTO "django_geo_db_location" VALUES(1237,NULL,'North Reading, MA 1889',358,222,NULL,39,578,0);
INSERT INTO "django_geo_db_location" VALUES(1238,NULL,'Winchester, MA',367,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1239,NULL,'Winchester, MA 1890',367,222,NULL,39,579,0);
INSERT INTO "django_geo_db_location" VALUES(1240,NULL,'Andover, MA 1899',342,222,NULL,39,580,0);
INSERT INTO "django_geo_db_location" VALUES(1241,NULL,'Lynn, MA',368,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1242,NULL,'Lynn, MA 1901',368,222,NULL,39,581,0);
INSERT INTO "django_geo_db_location" VALUES(1243,NULL,'Lynn, MA 1902',368,222,NULL,39,582,0);
INSERT INTO "django_geo_db_location" VALUES(1244,NULL,'Lynn, MA 1903',368,222,NULL,39,583,0);
INSERT INTO "django_geo_db_location" VALUES(1245,NULL,'Lynn, MA 1904',368,222,NULL,39,584,0);
INSERT INTO "django_geo_db_location" VALUES(1246,NULL,'Lynn, MA 1905',368,222,NULL,39,585,0);
INSERT INTO "django_geo_db_location" VALUES(1247,NULL,'Saugus, MA',369,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1248,NULL,'Saugus, MA 1906',369,222,NULL,39,586,0);
INSERT INTO "django_geo_db_location" VALUES(1249,NULL,'Swampscott, MA',370,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1250,NULL,'Swampscott, MA 1907',370,222,NULL,39,587,0);
INSERT INTO "django_geo_db_location" VALUES(1251,NULL,'Nahant, MA',371,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1252,NULL,'Nahant, MA 1908',371,222,NULL,39,588,0);
INSERT INTO "django_geo_db_location" VALUES(1253,NULL,'Lynn, MA 1910',368,222,NULL,39,589,0);
INSERT INTO "django_geo_db_location" VALUES(1254,NULL,'Amesbury, MA',372,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1255,NULL,'Amesbury, MA 1913',372,222,NULL,39,590,0);
INSERT INTO "django_geo_db_location" VALUES(1256,NULL,'Beverly, MA',373,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1257,NULL,'Beverly, MA 1915',373,222,NULL,39,591,0);
INSERT INTO "django_geo_db_location" VALUES(1258,NULL,'Boxford, MA',374,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1259,NULL,'Boxford, MA 1921',374,222,NULL,39,592,0);
INSERT INTO "django_geo_db_location" VALUES(1260,NULL,'Byfield, MA',375,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1261,NULL,'Byfield, MA 1922',375,222,NULL,39,593,0);
INSERT INTO "django_geo_db_location" VALUES(1262,NULL,'Danvers, MA',376,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1263,NULL,'Danvers, MA 1923',376,222,NULL,39,594,0);
INSERT INTO "django_geo_db_location" VALUES(1264,NULL,'Essex, MA',377,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1265,NULL,'Essex, MA 1929',377,222,NULL,39,595,0);
INSERT INTO "django_geo_db_location" VALUES(1266,NULL,'Gloucester, MA',378,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1267,NULL,'Gloucester, MA 1930',378,222,NULL,39,596,0);
INSERT INTO "django_geo_db_location" VALUES(1268,NULL,'Gloucester, MA 1931',378,222,NULL,39,597,0);
INSERT INTO "django_geo_db_location" VALUES(1269,NULL,'Hamilton, MA',379,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1270,NULL,'Hamilton, MA 1936',379,222,NULL,39,598,0);
INSERT INTO "django_geo_db_location" VALUES(1271,NULL,'Hathorne, MA',380,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1272,NULL,'Hathorne, MA 1937',380,222,NULL,39,599,0);
INSERT INTO "django_geo_db_location" VALUES(1273,NULL,'Ipswich, MA',381,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1274,NULL,'Ipswich, MA 1938',381,222,NULL,39,600,0);
INSERT INTO "django_geo_db_location" VALUES(1275,NULL,'Lynnfield, MA',382,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1276,NULL,'Lynnfield, MA 1940',382,222,NULL,39,601,0);
INSERT INTO "django_geo_db_location" VALUES(1277,NULL,'Manchester, MA',383,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1278,NULL,'Manchester, MA 1944',383,222,NULL,39,602,0);
INSERT INTO "django_geo_db_location" VALUES(1279,NULL,'Marblehead, MA',384,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1280,NULL,'Marblehead, MA 1945',384,222,NULL,39,603,0);
INSERT INTO "django_geo_db_location" VALUES(1281,NULL,'Salem, MA',385,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1282,NULL,'Salem, MA 1947',385,222,NULL,39,604,0);
INSERT INTO "django_geo_db_location" VALUES(1283,NULL,'Middleton, MA',386,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1284,NULL,'Middleton, MA 1949',386,222,NULL,39,605,0);
INSERT INTO "django_geo_db_location" VALUES(1285,NULL,'Newburyport, MA',387,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1286,NULL,'Newburyport, MA 1950',387,222,NULL,39,606,0);
INSERT INTO "django_geo_db_location" VALUES(1287,NULL,'Newbury, MA',388,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1288,NULL,'Newbury, MA 1951',388,222,NULL,39,607,0);
INSERT INTO "django_geo_db_location" VALUES(1289,NULL,'Salisbury, MA',389,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1290,NULL,'Salisbury, MA 1952',389,222,NULL,39,608,0);
INSERT INTO "django_geo_db_location" VALUES(1291,NULL,'Peabody, MA',390,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1292,NULL,'Peabody, MA 1960',390,222,NULL,39,609,0);
INSERT INTO "django_geo_db_location" VALUES(1293,NULL,'Peabody, MA 1961',390,222,NULL,39,610,0);
INSERT INTO "django_geo_db_location" VALUES(1294,NULL,'Prides Crossing, MA',391,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1295,NULL,'Prides Crossing, MA 1965',391,222,NULL,39,611,0);
INSERT INTO "django_geo_db_location" VALUES(1296,NULL,'Rockport, MA',392,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1297,NULL,'Rockport, MA 1966',392,222,NULL,39,612,0);
INSERT INTO "django_geo_db_location" VALUES(1298,NULL,'Rowley, MA',393,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1299,NULL,'Rowley, MA 1969',393,222,NULL,39,613,0);
INSERT INTO "django_geo_db_location" VALUES(1300,NULL,'Salem, MA 1970',385,222,NULL,39,614,0);
INSERT INTO "django_geo_db_location" VALUES(1301,NULL,'Salem, MA 1971',385,222,NULL,39,615,0);
INSERT INTO "django_geo_db_location" VALUES(1302,NULL,'South Hamilton, MA',394,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1303,NULL,'South Hamilton, MA 1982',394,222,NULL,39,616,0);
INSERT INTO "django_geo_db_location" VALUES(1304,NULL,'Topsfield, MA',395,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1305,NULL,'Topsfield, MA 1983',395,222,NULL,39,617,0);
INSERT INTO "django_geo_db_location" VALUES(1306,NULL,'Wenham, MA',396,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1307,NULL,'Wenham, MA 1984',396,222,NULL,39,618,0);
INSERT INTO "django_geo_db_location" VALUES(1308,NULL,'West Newbury, MA',397,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1309,NULL,'West Newbury, MA 1985',397,222,NULL,39,619,0);
INSERT INTO "django_geo_db_location" VALUES(1310,NULL,'Accord, MA',398,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1311,NULL,'Accord, MA 2018',398,222,NULL,39,620,0);
INSERT INTO "django_geo_db_location" VALUES(1312,NULL,'Bellingham, MA',399,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1313,NULL,'Bellingham, MA 2019',399,222,NULL,39,621,0);
INSERT INTO "django_geo_db_location" VALUES(1314,NULL,'Brant Rock, MA',400,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1315,NULL,'Brant Rock, MA 2020',400,222,NULL,39,622,0);
INSERT INTO "django_geo_db_location" VALUES(1316,NULL,'Canton, MA',401,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1317,NULL,'Canton, MA 2021',401,222,NULL,39,623,0);
INSERT INTO "django_geo_db_location" VALUES(1318,NULL,'Cohasset, MA',402,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1319,NULL,'Cohasset, MA 2025',402,222,NULL,39,624,0);
INSERT INTO "django_geo_db_location" VALUES(1320,NULL,'Dedham, MA',403,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1321,NULL,'Dedham, MA 2026',403,222,NULL,39,625,0);
INSERT INTO "django_geo_db_location" VALUES(1322,NULL,'Dedham, MA 2027',403,222,NULL,39,626,0);
INSERT INTO "django_geo_db_location" VALUES(1323,NULL,'Providence, RI',404,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1324,NULL,'Providence, RI 2029',404,222,NULL,46,627,0);
INSERT INTO "django_geo_db_location" VALUES(1325,NULL,'Dover, MA',405,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1326,NULL,'Dover, MA 2030',405,222,NULL,39,628,0);
INSERT INTO "django_geo_db_location" VALUES(1327,NULL,'East Mansfield, MA',406,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1328,NULL,'East Mansfield, MA 2031',406,222,NULL,39,629,0);
INSERT INTO "django_geo_db_location" VALUES(1329,NULL,'East Walpole, MA',407,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1330,NULL,'East Walpole, MA 2032',407,222,NULL,39,630,0);
INSERT INTO "django_geo_db_location" VALUES(1331,NULL,'Foxboro, MA',408,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1332,NULL,'Foxboro, MA 2035',408,222,NULL,39,631,0);
INSERT INTO "django_geo_db_location" VALUES(1333,NULL,'Franklin, MA',409,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1334,NULL,'Franklin, MA 2038',409,222,NULL,39,632,0);
INSERT INTO "django_geo_db_location" VALUES(1335,NULL,'Greenbush, MA',410,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1336,NULL,'Greenbush, MA 2040',410,222,NULL,39,633,0);
INSERT INTO "django_geo_db_location" VALUES(1337,NULL,'Green Harbor, MA',411,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1338,NULL,'Green Harbor, MA 2041',411,222,NULL,39,634,0);
INSERT INTO "django_geo_db_location" VALUES(1339,NULL,'Hingham, MA',412,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1340,NULL,'Hingham, MA 2043',412,222,NULL,39,635,0);
INSERT INTO "django_geo_db_location" VALUES(1341,NULL,'Hingham, MA 2044',412,222,NULL,39,636,0);
INSERT INTO "django_geo_db_location" VALUES(1342,NULL,'Hull, MA',413,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1343,NULL,'Hull, MA 2045',413,222,NULL,39,637,0);
INSERT INTO "django_geo_db_location" VALUES(1344,NULL,'Humarock, MA',414,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1345,NULL,'Humarock, MA 2047',414,222,NULL,39,638,0);
INSERT INTO "django_geo_db_location" VALUES(1346,NULL,'Mansfield, MA',415,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1347,NULL,'Mansfield, MA 2048',415,222,NULL,39,639,0);
INSERT INTO "django_geo_db_location" VALUES(1348,NULL,'Marshfield, MA',416,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1349,NULL,'Marshfield, MA 2050',416,222,NULL,39,640,0);
INSERT INTO "django_geo_db_location" VALUES(1350,NULL,'Marshfield Hills, MA',417,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1351,NULL,'Marshfield Hills, MA 2051',417,222,NULL,39,641,0);
INSERT INTO "django_geo_db_location" VALUES(1352,NULL,'Medfield, MA',418,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1353,NULL,'Medfield, MA 2052',418,222,NULL,39,642,0);
INSERT INTO "django_geo_db_location" VALUES(1354,NULL,'Medway, MA',419,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1355,NULL,'Medway, MA 2053',419,222,NULL,39,643,0);
INSERT INTO "django_geo_db_location" VALUES(1356,NULL,'Millis, MA',420,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1357,NULL,'Millis, MA 2054',420,222,NULL,39,644,0);
INSERT INTO "django_geo_db_location" VALUES(1358,NULL,'Minot, MA',421,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1359,NULL,'Minot, MA 2055',421,222,NULL,39,645,0);
INSERT INTO "django_geo_db_location" VALUES(1360,NULL,'Norfolk, MA',422,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1361,NULL,'Norfolk, MA 2056',422,222,NULL,39,646,0);
INSERT INTO "django_geo_db_location" VALUES(1362,NULL,'North Marshfield, MA',423,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1363,NULL,'North Marshfield, MA 2059',423,222,NULL,39,647,0);
INSERT INTO "django_geo_db_location" VALUES(1364,NULL,'North Scituate, MA',424,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1365,NULL,'North Scituate, MA 2060',424,222,NULL,39,648,0);
INSERT INTO "django_geo_db_location" VALUES(1366,NULL,'Norwell, MA',425,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1367,NULL,'Norwell, MA 2061',425,222,NULL,39,649,0);
INSERT INTO "django_geo_db_location" VALUES(1368,NULL,'Norwood, MA',426,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1369,NULL,'Norwood, MA 2062',426,222,NULL,39,650,0);
INSERT INTO "django_geo_db_location" VALUES(1370,NULL,'Ocean Bluff, MA',427,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1371,NULL,'Ocean Bluff, MA 2065',427,222,NULL,39,651,0);
INSERT INTO "django_geo_db_location" VALUES(1372,NULL,'Scituate, MA',428,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1373,NULL,'Scituate, MA 2066',428,222,NULL,39,652,0);
INSERT INTO "django_geo_db_location" VALUES(1374,NULL,'Sharon, MA',429,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1375,NULL,'Sharon, MA 2067',429,222,NULL,39,653,0);
INSERT INTO "django_geo_db_location" VALUES(1376,NULL,'Sheldonville, MA',430,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1377,NULL,'Sheldonville, MA 2070',430,222,NULL,39,654,0);
INSERT INTO "django_geo_db_location" VALUES(1378,NULL,'South Walpole, MA',431,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1379,NULL,'South Walpole, MA 2071',431,222,NULL,39,655,0);
INSERT INTO "django_geo_db_location" VALUES(1380,NULL,'Stoughton, MA',432,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1381,NULL,'Stoughton, MA 2072',432,222,NULL,39,656,0);
INSERT INTO "django_geo_db_location" VALUES(1382,NULL,'Walpole, MA',433,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1383,NULL,'Walpole, MA 2081',433,222,NULL,39,657,0);
INSERT INTO "django_geo_db_location" VALUES(1384,NULL,'Foxborough, MA',434,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1385,NULL,'Foxborough, MA 2085',434,222,NULL,39,658,0);
INSERT INTO "django_geo_db_location" VALUES(1386,NULL,'Westwood, MA',435,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1387,NULL,'Westwood, MA 2090',435,222,NULL,39,659,0);
INSERT INTO "django_geo_db_location" VALUES(1388,NULL,'Wrentham, MA',436,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1389,NULL,'Wrentham, MA 2093',436,222,NULL,39,660,0);
INSERT INTO "django_geo_db_location" VALUES(1390,NULL,'Boston, MA',437,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1391,NULL,'Boston, MA 2101',437,222,NULL,39,661,0);
INSERT INTO "django_geo_db_location" VALUES(1392,NULL,'Boston, MA 2102',437,222,NULL,39,662,0);
INSERT INTO "django_geo_db_location" VALUES(1393,NULL,'Boston, MA 2103',437,222,NULL,39,663,0);
INSERT INTO "django_geo_db_location" VALUES(1394,NULL,'Boston, MA 2104',437,222,NULL,39,664,0);
INSERT INTO "django_geo_db_location" VALUES(1395,NULL,'Boston, MA 2105',437,222,NULL,39,665,0);
INSERT INTO "django_geo_db_location" VALUES(1396,NULL,'Boston, MA 2106',437,222,NULL,39,666,0);
INSERT INTO "django_geo_db_location" VALUES(1397,NULL,'Boston, MA 2107',437,222,NULL,39,667,0);
INSERT INTO "django_geo_db_location" VALUES(1398,NULL,'Boston, MA 2108',437,222,NULL,39,668,0);
INSERT INTO "django_geo_db_location" VALUES(1399,NULL,'Boston, MA 2109',437,222,NULL,39,669,0);
INSERT INTO "django_geo_db_location" VALUES(1400,NULL,'Boston, MA 2110',437,222,NULL,39,670,0);
INSERT INTO "django_geo_db_location" VALUES(1401,NULL,'Boston, MA 2111',437,222,NULL,39,671,0);
INSERT INTO "django_geo_db_location" VALUES(1402,NULL,'Boston, MA 2112',437,222,NULL,39,672,0);
INSERT INTO "django_geo_db_location" VALUES(1403,NULL,'Boston, MA 2113',437,222,NULL,39,673,0);
INSERT INTO "django_geo_db_location" VALUES(1404,NULL,'Boston, MA 2114',437,222,NULL,39,674,0);
INSERT INTO "django_geo_db_location" VALUES(1405,NULL,'Boston, MA 2115',437,222,NULL,39,675,0);
INSERT INTO "django_geo_db_location" VALUES(1406,NULL,'Boston, MA 2116',437,222,NULL,39,676,0);
INSERT INTO "django_geo_db_location" VALUES(1407,NULL,'Boston, MA 2117',437,222,NULL,39,677,0);
INSERT INTO "django_geo_db_location" VALUES(1408,NULL,'Boston, MA 2118',437,222,NULL,39,678,0);
INSERT INTO "django_geo_db_location" VALUES(1409,NULL,'Boston, MA 2119',437,222,NULL,39,679,0);
INSERT INTO "django_geo_db_location" VALUES(1410,NULL,'Boston, MA 2120',437,222,NULL,39,680,0);
INSERT INTO "django_geo_db_location" VALUES(1411,NULL,'Boston, MA 2121',437,222,NULL,39,681,0);
INSERT INTO "django_geo_db_location" VALUES(1412,NULL,'Boston, MA 2122',437,222,NULL,39,682,0);
INSERT INTO "django_geo_db_location" VALUES(1413,NULL,'Boston, MA 2123',437,222,NULL,39,683,0);
INSERT INTO "django_geo_db_location" VALUES(1414,NULL,'Boston, MA 2124',437,222,NULL,39,684,0);
INSERT INTO "django_geo_db_location" VALUES(1415,NULL,'Boston, MA 2125',437,222,NULL,39,685,0);
INSERT INTO "django_geo_db_location" VALUES(1416,NULL,'Mattapan, MA',438,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1417,NULL,'Mattapan, MA 2126',438,222,NULL,39,686,0);
INSERT INTO "django_geo_db_location" VALUES(1418,NULL,'Boston, MA 2127',437,222,NULL,39,687,0);
INSERT INTO "django_geo_db_location" VALUES(1419,NULL,'Boston, MA 2128',437,222,NULL,39,688,0);
INSERT INTO "django_geo_db_location" VALUES(1420,NULL,'Charlestown, MA',439,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1421,NULL,'Charlestown, MA 2129',439,222,NULL,39,689,0);
INSERT INTO "django_geo_db_location" VALUES(1422,NULL,'Jamaica Plain, MA',440,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1423,NULL,'Jamaica Plain, MA 2130',440,222,NULL,39,690,0);
INSERT INTO "django_geo_db_location" VALUES(1424,NULL,'Roslindale, MA',441,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1425,NULL,'Roslindale, MA 2131',441,222,NULL,39,691,0);
INSERT INTO "django_geo_db_location" VALUES(1426,NULL,'West Roxbury, MA',442,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1427,NULL,'West Roxbury, MA 2132',442,222,NULL,39,692,0);
INSERT INTO "django_geo_db_location" VALUES(1428,NULL,'Boston, MA 2133',437,222,NULL,39,693,0);
INSERT INTO "django_geo_db_location" VALUES(1429,NULL,'Allston, MA',443,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1430,NULL,'Allston, MA 2134',443,222,NULL,39,694,0);
INSERT INTO "django_geo_db_location" VALUES(1431,NULL,'Brighton, MA',444,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1432,NULL,'Brighton, MA 2135',444,222,NULL,39,695,0);
INSERT INTO "django_geo_db_location" VALUES(1433,NULL,'Hyde Park, MA',445,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1434,NULL,'Hyde Park, MA 2136',445,222,NULL,39,696,0);
INSERT INTO "django_geo_db_location" VALUES(1435,NULL,'Readville, MA',446,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1436,NULL,'Readville, MA 2137',446,222,NULL,39,697,0);
INSERT INTO "django_geo_db_location" VALUES(1437,NULL,'Cambridge, MA',447,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1438,NULL,'Cambridge, MA 2138',447,222,NULL,39,698,0);
INSERT INTO "django_geo_db_location" VALUES(1439,NULL,'Cambridge, MA 2139',447,222,NULL,39,699,0);
INSERT INTO "django_geo_db_location" VALUES(1440,NULL,'Cambridge, MA 2140',447,222,NULL,39,700,0);
INSERT INTO "django_geo_db_location" VALUES(1441,NULL,'Cambridge, MA 2141',447,222,NULL,39,701,0);
INSERT INTO "django_geo_db_location" VALUES(1442,NULL,'Cambridge, MA 2142',447,222,NULL,39,702,0);
INSERT INTO "django_geo_db_location" VALUES(1443,NULL,'Somerville, MA',448,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1444,NULL,'Somerville, MA 2143',448,222,NULL,39,703,0);
INSERT INTO "django_geo_db_location" VALUES(1445,NULL,'Somerville, MA 2144',448,222,NULL,39,704,0);
INSERT INTO "django_geo_db_location" VALUES(1446,NULL,'Somerville, MA 2145',448,222,NULL,39,705,0);
INSERT INTO "django_geo_db_location" VALUES(1447,NULL,'Brookline, MA',449,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1448,NULL,'Brookline, MA 2146',449,222,NULL,39,706,0);
INSERT INTO "django_geo_db_location" VALUES(1449,NULL,'Brookline Village, MA',450,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1450,NULL,'Brookline Village, MA 2147',450,222,NULL,39,707,0);
INSERT INTO "django_geo_db_location" VALUES(1451,NULL,'Malden, MA',451,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1452,NULL,'Malden, MA 2148',451,222,NULL,39,708,0);
INSERT INTO "django_geo_db_location" VALUES(1453,NULL,'Everett, MA',452,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1454,NULL,'Everett, MA 2149',452,222,NULL,39,709,0);
INSERT INTO "django_geo_db_location" VALUES(1455,NULL,'Chelsea, MA',453,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1456,NULL,'Chelsea, MA 2150',453,222,NULL,39,710,0);
INSERT INTO "django_geo_db_location" VALUES(1457,NULL,'Revere, MA',454,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1458,NULL,'Revere, MA 2151',454,222,NULL,39,711,0);
INSERT INTO "django_geo_db_location" VALUES(1459,NULL,'Winthrop, MA',455,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1460,NULL,'Winthrop, MA 2152',455,222,NULL,39,712,0);
INSERT INTO "django_geo_db_location" VALUES(1461,NULL,'Medford, MA',456,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1462,NULL,'Medford, MA 2153',456,222,NULL,39,713,0);
INSERT INTO "django_geo_db_location" VALUES(1463,NULL,'Waltham, MA',457,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1464,NULL,'Waltham, MA 2154',457,222,NULL,39,714,0);
INSERT INTO "django_geo_db_location" VALUES(1465,NULL,'Medford, MA 2155',456,222,NULL,39,715,0);
INSERT INTO "django_geo_db_location" VALUES(1466,NULL,'West Medford, MA',458,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1467,NULL,'West Medford, MA 2156',458,222,NULL,39,716,0);
INSERT INTO "django_geo_db_location" VALUES(1468,NULL,'Babson Park, MA',459,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1469,NULL,'Babson Park, MA 2157',459,222,NULL,39,717,0);
INSERT INTO "django_geo_db_location" VALUES(1470,NULL,'Newton, MA',460,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1471,NULL,'Newton, MA 2158',460,222,NULL,39,718,0);
INSERT INTO "django_geo_db_location" VALUES(1472,NULL,'Newton, MA 2159',460,222,NULL,39,719,0);
INSERT INTO "django_geo_db_location" VALUES(1473,NULL,'Newton, MA 2160',460,222,NULL,39,720,0);
INSERT INTO "django_geo_db_location" VALUES(1474,NULL,'Newton, MA 2161',460,222,NULL,39,721,0);
INSERT INTO "django_geo_db_location" VALUES(1475,NULL,'Newton, MA 2162',460,222,NULL,39,722,0);
INSERT INTO "django_geo_db_location" VALUES(1476,NULL,'Boston, MA 2163',437,222,NULL,39,723,0);
INSERT INTO "django_geo_db_location" VALUES(1477,NULL,'Newton, MA 2164',460,222,NULL,39,724,0);
INSERT INTO "django_geo_db_location" VALUES(1478,NULL,'Newton, MA 2165',460,222,NULL,39,725,0);
INSERT INTO "django_geo_db_location" VALUES(1479,NULL,'Auburndale, MA',461,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1480,NULL,'Auburndale, MA 2166',461,222,NULL,39,726,0);
INSERT INTO "django_geo_db_location" VALUES(1481,NULL,'Chestnut Hill, MA',462,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1482,NULL,'Chestnut Hill, MA 2167',462,222,NULL,39,727,0);
INSERT INTO "django_geo_db_location" VALUES(1483,NULL,'Waban, MA',463,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1484,NULL,'Waban, MA 2168',463,222,NULL,39,728,0);
INSERT INTO "django_geo_db_location" VALUES(1485,NULL,'Quincy, MA',464,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1486,NULL,'Quincy, MA 2169',464,222,NULL,39,729,0);
INSERT INTO "django_geo_db_location" VALUES(1487,NULL,'Quincy, MA 2170',464,222,NULL,39,730,0);
INSERT INTO "django_geo_db_location" VALUES(1488,NULL,'Quincy, MA 2171',464,222,NULL,39,731,0);
INSERT INTO "django_geo_db_location" VALUES(1489,NULL,'Watertown, MA',465,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1490,NULL,'Watertown, MA 2172',465,222,NULL,39,732,0);
INSERT INTO "django_geo_db_location" VALUES(1491,NULL,'Lexington, MA',466,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1492,NULL,'Lexington, MA 2173',466,222,NULL,39,733,0);
INSERT INTO "django_geo_db_location" VALUES(1493,NULL,'Arlington, MA',467,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1494,NULL,'Arlington, MA 2174',467,222,NULL,39,734,0);
INSERT INTO "django_geo_db_location" VALUES(1495,NULL,'Arlington Heights, MA',468,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1496,NULL,'Arlington Heights, MA 2175',468,222,NULL,39,735,0);
INSERT INTO "django_geo_db_location" VALUES(1497,NULL,'Melrose, MA',469,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1498,NULL,'Melrose, MA 2176',469,222,NULL,39,736,0);
INSERT INTO "django_geo_db_location" VALUES(1499,NULL,'Melrose, MA 2177',469,222,NULL,39,737,0);
INSERT INTO "django_geo_db_location" VALUES(1500,NULL,'Belmont, MA',470,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1501,NULL,'Belmont, MA 2178',470,222,NULL,39,738,0);
INSERT INTO "django_geo_db_location" VALUES(1502,NULL,'Waverley, MA',471,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1503,NULL,'Waverley, MA 2179',471,222,NULL,39,739,0);
INSERT INTO "django_geo_db_location" VALUES(1504,NULL,'Stoneham, MA',472,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1505,NULL,'Stoneham, MA 2180',472,222,NULL,39,740,0);
INSERT INTO "django_geo_db_location" VALUES(1506,NULL,'Wellesley, MA',473,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1507,NULL,'Wellesley, MA 2181',473,222,NULL,39,741,0);
INSERT INTO "django_geo_db_location" VALUES(1508,NULL,'Braintree, MA',474,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1509,NULL,'Braintree, MA 2184',474,222,NULL,39,742,0);
INSERT INTO "django_geo_db_location" VALUES(1510,NULL,'Braintree, MA 2185',474,222,NULL,39,743,0);
INSERT INTO "django_geo_db_location" VALUES(1511,NULL,'Milton, MA',475,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1512,NULL,'Milton, MA 2186',475,222,NULL,39,744,0);
INSERT INTO "django_geo_db_location" VALUES(1513,NULL,'Milton Village, MA',476,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1514,NULL,'Milton Village, MA 2187',476,222,NULL,39,745,0);
INSERT INTO "django_geo_db_location" VALUES(1515,NULL,'Weymouth, MA',477,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1516,NULL,'Weymouth, MA 2188',477,222,NULL,39,746,0);
INSERT INTO "django_geo_db_location" VALUES(1517,NULL,'Weymouth, MA 2189',477,222,NULL,39,747,0);
INSERT INTO "django_geo_db_location" VALUES(1518,NULL,'Weymouth, MA 2190',477,222,NULL,39,748,0);
INSERT INTO "django_geo_db_location" VALUES(1519,NULL,'Weymouth, MA 2191',477,222,NULL,39,749,0);
INSERT INTO "django_geo_db_location" VALUES(1520,NULL,'Needham, MA',478,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1521,NULL,'Needham, MA 2192',478,222,NULL,39,750,0);
INSERT INTO "django_geo_db_location" VALUES(1522,NULL,'Weston, MA',479,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1523,NULL,'Weston, MA 2193',479,222,NULL,39,751,0);
INSERT INTO "django_geo_db_location" VALUES(1524,NULL,'Needham, MA 2194',478,222,NULL,39,752,0);
INSERT INTO "django_geo_db_location" VALUES(1525,NULL,'Newton, MA 2195',460,222,NULL,39,753,0);
INSERT INTO "django_geo_db_location" VALUES(1526,NULL,'Boston, MA 2196',437,222,NULL,39,754,0);
INSERT INTO "django_geo_db_location" VALUES(1527,NULL,'Boston, MA 2199',437,222,NULL,39,755,0);
INSERT INTO "django_geo_db_location" VALUES(1528,NULL,'Boston, MA 2201',437,222,NULL,39,756,0);
INSERT INTO "django_geo_db_location" VALUES(1529,NULL,'Boston, MA 2202',437,222,NULL,39,757,0);
INSERT INTO "django_geo_db_location" VALUES(1530,NULL,'Boston, MA 2203',437,222,NULL,39,758,0);
INSERT INTO "django_geo_db_location" VALUES(1531,NULL,'Boston, MA 2204',437,222,NULL,39,759,0);
INSERT INTO "django_geo_db_location" VALUES(1532,NULL,'Boston, MA 2205',437,222,NULL,39,760,0);
INSERT INTO "django_geo_db_location" VALUES(1533,NULL,'Boston, MA 2206',437,222,NULL,39,761,0);
INSERT INTO "django_geo_db_location" VALUES(1534,NULL,'Boston, MA 2207',437,222,NULL,39,762,0);
INSERT INTO "django_geo_db_location" VALUES(1535,NULL,'Boston, MA 2208',437,222,NULL,39,763,0);
INSERT INTO "django_geo_db_location" VALUES(1536,NULL,'Boston, MA 2209',437,222,NULL,39,764,0);
INSERT INTO "django_geo_db_location" VALUES(1537,NULL,'Boston, MA 2210',437,222,NULL,39,765,0);
INSERT INTO "django_geo_db_location" VALUES(1538,NULL,'Boston, MA 2211',437,222,NULL,39,766,0);
INSERT INTO "django_geo_db_location" VALUES(1539,NULL,'Boston, MA 2212',437,222,NULL,39,767,0);
INSERT INTO "django_geo_db_location" VALUES(1540,NULL,'Boston, MA 2215',437,222,NULL,39,768,0);
INSERT INTO "django_geo_db_location" VALUES(1541,NULL,'Boston, MA 2216',437,222,NULL,39,769,0);
INSERT INTO "django_geo_db_location" VALUES(1542,NULL,'Boston, MA 2217',437,222,NULL,39,770,0);
INSERT INTO "django_geo_db_location" VALUES(1543,NULL,'Boston, MA 2222',437,222,NULL,39,771,0);
INSERT INTO "django_geo_db_location" VALUES(1544,NULL,'Cambridge, MA 2238',447,222,NULL,39,772,0);
INSERT INTO "django_geo_db_location" VALUES(1545,NULL,'Cambridge, MA 2239',447,222,NULL,39,773,0);
INSERT INTO "django_geo_db_location" VALUES(1546,NULL,'Boston, MA 2241',437,222,NULL,39,774,0);
INSERT INTO "django_geo_db_location" VALUES(1547,NULL,'Waltham, MA 2254',457,222,NULL,39,775,0);
INSERT INTO "django_geo_db_location" VALUES(1548,NULL,'Newton, MA 2258',460,222,NULL,39,776,0);
INSERT INTO "django_geo_db_location" VALUES(1549,NULL,'Boston, MA 2266',437,222,NULL,39,777,0);
INSERT INTO "django_geo_db_location" VALUES(1550,NULL,'Quincy, MA 2269',464,222,NULL,39,778,0);
INSERT INTO "django_geo_db_location" VALUES(1551,NULL,'Watertown, MA 2272',465,222,NULL,39,779,0);
INSERT INTO "django_geo_db_location" VALUES(1552,NULL,'Watertown, MA 2277',465,222,NULL,39,780,0);
INSERT INTO "django_geo_db_location" VALUES(1553,NULL,'Boston, MA 2283',437,222,NULL,39,781,0);
INSERT INTO "django_geo_db_location" VALUES(1554,NULL,'Boston, MA 2284',437,222,NULL,39,782,0);
INSERT INTO "django_geo_db_location" VALUES(1555,NULL,'Boston, MA 2293',437,222,NULL,39,783,0);
INSERT INTO "django_geo_db_location" VALUES(1556,NULL,'Boston, MA 2295',437,222,NULL,39,784,0);
INSERT INTO "django_geo_db_location" VALUES(1557,NULL,'Boston, MA 2297',437,222,NULL,39,785,0);
INSERT INTO "django_geo_db_location" VALUES(1558,NULL,'Brockton, MA',480,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1559,NULL,'Brockton, MA 2301',480,222,NULL,39,786,0);
INSERT INTO "django_geo_db_location" VALUES(1560,NULL,'Brockton, MA 2302',480,222,NULL,39,787,0);
INSERT INTO "django_geo_db_location" VALUES(1561,NULL,'Brockton, MA 2303',480,222,NULL,39,788,0);
INSERT INTO "django_geo_db_location" VALUES(1562,NULL,'Brockton, MA 2304',480,222,NULL,39,789,0);
INSERT INTO "django_geo_db_location" VALUES(1563,NULL,'Brockton, MA 2305',480,222,NULL,39,790,0);
INSERT INTO "django_geo_db_location" VALUES(1564,NULL,'Avon, MA',481,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1565,NULL,'Avon, MA 2322',481,222,NULL,39,791,0);
INSERT INTO "django_geo_db_location" VALUES(1566,NULL,'Bridgewater, MA',482,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1567,NULL,'Bridgewater, MA 2324',482,222,NULL,39,792,0);
INSERT INTO "django_geo_db_location" VALUES(1568,NULL,'Bridgewater, MA 2325',482,222,NULL,39,793,0);
INSERT INTO "django_geo_db_location" VALUES(1569,NULL,'Bryantville, MA',483,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1570,NULL,'Bryantville, MA 2327',483,222,NULL,39,794,0);
INSERT INTO "django_geo_db_location" VALUES(1571,NULL,'Carver, MA',484,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1572,NULL,'Carver, MA 2330',484,222,NULL,39,795,0);
INSERT INTO "django_geo_db_location" VALUES(1573,NULL,'Duxbury, MA',485,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1574,NULL,'Duxbury, MA 2331',485,222,NULL,39,796,0);
INSERT INTO "django_geo_db_location" VALUES(1575,NULL,'Duxbury, MA 2332',485,222,NULL,39,797,0);
INSERT INTO "django_geo_db_location" VALUES(1576,NULL,'East Bridgewater, MA',486,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1577,NULL,'East Bridgewater, MA 2333',486,222,NULL,39,798,0);
INSERT INTO "django_geo_db_location" VALUES(1578,NULL,'Easton, MA',487,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1579,NULL,'Easton, MA 2334',487,222,NULL,39,799,0);
INSERT INTO "django_geo_db_location" VALUES(1580,NULL,'Elmwood, MA',488,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1581,NULL,'Elmwood, MA 2337',488,222,NULL,39,800,0);
INSERT INTO "django_geo_db_location" VALUES(1582,NULL,'Halifax, MA',489,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1583,NULL,'Halifax, MA 2338',489,222,NULL,39,801,0);
INSERT INTO "django_geo_db_location" VALUES(1584,NULL,'Hanover, MA',490,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1585,NULL,'Hanover, MA 2339',490,222,NULL,39,802,0);
INSERT INTO "django_geo_db_location" VALUES(1586,NULL,'Hanson, MA',491,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1587,NULL,'Hanson, MA 2341',491,222,NULL,39,803,0);
INSERT INTO "django_geo_db_location" VALUES(1588,NULL,'Holbrook, MA',492,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1589,NULL,'Holbrook, MA 2343',492,222,NULL,39,804,0);
INSERT INTO "django_geo_db_location" VALUES(1590,NULL,'Middleboro, MA',493,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1591,NULL,'Middleboro, MA 2344',493,222,NULL,39,805,0);
INSERT INTO "django_geo_db_location" VALUES(1592,NULL,'Manomet, MA',494,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1593,NULL,'Manomet, MA 2345',494,222,NULL,39,806,0);
INSERT INTO "django_geo_db_location" VALUES(1594,NULL,'Middleboro, MA 2346',493,222,NULL,39,807,0);
INSERT INTO "django_geo_db_location" VALUES(1595,NULL,'Lakeville, MA',495,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1596,NULL,'Lakeville, MA 2347',495,222,NULL,39,808,0);
INSERT INTO "django_geo_db_location" VALUES(1597,NULL,'Middleboro, MA 2348',493,222,NULL,39,809,0);
INSERT INTO "django_geo_db_location" VALUES(1598,NULL,'Middleboro, MA 2349',493,222,NULL,39,810,0);
INSERT INTO "django_geo_db_location" VALUES(1599,NULL,'Monponsett, MA',496,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1600,NULL,'Monponsett, MA 2350',496,222,NULL,39,811,0);
INSERT INTO "django_geo_db_location" VALUES(1601,NULL,'Abington, MA',497,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1602,NULL,'Abington, MA 2351',497,222,NULL,39,812,0);
INSERT INTO "django_geo_db_location" VALUES(1603,NULL,'North Carver, MA',498,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1604,NULL,'North Carver, MA 2355',498,222,NULL,39,813,0);
INSERT INTO "django_geo_db_location" VALUES(1605,NULL,'North Easton, MA',499,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1606,NULL,'North Easton, MA 2356',499,222,NULL,39,814,0);
INSERT INTO "django_geo_db_location" VALUES(1607,NULL,'North Easton, MA 2357',499,222,NULL,39,815,0);
INSERT INTO "django_geo_db_location" VALUES(1608,NULL,'North Pembroke, MA',500,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1609,NULL,'North Pembroke, MA 2358',500,222,NULL,39,816,0);
INSERT INTO "django_geo_db_location" VALUES(1610,NULL,'Pembroke, MA',501,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1611,NULL,'Pembroke, MA 2359',501,222,NULL,39,817,0);
INSERT INTO "django_geo_db_location" VALUES(1612,NULL,'Plymouth, MA',502,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1613,NULL,'Plymouth, MA 2360',502,222,NULL,39,818,0);
INSERT INTO "django_geo_db_location" VALUES(1614,NULL,'Plymouth, MA 2361',502,222,NULL,39,819,0);
INSERT INTO "django_geo_db_location" VALUES(1615,NULL,'Plymouth, MA 2362',502,222,NULL,39,820,0);
INSERT INTO "django_geo_db_location" VALUES(1616,NULL,'Plymouth, MA 2363',502,222,NULL,39,821,0);
INSERT INTO "django_geo_db_location" VALUES(1617,NULL,'Kingston, MA',503,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1618,NULL,'Kingston, MA 2364',503,222,NULL,39,822,0);
INSERT INTO "django_geo_db_location" VALUES(1619,NULL,'South Carver, MA',504,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1620,NULL,'South Carver, MA 2366',504,222,NULL,39,823,0);
INSERT INTO "django_geo_db_location" VALUES(1621,NULL,'Plympton, MA',505,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1622,NULL,'Plympton, MA 2367',505,222,NULL,39,824,0);
INSERT INTO "django_geo_db_location" VALUES(1623,NULL,'Randolph, MA',506,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1624,NULL,'Randolph, MA 2368',506,222,NULL,39,825,0);
INSERT INTO "django_geo_db_location" VALUES(1625,NULL,'Dennis Port, MA',507,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1626,NULL,'Dennis Port, MA 2369',507,222,NULL,39,826,0);
INSERT INTO "django_geo_db_location" VALUES(1627,NULL,'Rockland, MA',508,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1628,NULL,'Rockland, MA 2370',508,222,NULL,39,827,0);
INSERT INTO "django_geo_db_location" VALUES(1629,NULL,'South Easton, MA',509,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1630,NULL,'South Easton, MA 2375',509,222,NULL,39,828,0);
INSERT INTO "django_geo_db_location" VALUES(1631,NULL,'West Bridgewater, MA',510,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1632,NULL,'West Bridgewater, MA 2379',510,222,NULL,39,829,0);
INSERT INTO "django_geo_db_location" VALUES(1633,NULL,'White Horse Beach, MA',511,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1634,NULL,'White Horse Beach, MA 2381',511,222,NULL,39,830,0);
INSERT INTO "django_geo_db_location" VALUES(1635,NULL,'Whitman, MA',512,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1636,NULL,'Whitman, MA 2382',512,222,NULL,39,831,0);
INSERT INTO "django_geo_db_location" VALUES(1637,NULL,'Brockton, MA 2401',480,222,NULL,39,832,0);
INSERT INTO "django_geo_db_location" VALUES(1638,NULL,'Brockton, MA 2402',480,222,NULL,39,833,0);
INSERT INTO "django_geo_db_location" VALUES(1639,NULL,'Brockton, MA 2403',480,222,NULL,39,834,0);
INSERT INTO "django_geo_db_location" VALUES(1640,NULL,'Brockton, MA 2404',480,222,NULL,39,835,0);
INSERT INTO "django_geo_db_location" VALUES(1641,NULL,'Brockton, MA 2405',480,222,NULL,39,836,0);
INSERT INTO "django_geo_db_location" VALUES(1642,NULL,'Scituate, MA 2407',428,222,NULL,39,837,0);
INSERT INTO "django_geo_db_location" VALUES(1643,NULL,'Lexington, MA 2420',466,222,NULL,39,838,0);
INSERT INTO "django_geo_db_location" VALUES(1644,NULL,'Lexington, MA 2421',466,222,NULL,39,839,0);
INSERT INTO "django_geo_db_location" VALUES(1645,NULL,'Brookline, MA 2445',449,222,NULL,39,840,0);
INSERT INTO "django_geo_db_location" VALUES(1646,NULL,'Brookline, MA 2446',449,222,NULL,39,841,0);
INSERT INTO "django_geo_db_location" VALUES(1647,NULL,'Brookline Village, MA 2447',450,222,NULL,39,842,0);
INSERT INTO "django_geo_db_location" VALUES(1648,NULL,'Waltham, MA 2451',457,222,NULL,39,843,0);
INSERT INTO "django_geo_db_location" VALUES(1649,NULL,'Waltham, MA 2452',457,222,NULL,39,844,0);
INSERT INTO "django_geo_db_location" VALUES(1650,NULL,'Waltham, MA 2453',457,222,NULL,39,845,0);
INSERT INTO "django_geo_db_location" VALUES(1651,NULL,'Waltham, MA 2454',457,222,NULL,39,846,0);
INSERT INTO "django_geo_db_location" VALUES(1652,NULL,'New Town, MA',513,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1653,NULL,'New Town, MA 2456',513,222,NULL,39,847,0);
INSERT INTO "django_geo_db_location" VALUES(1654,NULL,'Babson Park, MA 2457',459,222,NULL,39,848,0);
INSERT INTO "django_geo_db_location" VALUES(1655,NULL,'Newton, MA 2458',460,222,NULL,39,849,0);
INSERT INTO "django_geo_db_location" VALUES(1656,NULL,'Newton Center, MA',514,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1657,NULL,'Newton Center, MA 2459',514,222,NULL,39,850,0);
INSERT INTO "django_geo_db_location" VALUES(1658,NULL,'Newtonville, MA',515,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1659,NULL,'Newtonville, MA 2460',515,222,NULL,39,851,0);
INSERT INTO "django_geo_db_location" VALUES(1660,NULL,'Newton Highlands, MA',516,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1661,NULL,'Newton Highlands, MA 2461',516,222,NULL,39,852,0);
INSERT INTO "django_geo_db_location" VALUES(1662,NULL,'Newton Lower Falls, MA',517,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1663,NULL,'Newton Lower Falls, MA 2462',517,222,NULL,39,853,0);
INSERT INTO "django_geo_db_location" VALUES(1664,NULL,'Newton Upper Falls, MA',518,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1665,NULL,'Newton Upper Falls, MA 2464',518,222,NULL,39,854,0);
INSERT INTO "django_geo_db_location" VALUES(1666,NULL,'West Newton, MA',519,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1667,NULL,'West Newton, MA 2465',519,222,NULL,39,855,0);
INSERT INTO "django_geo_db_location" VALUES(1668,NULL,'Auburndale, MA 2466',461,222,NULL,39,856,0);
INSERT INTO "django_geo_db_location" VALUES(1669,NULL,'Chestnut Hill, MA 2467',462,222,NULL,39,857,0);
INSERT INTO "django_geo_db_location" VALUES(1670,NULL,'Waban, MA 2468',463,222,NULL,39,858,0);
INSERT INTO "django_geo_db_location" VALUES(1671,NULL,'Watertown, MA 2471',465,222,NULL,39,859,0);
INSERT INTO "django_geo_db_location" VALUES(1672,NULL,'Watertown, MA 2472',465,222,NULL,39,860,0);
INSERT INTO "django_geo_db_location" VALUES(1673,NULL,'Arlington, MA 2474',467,222,NULL,39,861,0);
INSERT INTO "django_geo_db_location" VALUES(1674,NULL,'Arlington Heights, MA 2475',468,222,NULL,39,862,0);
INSERT INTO "django_geo_db_location" VALUES(1675,NULL,'Arlington, MA 2476',467,222,NULL,39,863,0);
INSERT INTO "django_geo_db_location" VALUES(1676,NULL,'Watertown, MA 2477',465,222,NULL,39,864,0);
INSERT INTO "django_geo_db_location" VALUES(1677,NULL,'Belmont, MA 2478',470,222,NULL,39,865,0);
INSERT INTO "django_geo_db_location" VALUES(1678,NULL,'Waverley, MA 2479',471,222,NULL,39,866,0);
INSERT INTO "django_geo_db_location" VALUES(1679,NULL,'Wellesley Hills, MA',520,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1680,NULL,'Wellesley Hills, MA 2481',520,222,NULL,39,867,0);
INSERT INTO "django_geo_db_location" VALUES(1681,NULL,'Wellesley, MA 2482',473,222,NULL,39,868,0);
INSERT INTO "django_geo_db_location" VALUES(1682,NULL,'Needham, MA 2492',478,222,NULL,39,869,0);
INSERT INTO "django_geo_db_location" VALUES(1683,NULL,'Weston, MA 2493',479,222,NULL,39,870,0);
INSERT INTO "django_geo_db_location" VALUES(1684,NULL,'Needham, MA 2494',478,222,NULL,39,871,0);
INSERT INTO "django_geo_db_location" VALUES(1685,NULL,'Nonantum, MA',521,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1686,NULL,'Nonantum, MA 2495',521,222,NULL,39,872,0);
INSERT INTO "django_geo_db_location" VALUES(1687,NULL,'Buzzards Bay, MA',522,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1688,NULL,'Buzzards Bay, MA 2532',522,222,NULL,39,873,0);
INSERT INTO "django_geo_db_location" VALUES(1689,NULL,'Cataumet, MA',523,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1690,NULL,'Cataumet, MA 2534',523,222,NULL,39,874,0);
INSERT INTO "django_geo_db_location" VALUES(1691,NULL,'Chilmark, MA',524,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1692,NULL,'Chilmark, MA 2535',524,222,NULL,39,875,0);
INSERT INTO "django_geo_db_location" VALUES(1693,NULL,'East Falmouth, MA',525,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1694,NULL,'East Falmouth, MA 2536',525,222,NULL,39,876,0);
INSERT INTO "django_geo_db_location" VALUES(1695,NULL,'East Sandwich, MA',526,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1696,NULL,'East Sandwich, MA 2537',526,222,NULL,39,877,0);
INSERT INTO "django_geo_db_location" VALUES(1697,NULL,'East Wareham, MA',527,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1698,NULL,'East Wareham, MA 2538',527,222,NULL,39,878,0);
INSERT INTO "django_geo_db_location" VALUES(1699,NULL,'Edgartown, MA',528,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1700,NULL,'Edgartown, MA 2539',528,222,NULL,39,879,0);
INSERT INTO "django_geo_db_location" VALUES(1701,NULL,'Falmouth, MA',529,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1702,NULL,'Falmouth, MA 2540',529,222,NULL,39,880,0);
INSERT INTO "django_geo_db_location" VALUES(1703,NULL,'Falmouth, MA 2541',529,222,NULL,39,881,0);
INSERT INTO "django_geo_db_location" VALUES(1704,NULL,'Buzzards Bay, MA 2542',522,222,NULL,39,882,0);
INSERT INTO "django_geo_db_location" VALUES(1705,NULL,'Woods Hole, MA',530,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1706,NULL,'Woods Hole, MA 2543',530,222,NULL,39,883,0);
INSERT INTO "django_geo_db_location" VALUES(1707,NULL,'Mashpee, MA',531,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1708,NULL,'Mashpee, MA 2549',531,222,NULL,39,884,0);
INSERT INTO "django_geo_db_location" VALUES(1709,NULL,'Oak Bluffs, MA',532,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1710,NULL,'Oak Bluffs, MA 2551',532,222,NULL,39,885,0);
INSERT INTO "django_geo_db_location" VALUES(1711,NULL,'Menemsha, MA',533,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1712,NULL,'Menemsha, MA 2552',533,222,NULL,39,886,0);
INSERT INTO "django_geo_db_location" VALUES(1713,NULL,'Monument Beach, MA',534,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1714,NULL,'Monument Beach, MA 2553',534,222,NULL,39,887,0);
INSERT INTO "django_geo_db_location" VALUES(1715,NULL,'Nantucket, MA',535,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1716,NULL,'Nantucket, MA 2554',535,222,NULL,39,888,0);
INSERT INTO "django_geo_db_location" VALUES(1717,NULL,'North Falmouth, MA',536,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1718,NULL,'North Falmouth, MA 2556',536,222,NULL,39,889,0);
INSERT INTO "django_geo_db_location" VALUES(1719,NULL,'Oak Bluffs, MA 2557',532,222,NULL,39,890,0);
INSERT INTO "django_geo_db_location" VALUES(1720,NULL,'Onset, MA',537,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1721,NULL,'Onset, MA 2558',537,222,NULL,39,891,0);
INSERT INTO "django_geo_db_location" VALUES(1722,NULL,'Pocasset, MA',538,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1723,NULL,'Pocasset, MA 2559',538,222,NULL,39,892,0);
INSERT INTO "django_geo_db_location" VALUES(1724,NULL,'Sagamore, MA',539,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1725,NULL,'Sagamore, MA 2561',539,222,NULL,39,893,0);
INSERT INTO "django_geo_db_location" VALUES(1726,NULL,'Sagamore Beach, MA',540,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1727,NULL,'Sagamore Beach, MA 2562',540,222,NULL,39,894,0);
INSERT INTO "django_geo_db_location" VALUES(1728,NULL,'Sandwich, MA',541,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1729,NULL,'Sandwich, MA 2563',541,222,NULL,39,895,0);
INSERT INTO "django_geo_db_location" VALUES(1730,NULL,'Siasconset, MA',542,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1731,NULL,'Siasconset, MA 2564',542,222,NULL,39,896,0);
INSERT INTO "django_geo_db_location" VALUES(1732,NULL,'Silver Beach, MA',543,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1733,NULL,'Silver Beach, MA 2565',543,222,NULL,39,897,0);
INSERT INTO "django_geo_db_location" VALUES(1734,NULL,'Sagamore, MA 2567',539,222,NULL,39,898,0);
INSERT INTO "django_geo_db_location" VALUES(1735,NULL,'Vineyard Haven, MA',544,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1736,NULL,'Vineyard Haven, MA 2568',544,222,NULL,39,899,0);
INSERT INTO "django_geo_db_location" VALUES(1737,NULL,'Wareham, MA',545,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1738,NULL,'Wareham, MA 2571',545,222,NULL,39,900,0);
INSERT INTO "django_geo_db_location" VALUES(1739,NULL,'Vineyard Haven, MA 2573',544,222,NULL,39,901,0);
INSERT INTO "django_geo_db_location" VALUES(1740,NULL,'West Falmouth, MA',546,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1741,NULL,'West Falmouth, MA 2574',546,222,NULL,39,902,0);
INSERT INTO "django_geo_db_location" VALUES(1742,NULL,'West Tisbury, MA',547,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1743,NULL,'West Tisbury, MA 2575',547,222,NULL,39,903,0);
INSERT INTO "django_geo_db_location" VALUES(1744,NULL,'West Wareham, MA',548,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1745,NULL,'West Wareham, MA 2576',548,222,NULL,39,904,0);
INSERT INTO "django_geo_db_location" VALUES(1746,NULL,'Nantucket, MA 2584',535,222,NULL,39,905,0);
INSERT INTO "django_geo_db_location" VALUES(1747,NULL,'West Tisbury, MA 2595',547,222,NULL,39,906,0);
INSERT INTO "django_geo_db_location" VALUES(1748,NULL,'Hyannis, MA',549,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1749,NULL,'Hyannis, MA 2601',549,222,NULL,39,907,0);
INSERT INTO "django_geo_db_location" VALUES(1750,NULL,'Barnstable Town, MA',550,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1751,NULL,'Barnstable Town, MA 2625',550,222,NULL,39,908,0);
INSERT INTO "django_geo_db_location" VALUES(1752,NULL,'Barnstable, MA',551,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1753,NULL,'Barnstable, MA 2630',551,222,NULL,39,909,0);
INSERT INTO "django_geo_db_location" VALUES(1754,NULL,'Brewster, MA',552,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1755,NULL,'Brewster, MA 2631',552,222,NULL,39,910,0);
INSERT INTO "django_geo_db_location" VALUES(1756,NULL,'Centerville, MA',553,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1757,NULL,'Centerville, MA 2632',553,222,NULL,39,911,0);
INSERT INTO "django_geo_db_location" VALUES(1758,NULL,'Chatham, MA',554,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1759,NULL,'Chatham, MA 2633',554,222,NULL,39,912,0);
INSERT INTO "django_geo_db_location" VALUES(1760,NULL,'Centerville, MA 2634',553,222,NULL,39,913,0);
INSERT INTO "django_geo_db_location" VALUES(1761,NULL,'Cotuit, MA',555,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1762,NULL,'Cotuit, MA 2635',555,222,NULL,39,914,0);
INSERT INTO "django_geo_db_location" VALUES(1763,NULL,'Centerville, MA 2636',553,222,NULL,39,915,0);
INSERT INTO "django_geo_db_location" VALUES(1764,NULL,'Cummaquid, MA',556,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1765,NULL,'Cummaquid, MA 2637',556,222,NULL,39,916,0);
INSERT INTO "django_geo_db_location" VALUES(1766,NULL,'Dennis, MA',557,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1767,NULL,'Dennis, MA 2638',557,222,NULL,39,917,0);
INSERT INTO "django_geo_db_location" VALUES(1768,NULL,'Dennis Port, MA 2639',507,222,NULL,39,918,0);
INSERT INTO "django_geo_db_location" VALUES(1769,NULL,'East Dennis, MA',558,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1770,NULL,'East Dennis, MA 2641',558,222,NULL,39,919,0);
INSERT INTO "django_geo_db_location" VALUES(1771,NULL,'Eastham, MA',559,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1772,NULL,'Eastham, MA 2642',559,222,NULL,39,920,0);
INSERT INTO "django_geo_db_location" VALUES(1773,NULL,'East Orleans, MA',560,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1774,NULL,'East Orleans, MA 2643',560,222,NULL,39,921,0);
INSERT INTO "django_geo_db_location" VALUES(1775,NULL,'Forestdale, MA',561,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1776,NULL,'Forestdale, MA 2644',561,222,NULL,39,922,0);
INSERT INTO "django_geo_db_location" VALUES(1777,NULL,'Harwich, MA',562,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1778,NULL,'Harwich, MA 2645',562,222,NULL,39,923,0);
INSERT INTO "django_geo_db_location" VALUES(1779,NULL,'Harwich Port, MA',563,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1780,NULL,'Harwich Port, MA 2646',563,222,NULL,39,924,0);
INSERT INTO "django_geo_db_location" VALUES(1781,NULL,'Hyannis Port, MA',564,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1782,NULL,'Hyannis Port, MA 2647',564,222,NULL,39,925,0);
INSERT INTO "django_geo_db_location" VALUES(1783,NULL,'Marstons Mills, MA',565,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1784,NULL,'Marstons Mills, MA 2648',565,222,NULL,39,926,0);
INSERT INTO "django_geo_db_location" VALUES(1785,NULL,'Mashpee, MA 2649',531,222,NULL,39,927,0);
INSERT INTO "django_geo_db_location" VALUES(1786,NULL,'North Chatham, MA',566,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1787,NULL,'North Chatham, MA 2650',566,222,NULL,39,928,0);
INSERT INTO "django_geo_db_location" VALUES(1788,NULL,'North Eastham, MA',567,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1789,NULL,'North Eastham, MA 2651',567,222,NULL,39,929,0);
INSERT INTO "django_geo_db_location" VALUES(1790,NULL,'North Truro, MA',568,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1791,NULL,'North Truro, MA 2652',568,222,NULL,39,930,0);
INSERT INTO "django_geo_db_location" VALUES(1792,NULL,'Orleans, MA',569,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1793,NULL,'Orleans, MA 2653',569,222,NULL,39,931,0);
INSERT INTO "django_geo_db_location" VALUES(1794,NULL,'Nantucket, MA 2654',535,222,NULL,39,932,0);
INSERT INTO "django_geo_db_location" VALUES(1795,NULL,'Osterville, MA',570,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1796,NULL,'Osterville, MA 2655',570,222,NULL,39,933,0);
INSERT INTO "django_geo_db_location" VALUES(1797,NULL,'Provincetown, MA',571,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1798,NULL,'Provincetown, MA 2657',571,222,NULL,39,934,0);
INSERT INTO "django_geo_db_location" VALUES(1799,NULL,'South Chatham, MA',572,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1800,NULL,'South Chatham, MA 2659',572,222,NULL,39,935,0);
INSERT INTO "django_geo_db_location" VALUES(1801,NULL,'South Dennis, MA',573,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1802,NULL,'South Dennis, MA 2660',573,222,NULL,39,936,0);
INSERT INTO "django_geo_db_location" VALUES(1803,NULL,'South Harwich, MA',574,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1804,NULL,'South Harwich, MA 2661',574,222,NULL,39,937,0);
INSERT INTO "django_geo_db_location" VALUES(1805,NULL,'South Orleans, MA',575,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1806,NULL,'South Orleans, MA 2662',575,222,NULL,39,938,0);
INSERT INTO "django_geo_db_location" VALUES(1807,NULL,'South Wellfleet, MA',576,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1808,NULL,'South Wellfleet, MA 2663',576,222,NULL,39,939,0);
INSERT INTO "django_geo_db_location" VALUES(1809,NULL,'South Yarmouth, MA',577,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1810,NULL,'South Yarmouth, MA 2664',577,222,NULL,39,940,0);
INSERT INTO "django_geo_db_location" VALUES(1811,NULL,'Truro, MA',578,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1812,NULL,'Truro, MA 2666',578,222,NULL,39,941,0);
INSERT INTO "django_geo_db_location" VALUES(1813,NULL,'Wellfleet, MA',579,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1814,NULL,'Wellfleet, MA 2667',579,222,NULL,39,942,0);
INSERT INTO "django_geo_db_location" VALUES(1815,NULL,'West Barnstable, MA',580,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1816,NULL,'West Barnstable, MA 2668',580,222,NULL,39,943,0);
INSERT INTO "django_geo_db_location" VALUES(1817,NULL,'West Chatham, MA',581,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1818,NULL,'West Chatham, MA 2669',581,222,NULL,39,944,0);
INSERT INTO "django_geo_db_location" VALUES(1819,NULL,'West Dennis, MA',582,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1820,NULL,'West Dennis, MA 2670',582,222,NULL,39,945,0);
INSERT INTO "django_geo_db_location" VALUES(1821,NULL,'West Harwich, MA',583,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1822,NULL,'West Harwich, MA 2671',583,222,NULL,39,946,0);
INSERT INTO "django_geo_db_location" VALUES(1823,NULL,'West Hyannisport, MA',584,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1824,NULL,'West Hyannisport, MA 2672',584,222,NULL,39,947,0);
INSERT INTO "django_geo_db_location" VALUES(1825,NULL,'West Yarmouth, MA',585,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1826,NULL,'West Yarmouth, MA 2673',585,222,NULL,39,948,0);
INSERT INTO "django_geo_db_location" VALUES(1827,NULL,'Yarmouth Port, MA',586,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1828,NULL,'Yarmouth Port, MA 2675',586,222,NULL,39,949,0);
INSERT INTO "django_geo_db_location" VALUES(1829,NULL,'Assonet, MA',587,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1830,NULL,'Assonet, MA 2702',587,222,NULL,39,950,0);
INSERT INTO "django_geo_db_location" VALUES(1831,NULL,'Attleboro, MA',588,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1832,NULL,'Attleboro, MA 2703',588,222,NULL,39,951,0);
INSERT INTO "django_geo_db_location" VALUES(1833,NULL,'Chartley, MA',589,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1834,NULL,'Chartley, MA 2712',589,222,NULL,39,952,0);
INSERT INTO "django_geo_db_location" VALUES(1835,NULL,'Cuttyhunk, MA',590,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1836,NULL,'Cuttyhunk, MA 2713',590,222,NULL,39,953,0);
INSERT INTO "django_geo_db_location" VALUES(1837,NULL,'Dartmouth, MA',591,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1838,NULL,'Dartmouth, MA 2714',591,222,NULL,39,954,0);
INSERT INTO "django_geo_db_location" VALUES(1839,NULL,'Dighton, MA',592,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1840,NULL,'Dighton, MA 2715',592,222,NULL,39,955,0);
INSERT INTO "django_geo_db_location" VALUES(1841,NULL,'East Freetown, MA',593,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1842,NULL,'East Freetown, MA 2717',593,222,NULL,39,956,0);
INSERT INTO "django_geo_db_location" VALUES(1843,NULL,'East Taunton, MA',594,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1844,NULL,'East Taunton, MA 2718',594,222,NULL,39,957,0);
INSERT INTO "django_geo_db_location" VALUES(1845,NULL,'Fairhaven, MA',595,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1846,NULL,'Fairhaven, MA 2719',595,222,NULL,39,958,0);
INSERT INTO "django_geo_db_location" VALUES(1847,NULL,'Fall River, MA',596,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1848,NULL,'Fall River, MA 2720',596,222,NULL,39,959,0);
INSERT INTO "django_geo_db_location" VALUES(1849,NULL,'Fall River, MA 2721',596,222,NULL,39,960,0);
INSERT INTO "django_geo_db_location" VALUES(1850,NULL,'Fall River, MA 2722',596,222,NULL,39,961,0);
INSERT INTO "django_geo_db_location" VALUES(1851,NULL,'Fall River, MA 2723',596,222,NULL,39,962,0);
INSERT INTO "django_geo_db_location" VALUES(1852,NULL,'Fall River, MA 2724',596,222,NULL,39,963,0);
INSERT INTO "django_geo_db_location" VALUES(1853,NULL,'Somerset, MA',597,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1854,NULL,'Somerset, MA 2725',597,222,NULL,39,964,0);
INSERT INTO "django_geo_db_location" VALUES(1855,NULL,'Somerset, MA 2726',597,222,NULL,39,965,0);
INSERT INTO "django_geo_db_location" VALUES(1856,NULL,'Easton, MA 2735',487,222,NULL,39,966,0);
INSERT INTO "django_geo_db_location" VALUES(1857,NULL,'Marion, MA',598,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1858,NULL,'Marion, MA 2738',598,222,NULL,39,967,0);
INSERT INTO "django_geo_db_location" VALUES(1859,NULL,'Mattapoisett, MA',599,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1860,NULL,'Mattapoisett, MA 2739',599,222,NULL,39,968,0);
INSERT INTO "django_geo_db_location" VALUES(1861,NULL,'New Bedford, MA',600,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1862,NULL,'New Bedford, MA 2740',600,222,NULL,39,969,0);
INSERT INTO "django_geo_db_location" VALUES(1863,NULL,'New Bedford, MA 2741',600,222,NULL,39,970,0);
INSERT INTO "django_geo_db_location" VALUES(1864,NULL,'New Bedford, MA 2742',600,222,NULL,39,971,0);
INSERT INTO "django_geo_db_location" VALUES(1865,NULL,'Acushnet, MA',601,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1866,NULL,'Acushnet, MA 2743',601,222,NULL,39,972,0);
INSERT INTO "django_geo_db_location" VALUES(1867,NULL,'New Bedford, MA 2744',600,222,NULL,39,973,0);
INSERT INTO "django_geo_db_location" VALUES(1868,NULL,'New Bedford, MA 2745',600,222,NULL,39,974,0);
INSERT INTO "django_geo_db_location" VALUES(1869,NULL,'New Bedford, MA 2746',600,222,NULL,39,975,0);
INSERT INTO "django_geo_db_location" VALUES(1870,NULL,'North Dartmouth, MA',602,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1871,NULL,'North Dartmouth, MA 2747',602,222,NULL,39,976,0);
INSERT INTO "django_geo_db_location" VALUES(1872,NULL,'South Dartmouth, MA',603,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1873,NULL,'South Dartmouth, MA 2748',603,222,NULL,39,977,0);
INSERT INTO "django_geo_db_location" VALUES(1874,NULL,'North Attleboro, MA',604,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1875,NULL,'North Attleboro, MA 2760',604,222,NULL,39,978,0);
INSERT INTO "django_geo_db_location" VALUES(1876,NULL,'North Attleboro, MA 2761',604,222,NULL,39,979,0);
INSERT INTO "django_geo_db_location" VALUES(1877,NULL,'Plainville, MA',605,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1878,NULL,'Plainville, MA 2762',605,222,NULL,39,980,0);
INSERT INTO "django_geo_db_location" VALUES(1879,NULL,'Attleboro Falls, MA',606,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1880,NULL,'Attleboro Falls, MA 2763',606,222,NULL,39,981,0);
INSERT INTO "django_geo_db_location" VALUES(1881,NULL,'North Dighton, MA',607,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1882,NULL,'North Dighton, MA 2764',607,222,NULL,39,982,0);
INSERT INTO "django_geo_db_location" VALUES(1883,NULL,'Norton, MA',608,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1884,NULL,'Norton, MA 2766',608,222,NULL,39,983,0);
INSERT INTO "django_geo_db_location" VALUES(1885,NULL,'Raynham, MA',609,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1886,NULL,'Raynham, MA 2767',609,222,NULL,39,984,0);
INSERT INTO "django_geo_db_location" VALUES(1887,NULL,'Raynham Center, MA',610,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1888,NULL,'Raynham Center, MA 2768',610,222,NULL,39,985,0);
INSERT INTO "django_geo_db_location" VALUES(1889,NULL,'Rehoboth, MA',611,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1890,NULL,'Rehoboth, MA 2769',611,222,NULL,39,986,0);
INSERT INTO "django_geo_db_location" VALUES(1891,NULL,'Rochester, MA',612,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1892,NULL,'Rochester, MA 2770',612,222,NULL,39,987,0);
INSERT INTO "django_geo_db_location" VALUES(1893,NULL,'Seekonk, MA',613,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1894,NULL,'Seekonk, MA 2771',613,222,NULL,39,988,0);
INSERT INTO "django_geo_db_location" VALUES(1895,NULL,'Swansea, MA',614,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1896,NULL,'Swansea, MA 2777',614,222,NULL,39,989,0);
INSERT INTO "django_geo_db_location" VALUES(1897,NULL,'Berkley, MA',615,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1898,NULL,'Berkley, MA 2779',615,222,NULL,39,990,0);
INSERT INTO "django_geo_db_location" VALUES(1899,NULL,'Taunton, MA',616,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1900,NULL,'Taunton, MA 2780',616,222,NULL,39,991,0);
INSERT INTO "django_geo_db_location" VALUES(1901,NULL,'Westport, MA',617,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1902,NULL,'Westport, MA 2781',617,222,NULL,39,992,0);
INSERT INTO "django_geo_db_location" VALUES(1903,NULL,'Taunton, MA 2783',616,222,NULL,39,993,0);
INSERT INTO "django_geo_db_location" VALUES(1904,NULL,'South Kingstown, RI',618,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1905,NULL,'South Kingstown, RI 2789',618,222,NULL,46,994,0);
INSERT INTO "django_geo_db_location" VALUES(1906,NULL,'Westport, MA 2790',617,222,NULL,39,995,0);
INSERT INTO "django_geo_db_location" VALUES(1907,NULL,'Westport Point, MA',619,222,NULL,39,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1908,NULL,'Westport Point, MA 2791',619,222,NULL,39,996,0);
INSERT INTO "django_geo_db_location" VALUES(1909,NULL,'Adamsville, RI',620,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1910,NULL,'Adamsville, RI 2801',620,222,NULL,46,997,0);
INSERT INTO "django_geo_db_location" VALUES(1911,NULL,'Albion, RI',621,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1912,NULL,'Albion, RI 2802',621,222,NULL,46,998,0);
INSERT INTO "django_geo_db_location" VALUES(1913,NULL,'Ashaway, RI',622,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1914,NULL,'Ashaway, RI 2804',622,222,NULL,46,999,0);
INSERT INTO "django_geo_db_location" VALUES(1915,NULL,'Foster, RI',623,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1916,NULL,'Foster, RI 2805',623,222,NULL,46,1000,0);
INSERT INTO "django_geo_db_location" VALUES(1917,NULL,'Barrington, RI',624,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1918,NULL,'Barrington, RI 2806',624,222,NULL,46,1001,0);
INSERT INTO "django_geo_db_location" VALUES(1919,NULL,'Block Island, RI',625,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1920,NULL,'Block Island, RI 2807',625,222,NULL,46,1002,0);
INSERT INTO "django_geo_db_location" VALUES(1921,NULL,'Bradford, RI',626,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1922,NULL,'Bradford, RI 2808',626,222,NULL,46,1003,0);
INSERT INTO "django_geo_db_location" VALUES(1923,NULL,'Bristol, RI',627,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1924,NULL,'Bristol, RI 2809',627,222,NULL,46,1004,0);
INSERT INTO "django_geo_db_location" VALUES(1925,NULL,'Carolina, RI',628,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1926,NULL,'Carolina, RI 2812',628,222,NULL,46,1005,0);
INSERT INTO "django_geo_db_location" VALUES(1927,NULL,'Charlestown, RI',629,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1928,NULL,'Charlestown, RI 2813',629,222,NULL,46,1006,0);
INSERT INTO "django_geo_db_location" VALUES(1929,NULL,'Chepachet, RI',630,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1930,NULL,'Chepachet, RI 2814',630,222,NULL,46,1007,0);
INSERT INTO "django_geo_db_location" VALUES(1931,NULL,'Clayville, RI',631,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1932,NULL,'Clayville, RI 2815',631,222,NULL,46,1008,0);
INSERT INTO "django_geo_db_location" VALUES(1933,NULL,'Coventry, RI',632,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1934,NULL,'Coventry, RI 2816',632,222,NULL,46,1009,0);
INSERT INTO "django_geo_db_location" VALUES(1935,NULL,'West Greenwich, RI',633,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1936,NULL,'West Greenwich, RI 2817',633,222,NULL,46,1010,0);
INSERT INTO "django_geo_db_location" VALUES(1937,NULL,'East Greenwich, RI',634,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1938,NULL,'East Greenwich, RI 2818',634,222,NULL,46,1011,0);
INSERT INTO "django_geo_db_location" VALUES(1939,NULL,'Exeter, RI',635,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1940,NULL,'Exeter, RI 2822',635,222,NULL,46,1012,0);
INSERT INTO "django_geo_db_location" VALUES(1941,NULL,'Fiskeville, RI',636,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1942,NULL,'Fiskeville, RI 2823',636,222,NULL,46,1013,0);
INSERT INTO "django_geo_db_location" VALUES(1943,NULL,'Forestdale, RI',637,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1944,NULL,'Forestdale, RI 2824',637,222,NULL,46,1014,0);
INSERT INTO "django_geo_db_location" VALUES(1945,NULL,'Foster, RI 2825',623,222,NULL,46,1015,0);
INSERT INTO "django_geo_db_location" VALUES(1946,NULL,'Glendale, RI',638,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1947,NULL,'Glendale, RI 2826',638,222,NULL,46,1016,0);
INSERT INTO "django_geo_db_location" VALUES(1948,NULL,'Greene, RI',639,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1949,NULL,'Greene, RI 2827',639,222,NULL,46,1017,0);
INSERT INTO "django_geo_db_location" VALUES(1950,NULL,'Greenville, RI',640,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1951,NULL,'Greenville, RI 2828',640,222,NULL,46,1018,0);
INSERT INTO "django_geo_db_location" VALUES(1952,NULL,'Harmony, RI',641,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1953,NULL,'Harmony, RI 2829',641,222,NULL,46,1019,0);
INSERT INTO "django_geo_db_location" VALUES(1954,NULL,'Harrisville, RI',642,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1955,NULL,'Harrisville, RI 2830',642,222,NULL,46,1020,0);
INSERT INTO "django_geo_db_location" VALUES(1956,NULL,'Hope, RI',643,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1957,NULL,'Hope, RI 2831',643,222,NULL,46,1021,0);
INSERT INTO "django_geo_db_location" VALUES(1958,NULL,'Hope Valley, RI',644,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1959,NULL,'Hope Valley, RI 2832',644,222,NULL,46,1022,0);
INSERT INTO "django_geo_db_location" VALUES(1960,NULL,'Hopkinton, RI',645,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1961,NULL,'Hopkinton, RI 2833',645,222,NULL,46,1023,0);
INSERT INTO "django_geo_db_location" VALUES(1962,NULL,'Jamestown, RI',646,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1963,NULL,'Jamestown, RI 2835',646,222,NULL,46,1024,0);
INSERT INTO "django_geo_db_location" VALUES(1964,NULL,'Kenyon, RI',647,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1965,NULL,'Kenyon, RI 2836',647,222,NULL,46,1025,0);
INSERT INTO "django_geo_db_location" VALUES(1966,NULL,'Little Compton, RI',648,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1967,NULL,'Little Compton, RI 2837',648,222,NULL,46,1026,0);
INSERT INTO "django_geo_db_location" VALUES(1968,NULL,'Manville, RI',649,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1969,NULL,'Manville, RI 2838',649,222,NULL,46,1027,0);
INSERT INTO "django_geo_db_location" VALUES(1970,NULL,'Mapleville, RI',650,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1971,NULL,'Mapleville, RI 2839',650,222,NULL,46,1028,0);
INSERT INTO "django_geo_db_location" VALUES(1972,NULL,'Newport, RI',651,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1973,NULL,'Newport, RI 2840',651,222,NULL,46,1029,0);
INSERT INTO "django_geo_db_location" VALUES(1974,NULL,'Newport, RI 2841',651,222,NULL,46,1030,0);
INSERT INTO "django_geo_db_location" VALUES(1975,NULL,'Middletown, RI',652,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1976,NULL,'Middletown, RI 2842',652,222,NULL,46,1031,0);
INSERT INTO "django_geo_db_location" VALUES(1977,NULL,'North Kingstown, RI',653,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1978,NULL,'North Kingstown, RI 2852',653,222,NULL,46,1032,0);
INSERT INTO "django_geo_db_location" VALUES(1979,NULL,'North Kingstown, RI 2854',653,222,NULL,46,1033,0);
INSERT INTO "django_geo_db_location" VALUES(1980,NULL,'North Scituate, RI',654,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1981,NULL,'North Scituate, RI 2857',654,222,NULL,46,1034,0);
INSERT INTO "django_geo_db_location" VALUES(1982,NULL,'Oakland, RI',655,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1983,NULL,'Oakland, RI 2858',655,222,NULL,46,1035,0);
INSERT INTO "django_geo_db_location" VALUES(1984,NULL,'Pascoag, RI',656,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1985,NULL,'Pascoag, RI 2859',656,222,NULL,46,1036,0);
INSERT INTO "django_geo_db_location" VALUES(1986,NULL,'Pawtucket, RI',657,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1987,NULL,'Pawtucket, RI 2860',657,222,NULL,46,1037,0);
INSERT INTO "django_geo_db_location" VALUES(1988,NULL,'Pawtucket, RI 2861',657,222,NULL,46,1038,0);
INSERT INTO "django_geo_db_location" VALUES(1989,NULL,'Pawtucket, RI 2862',657,222,NULL,46,1039,0);
INSERT INTO "django_geo_db_location" VALUES(1990,NULL,'Central Falls, RI',658,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1991,NULL,'Central Falls, RI 2863',658,222,NULL,46,1040,0);
INSERT INTO "django_geo_db_location" VALUES(1992,NULL,'Cumberland, RI',659,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1993,NULL,'Cumberland, RI 2864',659,222,NULL,46,1041,0);
INSERT INTO "django_geo_db_location" VALUES(1994,NULL,'Lincoln, RI',660,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1995,NULL,'Lincoln, RI 2865',660,222,NULL,46,1042,0);
INSERT INTO "django_geo_db_location" VALUES(1996,NULL,'Portsmouth, RI',661,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1997,NULL,'Portsmouth, RI 2871',661,222,NULL,46,1043,0);
INSERT INTO "django_geo_db_location" VALUES(1998,NULL,'Prudence Island, RI',662,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(1999,NULL,'Prudence Island, RI 2872',662,222,NULL,46,1044,0);
INSERT INTO "django_geo_db_location" VALUES(2000,NULL,'Rockville, RI',663,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2001,NULL,'Rockville, RI 2873',663,222,NULL,46,1045,0);
INSERT INTO "django_geo_db_location" VALUES(2002,NULL,'Saunderstown, RI',664,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2003,NULL,'Saunderstown, RI 2874',664,222,NULL,46,1046,0);
INSERT INTO "django_geo_db_location" VALUES(2004,NULL,'Shannock, RI',665,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2005,NULL,'Shannock, RI 2875',665,222,NULL,46,1047,0);
INSERT INTO "django_geo_db_location" VALUES(2006,NULL,'Slatersville, RI',666,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2007,NULL,'Slatersville, RI 2876',666,222,NULL,46,1048,0);
INSERT INTO "django_geo_db_location" VALUES(2008,NULL,'Slocum, RI',667,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2009,NULL,'Slocum, RI 2877',667,222,NULL,46,1049,0);
INSERT INTO "django_geo_db_location" VALUES(2010,NULL,'Tiverton, RI',668,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2011,NULL,'Tiverton, RI 2878',668,222,NULL,46,1050,0);
INSERT INTO "django_geo_db_location" VALUES(2012,NULL,'Wakefield, RI',669,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2013,NULL,'Wakefield, RI 2879',669,222,NULL,46,1051,0);
INSERT INTO "django_geo_db_location" VALUES(2014,NULL,'Wakefield, RI 2880',669,222,NULL,46,1052,0);
INSERT INTO "django_geo_db_location" VALUES(2015,NULL,'Kingston, RI',670,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2016,NULL,'Kingston, RI 2881',670,222,NULL,46,1053,0);
INSERT INTO "django_geo_db_location" VALUES(2017,NULL,'Narragansett, RI',671,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2018,NULL,'Narragansett, RI 2882',671,222,NULL,46,1054,0);
INSERT INTO "django_geo_db_location" VALUES(2019,NULL,'Peace Dale, RI',672,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2020,NULL,'Peace Dale, RI 2883',672,222,NULL,46,1055,0);
INSERT INTO "django_geo_db_location" VALUES(2021,NULL,'Warren, RI',673,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2022,NULL,'Warren, RI 2885',673,222,NULL,46,1056,0);
INSERT INTO "django_geo_db_location" VALUES(2023,NULL,'Warwick, RI',674,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2024,NULL,'Warwick, RI 2886',674,222,NULL,46,1057,0);
INSERT INTO "django_geo_db_location" VALUES(2025,NULL,'Warwick, RI 2887',674,222,NULL,46,1058,0);
INSERT INTO "django_geo_db_location" VALUES(2026,NULL,'Warwick, RI 2888',674,222,NULL,46,1059,0);
INSERT INTO "django_geo_db_location" VALUES(2027,NULL,'Warwick, RI 2889',674,222,NULL,46,1060,0);
INSERT INTO "django_geo_db_location" VALUES(2028,NULL,'Westerly, RI',675,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2029,NULL,'Westerly, RI 2891',675,222,NULL,46,1061,0);
INSERT INTO "django_geo_db_location" VALUES(2030,NULL,'West Kingston, RI',676,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2031,NULL,'West Kingston, RI 2892',676,222,NULL,46,1062,0);
INSERT INTO "django_geo_db_location" VALUES(2032,NULL,'West Warwick, RI',677,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2033,NULL,'West Warwick, RI 2893',677,222,NULL,46,1063,0);
INSERT INTO "django_geo_db_location" VALUES(2034,NULL,'Wood River Junction, RI',678,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2035,NULL,'Wood River Junction, RI 2894',678,222,NULL,46,1064,0);
INSERT INTO "django_geo_db_location" VALUES(2036,NULL,'Woonsocket, RI',679,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2037,NULL,'Woonsocket, RI 2895',679,222,NULL,46,1065,0);
INSERT INTO "django_geo_db_location" VALUES(2038,NULL,'North Smithfield, RI',680,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2039,NULL,'North Smithfield, RI 2896',680,222,NULL,46,1066,0);
INSERT INTO "django_geo_db_location" VALUES(2040,NULL,'Wyoming, RI',681,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2041,NULL,'Wyoming, RI 2898',681,222,NULL,46,1067,0);
INSERT INTO "django_geo_db_location" VALUES(2042,NULL,'Providence, RI 2901',404,222,NULL,46,1068,0);
INSERT INTO "django_geo_db_location" VALUES(2043,NULL,'Providence, RI 2902',404,222,NULL,46,1069,0);
INSERT INTO "django_geo_db_location" VALUES(2044,NULL,'Providence, RI 2903',404,222,NULL,46,1070,0);
INSERT INTO "django_geo_db_location" VALUES(2045,NULL,'Providence, RI 2904',404,222,NULL,46,1071,0);
INSERT INTO "django_geo_db_location" VALUES(2046,NULL,'Providence, RI 2905',404,222,NULL,46,1072,0);
INSERT INTO "django_geo_db_location" VALUES(2047,NULL,'Providence, RI 2906',404,222,NULL,46,1073,0);
INSERT INTO "django_geo_db_location" VALUES(2048,NULL,'Providence, RI 2907',404,222,NULL,46,1074,0);
INSERT INTO "django_geo_db_location" VALUES(2049,NULL,'Providence, RI 2908',404,222,NULL,46,1075,0);
INSERT INTO "django_geo_db_location" VALUES(2050,NULL,'Providence, RI 2909',404,222,NULL,46,1076,0);
INSERT INTO "django_geo_db_location" VALUES(2051,NULL,'Cranston, RI',682,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2052,NULL,'Cranston, RI 2910',682,222,NULL,46,1077,0);
INSERT INTO "django_geo_db_location" VALUES(2053,NULL,'North Providence, RI',683,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2054,NULL,'North Providence, RI 2911',683,222,NULL,46,1078,0);
INSERT INTO "django_geo_db_location" VALUES(2055,NULL,'Providence, RI 2912',404,222,NULL,46,1079,0);
INSERT INTO "django_geo_db_location" VALUES(2056,NULL,'East Providence, RI',684,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2057,NULL,'East Providence, RI 2914',684,222,NULL,46,1080,0);
INSERT INTO "django_geo_db_location" VALUES(2058,NULL,'Riverside, RI',685,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2059,NULL,'Riverside, RI 2915',685,222,NULL,46,1081,0);
INSERT INTO "django_geo_db_location" VALUES(2060,NULL,'Rumford, RI',686,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2061,NULL,'Rumford, RI 2916',686,222,NULL,46,1082,0);
INSERT INTO "django_geo_db_location" VALUES(2062,NULL,'Smithfield, RI',687,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2063,NULL,'Smithfield, RI 2917',687,222,NULL,46,1083,0);
INSERT INTO "django_geo_db_location" VALUES(2064,NULL,'Providence, RI 2918',404,222,NULL,46,1084,0);
INSERT INTO "django_geo_db_location" VALUES(2065,NULL,'Johnston, RI',688,222,NULL,46,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2066,NULL,'Johnston, RI 2919',688,222,NULL,46,1085,0);
INSERT INTO "django_geo_db_location" VALUES(2067,NULL,'Cranston, RI 2920',682,222,NULL,46,1086,0);
INSERT INTO "django_geo_db_location" VALUES(2068,NULL,'Cranston, RI 2921',682,222,NULL,46,1087,0);
INSERT INTO "django_geo_db_location" VALUES(2069,NULL,'Providence, RI 2940',404,222,NULL,46,1088,0);
INSERT INTO "django_geo_db_location" VALUES(2070,NULL,'Fremont, NH',689,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2071,NULL,'Fremont, NH 3004',689,222,NULL,29,1089,0);
INSERT INTO "django_geo_db_location" VALUES(2072,NULL,'Nashua, NH',690,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2073,NULL,'Nashua, NH 3030',690,222,NULL,29,1090,0);
INSERT INTO "django_geo_db_location" VALUES(2074,NULL,'Amherst, NH',691,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2075,NULL,'Amherst, NH 3031',691,222,NULL,29,1091,0);
INSERT INTO "django_geo_db_location" VALUES(2076,NULL,'Auburn, NH',692,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2077,NULL,'Auburn, NH 3032',692,222,NULL,29,1092,0);
INSERT INTO "django_geo_db_location" VALUES(2078,NULL,'Brookline, NH',693,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2079,NULL,'Brookline, NH 3033',693,222,NULL,29,1093,0);
INSERT INTO "django_geo_db_location" VALUES(2080,NULL,'Candia, NH',694,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2081,NULL,'Candia, NH 3034',694,222,NULL,29,1094,0);
INSERT INTO "django_geo_db_location" VALUES(2082,NULL,'Chester, NH',695,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2083,NULL,'Chester, NH 3036',695,222,NULL,29,1095,0);
INSERT INTO "django_geo_db_location" VALUES(2084,NULL,'Deerfield, NH',696,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2085,NULL,'Deerfield, NH 3037',696,222,NULL,29,1096,0);
INSERT INTO "django_geo_db_location" VALUES(2086,NULL,'Derry, NH',697,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2087,NULL,'Derry, NH 3038',697,222,NULL,29,1097,0);
INSERT INTO "django_geo_db_location" VALUES(2088,NULL,'East Candia, NH',698,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2089,NULL,'East Candia, NH 3040',698,222,NULL,29,1098,0);
INSERT INTO "django_geo_db_location" VALUES(2090,NULL,'East Derry, NH',699,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2091,NULL,'East Derry, NH 3041',699,222,NULL,29,1099,0);
INSERT INTO "django_geo_db_location" VALUES(2092,NULL,'Epping, NH',700,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2093,NULL,'Epping, NH 3042',700,222,NULL,29,1100,0);
INSERT INTO "django_geo_db_location" VALUES(2094,NULL,'Francestown, NH',701,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2095,NULL,'Francestown, NH 3043',701,222,NULL,29,1101,0);
INSERT INTO "django_geo_db_location" VALUES(2096,NULL,'Fremont, NH 3044',689,222,NULL,29,1102,0);
INSERT INTO "django_geo_db_location" VALUES(2097,NULL,'Goffstown, NH',702,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2098,NULL,'Goffstown, NH 3045',702,222,NULL,29,1103,0);
INSERT INTO "django_geo_db_location" VALUES(2099,NULL,'Dunbarton, NH',703,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2100,NULL,'Dunbarton, NH 3046',703,222,NULL,29,1104,0);
INSERT INTO "django_geo_db_location" VALUES(2101,NULL,'Greenfield, NH',704,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2102,NULL,'Greenfield, NH 3047',704,222,NULL,29,1105,0);
INSERT INTO "django_geo_db_location" VALUES(2103,NULL,'Greenville, NH',705,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2104,NULL,'Greenville, NH 3048',705,222,NULL,29,1106,0);
INSERT INTO "django_geo_db_location" VALUES(2105,NULL,'Hollis, NH',706,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2106,NULL,'Hollis, NH 3049',706,222,NULL,29,1107,0);
INSERT INTO "django_geo_db_location" VALUES(2107,NULL,'Hudson, NH',707,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2108,NULL,'Hudson, NH 3051',707,222,NULL,29,1108,0);
INSERT INTO "django_geo_db_location" VALUES(2109,NULL,'Litchfield, NH',708,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2110,NULL,'Litchfield, NH 3052',708,222,NULL,29,1109,0);
INSERT INTO "django_geo_db_location" VALUES(2111,NULL,'Londonderry, NH',709,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2112,NULL,'Londonderry, NH 3053',709,222,NULL,29,1110,0);
INSERT INTO "django_geo_db_location" VALUES(2113,NULL,'Merrimack, NH',710,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2114,NULL,'Merrimack, NH 3054',710,222,NULL,29,1111,0);
INSERT INTO "django_geo_db_location" VALUES(2115,NULL,'Milford, NH',711,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2116,NULL,'Milford, NH 3055',711,222,NULL,29,1112,0);
INSERT INTO "django_geo_db_location" VALUES(2117,NULL,'Mont Vernon, NH',712,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2118,NULL,'Mont Vernon, NH 3057',712,222,NULL,29,1113,0);
INSERT INTO "django_geo_db_location" VALUES(2119,NULL,'Sharon, NH',713,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2120,NULL,'Sharon, NH 3058',713,222,NULL,29,1114,0);
INSERT INTO "django_geo_db_location" VALUES(2121,NULL,'Nashua, NH 3060',690,222,NULL,29,1115,0);
INSERT INTO "django_geo_db_location" VALUES(2122,NULL,'Nashua, NH 3061',690,222,NULL,29,1116,0);
INSERT INTO "django_geo_db_location" VALUES(2123,NULL,'Nashua, NH 3062',690,222,NULL,29,1117,0);
INSERT INTO "django_geo_db_location" VALUES(2124,NULL,'Nashua, NH 3063',690,222,NULL,29,1118,0);
INSERT INTO "django_geo_db_location" VALUES(2125,NULL,'Nashua, NH 3064',690,222,NULL,29,1119,0);
INSERT INTO "django_geo_db_location" VALUES(2126,NULL,'New Boston, NH',714,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2127,NULL,'New Boston, NH 3070',714,222,NULL,29,1120,0);
INSERT INTO "django_geo_db_location" VALUES(2128,NULL,'New Ipswich, NH',715,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2129,NULL,'New Ipswich, NH 3071',715,222,NULL,29,1121,0);
INSERT INTO "django_geo_db_location" VALUES(2130,NULL,'North Salem, NH',716,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2131,NULL,'North Salem, NH 3073',716,222,NULL,29,1122,0);
INSERT INTO "django_geo_db_location" VALUES(2132,NULL,'Pelham, NH',717,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2133,NULL,'Pelham, NH 3076',717,222,NULL,29,1123,0);
INSERT INTO "django_geo_db_location" VALUES(2134,NULL,'Raymond, NH',718,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2135,NULL,'Raymond, NH 3077',718,222,NULL,29,1124,0);
INSERT INTO "django_geo_db_location" VALUES(2136,NULL,'Salem, NH',719,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2137,NULL,'Salem, NH 3079',719,222,NULL,29,1125,0);
INSERT INTO "django_geo_db_location" VALUES(2138,NULL,'Lyndeborough, NH',720,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2139,NULL,'Lyndeborough, NH 3082',720,222,NULL,29,1126,0);
INSERT INTO "django_geo_db_location" VALUES(2140,NULL,'Temple, NH',721,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2141,NULL,'Temple, NH 3084',721,222,NULL,29,1127,0);
INSERT INTO "django_geo_db_location" VALUES(2142,NULL,'Wilton, NH',722,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2143,NULL,'Wilton, NH 3086',722,222,NULL,29,1128,0);
INSERT INTO "django_geo_db_location" VALUES(2144,NULL,'Windham, NH',723,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2145,NULL,'Windham, NH 3087',723,222,NULL,29,1129,0);
INSERT INTO "django_geo_db_location" VALUES(2146,NULL,'Berwick, ME',724,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2147,NULL,'Berwick, ME 3091',724,222,NULL,23,1130,0);
INSERT INTO "django_geo_db_location" VALUES(2148,NULL,'Ogunquit, ME',725,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2149,NULL,'Ogunquit, ME 3097',725,222,NULL,23,1131,0);
INSERT INTO "django_geo_db_location" VALUES(2150,NULL,'Manchester, NH',726,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2151,NULL,'Manchester, NH 3101',726,222,NULL,29,1132,0);
INSERT INTO "django_geo_db_location" VALUES(2152,NULL,'Manchester, NH 3102',726,222,NULL,29,1133,0);
INSERT INTO "django_geo_db_location" VALUES(2153,NULL,'Manchester, NH 3103',726,222,NULL,29,1134,0);
INSERT INTO "django_geo_db_location" VALUES(2154,NULL,'Manchester, NH 3104',726,222,NULL,29,1135,0);
INSERT INTO "django_geo_db_location" VALUES(2155,NULL,'Manchester, NH 3105',726,222,NULL,29,1136,0);
INSERT INTO "django_geo_db_location" VALUES(2156,NULL,'Hooksett, NH',727,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2157,NULL,'Hooksett, NH 3106',727,222,NULL,29,1137,0);
INSERT INTO "django_geo_db_location" VALUES(2158,NULL,'Manchester, NH 3107',726,222,NULL,29,1138,0);
INSERT INTO "django_geo_db_location" VALUES(2159,NULL,'Manchester, NH 3108',726,222,NULL,29,1139,0);
INSERT INTO "django_geo_db_location" VALUES(2160,NULL,'Manchester, NH 3109',726,222,NULL,29,1140,0);
INSERT INTO "django_geo_db_location" VALUES(2161,NULL,'Bedford, NH',728,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2162,NULL,'Bedford, NH 3110',728,222,NULL,29,1141,0);
INSERT INTO "django_geo_db_location" VALUES(2163,NULL,'Manchester, NH 3111',726,222,NULL,29,1142,0);
INSERT INTO "django_geo_db_location" VALUES(2164,NULL,'Waterville Valley, NH',729,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2165,NULL,'Waterville Valley, NH 3215',729,222,NULL,29,1143,0);
INSERT INTO "django_geo_db_location" VALUES(2166,NULL,'Andover, NH',730,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2167,NULL,'Andover, NH 3216',730,222,NULL,29,1144,0);
INSERT INTO "django_geo_db_location" VALUES(2168,NULL,'Ashland, NH',731,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2169,NULL,'Ashland, NH 3217',731,222,NULL,29,1145,0);
INSERT INTO "django_geo_db_location" VALUES(2170,NULL,'Barnstead, NH',732,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2171,NULL,'Barnstead, NH 3218',732,222,NULL,29,1146,0);
INSERT INTO "django_geo_db_location" VALUES(2172,NULL,'Belmont, NH',733,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2173,NULL,'Belmont, NH 3220',733,222,NULL,29,1147,0);
INSERT INTO "django_geo_db_location" VALUES(2174,NULL,'Bradford, NH',734,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2175,NULL,'Bradford, NH 3221',734,222,NULL,29,1148,0);
INSERT INTO "django_geo_db_location" VALUES(2176,NULL,'Bristol, NH',735,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2177,NULL,'Bristol, NH 3222',735,222,NULL,29,1149,0);
INSERT INTO "django_geo_db_location" VALUES(2178,NULL,'Campton, NH',736,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2179,NULL,'Campton, NH 3223',736,222,NULL,29,1150,0);
INSERT INTO "django_geo_db_location" VALUES(2180,NULL,'Canterbury, NH',737,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2181,NULL,'Canterbury, NH 3224',737,222,NULL,29,1151,0);
INSERT INTO "django_geo_db_location" VALUES(2182,NULL,'Center Barnstead, NH',738,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2183,NULL,'Center Barnstead, NH 3225',738,222,NULL,29,1152,0);
INSERT INTO "django_geo_db_location" VALUES(2184,NULL,'Center Harbor, NH',739,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2185,NULL,'Center Harbor, NH 3226',739,222,NULL,29,1153,0);
INSERT INTO "django_geo_db_location" VALUES(2186,NULL,'Center Sandwich, NH',740,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2187,NULL,'Center Sandwich, NH 3227',740,222,NULL,29,1154,0);
INSERT INTO "django_geo_db_location" VALUES(2188,NULL,'Contoocook, NH',741,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2189,NULL,'Contoocook, NH 3229',741,222,NULL,29,1155,0);
INSERT INTO "django_geo_db_location" VALUES(2190,NULL,'Danbury, NH',742,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2191,NULL,'Danbury, NH 3230',742,222,NULL,29,1156,0);
INSERT INTO "django_geo_db_location" VALUES(2192,NULL,'East Andover, NH',743,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2193,NULL,'East Andover, NH 3231',743,222,NULL,29,1157,0);
INSERT INTO "django_geo_db_location" VALUES(2194,NULL,'East Hebron, NH',744,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2195,NULL,'East Hebron, NH 3232',744,222,NULL,29,1158,0);
INSERT INTO "django_geo_db_location" VALUES(2196,NULL,'Elkins, NH',745,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2197,NULL,'Elkins, NH 3233',745,222,NULL,29,1159,0);
INSERT INTO "django_geo_db_location" VALUES(2198,NULL,'Epsom, NH',746,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2199,NULL,'Epsom, NH 3234',746,222,NULL,29,1160,0);
INSERT INTO "django_geo_db_location" VALUES(2200,NULL,'Franklin, NH',747,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2201,NULL,'Franklin, NH 3235',747,222,NULL,29,1161,0);
INSERT INTO "django_geo_db_location" VALUES(2202,NULL,'Gilmanton, NH',748,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2203,NULL,'Gilmanton, NH 3237',748,222,NULL,29,1162,0);
INSERT INTO "django_geo_db_location" VALUES(2204,NULL,'Glencliff, NH',749,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2205,NULL,'Glencliff, NH 3238',749,222,NULL,29,1163,0);
INSERT INTO "django_geo_db_location" VALUES(2206,NULL,'Grafton, NH',750,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2207,NULL,'Grafton, NH 3240',750,222,NULL,29,1164,0);
INSERT INTO "django_geo_db_location" VALUES(2208,NULL,'Hebron, NH',751,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2209,NULL,'Hebron, NH 3241',751,222,NULL,29,1165,0);
INSERT INTO "django_geo_db_location" VALUES(2210,NULL,'Henniker, NH',752,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2211,NULL,'Henniker, NH 3242',752,222,NULL,29,1166,0);
INSERT INTO "django_geo_db_location" VALUES(2212,NULL,'Hill, NH',753,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2213,NULL,'Hill, NH 3243',753,222,NULL,29,1167,0);
INSERT INTO "django_geo_db_location" VALUES(2214,NULL,'Hillsboro, NH',754,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2215,NULL,'Hillsboro, NH 3244',754,222,NULL,29,1168,0);
INSERT INTO "django_geo_db_location" VALUES(2216,NULL,'Holderness, NH',755,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2217,NULL,'Holderness, NH 3245',755,222,NULL,29,1169,0);
INSERT INTO "django_geo_db_location" VALUES(2218,NULL,'Laconia, NH',756,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2219,NULL,'Laconia, NH 3246',756,222,NULL,29,1170,0);
INSERT INTO "django_geo_db_location" VALUES(2220,NULL,'Laconia, NH 3247',756,222,NULL,29,1171,0);
INSERT INTO "django_geo_db_location" VALUES(2221,NULL,'Laconia, NH 3249',756,222,NULL,29,1172,0);
INSERT INTO "django_geo_db_location" VALUES(2222,NULL,'Lincoln, NH',757,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2223,NULL,'Lincoln, NH 3251',757,222,NULL,29,1173,0);
INSERT INTO "django_geo_db_location" VALUES(2224,NULL,'Lochmere, NH',758,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2225,NULL,'Lochmere, NH 3252',758,222,NULL,29,1174,0);
INSERT INTO "django_geo_db_location" VALUES(2226,NULL,'Meredith, NH',759,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2227,NULL,'Meredith, NH 3253',759,222,NULL,29,1175,0);
INSERT INTO "django_geo_db_location" VALUES(2228,NULL,'Moultonborough, NH',760,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2229,NULL,'Moultonborough, NH 3254',760,222,NULL,29,1176,0);
INSERT INTO "django_geo_db_location" VALUES(2230,NULL,'Newbury, NH',761,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2231,NULL,'Newbury, NH 3255',761,222,NULL,29,1177,0);
INSERT INTO "django_geo_db_location" VALUES(2232,NULL,'New Hampton, NH',762,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2233,NULL,'New Hampton, NH 3256',762,222,NULL,29,1178,0);
INSERT INTO "django_geo_db_location" VALUES(2234,NULL,'New London, NH',763,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2235,NULL,'New London, NH 3257',763,222,NULL,29,1179,0);
INSERT INTO "django_geo_db_location" VALUES(2236,NULL,'Chichester, NH',764,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2237,NULL,'Chichester, NH 3258',764,222,NULL,29,1180,0);
INSERT INTO "django_geo_db_location" VALUES(2238,NULL,'North Sandwich, NH',765,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2239,NULL,'North Sandwich, NH 3259',765,222,NULL,29,1181,0);
INSERT INTO "django_geo_db_location" VALUES(2240,NULL,'North Sutton, NH',766,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2241,NULL,'North Sutton, NH 3260',766,222,NULL,29,1182,0);
INSERT INTO "django_geo_db_location" VALUES(2242,NULL,'Northwood, NH',767,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2243,NULL,'Northwood, NH 3261',767,222,NULL,29,1183,0);
INSERT INTO "django_geo_db_location" VALUES(2244,NULL,'North Woodstock, NH',768,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2245,NULL,'North Woodstock, NH 3262',768,222,NULL,29,1184,0);
INSERT INTO "django_geo_db_location" VALUES(2246,NULL,'Pittsfield, NH',769,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2247,NULL,'Pittsfield, NH 3263',769,222,NULL,29,1185,0);
INSERT INTO "django_geo_db_location" VALUES(2248,NULL,'Plymouth, NH',770,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2249,NULL,'Plymouth, NH 3264',770,222,NULL,29,1186,0);
INSERT INTO "django_geo_db_location" VALUES(2250,NULL,'Rumney, NH',771,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2251,NULL,'Rumney, NH 3266',771,222,NULL,29,1187,0);
INSERT INTO "django_geo_db_location" VALUES(2252,NULL,'Salisbury, NH',772,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2253,NULL,'Salisbury, NH 3268',772,222,NULL,29,1188,0);
INSERT INTO "django_geo_db_location" VALUES(2254,NULL,'Sanbornton, NH',773,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2255,NULL,'Sanbornton, NH 3269',773,222,NULL,29,1189,0);
INSERT INTO "django_geo_db_location" VALUES(2256,NULL,'New Boston, NH 3270',714,222,NULL,29,1190,0);
INSERT INTO "django_geo_db_location" VALUES(2257,NULL,'South Newbury, NH',774,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2258,NULL,'South Newbury, NH 3272',774,222,NULL,29,1191,0);
INSERT INTO "django_geo_db_location" VALUES(2259,NULL,'South Sutton, NH',775,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2260,NULL,'South Sutton, NH 3273',775,222,NULL,29,1192,0);
INSERT INTO "django_geo_db_location" VALUES(2261,NULL,'Stinson Lake, NH',776,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2262,NULL,'Stinson Lake, NH 3274',776,222,NULL,29,1193,0);
INSERT INTO "django_geo_db_location" VALUES(2263,NULL,'Suncook, NH',777,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2264,NULL,'Suncook, NH 3275',777,222,NULL,29,1194,0);
INSERT INTO "django_geo_db_location" VALUES(2265,NULL,'Tilton, NH',778,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2266,NULL,'Tilton, NH 3276',778,222,NULL,29,1195,0);
INSERT INTO "django_geo_db_location" VALUES(2267,NULL,'Warner, NH',779,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2268,NULL,'Warner, NH 3278',779,222,NULL,29,1196,0);
INSERT INTO "django_geo_db_location" VALUES(2269,NULL,'Warren, NH',780,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2270,NULL,'Warren, NH 3279',780,222,NULL,29,1197,0);
INSERT INTO "django_geo_db_location" VALUES(2271,NULL,'Washington, NH',781,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2272,NULL,'Washington, NH 3280',781,222,NULL,29,1198,0);
INSERT INTO "django_geo_db_location" VALUES(2273,NULL,'Weare, NH',782,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2274,NULL,'Weare, NH 3281',782,222,NULL,29,1199,0);
INSERT INTO "django_geo_db_location" VALUES(2275,NULL,'Wentworth, NH',783,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2276,NULL,'Wentworth, NH 3282',783,222,NULL,29,1200,0);
INSERT INTO "django_geo_db_location" VALUES(2277,NULL,'Springfield, NH',784,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2278,NULL,'Springfield, NH 3284',784,222,NULL,29,1201,0);
INSERT INTO "django_geo_db_location" VALUES(2279,NULL,'Wilmot, NH',785,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2280,NULL,'Wilmot, NH 3287',785,222,NULL,29,1202,0);
INSERT INTO "django_geo_db_location" VALUES(2281,NULL,'Winnisquam, NH',786,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2282,NULL,'Winnisquam, NH 3289',786,222,NULL,29,1203,0);
INSERT INTO "django_geo_db_location" VALUES(2283,NULL,'Nottingham, NH',787,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2284,NULL,'Nottingham, NH 3290',787,222,NULL,29,1204,0);
INSERT INTO "django_geo_db_location" VALUES(2285,NULL,'West Nottingham, NH',788,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2286,NULL,'West Nottingham, NH 3291',788,222,NULL,29,1205,0);
INSERT INTO "django_geo_db_location" VALUES(2287,NULL,'Woodstock, NH',789,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2288,NULL,'Woodstock, NH 3293',789,222,NULL,29,1206,0);
INSERT INTO "django_geo_db_location" VALUES(2289,NULL,'Tilton, NH 3298',778,222,NULL,29,1207,0);
INSERT INTO "django_geo_db_location" VALUES(2290,NULL,'Tilton, NH 3299',778,222,NULL,29,1208,0);
INSERT INTO "django_geo_db_location" VALUES(2291,NULL,'Concord, NH',790,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2292,NULL,'Concord, NH 3301',790,222,NULL,29,1209,0);
INSERT INTO "django_geo_db_location" VALUES(2293,NULL,'Concord, NH 3302',790,222,NULL,29,1210,0);
INSERT INTO "django_geo_db_location" VALUES(2294,NULL,'Concord, NH 3303',790,222,NULL,29,1211,0);
INSERT INTO "django_geo_db_location" VALUES(2295,NULL,'Bow, NH',791,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2296,NULL,'Bow, NH 3304',791,222,NULL,29,1212,0);
INSERT INTO "django_geo_db_location" VALUES(2297,NULL,'Concord, NH 3305',790,222,NULL,29,1213,0);
INSERT INTO "django_geo_db_location" VALUES(2298,NULL,'Loudon, NH',792,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2299,NULL,'Loudon, NH 3307',792,222,NULL,29,1214,0);
INSERT INTO "django_geo_db_location" VALUES(2300,NULL,'Bennington, NH',793,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2301,NULL,'Bennington, NH 3342',793,222,NULL,29,1215,0);
INSERT INTO "django_geo_db_location" VALUES(2302,NULL,'Tamworth, NH',794,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2303,NULL,'Tamworth, NH 3386',794,222,NULL,29,1216,0);
INSERT INTO "django_geo_db_location" VALUES(2304,NULL,'Keene, NH',795,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2305,NULL,'Keene, NH 3431',795,222,NULL,29,1217,0);
INSERT INTO "django_geo_db_location" VALUES(2306,NULL,'Keene, NH 3435',795,222,NULL,29,1218,0);
INSERT INTO "django_geo_db_location" VALUES(2307,NULL,'Harrisville, NH',796,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2308,NULL,'Harrisville, NH 3438',796,222,NULL,29,1219,0);
INSERT INTO "django_geo_db_location" VALUES(2309,NULL,'Antrim, NH',797,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2310,NULL,'Antrim, NH 3440',797,222,NULL,29,1220,0);
INSERT INTO "django_geo_db_location" VALUES(2311,NULL,'Ashuelot, NH',798,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2312,NULL,'Ashuelot, NH 3441',798,222,NULL,29,1221,0);
INSERT INTO "django_geo_db_location" VALUES(2313,NULL,'Bennington, NH 3442',793,222,NULL,29,1222,0);
INSERT INTO "django_geo_db_location" VALUES(2314,NULL,'Chesterfield, NH',799,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2315,NULL,'Chesterfield, NH 3443',799,222,NULL,29,1223,0);
INSERT INTO "django_geo_db_location" VALUES(2316,NULL,'Dublin, NH',800,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2317,NULL,'Dublin, NH 3444',800,222,NULL,29,1224,0);
INSERT INTO "django_geo_db_location" VALUES(2318,NULL,'Sullivan, NH',801,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2319,NULL,'Sullivan, NH 3445',801,222,NULL,29,1225,0);
INSERT INTO "django_geo_db_location" VALUES(2320,NULL,'Swanzey, NH',802,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2321,NULL,'Swanzey, NH 3446',802,222,NULL,29,1226,0);
INSERT INTO "django_geo_db_location" VALUES(2322,NULL,'Fitzwilliam, NH',803,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2323,NULL,'Fitzwilliam, NH 3447',803,222,NULL,29,1227,0);
INSERT INTO "django_geo_db_location" VALUES(2324,NULL,'Gilsum, NH',804,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2325,NULL,'Gilsum, NH 3448',804,222,NULL,29,1228,0);
INSERT INTO "django_geo_db_location" VALUES(2326,NULL,'Hancock, NH',805,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2327,NULL,'Hancock, NH 3449',805,222,NULL,29,1229,0);
INSERT INTO "django_geo_db_location" VALUES(2328,NULL,'Harrisville, NH 3450',796,222,NULL,29,1230,0);
INSERT INTO "django_geo_db_location" VALUES(2329,NULL,'Hinsdale, NH',806,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2330,NULL,'Hinsdale, NH 3451',806,222,NULL,29,1231,0);
INSERT INTO "django_geo_db_location" VALUES(2331,NULL,'Jaffrey, NH',807,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2332,NULL,'Jaffrey, NH 3452',807,222,NULL,29,1232,0);
INSERT INTO "django_geo_db_location" VALUES(2333,NULL,'Marlborough, NH',808,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2334,NULL,'Marlborough, NH 3455',808,222,NULL,29,1233,0);
INSERT INTO "django_geo_db_location" VALUES(2335,NULL,'Marlow, NH',809,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2336,NULL,'Marlow, NH 3456',809,222,NULL,29,1234,0);
INSERT INTO "django_geo_db_location" VALUES(2337,NULL,'Munsonville, NH',810,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2338,NULL,'Munsonville, NH 3457',810,222,NULL,29,1235,0);
INSERT INTO "django_geo_db_location" VALUES(2339,NULL,'Peterborough, NH',811,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2340,NULL,'Peterborough, NH 3458',811,222,NULL,29,1236,0);
INSERT INTO "django_geo_db_location" VALUES(2341,NULL,'Rindge, NH',812,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2342,NULL,'Rindge, NH 3461',812,222,NULL,29,1237,0);
INSERT INTO "django_geo_db_location" VALUES(2343,NULL,'Spofford, NH',813,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2344,NULL,'Spofford, NH 3462',813,222,NULL,29,1238,0);
INSERT INTO "django_geo_db_location" VALUES(2345,NULL,'Stoddard, NH',814,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2346,NULL,'Stoddard, NH 3464',814,222,NULL,29,1239,0);
INSERT INTO "django_geo_db_location" VALUES(2347,NULL,'Troy, NH',815,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2348,NULL,'Troy, NH 3465',815,222,NULL,29,1240,0);
INSERT INTO "django_geo_db_location" VALUES(2349,NULL,'West Chesterfield, NH',816,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2350,NULL,'West Chesterfield, NH 3466',816,222,NULL,29,1241,0);
INSERT INTO "django_geo_db_location" VALUES(2351,NULL,'Westmoreland, NH',817,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2352,NULL,'Westmoreland, NH 3467',817,222,NULL,29,1242,0);
INSERT INTO "django_geo_db_location" VALUES(2353,NULL,'West Peterborough, NH',818,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2354,NULL,'West Peterborough, NH 3468',818,222,NULL,29,1243,0);
INSERT INTO "django_geo_db_location" VALUES(2355,NULL,'West Swanzey, NH',819,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2356,NULL,'West Swanzey, NH 3469',819,222,NULL,29,1244,0);
INSERT INTO "django_geo_db_location" VALUES(2357,NULL,'Winchester, NH',820,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2358,NULL,'Winchester, NH 3470',820,222,NULL,29,1245,0);
INSERT INTO "django_geo_db_location" VALUES(2359,NULL,'Fitzwilliam, NH 3477',803,222,NULL,29,1246,0);
INSERT INTO "django_geo_db_location" VALUES(2360,NULL,'Pittsburg, NH',821,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2361,NULL,'Pittsburg, NH 3552',821,222,NULL,29,1247,0);
INSERT INTO "django_geo_db_location" VALUES(2362,NULL,'Littleton, NH',822,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2363,NULL,'Littleton, NH 3561',822,222,NULL,29,1248,0);
INSERT INTO "django_geo_db_location" VALUES(2364,NULL,'Berlin, NH',823,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2365,NULL,'Berlin, NH 3570',823,222,NULL,29,1249,0);
INSERT INTO "django_geo_db_location" VALUES(2366,NULL,'Goshen, NH',824,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2367,NULL,'Goshen, NH 3572',824,222,NULL,29,1250,0);
INSERT INTO "django_geo_db_location" VALUES(2368,NULL,'Bethlehem, NH',825,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2369,NULL,'Bethlehem, NH 3574',825,222,NULL,29,1251,0);
INSERT INTO "django_geo_db_location" VALUES(2370,NULL,'Bretton Woods, NH',826,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2371,NULL,'Bretton Woods, NH 3575',826,222,NULL,29,1252,0);
INSERT INTO "django_geo_db_location" VALUES(2372,NULL,'Colebrook, NH',827,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2373,NULL,'Colebrook, NH 3576',827,222,NULL,29,1253,0);
INSERT INTO "django_geo_db_location" VALUES(2374,NULL,'Landaff, NH',828,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2375,NULL,'Landaff, NH 3578',828,222,NULL,29,1254,0);
INSERT INTO "django_geo_db_location" VALUES(2376,NULL,'Errol, NH',829,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2377,NULL,'Errol, NH 3579',829,222,NULL,29,1255,0);
INSERT INTO "django_geo_db_location" VALUES(2378,NULL,'Franconia, NH',830,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2379,NULL,'Franconia, NH 3580',830,222,NULL,29,1256,0);
INSERT INTO "django_geo_db_location" VALUES(2380,NULL,'Gorham, NH',831,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2381,NULL,'Gorham, NH 3581',831,222,NULL,29,1257,0);
INSERT INTO "django_geo_db_location" VALUES(2382,NULL,'Groveton, NH',832,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2383,NULL,'Groveton, NH 3582',832,222,NULL,29,1258,0);
INSERT INTO "django_geo_db_location" VALUES(2384,NULL,'Jefferson, NH',833,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2385,NULL,'Jefferson, NH 3583',833,222,NULL,29,1259,0);
INSERT INTO "django_geo_db_location" VALUES(2386,NULL,'Lancaster, NH',834,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2387,NULL,'Lancaster, NH 3584',834,222,NULL,29,1260,0);
INSERT INTO "django_geo_db_location" VALUES(2388,NULL,'Lisbon, NH',835,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2389,NULL,'Lisbon, NH 3585',835,222,NULL,29,1261,0);
INSERT INTO "django_geo_db_location" VALUES(2390,NULL,'Meadows, NH',836,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2391,NULL,'Meadows, NH 3587',836,222,NULL,29,1262,0);
INSERT INTO "django_geo_db_location" VALUES(2392,NULL,'Milan, NH',837,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2393,NULL,'Milan, NH 3588',837,222,NULL,29,1263,0);
INSERT INTO "django_geo_db_location" VALUES(2394,NULL,'Mount Washington, NH',838,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2395,NULL,'Mount Washington, NH 3589',838,222,NULL,29,1264,0);
INSERT INTO "django_geo_db_location" VALUES(2396,NULL,'North Stratford, NH',839,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2397,NULL,'North Stratford, NH 3590',839,222,NULL,29,1265,0);
INSERT INTO "django_geo_db_location" VALUES(2398,NULL,'Pittsburg, NH 3592',821,222,NULL,29,1266,0);
INSERT INTO "django_geo_db_location" VALUES(2399,NULL,'Twin Mountain, NH',840,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2400,NULL,'Twin Mountain, NH 3595',840,222,NULL,29,1267,0);
INSERT INTO "django_geo_db_location" VALUES(2401,NULL,'West Stewartstown, NH',841,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2402,NULL,'West Stewartstown, NH 3597',841,222,NULL,29,1268,0);
INSERT INTO "django_geo_db_location" VALUES(2403,NULL,'Whitefield, NH',842,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2404,NULL,'Whitefield, NH 3598',842,222,NULL,29,1269,0);
INSERT INTO "django_geo_db_location" VALUES(2405,NULL,'Acworth, NH',843,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2406,NULL,'Acworth, NH 3601',843,222,NULL,29,1270,0);
INSERT INTO "django_geo_db_location" VALUES(2407,NULL,'Alstead, NH',844,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2408,NULL,'Alstead, NH 3602',844,222,NULL,29,1271,0);
INSERT INTO "django_geo_db_location" VALUES(2409,NULL,'Charlestown, NH',845,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2410,NULL,'Charlestown, NH 3603',845,222,NULL,29,1272,0);
INSERT INTO "django_geo_db_location" VALUES(2411,NULL,'Drewsville, NH',846,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2412,NULL,'Drewsville, NH 3604',846,222,NULL,29,1273,0);
INSERT INTO "django_geo_db_location" VALUES(2413,NULL,'Lempster, NH',847,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2414,NULL,'Lempster, NH 3605',847,222,NULL,29,1274,0);
INSERT INTO "django_geo_db_location" VALUES(2415,NULL,'South Acworth, NH',848,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2416,NULL,'South Acworth, NH 3607',848,222,NULL,29,1275,0);
INSERT INTO "django_geo_db_location" VALUES(2417,NULL,'Walpole, NH',849,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2418,NULL,'Walpole, NH 3608',849,222,NULL,29,1276,0);
INSERT INTO "django_geo_db_location" VALUES(2419,NULL,'North Walpole, NH',850,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2420,NULL,'North Walpole, NH 3609',850,222,NULL,29,1277,0);
INSERT INTO "django_geo_db_location" VALUES(2421,NULL,'Freedom, NH',851,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2422,NULL,'Freedom, NH 3638',851,222,NULL,29,1278,0);
INSERT INTO "django_geo_db_location" VALUES(2423,NULL,'Enfield, NH',852,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2424,NULL,'Enfield, NH 3648',852,222,NULL,29,1279,0);
INSERT INTO "django_geo_db_location" VALUES(2425,NULL,'Lyme, NH',853,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2426,NULL,'Lyme, NH 3678',853,222,NULL,29,1280,0);
INSERT INTO "django_geo_db_location" VALUES(2427,NULL,'Lebanon, ME',854,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2428,NULL,'Lebanon, ME 3688',854,222,NULL,23,1281,0);
INSERT INTO "django_geo_db_location" VALUES(2429,NULL,'Newport, NH',855,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2430,NULL,'Newport, NH 3733',855,222,NULL,29,1282,0);
INSERT INTO "django_geo_db_location" VALUES(2431,NULL,'Bath, NH',856,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2432,NULL,'Bath, NH 3740',856,222,NULL,29,1283,0);
INSERT INTO "django_geo_db_location" VALUES(2433,NULL,'Canaan, NH',857,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2434,NULL,'Canaan, NH 3741',857,222,NULL,29,1284,0);
INSERT INTO "django_geo_db_location" VALUES(2435,NULL,'Claremont, NH',858,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2436,NULL,'Claremont, NH 3743',858,222,NULL,29,1285,0);
INSERT INTO "django_geo_db_location" VALUES(2437,NULL,'Cornish, NH',859,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2438,NULL,'Cornish, NH 3745',859,222,NULL,29,1286,0);
INSERT INTO "django_geo_db_location" VALUES(2439,NULL,'Cornish Flat, NH',860,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2440,NULL,'Cornish Flat, NH 3746',860,222,NULL,29,1287,0);
INSERT INTO "django_geo_db_location" VALUES(2441,NULL,'Enfield, NH 3747',852,222,NULL,29,1288,0);
INSERT INTO "django_geo_db_location" VALUES(2442,NULL,'Enfield, NH 3748',852,222,NULL,29,1289,0);
INSERT INTO "django_geo_db_location" VALUES(2443,NULL,'Enfield Center, NH',861,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2444,NULL,'Enfield Center, NH 3749',861,222,NULL,29,1290,0);
INSERT INTO "django_geo_db_location" VALUES(2445,NULL,'Etna, NH',862,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2446,NULL,'Etna, NH 3750',862,222,NULL,29,1291,0);
INSERT INTO "django_geo_db_location" VALUES(2447,NULL,'Georges Mills, NH',863,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2448,NULL,'Georges Mills, NH 3751',863,222,NULL,29,1292,0);
INSERT INTO "django_geo_db_location" VALUES(2449,NULL,'Goshen, NH 3752',824,222,NULL,29,1293,0);
INSERT INTO "django_geo_db_location" VALUES(2450,NULL,'Grantham, NH',864,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2451,NULL,'Grantham, NH 3753',864,222,NULL,29,1294,0);
INSERT INTO "django_geo_db_location" VALUES(2452,NULL,'Guild, NH',865,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2453,NULL,'Guild, NH 3754',865,222,NULL,29,1295,0);
INSERT INTO "django_geo_db_location" VALUES(2454,NULL,'Hanover, NH',866,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2455,NULL,'Hanover, NH 3755',866,222,NULL,29,1296,0);
INSERT INTO "django_geo_db_location" VALUES(2456,NULL,'Lebanon, NH',867,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2457,NULL,'Lebanon, NH 3756',867,222,NULL,29,1297,0);
INSERT INTO "django_geo_db_location" VALUES(2458,NULL,'Sunapee, NH',868,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2459,NULL,'Sunapee, NH 3757',868,222,NULL,29,1298,0);
INSERT INTO "django_geo_db_location" VALUES(2460,NULL,'Haverhill, NH',869,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2461,NULL,'Haverhill, NH 3765',869,222,NULL,29,1299,0);
INSERT INTO "django_geo_db_location" VALUES(2462,NULL,'Lebanon, NH 3766',867,222,NULL,29,1300,0);
INSERT INTO "django_geo_db_location" VALUES(2463,NULL,'Lyme, NH 3768',853,222,NULL,29,1301,0);
INSERT INTO "django_geo_db_location" VALUES(2464,NULL,'Lyme Center, NH',870,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2465,NULL,'Lyme Center, NH 3769',870,222,NULL,29,1302,0);
INSERT INTO "django_geo_db_location" VALUES(2466,NULL,'Meriden, NH',871,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2467,NULL,'Meriden, NH 3770',871,222,NULL,29,1303,0);
INSERT INTO "django_geo_db_location" VALUES(2468,NULL,'Monroe, NH',872,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2469,NULL,'Monroe, NH 3771',872,222,NULL,29,1304,0);
INSERT INTO "django_geo_db_location" VALUES(2470,NULL,'Newport, NH 3773',855,222,NULL,29,1305,0);
INSERT INTO "django_geo_db_location" VALUES(2471,NULL,'North Haverhill, NH',873,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2472,NULL,'North Haverhill, NH 3774',873,222,NULL,29,1306,0);
INSERT INTO "django_geo_db_location" VALUES(2473,NULL,'Orford, NH',874,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2474,NULL,'Orford, NH 3777',874,222,NULL,29,1307,0);
INSERT INTO "django_geo_db_location" VALUES(2475,NULL,'Piermont, NH',875,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2476,NULL,'Piermont, NH 3779',875,222,NULL,29,1308,0);
INSERT INTO "django_geo_db_location" VALUES(2477,NULL,'Pike, NH',876,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2478,NULL,'Pike, NH 3780',876,222,NULL,29,1309,0);
INSERT INTO "django_geo_db_location" VALUES(2479,NULL,'Plainfield, NH',877,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2480,NULL,'Plainfield, NH 3781',877,222,NULL,29,1310,0);
INSERT INTO "django_geo_db_location" VALUES(2481,NULL,'Sunapee, NH 3782',868,222,NULL,29,1311,0);
INSERT INTO "django_geo_db_location" VALUES(2482,NULL,'West Lebanon, NH',878,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2483,NULL,'West Lebanon, NH 3784',878,222,NULL,29,1312,0);
INSERT INTO "django_geo_db_location" VALUES(2484,NULL,'Woodsville, NH',879,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2485,NULL,'Woodsville, NH 3785',879,222,NULL,29,1313,0);
INSERT INTO "django_geo_db_location" VALUES(2486,NULL,'Portsmouth, NH 3801',1,222,NULL,29,1314,0);
INSERT INTO "django_geo_db_location" VALUES(2487,NULL,'Portsmouth, NH 3802',1,222,NULL,29,1315,0);
INSERT INTO "django_geo_db_location" VALUES(2488,NULL,'Portsmouth, NH 3803',1,222,NULL,29,1316,0);
INSERT INTO "django_geo_db_location" VALUES(2489,NULL,'Portsmouth, NH 3804',1,222,NULL,29,1317,0);
INSERT INTO "django_geo_db_location" VALUES(2490,NULL,'Rollinsford, NH',880,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2491,NULL,'Rollinsford, NH 3805',880,222,NULL,29,1318,0);
INSERT INTO "django_geo_db_location" VALUES(2492,NULL,'Alton, NH',881,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2493,NULL,'Alton, NH 3809',881,222,NULL,29,1319,0);
INSERT INTO "django_geo_db_location" VALUES(2494,NULL,'Alton Bay, NH',882,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2495,NULL,'Alton Bay, NH 3810',882,222,NULL,29,1320,0);
INSERT INTO "django_geo_db_location" VALUES(2496,NULL,'Atkinson, NH',883,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2497,NULL,'Atkinson, NH 3811',883,222,NULL,29,1321,0);
INSERT INTO "django_geo_db_location" VALUES(2498,NULL,'Bartlett, NH',884,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2499,NULL,'Bartlett, NH 3812',884,222,NULL,29,1322,0);
INSERT INTO "django_geo_db_location" VALUES(2500,NULL,'Center Conway, NH',885,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2501,NULL,'Center Conway, NH 3813',885,222,NULL,29,1323,0);
INSERT INTO "django_geo_db_location" VALUES(2502,NULL,'Center Ossipee, NH',886,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2503,NULL,'Center Ossipee, NH 3814',886,222,NULL,29,1324,0);
INSERT INTO "django_geo_db_location" VALUES(2504,NULL,'Center Strafford, NH',887,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2505,NULL,'Center Strafford, NH 3815',887,222,NULL,29,1325,0);
INSERT INTO "django_geo_db_location" VALUES(2506,NULL,'Center Tuftonboro, NH',888,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2507,NULL,'Center Tuftonboro, NH 3816',888,222,NULL,29,1326,0);
INSERT INTO "django_geo_db_location" VALUES(2508,NULL,'Chocorua, NH',889,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2509,NULL,'Chocorua, NH 3817',889,222,NULL,29,1327,0);
INSERT INTO "django_geo_db_location" VALUES(2510,NULL,'Conway, NH',890,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2511,NULL,'Conway, NH 3818',890,222,NULL,29,1328,0);
INSERT INTO "django_geo_db_location" VALUES(2512,NULL,'Danville, NH',891,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2513,NULL,'Danville, NH 3819',891,222,NULL,29,1329,0);
INSERT INTO "django_geo_db_location" VALUES(2514,NULL,'Dover, NH',892,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2515,NULL,'Dover, NH 3820',892,222,NULL,29,1330,0);
INSERT INTO "django_geo_db_location" VALUES(2516,NULL,'Dover, NH 3821',892,222,NULL,29,1331,0);
INSERT INTO "django_geo_db_location" VALUES(2517,NULL,'Dover, NH 3822',892,222,NULL,29,1332,0);
INSERT INTO "django_geo_db_location" VALUES(2518,NULL,'Durham, NH',893,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2519,NULL,'Durham, NH 3824',893,222,NULL,29,1333,0);
INSERT INTO "django_geo_db_location" VALUES(2520,NULL,'Barrington, NH',894,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2521,NULL,'Barrington, NH 3825',894,222,NULL,29,1334,0);
INSERT INTO "django_geo_db_location" VALUES(2522,NULL,'East Hampstead, NH',895,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2523,NULL,'East Hampstead, NH 3826',895,222,NULL,29,1335,0);
INSERT INTO "django_geo_db_location" VALUES(2524,NULL,'East Kingston, NH',896,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2525,NULL,'East Kingston, NH 3827',896,222,NULL,29,1336,0);
INSERT INTO "django_geo_db_location" VALUES(2526,NULL,'East Wakefield, NH',897,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2527,NULL,'East Wakefield, NH 3830',897,222,NULL,29,1337,0);
INSERT INTO "django_geo_db_location" VALUES(2528,NULL,'Eaton Center, NH',898,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2529,NULL,'Eaton Center, NH 3832',898,222,NULL,29,1338,0);
INSERT INTO "django_geo_db_location" VALUES(2530,NULL,'Exeter, NH',899,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2531,NULL,'Exeter, NH 3833',899,222,NULL,29,1339,0);
INSERT INTO "django_geo_db_location" VALUES(2532,NULL,'Farmington, NH',900,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2533,NULL,'Farmington, NH 3835',900,222,NULL,29,1340,0);
INSERT INTO "django_geo_db_location" VALUES(2534,NULL,'Freedom, NH 3836',851,222,NULL,29,1341,0);
INSERT INTO "django_geo_db_location" VALUES(2535,NULL,'Gilmanton Iron Works, NH',901,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2536,NULL,'Gilmanton Iron Works, NH 3837',901,222,NULL,29,1342,0);
INSERT INTO "django_geo_db_location" VALUES(2537,NULL,'Glen, NH',902,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2538,NULL,'Glen, NH 3838',902,222,NULL,29,1343,0);
INSERT INTO "django_geo_db_location" VALUES(2539,NULL,'Rochester, NH',903,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2540,NULL,'Rochester, NH 3839',903,222,NULL,29,1344,0);
INSERT INTO "django_geo_db_location" VALUES(2541,NULL,'Greenland, NH',904,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2542,NULL,'Greenland, NH 3840',904,222,NULL,29,1345,0);
INSERT INTO "django_geo_db_location" VALUES(2543,NULL,'Hampstead, NH',905,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2544,NULL,'Hampstead, NH 3841',905,222,NULL,29,1346,0);
INSERT INTO "django_geo_db_location" VALUES(2545,NULL,'Hampton, NH',906,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2546,NULL,'Hampton, NH 3842',906,222,NULL,29,1347,0);
INSERT INTO "django_geo_db_location" VALUES(2547,NULL,'Hampton, NH 3843',906,222,NULL,29,1348,0);
INSERT INTO "django_geo_db_location" VALUES(2548,NULL,'Hampton Falls, NH',907,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2549,NULL,'Hampton Falls, NH 3844',907,222,NULL,29,1349,0);
INSERT INTO "django_geo_db_location" VALUES(2550,NULL,'Intervale, NH',908,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2551,NULL,'Intervale, NH 3845',908,222,NULL,29,1350,0);
INSERT INTO "django_geo_db_location" VALUES(2552,NULL,'Jackson, NH',909,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2553,NULL,'Jackson, NH 3846',909,222,NULL,29,1351,0);
INSERT INTO "django_geo_db_location" VALUES(2554,NULL,'Kearsarge, NH',910,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2555,NULL,'Kearsarge, NH 3847',910,222,NULL,29,1352,0);
INSERT INTO "django_geo_db_location" VALUES(2556,NULL,'Kingston, NH',911,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2557,NULL,'Kingston, NH 3848',911,222,NULL,29,1353,0);
INSERT INTO "django_geo_db_location" VALUES(2558,NULL,'Madison, NH',912,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2559,NULL,'Madison, NH 3849',912,222,NULL,29,1354,0);
INSERT INTO "django_geo_db_location" VALUES(2560,NULL,'Melvin Village, NH',913,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2561,NULL,'Melvin Village, NH 3850',913,222,NULL,29,1355,0);
INSERT INTO "django_geo_db_location" VALUES(2562,NULL,'Milton, NH',914,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2563,NULL,'Milton, NH 3851',914,222,NULL,29,1356,0);
INSERT INTO "django_geo_db_location" VALUES(2564,NULL,'Milton Mills, NH',915,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2565,NULL,'Milton Mills, NH 3852',915,222,NULL,29,1357,0);
INSERT INTO "django_geo_db_location" VALUES(2566,NULL,'Mirror Lake, NH',916,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2567,NULL,'Mirror Lake, NH 3853',916,222,NULL,29,1358,0);
INSERT INTO "django_geo_db_location" VALUES(2568,NULL,'New Castle, NH',917,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2569,NULL,'New Castle, NH 3854',917,222,NULL,29,1359,0);
INSERT INTO "django_geo_db_location" VALUES(2570,NULL,'New Durham, NH',918,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2571,NULL,'New Durham, NH 3855',918,222,NULL,29,1360,0);
INSERT INTO "django_geo_db_location" VALUES(2572,NULL,'Newfields, NH',919,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2573,NULL,'Newfields, NH 3856',919,222,NULL,29,1361,0);
INSERT INTO "django_geo_db_location" VALUES(2574,NULL,'Newmarket, NH',920,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2575,NULL,'Newmarket, NH 3857',920,222,NULL,29,1362,0);
INSERT INTO "django_geo_db_location" VALUES(2576,NULL,'Newton, NH',921,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2577,NULL,'Newton, NH 3858',921,222,NULL,29,1363,0);
INSERT INTO "django_geo_db_location" VALUES(2578,NULL,'Newton Junction, NH',922,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2579,NULL,'Newton Junction, NH 3859',922,222,NULL,29,1364,0);
INSERT INTO "django_geo_db_location" VALUES(2580,NULL,'North Conway, NH',923,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2581,NULL,'North Conway, NH 3860',923,222,NULL,29,1365,0);
INSERT INTO "django_geo_db_location" VALUES(2582,NULL,'North Hampton, NH',924,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2583,NULL,'North Hampton, NH 3862',924,222,NULL,29,1366,0);
INSERT INTO "django_geo_db_location" VALUES(2584,NULL,'Ossipee, NH',925,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2585,NULL,'Ossipee, NH 3864',925,222,NULL,29,1367,0);
INSERT INTO "django_geo_db_location" VALUES(2586,NULL,'Plaistow, NH',926,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2587,NULL,'Plaistow, NH 3865',926,222,NULL,29,1368,0);
INSERT INTO "django_geo_db_location" VALUES(2588,NULL,'Rochester, NH 3866',903,222,NULL,29,1369,0);
INSERT INTO "django_geo_db_location" VALUES(2589,NULL,'Rochester, NH 3867',903,222,NULL,29,1370,0);
INSERT INTO "django_geo_db_location" VALUES(2590,NULL,'Rochester, NH 3868',903,222,NULL,29,1371,0);
INSERT INTO "django_geo_db_location" VALUES(2591,NULL,'Rollinsford, NH 3869',880,222,NULL,29,1372,0);
INSERT INTO "django_geo_db_location" VALUES(2592,NULL,'Rye, NH',927,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2593,NULL,'Rye, NH 3870',927,222,NULL,29,1373,0);
INSERT INTO "django_geo_db_location" VALUES(2594,NULL,'Rye Beach, NH',928,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2595,NULL,'Rye Beach, NH 3871',928,222,NULL,29,1374,0);
INSERT INTO "django_geo_db_location" VALUES(2596,NULL,'Sanbornville, NH',929,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2597,NULL,'Sanbornville, NH 3872',929,222,NULL,29,1375,0);
INSERT INTO "django_geo_db_location" VALUES(2598,NULL,'Sandown, NH',930,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2599,NULL,'Sandown, NH 3873',930,222,NULL,29,1376,0);
INSERT INTO "django_geo_db_location" VALUES(2600,NULL,'Seabrook, NH',931,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2601,NULL,'Seabrook, NH 3874',931,222,NULL,29,1377,0);
INSERT INTO "django_geo_db_location" VALUES(2602,NULL,'Silver Lake, NH',932,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2603,NULL,'Silver Lake, NH 3875',932,222,NULL,29,1378,0);
INSERT INTO "django_geo_db_location" VALUES(2604,NULL,'Somersworth, NH',933,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2605,NULL,'Somersworth, NH 3878',933,222,NULL,29,1379,0);
INSERT INTO "django_geo_db_location" VALUES(2606,NULL,'South Effingham, NH',934,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2607,NULL,'South Effingham, NH 3882',934,222,NULL,29,1380,0);
INSERT INTO "django_geo_db_location" VALUES(2608,NULL,'South Tamworth, NH',935,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2609,NULL,'South Tamworth, NH 3883',935,222,NULL,29,1381,0);
INSERT INTO "django_geo_db_location" VALUES(2610,NULL,'Strafford, NH',936,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2611,NULL,'Strafford, NH 3884',936,222,NULL,29,1382,0);
INSERT INTO "django_geo_db_location" VALUES(2612,NULL,'Stratham, NH',937,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2613,NULL,'Stratham, NH 3885',937,222,NULL,29,1383,0);
INSERT INTO "django_geo_db_location" VALUES(2614,NULL,'Tamworth, NH 3886',794,222,NULL,29,1384,0);
INSERT INTO "django_geo_db_location" VALUES(2615,NULL,'Union, NH',938,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2616,NULL,'Union, NH 3887',938,222,NULL,29,1385,0);
INSERT INTO "django_geo_db_location" VALUES(2617,NULL,'West Ossipee, NH',939,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2618,NULL,'West Ossipee, NH 3890',939,222,NULL,29,1386,0);
INSERT INTO "django_geo_db_location" VALUES(2619,NULL,'Danville, NH 3891',891,222,NULL,29,1387,0);
INSERT INTO "django_geo_db_location" VALUES(2620,NULL,'Wolfeboro, NH',940,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2621,NULL,'Wolfeboro, NH 3894',940,222,NULL,29,1388,0);
INSERT INTO "django_geo_db_location" VALUES(2622,NULL,'Wolfeboro Falls, NH',941,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2623,NULL,'Wolfeboro Falls, NH 3896',941,222,NULL,29,1389,0);
INSERT INTO "django_geo_db_location" VALUES(2624,NULL,'Wonalancet, NH',942,222,NULL,29,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2625,NULL,'Wonalancet, NH 3897',942,222,NULL,29,1390,0);
INSERT INTO "django_geo_db_location" VALUES(2626,NULL,'Berwick, ME 3901',724,222,NULL,23,1391,0);
INSERT INTO "django_geo_db_location" VALUES(2627,NULL,'Cape Neddick, ME',943,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2628,NULL,'Cape Neddick, ME 3902',943,222,NULL,23,1392,0);
INSERT INTO "django_geo_db_location" VALUES(2629,NULL,'Eliot, ME',944,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2630,NULL,'Eliot, ME 3903',944,222,NULL,23,1393,0);
INSERT INTO "django_geo_db_location" VALUES(2631,NULL,'Kittery, ME',945,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2632,NULL,'Kittery, ME 3904',945,222,NULL,23,1394,0);
INSERT INTO "django_geo_db_location" VALUES(2633,NULL,'Kittery Point, ME',946,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2634,NULL,'Kittery Point, ME 3905',946,222,NULL,23,1395,0);
INSERT INTO "django_geo_db_location" VALUES(2635,NULL,'North Berwick, ME',947,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2636,NULL,'North Berwick, ME 3906',947,222,NULL,23,1396,0);
INSERT INTO "django_geo_db_location" VALUES(2637,NULL,'Ogunquit, ME 3907',725,222,NULL,23,1397,0);
INSERT INTO "django_geo_db_location" VALUES(2638,NULL,'South Berwick, ME',948,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2639,NULL,'South Berwick, ME 3908',948,222,NULL,23,1398,0);
INSERT INTO "django_geo_db_location" VALUES(2640,NULL,'York, ME',949,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2641,NULL,'York, ME 3909',949,222,NULL,23,1399,0);
INSERT INTO "django_geo_db_location" VALUES(2642,NULL,'York Beach, ME',950,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2643,NULL,'York Beach, ME 3910',950,222,NULL,23,1400,0);
INSERT INTO "django_geo_db_location" VALUES(2644,NULL,'York Harbor, ME',951,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2645,NULL,'York Harbor, ME 3911',951,222,NULL,23,1401,0);
INSERT INTO "django_geo_db_location" VALUES(2646,NULL,'Acton, ME',952,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2647,NULL,'Acton, ME 4001',952,222,NULL,23,1402,0);
INSERT INTO "django_geo_db_location" VALUES(2648,NULL,'Alfred, ME',953,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2649,NULL,'Alfred, ME 4002',953,222,NULL,23,1403,0);
INSERT INTO "django_geo_db_location" VALUES(2650,NULL,'Bailey Island, ME',954,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2651,NULL,'Bailey Island, ME 4003',954,222,NULL,23,1404,0);
INSERT INTO "django_geo_db_location" VALUES(2652,NULL,'Bar Mills, ME',955,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2653,NULL,'Bar Mills, ME 4004',955,222,NULL,23,1405,0);
INSERT INTO "django_geo_db_location" VALUES(2654,NULL,'Biddeford, ME',956,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2655,NULL,'Biddeford, ME 4005',956,222,NULL,23,1406,0);
INSERT INTO "django_geo_db_location" VALUES(2656,NULL,'Biddeford Pool, ME',957,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2657,NULL,'Biddeford Pool, ME 4006',957,222,NULL,23,1407,0);
INSERT INTO "django_geo_db_location" VALUES(2658,NULL,'Biddeford, ME 4007',956,222,NULL,23,1408,0);
INSERT INTO "django_geo_db_location" VALUES(2659,NULL,'Bowdoinham, ME',958,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2660,NULL,'Bowdoinham, ME 4008',958,222,NULL,23,1409,0);
INSERT INTO "django_geo_db_location" VALUES(2661,NULL,'Bridgton, ME',959,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2662,NULL,'Bridgton, ME 4009',959,222,NULL,23,1410,0);
INSERT INTO "django_geo_db_location" VALUES(2663,NULL,'Brownfield, ME',960,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2664,NULL,'Brownfield, ME 4010',960,222,NULL,23,1411,0);
INSERT INTO "django_geo_db_location" VALUES(2665,NULL,'Brunswick, ME',961,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2666,NULL,'Brunswick, ME 4011',961,222,NULL,23,1412,0);
INSERT INTO "django_geo_db_location" VALUES(2667,NULL,'Bustins Island, ME',962,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2668,NULL,'Bustins Island, ME 4013',962,222,NULL,23,1413,0);
INSERT INTO "django_geo_db_location" VALUES(2669,NULL,'Cape Porpoise, ME',963,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2670,NULL,'Cape Porpoise, ME 4014',963,222,NULL,23,1414,0);
INSERT INTO "django_geo_db_location" VALUES(2671,NULL,'Casco, ME',964,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2672,NULL,'Casco, ME 4015',964,222,NULL,23,1415,0);
INSERT INTO "django_geo_db_location" VALUES(2673,NULL,'Center Lovell, ME',965,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2674,NULL,'Center Lovell, ME 4016',965,222,NULL,23,1416,0);
INSERT INTO "django_geo_db_location" VALUES(2675,NULL,'Chebeague Island, ME',966,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2676,NULL,'Chebeague Island, ME 4017',966,222,NULL,23,1417,0);
INSERT INTO "django_geo_db_location" VALUES(2677,NULL,'Cliff Island, ME',967,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2678,NULL,'Cliff Island, ME 4019',967,222,NULL,23,1418,0);
INSERT INTO "django_geo_db_location" VALUES(2679,NULL,'Cornish, ME',968,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2680,NULL,'Cornish, ME 4020',968,222,NULL,23,1419,0);
INSERT INTO "django_geo_db_location" VALUES(2681,NULL,'Cumberland Center, ME',969,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2682,NULL,'Cumberland Center, ME 4021',969,222,NULL,23,1420,0);
INSERT INTO "django_geo_db_location" VALUES(2683,NULL,'Denmark, ME',970,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2684,NULL,'Denmark, ME 4022',970,222,NULL,23,1421,0);
INSERT INTO "django_geo_db_location" VALUES(2685,NULL,'East Baldwin, ME',971,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2686,NULL,'East Baldwin, ME 4024',971,222,NULL,23,1422,0);
INSERT INTO "django_geo_db_location" VALUES(2687,NULL,'Lebanon, ME 4027',854,222,NULL,23,1423,0);
INSERT INTO "django_geo_db_location" VALUES(2688,NULL,'East Parsonfield, ME',972,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2689,NULL,'East Parsonfield, ME 4028',972,222,NULL,23,1424,0);
INSERT INTO "django_geo_db_location" VALUES(2690,NULL,'Sebago, ME',973,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2691,NULL,'Sebago, ME 4029',973,222,NULL,23,1425,0);
INSERT INTO "django_geo_db_location" VALUES(2692,NULL,'East Waterboro, ME',974,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2693,NULL,'East Waterboro, ME 4030',974,222,NULL,23,1426,0);
INSERT INTO "django_geo_db_location" VALUES(2694,NULL,'Raymond, ME',975,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2695,NULL,'Raymond, ME 4031',975,222,NULL,23,1427,0);
INSERT INTO "django_geo_db_location" VALUES(2696,NULL,'Freeport, ME',976,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2697,NULL,'Freeport, ME 4032',976,222,NULL,23,1428,0);
INSERT INTO "django_geo_db_location" VALUES(2698,NULL,'Freeport, ME 4033',976,222,NULL,23,1429,0);
INSERT INTO "django_geo_db_location" VALUES(2699,NULL,'Freeport, ME 4034',976,222,NULL,23,1430,0);
INSERT INTO "django_geo_db_location" VALUES(2700,NULL,'Fryeburg, ME',977,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2701,NULL,'Fryeburg, ME 4037',977,222,NULL,23,1431,0);
INSERT INTO "django_geo_db_location" VALUES(2702,NULL,'Gorham, ME',978,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2703,NULL,'Gorham, ME 4038',978,222,NULL,23,1432,0);
INSERT INTO "django_geo_db_location" VALUES(2704,NULL,'Gray, ME',979,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2705,NULL,'Gray, ME 4039',979,222,NULL,23,1433,0);
INSERT INTO "django_geo_db_location" VALUES(2706,NULL,'Harrison, ME',980,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2707,NULL,'Harrison, ME 4040',980,222,NULL,23,1434,0);
INSERT INTO "django_geo_db_location" VALUES(2708,NULL,'Hiram, ME',981,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2709,NULL,'Hiram, ME 4041',981,222,NULL,23,1435,0);
INSERT INTO "django_geo_db_location" VALUES(2710,NULL,'Hollis Center, ME',982,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2711,NULL,'Hollis Center, ME 4042',982,222,NULL,23,1436,0);
INSERT INTO "django_geo_db_location" VALUES(2712,NULL,'Kennebunk, ME',983,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2713,NULL,'Kennebunk, ME 4043',983,222,NULL,23,1437,0);
INSERT INTO "django_geo_db_location" VALUES(2714,NULL,'Kennebunkport, ME',984,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2715,NULL,'Kennebunkport, ME 4046',984,222,NULL,23,1438,0);
INSERT INTO "django_geo_db_location" VALUES(2716,NULL,'Parsonsfield, ME',985,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2717,NULL,'Parsonsfield, ME 4047',985,222,NULL,23,1439,0);
INSERT INTO "django_geo_db_location" VALUES(2718,NULL,'Limerick, ME',986,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2719,NULL,'Limerick, ME 4048',986,222,NULL,23,1440,0);
INSERT INTO "django_geo_db_location" VALUES(2720,NULL,'Limington, ME',987,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2721,NULL,'Limington, ME 4049',987,222,NULL,23,1441,0);
INSERT INTO "django_geo_db_location" VALUES(2722,NULL,'Long Island, ME',988,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2723,NULL,'Long Island, ME 4050',988,222,NULL,23,1442,0);
INSERT INTO "django_geo_db_location" VALUES(2724,NULL,'Lovell, ME',989,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2725,NULL,'Lovell, ME 4051',989,222,NULL,23,1443,0);
INSERT INTO "django_geo_db_location" VALUES(2726,NULL,'Merepoint, ME',990,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2727,NULL,'Merepoint, ME 4053',990,222,NULL,23,1444,0);
INSERT INTO "django_geo_db_location" VALUES(2728,NULL,'Moody, ME',991,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2729,NULL,'Moody, ME 4054',991,222,NULL,23,1445,0);
INSERT INTO "django_geo_db_location" VALUES(2730,NULL,'Naples, ME',992,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2731,NULL,'Naples, ME 4055',992,222,NULL,23,1446,0);
INSERT INTO "django_geo_db_location" VALUES(2732,NULL,'Newfield, ME',993,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2733,NULL,'Newfield, ME 4056',993,222,NULL,23,1447,0);
INSERT INTO "django_geo_db_location" VALUES(2734,NULL,'North Bridgton, ME',994,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2735,NULL,'North Bridgton, ME 4057',994,222,NULL,23,1448,0);
INSERT INTO "django_geo_db_location" VALUES(2736,NULL,'North Waterboro, ME',995,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2737,NULL,'North Waterboro, ME 4061',995,222,NULL,23,1449,0);
INSERT INTO "django_geo_db_location" VALUES(2738,NULL,'Windham, ME',996,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2739,NULL,'Windham, ME 4062',996,222,NULL,23,1450,0);
INSERT INTO "django_geo_db_location" VALUES(2740,NULL,'Ocean Park, ME',997,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2741,NULL,'Ocean Park, ME 4063',997,222,NULL,23,1451,0);
INSERT INTO "django_geo_db_location" VALUES(2742,NULL,'Old Orchard Beach, ME',998,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2743,NULL,'Old Orchard Beach, ME 4064',998,222,NULL,23,1452,0);
INSERT INTO "django_geo_db_location" VALUES(2744,NULL,'Ellsworth, ME',999,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2745,NULL,'Ellsworth, ME 4065',999,222,NULL,23,1453,0);
INSERT INTO "django_geo_db_location" VALUES(2746,NULL,'Orrs Island, ME',1000,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2747,NULL,'Orrs Island, ME 4066',1000,222,NULL,23,1454,0);
INSERT INTO "django_geo_db_location" VALUES(2748,NULL,'Porter, ME',1001,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2749,NULL,'Porter, ME 4068',1001,222,NULL,23,1455,0);
INSERT INTO "django_geo_db_location" VALUES(2750,NULL,'Pownal, ME',1002,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2751,NULL,'Pownal, ME 4069',1002,222,NULL,23,1456,0);
INSERT INTO "django_geo_db_location" VALUES(2752,NULL,'Scarborough, ME',1003,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2753,NULL,'Scarborough, ME 4070',1003,222,NULL,23,1457,0);
INSERT INTO "django_geo_db_location" VALUES(2754,NULL,'Raymond, ME 4071',975,222,NULL,23,1458,0);
INSERT INTO "django_geo_db_location" VALUES(2755,NULL,'Saco, ME',1004,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2756,NULL,'Saco, ME 4072',1004,222,NULL,23,1459,0);
INSERT INTO "django_geo_db_location" VALUES(2757,NULL,'Sanford, ME',1005,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2758,NULL,'Sanford, ME 4073',1005,222,NULL,23,1460,0);
INSERT INTO "django_geo_db_location" VALUES(2759,NULL,'Scarborough, ME 4074',1003,222,NULL,23,1461,0);
INSERT INTO "django_geo_db_location" VALUES(2760,NULL,'Sebago Lake, ME',1006,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2761,NULL,'Sebago Lake, ME 4075',1006,222,NULL,23,1462,0);
INSERT INTO "django_geo_db_location" VALUES(2762,NULL,'Shapleigh, ME',1007,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2763,NULL,'Shapleigh, ME 4076',1007,222,NULL,23,1463,0);
INSERT INTO "django_geo_db_location" VALUES(2764,NULL,'South Casco, ME',1008,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2765,NULL,'South Casco, ME 4077',1008,222,NULL,23,1464,0);
INSERT INTO "django_geo_db_location" VALUES(2766,NULL,'South Freeport, ME',1009,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2767,NULL,'South Freeport, ME 4078',1009,222,NULL,23,1465,0);
INSERT INTO "django_geo_db_location" VALUES(2768,NULL,'Harpswell, ME',1010,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2769,NULL,'Harpswell, ME 4079',1010,222,NULL,23,1466,0);
INSERT INTO "django_geo_db_location" VALUES(2770,NULL,'South Waterford, ME',1011,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2771,NULL,'South Waterford, ME 4081',1011,222,NULL,23,1467,0);
INSERT INTO "django_geo_db_location" VALUES(2772,NULL,'South Windham, ME',1012,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2773,NULL,'South Windham, ME 4082',1012,222,NULL,23,1468,0);
INSERT INTO "django_geo_db_location" VALUES(2774,NULL,'Springvale, ME',1013,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2775,NULL,'Springvale, ME 4083',1013,222,NULL,23,1469,0);
INSERT INTO "django_geo_db_location" VALUES(2776,NULL,'Standish, ME',1014,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2777,NULL,'Standish, ME 4084',1014,222,NULL,23,1470,0);
INSERT INTO "django_geo_db_location" VALUES(2778,NULL,'Steep Falls, ME',1015,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2779,NULL,'Steep Falls, ME 4085',1015,222,NULL,23,1471,0);
INSERT INTO "django_geo_db_location" VALUES(2780,NULL,'Topsham, ME',1016,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2781,NULL,'Topsham, ME 4086',1016,222,NULL,23,1472,0);
INSERT INTO "django_geo_db_location" VALUES(2782,NULL,'Waterboro, ME',1017,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2783,NULL,'Waterboro, ME 4087',1017,222,NULL,23,1473,0);
INSERT INTO "django_geo_db_location" VALUES(2784,NULL,'Waterford, ME',1018,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2785,NULL,'Waterford, ME 4088',1018,222,NULL,23,1474,0);
INSERT INTO "django_geo_db_location" VALUES(2786,NULL,'Wells, ME',1019,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2787,NULL,'Wells, ME 4090',1019,222,NULL,23,1475,0);
INSERT INTO "django_geo_db_location" VALUES(2788,NULL,'West Baldwin, ME',1020,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2789,NULL,'West Baldwin, ME 4091',1020,222,NULL,23,1476,0);
INSERT INTO "django_geo_db_location" VALUES(2790,NULL,'Westbrook, ME',1021,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2791,NULL,'Westbrook, ME 4092',1021,222,NULL,23,1477,0);
INSERT INTO "django_geo_db_location" VALUES(2792,NULL,'West Buxton, ME',1022,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2793,NULL,'West Buxton, ME 4093',1022,222,NULL,23,1478,0);
INSERT INTO "django_geo_db_location" VALUES(2794,NULL,'West Kennebunk, ME',1023,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2795,NULL,'West Kennebunk, ME 4094',1023,222,NULL,23,1479,0);
INSERT INTO "django_geo_db_location" VALUES(2796,NULL,'West Newfield, ME',1024,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2797,NULL,'West Newfield, ME 4095',1024,222,NULL,23,1480,0);
INSERT INTO "django_geo_db_location" VALUES(2798,NULL,'Yarmouth, ME',1025,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2799,NULL,'Yarmouth, ME 4096',1025,222,NULL,23,1481,0);
INSERT INTO "django_geo_db_location" VALUES(2800,NULL,'North Yarmouth, ME',1026,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2801,NULL,'North Yarmouth, ME 4097',1026,222,NULL,23,1482,0);
INSERT INTO "django_geo_db_location" VALUES(2802,NULL,'Westbrook, ME 4098',1021,222,NULL,23,1483,0);
INSERT INTO "django_geo_db_location" VALUES(2803,NULL,'Portland, ME',1027,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2804,NULL,'Portland, ME 4101',1027,222,NULL,23,1484,0);
INSERT INTO "django_geo_db_location" VALUES(2805,NULL,'Portland, ME 4102',1027,222,NULL,23,1485,0);
INSERT INTO "django_geo_db_location" VALUES(2806,NULL,'Portland, ME 4103',1027,222,NULL,23,1486,0);
INSERT INTO "django_geo_db_location" VALUES(2807,NULL,'Portland, ME 4104',1027,222,NULL,23,1487,0);
INSERT INTO "django_geo_db_location" VALUES(2808,NULL,'Falmouth, ME',1028,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2809,NULL,'Falmouth, ME 4105',1028,222,NULL,23,1488,0);
INSERT INTO "django_geo_db_location" VALUES(2810,NULL,'South Portland, ME',1029,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2811,NULL,'South Portland, ME 4106',1029,222,NULL,23,1489,0);
INSERT INTO "django_geo_db_location" VALUES(2812,NULL,'Cape Elizabeth, ME',1030,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2813,NULL,'Cape Elizabeth, ME 4107',1030,222,NULL,23,1490,0);
INSERT INTO "django_geo_db_location" VALUES(2814,NULL,'Peaks Island, ME',1031,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2815,NULL,'Peaks Island, ME 4108',1031,222,NULL,23,1491,0);
INSERT INTO "django_geo_db_location" VALUES(2816,NULL,'Portland, ME 4109',1027,222,NULL,23,1492,0);
INSERT INTO "django_geo_db_location" VALUES(2817,NULL,'Cumberland Foreside, ME',1032,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2818,NULL,'Cumberland Foreside, ME 4110',1032,222,NULL,23,1493,0);
INSERT INTO "django_geo_db_location" VALUES(2819,NULL,'Portland, ME 4112',1027,222,NULL,23,1494,0);
INSERT INTO "django_geo_db_location" VALUES(2820,NULL,'South Portland, ME 4116',1029,222,NULL,23,1495,0);
INSERT INTO "django_geo_db_location" VALUES(2821,NULL,'Portland, ME 4122',1027,222,NULL,23,1496,0);
INSERT INTO "django_geo_db_location" VALUES(2822,NULL,'Portland, ME 4123',1027,222,NULL,23,1497,0);
INSERT INTO "django_geo_db_location" VALUES(2823,NULL,'Portland, ME 4124',1027,222,NULL,23,1498,0);
INSERT INTO "django_geo_db_location" VALUES(2824,NULL,'Auburn, ME',1033,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2825,NULL,'Auburn, ME 4210',1033,222,NULL,23,1499,0);
INSERT INTO "django_geo_db_location" VALUES(2826,NULL,'Auburn, ME 4211',1033,222,NULL,23,1500,0);
INSERT INTO "django_geo_db_location" VALUES(2827,NULL,'Auburn, ME 4212',1033,222,NULL,23,1501,0);
INSERT INTO "django_geo_db_location" VALUES(2828,NULL,'Andover, ME',1034,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2829,NULL,'Andover, ME 4216',1034,222,NULL,23,1502,0);
INSERT INTO "django_geo_db_location" VALUES(2830,NULL,'Bethel, ME',1035,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2831,NULL,'Bethel, ME 4217',1035,222,NULL,23,1503,0);
INSERT INTO "django_geo_db_location" VALUES(2832,NULL,'Bryant Pond, ME',1036,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2833,NULL,'Bryant Pond, ME 4219',1036,222,NULL,23,1504,0);
INSERT INTO "django_geo_db_location" VALUES(2834,NULL,'Buckfield, ME',1037,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2835,NULL,'Buckfield, ME 4220',1037,222,NULL,23,1505,0);
INSERT INTO "django_geo_db_location" VALUES(2836,NULL,'Canton, ME',1038,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2837,NULL,'Canton, ME 4221',1038,222,NULL,23,1506,0);
INSERT INTO "django_geo_db_location" VALUES(2838,NULL,'Durham, ME',1039,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2839,NULL,'Durham, ME 4222',1039,222,NULL,23,1507,0);
INSERT INTO "django_geo_db_location" VALUES(2840,NULL,'Danville, ME',1040,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2841,NULL,'Danville, ME 4223',1040,222,NULL,23,1508,0);
INSERT INTO "django_geo_db_location" VALUES(2842,NULL,'Dixfield, ME',1041,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2843,NULL,'Dixfield, ME 4224',1041,222,NULL,23,1509,0);
INSERT INTO "django_geo_db_location" VALUES(2844,NULL,'Dryden, ME',1042,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2845,NULL,'Dryden, ME 4225',1042,222,NULL,23,1510,0);
INSERT INTO "django_geo_db_location" VALUES(2846,NULL,'East Andover, ME',1043,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2847,NULL,'East Andover, ME 4226',1043,222,NULL,23,1511,0);
INSERT INTO "django_geo_db_location" VALUES(2848,NULL,'East Dixfield, ME',1044,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2849,NULL,'East Dixfield, ME 4227',1044,222,NULL,23,1512,0);
INSERT INTO "django_geo_db_location" VALUES(2850,NULL,'East Livermore, ME',1045,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2851,NULL,'East Livermore, ME 4228',1045,222,NULL,23,1513,0);
INSERT INTO "django_geo_db_location" VALUES(2852,NULL,'East Poland, ME',1046,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2853,NULL,'East Poland, ME 4230',1046,222,NULL,23,1514,0);
INSERT INTO "django_geo_db_location" VALUES(2854,NULL,'Stoneham, ME',1047,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2855,NULL,'Stoneham, ME 4231',1047,222,NULL,23,1515,0);
INSERT INTO "django_geo_db_location" VALUES(2856,NULL,'East Wilton, ME',1048,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2857,NULL,'East Wilton, ME 4234',1048,222,NULL,23,1516,0);
INSERT INTO "django_geo_db_location" VALUES(2858,NULL,'Greene, ME',1049,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2859,NULL,'Greene, ME 4236',1049,222,NULL,23,1517,0);
INSERT INTO "django_geo_db_location" VALUES(2860,NULL,'Hanover, ME',1050,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2861,NULL,'Hanover, ME 4237',1050,222,NULL,23,1518,0);
INSERT INTO "django_geo_db_location" VALUES(2862,NULL,'Hebron, ME',1051,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2863,NULL,'Hebron, ME 4238',1051,222,NULL,23,1519,0);
INSERT INTO "django_geo_db_location" VALUES(2864,NULL,'Jay, ME',1052,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2865,NULL,'Jay, ME 4239',1052,222,NULL,23,1520,0);
INSERT INTO "django_geo_db_location" VALUES(2866,NULL,'Lewiston, ME',1053,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2867,NULL,'Lewiston, ME 4240',1053,222,NULL,23,1521,0);
INSERT INTO "django_geo_db_location" VALUES(2868,NULL,'Lewiston, ME 4241',1053,222,NULL,23,1522,0);
INSERT INTO "django_geo_db_location" VALUES(2869,NULL,'Lewiston, ME 4243',1053,222,NULL,23,1523,0);
INSERT INTO "django_geo_db_location" VALUES(2870,NULL,'Lisbon, ME',1054,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2871,NULL,'Lisbon, ME 4250',1054,222,NULL,23,1524,0);
INSERT INTO "django_geo_db_location" VALUES(2872,NULL,'Lisbon Falls, ME',1055,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2873,NULL,'Lisbon Falls, ME 4252',1055,222,NULL,23,1525,0);
INSERT INTO "django_geo_db_location" VALUES(2874,NULL,'Livermore, ME',1056,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2875,NULL,'Livermore, ME 4253',1056,222,NULL,23,1526,0);
INSERT INTO "django_geo_db_location" VALUES(2876,NULL,'Livermore Falls, ME',1057,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2877,NULL,'Livermore Falls, ME 4254',1057,222,NULL,23,1527,0);
INSERT INTO "django_geo_db_location" VALUES(2878,NULL,'Locke Mills, ME',1058,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2879,NULL,'Locke Mills, ME 4255',1058,222,NULL,23,1528,0);
INSERT INTO "django_geo_db_location" VALUES(2880,NULL,'Mechanic Falls, ME',1059,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2881,NULL,'Mechanic Falls, ME 4256',1059,222,NULL,23,1529,0);
INSERT INTO "django_geo_db_location" VALUES(2882,NULL,'Mexico, ME',1060,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2883,NULL,'Mexico, ME 4257',1060,222,NULL,23,1530,0);
INSERT INTO "django_geo_db_location" VALUES(2884,NULL,'Minot, ME',1061,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2885,NULL,'Minot, ME 4258',1061,222,NULL,23,1531,0);
INSERT INTO "django_geo_db_location" VALUES(2886,NULL,'Monmouth, ME',1062,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2887,NULL,'Monmouth, ME 4259',1062,222,NULL,23,1532,0);
INSERT INTO "django_geo_db_location" VALUES(2888,NULL,'New Gloucester, ME',1063,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2889,NULL,'New Gloucester, ME 4260',1063,222,NULL,23,1533,0);
INSERT INTO "django_geo_db_location" VALUES(2890,NULL,'Newry, ME',1064,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2891,NULL,'Newry, ME 4261',1064,222,NULL,23,1534,0);
INSERT INTO "django_geo_db_location" VALUES(2892,NULL,'North Jay, ME',1065,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2893,NULL,'North Jay, ME 4262',1065,222,NULL,23,1535,0);
INSERT INTO "django_geo_db_location" VALUES(2894,NULL,'Leeds, ME',1066,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2895,NULL,'Leeds, ME 4263',1066,222,NULL,23,1536,0);
INSERT INTO "django_geo_db_location" VALUES(2896,NULL,'North Monmouth, ME',1067,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2897,NULL,'North Monmouth, ME 4265',1067,222,NULL,23,1537,0);
INSERT INTO "django_geo_db_location" VALUES(2898,NULL,'North Turner, ME',1068,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2899,NULL,'North Turner, ME 4266',1068,222,NULL,23,1538,0);
INSERT INTO "django_geo_db_location" VALUES(2900,NULL,'North Waterford, ME',1069,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2901,NULL,'North Waterford, ME 4267',1069,222,NULL,23,1539,0);
INSERT INTO "django_geo_db_location" VALUES(2902,NULL,'Norway, ME',1070,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2903,NULL,'Norway, ME 4268',1070,222,NULL,23,1540,0);
INSERT INTO "django_geo_db_location" VALUES(2904,NULL,'Oxford, ME',1071,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2905,NULL,'Oxford, ME 4270',1071,222,NULL,23,1541,0);
INSERT INTO "django_geo_db_location" VALUES(2906,NULL,'Paris, ME',1072,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2907,NULL,'Paris, ME 4271',1072,222,NULL,23,1542,0);
INSERT INTO "django_geo_db_location" VALUES(2908,NULL,'Hanover, ME 4273',1050,222,NULL,23,1543,0);
INSERT INTO "django_geo_db_location" VALUES(2909,NULL,'Poland, ME',1073,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2910,NULL,'Poland, ME 4274',1073,222,NULL,23,1544,0);
INSERT INTO "django_geo_db_location" VALUES(2911,NULL,'Roxbury, ME',1074,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2912,NULL,'Roxbury, ME 4275',1074,222,NULL,23,1545,0);
INSERT INTO "django_geo_db_location" VALUES(2913,NULL,'Rumford, ME',1075,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2914,NULL,'Rumford, ME 4276',1075,222,NULL,23,1546,0);
INSERT INTO "django_geo_db_location" VALUES(2915,NULL,'Rumford Center, ME',1076,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2916,NULL,'Rumford Center, ME 4278',1076,222,NULL,23,1547,0);
INSERT INTO "django_geo_db_location" VALUES(2917,NULL,'Rumford, ME 4279',1075,222,NULL,23,1548,0);
INSERT INTO "django_geo_db_location" VALUES(2918,NULL,'Sabattus, ME',1077,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2919,NULL,'Sabattus, ME 4280',1077,222,NULL,23,1549,0);
INSERT INTO "django_geo_db_location" VALUES(2920,NULL,'South Paris, ME',1078,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2921,NULL,'South Paris, ME 4281',1078,222,NULL,23,1550,0);
INSERT INTO "django_geo_db_location" VALUES(2922,NULL,'Turner, ME',1079,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2923,NULL,'Turner, ME 4282',1079,222,NULL,23,1551,0);
INSERT INTO "django_geo_db_location" VALUES(2924,NULL,'Turner Center, ME',1080,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2925,NULL,'Turner Center, ME 4283',1080,222,NULL,23,1552,0);
INSERT INTO "django_geo_db_location" VALUES(2926,NULL,'Wayne, ME',1081,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2927,NULL,'Wayne, ME 4284',1081,222,NULL,23,1553,0);
INSERT INTO "django_geo_db_location" VALUES(2928,NULL,'Weld, ME',1082,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2929,NULL,'Weld, ME 4285',1082,222,NULL,23,1554,0);
INSERT INTO "django_geo_db_location" VALUES(2930,NULL,'West Bethel, ME',1083,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2931,NULL,'West Bethel, ME 4286',1083,222,NULL,23,1555,0);
INSERT INTO "django_geo_db_location" VALUES(2932,NULL,'Bowdoin, ME',1084,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2933,NULL,'Bowdoin, ME 4287',1084,222,NULL,23,1556,0);
INSERT INTO "django_geo_db_location" VALUES(2934,NULL,'West Minot, ME',1085,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2935,NULL,'West Minot, ME 4288',1085,222,NULL,23,1557,0);
INSERT INTO "django_geo_db_location" VALUES(2936,NULL,'West Paris, ME',1086,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2937,NULL,'West Paris, ME 4289',1086,222,NULL,23,1558,0);
INSERT INTO "django_geo_db_location" VALUES(2938,NULL,'Peru, ME',1087,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2939,NULL,'Peru, ME 4290',1087,222,NULL,23,1559,0);
INSERT INTO "django_geo_db_location" VALUES(2940,NULL,'West Poland, ME',1088,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2941,NULL,'West Poland, ME 4291',1088,222,NULL,23,1560,0);
INSERT INTO "django_geo_db_location" VALUES(2942,NULL,'Sumner, ME',1089,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2943,NULL,'Sumner, ME 4292',1089,222,NULL,23,1561,0);
INSERT INTO "django_geo_db_location" VALUES(2944,NULL,'Wilton, ME',1090,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2945,NULL,'Wilton, ME 4294',1090,222,NULL,23,1562,0);
INSERT INTO "django_geo_db_location" VALUES(2946,NULL,'Stoneham, ME 4321',1047,222,NULL,23,1563,0);
INSERT INTO "django_geo_db_location" VALUES(2947,NULL,'Richmond, ME',1091,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2948,NULL,'Richmond, ME 4327',1091,222,NULL,23,1564,0);
INSERT INTO "django_geo_db_location" VALUES(2949,NULL,'Augusta, ME',1092,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2950,NULL,'Augusta, ME 4330',1092,222,NULL,23,1565,0);
INSERT INTO "django_geo_db_location" VALUES(2951,NULL,'Augusta, ME 4332',1092,222,NULL,23,1566,0);
INSERT INTO "django_geo_db_location" VALUES(2952,NULL,'Augusta, ME 4333',1092,222,NULL,23,1567,0);
INSERT INTO "django_geo_db_location" VALUES(2953,NULL,'Augusta, ME 4336',1092,222,NULL,23,1568,0);
INSERT INTO "django_geo_db_location" VALUES(2954,NULL,'Augusta, ME 4338',1092,222,NULL,23,1569,0);
INSERT INTO "django_geo_db_location" VALUES(2955,NULL,'Coopers Mills, ME',1093,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2956,NULL,'Coopers Mills, ME 4341',1093,222,NULL,23,1570,0);
INSERT INTO "django_geo_db_location" VALUES(2957,NULL,'Dresden, ME',1094,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2958,NULL,'Dresden, ME 4342',1094,222,NULL,23,1571,0);
INSERT INTO "django_geo_db_location" VALUES(2959,NULL,'East Winthrop, ME',1095,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2960,NULL,'East Winthrop, ME 4343',1095,222,NULL,23,1572,0);
INSERT INTO "django_geo_db_location" VALUES(2961,NULL,'Farmingdale, ME',1096,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2962,NULL,'Farmingdale, ME 4344',1096,222,NULL,23,1573,0);
INSERT INTO "django_geo_db_location" VALUES(2963,NULL,'Gardiner, ME',1097,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2964,NULL,'Gardiner, ME 4345',1097,222,NULL,23,1574,0);
INSERT INTO "django_geo_db_location" VALUES(2965,NULL,'Randolph, ME',1098,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2966,NULL,'Randolph, ME 4346',1098,222,NULL,23,1575,0);
INSERT INTO "django_geo_db_location" VALUES(2967,NULL,'Hallowell, ME',1099,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2968,NULL,'Hallowell, ME 4347',1099,222,NULL,23,1576,0);
INSERT INTO "django_geo_db_location" VALUES(2969,NULL,'Jefferson, ME',1100,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2970,NULL,'Jefferson, ME 4348',1100,222,NULL,23,1577,0);
INSERT INTO "django_geo_db_location" VALUES(2971,NULL,'Kents Hill, ME',1101,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2972,NULL,'Kents Hill, ME 4349',1101,222,NULL,23,1578,0);
INSERT INTO "django_geo_db_location" VALUES(2973,NULL,'Litchfield, ME',1102,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2974,NULL,'Litchfield, ME 4350',1102,222,NULL,23,1579,0);
INSERT INTO "django_geo_db_location" VALUES(2975,NULL,'Manchester, ME',1103,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2976,NULL,'Manchester, ME 4351',1103,222,NULL,23,1580,0);
INSERT INTO "django_geo_db_location" VALUES(2977,NULL,'Mount Vernon, ME',1104,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2978,NULL,'Mount Vernon, ME 4352',1104,222,NULL,23,1581,0);
INSERT INTO "django_geo_db_location" VALUES(2979,NULL,'Whitefield, ME',1105,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2980,NULL,'Whitefield, ME 4353',1105,222,NULL,23,1582,0);
INSERT INTO "django_geo_db_location" VALUES(2981,NULL,'Palermo, ME',1106,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2982,NULL,'Palermo, ME 4354',1106,222,NULL,23,1583,0);
INSERT INTO "django_geo_db_location" VALUES(2983,NULL,'Readfield, ME',1107,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2984,NULL,'Readfield, ME 4355',1107,222,NULL,23,1584,0);
INSERT INTO "django_geo_db_location" VALUES(2985,NULL,'Richmond, ME 4357',1091,222,NULL,23,1585,0);
INSERT INTO "django_geo_db_location" VALUES(2986,NULL,'South China, ME',1108,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2987,NULL,'South China, ME 4358',1108,222,NULL,23,1586,0);
INSERT INTO "django_geo_db_location" VALUES(2988,NULL,'South Gardiner, ME',1109,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2989,NULL,'South Gardiner, ME 4359',1109,222,NULL,23,1587,0);
INSERT INTO "django_geo_db_location" VALUES(2990,NULL,'Vienna, ME',1110,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2991,NULL,'Vienna, ME 4360',1110,222,NULL,23,1588,0);
INSERT INTO "django_geo_db_location" VALUES(2992,NULL,'Windsor, ME',1111,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2993,NULL,'Windsor, ME 4363',1111,222,NULL,23,1589,0);
INSERT INTO "django_geo_db_location" VALUES(2994,NULL,'Winthrop, ME',1112,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2995,NULL,'Winthrop, ME 4364',1112,222,NULL,23,1590,0);
INSERT INTO "django_geo_db_location" VALUES(2996,NULL,'Bangor, ME',1113,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(2997,NULL,'Bangor, ME 4401',1113,222,NULL,23,1591,0);
INSERT INTO "django_geo_db_location" VALUES(2998,NULL,'Bangor, ME 4402',1113,222,NULL,23,1592,0);
INSERT INTO "django_geo_db_location" VALUES(2999,NULL,'Abbot, ME',1114,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3000,NULL,'Abbot, ME 4406',1114,222,NULL,23,1593,0);
INSERT INTO "django_geo_db_location" VALUES(3001,NULL,'Aurora, ME',1115,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3002,NULL,'Aurora, ME 4408',1115,222,NULL,23,1594,0);
INSERT INTO "django_geo_db_location" VALUES(3003,NULL,'Bradford, ME',1116,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3004,NULL,'Bradford, ME 4410',1116,222,NULL,23,1595,0);
INSERT INTO "django_geo_db_location" VALUES(3005,NULL,'Bradley, ME',1117,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3006,NULL,'Bradley, ME 4411',1117,222,NULL,23,1596,0);
INSERT INTO "django_geo_db_location" VALUES(3007,NULL,'Brewer, ME',1118,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3008,NULL,'Brewer, ME 4412',1118,222,NULL,23,1597,0);
INSERT INTO "django_geo_db_location" VALUES(3009,NULL,'Brookton, ME',1119,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3010,NULL,'Brookton, ME 4413',1119,222,NULL,23,1598,0);
INSERT INTO "django_geo_db_location" VALUES(3011,NULL,'Brownville, ME',1120,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3012,NULL,'Brownville, ME 4414',1120,222,NULL,23,1599,0);
INSERT INTO "django_geo_db_location" VALUES(3013,NULL,'Brownville Junction, ME',1121,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3014,NULL,'Brownville Junction, ME 4415',1121,222,NULL,23,1600,0);
INSERT INTO "django_geo_db_location" VALUES(3015,NULL,'Bucksport, ME',1122,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3016,NULL,'Bucksport, ME 4416',1122,222,NULL,23,1601,0);
INSERT INTO "django_geo_db_location" VALUES(3017,NULL,'Burlington, ME',1123,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3018,NULL,'Burlington, ME 4417',1123,222,NULL,23,1602,0);
INSERT INTO "django_geo_db_location" VALUES(3019,NULL,'Cardville, ME',1124,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3020,NULL,'Cardville, ME 4418',1124,222,NULL,23,1603,0);
INSERT INTO "django_geo_db_location" VALUES(3021,NULL,'Carmel, ME',1125,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3022,NULL,'Carmel, ME 4419',1125,222,NULL,23,1604,0);
INSERT INTO "django_geo_db_location" VALUES(3023,NULL,'Castine, ME',1126,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3024,NULL,'Castine, ME 4420',1126,222,NULL,23,1605,0);
INSERT INTO "django_geo_db_location" VALUES(3025,NULL,'Castine, ME 4421',1126,222,NULL,23,1606,0);
INSERT INTO "django_geo_db_location" VALUES(3026,NULL,'Charleston, ME',1127,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3027,NULL,'Charleston, ME 4422',1127,222,NULL,23,1607,0);
INSERT INTO "django_geo_db_location" VALUES(3028,NULL,'Costigan, ME',1128,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3029,NULL,'Costigan, ME 4423',1128,222,NULL,23,1608,0);
INSERT INTO "django_geo_db_location" VALUES(3030,NULL,'Danforth, ME',1129,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3031,NULL,'Danforth, ME 4424',1129,222,NULL,23,1609,0);
INSERT INTO "django_geo_db_location" VALUES(3032,NULL,'Dover Foxcroft, ME',1130,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3033,NULL,'Dover Foxcroft, ME 4426',1130,222,NULL,23,1610,0);
INSERT INTO "django_geo_db_location" VALUES(3034,NULL,'Corinth, ME',1131,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3035,NULL,'Corinth, ME 4427',1131,222,NULL,23,1611,0);
INSERT INTO "django_geo_db_location" VALUES(3036,NULL,'Eddington, ME',1132,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3037,NULL,'Eddington, ME 4428',1132,222,NULL,23,1612,0);
INSERT INTO "django_geo_db_location" VALUES(3038,NULL,'Holden, ME',1133,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3039,NULL,'Holden, ME 4429',1133,222,NULL,23,1613,0);
INSERT INTO "django_geo_db_location" VALUES(3040,NULL,'East Millinocket, ME',1134,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3041,NULL,'East Millinocket, ME 4430',1134,222,NULL,23,1614,0);
INSERT INTO "django_geo_db_location" VALUES(3042,NULL,'East Orland, ME',1135,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3043,NULL,'East Orland, ME 4431',1135,222,NULL,23,1615,0);
INSERT INTO "django_geo_db_location" VALUES(3044,NULL,'Etna, ME',1136,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3045,NULL,'Etna, ME 4434',1136,222,NULL,23,1616,0);
INSERT INTO "django_geo_db_location" VALUES(3046,NULL,'Exeter, ME',1137,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3047,NULL,'Exeter, ME 4435',1137,222,NULL,23,1617,0);
INSERT INTO "django_geo_db_location" VALUES(3048,NULL,'Frankfort, ME',1138,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3049,NULL,'Frankfort, ME 4438',1138,222,NULL,23,1618,0);
INSERT INTO "django_geo_db_location" VALUES(3050,NULL,'Greenville, ME',1139,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3051,NULL,'Greenville, ME 4441',1139,222,NULL,23,1619,0);
INSERT INTO "django_geo_db_location" VALUES(3052,NULL,'Greenville Junction, ME',1140,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3053,NULL,'Greenville Junction, ME 4442',1140,222,NULL,23,1620,0);
INSERT INTO "django_geo_db_location" VALUES(3054,NULL,'Guilford, ME',1141,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3055,NULL,'Guilford, ME 4443',1141,222,NULL,23,1621,0);
INSERT INTO "django_geo_db_location" VALUES(3056,NULL,'Hampden, ME',1142,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3057,NULL,'Hampden, ME 4444',1142,222,NULL,23,1622,0);
INSERT INTO "django_geo_db_location" VALUES(3058,NULL,'Howland, ME',1143,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3059,NULL,'Howland, ME 4448',1143,222,NULL,23,1623,0);
INSERT INTO "django_geo_db_location" VALUES(3060,NULL,'Hudson, ME',1144,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3061,NULL,'Hudson, ME 4449',1144,222,NULL,23,1624,0);
INSERT INTO "django_geo_db_location" VALUES(3062,NULL,'Kenduskeag, ME',1145,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3063,NULL,'Kenduskeag, ME 4450',1145,222,NULL,23,1625,0);
INSERT INTO "django_geo_db_location" VALUES(3064,NULL,'Kingman, ME',1146,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3065,NULL,'Kingman, ME 4451',1146,222,NULL,23,1626,0);
INSERT INTO "django_geo_db_location" VALUES(3066,NULL,'Lagrange, ME',1147,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3067,NULL,'Lagrange, ME 4453',1147,222,NULL,23,1627,0);
INSERT INTO "django_geo_db_location" VALUES(3068,NULL,'Lambert Lake, ME',1148,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3069,NULL,'Lambert Lake, ME 4454',1148,222,NULL,23,1628,0);
INSERT INTO "django_geo_db_location" VALUES(3070,NULL,'Lee, ME',1149,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3071,NULL,'Lee, ME 4455',1149,222,NULL,23,1629,0);
INSERT INTO "django_geo_db_location" VALUES(3072,NULL,'Levant, ME',1150,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3073,NULL,'Levant, ME 4456',1150,222,NULL,23,1630,0);
INSERT INTO "django_geo_db_location" VALUES(3074,NULL,'Lincoln, ME',1151,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3075,NULL,'Lincoln, ME 4457',1151,222,NULL,23,1631,0);
INSERT INTO "django_geo_db_location" VALUES(3076,NULL,'Mattawamkeag, ME',1152,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3077,NULL,'Mattawamkeag, ME 4459',1152,222,NULL,23,1632,0);
INSERT INTO "django_geo_db_location" VALUES(3078,NULL,'Medway, ME',1153,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3079,NULL,'Medway, ME 4460',1153,222,NULL,23,1633,0);
INSERT INTO "django_geo_db_location" VALUES(3080,NULL,'Milford, ME',1154,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3081,NULL,'Milford, ME 4461',1154,222,NULL,23,1634,0);
INSERT INTO "django_geo_db_location" VALUES(3082,NULL,'Millinocket, ME',1155,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3083,NULL,'Millinocket, ME 4462',1155,222,NULL,23,1635,0);
INSERT INTO "django_geo_db_location" VALUES(3084,NULL,'Milo, ME',1156,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3085,NULL,'Milo, ME 4463',1156,222,NULL,23,1636,0);
INSERT INTO "django_geo_db_location" VALUES(3086,NULL,'Monson, ME',1157,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3087,NULL,'Monson, ME 4464',1157,222,NULL,23,1637,0);
INSERT INTO "django_geo_db_location" VALUES(3088,NULL,'Cary, ME',1158,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3089,NULL,'Cary, ME 4465',1158,222,NULL,23,1638,0);
INSERT INTO "django_geo_db_location" VALUES(3090,NULL,'Olamon, ME',1159,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3091,NULL,'Olamon, ME 4467',1159,222,NULL,23,1639,0);
INSERT INTO "django_geo_db_location" VALUES(3092,NULL,'Old Town, ME',1160,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3093,NULL,'Old Town, ME 4468',1160,222,NULL,23,1640,0);
INSERT INTO "django_geo_db_location" VALUES(3094,NULL,'Orono, ME',1161,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3095,NULL,'Orono, ME 4469',1161,222,NULL,23,1641,0);
INSERT INTO "django_geo_db_location" VALUES(3096,NULL,'Orient, ME',1162,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3097,NULL,'Orient, ME 4471',1162,222,NULL,23,1642,0);
INSERT INTO "django_geo_db_location" VALUES(3098,NULL,'Orland, ME',1163,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3099,NULL,'Orland, ME 4472',1163,222,NULL,23,1643,0);
INSERT INTO "django_geo_db_location" VALUES(3100,NULL,'Orono, ME 4473',1161,222,NULL,23,1644,0);
INSERT INTO "django_geo_db_location" VALUES(3101,NULL,'Orrington, ME',1164,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3102,NULL,'Orrington, ME 4474',1164,222,NULL,23,1645,0);
INSERT INTO "django_geo_db_location" VALUES(3103,NULL,'Passadumkeag, ME',1165,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3104,NULL,'Passadumkeag, ME 4475',1165,222,NULL,23,1646,0);
INSERT INTO "django_geo_db_location" VALUES(3105,NULL,'Penobscot, ME',1166,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3106,NULL,'Penobscot, ME 4476',1166,222,NULL,23,1647,0);
INSERT INTO "django_geo_db_location" VALUES(3107,NULL,'Rockwood, ME',1167,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3108,NULL,'Rockwood, ME 4478',1167,222,NULL,23,1648,0);
INSERT INTO "django_geo_db_location" VALUES(3109,NULL,'Sangerville, ME',1168,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3110,NULL,'Sangerville, ME 4479',1168,222,NULL,23,1649,0);
INSERT INTO "django_geo_db_location" VALUES(3111,NULL,'Sebec, ME',1169,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3112,NULL,'Sebec, ME 4481',1169,222,NULL,23,1650,0);
INSERT INTO "django_geo_db_location" VALUES(3113,NULL,'Shirley Mills, ME',1170,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3114,NULL,'Shirley Mills, ME 4485',1170,222,NULL,23,1651,0);
INSERT INTO "django_geo_db_location" VALUES(3115,NULL,'Springfield, ME',1171,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3116,NULL,'Springfield, ME 4487',1171,222,NULL,23,1652,0);
INSERT INTO "django_geo_db_location" VALUES(3117,NULL,'Stetson, ME',1172,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3118,NULL,'Stetson, ME 4488',1172,222,NULL,23,1653,0);
INSERT INTO "django_geo_db_location" VALUES(3119,NULL,'Stillwater, ME',1173,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3120,NULL,'Stillwater, ME 4489',1173,222,NULL,23,1654,0);
INSERT INTO "django_geo_db_location" VALUES(3121,NULL,'Topsfield, ME',1174,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3122,NULL,'Topsfield, ME 4490',1174,222,NULL,23,1655,0);
INSERT INTO "django_geo_db_location" VALUES(3123,NULL,'Vanceboro, ME',1175,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3124,NULL,'Vanceboro, ME 4491',1175,222,NULL,23,1656,0);
INSERT INTO "django_geo_db_location" VALUES(3125,NULL,'Waite, ME',1176,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3126,NULL,'Waite, ME 4492',1176,222,NULL,23,1657,0);
INSERT INTO "django_geo_db_location" VALUES(3127,NULL,'West Enfield, ME',1177,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3128,NULL,'West Enfield, ME 4493',1177,222,NULL,23,1658,0);
INSERT INTO "django_geo_db_location" VALUES(3129,NULL,'Winn, ME',1178,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3130,NULL,'Winn, ME 4495',1178,222,NULL,23,1659,0);
INSERT INTO "django_geo_db_location" VALUES(3131,NULL,'Winterport, ME',1179,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3132,NULL,'Winterport, ME 4496',1179,222,NULL,23,1660,0);
INSERT INTO "django_geo_db_location" VALUES(3133,NULL,'Wytopitlock, ME',1180,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3134,NULL,'Wytopitlock, ME 4497',1180,222,NULL,23,1661,0);
INSERT INTO "django_geo_db_location" VALUES(3135,NULL,'Bath, ME',1181,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3136,NULL,'Bath, ME 4530',1181,222,NULL,23,1662,0);
INSERT INTO "django_geo_db_location" VALUES(3137,NULL,'Alna, ME',1182,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3138,NULL,'Alna, ME 4535',1182,222,NULL,23,1663,0);
INSERT INTO "django_geo_db_location" VALUES(3139,NULL,'Bayville, ME',1183,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3140,NULL,'Bayville, ME 4536',1183,222,NULL,23,1664,0);
INSERT INTO "django_geo_db_location" VALUES(3141,NULL,'Boothbay, ME',1184,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3142,NULL,'Boothbay, ME 4537',1184,222,NULL,23,1665,0);
INSERT INTO "django_geo_db_location" VALUES(3143,NULL,'Boothbay Harbor, ME',1185,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3144,NULL,'Boothbay Harbor, ME 4538',1185,222,NULL,23,1666,0);
INSERT INTO "django_geo_db_location" VALUES(3145,NULL,'Bristol, ME',1186,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3146,NULL,'Bristol, ME 4539',1186,222,NULL,23,1667,0);
INSERT INTO "django_geo_db_location" VALUES(3147,NULL,'Chamberlain, ME',1187,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3148,NULL,'Chamberlain, ME 4541',1187,222,NULL,23,1668,0);
INSERT INTO "django_geo_db_location" VALUES(3149,NULL,'Damariscotta, ME',1188,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3150,NULL,'Damariscotta, ME 4543',1188,222,NULL,23,1669,0);
INSERT INTO "django_geo_db_location" VALUES(3151,NULL,'East Boothbay, ME',1189,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3152,NULL,'East Boothbay, ME 4544',1189,222,NULL,23,1670,0);
INSERT INTO "django_geo_db_location" VALUES(3153,NULL,'Georgetown, ME',1190,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3154,NULL,'Georgetown, ME 4546',1190,222,NULL,23,1671,0);
INSERT INTO "django_geo_db_location" VALUES(3155,NULL,'Friendship, ME',1191,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3156,NULL,'Friendship, ME 4547',1191,222,NULL,23,1672,0);
INSERT INTO "django_geo_db_location" VALUES(3157,NULL,'Georgetown, ME 4548',1190,222,NULL,23,1673,0);
INSERT INTO "django_geo_db_location" VALUES(3158,NULL,'Isle Of Springs, ME',1192,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3159,NULL,'Isle Of Springs, ME 4549',1192,222,NULL,23,1674,0);
INSERT INTO "django_geo_db_location" VALUES(3160,NULL,'Bremen, ME',1193,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3161,NULL,'Bremen, ME 4551',1193,222,NULL,23,1675,0);
INSERT INTO "django_geo_db_location" VALUES(3162,NULL,'Newagen, ME',1194,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3163,NULL,'Newagen, ME 4552',1194,222,NULL,23,1676,0);
INSERT INTO "django_geo_db_location" VALUES(3164,NULL,'Newcastle, ME',1195,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3165,NULL,'Newcastle, ME 4553',1195,222,NULL,23,1677,0);
INSERT INTO "django_geo_db_location" VALUES(3166,NULL,'New Harbor, ME',1196,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3167,NULL,'New Harbor, ME 4554',1196,222,NULL,23,1678,0);
INSERT INTO "django_geo_db_location" VALUES(3168,NULL,'Nobleboro, ME',1197,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3169,NULL,'Nobleboro, ME 4555',1197,222,NULL,23,1679,0);
INSERT INTO "django_geo_db_location" VALUES(3170,NULL,'Edgecomb, ME',1198,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3171,NULL,'Edgecomb, ME 4556',1198,222,NULL,23,1680,0);
INSERT INTO "django_geo_db_location" VALUES(3172,NULL,'Richmond, ME 4557',1091,222,NULL,23,1681,0);
INSERT INTO "django_geo_db_location" VALUES(3173,NULL,'Pemaquid, ME',1199,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3174,NULL,'Pemaquid, ME 4558',1199,222,NULL,23,1682,0);
INSERT INTO "django_geo_db_location" VALUES(3175,NULL,'Phippsburg, ME',1200,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3176,NULL,'Phippsburg, ME 4562',1200,222,NULL,23,1683,0);
INSERT INTO "django_geo_db_location" VALUES(3177,NULL,'Cushing, ME',1201,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3178,NULL,'Cushing, ME 4563',1201,222,NULL,23,1684,0);
INSERT INTO "django_geo_db_location" VALUES(3179,NULL,'Round Pond, ME',1202,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3180,NULL,'Round Pond, ME 4564',1202,222,NULL,23,1685,0);
INSERT INTO "django_geo_db_location" VALUES(3181,NULL,'Sebasco Estates, ME',1203,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3182,NULL,'Sebasco Estates, ME 4565',1203,222,NULL,23,1686,0);
INSERT INTO "django_geo_db_location" VALUES(3183,NULL,'Small Point, ME',1204,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3184,NULL,'Small Point, ME 4567',1204,222,NULL,23,1687,0);
INSERT INTO "django_geo_db_location" VALUES(3185,NULL,'South Bristol, ME',1205,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3186,NULL,'South Bristol, ME 4568',1205,222,NULL,23,1688,0);
INSERT INTO "django_geo_db_location" VALUES(3187,NULL,'Squirrel Island, ME',1206,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3188,NULL,'Squirrel Island, ME 4570',1206,222,NULL,23,1689,0);
INSERT INTO "django_geo_db_location" VALUES(3189,NULL,'Trevett, ME',1207,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3190,NULL,'Trevett, ME 4571',1207,222,NULL,23,1690,0);
INSERT INTO "django_geo_db_location" VALUES(3191,NULL,'Waldoboro, ME',1208,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3192,NULL,'Waldoboro, ME 4572',1208,222,NULL,23,1691,0);
INSERT INTO "django_geo_db_location" VALUES(3193,NULL,'Walpole, ME',1209,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3194,NULL,'Walpole, ME 4573',1209,222,NULL,23,1692,0);
INSERT INTO "django_geo_db_location" VALUES(3195,NULL,'Washington, ME',1210,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3196,NULL,'Washington, ME 4574',1210,222,NULL,23,1693,0);
INSERT INTO "django_geo_db_location" VALUES(3197,NULL,'West Boothbay Harbor, ME',1211,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3198,NULL,'West Boothbay Harbor, ME 4575',1211,222,NULL,23,1694,0);
INSERT INTO "django_geo_db_location" VALUES(3199,NULL,'Southport, ME',1212,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3200,NULL,'Southport, ME 4576',1212,222,NULL,23,1695,0);
INSERT INTO "django_geo_db_location" VALUES(3201,NULL,'Wiscasset, ME',1213,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3202,NULL,'Wiscasset, ME 4578',1213,222,NULL,23,1696,0);
INSERT INTO "django_geo_db_location" VALUES(3203,NULL,'Woolwich, ME',1214,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3204,NULL,'Woolwich, ME 4579',1214,222,NULL,23,1697,0);
INSERT INTO "django_geo_db_location" VALUES(3205,NULL,'Winter Harbor, ME',1215,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3206,NULL,'Winter Harbor, ME 4600',1215,222,NULL,23,1698,0);
INSERT INTO "django_geo_db_location" VALUES(3207,NULL,'Ellsworth, ME 4605',999,222,NULL,23,1699,0);
INSERT INTO "django_geo_db_location" VALUES(3208,NULL,'Addison, ME',1216,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3209,NULL,'Addison, ME 4606',1216,222,NULL,23,1700,0);
INSERT INTO "django_geo_db_location" VALUES(3210,NULL,'Gouldsboro, ME',1217,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3211,NULL,'Gouldsboro, ME 4607',1217,222,NULL,23,1701,0);
INSERT INTO "django_geo_db_location" VALUES(3212,NULL,'Bar Harbor, ME',1218,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3213,NULL,'Bar Harbor, ME 4609',1218,222,NULL,23,1702,0);
INSERT INTO "django_geo_db_location" VALUES(3214,NULL,'Beals, ME',1219,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3215,NULL,'Beals, ME 4611',1219,222,NULL,23,1703,0);
INSERT INTO "django_geo_db_location" VALUES(3216,NULL,'Bernard, ME',1220,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3217,NULL,'Bernard, ME 4612',1220,222,NULL,23,1704,0);
INSERT INTO "django_geo_db_location" VALUES(3218,NULL,'Birch Harbor, ME',1221,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3219,NULL,'Birch Harbor, ME 4613',1221,222,NULL,23,1705,0);
INSERT INTO "django_geo_db_location" VALUES(3220,NULL,'Blue Hill, ME',1222,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3221,NULL,'Blue Hill, ME 4614',1222,222,NULL,23,1706,0);
INSERT INTO "django_geo_db_location" VALUES(3222,NULL,'Blue Hill Falls, ME',1223,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3223,NULL,'Blue Hill Falls, ME 4615',1223,222,NULL,23,1707,0);
INSERT INTO "django_geo_db_location" VALUES(3224,NULL,'Brooklin, ME',1224,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3225,NULL,'Brooklin, ME 4616',1224,222,NULL,23,1708,0);
INSERT INTO "django_geo_db_location" VALUES(3226,NULL,'Brooksville, ME',1225,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3227,NULL,'Brooksville, ME 4617',1225,222,NULL,23,1709,0);
INSERT INTO "django_geo_db_location" VALUES(3228,NULL,'Calais, ME',1226,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3229,NULL,'Calais, ME 4619',1226,222,NULL,23,1710,0);
INSERT INTO "django_geo_db_location" VALUES(3230,NULL,'Eastport, ME',1227,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3231,NULL,'Eastport, ME 4621',1227,222,NULL,23,1711,0);
INSERT INTO "django_geo_db_location" VALUES(3232,NULL,'Cherryfield, ME',1228,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3233,NULL,'Cherryfield, ME 4622',1228,222,NULL,23,1712,0);
INSERT INTO "django_geo_db_location" VALUES(3234,NULL,'Columbia Falls, ME',1229,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3235,NULL,'Columbia Falls, ME 4623',1229,222,NULL,23,1713,0);
INSERT INTO "django_geo_db_location" VALUES(3236,NULL,'Corea, ME',1230,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3237,NULL,'Corea, ME 4624',1230,222,NULL,23,1714,0);
INSERT INTO "django_geo_db_location" VALUES(3238,NULL,'Cranberry Isles, ME',1231,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3239,NULL,'Cranberry Isles, ME 4625',1231,222,NULL,23,1715,0);
INSERT INTO "django_geo_db_location" VALUES(3240,NULL,'Cutler, ME',1232,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3241,NULL,'Cutler, ME 4626',1232,222,NULL,23,1716,0);
INSERT INTO "django_geo_db_location" VALUES(3242,NULL,'Deer Isle, ME',1233,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3243,NULL,'Deer Isle, ME 4627',1233,222,NULL,23,1717,0);
INSERT INTO "django_geo_db_location" VALUES(3244,NULL,'Dennysville, ME',1234,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3245,NULL,'Dennysville, ME 4628',1234,222,NULL,23,1718,0);
INSERT INTO "django_geo_db_location" VALUES(3246,NULL,'East Blue Hill, ME',1235,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3247,NULL,'East Blue Hill, ME 4629',1235,222,NULL,23,1719,0);
INSERT INTO "django_geo_db_location" VALUES(3248,NULL,'East Machias, ME',1236,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3249,NULL,'East Machias, ME 4630',1236,222,NULL,23,1720,0);
INSERT INTO "django_geo_db_location" VALUES(3250,NULL,'Eastport, ME 4631',1227,222,NULL,23,1721,0);
INSERT INTO "django_geo_db_location" VALUES(3251,NULL,'Franklin, ME',1237,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3252,NULL,'Franklin, ME 4634',1237,222,NULL,23,1722,0);
INSERT INTO "django_geo_db_location" VALUES(3253,NULL,'Frenchboro, ME',1238,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3254,NULL,'Frenchboro, ME 4635',1238,222,NULL,23,1723,0);
INSERT INTO "django_geo_db_location" VALUES(3255,NULL,'Grand Lake Stream, ME',1239,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3256,NULL,'Grand Lake Stream, ME 4637',1239,222,NULL,23,1724,0);
INSERT INTO "django_geo_db_location" VALUES(3257,NULL,'Hancock, ME',1240,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3258,NULL,'Hancock, ME 4640',1240,222,NULL,23,1725,0);
INSERT INTO "django_geo_db_location" VALUES(3259,NULL,'Harborside, ME',1241,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3260,NULL,'Harborside, ME 4642',1241,222,NULL,23,1726,0);
INSERT INTO "django_geo_db_location" VALUES(3261,NULL,'Harrington, ME',1242,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3262,NULL,'Harrington, ME 4643',1242,222,NULL,23,1727,0);
INSERT INTO "django_geo_db_location" VALUES(3263,NULL,'Hulls Cove, ME',1243,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3264,NULL,'Hulls Cove, ME 4644',1243,222,NULL,23,1728,0);
INSERT INTO "django_geo_db_location" VALUES(3265,NULL,'Isle Au Haut, ME',1244,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3266,NULL,'Isle Au Haut, ME 4645',1244,222,NULL,23,1729,0);
INSERT INTO "django_geo_db_location" VALUES(3267,NULL,'Islesford, ME',1245,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3268,NULL,'Islesford, ME 4646',1245,222,NULL,23,1730,0);
INSERT INTO "django_geo_db_location" VALUES(3269,NULL,'Jonesboro, ME',1246,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3270,NULL,'Jonesboro, ME 4648',1246,222,NULL,23,1731,0);
INSERT INTO "django_geo_db_location" VALUES(3271,NULL,'Jonesport, ME',1247,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3272,NULL,'Jonesport, ME 4649',1247,222,NULL,23,1732,0);
INSERT INTO "django_geo_db_location" VALUES(3273,NULL,'Little Deer Isle, ME',1248,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3274,NULL,'Little Deer Isle, ME 4650',1248,222,NULL,23,1733,0);
INSERT INTO "django_geo_db_location" VALUES(3275,NULL,'Lubec, ME',1249,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3276,NULL,'Lubec, ME 4652',1249,222,NULL,23,1734,0);
INSERT INTO "django_geo_db_location" VALUES(3277,NULL,'Bass Harbor, ME',1250,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3278,NULL,'Bass Harbor, ME 4653',1250,222,NULL,23,1735,0);
INSERT INTO "django_geo_db_location" VALUES(3279,NULL,'Machias, ME',1251,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3280,NULL,'Machias, ME 4654',1251,222,NULL,23,1736,0);
INSERT INTO "django_geo_db_location" VALUES(3281,NULL,'Machiasport, ME',1252,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3282,NULL,'Machiasport, ME 4655',1252,222,NULL,23,1737,0);
INSERT INTO "django_geo_db_location" VALUES(3283,NULL,'Manset, ME',1253,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3284,NULL,'Manset, ME 4656',1253,222,NULL,23,1738,0);
INSERT INTO "django_geo_db_location" VALUES(3285,NULL,'Meddybemps, ME',1254,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3286,NULL,'Meddybemps, ME 4657',1254,222,NULL,23,1739,0);
INSERT INTO "django_geo_db_location" VALUES(3287,NULL,'Milbridge, ME',1255,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3288,NULL,'Milbridge, ME 4658',1255,222,NULL,23,1740,0);
INSERT INTO "django_geo_db_location" VALUES(3289,NULL,'Mount Desert, ME',1256,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3290,NULL,'Mount Desert, ME 4660',1256,222,NULL,23,1741,0);
INSERT INTO "django_geo_db_location" VALUES(3291,NULL,'Northeast Harbor, ME',1257,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3292,NULL,'Northeast Harbor, ME 4662',1257,222,NULL,23,1742,0);
INSERT INTO "django_geo_db_location" VALUES(3293,NULL,'Sullivan, ME',1258,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3294,NULL,'Sullivan, ME 4664',1258,222,NULL,23,1743,0);
INSERT INTO "django_geo_db_location" VALUES(3295,NULL,'Otter Creek, ME',1259,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3296,NULL,'Otter Creek, ME 4665',1259,222,NULL,23,1744,0);
INSERT INTO "django_geo_db_location" VALUES(3297,NULL,'Pembroke, ME',1260,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3298,NULL,'Pembroke, ME 4666',1260,222,NULL,23,1745,0);
INSERT INTO "django_geo_db_location" VALUES(3299,NULL,'Perry, ME',1261,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3300,NULL,'Perry, ME 4667',1261,222,NULL,23,1746,0);
INSERT INTO "django_geo_db_location" VALUES(3301,NULL,'Princeton, ME',1262,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3302,NULL,'Princeton, ME 4668',1262,222,NULL,23,1747,0);
INSERT INTO "django_geo_db_location" VALUES(3303,NULL,'Prospect Harbor, ME',1263,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3304,NULL,'Prospect Harbor, ME 4669',1263,222,NULL,23,1748,0);
INSERT INTO "django_geo_db_location" VALUES(3305,NULL,'Robbinston, ME',1264,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3306,NULL,'Robbinston, ME 4671',1264,222,NULL,23,1749,0);
INSERT INTO "django_geo_db_location" VALUES(3307,NULL,'Salsbury Cove, ME',1265,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3308,NULL,'Salsbury Cove, ME 4672',1265,222,NULL,23,1750,0);
INSERT INTO "django_geo_db_location" VALUES(3309,NULL,'Sargentville, ME',1266,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3310,NULL,'Sargentville, ME 4673',1266,222,NULL,23,1751,0);
INSERT INTO "django_geo_db_location" VALUES(3311,NULL,'Seal Cove, ME',1267,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3312,NULL,'Seal Cove, ME 4674',1267,222,NULL,23,1752,0);
INSERT INTO "django_geo_db_location" VALUES(3313,NULL,'Seal Harbor, ME',1268,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3314,NULL,'Seal Harbor, ME 4675',1268,222,NULL,23,1753,0);
INSERT INTO "django_geo_db_location" VALUES(3315,NULL,'Sedgwick, ME',1269,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3316,NULL,'Sedgwick, ME 4676',1269,222,NULL,23,1754,0);
INSERT INTO "django_geo_db_location" VALUES(3317,NULL,'Sorrento, ME',1270,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3318,NULL,'Sorrento, ME 4677',1270,222,NULL,23,1755,0);
INSERT INTO "django_geo_db_location" VALUES(3319,NULL,'Southwest Harbor, ME',1271,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3320,NULL,'Southwest Harbor, ME 4679',1271,222,NULL,23,1756,0);
INSERT INTO "django_geo_db_location" VALUES(3321,NULL,'Steuben, ME',1272,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3322,NULL,'Steuben, ME 4680',1272,222,NULL,23,1757,0);
INSERT INTO "django_geo_db_location" VALUES(3323,NULL,'Stonington, ME',1273,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3324,NULL,'Stonington, ME 4681',1273,222,NULL,23,1758,0);
INSERT INTO "django_geo_db_location" VALUES(3325,NULL,'Sunset, ME',1274,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3326,NULL,'Sunset, ME 4683',1274,222,NULL,23,1759,0);
INSERT INTO "django_geo_db_location" VALUES(3327,NULL,'Surry, ME',1275,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3328,NULL,'Surry, ME 4684',1275,222,NULL,23,1760,0);
INSERT INTO "django_geo_db_location" VALUES(3329,NULL,'Swans Island, ME',1276,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3330,NULL,'Swans Island, ME 4685',1276,222,NULL,23,1761,0);
INSERT INTO "django_geo_db_location" VALUES(3331,NULL,'Wesley, ME',1277,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3332,NULL,'Wesley, ME 4686',1277,222,NULL,23,1762,0);
INSERT INTO "django_geo_db_location" VALUES(3333,NULL,'West Tremont, ME',1278,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3334,NULL,'West Tremont, ME 4690',1278,222,NULL,23,1763,0);
INSERT INTO "django_geo_db_location" VALUES(3335,NULL,'Whiting, ME',1279,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3336,NULL,'Whiting, ME 4691',1279,222,NULL,23,1764,0);
INSERT INTO "django_geo_db_location" VALUES(3337,NULL,'Winter Harbor, ME 4693',1215,222,NULL,23,1765,0);
INSERT INTO "django_geo_db_location" VALUES(3338,NULL,'Baileyville, ME',1280,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3339,NULL,'Baileyville, ME 4694',1280,222,NULL,23,1766,0);
INSERT INTO "django_geo_db_location" VALUES(3340,NULL,'Poland, ME 4724',1073,222,NULL,23,1767,0);
INSERT INTO "django_geo_db_location" VALUES(3341,NULL,'Houlton, ME',1281,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3342,NULL,'Houlton, ME 4730',1281,222,NULL,23,1768,0);
INSERT INTO "django_geo_db_location" VALUES(3343,NULL,'Ashland, ME',1282,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3344,NULL,'Ashland, ME 4732',1282,222,NULL,23,1769,0);
INSERT INTO "django_geo_db_location" VALUES(3345,NULL,'Benedicta, ME',1283,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3346,NULL,'Benedicta, ME 4733',1283,222,NULL,23,1770,0);
INSERT INTO "django_geo_db_location" VALUES(3347,NULL,'Blaine, ME',1284,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3348,NULL,'Blaine, ME 4734',1284,222,NULL,23,1771,0);
INSERT INTO "django_geo_db_location" VALUES(3349,NULL,'Bridgewater, ME',1285,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3350,NULL,'Bridgewater, ME 4735',1285,222,NULL,23,1772,0);
INSERT INTO "django_geo_db_location" VALUES(3351,NULL,'Caribou, ME',1286,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3352,NULL,'Caribou, ME 4736',1286,222,NULL,23,1773,0);
INSERT INTO "django_geo_db_location" VALUES(3353,NULL,'Clayton Lake, ME',1287,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3354,NULL,'Clayton Lake, ME 4737',1287,222,NULL,23,1774,0);
INSERT INTO "django_geo_db_location" VALUES(3355,NULL,'Crouseville, ME',1288,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3356,NULL,'Crouseville, ME 4738',1288,222,NULL,23,1775,0);
INSERT INTO "django_geo_db_location" VALUES(3357,NULL,'Eagle Lake, ME',1289,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3358,NULL,'Eagle Lake, ME 4739',1289,222,NULL,23,1776,0);
INSERT INTO "django_geo_db_location" VALUES(3359,NULL,'Easton, ME',1290,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3360,NULL,'Easton, ME 4740',1290,222,NULL,23,1777,0);
INSERT INTO "django_geo_db_location" VALUES(3361,NULL,'Estcourt Station, ME',1291,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3362,NULL,'Estcourt Station, ME 4741',1291,222,NULL,23,1778,0);
INSERT INTO "django_geo_db_location" VALUES(3363,NULL,'Fort Fairfield, ME',1292,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3364,NULL,'Fort Fairfield, ME 4742',1292,222,NULL,23,1779,0);
INSERT INTO "django_geo_db_location" VALUES(3365,NULL,'Fort Kent, ME',1293,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3366,NULL,'Fort Kent, ME 4743',1293,222,NULL,23,1780,0);
INSERT INTO "django_geo_db_location" VALUES(3367,NULL,'Fort Kent Mills, ME',1294,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3368,NULL,'Fort Kent Mills, ME 4744',1294,222,NULL,23,1781,0);
INSERT INTO "django_geo_db_location" VALUES(3369,NULL,'Frenchville, ME',1295,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3370,NULL,'Frenchville, ME 4745',1295,222,NULL,23,1782,0);
INSERT INTO "django_geo_db_location" VALUES(3371,NULL,'Grand Isle, ME',1296,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3372,NULL,'Grand Isle, ME 4746',1296,222,NULL,23,1783,0);
INSERT INTO "django_geo_db_location" VALUES(3373,NULL,'Island Falls, ME',1297,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3374,NULL,'Island Falls, ME 4747',1297,222,NULL,23,1784,0);
INSERT INTO "django_geo_db_location" VALUES(3375,NULL,'Limestone, ME',1298,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3376,NULL,'Limestone, ME 4750',1298,222,NULL,23,1785,0);
INSERT INTO "django_geo_db_location" VALUES(3377,NULL,'Limestone, ME 4751',1298,222,NULL,23,1786,0);
INSERT INTO "django_geo_db_location" VALUES(3378,NULL,'Ashland, ME 4752',1282,222,NULL,23,1787,0);
INSERT INTO "django_geo_db_location" VALUES(3379,NULL,'Madawaska, ME',1299,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3380,NULL,'Madawaska, ME 4756',1299,222,NULL,23,1788,0);
INSERT INTO "django_geo_db_location" VALUES(3381,NULL,'Mapleton, ME',1300,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3382,NULL,'Mapleton, ME 4757',1300,222,NULL,23,1789,0);
INSERT INTO "django_geo_db_location" VALUES(3383,NULL,'Mars Hill, ME',1301,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3384,NULL,'Mars Hill, ME 4758',1301,222,NULL,23,1790,0);
INSERT INTO "django_geo_db_location" VALUES(3385,NULL,'Masardis, ME',1302,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3386,NULL,'Masardis, ME 4759',1302,222,NULL,23,1791,0);
INSERT INTO "django_geo_db_location" VALUES(3387,NULL,'Monticello, ME',1303,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3388,NULL,'Monticello, ME 4760',1303,222,NULL,23,1792,0);
INSERT INTO "django_geo_db_location" VALUES(3389,NULL,'New Limerick, ME',1304,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3390,NULL,'New Limerick, ME 4761',1304,222,NULL,23,1793,0);
INSERT INTO "django_geo_db_location" VALUES(3391,NULL,'New Sweden, ME',1305,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3392,NULL,'New Sweden, ME 4762',1305,222,NULL,23,1794,0);
INSERT INTO "django_geo_db_location" VALUES(3393,NULL,'Oakfield, ME',1306,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3394,NULL,'Oakfield, ME 4763',1306,222,NULL,23,1795,0);
INSERT INTO "django_geo_db_location" VALUES(3395,NULL,'Oxbow, ME',1307,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3396,NULL,'Oxbow, ME 4764',1307,222,NULL,23,1796,0);
INSERT INTO "django_geo_db_location" VALUES(3397,NULL,'Patten, ME',1308,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3398,NULL,'Patten, ME 4765',1308,222,NULL,23,1797,0);
INSERT INTO "django_geo_db_location" VALUES(3399,NULL,'Perham, ME',1309,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3400,NULL,'Perham, ME 4766',1309,222,NULL,23,1798,0);
INSERT INTO "django_geo_db_location" VALUES(3401,NULL,'Portage, ME',1310,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3402,NULL,'Portage, ME 4768',1310,222,NULL,23,1799,0);
INSERT INTO "django_geo_db_location" VALUES(3403,NULL,'Presque Isle, ME',1311,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3404,NULL,'Presque Isle, ME 4769',1311,222,NULL,23,1800,0);
INSERT INTO "django_geo_db_location" VALUES(3405,NULL,'Quimby, ME',1312,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3406,NULL,'Quimby, ME 4770',1312,222,NULL,23,1801,0);
INSERT INTO "django_geo_db_location" VALUES(3407,NULL,'Saint Agatha, ME',1313,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3408,NULL,'Saint Agatha, ME 4772',1313,222,NULL,23,1802,0);
INSERT INTO "django_geo_db_location" VALUES(3409,NULL,'Saint David, ME',1314,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3410,NULL,'Saint David, ME 4773',1314,222,NULL,23,1803,0);
INSERT INTO "django_geo_db_location" VALUES(3411,NULL,'Saint Francis, ME',1315,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3412,NULL,'Saint Francis, ME 4774',1315,222,NULL,23,1804,0);
INSERT INTO "django_geo_db_location" VALUES(3413,NULL,'Sheridan, ME',1316,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3414,NULL,'Sheridan, ME 4775',1316,222,NULL,23,1805,0);
INSERT INTO "django_geo_db_location" VALUES(3415,NULL,'Sherman Mills, ME',1317,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3416,NULL,'Sherman Mills, ME 4776',1317,222,NULL,23,1806,0);
INSERT INTO "django_geo_db_location" VALUES(3417,NULL,'Sherman Station, ME',1318,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3418,NULL,'Sherman Station, ME 4777',1318,222,NULL,23,1807,0);
INSERT INTO "django_geo_db_location" VALUES(3419,NULL,'Sinclair, ME',1319,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3420,NULL,'Sinclair, ME 4779',1319,222,NULL,23,1808,0);
INSERT INTO "django_geo_db_location" VALUES(3421,NULL,'Smyrna Mills, ME',1320,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3422,NULL,'Smyrna Mills, ME 4780',1320,222,NULL,23,1809,0);
INSERT INTO "django_geo_db_location" VALUES(3423,NULL,'Soldier Pond, ME',1321,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3424,NULL,'Soldier Pond, ME 4781',1321,222,NULL,23,1810,0);
INSERT INTO "django_geo_db_location" VALUES(3425,NULL,'Stacyville, ME',1322,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3426,NULL,'Stacyville, ME 4782',1322,222,NULL,23,1811,0);
INSERT INTO "django_geo_db_location" VALUES(3427,NULL,'Stockholm, ME',1323,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3428,NULL,'Stockholm, ME 4783',1323,222,NULL,23,1812,0);
INSERT INTO "django_geo_db_location" VALUES(3429,NULL,'Van Buren, ME',1324,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3430,NULL,'Van Buren, ME 4785',1324,222,NULL,23,1813,0);
INSERT INTO "django_geo_db_location" VALUES(3431,NULL,'Washburn, ME',1325,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3432,NULL,'Washburn, ME 4786',1325,222,NULL,23,1814,0);
INSERT INTO "django_geo_db_location" VALUES(3433,NULL,'Westfield, ME',1326,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3434,NULL,'Westfield, ME 4787',1326,222,NULL,23,1815,0);
INSERT INTO "django_geo_db_location" VALUES(3435,NULL,'Winterville, ME',1327,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3436,NULL,'Winterville, ME 4788',1327,222,NULL,23,1816,0);
INSERT INTO "django_geo_db_location" VALUES(3437,NULL,'Camden, ME',1328,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3438,NULL,'Camden, ME 4840',1328,222,NULL,23,1817,0);
INSERT INTO "django_geo_db_location" VALUES(3439,NULL,'Rockland, ME',1329,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3440,NULL,'Rockland, ME 4841',1329,222,NULL,23,1818,0);
INSERT INTO "django_geo_db_location" VALUES(3441,NULL,'Owls Head, ME',1330,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3442,NULL,'Owls Head, ME 4842',1330,222,NULL,23,1819,0);
INSERT INTO "django_geo_db_location" VALUES(3443,NULL,'Camden, ME 4843',1328,222,NULL,23,1820,0);
INSERT INTO "django_geo_db_location" VALUES(3444,NULL,'Glen Cove, ME',1331,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3445,NULL,'Glen Cove, ME 4846',1331,222,NULL,23,1821,0);
INSERT INTO "django_geo_db_location" VALUES(3446,NULL,'Hope, ME',1332,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3447,NULL,'Hope, ME 4847',1332,222,NULL,23,1822,0);
INSERT INTO "django_geo_db_location" VALUES(3448,NULL,'Islesboro, ME',1333,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3449,NULL,'Islesboro, ME 4848',1333,222,NULL,23,1823,0);
INSERT INTO "django_geo_db_location" VALUES(3450,NULL,'Lincolnville, ME',1334,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3451,NULL,'Lincolnville, ME 4849',1334,222,NULL,23,1824,0);
INSERT INTO "django_geo_db_location" VALUES(3452,NULL,'Lincolnville Center, ME',1335,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3453,NULL,'Lincolnville Center, ME 4850',1335,222,NULL,23,1825,0);
INSERT INTO "django_geo_db_location" VALUES(3454,NULL,'Matinicus, ME',1336,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3455,NULL,'Matinicus, ME 4851',1336,222,NULL,23,1826,0);
INSERT INTO "django_geo_db_location" VALUES(3456,NULL,'Monhegan, ME',1337,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3457,NULL,'Monhegan, ME 4852',1337,222,NULL,23,1827,0);
INSERT INTO "django_geo_db_location" VALUES(3458,NULL,'North Haven, ME',1338,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3459,NULL,'North Haven, ME 4853',1338,222,NULL,23,1828,0);
INSERT INTO "django_geo_db_location" VALUES(3460,NULL,'Owls Head, ME 4854',1330,222,NULL,23,1829,0);
INSERT INTO "django_geo_db_location" VALUES(3461,NULL,'Port Clyde, ME',1339,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3462,NULL,'Port Clyde, ME 4855',1339,222,NULL,23,1830,0);
INSERT INTO "django_geo_db_location" VALUES(3463,NULL,'Rockport, ME',1340,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3464,NULL,'Rockport, ME 4856',1340,222,NULL,23,1831,0);
INSERT INTO "django_geo_db_location" VALUES(3465,NULL,'Saint George, ME',1341,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3466,NULL,'Saint George, ME 4857',1341,222,NULL,23,1832,0);
INSERT INTO "django_geo_db_location" VALUES(3467,NULL,'South Thomaston, ME',1342,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3468,NULL,'South Thomaston, ME 4858',1342,222,NULL,23,1833,0);
INSERT INTO "django_geo_db_location" VALUES(3469,NULL,'Spruce Head, ME',1343,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3470,NULL,'Spruce Head, ME 4859',1343,222,NULL,23,1834,0);
INSERT INTO "django_geo_db_location" VALUES(3471,NULL,'Tenants Harbor, ME',1344,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3472,NULL,'Tenants Harbor, ME 4860',1344,222,NULL,23,1835,0);
INSERT INTO "django_geo_db_location" VALUES(3473,NULL,'Thomaston, ME',1345,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3474,NULL,'Thomaston, ME 4861',1345,222,NULL,23,1836,0);
INSERT INTO "django_geo_db_location" VALUES(3475,NULL,'Union, ME',1346,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3476,NULL,'Union, ME 4862',1346,222,NULL,23,1837,0);
INSERT INTO "django_geo_db_location" VALUES(3477,NULL,'Vinalhaven, ME',1347,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3478,NULL,'Vinalhaven, ME 4863',1347,222,NULL,23,1838,0);
INSERT INTO "django_geo_db_location" VALUES(3479,NULL,'Warren, ME',1348,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3480,NULL,'Warren, ME 4864',1348,222,NULL,23,1839,0);
INSERT INTO "django_geo_db_location" VALUES(3481,NULL,'West Rockport, ME',1349,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3482,NULL,'West Rockport, ME 4865',1349,222,NULL,23,1840,0);
INSERT INTO "django_geo_db_location" VALUES(3483,NULL,'Waterville, ME',1350,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3484,NULL,'Waterville, ME 4901',1350,222,NULL,23,1841,0);
INSERT INTO "django_geo_db_location" VALUES(3485,NULL,'Waterville, ME 4903',1350,222,NULL,23,1842,0);
INSERT INTO "django_geo_db_location" VALUES(3486,NULL,'Albion, ME',1351,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3487,NULL,'Albion, ME 4910',1351,222,NULL,23,1843,0);
INSERT INTO "django_geo_db_location" VALUES(3488,NULL,'Anson, ME',1352,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3489,NULL,'Anson, ME 4911',1352,222,NULL,23,1844,0);
INSERT INTO "django_geo_db_location" VALUES(3490,NULL,'Athens, ME',1353,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3491,NULL,'Athens, ME 4912',1353,222,NULL,23,1845,0);
INSERT INTO "django_geo_db_location" VALUES(3492,NULL,'Belfast, ME',1354,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3493,NULL,'Belfast, ME 4915',1354,222,NULL,23,1846,0);
INSERT INTO "django_geo_db_location" VALUES(3494,NULL,'Belgrade, ME',1355,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3495,NULL,'Belgrade, ME 4917',1355,222,NULL,23,1847,0);
INSERT INTO "django_geo_db_location" VALUES(3496,NULL,'Belgrade Lakes, ME',1356,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3497,NULL,'Belgrade Lakes, ME 4918',1356,222,NULL,23,1848,0);
INSERT INTO "django_geo_db_location" VALUES(3498,NULL,'Bingham, ME',1357,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3499,NULL,'Bingham, ME 4920',1357,222,NULL,23,1849,0);
INSERT INTO "django_geo_db_location" VALUES(3500,NULL,'Brooks, ME',1358,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3501,NULL,'Brooks, ME 4921',1358,222,NULL,23,1850,0);
INSERT INTO "django_geo_db_location" VALUES(3502,NULL,'Burnham, ME',1359,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3503,NULL,'Burnham, ME 4922',1359,222,NULL,23,1851,0);
INSERT INTO "django_geo_db_location" VALUES(3504,NULL,'Cambridge, ME',1360,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3505,NULL,'Cambridge, ME 4923',1360,222,NULL,23,1852,0);
INSERT INTO "django_geo_db_location" VALUES(3506,NULL,'Canaan, ME',1361,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3507,NULL,'Canaan, ME 4924',1361,222,NULL,23,1853,0);
INSERT INTO "django_geo_db_location" VALUES(3508,NULL,'Caratunk, ME',1362,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3509,NULL,'Caratunk, ME 4925',1362,222,NULL,23,1854,0);
INSERT INTO "django_geo_db_location" VALUES(3510,NULL,'China, ME',1363,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3511,NULL,'China, ME 4926',1363,222,NULL,23,1855,0);
INSERT INTO "django_geo_db_location" VALUES(3512,NULL,'Clinton, ME',1364,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3513,NULL,'Clinton, ME 4927',1364,222,NULL,23,1856,0);
INSERT INTO "django_geo_db_location" VALUES(3514,NULL,'Corinna, ME',1365,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3515,NULL,'Corinna, ME 4928',1365,222,NULL,23,1857,0);
INSERT INTO "django_geo_db_location" VALUES(3516,NULL,'Detroit, ME',1366,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3517,NULL,'Detroit, ME 4929',1366,222,NULL,23,1858,0);
INSERT INTO "django_geo_db_location" VALUES(3518,NULL,'Dexter, ME',1367,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3519,NULL,'Dexter, ME 4930',1367,222,NULL,23,1859,0);
INSERT INTO "django_geo_db_location" VALUES(3520,NULL,'Dixmont, ME',1368,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3521,NULL,'Dixmont, ME 4932',1368,222,NULL,23,1860,0);
INSERT INTO "django_geo_db_location" VALUES(3522,NULL,'East Newport, ME',1369,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3523,NULL,'East Newport, ME 4933',1369,222,NULL,23,1861,0);
INSERT INTO "django_geo_db_location" VALUES(3524,NULL,'East Vassalboro, ME',1370,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3525,NULL,'East Vassalboro, ME 4935',1370,222,NULL,23,1862,0);
INSERT INTO "django_geo_db_location" VALUES(3526,NULL,'Eustis, ME',1371,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3527,NULL,'Eustis, ME 4936',1371,222,NULL,23,1863,0);
INSERT INTO "django_geo_db_location" VALUES(3528,NULL,'Fairfield, ME',1372,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3529,NULL,'Fairfield, ME 4937',1372,222,NULL,23,1864,0);
INSERT INTO "django_geo_db_location" VALUES(3530,NULL,'Farmington, ME',1373,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3531,NULL,'Farmington, ME 4938',1373,222,NULL,23,1865,0);
INSERT INTO "django_geo_db_location" VALUES(3532,NULL,'Garland, ME',1374,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3533,NULL,'Garland, ME 4939',1374,222,NULL,23,1866,0);
INSERT INTO "django_geo_db_location" VALUES(3534,NULL,'Farmington Falls, ME',1375,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3535,NULL,'Farmington Falls, ME 4940',1375,222,NULL,23,1867,0);
INSERT INTO "django_geo_db_location" VALUES(3536,NULL,'Freedom, ME',1376,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3537,NULL,'Freedom, ME 4941',1376,222,NULL,23,1868,0);
INSERT INTO "django_geo_db_location" VALUES(3538,NULL,'Harmony, ME',1377,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3539,NULL,'Harmony, ME 4942',1377,222,NULL,23,1869,0);
INSERT INTO "django_geo_db_location" VALUES(3540,NULL,'Hartland, ME',1378,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3541,NULL,'Hartland, ME 4943',1378,222,NULL,23,1870,0);
INSERT INTO "django_geo_db_location" VALUES(3542,NULL,'Hinckley, ME',1379,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3543,NULL,'Hinckley, ME 4944',1379,222,NULL,23,1871,0);
INSERT INTO "django_geo_db_location" VALUES(3544,NULL,'Jackman, ME',1380,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3545,NULL,'Jackman, ME 4945',1380,222,NULL,23,1872,0);
INSERT INTO "django_geo_db_location" VALUES(3546,NULL,'Kingfield, ME',1381,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3547,NULL,'Kingfield, ME 4947',1381,222,NULL,23,1873,0);
INSERT INTO "django_geo_db_location" VALUES(3548,NULL,'Liberty, ME',1382,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3549,NULL,'Liberty, ME 4949',1382,222,NULL,23,1874,0);
INSERT INTO "django_geo_db_location" VALUES(3550,NULL,'Madison, ME',1383,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3551,NULL,'Madison, ME 4950',1383,222,NULL,23,1875,0);
INSERT INTO "django_geo_db_location" VALUES(3552,NULL,'Monroe, ME',1384,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3553,NULL,'Monroe, ME 4951',1384,222,NULL,23,1876,0);
INSERT INTO "django_geo_db_location" VALUES(3554,NULL,'Morrill, ME',1385,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3555,NULL,'Morrill, ME 4952',1385,222,NULL,23,1877,0);
INSERT INTO "django_geo_db_location" VALUES(3556,NULL,'Newport, ME',1386,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3557,NULL,'Newport, ME 4953',1386,222,NULL,23,1878,0);
INSERT INTO "django_geo_db_location" VALUES(3558,NULL,'New Portland, ME',1387,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3559,NULL,'New Portland, ME 4954',1387,222,NULL,23,1879,0);
INSERT INTO "django_geo_db_location" VALUES(3560,NULL,'New Sharon, ME',1388,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3561,NULL,'New Sharon, ME 4955',1388,222,NULL,23,1880,0);
INSERT INTO "django_geo_db_location" VALUES(3562,NULL,'New Vineyard, ME',1389,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3563,NULL,'New Vineyard, ME 4956',1389,222,NULL,23,1881,0);
INSERT INTO "django_geo_db_location" VALUES(3564,NULL,'Norridgewock, ME',1390,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3565,NULL,'Norridgewock, ME 4957',1390,222,NULL,23,1882,0);
INSERT INTO "django_geo_db_location" VALUES(3566,NULL,'North Anson, ME',1391,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3567,NULL,'North Anson, ME 4958',1391,222,NULL,23,1883,0);
INSERT INTO "django_geo_db_location" VALUES(3568,NULL,'North New Portland, ME',1392,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3569,NULL,'North New Portland, ME 4961',1392,222,NULL,23,1884,0);
INSERT INTO "django_geo_db_location" VALUES(3570,NULL,'North Vassalboro, ME',1393,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3571,NULL,'North Vassalboro, ME 4962',1393,222,NULL,23,1885,0);
INSERT INTO "django_geo_db_location" VALUES(3572,NULL,'Oakland, ME',1394,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3573,NULL,'Oakland, ME 4963',1394,222,NULL,23,1886,0);
INSERT INTO "django_geo_db_location" VALUES(3574,NULL,'Oquossoc, ME',1395,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3575,NULL,'Oquossoc, ME 4964',1395,222,NULL,23,1887,0);
INSERT INTO "django_geo_db_location" VALUES(3576,NULL,'Palmyra, ME',1396,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3577,NULL,'Palmyra, ME 4965',1396,222,NULL,23,1888,0);
INSERT INTO "django_geo_db_location" VALUES(3578,NULL,'Phillips, ME',1397,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3579,NULL,'Phillips, ME 4966',1397,222,NULL,23,1889,0);
INSERT INTO "django_geo_db_location" VALUES(3580,NULL,'Pittsfield, ME',1398,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3581,NULL,'Pittsfield, ME 4967',1398,222,NULL,23,1890,0);
INSERT INTO "django_geo_db_location" VALUES(3582,NULL,'Plymouth, ME',1399,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3583,NULL,'Plymouth, ME 4969',1399,222,NULL,23,1891,0);
INSERT INTO "django_geo_db_location" VALUES(3584,NULL,'Rangeley, ME',1400,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3585,NULL,'Rangeley, ME 4970',1400,222,NULL,23,1892,0);
INSERT INTO "django_geo_db_location" VALUES(3586,NULL,'Saint Albans, ME',1401,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3587,NULL,'Saint Albans, ME 4971',1401,222,NULL,23,1893,0);
INSERT INTO "django_geo_db_location" VALUES(3588,NULL,'Sandy Point, ME',1402,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3589,NULL,'Sandy Point, ME 4972',1402,222,NULL,23,1894,0);
INSERT INTO "django_geo_db_location" VALUES(3590,NULL,'Searsmont, ME',1403,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3591,NULL,'Searsmont, ME 4973',1403,222,NULL,23,1895,0);
INSERT INTO "django_geo_db_location" VALUES(3592,NULL,'Searsport, ME',1404,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3593,NULL,'Searsport, ME 4974',1404,222,NULL,23,1896,0);
INSERT INTO "django_geo_db_location" VALUES(3594,NULL,'Shawmut, ME',1405,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3595,NULL,'Shawmut, ME 4975',1405,222,NULL,23,1897,0);
INSERT INTO "django_geo_db_location" VALUES(3596,NULL,'Skowhegan, ME',1406,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3597,NULL,'Skowhegan, ME 4976',1406,222,NULL,23,1898,0);
INSERT INTO "django_geo_db_location" VALUES(3598,NULL,'Smithfield, ME',1407,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3599,NULL,'Smithfield, ME 4978',1407,222,NULL,23,1899,0);
INSERT INTO "django_geo_db_location" VALUES(3600,NULL,'Solon, ME',1408,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3601,NULL,'Solon, ME 4979',1408,222,NULL,23,1900,0);
INSERT INTO "django_geo_db_location" VALUES(3602,NULL,'Stockton Springs, ME',1409,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3603,NULL,'Stockton Springs, ME 4981',1409,222,NULL,23,1901,0);
INSERT INTO "django_geo_db_location" VALUES(3604,NULL,'Stratton, ME',1410,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3605,NULL,'Stratton, ME 4982',1410,222,NULL,23,1902,0);
INSERT INTO "django_geo_db_location" VALUES(3606,NULL,'Strong, ME',1411,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3607,NULL,'Strong, ME 4983',1411,222,NULL,23,1903,0);
INSERT INTO "django_geo_db_location" VALUES(3608,NULL,'Temple, ME',1412,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3609,NULL,'Temple, ME 4984',1412,222,NULL,23,1904,0);
INSERT INTO "django_geo_db_location" VALUES(3610,NULL,'West Forks, ME',1413,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3611,NULL,'West Forks, ME 4985',1413,222,NULL,23,1905,0);
INSERT INTO "django_geo_db_location" VALUES(3612,NULL,'Thorndike, ME',1414,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3613,NULL,'Thorndike, ME 4986',1414,222,NULL,23,1906,0);
INSERT INTO "django_geo_db_location" VALUES(3614,NULL,'Troy, ME',1415,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3615,NULL,'Troy, ME 4987',1415,222,NULL,23,1907,0);
INSERT INTO "django_geo_db_location" VALUES(3616,NULL,'Unity, ME',1416,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3617,NULL,'Unity, ME 4988',1416,222,NULL,23,1908,0);
INSERT INTO "django_geo_db_location" VALUES(3618,NULL,'Vassalboro, ME',1417,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3619,NULL,'Vassalboro, ME 4989',1417,222,NULL,23,1909,0);
INSERT INTO "django_geo_db_location" VALUES(3620,NULL,'West Farmington, ME',1418,222,NULL,23,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3621,NULL,'West Farmington, ME 4992',1418,222,NULL,23,1910,0);
INSERT INTO "django_geo_db_location" VALUES(3622,NULL,'White River Junction, VT',1419,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3623,NULL,'White River Junction, VT 5001',1419,222,NULL,53,1911,0);
INSERT INTO "django_geo_db_location" VALUES(3624,NULL,'White River Junction, VT 5009',1419,222,NULL,53,1912,0);
INSERT INTO "django_geo_db_location" VALUES(3625,NULL,'Ascutney, VT',1420,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3626,NULL,'Ascutney, VT 5030',1420,222,NULL,53,1913,0);
INSERT INTO "django_geo_db_location" VALUES(3627,NULL,'Barnard, VT',1421,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3628,NULL,'Barnard, VT 5031',1421,222,NULL,53,1914,0);
INSERT INTO "django_geo_db_location" VALUES(3629,NULL,'Bethel, VT',1422,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3630,NULL,'Bethel, VT 5032',1422,222,NULL,53,1915,0);
INSERT INTO "django_geo_db_location" VALUES(3631,NULL,'Bradford, VT',1423,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3632,NULL,'Bradford, VT 5033',1423,222,NULL,53,1916,0);
INSERT INTO "django_geo_db_location" VALUES(3633,NULL,'Bridgewater, VT',1424,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3634,NULL,'Bridgewater, VT 5034',1424,222,NULL,53,1917,0);
INSERT INTO "django_geo_db_location" VALUES(3635,NULL,'Bridgewater Corners, VT',1425,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3636,NULL,'Bridgewater Corners, VT 5035',1425,222,NULL,53,1918,0);
INSERT INTO "django_geo_db_location" VALUES(3637,NULL,'Brookfield, VT',1426,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3638,NULL,'Brookfield, VT 5036',1426,222,NULL,53,1919,0);
INSERT INTO "django_geo_db_location" VALUES(3639,NULL,'Brownsville, VT',1427,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3640,NULL,'Brownsville, VT 5037',1427,222,NULL,53,1920,0);
INSERT INTO "django_geo_db_location" VALUES(3641,NULL,'Chelsea, VT',1428,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3642,NULL,'Chelsea, VT 5038',1428,222,NULL,53,1921,0);
INSERT INTO "django_geo_db_location" VALUES(3643,NULL,'Corinth, VT',1429,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3644,NULL,'Corinth, VT 5039',1429,222,NULL,53,1922,0);
INSERT INTO "django_geo_db_location" VALUES(3645,NULL,'East Corinth, VT',1430,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3646,NULL,'East Corinth, VT 5040',1430,222,NULL,53,1923,0);
INSERT INTO "django_geo_db_location" VALUES(3647,NULL,'East Randolph, VT',1431,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3648,NULL,'East Randolph, VT 5041',1431,222,NULL,53,1924,0);
INSERT INTO "django_geo_db_location" VALUES(3649,NULL,'East Ryegate, VT',1432,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3650,NULL,'East Ryegate, VT 5042',1432,222,NULL,53,1925,0);
INSERT INTO "django_geo_db_location" VALUES(3651,NULL,'East Thetford, VT',1433,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3652,NULL,'East Thetford, VT 5043',1433,222,NULL,53,1926,0);
INSERT INTO "django_geo_db_location" VALUES(3653,NULL,'Fairlee, VT',1434,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3654,NULL,'Fairlee, VT 5045',1434,222,NULL,53,1927,0);
INSERT INTO "django_geo_db_location" VALUES(3655,NULL,'Groton, VT',1435,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3656,NULL,'Groton, VT 5046',1435,222,NULL,53,1928,0);
INSERT INTO "django_geo_db_location" VALUES(3657,NULL,'Hartford, VT',1436,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3658,NULL,'Hartford, VT 5047',1436,222,NULL,53,1929,0);
INSERT INTO "django_geo_db_location" VALUES(3659,NULL,'Hartland, VT',1437,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3660,NULL,'Hartland, VT 5048',1437,222,NULL,53,1930,0);
INSERT INTO "django_geo_db_location" VALUES(3661,NULL,'Hartland Four Corners, VT',1438,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3662,NULL,'Hartland Four Corners, VT 5049',1438,222,NULL,53,1931,0);
INSERT INTO "django_geo_db_location" VALUES(3663,NULL,'McIndoe Falls, VT',1439,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3664,NULL,'McIndoe Falls, VT 5050',1439,222,NULL,53,1932,0);
INSERT INTO "django_geo_db_location" VALUES(3665,NULL,'Newbury, VT',1440,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3666,NULL,'Newbury, VT 5051',1440,222,NULL,53,1933,0);
INSERT INTO "django_geo_db_location" VALUES(3667,NULL,'North Hartland, VT',1441,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3668,NULL,'North Hartland, VT 5052',1441,222,NULL,53,1934,0);
INSERT INTO "django_geo_db_location" VALUES(3669,NULL,'North Pomfret, VT',1442,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3670,NULL,'North Pomfret, VT 5053',1442,222,NULL,53,1935,0);
INSERT INTO "django_geo_db_location" VALUES(3671,NULL,'North Thetford, VT',1443,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3672,NULL,'North Thetford, VT 5054',1443,222,NULL,53,1936,0);
INSERT INTO "django_geo_db_location" VALUES(3673,NULL,'Norwich, VT',1444,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3674,NULL,'Norwich, VT 5055',1444,222,NULL,53,1937,0);
INSERT INTO "django_geo_db_location" VALUES(3675,NULL,'Plymouth, VT',1445,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3676,NULL,'Plymouth, VT 5056',1445,222,NULL,53,1938,0);
INSERT INTO "django_geo_db_location" VALUES(3677,NULL,'Post Mills, VT',1446,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3678,NULL,'Post Mills, VT 5058',1446,222,NULL,53,1939,0);
INSERT INTO "django_geo_db_location" VALUES(3679,NULL,'Quechee, VT',1447,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3680,NULL,'Quechee, VT 5059',1447,222,NULL,53,1940,0);
INSERT INTO "django_geo_db_location" VALUES(3681,NULL,'Randolph, VT',1448,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3682,NULL,'Randolph, VT 5060',1448,222,NULL,53,1941,0);
INSERT INTO "django_geo_db_location" VALUES(3683,NULL,'Randolph Center, VT',1449,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3684,NULL,'Randolph Center, VT 5061',1449,222,NULL,53,1942,0);
INSERT INTO "django_geo_db_location" VALUES(3685,NULL,'Reading, VT',1450,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3686,NULL,'Reading, VT 5062',1450,222,NULL,53,1943,0);
INSERT INTO "django_geo_db_location" VALUES(3687,NULL,'Sharon, VT',1451,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3688,NULL,'Sharon, VT 5065',1451,222,NULL,53,1944,0);
INSERT INTO "django_geo_db_location" VALUES(3689,NULL,'South Pomfret, VT',1452,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3690,NULL,'South Pomfret, VT 5067',1452,222,NULL,53,1945,0);
INSERT INTO "django_geo_db_location" VALUES(3691,NULL,'South Royalton, VT',1453,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3692,NULL,'South Royalton, VT 5068',1453,222,NULL,53,1946,0);
INSERT INTO "django_geo_db_location" VALUES(3693,NULL,'South Ryegate, VT',1454,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3694,NULL,'South Ryegate, VT 5069',1454,222,NULL,53,1947,0);
INSERT INTO "django_geo_db_location" VALUES(3695,NULL,'South Strafford, VT',1455,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3696,NULL,'South Strafford, VT 5070',1455,222,NULL,53,1948,0);
INSERT INTO "django_geo_db_location" VALUES(3697,NULL,'South Woodstock, VT',1456,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3698,NULL,'South Woodstock, VT 5071',1456,222,NULL,53,1949,0);
INSERT INTO "django_geo_db_location" VALUES(3699,NULL,'Strafford, VT',1457,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3700,NULL,'Strafford, VT 5072',1457,222,NULL,53,1950,0);
INSERT INTO "django_geo_db_location" VALUES(3701,NULL,'Taftsville, VT',1458,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3702,NULL,'Taftsville, VT 5073',1458,222,NULL,53,1951,0);
INSERT INTO "django_geo_db_location" VALUES(3703,NULL,'Thetford, VT',1459,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3704,NULL,'Thetford, VT 5074',1459,222,NULL,53,1952,0);
INSERT INTO "django_geo_db_location" VALUES(3705,NULL,'Thetford Center, VT',1460,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3706,NULL,'Thetford Center, VT 5075',1460,222,NULL,53,1953,0);
INSERT INTO "django_geo_db_location" VALUES(3707,NULL,'East Corinth, VT 5076',1430,222,NULL,53,1954,0);
INSERT INTO "django_geo_db_location" VALUES(3708,NULL,'Tunbridge, VT',1461,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3709,NULL,'Tunbridge, VT 5077',1461,222,NULL,53,1955,0);
INSERT INTO "django_geo_db_location" VALUES(3710,NULL,'Vershire, VT',1462,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3711,NULL,'Vershire, VT 5079',1462,222,NULL,53,1956,0);
INSERT INTO "django_geo_db_location" VALUES(3712,NULL,'Hartford, VT 5080',1436,222,NULL,53,1957,0);
INSERT INTO "django_geo_db_location" VALUES(3713,NULL,'Wells River, VT',1463,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3714,NULL,'Wells River, VT 5081',1463,222,NULL,53,1958,0);
INSERT INTO "django_geo_db_location" VALUES(3715,NULL,'West Fairlee, VT',1464,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3716,NULL,'West Fairlee, VT 5083',1464,222,NULL,53,1959,0);
INSERT INTO "django_geo_db_location" VALUES(3717,NULL,'West Hartford, VT',1465,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3718,NULL,'West Hartford, VT 5084',1465,222,NULL,53,1960,0);
INSERT INTO "django_geo_db_location" VALUES(3719,NULL,'West Newbury, VT',1466,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3720,NULL,'West Newbury, VT 5085',1466,222,NULL,53,1961,0);
INSERT INTO "django_geo_db_location" VALUES(3721,NULL,'West Topsham, VT',1467,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3722,NULL,'West Topsham, VT 5086',1467,222,NULL,53,1962,0);
INSERT INTO "django_geo_db_location" VALUES(3723,NULL,'Wilder, VT',1468,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3724,NULL,'Wilder, VT 5088',1468,222,NULL,53,1963,0);
INSERT INTO "django_geo_db_location" VALUES(3725,NULL,'Windsor, VT',1469,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3726,NULL,'Windsor, VT 5089',1469,222,NULL,53,1964,0);
INSERT INTO "django_geo_db_location" VALUES(3727,NULL,'Woodstock, VT',1470,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3728,NULL,'Woodstock, VT 5091',1470,222,NULL,53,1965,0);
INSERT INTO "django_geo_db_location" VALUES(3729,NULL,'Bellows Falls, VT',1471,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3730,NULL,'Bellows Falls, VT 5101',1471,222,NULL,53,1966,0);
INSERT INTO "django_geo_db_location" VALUES(3731,NULL,'Cavendish, VT',1472,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3732,NULL,'Cavendish, VT 5124',1472,222,NULL,53,1967,0);
INSERT INTO "django_geo_db_location" VALUES(3733,NULL,'Cambridgeport, VT',1473,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3734,NULL,'Cambridgeport, VT 5141',1473,222,NULL,53,1968,0);
INSERT INTO "django_geo_db_location" VALUES(3735,NULL,'Cavendish, VT 5142',1472,222,NULL,53,1969,0);
INSERT INTO "django_geo_db_location" VALUES(3736,NULL,'Chester, VT',1474,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3737,NULL,'Chester, VT 5143',1474,222,NULL,53,1970,0);
INSERT INTO "django_geo_db_location" VALUES(3738,NULL,'Chester Depot, VT',1475,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3739,NULL,'Chester Depot, VT 5144',1475,222,NULL,53,1971,0);
INSERT INTO "django_geo_db_location" VALUES(3740,NULL,'Grafton, VT',1476,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3741,NULL,'Grafton, VT 5146',1476,222,NULL,53,1972,0);
INSERT INTO "django_geo_db_location" VALUES(3742,NULL,'Londonderry, VT',1477,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3743,NULL,'Londonderry, VT 5148',1477,222,NULL,53,1973,0);
INSERT INTO "django_geo_db_location" VALUES(3744,NULL,'Ludlow, VT',1478,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3745,NULL,'Ludlow, VT 5149',1478,222,NULL,53,1974,0);
INSERT INTO "django_geo_db_location" VALUES(3746,NULL,'North Springfield, VT',1479,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3747,NULL,'North Springfield, VT 5150',1479,222,NULL,53,1975,0);
INSERT INTO "django_geo_db_location" VALUES(3748,NULL,'Perkinsville, VT',1480,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3749,NULL,'Perkinsville, VT 5151',1480,222,NULL,53,1976,0);
INSERT INTO "django_geo_db_location" VALUES(3750,NULL,'Peru, VT',1481,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3751,NULL,'Peru, VT 5152',1481,222,NULL,53,1977,0);
INSERT INTO "django_geo_db_location" VALUES(3752,NULL,'Proctorsville, VT',1482,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3753,NULL,'Proctorsville, VT 5153',1482,222,NULL,53,1978,0);
INSERT INTO "django_geo_db_location" VALUES(3754,NULL,'Saxtons River, VT',1483,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3755,NULL,'Saxtons River, VT 5154',1483,222,NULL,53,1979,0);
INSERT INTO "django_geo_db_location" VALUES(3756,NULL,'South Londonderry, VT',1484,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3757,NULL,'South Londonderry, VT 5155',1484,222,NULL,53,1980,0);
INSERT INTO "django_geo_db_location" VALUES(3758,NULL,'Springfield, VT',1485,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3759,NULL,'Springfield, VT 5156',1485,222,NULL,53,1981,0);
INSERT INTO "django_geo_db_location" VALUES(3760,NULL,'Westminster, VT',1486,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3761,NULL,'Westminster, VT 5158',1486,222,NULL,53,1982,0);
INSERT INTO "django_geo_db_location" VALUES(3762,NULL,'Westminster Station, VT',1487,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3763,NULL,'Westminster Station, VT 5159',1487,222,NULL,53,1983,0);
INSERT INTO "django_geo_db_location" VALUES(3764,NULL,'Weston, VT',1488,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3765,NULL,'Weston, VT 5161',1488,222,NULL,53,1984,0);
INSERT INTO "django_geo_db_location" VALUES(3766,NULL,'Bennington, VT',1489,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3767,NULL,'Bennington, VT 5201',1489,222,NULL,53,1985,0);
INSERT INTO "django_geo_db_location" VALUES(3768,NULL,'Woodford, VT',1490,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3769,NULL,'Woodford, VT 5210',1490,222,NULL,53,1986,0);
INSERT INTO "django_geo_db_location" VALUES(3770,NULL,'Barnet, VT',1491,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3771,NULL,'Barnet, VT 5219',1491,222,NULL,53,1987,0);
INSERT INTO "django_geo_db_location" VALUES(3772,NULL,'Sudbury, VT',1492,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3773,NULL,'Sudbury, VT 5233',1492,222,NULL,53,1988,0);
INSERT INTO "django_geo_db_location" VALUES(3774,NULL,'Arlington, VT',1493,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3775,NULL,'Arlington, VT 5250',1493,222,NULL,53,1989,0);
INSERT INTO "django_geo_db_location" VALUES(3776,NULL,'Dorset, VT',1494,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3777,NULL,'Dorset, VT 5251',1494,222,NULL,53,1990,0);
INSERT INTO "django_geo_db_location" VALUES(3778,NULL,'East Arlington, VT',1495,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3779,NULL,'East Arlington, VT 5252',1495,222,NULL,53,1991,0);
INSERT INTO "django_geo_db_location" VALUES(3780,NULL,'East Dorset, VT',1496,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3781,NULL,'East Dorset, VT 5253',1496,222,NULL,53,1992,0);
INSERT INTO "django_geo_db_location" VALUES(3782,NULL,'Manchester, VT',1497,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3783,NULL,'Manchester, VT 5254',1497,222,NULL,53,1993,0);
INSERT INTO "django_geo_db_location" VALUES(3784,NULL,'Manchester Center, VT',1498,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3785,NULL,'Manchester Center, VT 5255',1498,222,NULL,53,1994,0);
INSERT INTO "django_geo_db_location" VALUES(3786,NULL,'North Bennington, VT',1499,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3787,NULL,'North Bennington, VT 5257',1499,222,NULL,53,1995,0);
INSERT INTO "django_geo_db_location" VALUES(3788,NULL,'North Pownal, VT',1500,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3789,NULL,'North Pownal, VT 5260',1500,222,NULL,53,1996,0);
INSERT INTO "django_geo_db_location" VALUES(3790,NULL,'Pownal, VT',1501,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3791,NULL,'Pownal, VT 5261',1501,222,NULL,53,1997,0);
INSERT INTO "django_geo_db_location" VALUES(3792,NULL,'Shaftsbury, VT',1502,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3793,NULL,'Shaftsbury, VT 5262',1502,222,NULL,53,1998,0);
INSERT INTO "django_geo_db_location" VALUES(3794,NULL,'Sutton, VT',1503,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3795,NULL,'Sutton, VT 5267',1503,222,NULL,53,1999,0);
INSERT INTO "django_geo_db_location" VALUES(3796,NULL,'Craftsbury, VT',1504,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3797,NULL,'Craftsbury, VT 5286',1504,222,NULL,53,2000,0);
INSERT INTO "django_geo_db_location" VALUES(3798,NULL,'Brattleboro, VT',1505,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3799,NULL,'Brattleboro, VT 5301',1505,222,NULL,53,2001,0);
INSERT INTO "django_geo_db_location" VALUES(3800,NULL,'Brattleboro, VT 5302',1505,222,NULL,53,2002,0);
INSERT INTO "django_geo_db_location" VALUES(3801,NULL,'Brattleboro, VT 5303',1505,222,NULL,53,2003,0);
INSERT INTO "django_geo_db_location" VALUES(3802,NULL,'Brattleboro, VT 5304',1505,222,NULL,53,2004,0);
INSERT INTO "django_geo_db_location" VALUES(3803,NULL,'Bondville, VT',1506,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3804,NULL,'Bondville, VT 5340',1506,222,NULL,53,2005,0);
INSERT INTO "django_geo_db_location" VALUES(3805,NULL,'East Dover, VT',1507,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3806,NULL,'East Dover, VT 5341',1507,222,NULL,53,2006,0);
INSERT INTO "django_geo_db_location" VALUES(3807,NULL,'Jacksonville, VT',1508,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3808,NULL,'Jacksonville, VT 5342',1508,222,NULL,53,2007,0);
INSERT INTO "django_geo_db_location" VALUES(3809,NULL,'Jamaica, VT',1509,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3810,NULL,'Jamaica, VT 5343',1509,222,NULL,53,2008,0);
INSERT INTO "django_geo_db_location" VALUES(3811,NULL,'Marlboro, VT',1510,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3812,NULL,'Marlboro, VT 5344',1510,222,NULL,53,2009,0);
INSERT INTO "django_geo_db_location" VALUES(3813,NULL,'Newfane, VT',1511,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3814,NULL,'Newfane, VT 5345',1511,222,NULL,53,2010,0);
INSERT INTO "django_geo_db_location" VALUES(3815,NULL,'Putney, VT',1512,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3816,NULL,'Putney, VT 5346',1512,222,NULL,53,2011,0);
INSERT INTO "django_geo_db_location" VALUES(3817,NULL,'Readsboro, VT',1513,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3818,NULL,'Readsboro, VT 5350',1513,222,NULL,53,2012,0);
INSERT INTO "django_geo_db_location" VALUES(3819,NULL,'South Newfane, VT',1514,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3820,NULL,'South Newfane, VT 5351',1514,222,NULL,53,2013,0);
INSERT INTO "django_geo_db_location" VALUES(3821,NULL,'Readsboro, VT 5352',1513,222,NULL,53,2014,0);
INSERT INTO "django_geo_db_location" VALUES(3822,NULL,'Townshend, VT',1515,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3823,NULL,'Townshend, VT 5353',1515,222,NULL,53,2015,0);
INSERT INTO "django_geo_db_location" VALUES(3824,NULL,'Vernon, VT',1516,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3825,NULL,'Vernon, VT 5354',1516,222,NULL,53,2016,0);
INSERT INTO "django_geo_db_location" VALUES(3826,NULL,'Wardsboro, VT',1517,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3827,NULL,'Wardsboro, VT 5355',1517,222,NULL,53,2017,0);
INSERT INTO "django_geo_db_location" VALUES(3828,NULL,'West Dover, VT',1518,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3829,NULL,'West Dover, VT 5356',1518,222,NULL,53,2018,0);
INSERT INTO "django_geo_db_location" VALUES(3830,NULL,'West Dummerston, VT',1519,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3831,NULL,'West Dummerston, VT 5357',1519,222,NULL,53,2019,0);
INSERT INTO "django_geo_db_location" VALUES(3832,NULL,'West Halifax, VT',1520,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3833,NULL,'West Halifax, VT 5358',1520,222,NULL,53,2020,0);
INSERT INTO "django_geo_db_location" VALUES(3834,NULL,'West Townshend, VT',1521,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3835,NULL,'West Townshend, VT 5359',1521,222,NULL,53,2021,0);
INSERT INTO "django_geo_db_location" VALUES(3836,NULL,'West Wardsboro, VT',1522,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3837,NULL,'West Wardsboro, VT 5360',1522,222,NULL,53,2022,0);
INSERT INTO "django_geo_db_location" VALUES(3838,NULL,'Whitingham, VT',1523,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3839,NULL,'Whitingham, VT 5361',1523,222,NULL,53,2023,0);
INSERT INTO "django_geo_db_location" VALUES(3840,NULL,'Williamsville, VT',1524,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3841,NULL,'Williamsville, VT 5362',1524,222,NULL,53,2024,0);
INSERT INTO "django_geo_db_location" VALUES(3842,NULL,'Wilmington, VT',1525,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3843,NULL,'Wilmington, VT 5363',1525,222,NULL,53,2025,0);
INSERT INTO "django_geo_db_location" VALUES(3844,NULL,'Westminster, VT 5364',1486,222,NULL,53,2026,0);
INSERT INTO "django_geo_db_location" VALUES(3845,NULL,'Burlington, VT',1526,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3846,NULL,'Burlington, VT 5401',1526,222,NULL,53,2027,0);
INSERT INTO "django_geo_db_location" VALUES(3847,NULL,'Burlington, VT 5402',1526,222,NULL,53,2028,0);
INSERT INTO "django_geo_db_location" VALUES(3848,NULL,'South Burlington, VT',1527,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3849,NULL,'South Burlington, VT 5403',1527,222,NULL,53,2029,0);
INSERT INTO "django_geo_db_location" VALUES(3850,NULL,'Winooski, VT',1528,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3851,NULL,'Winooski, VT 5404',1528,222,NULL,53,2030,0);
INSERT INTO "django_geo_db_location" VALUES(3852,NULL,'Burlington, VT 5405',1526,222,NULL,53,2031,0);
INSERT INTO "django_geo_db_location" VALUES(3853,NULL,'Burlington, VT 5406',1526,222,NULL,53,2032,0);
INSERT INTO "django_geo_db_location" VALUES(3854,NULL,'South Burlington, VT 5407',1527,222,NULL,53,2033,0);
INSERT INTO "django_geo_db_location" VALUES(3855,NULL,'Fletcher, VT',1529,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3856,NULL,'Fletcher, VT 5418',1529,222,NULL,53,2034,0);
INSERT INTO "django_geo_db_location" VALUES(3857,NULL,'Lincoln, VT',1530,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3858,NULL,'Lincoln, VT 5433',1530,222,NULL,53,2035,0);
INSERT INTO "django_geo_db_location" VALUES(3859,NULL,'Colchester, VT',1531,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3860,NULL,'Colchester, VT 5439',1531,222,NULL,53,2036,0);
INSERT INTO "django_geo_db_location" VALUES(3861,NULL,'Alburg, VT',1532,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3862,NULL,'Alburg, VT 5440',1532,222,NULL,53,2037,0);
INSERT INTO "django_geo_db_location" VALUES(3863,NULL,'Bakersfield, VT',1533,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3864,NULL,'Bakersfield, VT 5441',1533,222,NULL,53,2038,0);
INSERT INTO "django_geo_db_location" VALUES(3865,NULL,'Belvidere Center, VT',1534,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3866,NULL,'Belvidere Center, VT 5442',1534,222,NULL,53,2039,0);
INSERT INTO "django_geo_db_location" VALUES(3867,NULL,'Bristol, VT',1535,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3868,NULL,'Bristol, VT 5443',1535,222,NULL,53,2040,0);
INSERT INTO "django_geo_db_location" VALUES(3869,NULL,'Cambridge, VT',1536,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3870,NULL,'Cambridge, VT 5444',1536,222,NULL,53,2041,0);
INSERT INTO "django_geo_db_location" VALUES(3871,NULL,'Charlotte, VT',1537,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3872,NULL,'Charlotte, VT 5445',1537,222,NULL,53,2042,0);
INSERT INTO "django_geo_db_location" VALUES(3873,NULL,'Colchester, VT 5446',1531,222,NULL,53,2043,0);
INSERT INTO "django_geo_db_location" VALUES(3874,NULL,'East Berkshire, VT',1538,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3875,NULL,'East Berkshire, VT 5447',1538,222,NULL,53,2044,0);
INSERT INTO "django_geo_db_location" VALUES(3876,NULL,'East Fairfield, VT',1539,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3877,NULL,'East Fairfield, VT 5448',1539,222,NULL,53,2045,0);
INSERT INTO "django_geo_db_location" VALUES(3878,NULL,'Colchester, VT 5449',1531,222,NULL,53,2046,0);
INSERT INTO "django_geo_db_location" VALUES(3879,NULL,'Enosburg Falls, VT',1540,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3880,NULL,'Enosburg Falls, VT 5450',1540,222,NULL,53,2047,0);
INSERT INTO "django_geo_db_location" VALUES(3881,NULL,'Essex, VT',1541,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3882,NULL,'Essex, VT 5451',1541,222,NULL,53,2048,0);
INSERT INTO "django_geo_db_location" VALUES(3883,NULL,'Essex Junction, VT',1542,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3884,NULL,'Essex Junction, VT 5452',1542,222,NULL,53,2049,0);
INSERT INTO "django_geo_db_location" VALUES(3885,NULL,'Essex Junction, VT 5453',1542,222,NULL,53,2050,0);
INSERT INTO "django_geo_db_location" VALUES(3886,NULL,'Fairfax, VT',1543,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3887,NULL,'Fairfax, VT 5454',1543,222,NULL,53,2051,0);
INSERT INTO "django_geo_db_location" VALUES(3888,NULL,'Fairfield, VT',1544,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3889,NULL,'Fairfield, VT 5455',1544,222,NULL,53,2052,0);
INSERT INTO "django_geo_db_location" VALUES(3890,NULL,'Ferrisburg, VT',1545,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3891,NULL,'Ferrisburg, VT 5456',1545,222,NULL,53,2053,0);
INSERT INTO "django_geo_db_location" VALUES(3892,NULL,'Franklin, VT',1546,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3893,NULL,'Franklin, VT 5457',1546,222,NULL,53,2054,0);
INSERT INTO "django_geo_db_location" VALUES(3894,NULL,'Grand Isle, VT',1547,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3895,NULL,'Grand Isle, VT 5458',1547,222,NULL,53,2055,0);
INSERT INTO "django_geo_db_location" VALUES(3896,NULL,'Highgate Center, VT',1548,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3897,NULL,'Highgate Center, VT 5459',1548,222,NULL,53,2056,0);
INSERT INTO "django_geo_db_location" VALUES(3898,NULL,'Highgate Springs, VT',1549,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3899,NULL,'Highgate Springs, VT 5460',1549,222,NULL,53,2057,0);
INSERT INTO "django_geo_db_location" VALUES(3900,NULL,'Hinesburg, VT',1550,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3901,NULL,'Hinesburg, VT 5461',1550,222,NULL,53,2058,0);
INSERT INTO "django_geo_db_location" VALUES(3902,NULL,'Huntington, VT',1551,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3903,NULL,'Huntington, VT 5462',1551,222,NULL,53,2059,0);
INSERT INTO "django_geo_db_location" VALUES(3904,NULL,'Isle La Motte, VT',1552,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3905,NULL,'Isle La Motte, VT 5463',1552,222,NULL,53,2060,0);
INSERT INTO "django_geo_db_location" VALUES(3906,NULL,'Jeffersonville, VT',1553,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3907,NULL,'Jeffersonville, VT 5464',1553,222,NULL,53,2061,0);
INSERT INTO "django_geo_db_location" VALUES(3908,NULL,'Jericho, VT',1554,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3909,NULL,'Jericho, VT 5465',1554,222,NULL,53,2062,0);
INSERT INTO "django_geo_db_location" VALUES(3910,NULL,'Jonesville, VT',1555,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3911,NULL,'Jonesville, VT 5466',1555,222,NULL,53,2063,0);
INSERT INTO "django_geo_db_location" VALUES(3912,NULL,'Milton, VT',1556,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3913,NULL,'Milton, VT 5468',1556,222,NULL,53,2064,0);
INSERT INTO "django_geo_db_location" VALUES(3914,NULL,'Monkton, VT',1557,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3915,NULL,'Monkton, VT 5469',1557,222,NULL,53,2065,0);
INSERT INTO "django_geo_db_location" VALUES(3916,NULL,'Montgomery, VT',1558,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3917,NULL,'Montgomery, VT 5470',1558,222,NULL,53,2066,0);
INSERT INTO "django_geo_db_location" VALUES(3918,NULL,'Montgomery Center, VT',1559,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3919,NULL,'Montgomery Center, VT 5471',1559,222,NULL,53,2067,0);
INSERT INTO "django_geo_db_location" VALUES(3920,NULL,'New Haven, VT',1560,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3921,NULL,'New Haven, VT 5472',1560,222,NULL,53,2068,0);
INSERT INTO "django_geo_db_location" VALUES(3922,NULL,'North Ferrisburg, VT',1561,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3923,NULL,'North Ferrisburg, VT 5473',1561,222,NULL,53,2069,0);
INSERT INTO "django_geo_db_location" VALUES(3924,NULL,'North Hero, VT',1562,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3925,NULL,'North Hero, VT 5474',1562,222,NULL,53,2070,0);
INSERT INTO "django_geo_db_location" VALUES(3926,NULL,'Richford, VT',1563,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3927,NULL,'Richford, VT 5476',1563,222,NULL,53,2071,0);
INSERT INTO "django_geo_db_location" VALUES(3928,NULL,'Richmond, VT',1564,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3929,NULL,'Richmond, VT 5477',1564,222,NULL,53,2072,0);
INSERT INTO "django_geo_db_location" VALUES(3930,NULL,'Saint Albans, VT',1565,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3931,NULL,'Saint Albans, VT 5478',1565,222,NULL,53,2073,0);
INSERT INTO "django_geo_db_location" VALUES(3932,NULL,'Saint Albans, VT 5479',1565,222,NULL,53,2074,0);
INSERT INTO "django_geo_db_location" VALUES(3933,NULL,'Saint Albans Bay, VT',1566,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3934,NULL,'Saint Albans Bay, VT 5481',1566,222,NULL,53,2075,0);
INSERT INTO "django_geo_db_location" VALUES(3935,NULL,'Shelburne, VT',1567,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3936,NULL,'Shelburne, VT 5482',1567,222,NULL,53,2076,0);
INSERT INTO "django_geo_db_location" VALUES(3937,NULL,'Sheldon, VT',1568,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3938,NULL,'Sheldon, VT 5483',1568,222,NULL,53,2077,0);
INSERT INTO "django_geo_db_location" VALUES(3939,NULL,'Sheldon Springs, VT',1569,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3940,NULL,'Sheldon Springs, VT 5485',1569,222,NULL,53,2078,0);
INSERT INTO "django_geo_db_location" VALUES(3941,NULL,'South Hero, VT',1570,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3942,NULL,'South Hero, VT 5486',1570,222,NULL,53,2079,0);
INSERT INTO "django_geo_db_location" VALUES(3943,NULL,'Starksboro, VT',1571,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3944,NULL,'Starksboro, VT 5487',1571,222,NULL,53,2080,0);
INSERT INTO "django_geo_db_location" VALUES(3945,NULL,'Swanton, VT',1572,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3946,NULL,'Swanton, VT 5488',1572,222,NULL,53,2081,0);
INSERT INTO "django_geo_db_location" VALUES(3947,NULL,'Underhill, VT',1573,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3948,NULL,'Underhill, VT 5489',1573,222,NULL,53,2082,0);
INSERT INTO "django_geo_db_location" VALUES(3949,NULL,'Underhill Center, VT',1574,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3950,NULL,'Underhill Center, VT 5490',1574,222,NULL,53,2083,0);
INSERT INTO "django_geo_db_location" VALUES(3951,NULL,'Vergennes, VT',1575,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3952,NULL,'Vergennes, VT 5491',1575,222,NULL,53,2084,0);
INSERT INTO "django_geo_db_location" VALUES(3953,NULL,'Waterville, VT',1576,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3954,NULL,'Waterville, VT 5492',1576,222,NULL,53,2085,0);
INSERT INTO "django_geo_db_location" VALUES(3955,NULL,'Westford, VT',1577,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3956,NULL,'Westford, VT 5494',1577,222,NULL,53,2086,0);
INSERT INTO "django_geo_db_location" VALUES(3957,NULL,'Williston, VT',1578,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3958,NULL,'Williston, VT 5495',1578,222,NULL,53,2087,0);
INSERT INTO "django_geo_db_location" VALUES(3959,NULL,'Andover, MA 5501',342,222,NULL,39,2088,0);
INSERT INTO "django_geo_db_location" VALUES(3960,NULL,'Andover, MA 5544',342,222,NULL,39,2089,0);
INSERT INTO "django_geo_db_location" VALUES(3961,NULL,'Montpelier, VT',1579,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3962,NULL,'Montpelier, VT 5601',1579,222,NULL,53,2090,0);
INSERT INTO "django_geo_db_location" VALUES(3963,NULL,'Montpelier, VT 5602',1579,222,NULL,53,2091,0);
INSERT INTO "django_geo_db_location" VALUES(3964,NULL,'Montpelier, VT 5603',1579,222,NULL,53,2092,0);
INSERT INTO "django_geo_db_location" VALUES(3965,NULL,'Montpelier, VT 5604',1579,222,NULL,53,2093,0);
INSERT INTO "django_geo_db_location" VALUES(3966,NULL,'Montpelier, VT 5609',1579,222,NULL,53,2094,0);
INSERT INTO "django_geo_db_location" VALUES(3967,NULL,'Montpelier, VT 5620',1579,222,NULL,53,2095,0);
INSERT INTO "django_geo_db_location" VALUES(3968,NULL,'Waterbury, VT',1580,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3969,NULL,'Waterbury, VT 5626',1580,222,NULL,53,2096,0);
INSERT INTO "django_geo_db_location" VALUES(3970,NULL,'Montpelier, VT 5633',1579,222,NULL,53,2097,0);
INSERT INTO "django_geo_db_location" VALUES(3971,NULL,'Adamant, VT',1581,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3972,NULL,'Adamant, VT 5640',1581,222,NULL,53,2098,0);
INSERT INTO "django_geo_db_location" VALUES(3973,NULL,'Barre, VT',1582,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3974,NULL,'Barre, VT 5641',1582,222,NULL,53,2099,0);
INSERT INTO "django_geo_db_location" VALUES(3975,NULL,'Cabot, VT',1583,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3976,NULL,'Cabot, VT 5647',1583,222,NULL,53,2100,0);
INSERT INTO "django_geo_db_location" VALUES(3977,NULL,'Calais, VT',1584,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3978,NULL,'Calais, VT 5648',1584,222,NULL,53,2101,0);
INSERT INTO "django_geo_db_location" VALUES(3979,NULL,'East Barre, VT',1585,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3980,NULL,'East Barre, VT 5649',1585,222,NULL,53,2102,0);
INSERT INTO "django_geo_db_location" VALUES(3981,NULL,'East Calais, VT',1586,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3982,NULL,'East Calais, VT 5650',1586,222,NULL,53,2103,0);
INSERT INTO "django_geo_db_location" VALUES(3983,NULL,'East Montpelier, VT',1587,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3984,NULL,'East Montpelier, VT 5651',1587,222,NULL,53,2104,0);
INSERT INTO "django_geo_db_location" VALUES(3985,NULL,'Eden, VT',1588,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3986,NULL,'Eden, VT 5652',1588,222,NULL,53,2105,0);
INSERT INTO "django_geo_db_location" VALUES(3987,NULL,'Eden Mills, VT',1589,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3988,NULL,'Eden Mills, VT 5653',1589,222,NULL,53,2106,0);
INSERT INTO "django_geo_db_location" VALUES(3989,NULL,'Graniteville, VT',1590,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3990,NULL,'Graniteville, VT 5654',1590,222,NULL,53,2107,0);
INSERT INTO "django_geo_db_location" VALUES(3991,NULL,'Hyde Park, VT',1591,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3992,NULL,'Hyde Park, VT 5655',1591,222,NULL,53,2108,0);
INSERT INTO "django_geo_db_location" VALUES(3993,NULL,'Johnson, VT',1592,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3994,NULL,'Johnson, VT 5656',1592,222,NULL,53,2109,0);
INSERT INTO "django_geo_db_location" VALUES(3995,NULL,'Lake Elmore, VT',1593,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3996,NULL,'Lake Elmore, VT 5657',1593,222,NULL,53,2110,0);
INSERT INTO "django_geo_db_location" VALUES(3997,NULL,'Marshfield, VT',1594,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(3998,NULL,'Marshfield, VT 5658',1594,222,NULL,53,2111,0);
INSERT INTO "django_geo_db_location" VALUES(3999,NULL,'Moretown, VT',1595,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4000,NULL,'Moretown, VT 5660',1595,222,NULL,53,2112,0);
INSERT INTO "django_geo_db_location" VALUES(4001,NULL,'Morrisville, VT',1596,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4002,NULL,'Morrisville, VT 5661',1596,222,NULL,53,2113,0);
INSERT INTO "django_geo_db_location" VALUES(4003,NULL,'Moscow, VT',1597,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4004,NULL,'Moscow, VT 5662',1597,222,NULL,53,2114,0);
INSERT INTO "django_geo_db_location" VALUES(4005,NULL,'Northfield, VT',1598,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4006,NULL,'Northfield, VT 5663',1598,222,NULL,53,2115,0);
INSERT INTO "django_geo_db_location" VALUES(4007,NULL,'Northfield Falls, VT',1599,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4008,NULL,'Northfield Falls, VT 5664',1599,222,NULL,53,2116,0);
INSERT INTO "django_geo_db_location" VALUES(4009,NULL,'North Hyde Park, VT',1600,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4010,NULL,'North Hyde Park, VT 5665',1600,222,NULL,53,2117,0);
INSERT INTO "django_geo_db_location" VALUES(4011,NULL,'North Montpelier, VT',1601,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4012,NULL,'North Montpelier, VT 5666',1601,222,NULL,53,2118,0);
INSERT INTO "django_geo_db_location" VALUES(4013,NULL,'Plainfield, VT',1602,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4014,NULL,'Plainfield, VT 5667',1602,222,NULL,53,2119,0);
INSERT INTO "django_geo_db_location" VALUES(4015,NULL,'Roxbury, VT',1603,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4016,NULL,'Roxbury, VT 5669',1603,222,NULL,53,2120,0);
INSERT INTO "django_geo_db_location" VALUES(4017,NULL,'South Barre, VT',1604,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4018,NULL,'South Barre, VT 5670',1604,222,NULL,53,2121,0);
INSERT INTO "django_geo_db_location" VALUES(4019,NULL,'Waterbury, VT 5671',1580,222,NULL,53,2122,0);
INSERT INTO "django_geo_db_location" VALUES(4020,NULL,'Stowe, VT',1605,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4021,NULL,'Stowe, VT 5672',1605,222,NULL,53,2123,0);
INSERT INTO "django_geo_db_location" VALUES(4022,NULL,'Waitsfield, VT',1606,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4023,NULL,'Waitsfield, VT 5673',1606,222,NULL,53,2124,0);
INSERT INTO "django_geo_db_location" VALUES(4024,NULL,'Warren, VT',1607,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4025,NULL,'Warren, VT 5674',1607,222,NULL,53,2125,0);
INSERT INTO "django_geo_db_location" VALUES(4026,NULL,'Washington, VT',1608,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4027,NULL,'Washington, VT 5675',1608,222,NULL,53,2126,0);
INSERT INTO "django_geo_db_location" VALUES(4028,NULL,'Waterbury, VT 5676',1580,222,NULL,53,2127,0);
INSERT INTO "django_geo_db_location" VALUES(4029,NULL,'Waterbury Center, VT',1609,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4030,NULL,'Waterbury Center, VT 5677',1609,222,NULL,53,2128,0);
INSERT INTO "django_geo_db_location" VALUES(4031,NULL,'Websterville, VT',1610,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4032,NULL,'Websterville, VT 5678',1610,222,NULL,53,2129,0);
INSERT INTO "django_geo_db_location" VALUES(4033,NULL,'Williamstown, VT',1611,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4034,NULL,'Williamstown, VT 5679',1611,222,NULL,53,2130,0);
INSERT INTO "django_geo_db_location" VALUES(4035,NULL,'Wolcott, VT',1612,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4036,NULL,'Wolcott, VT 5680',1612,222,NULL,53,2131,0);
INSERT INTO "django_geo_db_location" VALUES(4037,NULL,'Woodbury, VT',1613,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4038,NULL,'Woodbury, VT 5681',1613,222,NULL,53,2132,0);
INSERT INTO "django_geo_db_location" VALUES(4039,NULL,'Worcester, VT',1614,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4040,NULL,'Worcester, VT 5682',1614,222,NULL,53,2133,0);
INSERT INTO "django_geo_db_location" VALUES(4041,NULL,'Rutland, VT',1615,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4042,NULL,'Rutland, VT 5701',1615,222,NULL,53,2134,0);
INSERT INTO "django_geo_db_location" VALUES(4043,NULL,'Rutland, VT 5702',1615,222,NULL,53,2135,0);
INSERT INTO "django_geo_db_location" VALUES(4044,NULL,'Belmont, VT',1616,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4045,NULL,'Belmont, VT 5730',1616,222,NULL,53,2136,0);
INSERT INTO "django_geo_db_location" VALUES(4046,NULL,'Benson, VT',1617,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4047,NULL,'Benson, VT 5731',1617,222,NULL,53,2137,0);
INSERT INTO "django_geo_db_location" VALUES(4048,NULL,'Bomoseen, VT',1618,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4049,NULL,'Bomoseen, VT 5732',1618,222,NULL,53,2138,0);
INSERT INTO "django_geo_db_location" VALUES(4050,NULL,'Brandon, VT',1619,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4051,NULL,'Brandon, VT 5733',1619,222,NULL,53,2139,0);
INSERT INTO "django_geo_db_location" VALUES(4052,NULL,'Bridport, VT',1620,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4053,NULL,'Bridport, VT 5734',1620,222,NULL,53,2140,0);
INSERT INTO "django_geo_db_location" VALUES(4054,NULL,'Castleton, VT',1621,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4055,NULL,'Castleton, VT 5735',1621,222,NULL,53,2141,0);
INSERT INTO "django_geo_db_location" VALUES(4056,NULL,'Center Rutland, VT',1622,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4057,NULL,'Center Rutland, VT 5736',1622,222,NULL,53,2142,0);
INSERT INTO "django_geo_db_location" VALUES(4058,NULL,'Chittenden, VT',1623,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4059,NULL,'Chittenden, VT 5737',1623,222,NULL,53,2143,0);
INSERT INTO "django_geo_db_location" VALUES(4060,NULL,'Cuttingsville, VT',1624,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4061,NULL,'Cuttingsville, VT 5738',1624,222,NULL,53,2144,0);
INSERT INTO "django_geo_db_location" VALUES(4062,NULL,'Danby, VT',1625,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4063,NULL,'Danby, VT 5739',1625,222,NULL,53,2145,0);
INSERT INTO "django_geo_db_location" VALUES(4064,NULL,'East Middlebury, VT',1626,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4065,NULL,'East Middlebury, VT 5740',1626,222,NULL,53,2146,0);
INSERT INTO "django_geo_db_location" VALUES(4066,NULL,'East Poultney, VT',1627,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4067,NULL,'East Poultney, VT 5741',1627,222,NULL,53,2147,0);
INSERT INTO "django_geo_db_location" VALUES(4068,NULL,'East Wallingford, VT',1628,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4069,NULL,'East Wallingford, VT 5742',1628,222,NULL,53,2148,0);
INSERT INTO "django_geo_db_location" VALUES(4070,NULL,'Fair Haven, VT',1629,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4071,NULL,'Fair Haven, VT 5743',1629,222,NULL,53,2149,0);
INSERT INTO "django_geo_db_location" VALUES(4072,NULL,'Florence, VT',1630,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4073,NULL,'Florence, VT 5744',1630,222,NULL,53,2150,0);
INSERT INTO "django_geo_db_location" VALUES(4074,NULL,'Forest Dale, VT',1631,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4075,NULL,'Forest Dale, VT 5745',1631,222,NULL,53,2151,0);
INSERT INTO "django_geo_db_location" VALUES(4076,NULL,'Gaysville, VT',1632,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4077,NULL,'Gaysville, VT 5746',1632,222,NULL,53,2152,0);
INSERT INTO "django_geo_db_location" VALUES(4078,NULL,'Granville, VT',1633,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4079,NULL,'Granville, VT 5747',1633,222,NULL,53,2153,0);
INSERT INTO "django_geo_db_location" VALUES(4080,NULL,'Hancock, VT',1634,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4081,NULL,'Hancock, VT 5748',1634,222,NULL,53,2154,0);
INSERT INTO "django_geo_db_location" VALUES(4082,NULL,'Hydeville, VT',1635,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4083,NULL,'Hydeville, VT 5750',1635,222,NULL,53,2155,0);
INSERT INTO "django_geo_db_location" VALUES(4084,NULL,'Killington, VT',1636,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4085,NULL,'Killington, VT 5751',1636,222,NULL,53,2156,0);
INSERT INTO "django_geo_db_location" VALUES(4086,NULL,'Poultney, VT',1637,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4087,NULL,'Poultney, VT 5752',1637,222,NULL,53,2157,0);
INSERT INTO "django_geo_db_location" VALUES(4088,NULL,'Middlebury, VT',1638,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4089,NULL,'Middlebury, VT 5753',1638,222,NULL,53,2158,0);
INSERT INTO "django_geo_db_location" VALUES(4090,NULL,'Middletown Springs, VT',1639,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4091,NULL,'Middletown Springs, VT 5757',1639,222,NULL,53,2159,0);
INSERT INTO "django_geo_db_location" VALUES(4092,NULL,'Mount Holly, VT',1640,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4093,NULL,'Mount Holly, VT 5758',1640,222,NULL,53,2160,0);
INSERT INTO "django_geo_db_location" VALUES(4094,NULL,'North Clarendon, VT',1641,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4095,NULL,'North Clarendon, VT 5759',1641,222,NULL,53,2161,0);
INSERT INTO "django_geo_db_location" VALUES(4096,NULL,'Orwell, VT',1642,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4097,NULL,'Orwell, VT 5760',1642,222,NULL,53,2162,0);
INSERT INTO "django_geo_db_location" VALUES(4098,NULL,'Pawlet, VT',1643,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4099,NULL,'Pawlet, VT 5761',1643,222,NULL,53,2163,0);
INSERT INTO "django_geo_db_location" VALUES(4100,NULL,'Pittsfield, VT',1644,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4101,NULL,'Pittsfield, VT 5762',1644,222,NULL,53,2164,0);
INSERT INTO "django_geo_db_location" VALUES(4102,NULL,'Pittsford, VT',1645,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4103,NULL,'Pittsford, VT 5763',1645,222,NULL,53,2165,0);
INSERT INTO "django_geo_db_location" VALUES(4104,NULL,'Poultney, VT 5764',1637,222,NULL,53,2166,0);
INSERT INTO "django_geo_db_location" VALUES(4105,NULL,'Proctor, VT',1646,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4106,NULL,'Proctor, VT 5765',1646,222,NULL,53,2167,0);
INSERT INTO "django_geo_db_location" VALUES(4107,NULL,'Ripton, VT',1647,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4108,NULL,'Ripton, VT 5766',1647,222,NULL,53,2168,0);
INSERT INTO "django_geo_db_location" VALUES(4109,NULL,'Rochester, VT',1648,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4110,NULL,'Rochester, VT 5767',1648,222,NULL,53,2169,0);
INSERT INTO "django_geo_db_location" VALUES(4111,NULL,'Rupert, VT',1649,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4112,NULL,'Rupert, VT 5768',1649,222,NULL,53,2170,0);
INSERT INTO "django_geo_db_location" VALUES(4113,NULL,'Salisbury, VT',1650,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4114,NULL,'Salisbury, VT 5769',1650,222,NULL,53,2171,0);
INSERT INTO "django_geo_db_location" VALUES(4115,NULL,'Shoreham, VT',1651,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4116,NULL,'Shoreham, VT 5770',1651,222,NULL,53,2172,0);
INSERT INTO "django_geo_db_location" VALUES(4117,NULL,'Stockbridge, VT',1652,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4118,NULL,'Stockbridge, VT 5772',1652,222,NULL,53,2173,0);
INSERT INTO "django_geo_db_location" VALUES(4119,NULL,'Wallingford, VT',1653,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4120,NULL,'Wallingford, VT 5773',1653,222,NULL,53,2174,0);
INSERT INTO "django_geo_db_location" VALUES(4121,NULL,'Wells, VT',1654,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4122,NULL,'Wells, VT 5774',1654,222,NULL,53,2175,0);
INSERT INTO "django_geo_db_location" VALUES(4123,NULL,'West Pawlet, VT',1655,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4124,NULL,'West Pawlet, VT 5775',1655,222,NULL,53,2176,0);
INSERT INTO "django_geo_db_location" VALUES(4125,NULL,'West Rupert, VT',1656,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4126,NULL,'West Rupert, VT 5776',1656,222,NULL,53,2177,0);
INSERT INTO "django_geo_db_location" VALUES(4127,NULL,'West Rutland, VT',1657,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4128,NULL,'West Rutland, VT 5777',1657,222,NULL,53,2178,0);
INSERT INTO "django_geo_db_location" VALUES(4129,NULL,'Whiting, VT',1658,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4130,NULL,'Whiting, VT 5778',1658,222,NULL,53,2179,0);
INSERT INTO "django_geo_db_location" VALUES(4131,NULL,'White River Junction, VT 5801',1419,222,NULL,53,2180,0);
INSERT INTO "django_geo_db_location" VALUES(4132,NULL,'Saint Johnsbury, VT',1659,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4133,NULL,'Saint Johnsbury, VT 5819',1659,222,NULL,53,2181,0);
INSERT INTO "django_geo_db_location" VALUES(4134,NULL,'Albany, VT',1660,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4135,NULL,'Albany, VT 5820',1660,222,NULL,53,2182,0);
INSERT INTO "django_geo_db_location" VALUES(4136,NULL,'Barnet, VT 5821',1491,222,NULL,53,2183,0);
INSERT INTO "django_geo_db_location" VALUES(4137,NULL,'Barton, VT',1661,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4138,NULL,'Barton, VT 5822',1661,222,NULL,53,2184,0);
INSERT INTO "django_geo_db_location" VALUES(4139,NULL,'Beebe Plain, VT',1662,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4140,NULL,'Beebe Plain, VT 5823',1662,222,NULL,53,2185,0);
INSERT INTO "django_geo_db_location" VALUES(4141,NULL,'Concord, VT',1663,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4142,NULL,'Concord, VT 5824',1663,222,NULL,53,2186,0);
INSERT INTO "django_geo_db_location" VALUES(4143,NULL,'Coventry, VT',1664,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4144,NULL,'Coventry, VT 5825',1664,222,NULL,53,2187,0);
INSERT INTO "django_geo_db_location" VALUES(4145,NULL,'Craftsbury, VT 5826',1504,222,NULL,53,2188,0);
INSERT INTO "django_geo_db_location" VALUES(4146,NULL,'Craftsbury Common, VT',1665,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4147,NULL,'Craftsbury Common, VT 5827',1665,222,NULL,53,2189,0);
INSERT INTO "django_geo_db_location" VALUES(4148,NULL,'Danville, VT',1666,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4149,NULL,'Danville, VT 5828',1666,222,NULL,53,2190,0);
INSERT INTO "django_geo_db_location" VALUES(4150,NULL,'Derby, VT',1667,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4151,NULL,'Derby, VT 5829',1667,222,NULL,53,2191,0);
INSERT INTO "django_geo_db_location" VALUES(4152,NULL,'Derby Line, VT',1668,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4153,NULL,'Derby Line, VT 5830',1668,222,NULL,53,2192,0);
INSERT INTO "django_geo_db_location" VALUES(4154,NULL,'East Burke, VT',1669,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4155,NULL,'East Burke, VT 5832',1669,222,NULL,53,2193,0);
INSERT INTO "django_geo_db_location" VALUES(4156,NULL,'East Charleston, VT',1670,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4157,NULL,'East Charleston, VT 5833',1670,222,NULL,53,2194,0);
INSERT INTO "django_geo_db_location" VALUES(4158,NULL,'East Hardwick, VT',1671,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4159,NULL,'East Hardwick, VT 5836',1671,222,NULL,53,2195,0);
INSERT INTO "django_geo_db_location" VALUES(4160,NULL,'East Haven, VT',1672,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4161,NULL,'East Haven, VT 5837',1672,222,NULL,53,2196,0);
INSERT INTO "django_geo_db_location" VALUES(4162,NULL,'East Saint Johnsbury, VT',1673,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4163,NULL,'East Saint Johnsbury, VT 5838',1673,222,NULL,53,2197,0);
INSERT INTO "django_geo_db_location" VALUES(4164,NULL,'Glover, VT',1674,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4165,NULL,'Glover, VT 5839',1674,222,NULL,53,2198,0);
INSERT INTO "django_geo_db_location" VALUES(4166,NULL,'Granby, VT',1675,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4167,NULL,'Granby, VT 5840',1675,222,NULL,53,2199,0);
INSERT INTO "django_geo_db_location" VALUES(4168,NULL,'Greensboro, VT',1676,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4169,NULL,'Greensboro, VT 5841',1676,222,NULL,53,2200,0);
INSERT INTO "django_geo_db_location" VALUES(4170,NULL,'Greensboro Bend, VT',1677,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4171,NULL,'Greensboro Bend, VT 5842',1677,222,NULL,53,2201,0);
INSERT INTO "django_geo_db_location" VALUES(4172,NULL,'Hardwick, VT',1678,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4173,NULL,'Hardwick, VT 5843',1678,222,NULL,53,2202,0);
INSERT INTO "django_geo_db_location" VALUES(4174,NULL,'Irasburg, VT',1679,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4175,NULL,'Irasburg, VT 5845',1679,222,NULL,53,2203,0);
INSERT INTO "django_geo_db_location" VALUES(4176,NULL,'Island Pond, VT',1680,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4177,NULL,'Island Pond, VT 5846',1680,222,NULL,53,2204,0);
INSERT INTO "django_geo_db_location" VALUES(4178,NULL,'Lowell, VT',1681,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4179,NULL,'Lowell, VT 5847',1681,222,NULL,53,2205,0);
INSERT INTO "django_geo_db_location" VALUES(4180,NULL,'Lower Waterford, VT',1682,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4181,NULL,'Lower Waterford, VT 5848',1682,222,NULL,53,2206,0);
INSERT INTO "django_geo_db_location" VALUES(4182,NULL,'Lyndon, VT',1683,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4183,NULL,'Lyndon, VT 5849',1683,222,NULL,53,2207,0);
INSERT INTO "django_geo_db_location" VALUES(4184,NULL,'Lyndon Center, VT',1684,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4185,NULL,'Lyndon Center, VT 5850',1684,222,NULL,53,2208,0);
INSERT INTO "django_geo_db_location" VALUES(4186,NULL,'Lyndonville, VT',1685,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4187,NULL,'Lyndonville, VT 5851',1685,222,NULL,53,2209,0);
INSERT INTO "django_geo_db_location" VALUES(4188,NULL,'Newport, VT',1686,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4189,NULL,'Newport, VT 5852',1686,222,NULL,53,2210,0);
INSERT INTO "django_geo_db_location" VALUES(4190,NULL,'Morgan, VT',1687,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4191,NULL,'Morgan, VT 5853',1687,222,NULL,53,2211,0);
INSERT INTO "django_geo_db_location" VALUES(4192,NULL,'Newport, VT 5855',1686,222,NULL,53,2212,0);
INSERT INTO "django_geo_db_location" VALUES(4193,NULL,'Newport Center, VT',1688,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4194,NULL,'Newport Center, VT 5857',1688,222,NULL,53,2213,0);
INSERT INTO "django_geo_db_location" VALUES(4195,NULL,'North Concord, VT',1689,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4196,NULL,'North Concord, VT 5858',1689,222,NULL,53,2214,0);
INSERT INTO "django_geo_db_location" VALUES(4197,NULL,'North Troy, VT',1690,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4198,NULL,'North Troy, VT 5859',1690,222,NULL,53,2215,0);
INSERT INTO "django_geo_db_location" VALUES(4199,NULL,'Orleans, VT',1691,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4200,NULL,'Orleans, VT 5860',1691,222,NULL,53,2216,0);
INSERT INTO "django_geo_db_location" VALUES(4201,NULL,'Passumpsic, VT',1692,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4202,NULL,'Passumpsic, VT 5861',1692,222,NULL,53,2217,0);
INSERT INTO "django_geo_db_location" VALUES(4203,NULL,'Peacham, VT',1693,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4204,NULL,'Peacham, VT 5862',1693,222,NULL,53,2218,0);
INSERT INTO "django_geo_db_location" VALUES(4205,NULL,'Saint Johnsbury Center, VT',1694,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4206,NULL,'Saint Johnsbury Center, VT 5863',1694,222,NULL,53,2219,0);
INSERT INTO "django_geo_db_location" VALUES(4207,NULL,'Stannard, VT',1695,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4208,NULL,'Stannard, VT 5864',1695,222,NULL,53,2220,0);
INSERT INTO "django_geo_db_location" VALUES(4209,NULL,'Sheffield, VT',1696,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4210,NULL,'Sheffield, VT 5866',1696,222,NULL,53,2221,0);
INSERT INTO "django_geo_db_location" VALUES(4211,NULL,'Sutton, VT 5867',1503,222,NULL,53,2222,0);
INSERT INTO "django_geo_db_location" VALUES(4212,NULL,'Troy, VT',1697,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4213,NULL,'Troy, VT 5868',1697,222,NULL,53,2223,0);
INSERT INTO "django_geo_db_location" VALUES(4214,NULL,'West Burke, VT',1698,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4215,NULL,'West Burke, VT 5871',1698,222,NULL,53,2224,0);
INSERT INTO "django_geo_db_location" VALUES(4216,NULL,'West Charleston, VT',1699,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4217,NULL,'West Charleston, VT 5872',1699,222,NULL,53,2225,0);
INSERT INTO "django_geo_db_location" VALUES(4218,NULL,'West Danville, VT',1700,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4219,NULL,'West Danville, VT 5873',1700,222,NULL,53,2226,0);
INSERT INTO "django_geo_db_location" VALUES(4220,NULL,'Westfield, VT',1701,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4221,NULL,'Westfield, VT 5874',1701,222,NULL,53,2227,0);
INSERT INTO "django_geo_db_location" VALUES(4222,NULL,'West Glover, VT',1702,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4223,NULL,'West Glover, VT 5875',1702,222,NULL,53,2228,0);
INSERT INTO "django_geo_db_location" VALUES(4224,NULL,'Derby, VT 5892',1667,222,NULL,53,2229,0);
INSERT INTO "django_geo_db_location" VALUES(4225,NULL,'Averill, VT',1703,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4226,NULL,'Averill, VT 5901',1703,222,NULL,53,2230,0);
INSERT INTO "django_geo_db_location" VALUES(4227,NULL,'Beecher Falls, VT',1704,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4228,NULL,'Beecher Falls, VT 5902',1704,222,NULL,53,2231,0);
INSERT INTO "django_geo_db_location" VALUES(4229,NULL,'Canaan, VT',1705,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4230,NULL,'Canaan, VT 5903',1705,222,NULL,53,2232,0);
INSERT INTO "django_geo_db_location" VALUES(4231,NULL,'Gilman, VT',1706,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4232,NULL,'Gilman, VT 5904',1706,222,NULL,53,2233,0);
INSERT INTO "django_geo_db_location" VALUES(4233,NULL,'Guildhall, VT',1707,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4234,NULL,'Guildhall, VT 5905',1707,222,NULL,53,2234,0);
INSERT INTO "django_geo_db_location" VALUES(4235,NULL,'Lunenburg, VT',1708,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4236,NULL,'Lunenburg, VT 5906',1708,222,NULL,53,2235,0);
INSERT INTO "django_geo_db_location" VALUES(4237,NULL,'Norton, VT',1709,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4238,NULL,'Norton, VT 5907',1709,222,NULL,53,2236,0);
INSERT INTO "django_geo_db_location" VALUES(4239,NULL,'Derby Center, VT',1710,222,NULL,53,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4240,NULL,'Derby Center, VT 5928',1710,222,NULL,53,2237,0);
INSERT INTO "django_geo_db_location" VALUES(4241,NULL,'Mount Holly, VT 5958',1640,222,NULL,53,2238,0);
INSERT INTO "django_geo_db_location" VALUES(4242,NULL,'Avon, CT',1711,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4243,NULL,'Avon, CT 6001',1711,222,NULL,8,2239,0);
INSERT INTO "django_geo_db_location" VALUES(4244,NULL,'Bloomfield, CT',1712,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4245,NULL,'Bloomfield, CT 6002',1712,222,NULL,8,2240,0);
INSERT INTO "django_geo_db_location" VALUES(4246,NULL,'Windsor, CT',1713,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4247,NULL,'Windsor, CT 6006',1713,222,NULL,8,2241,0);
INSERT INTO "django_geo_db_location" VALUES(4248,NULL,'Bristol, CT',1714,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4249,NULL,'Bristol, CT 6010',1714,222,NULL,8,2242,0);
INSERT INTO "django_geo_db_location" VALUES(4250,NULL,'Bristol, CT 6011',1714,222,NULL,8,2243,0);
INSERT INTO "django_geo_db_location" VALUES(4251,NULL,'Burlington, CT',1715,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4252,NULL,'Burlington, CT 6013',1715,222,NULL,8,2244,0);
INSERT INTO "django_geo_db_location" VALUES(4253,NULL,'Broad Brook, CT',1716,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4254,NULL,'Broad Brook, CT 6016',1716,222,NULL,8,2245,0);
INSERT INTO "django_geo_db_location" VALUES(4255,NULL,'Canaan, CT',1717,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4256,NULL,'Canaan, CT 6018',1717,222,NULL,8,2246,0);
INSERT INTO "django_geo_db_location" VALUES(4257,NULL,'Canton, CT',1718,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4258,NULL,'Canton, CT 6019',1718,222,NULL,8,2247,0);
INSERT INTO "django_geo_db_location" VALUES(4259,NULL,'Canton Center, CT',1719,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4260,NULL,'Canton Center, CT 6020',1719,222,NULL,8,2248,0);
INSERT INTO "django_geo_db_location" VALUES(4261,NULL,'Colebrook, CT',1720,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4262,NULL,'Colebrook, CT 6021',1720,222,NULL,8,2249,0);
INSERT INTO "django_geo_db_location" VALUES(4263,NULL,'Collinsville, CT',1721,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4264,NULL,'Collinsville, CT 6022',1721,222,NULL,8,2250,0);
INSERT INTO "django_geo_db_location" VALUES(4265,NULL,'East Berlin, CT',1722,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4266,NULL,'East Berlin, CT 6023',1722,222,NULL,8,2251,0);
INSERT INTO "django_geo_db_location" VALUES(4267,NULL,'East Canaan, CT',1723,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4268,NULL,'East Canaan, CT 6024',1723,222,NULL,8,2252,0);
INSERT INTO "django_geo_db_location" VALUES(4269,NULL,'East Glastonbury, CT',1724,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4270,NULL,'East Glastonbury, CT 6025',1724,222,NULL,8,2253,0);
INSERT INTO "django_geo_db_location" VALUES(4271,NULL,'East Granby, CT',1725,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4272,NULL,'East Granby, CT 6026',1725,222,NULL,8,2254,0);
INSERT INTO "django_geo_db_location" VALUES(4273,NULL,'East Hartland, CT',1726,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4274,NULL,'East Hartland, CT 6027',1726,222,NULL,8,2255,0);
INSERT INTO "django_geo_db_location" VALUES(4275,NULL,'East Windsor Hill, CT',1727,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4276,NULL,'East Windsor Hill, CT 6028',1727,222,NULL,8,2256,0);
INSERT INTO "django_geo_db_location" VALUES(4277,NULL,'Ellington, CT',1728,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4278,NULL,'Ellington, CT 6029',1728,222,NULL,8,2257,0);
INSERT INTO "django_geo_db_location" VALUES(4279,NULL,'Farmington, CT',1729,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4280,NULL,'Farmington, CT 6030',1729,222,NULL,8,2258,0);
INSERT INTO "django_geo_db_location" VALUES(4281,NULL,'Falls Village, CT',1730,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4282,NULL,'Falls Village, CT 6031',1730,222,NULL,8,2259,0);
INSERT INTO "django_geo_db_location" VALUES(4283,NULL,'Farmington, CT 6032',1729,222,NULL,8,2260,0);
INSERT INTO "django_geo_db_location" VALUES(4284,NULL,'Glastonbury, CT',1731,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4285,NULL,'Glastonbury, CT 6033',1731,222,NULL,8,2261,0);
INSERT INTO "django_geo_db_location" VALUES(4286,NULL,'Farmington, CT 6034',1729,222,NULL,8,2262,0);
INSERT INTO "django_geo_db_location" VALUES(4287,NULL,'Granby, CT',1732,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4288,NULL,'Granby, CT 6035',1732,222,NULL,8,2263,0);
INSERT INTO "django_geo_db_location" VALUES(4289,NULL,'Kensington, CT',1733,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4290,NULL,'Kensington, CT 6037',1733,222,NULL,8,2264,0);
INSERT INTO "django_geo_db_location" VALUES(4291,NULL,'Lakeville, CT',1734,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4292,NULL,'Lakeville, CT 6039',1734,222,NULL,8,2265,0);
INSERT INTO "django_geo_db_location" VALUES(4293,NULL,'Manchester, CT',1735,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4294,NULL,'Manchester, CT 6040',1735,222,NULL,8,2266,0);
INSERT INTO "django_geo_db_location" VALUES(4295,NULL,'Manchester, CT 6041',1735,222,NULL,8,2267,0);
INSERT INTO "django_geo_db_location" VALUES(4296,NULL,'Bolton, CT',1736,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4297,NULL,'Bolton, CT 6043',1736,222,NULL,8,2268,0);
INSERT INTO "django_geo_db_location" VALUES(4298,NULL,'Manchester, CT 6045',1735,222,NULL,8,2269,0);
INSERT INTO "django_geo_db_location" VALUES(4299,NULL,'Melrose, CT',1737,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4300,NULL,'Melrose, CT 6049',1737,222,NULL,8,2270,0);
INSERT INTO "django_geo_db_location" VALUES(4301,NULL,'New Britain, CT',1738,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4302,NULL,'New Britain, CT 6050',1738,222,NULL,8,2271,0);
INSERT INTO "django_geo_db_location" VALUES(4303,NULL,'New Britain, CT 6051',1738,222,NULL,8,2272,0);
INSERT INTO "django_geo_db_location" VALUES(4304,NULL,'New Britain, CT 6052',1738,222,NULL,8,2273,0);
INSERT INTO "django_geo_db_location" VALUES(4305,NULL,'New Britain, CT 6053',1738,222,NULL,8,2274,0);
INSERT INTO "django_geo_db_location" VALUES(4306,NULL,'New Hartford, CT',1739,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4307,NULL,'New Hartford, CT 6057',1739,222,NULL,8,2275,0);
INSERT INTO "django_geo_db_location" VALUES(4308,NULL,'Norfolk, CT',1740,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4309,NULL,'Norfolk, CT 6058',1740,222,NULL,8,2276,0);
INSERT INTO "django_geo_db_location" VALUES(4310,NULL,'North Canton, CT',1741,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4311,NULL,'North Canton, CT 6059',1741,222,NULL,8,2277,0);
INSERT INTO "django_geo_db_location" VALUES(4312,NULL,'North Granby, CT',1742,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4313,NULL,'North Granby, CT 6060',1742,222,NULL,8,2278,0);
INSERT INTO "django_geo_db_location" VALUES(4314,NULL,'Pine Meadow, CT',1743,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4315,NULL,'Pine Meadow, CT 6061',1743,222,NULL,8,2279,0);
INSERT INTO "django_geo_db_location" VALUES(4316,NULL,'Plainville, CT',1744,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4317,NULL,'Plainville, CT 6062',1744,222,NULL,8,2280,0);
INSERT INTO "django_geo_db_location" VALUES(4318,NULL,'Pleasant Valley, CT',1745,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4319,NULL,'Pleasant Valley, CT 6063',1745,222,NULL,8,2281,0);
INSERT INTO "django_geo_db_location" VALUES(4320,NULL,'Poquonock, CT',1746,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4321,NULL,'Poquonock, CT 6064',1746,222,NULL,8,2282,0);
INSERT INTO "django_geo_db_location" VALUES(4322,NULL,'Riverton, CT',1747,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4323,NULL,'Riverton, CT 6065',1747,222,NULL,8,2283,0);
INSERT INTO "django_geo_db_location" VALUES(4324,NULL,'Vernon Rockville, CT',1748,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4325,NULL,'Vernon Rockville, CT 6066',1748,222,NULL,8,2284,0);
INSERT INTO "django_geo_db_location" VALUES(4326,NULL,'Rocky Hill, CT',1749,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4327,NULL,'Rocky Hill, CT 6067',1749,222,NULL,8,2285,0);
INSERT INTO "django_geo_db_location" VALUES(4328,NULL,'Salisbury, CT',1750,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4329,NULL,'Salisbury, CT 6068',1750,222,NULL,8,2286,0);
INSERT INTO "django_geo_db_location" VALUES(4330,NULL,'Sharon, CT',1751,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4331,NULL,'Sharon, CT 6069',1751,222,NULL,8,2287,0);
INSERT INTO "django_geo_db_location" VALUES(4332,NULL,'Simsbury, CT',1752,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4333,NULL,'Simsbury, CT 6070',1752,222,NULL,8,2288,0);
INSERT INTO "django_geo_db_location" VALUES(4334,NULL,'Somers, CT',1753,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4335,NULL,'Somers, CT 6071',1753,222,NULL,8,2289,0);
INSERT INTO "django_geo_db_location" VALUES(4336,NULL,'Somersville, CT',1754,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4337,NULL,'Somersville, CT 6072',1754,222,NULL,8,2290,0);
INSERT INTO "django_geo_db_location" VALUES(4338,NULL,'South Glastonbury, CT',1755,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4339,NULL,'South Glastonbury, CT 6073',1755,222,NULL,8,2291,0);
INSERT INTO "django_geo_db_location" VALUES(4340,NULL,'South Windsor, CT',1756,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4341,NULL,'South Windsor, CT 6074',1756,222,NULL,8,2292,0);
INSERT INTO "django_geo_db_location" VALUES(4342,NULL,'Stafford, CT',1757,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4343,NULL,'Stafford, CT 6075',1757,222,NULL,8,2293,0);
INSERT INTO "django_geo_db_location" VALUES(4344,NULL,'Stafford Springs, CT',1758,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4345,NULL,'Stafford Springs, CT 6076',1758,222,NULL,8,2294,0);
INSERT INTO "django_geo_db_location" VALUES(4346,NULL,'Staffordville, CT',1759,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4347,NULL,'Staffordville, CT 6077',1759,222,NULL,8,2295,0);
INSERT INTO "django_geo_db_location" VALUES(4348,NULL,'Suffield, CT',1760,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4349,NULL,'Suffield, CT 6078',1760,222,NULL,8,2296,0);
INSERT INTO "django_geo_db_location" VALUES(4350,NULL,'Taconic, CT',1761,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4351,NULL,'Taconic, CT 6079',1761,222,NULL,8,2297,0);
INSERT INTO "django_geo_db_location" VALUES(4352,NULL,'Suffield, CT 6080',1760,222,NULL,8,2298,0);
INSERT INTO "django_geo_db_location" VALUES(4353,NULL,'Tariffville, CT',1762,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4354,NULL,'Tariffville, CT 6081',1762,222,NULL,8,2299,0);
INSERT INTO "django_geo_db_location" VALUES(4355,NULL,'Enfield, CT',1763,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4356,NULL,'Enfield, CT 6082',1763,222,NULL,8,2300,0);
INSERT INTO "django_geo_db_location" VALUES(4357,NULL,'Enfield, CT 6083',1763,222,NULL,8,2301,0);
INSERT INTO "django_geo_db_location" VALUES(4358,NULL,'Tolland, CT',1764,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4359,NULL,'Tolland, CT 6084',1764,222,NULL,8,2302,0);
INSERT INTO "django_geo_db_location" VALUES(4360,NULL,'Unionville, CT',1765,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4361,NULL,'Unionville, CT 6085',1765,222,NULL,8,2303,0);
INSERT INTO "django_geo_db_location" VALUES(4362,NULL,'Unionville, CT 6087',1765,222,NULL,8,2304,0);
INSERT INTO "django_geo_db_location" VALUES(4363,NULL,'East Windsor, CT',1766,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4364,NULL,'East Windsor, CT 6088',1766,222,NULL,8,2305,0);
INSERT INTO "django_geo_db_location" VALUES(4365,NULL,'Weatogue, CT',1767,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4366,NULL,'Weatogue, CT 6089',1767,222,NULL,8,2306,0);
INSERT INTO "django_geo_db_location" VALUES(4367,NULL,'West Granby, CT',1768,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4368,NULL,'West Granby, CT 6090',1768,222,NULL,8,2307,0);
INSERT INTO "django_geo_db_location" VALUES(4369,NULL,'West Hartland, CT',1769,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4370,NULL,'West Hartland, CT 6091',1769,222,NULL,8,2308,0);
INSERT INTO "django_geo_db_location" VALUES(4371,NULL,'West Simsbury, CT',1770,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4372,NULL,'West Simsbury, CT 6092',1770,222,NULL,8,2309,0);
INSERT INTO "django_geo_db_location" VALUES(4373,NULL,'West Suffield, CT',1771,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4374,NULL,'West Suffield, CT 6093',1771,222,NULL,8,2310,0);
INSERT INTO "django_geo_db_location" VALUES(4375,NULL,'Winchester Center, CT',1772,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4376,NULL,'Winchester Center, CT 6094',1772,222,NULL,8,2311,0);
INSERT INTO "django_geo_db_location" VALUES(4377,NULL,'Windsor, CT 6095',1713,222,NULL,8,2312,0);
INSERT INTO "django_geo_db_location" VALUES(4378,NULL,'Windsor Locks, CT',1773,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4379,NULL,'Windsor Locks, CT 6096',1773,222,NULL,8,2313,0);
INSERT INTO "django_geo_db_location" VALUES(4380,NULL,'Winsted, CT',1774,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4381,NULL,'Winsted, CT 6098',1774,222,NULL,8,2314,0);
INSERT INTO "django_geo_db_location" VALUES(4382,NULL,'Hartford, CT',1775,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4383,NULL,'Hartford, CT 6101',1775,222,NULL,8,2315,0);
INSERT INTO "django_geo_db_location" VALUES(4384,NULL,'Hartford, CT 6102',1775,222,NULL,8,2316,0);
INSERT INTO "django_geo_db_location" VALUES(4385,NULL,'Hartford, CT 6103',1775,222,NULL,8,2317,0);
INSERT INTO "django_geo_db_location" VALUES(4386,NULL,'Hartford, CT 6104',1775,222,NULL,8,2318,0);
INSERT INTO "django_geo_db_location" VALUES(4387,NULL,'Hartford, CT 6105',1775,222,NULL,8,2319,0);
INSERT INTO "django_geo_db_location" VALUES(4388,NULL,'Hartford, CT 6106',1775,222,NULL,8,2320,0);
INSERT INTO "django_geo_db_location" VALUES(4389,NULL,'W Hartford, CT',1776,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4390,NULL,'W Hartford, CT 6107',1776,222,NULL,8,2321,0);
INSERT INTO "django_geo_db_location" VALUES(4391,NULL,'East Hartford, CT',1777,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4392,NULL,'East Hartford, CT 6108',1777,222,NULL,8,2322,0);
INSERT INTO "django_geo_db_location" VALUES(4393,NULL,'Wethersfield, CT',1778,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4394,NULL,'Wethersfield, CT 6109',1778,222,NULL,8,2323,0);
INSERT INTO "django_geo_db_location" VALUES(4395,NULL,'W Hartford, CT 6110',1776,222,NULL,8,2324,0);
INSERT INTO "django_geo_db_location" VALUES(4396,NULL,'Newington, CT',1779,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4397,NULL,'Newington, CT 6111',1779,222,NULL,8,2325,0);
INSERT INTO "django_geo_db_location" VALUES(4398,NULL,'Hartford, CT 6112',1775,222,NULL,8,2326,0);
INSERT INTO "django_geo_db_location" VALUES(4399,NULL,'Hartford, CT 6114',1775,222,NULL,8,2327,0);
INSERT INTO "django_geo_db_location" VALUES(4400,NULL,'Hartford, CT 6115',1775,222,NULL,8,2328,0);
INSERT INTO "django_geo_db_location" VALUES(4401,NULL,'W Hartford, CT 6117',1776,222,NULL,8,2329,0);
INSERT INTO "django_geo_db_location" VALUES(4402,NULL,'East Hartford, CT 6118',1777,222,NULL,8,2330,0);
INSERT INTO "django_geo_db_location" VALUES(4403,NULL,'W Hartford, CT 6119',1776,222,NULL,8,2331,0);
INSERT INTO "django_geo_db_location" VALUES(4404,NULL,'Hartford, CT 6120',1775,222,NULL,8,2332,0);
INSERT INTO "django_geo_db_location" VALUES(4405,NULL,'Hartford, CT 6123',1775,222,NULL,8,2333,0);
INSERT INTO "django_geo_db_location" VALUES(4406,NULL,'Hartford, CT 6126',1775,222,NULL,8,2334,0);
INSERT INTO "django_geo_db_location" VALUES(4407,NULL,'W Hartford, CT 6127',1776,222,NULL,8,2335,0);
INSERT INTO "django_geo_db_location" VALUES(4408,NULL,'East Hartford, CT 6128',1777,222,NULL,8,2336,0);
INSERT INTO "django_geo_db_location" VALUES(4409,NULL,'Wethersfield, CT 6129',1778,222,NULL,8,2337,0);
INSERT INTO "django_geo_db_location" VALUES(4410,NULL,'Newington, CT 6131',1779,222,NULL,8,2338,0);
INSERT INTO "django_geo_db_location" VALUES(4411,NULL,'Hartford, CT 6132',1775,222,NULL,8,2339,0);
INSERT INTO "django_geo_db_location" VALUES(4412,NULL,'W Hartford, CT 6133',1776,222,NULL,8,2340,0);
INSERT INTO "django_geo_db_location" VALUES(4413,NULL,'Hartford, CT 6134',1775,222,NULL,8,2341,0);
INSERT INTO "django_geo_db_location" VALUES(4414,NULL,'W Hartford, CT 6137',1776,222,NULL,8,2342,0);
INSERT INTO "django_geo_db_location" VALUES(4415,NULL,'East Hartford, CT 6138',1777,222,NULL,8,2343,0);
INSERT INTO "django_geo_db_location" VALUES(4416,NULL,'Hartford, CT 6140',1775,222,NULL,8,2344,0);
INSERT INTO "django_geo_db_location" VALUES(4417,NULL,'Hartford, CT 6141',1775,222,NULL,8,2345,0);
INSERT INTO "django_geo_db_location" VALUES(4418,NULL,'Hartford, CT 6142',1775,222,NULL,8,2346,0);
INSERT INTO "django_geo_db_location" VALUES(4419,NULL,'Hartford, CT 6143',1775,222,NULL,8,2347,0);
INSERT INTO "django_geo_db_location" VALUES(4420,NULL,'Hartford, CT 6144',1775,222,NULL,8,2348,0);
INSERT INTO "django_geo_db_location" VALUES(4421,NULL,'Hartford, CT 6145',1775,222,NULL,8,2349,0);
INSERT INTO "django_geo_db_location" VALUES(4422,NULL,'Hartford, CT 6146',1775,222,NULL,8,2350,0);
INSERT INTO "django_geo_db_location" VALUES(4423,NULL,'Hartford, CT 6147',1775,222,NULL,8,2351,0);
INSERT INTO "django_geo_db_location" VALUES(4424,NULL,'Hartford, CT 6150',1775,222,NULL,8,2352,0);
INSERT INTO "django_geo_db_location" VALUES(4425,NULL,'Hartford, CT 6151',1775,222,NULL,8,2353,0);
INSERT INTO "django_geo_db_location" VALUES(4426,NULL,'Hartford, CT 6152',1775,222,NULL,8,2354,0);
INSERT INTO "django_geo_db_location" VALUES(4427,NULL,'Hartford, CT 6153',1775,222,NULL,8,2355,0);
INSERT INTO "django_geo_db_location" VALUES(4428,NULL,'Hartford, CT 6154',1775,222,NULL,8,2356,0);
INSERT INTO "django_geo_db_location" VALUES(4429,NULL,'Hartford, CT 6155',1775,222,NULL,8,2357,0);
INSERT INTO "django_geo_db_location" VALUES(4430,NULL,'Hartford, CT 6156',1775,222,NULL,8,2358,0);
INSERT INTO "django_geo_db_location" VALUES(4431,NULL,'Hartford, CT 6160',1775,222,NULL,8,2359,0);
INSERT INTO "django_geo_db_location" VALUES(4432,NULL,'Hartford, CT 6161',1775,222,NULL,8,2360,0);
INSERT INTO "django_geo_db_location" VALUES(4433,NULL,'Hartford, CT 6167',1775,222,NULL,8,2361,0);
INSERT INTO "django_geo_db_location" VALUES(4434,NULL,'Hartford, CT 6176',1775,222,NULL,8,2362,0);
INSERT INTO "django_geo_db_location" VALUES(4435,NULL,'Hartford, CT 6180',1775,222,NULL,8,2363,0);
INSERT INTO "django_geo_db_location" VALUES(4436,NULL,'Hartford, CT 6183',1775,222,NULL,8,2364,0);
INSERT INTO "django_geo_db_location" VALUES(4437,NULL,'Hartford, CT 6199',1775,222,NULL,8,2365,0);
INSERT INTO "django_geo_db_location" VALUES(4438,NULL,'Willimantic, CT',1780,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4439,NULL,'Willimantic, CT 6226',1780,222,NULL,8,2366,0);
INSERT INTO "django_geo_db_location" VALUES(4440,NULL,'Abington, CT',1781,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4441,NULL,'Abington, CT 6230',1781,222,NULL,8,2367,0);
INSERT INTO "django_geo_db_location" VALUES(4442,NULL,'Amston, CT',1782,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4443,NULL,'Amston, CT 6231',1782,222,NULL,8,2368,0);
INSERT INTO "django_geo_db_location" VALUES(4444,NULL,'Andover, CT',1783,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4445,NULL,'Andover, CT 6232',1783,222,NULL,8,2369,0);
INSERT INTO "django_geo_db_location" VALUES(4446,NULL,'Ballouville, CT',1784,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4447,NULL,'Ballouville, CT 6233',1784,222,NULL,8,2370,0);
INSERT INTO "django_geo_db_location" VALUES(4448,NULL,'Brooklyn, CT',1785,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4449,NULL,'Brooklyn, CT 6234',1785,222,NULL,8,2371,0);
INSERT INTO "django_geo_db_location" VALUES(4450,NULL,'Chaplin, CT',1786,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4451,NULL,'Chaplin, CT 6235',1786,222,NULL,8,2372,0);
INSERT INTO "django_geo_db_location" VALUES(4452,NULL,'Columbia, CT',1787,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4453,NULL,'Columbia, CT 6237',1787,222,NULL,8,2373,0);
INSERT INTO "django_geo_db_location" VALUES(4454,NULL,'Coventry, CT',1788,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4455,NULL,'Coventry, CT 6238',1788,222,NULL,8,2374,0);
INSERT INTO "django_geo_db_location" VALUES(4456,NULL,'Danielson, CT',1789,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4457,NULL,'Danielson, CT 6239',1789,222,NULL,8,2375,0);
INSERT INTO "django_geo_db_location" VALUES(4458,NULL,'Dayville, CT',1790,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4459,NULL,'Dayville, CT 6241',1790,222,NULL,8,2376,0);
INSERT INTO "django_geo_db_location" VALUES(4460,NULL,'Eastford, CT',1791,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4461,NULL,'Eastford, CT 6242',1791,222,NULL,8,2377,0);
INSERT INTO "django_geo_db_location" VALUES(4462,NULL,'East Killingly, CT',1792,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4463,NULL,'East Killingly, CT 6243',1792,222,NULL,8,2378,0);
INSERT INTO "django_geo_db_location" VALUES(4464,NULL,'East Woodstock, CT',1793,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4465,NULL,'East Woodstock, CT 6244',1793,222,NULL,8,2379,0);
INSERT INTO "django_geo_db_location" VALUES(4466,NULL,'Fabyan, CT',1794,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4467,NULL,'Fabyan, CT 6245',1794,222,NULL,8,2380,0);
INSERT INTO "django_geo_db_location" VALUES(4468,NULL,'Grosvenor Dale, CT',1795,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4469,NULL,'Grosvenor Dale, CT 6246',1795,222,NULL,8,2381,0);
INSERT INTO "django_geo_db_location" VALUES(4470,NULL,'Hampton, CT',1796,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4471,NULL,'Hampton, CT 6247',1796,222,NULL,8,2382,0);
INSERT INTO "django_geo_db_location" VALUES(4472,NULL,'Hebron, CT',1797,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4473,NULL,'Hebron, CT 6248',1797,222,NULL,8,2383,0);
INSERT INTO "django_geo_db_location" VALUES(4474,NULL,'Lebanon, CT',1798,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4475,NULL,'Lebanon, CT 6249',1798,222,NULL,8,2384,0);
INSERT INTO "django_geo_db_location" VALUES(4476,NULL,'Mansfield Center, CT',1799,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4477,NULL,'Mansfield Center, CT 6250',1799,222,NULL,8,2385,0);
INSERT INTO "django_geo_db_location" VALUES(4478,NULL,'Mansfield Depot, CT',1800,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4479,NULL,'Mansfield Depot, CT 6251',1800,222,NULL,8,2386,0);
INSERT INTO "django_geo_db_location" VALUES(4480,NULL,'North Franklin, CT',1801,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4481,NULL,'North Franklin, CT 6254',1801,222,NULL,8,2387,0);
INSERT INTO "django_geo_db_location" VALUES(4482,NULL,'North Grosvenordale, CT',1802,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4483,NULL,'North Grosvenordale, CT 6255',1802,222,NULL,8,2388,0);
INSERT INTO "django_geo_db_location" VALUES(4484,NULL,'North Windham, CT',1803,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4485,NULL,'North Windham, CT 6256',1803,222,NULL,8,2389,0);
INSERT INTO "django_geo_db_location" VALUES(4486,NULL,'Pomfret, CT',1804,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4487,NULL,'Pomfret, CT 6258',1804,222,NULL,8,2390,0);
INSERT INTO "django_geo_db_location" VALUES(4488,NULL,'Pomfret Center, CT',1805,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4489,NULL,'Pomfret Center, CT 6259',1805,222,NULL,8,2391,0);
INSERT INTO "django_geo_db_location" VALUES(4490,NULL,'Putnam, CT',1806,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4491,NULL,'Putnam, CT 6260',1806,222,NULL,8,2392,0);
INSERT INTO "django_geo_db_location" VALUES(4492,NULL,'Quinebaug, CT',1807,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4493,NULL,'Quinebaug, CT 6262',1807,222,NULL,8,2393,0);
INSERT INTO "django_geo_db_location" VALUES(4494,NULL,'Rogers, CT',1808,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4495,NULL,'Rogers, CT 6263',1808,222,NULL,8,2394,0);
INSERT INTO "django_geo_db_location" VALUES(4496,NULL,'Scotland, CT',1809,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4497,NULL,'Scotland, CT 6264',1809,222,NULL,8,2395,0);
INSERT INTO "django_geo_db_location" VALUES(4498,NULL,'South Willington, CT',1810,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4499,NULL,'South Willington, CT 6265',1810,222,NULL,8,2396,0);
INSERT INTO "django_geo_db_location" VALUES(4500,NULL,'South Windham, CT',1811,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4501,NULL,'South Windham, CT 6266',1811,222,NULL,8,2397,0);
INSERT INTO "django_geo_db_location" VALUES(4502,NULL,'South Woodstock, CT',1812,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4503,NULL,'South Woodstock, CT 6267',1812,222,NULL,8,2398,0);
INSERT INTO "django_geo_db_location" VALUES(4504,NULL,'Storrs Mansfield, CT',1813,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4505,NULL,'Storrs Mansfield, CT 6268',1813,222,NULL,8,2399,0);
INSERT INTO "django_geo_db_location" VALUES(4506,NULL,'Storrs Mansfield, CT 6269',1813,222,NULL,8,2400,0);
INSERT INTO "django_geo_db_location" VALUES(4507,NULL,'Thompson, CT',1814,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4508,NULL,'Thompson, CT 6277',1814,222,NULL,8,2401,0);
INSERT INTO "django_geo_db_location" VALUES(4509,NULL,'Ashford, CT',1815,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4510,NULL,'Ashford, CT 6278',1815,222,NULL,8,2402,0);
INSERT INTO "django_geo_db_location" VALUES(4511,NULL,'Willington, CT',1816,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4512,NULL,'Willington, CT 6279',1816,222,NULL,8,2403,0);
INSERT INTO "django_geo_db_location" VALUES(4513,NULL,'Windham, CT',1817,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4514,NULL,'Windham, CT 6280',1817,222,NULL,8,2404,0);
INSERT INTO "django_geo_db_location" VALUES(4515,NULL,'Woodstock, CT',1818,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4516,NULL,'Woodstock, CT 6281',1818,222,NULL,8,2405,0);
INSERT INTO "django_geo_db_location" VALUES(4517,NULL,'Woodstock Valley, CT',1819,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4518,NULL,'Woodstock Valley, CT 6282',1819,222,NULL,8,2406,0);
INSERT INTO "django_geo_db_location" VALUES(4519,NULL,'New London, CT',1820,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4520,NULL,'New London, CT 6320',1820,222,NULL,8,2407,0);
INSERT INTO "django_geo_db_location" VALUES(4521,NULL,'Baltic, CT',1821,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4522,NULL,'Baltic, CT 6330',1821,222,NULL,8,2408,0);
INSERT INTO "django_geo_db_location" VALUES(4523,NULL,'Canterbury, CT',1822,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4524,NULL,'Canterbury, CT 6331',1822,222,NULL,8,2409,0);
INSERT INTO "django_geo_db_location" VALUES(4525,NULL,'Central Village, CT',1823,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4526,NULL,'Central Village, CT 6332',1823,222,NULL,8,2410,0);
INSERT INTO "django_geo_db_location" VALUES(4527,NULL,'East Lyme, CT',1824,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4528,NULL,'East Lyme, CT 6333',1824,222,NULL,8,2411,0);
INSERT INTO "django_geo_db_location" VALUES(4529,NULL,'Bozrah, CT',1825,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4530,NULL,'Bozrah, CT 6334',1825,222,NULL,8,2412,0);
INSERT INTO "django_geo_db_location" VALUES(4531,NULL,'Gales Ferry, CT',1826,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4532,NULL,'Gales Ferry, CT 6335',1826,222,NULL,8,2413,0);
INSERT INTO "django_geo_db_location" VALUES(4533,NULL,'Gilman, CT',1827,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4534,NULL,'Gilman, CT 6336',1827,222,NULL,8,2414,0);
INSERT INTO "django_geo_db_location" VALUES(4535,NULL,'Glasgo, CT',1828,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4536,NULL,'Glasgo, CT 6337',1828,222,NULL,8,2415,0);
INSERT INTO "django_geo_db_location" VALUES(4537,NULL,'Ledyard, CT',1829,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4538,NULL,'Ledyard, CT 6339',1829,222,NULL,8,2416,0);
INSERT INTO "django_geo_db_location" VALUES(4539,NULL,'Groton, CT',1830,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4540,NULL,'Groton, CT 6340',1830,222,NULL,8,2417,0);
INSERT INTO "django_geo_db_location" VALUES(4541,NULL,'Groton, CT 6349',1830,222,NULL,8,2418,0);
INSERT INTO "django_geo_db_location" VALUES(4542,NULL,'Hanover, CT',1831,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4543,NULL,'Hanover, CT 6350',1831,222,NULL,8,2419,0);
INSERT INTO "django_geo_db_location" VALUES(4544,NULL,'Jewett City, CT',1832,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4545,NULL,'Jewett City, CT 6351',1832,222,NULL,8,2420,0);
INSERT INTO "django_geo_db_location" VALUES(4546,NULL,'Montville, CT',1833,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4547,NULL,'Montville, CT 6353',1833,222,NULL,8,2421,0);
INSERT INTO "django_geo_db_location" VALUES(4548,NULL,'Moosup, CT',1834,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4549,NULL,'Moosup, CT 6354',1834,222,NULL,8,2422,0);
INSERT INTO "django_geo_db_location" VALUES(4550,NULL,'Mystic, CT',1835,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4551,NULL,'Mystic, CT 6355',1835,222,NULL,8,2423,0);
INSERT INTO "django_geo_db_location" VALUES(4552,NULL,'Niantic, CT',1836,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4553,NULL,'Niantic, CT 6357',1836,222,NULL,8,2424,0);
INSERT INTO "django_geo_db_location" VALUES(4554,NULL,'North Stonington, CT',1837,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4555,NULL,'North Stonington, CT 6359',1837,222,NULL,8,2425,0);
INSERT INTO "django_geo_db_location" VALUES(4556,NULL,'Norwich, CT',1838,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4557,NULL,'Norwich, CT 6360',1838,222,NULL,8,2426,0);
INSERT INTO "django_geo_db_location" VALUES(4558,NULL,'Preston, CT',1839,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4559,NULL,'Preston, CT 6365',1839,222,NULL,8,2427,0);
INSERT INTO "django_geo_db_location" VALUES(4560,NULL,'Oakdale, CT',1840,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4561,NULL,'Oakdale, CT 6370',1840,222,NULL,8,2428,0);
INSERT INTO "django_geo_db_location" VALUES(4562,NULL,'Old Lyme, CT',1841,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4563,NULL,'Old Lyme, CT 6371',1841,222,NULL,8,2429,0);
INSERT INTO "django_geo_db_location" VALUES(4564,NULL,'Old Mystic, CT',1842,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4565,NULL,'Old Mystic, CT 6372',1842,222,NULL,8,2430,0);
INSERT INTO "django_geo_db_location" VALUES(4566,NULL,'Oneco, CT',1843,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4567,NULL,'Oneco, CT 6373',1843,222,NULL,8,2431,0);
INSERT INTO "django_geo_db_location" VALUES(4568,NULL,'Plainfield, CT',1844,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4569,NULL,'Plainfield, CT 6374',1844,222,NULL,8,2432,0);
INSERT INTO "django_geo_db_location" VALUES(4570,NULL,'Quaker Hill, CT',1845,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4571,NULL,'Quaker Hill, CT 6375',1845,222,NULL,8,2433,0);
INSERT INTO "django_geo_db_location" VALUES(4572,NULL,'South Lyme, CT',1846,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4573,NULL,'South Lyme, CT 6376',1846,222,NULL,8,2434,0);
INSERT INTO "django_geo_db_location" VALUES(4574,NULL,'Sterling, CT',1847,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4575,NULL,'Sterling, CT 6377',1847,222,NULL,8,2435,0);
INSERT INTO "django_geo_db_location" VALUES(4576,NULL,'Stonington, CT',1848,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4577,NULL,'Stonington, CT 6378',1848,222,NULL,8,2436,0);
INSERT INTO "django_geo_db_location" VALUES(4578,NULL,'Pawcatuck, CT',1849,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4579,NULL,'Pawcatuck, CT 6379',1849,222,NULL,8,2437,0);
INSERT INTO "django_geo_db_location" VALUES(4580,NULL,'Taftville, CT',1850,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4581,NULL,'Taftville, CT 6380',1850,222,NULL,8,2438,0);
INSERT INTO "django_geo_db_location" VALUES(4582,NULL,'Uncasville, CT',1851,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4583,NULL,'Uncasville, CT 6382',1851,222,NULL,8,2439,0);
INSERT INTO "django_geo_db_location" VALUES(4584,NULL,'Versailles, CT',1852,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4585,NULL,'Versailles, CT 6383',1852,222,NULL,8,2440,0);
INSERT INTO "django_geo_db_location" VALUES(4586,NULL,'Voluntown, CT',1853,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4587,NULL,'Voluntown, CT 6384',1853,222,NULL,8,2441,0);
INSERT INTO "django_geo_db_location" VALUES(4588,NULL,'Waterford, CT',1854,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4589,NULL,'Waterford, CT 6385',1854,222,NULL,8,2442,0);
INSERT INTO "django_geo_db_location" VALUES(4590,NULL,'Waterford, CT 6386',1854,222,NULL,8,2443,0);
INSERT INTO "django_geo_db_location" VALUES(4591,NULL,'Wauregan, CT',1855,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4592,NULL,'Wauregan, CT 6387',1855,222,NULL,8,2444,0);
INSERT INTO "django_geo_db_location" VALUES(4593,NULL,'West Mystic, CT',1856,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4594,NULL,'West Mystic, CT 6388',1856,222,NULL,8,2445,0);
INSERT INTO "django_geo_db_location" VALUES(4595,NULL,'Yantic, CT',1857,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4596,NULL,'Yantic, CT 6389',1857,222,NULL,8,2446,0);
INSERT INTO "django_geo_db_location" VALUES(4597,NULL,'Fishers Island, NY',1858,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4598,NULL,'Fishers Island, NY 6390',1858,222,NULL,32,2447,0);
INSERT INTO "django_geo_db_location" VALUES(4599,NULL,'Ansonia, CT',1859,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4600,NULL,'Ansonia, CT 6401',1859,222,NULL,8,2448,0);
INSERT INTO "django_geo_db_location" VALUES(4601,NULL,'Beacon Falls, CT',1860,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4602,NULL,'Beacon Falls, CT 6403',1860,222,NULL,8,2449,0);
INSERT INTO "django_geo_db_location" VALUES(4603,NULL,'Botsford, CT',1861,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4604,NULL,'Botsford, CT 6404',1861,222,NULL,8,2450,0);
INSERT INTO "django_geo_db_location" VALUES(4605,NULL,'Branford, CT',1862,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4606,NULL,'Branford, CT 6405',1862,222,NULL,8,2451,0);
INSERT INTO "django_geo_db_location" VALUES(4607,NULL,'Cheshire, CT',1863,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4608,NULL,'Cheshire, CT 6408',1863,222,NULL,8,2452,0);
INSERT INTO "django_geo_db_location" VALUES(4609,NULL,'Centerbrook, CT',1864,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4610,NULL,'Centerbrook, CT 6409',1864,222,NULL,8,2453,0);
INSERT INTO "django_geo_db_location" VALUES(4611,NULL,'Cheshire, CT 6410',1863,222,NULL,8,2454,0);
INSERT INTO "django_geo_db_location" VALUES(4612,NULL,'Cheshire, CT 6411',1863,222,NULL,8,2455,0);
INSERT INTO "django_geo_db_location" VALUES(4613,NULL,'Chester, CT',1865,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4614,NULL,'Chester, CT 6412',1865,222,NULL,8,2456,0);
INSERT INTO "django_geo_db_location" VALUES(4615,NULL,'Clinton, CT',1866,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4616,NULL,'Clinton, CT 6413',1866,222,NULL,8,2457,0);
INSERT INTO "django_geo_db_location" VALUES(4617,NULL,'Cobalt, CT',1867,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4618,NULL,'Cobalt, CT 6414',1867,222,NULL,8,2458,0);
INSERT INTO "django_geo_db_location" VALUES(4619,NULL,'Colchester, CT',1868,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4620,NULL,'Colchester, CT 6415',1868,222,NULL,8,2459,0);
INSERT INTO "django_geo_db_location" VALUES(4621,NULL,'Cromwell, CT',1869,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4622,NULL,'Cromwell, CT 6416',1869,222,NULL,8,2460,0);
INSERT INTO "django_geo_db_location" VALUES(4623,NULL,'Deep River, CT',1870,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4624,NULL,'Deep River, CT 6417',1870,222,NULL,8,2461,0);
INSERT INTO "django_geo_db_location" VALUES(4625,NULL,'Derby, CT',1871,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4626,NULL,'Derby, CT 6418',1871,222,NULL,8,2462,0);
INSERT INTO "django_geo_db_location" VALUES(4627,NULL,'Killingworth, CT',1872,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4628,NULL,'Killingworth, CT 6419',1872,222,NULL,8,2463,0);
INSERT INTO "django_geo_db_location" VALUES(4629,NULL,'Salem, CT',1873,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4630,NULL,'Salem, CT 6420',1873,222,NULL,8,2464,0);
INSERT INTO "django_geo_db_location" VALUES(4631,NULL,'Durham, CT',1874,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4632,NULL,'Durham, CT 6422',1874,222,NULL,8,2465,0);
INSERT INTO "django_geo_db_location" VALUES(4633,NULL,'East Haddam, CT',1875,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4634,NULL,'East Haddam, CT 6423',1875,222,NULL,8,2466,0);
INSERT INTO "django_geo_db_location" VALUES(4635,NULL,'East Hampton, CT',1876,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4636,NULL,'East Hampton, CT 6424',1876,222,NULL,8,2467,0);
INSERT INTO "django_geo_db_location" VALUES(4637,NULL,'Essex, CT',1877,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4638,NULL,'Essex, CT 6426',1877,222,NULL,8,2468,0);
INSERT INTO "django_geo_db_location" VALUES(4639,NULL,'Fairfield, CT',1878,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4640,NULL,'Fairfield, CT 6430',1878,222,NULL,8,2469,0);
INSERT INTO "django_geo_db_location" VALUES(4641,NULL,'Fairfield, CT 6431',1878,222,NULL,8,2470,0);
INSERT INTO "django_geo_db_location" VALUES(4642,NULL,'Fairfield, CT 6432',1878,222,NULL,8,2471,0);
INSERT INTO "django_geo_db_location" VALUES(4643,NULL,'Greens Farms, CT',1879,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4644,NULL,'Greens Farms, CT 6436',1879,222,NULL,8,2472,0);
INSERT INTO "django_geo_db_location" VALUES(4645,NULL,'Guilford, CT',1880,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4646,NULL,'Guilford, CT 6437',1880,222,NULL,8,2473,0);
INSERT INTO "django_geo_db_location" VALUES(4647,NULL,'Haddam, CT',1881,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4648,NULL,'Haddam, CT 6438',1881,222,NULL,8,2474,0);
INSERT INTO "django_geo_db_location" VALUES(4649,NULL,'Hadlyme, CT',1882,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4650,NULL,'Hadlyme, CT 6439',1882,222,NULL,8,2475,0);
INSERT INTO "django_geo_db_location" VALUES(4651,NULL,'Hawleyville, CT',1883,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4652,NULL,'Hawleyville, CT 6440',1883,222,NULL,8,2476,0);
INSERT INTO "django_geo_db_location" VALUES(4653,NULL,'Higganum, CT',1884,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4654,NULL,'Higganum, CT 6441',1884,222,NULL,8,2477,0);
INSERT INTO "django_geo_db_location" VALUES(4655,NULL,'Ivoryton, CT',1885,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4656,NULL,'Ivoryton, CT 6442',1885,222,NULL,8,2478,0);
INSERT INTO "django_geo_db_location" VALUES(4657,NULL,'Madison, CT',1886,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4658,NULL,'Madison, CT 6443',1886,222,NULL,8,2479,0);
INSERT INTO "django_geo_db_location" VALUES(4659,NULL,'Marion, CT',1887,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4660,NULL,'Marion, CT 6444',1887,222,NULL,8,2480,0);
INSERT INTO "django_geo_db_location" VALUES(4661,NULL,'Marlborough, CT',1888,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4662,NULL,'Marlborough, CT 6447',1888,222,NULL,8,2481,0);
INSERT INTO "django_geo_db_location" VALUES(4663,NULL,'Meriden, CT',1889,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4664,NULL,'Meriden, CT 6450',1889,222,NULL,8,2482,0);
INSERT INTO "django_geo_db_location" VALUES(4665,NULL,'Meriden, CT 6451',1889,222,NULL,8,2483,0);
INSERT INTO "django_geo_db_location" VALUES(4666,NULL,'Meriden, CT 6454',1889,222,NULL,8,2484,0);
INSERT INTO "django_geo_db_location" VALUES(4667,NULL,'Middlefield, CT',1890,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4668,NULL,'Middlefield, CT 6455',1890,222,NULL,8,2485,0);
INSERT INTO "django_geo_db_location" VALUES(4669,NULL,'Middle Haddam, CT',1891,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4670,NULL,'Middle Haddam, CT 6456',1891,222,NULL,8,2486,0);
INSERT INTO "django_geo_db_location" VALUES(4671,NULL,'Middletown, CT',1892,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4672,NULL,'Middletown, CT 6457',1892,222,NULL,8,2487,0);
INSERT INTO "django_geo_db_location" VALUES(4673,NULL,'Middletown, CT 6459',1892,222,NULL,8,2488,0);
INSERT INTO "django_geo_db_location" VALUES(4674,NULL,'Milford, CT',1893,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4675,NULL,'Milford, CT 6460',1893,222,NULL,8,2489,0);
INSERT INTO "django_geo_db_location" VALUES(4676,NULL,'Milldale, CT',1894,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4677,NULL,'Milldale, CT 6467',1894,222,NULL,8,2490,0);
INSERT INTO "django_geo_db_location" VALUES(4678,NULL,'Monroe, CT',1895,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4679,NULL,'Monroe, CT 6468',1895,222,NULL,8,2491,0);
INSERT INTO "django_geo_db_location" VALUES(4680,NULL,'Moodus, CT',1896,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4681,NULL,'Moodus, CT 6469',1896,222,NULL,8,2492,0);
INSERT INTO "django_geo_db_location" VALUES(4682,NULL,'Newtown, CT',1897,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4683,NULL,'Newtown, CT 6470',1897,222,NULL,8,2493,0);
INSERT INTO "django_geo_db_location" VALUES(4684,NULL,'North Branford, CT',1898,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4685,NULL,'North Branford, CT 6471',1898,222,NULL,8,2494,0);
INSERT INTO "django_geo_db_location" VALUES(4686,NULL,'Northford, CT',1899,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4687,NULL,'Northford, CT 6472',1899,222,NULL,8,2495,0);
INSERT INTO "django_geo_db_location" VALUES(4688,NULL,'North Haven, CT',1900,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4689,NULL,'North Haven, CT 6473',1900,222,NULL,8,2496,0);
INSERT INTO "django_geo_db_location" VALUES(4690,NULL,'North Westchester, CT',1901,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4691,NULL,'North Westchester, CT 6474',1901,222,NULL,8,2497,0);
INSERT INTO "django_geo_db_location" VALUES(4692,NULL,'Old Saybrook, CT',1902,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4693,NULL,'Old Saybrook, CT 6475',1902,222,NULL,8,2498,0);
INSERT INTO "django_geo_db_location" VALUES(4694,NULL,'Orange, CT',1903,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4695,NULL,'Orange, CT 6477',1903,222,NULL,8,2499,0);
INSERT INTO "django_geo_db_location" VALUES(4696,NULL,'Oxford, CT',1904,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4697,NULL,'Oxford, CT 6478',1904,222,NULL,8,2500,0);
INSERT INTO "django_geo_db_location" VALUES(4698,NULL,'Plantsville, CT',1905,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4699,NULL,'Plantsville, CT 6479',1905,222,NULL,8,2501,0);
INSERT INTO "django_geo_db_location" VALUES(4700,NULL,'Portland, CT',1906,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4701,NULL,'Portland, CT 6480',1906,222,NULL,8,2502,0);
INSERT INTO "django_geo_db_location" VALUES(4702,NULL,'Rockfall, CT',1907,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4703,NULL,'Rockfall, CT 6481',1907,222,NULL,8,2503,0);
INSERT INTO "django_geo_db_location" VALUES(4704,NULL,'Sandy Hook, CT',1908,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4705,NULL,'Sandy Hook, CT 6482',1908,222,NULL,8,2504,0);
INSERT INTO "django_geo_db_location" VALUES(4706,NULL,'Seymour, CT',1909,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4707,NULL,'Seymour, CT 6483',1909,222,NULL,8,2505,0);
INSERT INTO "django_geo_db_location" VALUES(4708,NULL,'Shelton, CT',1910,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4709,NULL,'Shelton, CT 6484',1910,222,NULL,8,2506,0);
INSERT INTO "django_geo_db_location" VALUES(4710,NULL,'South Britain, CT',1911,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4711,NULL,'South Britain, CT 6487',1911,222,NULL,8,2507,0);
INSERT INTO "django_geo_db_location" VALUES(4712,NULL,'Southbury, CT',1912,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4713,NULL,'Southbury, CT 6488',1912,222,NULL,8,2508,0);
INSERT INTO "django_geo_db_location" VALUES(4714,NULL,'Southington, CT',1913,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4715,NULL,'Southington, CT 6489',1913,222,NULL,8,2509,0);
INSERT INTO "django_geo_db_location" VALUES(4716,NULL,'Southport, CT',1914,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4717,NULL,'Southport, CT 6490',1914,222,NULL,8,2510,0);
INSERT INTO "django_geo_db_location" VALUES(4718,NULL,'Stevenson, CT',1915,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4719,NULL,'Stevenson, CT 6491',1915,222,NULL,8,2511,0);
INSERT INTO "django_geo_db_location" VALUES(4720,NULL,'Wallingford, CT',1916,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4721,NULL,'Wallingford, CT 6492',1916,222,NULL,8,2512,0);
INSERT INTO "django_geo_db_location" VALUES(4722,NULL,'Wallingford, CT 6493',1916,222,NULL,8,2513,0);
INSERT INTO "django_geo_db_location" VALUES(4723,NULL,'Wallingford, CT 6494',1916,222,NULL,8,2514,0);
INSERT INTO "django_geo_db_location" VALUES(4724,NULL,'Stratford, CT',1917,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4725,NULL,'Stratford, CT 6497',1917,222,NULL,8,2515,0);
INSERT INTO "django_geo_db_location" VALUES(4726,NULL,'Westbrook, CT',1918,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4727,NULL,'Westbrook, CT 6498',1918,222,NULL,8,2516,0);
INSERT INTO "django_geo_db_location" VALUES(4728,NULL,'New Haven, CT',1919,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4729,NULL,'New Haven, CT 6501',1919,222,NULL,8,2517,0);
INSERT INTO "django_geo_db_location" VALUES(4730,NULL,'New Haven, CT 6502',1919,222,NULL,8,2518,0);
INSERT INTO "django_geo_db_location" VALUES(4731,NULL,'New Haven, CT 6503',1919,222,NULL,8,2519,0);
INSERT INTO "django_geo_db_location" VALUES(4732,NULL,'New Haven, CT 6504',1919,222,NULL,8,2520,0);
INSERT INTO "django_geo_db_location" VALUES(4733,NULL,'New Haven, CT 6505',1919,222,NULL,8,2521,0);
INSERT INTO "django_geo_db_location" VALUES(4734,NULL,'New Haven, CT 6506',1919,222,NULL,8,2522,0);
INSERT INTO "django_geo_db_location" VALUES(4735,NULL,'New Haven, CT 6507',1919,222,NULL,8,2523,0);
INSERT INTO "django_geo_db_location" VALUES(4736,NULL,'New Haven, CT 6508',1919,222,NULL,8,2524,0);
INSERT INTO "django_geo_db_location" VALUES(4737,NULL,'New Haven, CT 6509',1919,222,NULL,8,2525,0);
INSERT INTO "django_geo_db_location" VALUES(4738,NULL,'New Haven, CT 6510',1919,222,NULL,8,2526,0);
INSERT INTO "django_geo_db_location" VALUES(4739,NULL,'New Haven, CT 6511',1919,222,NULL,8,2527,0);
INSERT INTO "django_geo_db_location" VALUES(4740,NULL,'East Haven, CT',1920,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4741,NULL,'East Haven, CT 6512',1920,222,NULL,8,2528,0);
INSERT INTO "django_geo_db_location" VALUES(4742,NULL,'New Haven, CT 6513',1919,222,NULL,8,2529,0);
INSERT INTO "django_geo_db_location" VALUES(4743,NULL,'Hamden, CT',1921,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4744,NULL,'Hamden, CT 6514',1921,222,NULL,8,2530,0);
INSERT INTO "django_geo_db_location" VALUES(4745,NULL,'New Haven, CT 6515',1919,222,NULL,8,2531,0);
INSERT INTO "django_geo_db_location" VALUES(4746,NULL,'West Haven, CT',1922,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4747,NULL,'West Haven, CT 6516',1922,222,NULL,8,2532,0);
INSERT INTO "django_geo_db_location" VALUES(4748,NULL,'Hamden, CT 6517',1921,222,NULL,8,2533,0);
INSERT INTO "django_geo_db_location" VALUES(4749,NULL,'Hamden, CT 6518',1921,222,NULL,8,2534,0);
INSERT INTO "django_geo_db_location" VALUES(4750,NULL,'New Haven, CT 6519',1919,222,NULL,8,2535,0);
INSERT INTO "django_geo_db_location" VALUES(4751,NULL,'New Haven, CT 6520',1919,222,NULL,8,2536,0);
INSERT INTO "django_geo_db_location" VALUES(4752,NULL,'New Haven, CT 6521',1919,222,NULL,8,2537,0);
INSERT INTO "django_geo_db_location" VALUES(4753,NULL,'Bethany, CT',1923,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4754,NULL,'Bethany, CT 6524',1923,222,NULL,8,2538,0);
INSERT INTO "django_geo_db_location" VALUES(4755,NULL,'Woodbridge, CT',1924,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4756,NULL,'Woodbridge, CT 6525',1924,222,NULL,8,2539,0);
INSERT INTO "django_geo_db_location" VALUES(4757,NULL,'New Haven, CT 6530',1919,222,NULL,8,2540,0);
INSERT INTO "django_geo_db_location" VALUES(4758,NULL,'New Haven, CT 6531',1919,222,NULL,8,2541,0);
INSERT INTO "django_geo_db_location" VALUES(4759,NULL,'New Haven, CT 6532',1919,222,NULL,8,2542,0);
INSERT INTO "django_geo_db_location" VALUES(4760,NULL,'New Haven, CT 6533',1919,222,NULL,8,2543,0);
INSERT INTO "django_geo_db_location" VALUES(4761,NULL,'New Haven, CT 6534',1919,222,NULL,8,2544,0);
INSERT INTO "django_geo_db_location" VALUES(4762,NULL,'New Haven, CT 6535',1919,222,NULL,8,2545,0);
INSERT INTO "django_geo_db_location" VALUES(4763,NULL,'New Haven, CT 6536',1919,222,NULL,8,2546,0);
INSERT INTO "django_geo_db_location" VALUES(4764,NULL,'New Haven, CT 6537',1919,222,NULL,8,2547,0);
INSERT INTO "django_geo_db_location" VALUES(4765,NULL,'New Haven, CT 6538',1919,222,NULL,8,2548,0);
INSERT INTO "django_geo_db_location" VALUES(4766,NULL,'New Haven, CT 6540',1919,222,NULL,8,2549,0);
INSERT INTO "django_geo_db_location" VALUES(4767,NULL,'Bridgeport, CT',1925,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4768,NULL,'Bridgeport, CT 6601',1925,222,NULL,8,2550,0);
INSERT INTO "django_geo_db_location" VALUES(4769,NULL,'Bridgeport, CT 6602',1925,222,NULL,8,2551,0);
INSERT INTO "django_geo_db_location" VALUES(4770,NULL,'Bridgeport, CT 6604',1925,222,NULL,8,2552,0);
INSERT INTO "django_geo_db_location" VALUES(4771,NULL,'Bridgeport, CT 6605',1925,222,NULL,8,2553,0);
INSERT INTO "django_geo_db_location" VALUES(4772,NULL,'Bridgeport, CT 6606',1925,222,NULL,8,2554,0);
INSERT INTO "django_geo_db_location" VALUES(4773,NULL,'Bridgeport, CT 6607',1925,222,NULL,8,2555,0);
INSERT INTO "django_geo_db_location" VALUES(4774,NULL,'Bridgeport, CT 6608',1925,222,NULL,8,2556,0);
INSERT INTO "django_geo_db_location" VALUES(4775,NULL,'Bridgeport, CT 6610',1925,222,NULL,8,2557,0);
INSERT INTO "django_geo_db_location" VALUES(4776,NULL,'Trumbull, CT',1926,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4777,NULL,'Trumbull, CT 6611',1926,222,NULL,8,2558,0);
INSERT INTO "django_geo_db_location" VALUES(4778,NULL,'Easton, CT',1927,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4779,NULL,'Easton, CT 6612',1927,222,NULL,8,2559,0);
INSERT INTO "django_geo_db_location" VALUES(4780,NULL,'Stratford, CT 6614',1917,222,NULL,8,2560,0);
INSERT INTO "django_geo_db_location" VALUES(4781,NULL,'Stratford, CT 6615',1917,222,NULL,8,2561,0);
INSERT INTO "django_geo_db_location" VALUES(4782,NULL,'Bridgeport, CT 6650',1925,222,NULL,8,2562,0);
INSERT INTO "django_geo_db_location" VALUES(4783,NULL,'Bridgeport, CT 6673',1925,222,NULL,8,2563,0);
INSERT INTO "django_geo_db_location" VALUES(4784,NULL,'Bridgeport, CT 6699',1925,222,NULL,8,2564,0);
INSERT INTO "django_geo_db_location" VALUES(4785,NULL,'Waterbury, CT',1928,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4786,NULL,'Waterbury, CT 6701',1928,222,NULL,8,2565,0);
INSERT INTO "django_geo_db_location" VALUES(4787,NULL,'Waterbury, CT 6702',1928,222,NULL,8,2566,0);
INSERT INTO "django_geo_db_location" VALUES(4788,NULL,'Waterbury, CT 6703',1928,222,NULL,8,2567,0);
INSERT INTO "django_geo_db_location" VALUES(4789,NULL,'Waterbury, CT 6704',1928,222,NULL,8,2568,0);
INSERT INTO "django_geo_db_location" VALUES(4790,NULL,'Waterbury, CT 6705',1928,222,NULL,8,2569,0);
INSERT INTO "django_geo_db_location" VALUES(4791,NULL,'Waterbury, CT 6706',1928,222,NULL,8,2570,0);
INSERT INTO "django_geo_db_location" VALUES(4792,NULL,'Waterbury, CT 6708',1928,222,NULL,8,2571,0);
INSERT INTO "django_geo_db_location" VALUES(4793,NULL,'Waterbury, CT 6710',1928,222,NULL,8,2572,0);
INSERT INTO "django_geo_db_location" VALUES(4794,NULL,'Prospect, CT',1929,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4795,NULL,'Prospect, CT 6712',1929,222,NULL,8,2573,0);
INSERT INTO "django_geo_db_location" VALUES(4796,NULL,'Wolcott, CT',1930,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4797,NULL,'Wolcott, CT 6716',1930,222,NULL,8,2574,0);
INSERT INTO "django_geo_db_location" VALUES(4798,NULL,'Waterbury, CT 6720',1928,222,NULL,8,2575,0);
INSERT INTO "django_geo_db_location" VALUES(4799,NULL,'Waterbury, CT 6721',1928,222,NULL,8,2576,0);
INSERT INTO "django_geo_db_location" VALUES(4800,NULL,'Waterbury, CT 6722',1928,222,NULL,8,2577,0);
INSERT INTO "django_geo_db_location" VALUES(4801,NULL,'Waterbury, CT 6723',1928,222,NULL,8,2578,0);
INSERT INTO "django_geo_db_location" VALUES(4802,NULL,'Waterbury, CT 6724',1928,222,NULL,8,2579,0);
INSERT INTO "django_geo_db_location" VALUES(4803,NULL,'Waterbury, CT 6725',1928,222,NULL,8,2580,0);
INSERT INTO "django_geo_db_location" VALUES(4804,NULL,'Waterbury, CT 6726',1928,222,NULL,8,2581,0);
INSERT INTO "django_geo_db_location" VALUES(4805,NULL,'Salisbury, CT 6731',1750,222,NULL,8,2582,0);
INSERT INTO "django_geo_db_location" VALUES(4806,NULL,'Oxford, CT 6748',1904,222,NULL,8,2583,0);
INSERT INTO "django_geo_db_location" VALUES(4807,NULL,'Waterbury, CT 6749',1928,222,NULL,8,2584,0);
INSERT INTO "django_geo_db_location" VALUES(4808,NULL,'Bantam, CT',1931,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4809,NULL,'Bantam, CT 6750',1931,222,NULL,8,2585,0);
INSERT INTO "django_geo_db_location" VALUES(4810,NULL,'Bethlehem, CT',1932,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4811,NULL,'Bethlehem, CT 6751',1932,222,NULL,8,2586,0);
INSERT INTO "django_geo_db_location" VALUES(4812,NULL,'Bridgewater, CT',1933,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4813,NULL,'Bridgewater, CT 6752',1933,222,NULL,8,2587,0);
INSERT INTO "django_geo_db_location" VALUES(4814,NULL,'Cornwall, CT',1934,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4815,NULL,'Cornwall, CT 6753',1934,222,NULL,8,2588,0);
INSERT INTO "django_geo_db_location" VALUES(4816,NULL,'Cornwall Bridge, CT',1935,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4817,NULL,'Cornwall Bridge, CT 6754',1935,222,NULL,8,2589,0);
INSERT INTO "django_geo_db_location" VALUES(4818,NULL,'Gaylordsville, CT',1936,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4819,NULL,'Gaylordsville, CT 6755',1936,222,NULL,8,2590,0);
INSERT INTO "django_geo_db_location" VALUES(4820,NULL,'Goshen, CT',1937,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4821,NULL,'Goshen, CT 6756',1937,222,NULL,8,2591,0);
INSERT INTO "django_geo_db_location" VALUES(4822,NULL,'Kent, CT',1938,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4823,NULL,'Kent, CT 6757',1938,222,NULL,8,2592,0);
INSERT INTO "django_geo_db_location" VALUES(4824,NULL,'Lakeside, CT',1939,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4825,NULL,'Lakeside, CT 6758',1939,222,NULL,8,2593,0);
INSERT INTO "django_geo_db_location" VALUES(4826,NULL,'Litchfield, CT',1940,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4827,NULL,'Litchfield, CT 6759',1940,222,NULL,8,2594,0);
INSERT INTO "django_geo_db_location" VALUES(4828,NULL,'Middlebury, CT',1941,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4829,NULL,'Middlebury, CT 6762',1941,222,NULL,8,2595,0);
INSERT INTO "django_geo_db_location" VALUES(4830,NULL,'Morris, CT',1942,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4831,NULL,'Morris, CT 6763',1942,222,NULL,8,2596,0);
INSERT INTO "django_geo_db_location" VALUES(4832,NULL,'Naugatuck, CT',1943,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4833,NULL,'Naugatuck, CT 6770',1943,222,NULL,8,2597,0);
INSERT INTO "django_geo_db_location" VALUES(4834,NULL,'New Milford, CT',1944,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4835,NULL,'New Milford, CT 6776',1944,222,NULL,8,2598,0);
INSERT INTO "django_geo_db_location" VALUES(4836,NULL,'New Preston Marble Dale, CT',1945,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4837,NULL,'New Preston Marble Dale, CT 6777',1945,222,NULL,8,2599,0);
INSERT INTO "django_geo_db_location" VALUES(4838,NULL,'Northfield, CT',1946,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4839,NULL,'Northfield, CT 6778',1946,222,NULL,8,2600,0);
INSERT INTO "django_geo_db_location" VALUES(4840,NULL,'Oakville, CT',1947,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4841,NULL,'Oakville, CT 6779',1947,222,NULL,8,2601,0);
INSERT INTO "django_geo_db_location" VALUES(4842,NULL,'Pequabuck, CT',1948,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4843,NULL,'Pequabuck, CT 6781',1948,222,NULL,8,2602,0);
INSERT INTO "django_geo_db_location" VALUES(4844,NULL,'Plymouth, CT',1949,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4845,NULL,'Plymouth, CT 6782',1949,222,NULL,8,2603,0);
INSERT INTO "django_geo_db_location" VALUES(4846,NULL,'Roxbury, CT',1950,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4847,NULL,'Roxbury, CT 6783',1950,222,NULL,8,2604,0);
INSERT INTO "django_geo_db_location" VALUES(4848,NULL,'Sherman, CT',1951,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4849,NULL,'Sherman, CT 6784',1951,222,NULL,8,2605,0);
INSERT INTO "django_geo_db_location" VALUES(4850,NULL,'South Kent, CT',1952,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4851,NULL,'South Kent, CT 6785',1952,222,NULL,8,2606,0);
INSERT INTO "django_geo_db_location" VALUES(4852,NULL,'Terryville, CT',1953,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4853,NULL,'Terryville, CT 6786',1953,222,NULL,8,2607,0);
INSERT INTO "django_geo_db_location" VALUES(4854,NULL,'Thomaston, CT',1954,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4855,NULL,'Thomaston, CT 6787',1954,222,NULL,8,2608,0);
INSERT INTO "django_geo_db_location" VALUES(4856,NULL,'Torrington, CT',1955,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4857,NULL,'Torrington, CT 6790',1955,222,NULL,8,2609,0);
INSERT INTO "django_geo_db_location" VALUES(4858,NULL,'Harwinton, CT',1956,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4859,NULL,'Harwinton, CT 6791',1956,222,NULL,8,2610,0);
INSERT INTO "django_geo_db_location" VALUES(4860,NULL,'Washington, CT',1957,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4861,NULL,'Washington, CT 6793',1957,222,NULL,8,2611,0);
INSERT INTO "django_geo_db_location" VALUES(4862,NULL,'Washington Depot, CT',1958,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4863,NULL,'Washington Depot, CT 6794',1958,222,NULL,8,2612,0);
INSERT INTO "django_geo_db_location" VALUES(4864,NULL,'Watertown, CT',1959,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4865,NULL,'Watertown, CT 6795',1959,222,NULL,8,2613,0);
INSERT INTO "django_geo_db_location" VALUES(4866,NULL,'West Cornwall, CT',1960,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4867,NULL,'West Cornwall, CT 6796',1960,222,NULL,8,2614,0);
INSERT INTO "django_geo_db_location" VALUES(4868,NULL,'Woodbury, CT',1961,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4869,NULL,'Woodbury, CT 6798',1961,222,NULL,8,2615,0);
INSERT INTO "django_geo_db_location" VALUES(4870,NULL,'Bethel, CT',1962,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4871,NULL,'Bethel, CT 6801',1962,222,NULL,8,2616,0);
INSERT INTO "django_geo_db_location" VALUES(4872,NULL,'Brookfield, CT',1963,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4873,NULL,'Brookfield, CT 6804',1963,222,NULL,8,2617,0);
INSERT INTO "django_geo_db_location" VALUES(4874,NULL,'Cos Cob, CT',1964,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4875,NULL,'Cos Cob, CT 6807',1964,222,NULL,8,2618,0);
INSERT INTO "django_geo_db_location" VALUES(4876,NULL,'Danbury, CT',1965,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4877,NULL,'Danbury, CT 6810',1965,222,NULL,8,2619,0);
INSERT INTO "django_geo_db_location" VALUES(4878,NULL,'Danbury, CT 6811',1965,222,NULL,8,2620,0);
INSERT INTO "django_geo_db_location" VALUES(4879,NULL,'New Fairfield, CT',1966,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4880,NULL,'New Fairfield, CT 6812',1966,222,NULL,8,2621,0);
INSERT INTO "django_geo_db_location" VALUES(4881,NULL,'Danbury, CT 6813',1965,222,NULL,8,2622,0);
INSERT INTO "django_geo_db_location" VALUES(4882,NULL,'Danbury, CT 6814',1965,222,NULL,8,2623,0);
INSERT INTO "django_geo_db_location" VALUES(4883,NULL,'Hamden, CT 6815',1921,222,NULL,8,2624,0);
INSERT INTO "django_geo_db_location" VALUES(4884,NULL,'Danbury, CT 6816',1965,222,NULL,8,2625,0);
INSERT INTO "django_geo_db_location" VALUES(4885,NULL,'Danbury, CT 6817',1965,222,NULL,8,2626,0);
INSERT INTO "django_geo_db_location" VALUES(4886,NULL,'Danbury, CT 6819',1965,222,NULL,8,2627,0);
INSERT INTO "django_geo_db_location" VALUES(4887,NULL,'Darien, CT',1967,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4888,NULL,'Darien, CT 6820',1967,222,NULL,8,2628,0);
INSERT INTO "django_geo_db_location" VALUES(4889,NULL,'Fairfield, CT 6824',1878,222,NULL,8,2629,0);
INSERT INTO "django_geo_db_location" VALUES(4890,NULL,'Bridgeport, CT 6825',1925,222,NULL,8,2630,0);
INSERT INTO "django_geo_db_location" VALUES(4891,NULL,'Georgetown, CT',1968,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4892,NULL,'Georgetown, CT 6829',1968,222,NULL,8,2631,0);
INSERT INTO "django_geo_db_location" VALUES(4893,NULL,'Greenwich, CT',1969,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4894,NULL,'Greenwich, CT 6830',1969,222,NULL,8,2632,0);
INSERT INTO "django_geo_db_location" VALUES(4895,NULL,'Greenwich, CT 6831',1969,222,NULL,8,2633,0);
INSERT INTO "django_geo_db_location" VALUES(4896,NULL,'Greenwich, CT 6832',1969,222,NULL,8,2634,0);
INSERT INTO "django_geo_db_location" VALUES(4897,NULL,'Greenwich, CT 6836',1969,222,NULL,8,2635,0);
INSERT INTO "django_geo_db_location" VALUES(4898,NULL,'New Canaan, CT',1970,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4899,NULL,'New Canaan, CT 6840',1970,222,NULL,8,2636,0);
INSERT INTO "django_geo_db_location" VALUES(4900,NULL,'New Canaan, CT 6842',1970,222,NULL,8,2637,0);
INSERT INTO "django_geo_db_location" VALUES(4901,NULL,'Norwalk, CT',1971,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4902,NULL,'Norwalk, CT 6850',1971,222,NULL,8,2638,0);
INSERT INTO "django_geo_db_location" VALUES(4903,NULL,'Norwalk, CT 6851',1971,222,NULL,8,2639,0);
INSERT INTO "django_geo_db_location" VALUES(4904,NULL,'Norwalk, CT 6852',1971,222,NULL,8,2640,0);
INSERT INTO "django_geo_db_location" VALUES(4905,NULL,'Norwalk, CT 6853',1971,222,NULL,8,2641,0);
INSERT INTO "django_geo_db_location" VALUES(4906,NULL,'Norwalk, CT 6854',1971,222,NULL,8,2642,0);
INSERT INTO "django_geo_db_location" VALUES(4907,NULL,'Norwalk, CT 6855',1971,222,NULL,8,2643,0);
INSERT INTO "django_geo_db_location" VALUES(4908,NULL,'Norwalk, CT 6856',1971,222,NULL,8,2644,0);
INSERT INTO "django_geo_db_location" VALUES(4909,NULL,'Norwalk, CT 6857',1971,222,NULL,8,2645,0);
INSERT INTO "django_geo_db_location" VALUES(4910,NULL,'Norwalk, CT 6858',1971,222,NULL,8,2646,0);
INSERT INTO "django_geo_db_location" VALUES(4911,NULL,'Norwalk, CT 6859',1971,222,NULL,8,2647,0);
INSERT INTO "django_geo_db_location" VALUES(4912,NULL,'Norwalk, CT 6860',1971,222,NULL,8,2648,0);
INSERT INTO "django_geo_db_location" VALUES(4913,NULL,'Old Greenwich, CT',1972,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4914,NULL,'Old Greenwich, CT 6870',1972,222,NULL,8,2649,0);
INSERT INTO "django_geo_db_location" VALUES(4915,NULL,'Redding Center, CT',1973,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4916,NULL,'Redding Center, CT 6875',1973,222,NULL,8,2650,0);
INSERT INTO "django_geo_db_location" VALUES(4917,NULL,'Redding Ridge, CT',1974,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4918,NULL,'Redding Ridge, CT 6876',1974,222,NULL,8,2651,0);
INSERT INTO "django_geo_db_location" VALUES(4919,NULL,'Ridgefield, CT',1975,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4920,NULL,'Ridgefield, CT 6877',1975,222,NULL,8,2652,0);
INSERT INTO "django_geo_db_location" VALUES(4921,NULL,'Riverside, CT',1976,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4922,NULL,'Riverside, CT 6878',1976,222,NULL,8,2653,0);
INSERT INTO "django_geo_db_location" VALUES(4923,NULL,'Ridgefield, CT 6879',1975,222,NULL,8,2654,0);
INSERT INTO "django_geo_db_location" VALUES(4924,NULL,'Westport, CT',1977,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4925,NULL,'Westport, CT 6880',1977,222,NULL,8,2655,0);
INSERT INTO "django_geo_db_location" VALUES(4926,NULL,'Westport, CT 6881',1977,222,NULL,8,2656,0);
INSERT INTO "django_geo_db_location" VALUES(4927,NULL,'Weston, CT',1978,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4928,NULL,'Weston, CT 6883',1978,222,NULL,8,2657,0);
INSERT INTO "django_geo_db_location" VALUES(4929,NULL,'Westport, CT 6888',1977,222,NULL,8,2658,0);
INSERT INTO "django_geo_db_location" VALUES(4930,NULL,'Westport, CT 6889',1977,222,NULL,8,2659,0);
INSERT INTO "django_geo_db_location" VALUES(4931,NULL,'Fairfield, CT 6890',1878,222,NULL,8,2660,0);
INSERT INTO "django_geo_db_location" VALUES(4932,NULL,'Redding, CT',1979,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4933,NULL,'Redding, CT 6896',1979,222,NULL,8,2661,0);
INSERT INTO "django_geo_db_location" VALUES(4934,NULL,'Wilton, CT',1980,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4935,NULL,'Wilton, CT 6897',1980,222,NULL,8,2662,0);
INSERT INTO "django_geo_db_location" VALUES(4936,NULL,'Stamford, CT',1981,222,NULL,8,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4937,NULL,'Stamford, CT 6901',1981,222,NULL,8,2663,0);
INSERT INTO "django_geo_db_location" VALUES(4938,NULL,'Stamford, CT 6902',1981,222,NULL,8,2664,0);
INSERT INTO "django_geo_db_location" VALUES(4939,NULL,'Stamford, CT 6903',1981,222,NULL,8,2665,0);
INSERT INTO "django_geo_db_location" VALUES(4940,NULL,'Stamford, CT 6904',1981,222,NULL,8,2666,0);
INSERT INTO "django_geo_db_location" VALUES(4941,NULL,'Stamford, CT 6905',1981,222,NULL,8,2667,0);
INSERT INTO "django_geo_db_location" VALUES(4942,NULL,'Stamford, CT 6906',1981,222,NULL,8,2668,0);
INSERT INTO "django_geo_db_location" VALUES(4943,NULL,'Stamford, CT 6907',1981,222,NULL,8,2669,0);
INSERT INTO "django_geo_db_location" VALUES(4944,NULL,'Stamford, CT 6910',1981,222,NULL,8,2670,0);
INSERT INTO "django_geo_db_location" VALUES(4945,NULL,'Stamford, CT 6911',1981,222,NULL,8,2671,0);
INSERT INTO "django_geo_db_location" VALUES(4946,NULL,'Stamford, CT 6912',1981,222,NULL,8,2672,0);
INSERT INTO "django_geo_db_location" VALUES(4947,NULL,'Stamford, CT 6913',1981,222,NULL,8,2673,0);
INSERT INTO "django_geo_db_location" VALUES(4948,NULL,'Stamford, CT 6914',1981,222,NULL,8,2674,0);
INSERT INTO "django_geo_db_location" VALUES(4949,NULL,'Stamford, CT 6920',1981,222,NULL,8,2675,0);
INSERT INTO "django_geo_db_location" VALUES(4950,NULL,'Stamford, CT 6921',1981,222,NULL,8,2676,0);
INSERT INTO "django_geo_db_location" VALUES(4951,NULL,'Stamford, CT 6922',1981,222,NULL,8,2677,0);
INSERT INTO "django_geo_db_location" VALUES(4952,NULL,'Stamford, CT 6925',1981,222,NULL,8,2678,0);
INSERT INTO "django_geo_db_location" VALUES(4953,NULL,'Stamford, CT 6926',1981,222,NULL,8,2679,0);
INSERT INTO "django_geo_db_location" VALUES(4954,NULL,'Stamford, CT 6927',1981,222,NULL,8,2680,0);
INSERT INTO "django_geo_db_location" VALUES(4955,NULL,'Stamford, CT 6928',1981,222,NULL,8,2681,0);
INSERT INTO "django_geo_db_location" VALUES(4956,NULL,'Weston, CT 6993',1978,222,NULL,8,2682,0);
INSERT INTO "django_geo_db_location" VALUES(4957,NULL,'Avenel, NJ',1982,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4958,NULL,'Avenel, NJ 7001',1982,222,NULL,30,2683,0);
INSERT INTO "django_geo_db_location" VALUES(4959,NULL,'Bayonne, NJ',1983,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4960,NULL,'Bayonne, NJ 7002',1983,222,NULL,30,2684,0);
INSERT INTO "django_geo_db_location" VALUES(4961,NULL,'Bloomfield, NJ',1984,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4962,NULL,'Bloomfield, NJ 7003',1984,222,NULL,30,2685,0);
INSERT INTO "django_geo_db_location" VALUES(4963,NULL,'Fairfield, NJ',1985,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4964,NULL,'Fairfield, NJ 7004',1985,222,NULL,30,2686,0);
INSERT INTO "django_geo_db_location" VALUES(4965,NULL,'Boonton, NJ',1986,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4966,NULL,'Boonton, NJ 7005',1986,222,NULL,30,2687,0);
INSERT INTO "django_geo_db_location" VALUES(4967,NULL,'Caldwell, NJ',1987,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4968,NULL,'Caldwell, NJ 7006',1987,222,NULL,30,2688,0);
INSERT INTO "django_geo_db_location" VALUES(4969,NULL,'Caldwell, NJ 7007',1987,222,NULL,30,2689,0);
INSERT INTO "django_geo_db_location" VALUES(4970,NULL,'Carteret, NJ',1988,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4971,NULL,'Carteret, NJ 7008',1988,222,NULL,30,2690,0);
INSERT INTO "django_geo_db_location" VALUES(4972,NULL,'Cedar Grove, NJ',1989,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4973,NULL,'Cedar Grove, NJ 7009',1989,222,NULL,30,2691,0);
INSERT INTO "django_geo_db_location" VALUES(4974,NULL,'Cliffside Park, NJ',1990,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4975,NULL,'Cliffside Park, NJ 7010',1990,222,NULL,30,2692,0);
INSERT INTO "django_geo_db_location" VALUES(4976,NULL,'Clifton, NJ',1991,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4977,NULL,'Clifton, NJ 7011',1991,222,NULL,30,2693,0);
INSERT INTO "django_geo_db_location" VALUES(4978,NULL,'Clifton, NJ 7012',1991,222,NULL,30,2694,0);
INSERT INTO "django_geo_db_location" VALUES(4979,NULL,'Clifton, NJ 7013',1991,222,NULL,30,2695,0);
INSERT INTO "django_geo_db_location" VALUES(4980,NULL,'Clifton, NJ 7014',1991,222,NULL,30,2696,0);
INSERT INTO "django_geo_db_location" VALUES(4981,NULL,'Clifton, NJ 7015',1991,222,NULL,30,2697,0);
INSERT INTO "django_geo_db_location" VALUES(4982,NULL,'Cranford, NJ',1992,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4983,NULL,'Cranford, NJ 7016',1992,222,NULL,30,2698,0);
INSERT INTO "django_geo_db_location" VALUES(4984,NULL,'East Orange, NJ',1993,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4985,NULL,'East Orange, NJ 7017',1993,222,NULL,30,2699,0);
INSERT INTO "django_geo_db_location" VALUES(4986,NULL,'East Orange, NJ 7018',1993,222,NULL,30,2700,0);
INSERT INTO "django_geo_db_location" VALUES(4987,NULL,'East Orange, NJ 7019',1993,222,NULL,30,2701,0);
INSERT INTO "django_geo_db_location" VALUES(4988,NULL,'Edgewater, NJ',1994,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4989,NULL,'Edgewater, NJ 7020',1994,222,NULL,30,2702,0);
INSERT INTO "django_geo_db_location" VALUES(4990,NULL,'Essex Fells, NJ',1995,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4991,NULL,'Essex Fells, NJ 7021',1995,222,NULL,30,2703,0);
INSERT INTO "django_geo_db_location" VALUES(4992,NULL,'Fairview, NJ',1996,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4993,NULL,'Fairview, NJ 7022',1996,222,NULL,30,2704,0);
INSERT INTO "django_geo_db_location" VALUES(4994,NULL,'Fanwood, NJ',1997,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4995,NULL,'Fanwood, NJ 7023',1997,222,NULL,30,2705,0);
INSERT INTO "django_geo_db_location" VALUES(4996,NULL,'Fort Lee, NJ',1998,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4997,NULL,'Fort Lee, NJ 7024',1998,222,NULL,30,2706,0);
INSERT INTO "django_geo_db_location" VALUES(4998,NULL,'Garfield, NJ',1999,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(4999,NULL,'Garfield, NJ 7026',1999,222,NULL,30,2707,0);
INSERT INTO "django_geo_db_location" VALUES(5000,NULL,'Garwood, NJ',2000,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5001,NULL,'Garwood, NJ 7027',2000,222,NULL,30,2708,0);
INSERT INTO "django_geo_db_location" VALUES(5002,NULL,'Glen Ridge, NJ',2001,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5003,NULL,'Glen Ridge, NJ 7028',2001,222,NULL,30,2709,0);
INSERT INTO "django_geo_db_location" VALUES(5004,NULL,'Harrison, NJ',2002,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5005,NULL,'Harrison, NJ 7029',2002,222,NULL,30,2710,0);
INSERT INTO "django_geo_db_location" VALUES(5006,NULL,'Hoboken, NJ',2003,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5007,NULL,'Hoboken, NJ 7030',2003,222,NULL,30,2711,0);
INSERT INTO "django_geo_db_location" VALUES(5008,NULL,'North Arlington, NJ',2004,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5009,NULL,'North Arlington, NJ 7031',2004,222,NULL,30,2712,0);
INSERT INTO "django_geo_db_location" VALUES(5010,NULL,'Kearny, NJ',2005,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5011,NULL,'Kearny, NJ 7032',2005,222,NULL,30,2713,0);
INSERT INTO "django_geo_db_location" VALUES(5012,NULL,'Kenilworth, NJ',2006,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5013,NULL,'Kenilworth, NJ 7033',2006,222,NULL,30,2714,0);
INSERT INTO "django_geo_db_location" VALUES(5014,NULL,'Lake Hiawatha, NJ',2007,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5015,NULL,'Lake Hiawatha, NJ 7034',2007,222,NULL,30,2715,0);
INSERT INTO "django_geo_db_location" VALUES(5016,NULL,'Lincoln Park, NJ',2008,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5017,NULL,'Lincoln Park, NJ 7035',2008,222,NULL,30,2716,0);
INSERT INTO "django_geo_db_location" VALUES(5018,NULL,'Linden, NJ',2009,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5019,NULL,'Linden, NJ 7036',2009,222,NULL,30,2717,0);
INSERT INTO "django_geo_db_location" VALUES(5020,NULL,'Livingston, NJ',2010,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5021,NULL,'Livingston, NJ 7039',2010,222,NULL,30,2718,0);
INSERT INTO "django_geo_db_location" VALUES(5022,NULL,'Maplewood, NJ',2011,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5023,NULL,'Maplewood, NJ 7040',2011,222,NULL,30,2719,0);
INSERT INTO "django_geo_db_location" VALUES(5024,NULL,'Millburn, NJ',2012,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5025,NULL,'Millburn, NJ 7041',2012,222,NULL,30,2720,0);
INSERT INTO "django_geo_db_location" VALUES(5026,NULL,'Montclair, NJ',2013,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5027,NULL,'Montclair, NJ 7042',2013,222,NULL,30,2721,0);
INSERT INTO "django_geo_db_location" VALUES(5028,NULL,'Montclair, NJ 7043',2013,222,NULL,30,2722,0);
INSERT INTO "django_geo_db_location" VALUES(5029,NULL,'Verona, NJ',2014,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5030,NULL,'Verona, NJ 7044',2014,222,NULL,30,2723,0);
INSERT INTO "django_geo_db_location" VALUES(5031,NULL,'Montville, NJ',2015,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5032,NULL,'Montville, NJ 7045',2015,222,NULL,30,2724,0);
INSERT INTO "django_geo_db_location" VALUES(5033,NULL,'Mountain Lakes, NJ',2016,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5034,NULL,'Mountain Lakes, NJ 7046',2016,222,NULL,30,2725,0);
INSERT INTO "django_geo_db_location" VALUES(5035,NULL,'North Bergen, NJ',2017,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5036,NULL,'North Bergen, NJ 7047',2017,222,NULL,30,2726,0);
INSERT INTO "django_geo_db_location" VALUES(5037,NULL,'Orange, NJ',2018,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5038,NULL,'Orange, NJ 7050',2018,222,NULL,30,2727,0);
INSERT INTO "django_geo_db_location" VALUES(5039,NULL,'Orange, NJ 7051',2018,222,NULL,30,2728,0);
INSERT INTO "django_geo_db_location" VALUES(5040,NULL,'West Orange, NJ',2019,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5041,NULL,'West Orange, NJ 7052',2019,222,NULL,30,2729,0);
INSERT INTO "django_geo_db_location" VALUES(5042,NULL,'Parsippany, NJ',2020,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5043,NULL,'Parsippany, NJ 7054',2020,222,NULL,30,2730,0);
INSERT INTO "django_geo_db_location" VALUES(5044,NULL,'Passaic, NJ',2021,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5045,NULL,'Passaic, NJ 7055',2021,222,NULL,30,2731,0);
INSERT INTO "django_geo_db_location" VALUES(5046,NULL,'Wallington, NJ',2022,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5047,NULL,'Wallington, NJ 7057',2022,222,NULL,30,2732,0);
INSERT INTO "django_geo_db_location" VALUES(5048,NULL,'Pine Brook, NJ',2023,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5049,NULL,'Pine Brook, NJ 7058',2023,222,NULL,30,2733,0);
INSERT INTO "django_geo_db_location" VALUES(5050,NULL,'Warren, NJ',2024,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5051,NULL,'Warren, NJ 7059',2024,222,NULL,30,2734,0);
INSERT INTO "django_geo_db_location" VALUES(5052,NULL,'Plainfield, NJ',2025,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5053,NULL,'Plainfield, NJ 7060',2025,222,NULL,30,2735,0);
INSERT INTO "django_geo_db_location" VALUES(5054,NULL,'Plainfield, NJ 7061',2025,222,NULL,30,2736,0);
INSERT INTO "django_geo_db_location" VALUES(5055,NULL,'Plainfield, NJ 7062',2025,222,NULL,30,2737,0);
INSERT INTO "django_geo_db_location" VALUES(5056,NULL,'Plainfield, NJ 7063',2025,222,NULL,30,2738,0);
INSERT INTO "django_geo_db_location" VALUES(5057,NULL,'Port Reading, NJ',2026,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5058,NULL,'Port Reading, NJ 7064',2026,222,NULL,30,2739,0);
INSERT INTO "django_geo_db_location" VALUES(5059,NULL,'Rahway, NJ',2027,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5060,NULL,'Rahway, NJ 7065',2027,222,NULL,30,2740,0);
INSERT INTO "django_geo_db_location" VALUES(5061,NULL,'Clark, NJ',2028,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5062,NULL,'Clark, NJ 7066',2028,222,NULL,30,2741,0);
INSERT INTO "django_geo_db_location" VALUES(5063,NULL,'Colonia, NJ',2029,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5064,NULL,'Colonia, NJ 7067',2029,222,NULL,30,2742,0);
INSERT INTO "django_geo_db_location" VALUES(5065,NULL,'Roseland, NJ',2030,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5066,NULL,'Roseland, NJ 7068',2030,222,NULL,30,2743,0);
INSERT INTO "django_geo_db_location" VALUES(5067,NULL,'Watchung, NJ',2031,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5068,NULL,'Watchung, NJ 7069',2031,222,NULL,30,2744,0);
INSERT INTO "django_geo_db_location" VALUES(5069,NULL,'Rutherford, NJ',2032,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5070,NULL,'Rutherford, NJ 7070',2032,222,NULL,30,2745,0);
INSERT INTO "django_geo_db_location" VALUES(5071,NULL,'Lyndhurst, NJ',2033,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5072,NULL,'Lyndhurst, NJ 7071',2033,222,NULL,30,2746,0);
INSERT INTO "django_geo_db_location" VALUES(5073,NULL,'Carlstadt, NJ',2034,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5074,NULL,'Carlstadt, NJ 7072',2034,222,NULL,30,2747,0);
INSERT INTO "django_geo_db_location" VALUES(5075,NULL,'East Rutherford, NJ',2035,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5076,NULL,'East Rutherford, NJ 7073',2035,222,NULL,30,2748,0);
INSERT INTO "django_geo_db_location" VALUES(5077,NULL,'Moonachie, NJ',2036,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5078,NULL,'Moonachie, NJ 7074',2036,222,NULL,30,2749,0);
INSERT INTO "django_geo_db_location" VALUES(5079,NULL,'Wood Ridge, NJ',2037,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5080,NULL,'Wood Ridge, NJ 7075',2037,222,NULL,30,2750,0);
INSERT INTO "django_geo_db_location" VALUES(5081,NULL,'Scotch Plains, NJ',2038,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5082,NULL,'Scotch Plains, NJ 7076',2038,222,NULL,30,2751,0);
INSERT INTO "django_geo_db_location" VALUES(5083,NULL,'Sewaren, NJ',2039,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5084,NULL,'Sewaren, NJ 7077',2039,222,NULL,30,2752,0);
INSERT INTO "django_geo_db_location" VALUES(5085,NULL,'Short Hills, NJ',2040,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5086,NULL,'Short Hills, NJ 7078',2040,222,NULL,30,2753,0);
INSERT INTO "django_geo_db_location" VALUES(5087,NULL,'South Orange, NJ',2041,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5088,NULL,'South Orange, NJ 7079',2041,222,NULL,30,2754,0);
INSERT INTO "django_geo_db_location" VALUES(5089,NULL,'South Plainfield, NJ',2042,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5090,NULL,'South Plainfield, NJ 7080',2042,222,NULL,30,2755,0);
INSERT INTO "django_geo_db_location" VALUES(5091,NULL,'Springfield, NJ',2043,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5092,NULL,'Springfield, NJ 7081',2043,222,NULL,30,2756,0);
INSERT INTO "django_geo_db_location" VALUES(5093,NULL,'Towaco, NJ',2044,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5094,NULL,'Towaco, NJ 7082',2044,222,NULL,30,2757,0);
INSERT INTO "django_geo_db_location" VALUES(5095,NULL,'Union, NJ',2045,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5096,NULL,'Union, NJ 7083',2045,222,NULL,30,2758,0);
INSERT INTO "django_geo_db_location" VALUES(5097,NULL,'Union City, NJ',2046,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5098,NULL,'Union City, NJ 7086',2046,222,NULL,30,2759,0);
INSERT INTO "django_geo_db_location" VALUES(5099,NULL,'Union City, NJ 7087',2046,222,NULL,30,2760,0);
INSERT INTO "django_geo_db_location" VALUES(5100,NULL,'Vauxhall, NJ',2047,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5101,NULL,'Vauxhall, NJ 7088',2047,222,NULL,30,2761,0);
INSERT INTO "django_geo_db_location" VALUES(5102,NULL,'Westfield, NJ',2048,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5103,NULL,'Westfield, NJ 7090',2048,222,NULL,30,2762,0);
INSERT INTO "django_geo_db_location" VALUES(5104,NULL,'Westfield, NJ 7091',2048,222,NULL,30,2763,0);
INSERT INTO "django_geo_db_location" VALUES(5105,NULL,'Mountainside, NJ',2049,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5106,NULL,'Mountainside, NJ 7092',2049,222,NULL,30,2764,0);
INSERT INTO "django_geo_db_location" VALUES(5107,NULL,'West New York, NJ',2050,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5108,NULL,'West New York, NJ 7093',2050,222,NULL,30,2765,0);
INSERT INTO "django_geo_db_location" VALUES(5109,NULL,'Secaucus, NJ',2051,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5110,NULL,'Secaucus, NJ 7094',2051,222,NULL,30,2766,0);
INSERT INTO "django_geo_db_location" VALUES(5111,NULL,'Woodbridge, NJ',2052,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5112,NULL,'Woodbridge, NJ 7095',2052,222,NULL,30,2767,0);
INSERT INTO "django_geo_db_location" VALUES(5113,NULL,'Secaucus, NJ 7096',2051,222,NULL,30,2768,0);
INSERT INTO "django_geo_db_location" VALUES(5114,NULL,'Jersey City, NJ',2053,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5115,NULL,'Jersey City, NJ 7097',2053,222,NULL,30,2769,0);
INSERT INTO "django_geo_db_location" VALUES(5116,NULL,'Kearny, NJ 7099',2005,222,NULL,30,2770,0);
INSERT INTO "django_geo_db_location" VALUES(5117,NULL,'Newark, NJ',2054,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5118,NULL,'Newark, NJ 7101',2054,222,NULL,30,2771,0);
INSERT INTO "django_geo_db_location" VALUES(5119,NULL,'Newark, NJ 7102',2054,222,NULL,30,2772,0);
INSERT INTO "django_geo_db_location" VALUES(5120,NULL,'Newark, NJ 7103',2054,222,NULL,30,2773,0);
INSERT INTO "django_geo_db_location" VALUES(5121,NULL,'Newark, NJ 7104',2054,222,NULL,30,2774,0);
INSERT INTO "django_geo_db_location" VALUES(5122,NULL,'Newark, NJ 7105',2054,222,NULL,30,2775,0);
INSERT INTO "django_geo_db_location" VALUES(5123,NULL,'Newark, NJ 7106',2054,222,NULL,30,2776,0);
INSERT INTO "django_geo_db_location" VALUES(5124,NULL,'Newark, NJ 7107',2054,222,NULL,30,2777,0);
INSERT INTO "django_geo_db_location" VALUES(5125,NULL,'Newark, NJ 7108',2054,222,NULL,30,2778,0);
INSERT INTO "django_geo_db_location" VALUES(5126,NULL,'Belleville, NJ',2055,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5127,NULL,'Belleville, NJ 7109',2055,222,NULL,30,2779,0);
INSERT INTO "django_geo_db_location" VALUES(5128,NULL,'Nutley, NJ',2056,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5129,NULL,'Nutley, NJ 7110',2056,222,NULL,30,2780,0);
INSERT INTO "django_geo_db_location" VALUES(5130,NULL,'Irvington, NJ',2057,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5131,NULL,'Irvington, NJ 7111',2057,222,NULL,30,2781,0);
INSERT INTO "django_geo_db_location" VALUES(5132,NULL,'Newark, NJ 7112',2054,222,NULL,30,2782,0);
INSERT INTO "django_geo_db_location" VALUES(5133,NULL,'Newark, NJ 7114',2054,222,NULL,30,2783,0);
INSERT INTO "django_geo_db_location" VALUES(5134,NULL,'Newark, NJ 7115',2054,222,NULL,30,2784,0);
INSERT INTO "django_geo_db_location" VALUES(5135,NULL,'Newark, NJ 7175',2054,222,NULL,30,2785,0);
INSERT INTO "django_geo_db_location" VALUES(5136,NULL,'Newark, NJ 7182',2054,222,NULL,30,2786,0);
INSERT INTO "django_geo_db_location" VALUES(5137,NULL,'Newark, NJ 7184',2054,222,NULL,30,2787,0);
INSERT INTO "django_geo_db_location" VALUES(5138,NULL,'Newark, NJ 7188',2054,222,NULL,30,2788,0);
INSERT INTO "django_geo_db_location" VALUES(5139,NULL,'Newark, NJ 7189',2054,222,NULL,30,2789,0);
INSERT INTO "django_geo_db_location" VALUES(5140,NULL,'Newark, NJ 7191',2054,222,NULL,30,2790,0);
INSERT INTO "django_geo_db_location" VALUES(5141,NULL,'Newark, NJ 7192',2054,222,NULL,30,2791,0);
INSERT INTO "django_geo_db_location" VALUES(5142,NULL,'Newark, NJ 7193',2054,222,NULL,30,2792,0);
INSERT INTO "django_geo_db_location" VALUES(5143,NULL,'Newark, NJ 7194',2054,222,NULL,30,2793,0);
INSERT INTO "django_geo_db_location" VALUES(5144,NULL,'Newark, NJ 7195',2054,222,NULL,30,2794,0);
INSERT INTO "django_geo_db_location" VALUES(5145,NULL,'Newark, NJ 7197',2054,222,NULL,30,2795,0);
INSERT INTO "django_geo_db_location" VALUES(5146,NULL,'Newark, NJ 7198',2054,222,NULL,30,2796,0);
INSERT INTO "django_geo_db_location" VALUES(5147,NULL,'Newark, NJ 7199',2054,222,NULL,30,2797,0);
INSERT INTO "django_geo_db_location" VALUES(5148,NULL,'Elizabeth, NJ',2058,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5149,NULL,'Elizabeth, NJ 7201',2058,222,NULL,30,2798,0);
INSERT INTO "django_geo_db_location" VALUES(5150,NULL,'Elizabeth, NJ 7202',2058,222,NULL,30,2799,0);
INSERT INTO "django_geo_db_location" VALUES(5151,NULL,'Roselle, NJ',2059,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5152,NULL,'Roselle, NJ 7203',2059,222,NULL,30,2800,0);
INSERT INTO "django_geo_db_location" VALUES(5153,NULL,'Roselle Park, NJ',2060,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5154,NULL,'Roselle Park, NJ 7204',2060,222,NULL,30,2801,0);
INSERT INTO "django_geo_db_location" VALUES(5155,NULL,'Hillside, NJ',2061,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5156,NULL,'Hillside, NJ 7205',2061,222,NULL,30,2802,0);
INSERT INTO "django_geo_db_location" VALUES(5157,NULL,'Elizabeth, NJ 7206',2058,222,NULL,30,2803,0);
INSERT INTO "django_geo_db_location" VALUES(5158,NULL,'Elizabeth, NJ 7207',2058,222,NULL,30,2804,0);
INSERT INTO "django_geo_db_location" VALUES(5159,NULL,'Elizabeth, NJ 7208',2058,222,NULL,30,2805,0);
INSERT INTO "django_geo_db_location" VALUES(5160,NULL,'Bernards, NJ',2062,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5161,NULL,'Bernards, NJ 7290',2062,222,NULL,30,2806,0);
INSERT INTO "django_geo_db_location" VALUES(5162,NULL,'Jersey City, NJ 7301',2053,222,NULL,30,2807,0);
INSERT INTO "django_geo_db_location" VALUES(5163,NULL,'Jersey City, NJ 7302',2053,222,NULL,30,2808,0);
INSERT INTO "django_geo_db_location" VALUES(5164,NULL,'Jersey City, NJ 7303',2053,222,NULL,30,2809,0);
INSERT INTO "django_geo_db_location" VALUES(5165,NULL,'Jersey City, NJ 7304',2053,222,NULL,30,2810,0);
INSERT INTO "django_geo_db_location" VALUES(5166,NULL,'Jersey City, NJ 7305',2053,222,NULL,30,2811,0);
INSERT INTO "django_geo_db_location" VALUES(5167,NULL,'Jersey City, NJ 7306',2053,222,NULL,30,2812,0);
INSERT INTO "django_geo_db_location" VALUES(5168,NULL,'Jersey City, NJ 7307',2053,222,NULL,30,2813,0);
INSERT INTO "django_geo_db_location" VALUES(5169,NULL,'Jersey City, NJ 7308',2053,222,NULL,30,2814,0);
INSERT INTO "django_geo_db_location" VALUES(5170,NULL,'Jersey City, NJ 7309',2053,222,NULL,30,2815,0);
INSERT INTO "django_geo_db_location" VALUES(5171,NULL,'Jersey City, NJ 7310',2053,222,NULL,30,2816,0);
INSERT INTO "django_geo_db_location" VALUES(5172,NULL,'Jersey City, NJ 7311',2053,222,NULL,30,2817,0);
INSERT INTO "django_geo_db_location" VALUES(5173,NULL,'Jersey City, NJ 7399',2053,222,NULL,30,2818,0);
INSERT INTO "django_geo_db_location" VALUES(5174,NULL,'Allendale, NJ',2063,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5175,NULL,'Allendale, NJ 7401',2063,222,NULL,30,2819,0);
INSERT INTO "django_geo_db_location" VALUES(5176,NULL,'Bloomingdale, NJ',2064,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5177,NULL,'Bloomingdale, NJ 7403',2064,222,NULL,30,2820,0);
INSERT INTO "django_geo_db_location" VALUES(5178,NULL,'Butler, NJ',2065,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5179,NULL,'Butler, NJ 7405',2065,222,NULL,30,2821,0);
INSERT INTO "django_geo_db_location" VALUES(5180,NULL,'Elmwood Park, NJ',2066,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5181,NULL,'Elmwood Park, NJ 7407',2066,222,NULL,30,2822,0);
INSERT INTO "django_geo_db_location" VALUES(5182,NULL,'Fair Lawn, NJ',2067,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5183,NULL,'Fair Lawn, NJ 7410',2067,222,NULL,30,2823,0);
INSERT INTO "django_geo_db_location" VALUES(5184,NULL,'Franklin, NJ',2068,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5185,NULL,'Franklin, NJ 7416',2068,222,NULL,30,2824,0);
INSERT INTO "django_geo_db_location" VALUES(5186,NULL,'Franklin Lakes, NJ',2069,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5187,NULL,'Franklin Lakes, NJ 7417',2069,222,NULL,30,2825,0);
INSERT INTO "django_geo_db_location" VALUES(5188,NULL,'Glenwood, NJ',2070,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5189,NULL,'Glenwood, NJ 7418',2070,222,NULL,30,2826,0);
INSERT INTO "django_geo_db_location" VALUES(5190,NULL,'Hamburg, NJ',2071,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5191,NULL,'Hamburg, NJ 7419',2071,222,NULL,30,2827,0);
INSERT INTO "django_geo_db_location" VALUES(5192,NULL,'Haskell, NJ',2072,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5193,NULL,'Haskell, NJ 7420',2072,222,NULL,30,2828,0);
INSERT INTO "django_geo_db_location" VALUES(5194,NULL,'Hewitt, NJ',2073,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5195,NULL,'Hewitt, NJ 7421',2073,222,NULL,30,2829,0);
INSERT INTO "django_geo_db_location" VALUES(5196,NULL,'Highland Lakes, NJ',2074,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5197,NULL,'Highland Lakes, NJ 7422',2074,222,NULL,30,2830,0);
INSERT INTO "django_geo_db_location" VALUES(5198,NULL,'Ho Ho Kus, NJ',2075,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5199,NULL,'Ho Ho Kus, NJ 7423',2075,222,NULL,30,2831,0);
INSERT INTO "django_geo_db_location" VALUES(5200,NULL,'Little Falls, NJ',2076,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5201,NULL,'Little Falls, NJ 7424',2076,222,NULL,30,2832,0);
INSERT INTO "django_geo_db_location" VALUES(5202,NULL,'West Paterson, NJ',2077,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5203,NULL,'West Paterson, NJ 7427',2077,222,NULL,30,2833,0);
INSERT INTO "django_geo_db_location" VALUES(5204,NULL,'McAfee, NJ',2078,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5205,NULL,'McAfee, NJ 7428',2078,222,NULL,30,2834,0);
INSERT INTO "django_geo_db_location" VALUES(5206,NULL,'Mahwah, NJ',2079,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5207,NULL,'Mahwah, NJ 7430',2079,222,NULL,30,2835,0);
INSERT INTO "django_geo_db_location" VALUES(5208,NULL,'Midland Park, NJ',2080,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5209,NULL,'Midland Park, NJ 7432',2080,222,NULL,30,2836,0);
INSERT INTO "django_geo_db_location" VALUES(5210,NULL,'Newfoundland, NJ',2081,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5211,NULL,'Newfoundland, NJ 7435',2081,222,NULL,30,2837,0);
INSERT INTO "django_geo_db_location" VALUES(5212,NULL,'Oakland, NJ',2082,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5213,NULL,'Oakland, NJ 7436',2082,222,NULL,30,2838,0);
INSERT INTO "django_geo_db_location" VALUES(5214,NULL,'Oak Ridge, NJ',2083,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5215,NULL,'Oak Ridge, NJ 7438',2083,222,NULL,30,2839,0);
INSERT INTO "django_geo_db_location" VALUES(5216,NULL,'Ogdensburg, NJ',2084,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5217,NULL,'Ogdensburg, NJ 7439',2084,222,NULL,30,2840,0);
INSERT INTO "django_geo_db_location" VALUES(5218,NULL,'Pequannock, NJ',2085,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5219,NULL,'Pequannock, NJ 7440',2085,222,NULL,30,2841,0);
INSERT INTO "django_geo_db_location" VALUES(5220,NULL,'Pompton Lakes, NJ',2086,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5221,NULL,'Pompton Lakes, NJ 7442',2086,222,NULL,30,2842,0);
INSERT INTO "django_geo_db_location" VALUES(5222,NULL,'Pompton Plains, NJ',2087,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5223,NULL,'Pompton Plains, NJ 7444',2087,222,NULL,30,2843,0);
INSERT INTO "django_geo_db_location" VALUES(5224,NULL,'Ramsey, NJ',2088,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5225,NULL,'Ramsey, NJ 7446',2088,222,NULL,30,2844,0);
INSERT INTO "django_geo_db_location" VALUES(5226,NULL,'Ridgewood, NJ',2089,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5227,NULL,'Ridgewood, NJ 7450',2089,222,NULL,30,2845,0);
INSERT INTO "django_geo_db_location" VALUES(5228,NULL,'Ridgewood, NJ 7451',2089,222,NULL,30,2846,0);
INSERT INTO "django_geo_db_location" VALUES(5229,NULL,'Glen Rock, NJ',2090,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5230,NULL,'Glen Rock, NJ 7452',2090,222,NULL,30,2847,0);
INSERT INTO "django_geo_db_location" VALUES(5231,NULL,'Ringwood, NJ',2091,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5232,NULL,'Ringwood, NJ 7456',2091,222,NULL,30,2848,0);
INSERT INTO "django_geo_db_location" VALUES(5233,NULL,'Riverdale, NJ',2092,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5234,NULL,'Riverdale, NJ 7457',2092,222,NULL,30,2849,0);
INSERT INTO "django_geo_db_location" VALUES(5235,NULL,'Saddle River, NJ',2093,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5236,NULL,'Saddle River, NJ 7458',2093,222,NULL,30,2850,0);
INSERT INTO "django_geo_db_location" VALUES(5237,NULL,'Stockholm, NJ',2094,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5238,NULL,'Stockholm, NJ 7460',2094,222,NULL,30,2851,0);
INSERT INTO "django_geo_db_location" VALUES(5239,NULL,'Sussex, NJ',2095,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5240,NULL,'Sussex, NJ 7461',2095,222,NULL,30,2852,0);
INSERT INTO "django_geo_db_location" VALUES(5241,NULL,'Vernon, NJ',2096,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5242,NULL,'Vernon, NJ 7462',2096,222,NULL,30,2853,0);
INSERT INTO "django_geo_db_location" VALUES(5243,NULL,'Waldwick, NJ',2097,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5244,NULL,'Waldwick, NJ 7463',2097,222,NULL,30,2854,0);
INSERT INTO "django_geo_db_location" VALUES(5245,NULL,'Wanaque, NJ',2098,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5246,NULL,'Wanaque, NJ 7465',2098,222,NULL,30,2855,0);
INSERT INTO "django_geo_db_location" VALUES(5247,NULL,'Wayne, NJ',2099,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5248,NULL,'Wayne, NJ 7470',2099,222,NULL,30,2856,0);
INSERT INTO "django_geo_db_location" VALUES(5249,NULL,'Wayne, NJ 7474',2099,222,NULL,30,2857,0);
INSERT INTO "django_geo_db_location" VALUES(5250,NULL,'Wayne, NJ 7477',2099,222,NULL,30,2858,0);
INSERT INTO "django_geo_db_location" VALUES(5251,NULL,'West Milford, NJ',2100,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5252,NULL,'West Milford, NJ 7480',2100,222,NULL,30,2859,0);
INSERT INTO "django_geo_db_location" VALUES(5253,NULL,'Wyckoff, NJ',2101,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5254,NULL,'Wyckoff, NJ 7481',2101,222,NULL,30,2860,0);
INSERT INTO "django_geo_db_location" VALUES(5255,NULL,'Mahwah, NJ 7495',2079,222,NULL,30,2861,0);
INSERT INTO "django_geo_db_location" VALUES(5256,NULL,'Mahwah, NJ 7498',2079,222,NULL,30,2862,0);
INSERT INTO "django_geo_db_location" VALUES(5257,NULL,'Paterson, NJ',2102,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5258,NULL,'Paterson, NJ 7501',2102,222,NULL,30,2863,0);
INSERT INTO "django_geo_db_location" VALUES(5259,NULL,'Paterson, NJ 7502',2102,222,NULL,30,2864,0);
INSERT INTO "django_geo_db_location" VALUES(5260,NULL,'Paterson, NJ 7503',2102,222,NULL,30,2865,0);
INSERT INTO "django_geo_db_location" VALUES(5261,NULL,'Paterson, NJ 7504',2102,222,NULL,30,2866,0);
INSERT INTO "django_geo_db_location" VALUES(5262,NULL,'Paterson, NJ 7505',2102,222,NULL,30,2867,0);
INSERT INTO "django_geo_db_location" VALUES(5263,NULL,'Hawthorne, NJ',2103,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5264,NULL,'Hawthorne, NJ 7506',2103,222,NULL,30,2868,0);
INSERT INTO "django_geo_db_location" VALUES(5265,NULL,'Hawthorne, NJ 7507',2103,222,NULL,30,2869,0);
INSERT INTO "django_geo_db_location" VALUES(5266,NULL,'Haledon, NJ',2104,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5267,NULL,'Haledon, NJ 7508',2104,222,NULL,30,2870,0);
INSERT INTO "django_geo_db_location" VALUES(5268,NULL,'Paterson, NJ 7509',2102,222,NULL,30,2871,0);
INSERT INTO "django_geo_db_location" VALUES(5269,NULL,'Paterson, NJ 7510',2102,222,NULL,30,2872,0);
INSERT INTO "django_geo_db_location" VALUES(5270,NULL,'Totowa, NJ',2105,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5271,NULL,'Totowa, NJ 7511',2105,222,NULL,30,2873,0);
INSERT INTO "django_geo_db_location" VALUES(5272,NULL,'Totowa, NJ 7512',2105,222,NULL,30,2874,0);
INSERT INTO "django_geo_db_location" VALUES(5273,NULL,'Paterson, NJ 7513',2102,222,NULL,30,2875,0);
INSERT INTO "django_geo_db_location" VALUES(5274,NULL,'Paterson, NJ 7514',2102,222,NULL,30,2876,0);
INSERT INTO "django_geo_db_location" VALUES(5275,NULL,'Paterson, NJ 7522',2102,222,NULL,30,2877,0);
INSERT INTO "django_geo_db_location" VALUES(5276,NULL,'Paterson, NJ 7524',2102,222,NULL,30,2878,0);
INSERT INTO "django_geo_db_location" VALUES(5277,NULL,'Paterson, NJ 7530',2102,222,NULL,30,2879,0);
INSERT INTO "django_geo_db_location" VALUES(5278,NULL,'Paterson, NJ 7533',2102,222,NULL,30,2880,0);
INSERT INTO "django_geo_db_location" VALUES(5279,NULL,'Haledon, NJ 7538',2104,222,NULL,30,2881,0);
INSERT INTO "django_geo_db_location" VALUES(5280,NULL,'Paterson, NJ 7543',2102,222,NULL,30,2882,0);
INSERT INTO "django_geo_db_location" VALUES(5281,NULL,'Paterson, NJ 7544',2102,222,NULL,30,2883,0);
INSERT INTO "django_geo_db_location" VALUES(5282,NULL,'Totowa, NJ 7571',2105,222,NULL,30,2884,0);
INSERT INTO "django_geo_db_location" VALUES(5283,NULL,'Hackensack, NJ',2106,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5284,NULL,'Hackensack, NJ 7601',2106,222,NULL,30,2885,0);
INSERT INTO "django_geo_db_location" VALUES(5285,NULL,'Hackensack, NJ 7602',2106,222,NULL,30,2886,0);
INSERT INTO "django_geo_db_location" VALUES(5286,NULL,'Bogota, NJ',2107,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5287,NULL,'Bogota, NJ 7603',2107,222,NULL,30,2887,0);
INSERT INTO "django_geo_db_location" VALUES(5288,NULL,'Hasbrouck Heights, NJ',2108,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5289,NULL,'Hasbrouck Heights, NJ 7604',2108,222,NULL,30,2888,0);
INSERT INTO "django_geo_db_location" VALUES(5290,NULL,'Leonia, NJ',2109,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5291,NULL,'Leonia, NJ 7605',2109,222,NULL,30,2889,0);
INSERT INTO "django_geo_db_location" VALUES(5292,NULL,'South Hackensack, NJ',2110,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5293,NULL,'South Hackensack, NJ 7606',2110,222,NULL,30,2890,0);
INSERT INTO "django_geo_db_location" VALUES(5294,NULL,'Maywood, NJ',2111,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5295,NULL,'Maywood, NJ 7607',2111,222,NULL,30,2891,0);
INSERT INTO "django_geo_db_location" VALUES(5296,NULL,'Teterboro, NJ',2112,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5297,NULL,'Teterboro, NJ 7608',2112,222,NULL,30,2892,0);
INSERT INTO "django_geo_db_location" VALUES(5298,NULL,'Oradell, NJ',2113,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5299,NULL,'Oradell, NJ 7610',2113,222,NULL,30,2893,0);
INSERT INTO "django_geo_db_location" VALUES(5300,NULL,'Alpine, NJ',2114,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5301,NULL,'Alpine, NJ 7620',2114,222,NULL,30,2894,0);
INSERT INTO "django_geo_db_location" VALUES(5302,NULL,'Bergenfield, NJ',2115,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5303,NULL,'Bergenfield, NJ 7621',2115,222,NULL,30,2895,0);
INSERT INTO "django_geo_db_location" VALUES(5304,NULL,'Closter, NJ',2116,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5305,NULL,'Closter, NJ 7624',2116,222,NULL,30,2896,0);
INSERT INTO "django_geo_db_location" VALUES(5306,NULL,'Cresskill, NJ',2117,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5307,NULL,'Cresskill, NJ 7626',2117,222,NULL,30,2897,0);
INSERT INTO "django_geo_db_location" VALUES(5308,NULL,'Demarest, NJ',2118,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5309,NULL,'Demarest, NJ 7627',2118,222,NULL,30,2898,0);
INSERT INTO "django_geo_db_location" VALUES(5310,NULL,'Dumont, NJ',2119,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5311,NULL,'Dumont, NJ 7628',2119,222,NULL,30,2899,0);
INSERT INTO "django_geo_db_location" VALUES(5312,NULL,'Emerson, NJ',2120,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5313,NULL,'Emerson, NJ 7630',2120,222,NULL,30,2900,0);
INSERT INTO "django_geo_db_location" VALUES(5314,NULL,'Englewood, NJ',2121,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5315,NULL,'Englewood, NJ 7631',2121,222,NULL,30,2901,0);
INSERT INTO "django_geo_db_location" VALUES(5316,NULL,'Englewood Cliffs, NJ',2122,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5317,NULL,'Englewood Cliffs, NJ 7632',2122,222,NULL,30,2902,0);
INSERT INTO "django_geo_db_location" VALUES(5318,NULL,'Harrington Park, NJ',2123,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5319,NULL,'Harrington Park, NJ 7640',2123,222,NULL,30,2903,0);
INSERT INTO "django_geo_db_location" VALUES(5320,NULL,'Haworth, NJ',2124,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5321,NULL,'Haworth, NJ 7641',2124,222,NULL,30,2904,0);
INSERT INTO "django_geo_db_location" VALUES(5322,NULL,'Hillsdale, NJ',2125,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5323,NULL,'Hillsdale, NJ 7642',2125,222,NULL,30,2905,0);
INSERT INTO "django_geo_db_location" VALUES(5324,NULL,'Little Ferry, NJ',2126,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5325,NULL,'Little Ferry, NJ 7643',2126,222,NULL,30,2906,0);
INSERT INTO "django_geo_db_location" VALUES(5326,NULL,'Lodi, NJ',2127,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5327,NULL,'Lodi, NJ 7644',2127,222,NULL,30,2907,0);
INSERT INTO "django_geo_db_location" VALUES(5328,NULL,'Montvale, NJ',2128,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5329,NULL,'Montvale, NJ 7645',2128,222,NULL,30,2908,0);
INSERT INTO "django_geo_db_location" VALUES(5330,NULL,'New Milford, NJ',2129,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5331,NULL,'New Milford, NJ 7646',2129,222,NULL,30,2909,0);
INSERT INTO "django_geo_db_location" VALUES(5332,NULL,'Northvale, NJ',2130,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5333,NULL,'Northvale, NJ 7647',2130,222,NULL,30,2910,0);
INSERT INTO "django_geo_db_location" VALUES(5334,NULL,'Norwood, NJ',2131,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5335,NULL,'Norwood, NJ 7648',2131,222,NULL,30,2911,0);
INSERT INTO "django_geo_db_location" VALUES(5336,NULL,'Oradell, NJ 7649',2113,222,NULL,30,2912,0);
INSERT INTO "django_geo_db_location" VALUES(5337,NULL,'Palisades Park, NJ',2132,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5338,NULL,'Palisades Park, NJ 7650',2132,222,NULL,30,2913,0);
INSERT INTO "django_geo_db_location" VALUES(5339,NULL,'Paramus, NJ',2133,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5340,NULL,'Paramus, NJ 7652',2133,222,NULL,30,2914,0);
INSERT INTO "django_geo_db_location" VALUES(5341,NULL,'Paramus, NJ 7653',2133,222,NULL,30,2915,0);
INSERT INTO "django_geo_db_location" VALUES(5342,NULL,'Park Ridge, NJ',2134,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5343,NULL,'Park Ridge, NJ 7656',2134,222,NULL,30,2916,0);
INSERT INTO "django_geo_db_location" VALUES(5344,NULL,'Ridgefield, NJ',2135,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5345,NULL,'Ridgefield, NJ 7657',2135,222,NULL,30,2917,0);
INSERT INTO "django_geo_db_location" VALUES(5346,NULL,'Ridgefield Park, NJ',2136,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5347,NULL,'Ridgefield Park, NJ 7660',2136,222,NULL,30,2918,0);
INSERT INTO "django_geo_db_location" VALUES(5348,NULL,'River Edge, NJ',2137,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5349,NULL,'River Edge, NJ 7661',2137,222,NULL,30,2919,0);
INSERT INTO "django_geo_db_location" VALUES(5350,NULL,'Rochelle Park, NJ',2138,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5351,NULL,'Rochelle Park, NJ 7662',2138,222,NULL,30,2920,0);
INSERT INTO "django_geo_db_location" VALUES(5352,NULL,'Saddle Brook, NJ',2139,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5353,NULL,'Saddle Brook, NJ 7663',2139,222,NULL,30,2921,0);
INSERT INTO "django_geo_db_location" VALUES(5354,NULL,'Teaneck, NJ',2140,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5355,NULL,'Teaneck, NJ 7666',2140,222,NULL,30,2922,0);
INSERT INTO "django_geo_db_location" VALUES(5356,NULL,'Tenafly, NJ',2141,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5357,NULL,'Tenafly, NJ 7670',2141,222,NULL,30,2923,0);
INSERT INTO "django_geo_db_location" VALUES(5358,NULL,'Westwood, NJ',2142,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5359,NULL,'Westwood, NJ 7675',2142,222,NULL,30,2924,0);
INSERT INTO "django_geo_db_location" VALUES(5360,NULL,'Ho-Ho-Kus, NJ',2143,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5361,NULL,'Ho-Ho-Kus, NJ 7676',2143,222,NULL,30,2925,0);
INSERT INTO "django_geo_db_location" VALUES(5362,NULL,'Woodcliff Lake, NJ',2144,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5363,NULL,'Woodcliff Lake, NJ 7677',2144,222,NULL,30,2926,0);
INSERT INTO "django_geo_db_location" VALUES(5364,NULL,'Teaneck, NJ 7688',2140,222,NULL,30,2927,0);
INSERT INTO "django_geo_db_location" VALUES(5365,NULL,'Red Bank, NJ',2145,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5366,NULL,'Red Bank, NJ 7701',2145,222,NULL,30,2928,0);
INSERT INTO "django_geo_db_location" VALUES(5367,NULL,'Shrewsbury, NJ',2146,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5368,NULL,'Shrewsbury, NJ 7702',2146,222,NULL,30,2929,0);
INSERT INTO "django_geo_db_location" VALUES(5369,NULL,'Fort Monmouth, NJ',2147,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5370,NULL,'Fort Monmouth, NJ 7703',2147,222,NULL,30,2930,0);
INSERT INTO "django_geo_db_location" VALUES(5371,NULL,'Fair Haven, NJ',2148,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5372,NULL,'Fair Haven, NJ 7704',2148,222,NULL,30,2931,0);
INSERT INTO "django_geo_db_location" VALUES(5373,NULL,'Allenhurst, NJ',2149,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5374,NULL,'Allenhurst, NJ 7709',2149,222,NULL,30,2932,0);
INSERT INTO "django_geo_db_location" VALUES(5375,NULL,'Adelphia, NJ',2150,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5376,NULL,'Adelphia, NJ 7710',2150,222,NULL,30,2933,0);
INSERT INTO "django_geo_db_location" VALUES(5377,NULL,'Allenhurst, NJ 7711',2149,222,NULL,30,2934,0);
INSERT INTO "django_geo_db_location" VALUES(5378,NULL,'Asbury Park, NJ',2151,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5379,NULL,'Asbury Park, NJ 7712',2151,222,NULL,30,2935,0);
INSERT INTO "django_geo_db_location" VALUES(5380,NULL,'Belmar, NJ',2152,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5381,NULL,'Belmar, NJ 7715',2152,222,NULL,30,2936,0);
INSERT INTO "django_geo_db_location" VALUES(5382,NULL,'Atlantic Highlands, NJ',2153,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5383,NULL,'Atlantic Highlands, NJ 7716',2153,222,NULL,30,2937,0);
INSERT INTO "django_geo_db_location" VALUES(5384,NULL,'Avon By The Sea, NJ',2154,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5385,NULL,'Avon By The Sea, NJ 7717',2154,222,NULL,30,2938,0);
INSERT INTO "django_geo_db_location" VALUES(5386,NULL,'Belford, NJ',2155,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5387,NULL,'Belford, NJ 7718',2155,222,NULL,30,2939,0);
INSERT INTO "django_geo_db_location" VALUES(5388,NULL,'Belmar, NJ 7719',2152,222,NULL,30,2940,0);
INSERT INTO "django_geo_db_location" VALUES(5389,NULL,'Bradley Beach, NJ',2156,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5390,NULL,'Bradley Beach, NJ 7720',2156,222,NULL,30,2941,0);
INSERT INTO "django_geo_db_location" VALUES(5391,NULL,'Cliffwood, NJ',2157,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5392,NULL,'Cliffwood, NJ 7721',2157,222,NULL,30,2942,0);
INSERT INTO "django_geo_db_location" VALUES(5393,NULL,'Colts Neck, NJ',2158,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5394,NULL,'Colts Neck, NJ 7722',2158,222,NULL,30,2943,0);
INSERT INTO "django_geo_db_location" VALUES(5395,NULL,'Deal, NJ',2159,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5396,NULL,'Deal, NJ 7723',2159,222,NULL,30,2944,0);
INSERT INTO "django_geo_db_location" VALUES(5397,NULL,'Eatontown, NJ',2160,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5398,NULL,'Eatontown, NJ 7724',2160,222,NULL,30,2945,0);
INSERT INTO "django_geo_db_location" VALUES(5399,NULL,'Englishtown, NJ',2161,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5400,NULL,'Englishtown, NJ 7726',2161,222,NULL,30,2946,0);
INSERT INTO "django_geo_db_location" VALUES(5401,NULL,'Farmingdale, NJ',2162,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5402,NULL,'Farmingdale, NJ 7727',2162,222,NULL,30,2947,0);
INSERT INTO "django_geo_db_location" VALUES(5403,NULL,'Freehold, NJ',2163,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5404,NULL,'Freehold, NJ 7728',2163,222,NULL,30,2948,0);
INSERT INTO "django_geo_db_location" VALUES(5405,NULL,'Hazlet, NJ',2164,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5406,NULL,'Hazlet, NJ 7730',2164,222,NULL,30,2949,0);
INSERT INTO "django_geo_db_location" VALUES(5407,NULL,'Howell, NJ',2165,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5408,NULL,'Howell, NJ 7731',2165,222,NULL,30,2950,0);
INSERT INTO "django_geo_db_location" VALUES(5409,NULL,'Highlands, NJ',2166,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5410,NULL,'Highlands, NJ 7732',2166,222,NULL,30,2951,0);
INSERT INTO "django_geo_db_location" VALUES(5411,NULL,'Holmdel, NJ',2167,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5412,NULL,'Holmdel, NJ 7733',2167,222,NULL,30,2952,0);
INSERT INTO "django_geo_db_location" VALUES(5413,NULL,'Keansburg, NJ',2168,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5414,NULL,'Keansburg, NJ 7734',2168,222,NULL,30,2953,0);
INSERT INTO "django_geo_db_location" VALUES(5415,NULL,'Keyport, NJ',2169,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5416,NULL,'Keyport, NJ 7735',2169,222,NULL,30,2954,0);
INSERT INTO "django_geo_db_location" VALUES(5417,NULL,'Leonardo, NJ',2170,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5418,NULL,'Leonardo, NJ 7737',2170,222,NULL,30,2955,0);
INSERT INTO "django_geo_db_location" VALUES(5419,NULL,'Lincroft, NJ',2171,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5420,NULL,'Lincroft, NJ 7738',2171,222,NULL,30,2956,0);
INSERT INTO "django_geo_db_location" VALUES(5421,NULL,'Little Silver, NJ',2172,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5422,NULL,'Little Silver, NJ 7739',2172,222,NULL,30,2957,0);
INSERT INTO "django_geo_db_location" VALUES(5423,NULL,'Long Branch, NJ',2173,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5424,NULL,'Long Branch, NJ 7740',2173,222,NULL,30,2958,0);
INSERT INTO "django_geo_db_location" VALUES(5425,NULL,'Marlboro, NJ',2174,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5426,NULL,'Marlboro, NJ 7746',2174,222,NULL,30,2959,0);
INSERT INTO "django_geo_db_location" VALUES(5427,NULL,'Matawan, NJ',2175,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5428,NULL,'Matawan, NJ 7747',2175,222,NULL,30,2960,0);
INSERT INTO "django_geo_db_location" VALUES(5429,NULL,'Middletown, NJ',2176,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5430,NULL,'Middletown, NJ 7748',2176,222,NULL,30,2961,0);
INSERT INTO "django_geo_db_location" VALUES(5431,NULL,'Monmouth Beach, NJ',2177,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5432,NULL,'Monmouth Beach, NJ 7750',2177,222,NULL,30,2962,0);
INSERT INTO "django_geo_db_location" VALUES(5433,NULL,'Morganville, NJ',2178,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5434,NULL,'Morganville, NJ 7751',2178,222,NULL,30,2963,0);
INSERT INTO "django_geo_db_location" VALUES(5435,NULL,'Navesink, NJ',2179,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5436,NULL,'Navesink, NJ 7752',2179,222,NULL,30,2964,0);
INSERT INTO "django_geo_db_location" VALUES(5437,NULL,'Neptune, NJ',2180,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5438,NULL,'Neptune, NJ 7753',2180,222,NULL,30,2965,0);
INSERT INTO "django_geo_db_location" VALUES(5439,NULL,'Neptune, NJ 7754',2180,222,NULL,30,2966,0);
INSERT INTO "django_geo_db_location" VALUES(5440,NULL,'Oakhurst, NJ',2181,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5441,NULL,'Oakhurst, NJ 7755',2181,222,NULL,30,2967,0);
INSERT INTO "django_geo_db_location" VALUES(5442,NULL,'Ocean Grove, NJ',2182,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5443,NULL,'Ocean Grove, NJ 7756',2182,222,NULL,30,2968,0);
INSERT INTO "django_geo_db_location" VALUES(5444,NULL,'Oceanport, NJ',2183,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5445,NULL,'Oceanport, NJ 7757',2183,222,NULL,30,2969,0);
INSERT INTO "django_geo_db_location" VALUES(5446,NULL,'Port Monmouth, NJ',2184,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5447,NULL,'Port Monmouth, NJ 7758',2184,222,NULL,30,2970,0);
INSERT INTO "django_geo_db_location" VALUES(5448,NULL,'Rumson, NJ',2185,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5449,NULL,'Rumson, NJ 7760',2185,222,NULL,30,2971,0);
INSERT INTO "django_geo_db_location" VALUES(5450,NULL,'Spring Lake, NJ',2186,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5451,NULL,'Spring Lake, NJ 7762',2186,222,NULL,30,2972,0);
INSERT INTO "django_geo_db_location" VALUES(5452,NULL,'Tennent, NJ',2187,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5453,NULL,'Tennent, NJ 7763',2187,222,NULL,30,2973,0);
INSERT INTO "django_geo_db_location" VALUES(5454,NULL,'West Long Branch, NJ',2188,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5455,NULL,'West Long Branch, NJ 7764',2188,222,NULL,30,2974,0);
INSERT INTO "django_geo_db_location" VALUES(5456,NULL,'Wickatunk, NJ',2189,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5457,NULL,'Wickatunk, NJ 7765',2189,222,NULL,30,2975,0);
INSERT INTO "django_geo_db_location" VALUES(5458,NULL,'Holmdel, NJ 7777',2167,222,NULL,30,2976,0);
INSERT INTO "django_geo_db_location" VALUES(5459,NULL,'Eatontown, NJ 7799',2160,222,NULL,30,2977,0);
INSERT INTO "django_geo_db_location" VALUES(5460,NULL,'Dover, NJ',2190,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5461,NULL,'Dover, NJ 7801',2190,222,NULL,30,2978,0);
INSERT INTO "django_geo_db_location" VALUES(5462,NULL,'Dover, NJ 7802',2190,222,NULL,30,2979,0);
INSERT INTO "django_geo_db_location" VALUES(5463,NULL,'Mine Hill, NJ',2191,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5464,NULL,'Mine Hill, NJ 7803',2191,222,NULL,30,2980,0);
INSERT INTO "django_geo_db_location" VALUES(5465,NULL,'Picatinny Arsenal, NJ',2192,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5466,NULL,'Picatinny Arsenal, NJ 7806',2192,222,NULL,30,2981,0);
INSERT INTO "django_geo_db_location" VALUES(5467,NULL,'Hardyston, NJ',2193,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5468,NULL,'Hardyston, NJ 7819',2193,222,NULL,30,2982,0);
INSERT INTO "django_geo_db_location" VALUES(5469,NULL,'Allamuchy, NJ',2194,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5470,NULL,'Allamuchy, NJ 7820',2194,222,NULL,30,2983,0);
INSERT INTO "django_geo_db_location" VALUES(5471,NULL,'Andover, NJ',2195,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5472,NULL,'Andover, NJ 7821',2195,222,NULL,30,2984,0);
INSERT INTO "django_geo_db_location" VALUES(5473,NULL,'Augusta, NJ',2196,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5474,NULL,'Augusta, NJ 7822',2196,222,NULL,30,2985,0);
INSERT INTO "django_geo_db_location" VALUES(5475,NULL,'Belvidere, NJ',2197,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5476,NULL,'Belvidere, NJ 7823',2197,222,NULL,30,2986,0);
INSERT INTO "django_geo_db_location" VALUES(5477,NULL,'Blairstown, NJ',2198,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5478,NULL,'Blairstown, NJ 7825',2198,222,NULL,30,2987,0);
INSERT INTO "django_geo_db_location" VALUES(5479,NULL,'Branchville, NJ',2199,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5480,NULL,'Branchville, NJ 7826',2199,222,NULL,30,2988,0);
INSERT INTO "django_geo_db_location" VALUES(5481,NULL,'Montague, NJ',2200,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5482,NULL,'Montague, NJ 7827',2200,222,NULL,30,2989,0);
INSERT INTO "django_geo_db_location" VALUES(5483,NULL,'Budd Lake, NJ',2201,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5484,NULL,'Budd Lake, NJ 7828',2201,222,NULL,30,2990,0);
INSERT INTO "django_geo_db_location" VALUES(5485,NULL,'Buttzville, NJ',2202,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5486,NULL,'Buttzville, NJ 7829',2202,222,NULL,30,2991,0);
INSERT INTO "django_geo_db_location" VALUES(5487,NULL,'Califon, NJ',2203,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5488,NULL,'Califon, NJ 7830',2203,222,NULL,30,2992,0);
INSERT INTO "django_geo_db_location" VALUES(5489,NULL,'Changewater, NJ',2204,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5490,NULL,'Changewater, NJ 7831',2204,222,NULL,30,2993,0);
INSERT INTO "django_geo_db_location" VALUES(5491,NULL,'Columbia, NJ',2205,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5492,NULL,'Columbia, NJ 7832',2205,222,NULL,30,2994,0);
INSERT INTO "django_geo_db_location" VALUES(5493,NULL,'Delaware, NJ',2206,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5494,NULL,'Delaware, NJ 7833',2206,222,NULL,30,2995,0);
INSERT INTO "django_geo_db_location" VALUES(5495,NULL,'Denville, NJ',2207,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5496,NULL,'Denville, NJ 7834',2207,222,NULL,30,2996,0);
INSERT INTO "django_geo_db_location" VALUES(5497,NULL,'Flanders, NJ',2208,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5498,NULL,'Flanders, NJ 7836',2208,222,NULL,30,2997,0);
INSERT INTO "django_geo_db_location" VALUES(5499,NULL,'Glasser, NJ',2209,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5500,NULL,'Glasser, NJ 7837',2209,222,NULL,30,2998,0);
INSERT INTO "django_geo_db_location" VALUES(5501,NULL,'Great Meadows, NJ',2210,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5502,NULL,'Great Meadows, NJ 7838',2210,222,NULL,30,2999,0);
INSERT INTO "django_geo_db_location" VALUES(5503,NULL,'Greendell, NJ',2211,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5504,NULL,'Greendell, NJ 7839',2211,222,NULL,30,3000,0);
INSERT INTO "django_geo_db_location" VALUES(5505,NULL,'Hackettstown, NJ',2212,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5506,NULL,'Hackettstown, NJ 7840',2212,222,NULL,30,3001,0);
INSERT INTO "django_geo_db_location" VALUES(5507,NULL,'Great Meadows-Vienna, NJ',2213,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5508,NULL,'Great Meadows-Vienna, NJ 7841',2213,222,NULL,30,3002,0);
INSERT INTO "django_geo_db_location" VALUES(5509,NULL,'Hibernia, NJ',2214,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5510,NULL,'Hibernia, NJ 7842',2214,222,NULL,30,3003,0);
INSERT INTO "django_geo_db_location" VALUES(5511,NULL,'Hopatcong, NJ',2215,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5512,NULL,'Hopatcong, NJ 7843',2215,222,NULL,30,3004,0);
INSERT INTO "django_geo_db_location" VALUES(5513,NULL,'Hope, NJ',2216,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5514,NULL,'Hope, NJ 7844',2216,222,NULL,30,3005,0);
INSERT INTO "django_geo_db_location" VALUES(5515,NULL,'Ironia, NJ',2217,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5516,NULL,'Ironia, NJ 7845',2217,222,NULL,30,3006,0);
INSERT INTO "django_geo_db_location" VALUES(5517,NULL,'Johnsonburg, NJ',2218,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5518,NULL,'Johnsonburg, NJ 7846',2218,222,NULL,30,3007,0);
INSERT INTO "django_geo_db_location" VALUES(5519,NULL,'Kenvil, NJ',2219,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5520,NULL,'Kenvil, NJ 7847',2219,222,NULL,30,3008,0);
INSERT INTO "django_geo_db_location" VALUES(5521,NULL,'Lafayette, NJ',2220,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5522,NULL,'Lafayette, NJ 7848',2220,222,NULL,30,3009,0);
INSERT INTO "django_geo_db_location" VALUES(5523,NULL,'Lake Hopatcong, NJ',2221,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5524,NULL,'Lake Hopatcong, NJ 7849',2221,222,NULL,30,3010,0);
INSERT INTO "django_geo_db_location" VALUES(5525,NULL,'Landing, NJ',2222,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5526,NULL,'Landing, NJ 7850',2222,222,NULL,30,3011,0);
INSERT INTO "django_geo_db_location" VALUES(5527,NULL,'Layton, NJ',2223,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5528,NULL,'Layton, NJ 7851',2223,222,NULL,30,3012,0);
INSERT INTO "django_geo_db_location" VALUES(5529,NULL,'Ledgewood, NJ',2224,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5530,NULL,'Ledgewood, NJ 7852',2224,222,NULL,30,3013,0);
INSERT INTO "django_geo_db_location" VALUES(5531,NULL,'Long Valley, NJ',2225,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5532,NULL,'Long Valley, NJ 7853',2225,222,NULL,30,3014,0);
INSERT INTO "django_geo_db_location" VALUES(5533,NULL,'Middleville, NJ',2226,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5534,NULL,'Middleville, NJ 7855',2226,222,NULL,30,3015,0);
INSERT INTO "django_geo_db_location" VALUES(5535,NULL,'Mount Arlington, NJ',2227,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5536,NULL,'Mount Arlington, NJ 7856',2227,222,NULL,30,3016,0);
INSERT INTO "django_geo_db_location" VALUES(5537,NULL,'Netcong, NJ',2228,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5538,NULL,'Netcong, NJ 7857',2228,222,NULL,30,3017,0);
INSERT INTO "django_geo_db_location" VALUES(5539,NULL,'Newton, NJ',2229,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5540,NULL,'Newton, NJ 7860',2229,222,NULL,30,3018,0);
INSERT INTO "django_geo_db_location" VALUES(5541,NULL,'Oxford, NJ',2230,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5542,NULL,'Oxford, NJ 7863',2230,222,NULL,30,3019,0);
INSERT INTO "django_geo_db_location" VALUES(5543,NULL,'Port Murray, NJ',2231,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5544,NULL,'Port Murray, NJ 7865',2231,222,NULL,30,3020,0);
INSERT INTO "django_geo_db_location" VALUES(5545,NULL,'Rockaway, NJ',2232,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5546,NULL,'Rockaway, NJ 7866',2232,222,NULL,30,3021,0);
INSERT INTO "django_geo_db_location" VALUES(5547,NULL,'Randolph, NJ',2233,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5548,NULL,'Randolph, NJ 7869',2233,222,NULL,30,3022,0);
INSERT INTO "django_geo_db_location" VALUES(5549,NULL,'Schooleys Mountain, NJ',2234,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5550,NULL,'Schooleys Mountain, NJ 7870',2234,222,NULL,30,3023,0);
INSERT INTO "django_geo_db_location" VALUES(5551,NULL,'Sparta, NJ',2235,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5552,NULL,'Sparta, NJ 7871',2235,222,NULL,30,3024,0);
INSERT INTO "django_geo_db_location" VALUES(5553,NULL,'Stanhope, NJ',2236,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5554,NULL,'Stanhope, NJ 7874',2236,222,NULL,30,3025,0);
INSERT INTO "django_geo_db_location" VALUES(5555,NULL,'Stillwater, NJ',2237,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5556,NULL,'Stillwater, NJ 7875',2237,222,NULL,30,3026,0);
INSERT INTO "django_geo_db_location" VALUES(5557,NULL,'Succasunna, NJ',2238,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5558,NULL,'Succasunna, NJ 7876',2238,222,NULL,30,3027,0);
INSERT INTO "django_geo_db_location" VALUES(5559,NULL,'Swartswood, NJ',2239,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5560,NULL,'Swartswood, NJ 7877',2239,222,NULL,30,3028,0);
INSERT INTO "django_geo_db_location" VALUES(5561,NULL,'Mount Tabor, NJ',2240,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5562,NULL,'Mount Tabor, NJ 7878',2240,222,NULL,30,3029,0);
INSERT INTO "django_geo_db_location" VALUES(5563,NULL,'Tranquility, NJ',2241,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5564,NULL,'Tranquility, NJ 7879',2241,222,NULL,30,3030,0);
INSERT INTO "django_geo_db_location" VALUES(5565,NULL,'Vienna, NJ',2242,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5566,NULL,'Vienna, NJ 7880',2242,222,NULL,30,3031,0);
INSERT INTO "django_geo_db_location" VALUES(5567,NULL,'Wallpack Center, NJ',2243,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5568,NULL,'Wallpack Center, NJ 7881',2243,222,NULL,30,3032,0);
INSERT INTO "django_geo_db_location" VALUES(5569,NULL,'Washington, NJ',2244,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5570,NULL,'Washington, NJ 7882',2244,222,NULL,30,3033,0);
INSERT INTO "django_geo_db_location" VALUES(5571,NULL,'Wharton, NJ',2245,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5572,NULL,'Wharton, NJ 7885',2245,222,NULL,30,3034,0);
INSERT INTO "django_geo_db_location" VALUES(5573,NULL,'Branchville, NJ 7890',2199,222,NULL,30,3035,0);
INSERT INTO "django_geo_db_location" VALUES(5574,NULL,'Summit, NJ',2246,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5575,NULL,'Summit, NJ 7901',2246,222,NULL,30,3036,0);
INSERT INTO "django_geo_db_location" VALUES(5576,NULL,'Summit, NJ 7902',2246,222,NULL,30,3037,0);
INSERT INTO "django_geo_db_location" VALUES(5577,NULL,'Hardyston, NJ 7919',2193,222,NULL,30,3038,0);
INSERT INTO "django_geo_db_location" VALUES(5578,NULL,'Basking Ridge, NJ',2247,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5579,NULL,'Basking Ridge, NJ 7920',2247,222,NULL,30,3039,0);
INSERT INTO "django_geo_db_location" VALUES(5580,NULL,'Bedminster, NJ',2248,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5581,NULL,'Bedminster, NJ 7921',2248,222,NULL,30,3040,0);
INSERT INTO "django_geo_db_location" VALUES(5582,NULL,'Berkeley Heights, NJ',2249,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5583,NULL,'Berkeley Heights, NJ 7922',2249,222,NULL,30,3041,0);
INSERT INTO "django_geo_db_location" VALUES(5584,NULL,'Bernardsville, NJ',2250,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5585,NULL,'Bernardsville, NJ 7924',2250,222,NULL,30,3042,0);
INSERT INTO "django_geo_db_location" VALUES(5586,NULL,'Brookside, NJ',2251,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5587,NULL,'Brookside, NJ 7926',2251,222,NULL,30,3043,0);
INSERT INTO "django_geo_db_location" VALUES(5588,NULL,'Cedar Knolls, NJ',2252,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5589,NULL,'Cedar Knolls, NJ 7927',2252,222,NULL,30,3044,0);
INSERT INTO "django_geo_db_location" VALUES(5590,NULL,'Chatham, NJ',2253,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5591,NULL,'Chatham, NJ 7928',2253,222,NULL,30,3045,0);
INSERT INTO "django_geo_db_location" VALUES(5592,NULL,'Chester, NJ',2254,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5593,NULL,'Chester, NJ 7930',2254,222,NULL,30,3046,0);
INSERT INTO "django_geo_db_location" VALUES(5594,NULL,'Far Hills, NJ',2255,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5595,NULL,'Far Hills, NJ 7931',2255,222,NULL,30,3047,0);
INSERT INTO "django_geo_db_location" VALUES(5596,NULL,'Florham Park, NJ',2256,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5597,NULL,'Florham Park, NJ 7932',2256,222,NULL,30,3048,0);
INSERT INTO "django_geo_db_location" VALUES(5598,NULL,'Gillette, NJ',2257,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5599,NULL,'Gillette, NJ 7933',2257,222,NULL,30,3049,0);
INSERT INTO "django_geo_db_location" VALUES(5600,NULL,'Gladstone, NJ',2258,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5601,NULL,'Gladstone, NJ 7934',2258,222,NULL,30,3050,0);
INSERT INTO "django_geo_db_location" VALUES(5602,NULL,'Green Village, NJ',2259,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5603,NULL,'Green Village, NJ 7935',2259,222,NULL,30,3051,0);
INSERT INTO "django_geo_db_location" VALUES(5604,NULL,'East Hanover, NJ',2260,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5605,NULL,'East Hanover, NJ 7936',2260,222,NULL,30,3052,0);
INSERT INTO "django_geo_db_location" VALUES(5606,NULL,'Liberty Corner, NJ',2261,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5607,NULL,'Liberty Corner, NJ 7938',2261,222,NULL,30,3053,0);
INSERT INTO "django_geo_db_location" VALUES(5608,NULL,'Lyons, NJ',2262,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5609,NULL,'Lyons, NJ 7939',2262,222,NULL,30,3054,0);
INSERT INTO "django_geo_db_location" VALUES(5610,NULL,'Madison, NJ',2263,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5611,NULL,'Madison, NJ 7940',2263,222,NULL,30,3055,0);
INSERT INTO "django_geo_db_location" VALUES(5612,NULL,'Mendham, NJ',2264,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5613,NULL,'Mendham, NJ 7945',2264,222,NULL,30,3056,0);
INSERT INTO "django_geo_db_location" VALUES(5614,NULL,'Millington, NJ',2265,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5615,NULL,'Millington, NJ 7946',2265,222,NULL,30,3057,0);
INSERT INTO "django_geo_db_location" VALUES(5616,NULL,'Morris Plains, NJ',2266,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5617,NULL,'Morris Plains, NJ 7950',2266,222,NULL,30,3058,0);
INSERT INTO "django_geo_db_location" VALUES(5618,NULL,'Bernardsville, NJ 7952',2250,222,NULL,30,3059,0);
INSERT INTO "django_geo_db_location" VALUES(5619,NULL,'Morristown, NJ',2267,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5620,NULL,'Morristown, NJ 7960',2267,222,NULL,30,3060,0);
INSERT INTO "django_geo_db_location" VALUES(5621,NULL,'Morristown, NJ 7961',2267,222,NULL,30,3061,0);
INSERT INTO "django_geo_db_location" VALUES(5622,NULL,'Morristown, NJ 7962',2267,222,NULL,30,3062,0);
INSERT INTO "django_geo_db_location" VALUES(5623,NULL,'Morristown, NJ 7963',2267,222,NULL,30,3063,0);
INSERT INTO "django_geo_db_location" VALUES(5624,NULL,'Watchung, NJ 7969',2031,222,NULL,30,3064,0);
INSERT INTO "django_geo_db_location" VALUES(5625,NULL,'Mount Freedom, NJ',2268,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5626,NULL,'Mount Freedom, NJ 7970',2268,222,NULL,30,3065,0);
INSERT INTO "django_geo_db_location" VALUES(5627,NULL,'New Providence, NJ',2269,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5628,NULL,'New Providence, NJ 7974',2269,222,NULL,30,3066,0);
INSERT INTO "django_geo_db_location" VALUES(5629,NULL,'New Vernon, NJ',2270,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5630,NULL,'New Vernon, NJ 7976',2270,222,NULL,30,3067,0);
INSERT INTO "django_geo_db_location" VALUES(5631,NULL,'Peapack, NJ',2271,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5632,NULL,'Peapack, NJ 7977',2271,222,NULL,30,3068,0);
INSERT INTO "django_geo_db_location" VALUES(5633,NULL,'Pluckemin, NJ',2272,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5634,NULL,'Pluckemin, NJ 7978',2272,222,NULL,30,3069,0);
INSERT INTO "django_geo_db_location" VALUES(5635,NULL,'Pottersville, NJ',2273,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5636,NULL,'Pottersville, NJ 7979',2273,222,NULL,30,3070,0);
INSERT INTO "django_geo_db_location" VALUES(5637,NULL,'Stirling, NJ',2274,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5638,NULL,'Stirling, NJ 7980',2274,222,NULL,30,3071,0);
INSERT INTO "django_geo_db_location" VALUES(5639,NULL,'Whippany, NJ',2275,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5640,NULL,'Whippany, NJ 7981',2275,222,NULL,30,3072,0);
INSERT INTO "django_geo_db_location" VALUES(5641,NULL,'Whippany, NJ 7983',2275,222,NULL,30,3073,0);
INSERT INTO "django_geo_db_location" VALUES(5642,NULL,'Peapack and Gladstone, NJ',2276,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5643,NULL,'Peapack and Gladstone, NJ 7997',2276,222,NULL,30,3074,0);
INSERT INTO "django_geo_db_location" VALUES(5644,NULL,'Whippany, NJ 7999',2275,222,NULL,30,3075,0);
INSERT INTO "django_geo_db_location" VALUES(5645,NULL,'Alloway, NJ',2277,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5646,NULL,'Alloway, NJ 8001',2277,222,NULL,30,3076,0);
INSERT INTO "django_geo_db_location" VALUES(5647,NULL,'Cherry Hill, NJ',2278,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5648,NULL,'Cherry Hill, NJ 8002',2278,222,NULL,30,3077,0);
INSERT INTO "django_geo_db_location" VALUES(5649,NULL,'Cherry Hill, NJ 8003',2278,222,NULL,30,3078,0);
INSERT INTO "django_geo_db_location" VALUES(5650,NULL,'Atco, NJ',2279,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5651,NULL,'Atco, NJ 8004',2279,222,NULL,30,3079,0);
INSERT INTO "django_geo_db_location" VALUES(5652,NULL,'Barnegat, NJ',2280,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5653,NULL,'Barnegat, NJ 8005',2280,222,NULL,30,3080,0);
INSERT INTO "django_geo_db_location" VALUES(5654,NULL,'Barnegat Light, NJ',2281,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5655,NULL,'Barnegat Light, NJ 8006',2281,222,NULL,30,3081,0);
INSERT INTO "django_geo_db_location" VALUES(5656,NULL,'Barrington, NJ',2282,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5657,NULL,'Barrington, NJ 8007',2282,222,NULL,30,3082,0);
INSERT INTO "django_geo_db_location" VALUES(5658,NULL,'Beach Haven, NJ',2283,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5659,NULL,'Beach Haven, NJ 8008',2283,222,NULL,30,3083,0);
INSERT INTO "django_geo_db_location" VALUES(5660,NULL,'Berlin, NJ',2284,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5661,NULL,'Berlin, NJ 8009',2284,222,NULL,30,3084,0);
INSERT INTO "django_geo_db_location" VALUES(5662,NULL,'Beverly, NJ',2285,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5663,NULL,'Beverly, NJ 8010',2285,222,NULL,30,3085,0);
INSERT INTO "django_geo_db_location" VALUES(5664,NULL,'Birmingham, NJ',2286,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5665,NULL,'Birmingham, NJ 8011',2286,222,NULL,30,3086,0);
INSERT INTO "django_geo_db_location" VALUES(5666,NULL,'Blackwood, NJ',2287,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5667,NULL,'Blackwood, NJ 8012',2287,222,NULL,30,3087,0);
INSERT INTO "django_geo_db_location" VALUES(5668,NULL,'Bridgeport, NJ',2288,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5669,NULL,'Bridgeport, NJ 8014',2288,222,NULL,30,3088,0);
INSERT INTO "django_geo_db_location" VALUES(5670,NULL,'Browns Mills, NJ',2289,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5671,NULL,'Browns Mills, NJ 8015',2289,222,NULL,30,3089,0);
INSERT INTO "django_geo_db_location" VALUES(5672,NULL,'Burlington, NJ',2290,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5673,NULL,'Burlington, NJ 8016',2290,222,NULL,30,3090,0);
INSERT INTO "django_geo_db_location" VALUES(5674,NULL,'Elwood-Magnolia, NJ',2291,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5675,NULL,'Elwood-Magnolia, NJ 8017',2291,222,NULL,30,3091,0);
INSERT INTO "django_geo_db_location" VALUES(5676,NULL,'Cedar Brook, NJ',2292,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5677,NULL,'Cedar Brook, NJ 8018',2292,222,NULL,30,3092,0);
INSERT INTO "django_geo_db_location" VALUES(5678,NULL,'Chatsworth, NJ',2293,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5679,NULL,'Chatsworth, NJ 8019',2293,222,NULL,30,3093,0);
INSERT INTO "django_geo_db_location" VALUES(5680,NULL,'Clarksboro, NJ',2294,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5681,NULL,'Clarksboro, NJ 8020',2294,222,NULL,30,3094,0);
INSERT INTO "django_geo_db_location" VALUES(5682,NULL,'Clementon, NJ',2295,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5683,NULL,'Clementon, NJ 8021',2295,222,NULL,30,3095,0);
INSERT INTO "django_geo_db_location" VALUES(5684,NULL,'Columbus, NJ',2296,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5685,NULL,'Columbus, NJ 8022',2296,222,NULL,30,3096,0);
INSERT INTO "django_geo_db_location" VALUES(5686,NULL,'Deepwater, NJ',2297,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5687,NULL,'Deepwater, NJ 8023',2297,222,NULL,30,3097,0);
INSERT INTO "django_geo_db_location" VALUES(5688,NULL,'Ewan, NJ',2298,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5689,NULL,'Ewan, NJ 8025',2298,222,NULL,30,3098,0);
INSERT INTO "django_geo_db_location" VALUES(5690,NULL,'Gibbsboro, NJ',2299,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5691,NULL,'Gibbsboro, NJ 8026',2299,222,NULL,30,3099,0);
INSERT INTO "django_geo_db_location" VALUES(5692,NULL,'Gibbstown, NJ',2300,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5693,NULL,'Gibbstown, NJ 8027',2300,222,NULL,30,3100,0);
INSERT INTO "django_geo_db_location" VALUES(5694,NULL,'Glassboro, NJ',2301,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5695,NULL,'Glassboro, NJ 8028',2301,222,NULL,30,3101,0);
INSERT INTO "django_geo_db_location" VALUES(5696,NULL,'Glendora, NJ',2302,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5697,NULL,'Glendora, NJ 8029',2302,222,NULL,30,3102,0);
INSERT INTO "django_geo_db_location" VALUES(5698,NULL,'Gloucester City, NJ',2303,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5699,NULL,'Gloucester City, NJ 8030',2303,222,NULL,30,3103,0);
INSERT INTO "django_geo_db_location" VALUES(5700,NULL,'Bellmawr, NJ',2304,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5701,NULL,'Bellmawr, NJ 8031',2304,222,NULL,30,3104,0);
INSERT INTO "django_geo_db_location" VALUES(5702,NULL,'Grenloch, NJ',2305,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5703,NULL,'Grenloch, NJ 8032',2305,222,NULL,30,3105,0);
INSERT INTO "django_geo_db_location" VALUES(5704,NULL,'Haddonfield, NJ',2306,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5705,NULL,'Haddonfield, NJ 8033',2306,222,NULL,30,3106,0);
INSERT INTO "django_geo_db_location" VALUES(5706,NULL,'Cherry Hill, NJ 8034',2278,222,NULL,30,3107,0);
INSERT INTO "django_geo_db_location" VALUES(5707,NULL,'Haddon Heights, NJ',2307,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5708,NULL,'Haddon Heights, NJ 8035',2307,222,NULL,30,3108,0);
INSERT INTO "django_geo_db_location" VALUES(5709,NULL,'Hainesport, NJ',2308,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5710,NULL,'Hainesport, NJ 8036',2308,222,NULL,30,3109,0);
INSERT INTO "django_geo_db_location" VALUES(5711,NULL,'Hammonton, NJ',2309,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5712,NULL,'Hammonton, NJ 8037',2309,222,NULL,30,3110,0);
INSERT INTO "django_geo_db_location" VALUES(5713,NULL,'Hancocks Bridge, NJ',2310,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5714,NULL,'Hancocks Bridge, NJ 8038',2310,222,NULL,30,3111,0);
INSERT INTO "django_geo_db_location" VALUES(5715,NULL,'Harrisonville, NJ',2311,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5716,NULL,'Harrisonville, NJ 8039',2311,222,NULL,30,3112,0);
INSERT INTO "django_geo_db_location" VALUES(5717,NULL,'Jobstown, NJ',2312,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5718,NULL,'Jobstown, NJ 8041',2312,222,NULL,30,3113,0);
INSERT INTO "django_geo_db_location" VALUES(5719,NULL,'Juliustown, NJ',2313,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5720,NULL,'Juliustown, NJ 8042',2313,222,NULL,30,3114,0);
INSERT INTO "django_geo_db_location" VALUES(5721,NULL,'Voorhees, NJ',2314,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5722,NULL,'Voorhees, NJ 8043',2314,222,NULL,30,3115,0);
INSERT INTO "django_geo_db_location" VALUES(5723,NULL,'Lawnside, NJ',2315,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5724,NULL,'Lawnside, NJ 8045',2315,222,NULL,30,3116,0);
INSERT INTO "django_geo_db_location" VALUES(5725,NULL,'Willingboro, NJ',2316,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5726,NULL,'Willingboro, NJ 8046',2316,222,NULL,30,3117,0);
INSERT INTO "django_geo_db_location" VALUES(5727,NULL,'Lumberton, NJ',2317,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5728,NULL,'Lumberton, NJ 8048',2317,222,NULL,30,3118,0);
INSERT INTO "django_geo_db_location" VALUES(5729,NULL,'Magnolia, NJ',2318,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5730,NULL,'Magnolia, NJ 8049',2318,222,NULL,30,3119,0);
INSERT INTO "django_geo_db_location" VALUES(5731,NULL,'Manahawkin, NJ',2319,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5732,NULL,'Manahawkin, NJ 8050',2319,222,NULL,30,3120,0);
INSERT INTO "django_geo_db_location" VALUES(5733,NULL,'Mantua, NJ',2320,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5734,NULL,'Mantua, NJ 8051',2320,222,NULL,30,3121,0);
INSERT INTO "django_geo_db_location" VALUES(5735,NULL,'Maple Shade, NJ',2321,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5736,NULL,'Maple Shade, NJ 8052',2321,222,NULL,30,3122,0);
INSERT INTO "django_geo_db_location" VALUES(5737,NULL,'Marlton, NJ',2322,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5738,NULL,'Marlton, NJ 8053',2322,222,NULL,30,3123,0);
INSERT INTO "django_geo_db_location" VALUES(5739,NULL,'Mount Laurel, NJ',2323,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5740,NULL,'Mount Laurel, NJ 8054',2323,222,NULL,30,3124,0);
INSERT INTO "django_geo_db_location" VALUES(5741,NULL,'Medford, NJ',2324,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5742,NULL,'Medford, NJ 8055',2324,222,NULL,30,3125,0);
INSERT INTO "django_geo_db_location" VALUES(5743,NULL,'Mickleton, NJ',2325,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5744,NULL,'Mickleton, NJ 8056',2325,222,NULL,30,3126,0);
INSERT INTO "django_geo_db_location" VALUES(5745,NULL,'Moorestown, NJ',2326,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5746,NULL,'Moorestown, NJ 8057',2326,222,NULL,30,3127,0);
INSERT INTO "django_geo_db_location" VALUES(5747,NULL,'Mount Ephraim, NJ',2327,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5748,NULL,'Mount Ephraim, NJ 8059',2327,222,NULL,30,3128,0);
INSERT INTO "django_geo_db_location" VALUES(5749,NULL,'Mount Holly, NJ',2328,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5750,NULL,'Mount Holly, NJ 8060',2328,222,NULL,30,3129,0);
INSERT INTO "django_geo_db_location" VALUES(5751,NULL,'Mount Royal, NJ',2329,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5752,NULL,'Mount Royal, NJ 8061',2329,222,NULL,30,3130,0);
INSERT INTO "django_geo_db_location" VALUES(5753,NULL,'Mullica Hill, NJ',2330,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5754,NULL,'Mullica Hill, NJ 8062',2330,222,NULL,30,3131,0);
INSERT INTO "django_geo_db_location" VALUES(5755,NULL,'National Park, NJ',2331,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5756,NULL,'National Park, NJ 8063',2331,222,NULL,30,3132,0);
INSERT INTO "django_geo_db_location" VALUES(5757,NULL,'New Lisbon, NJ',2332,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5758,NULL,'New Lisbon, NJ 8064',2332,222,NULL,30,3133,0);
INSERT INTO "django_geo_db_location" VALUES(5759,NULL,'Palmyra, NJ',2333,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5760,NULL,'Palmyra, NJ 8065',2333,222,NULL,30,3134,0);
INSERT INTO "django_geo_db_location" VALUES(5761,NULL,'Paulsboro, NJ',2334,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5762,NULL,'Paulsboro, NJ 8066',2334,222,NULL,30,3135,0);
INSERT INTO "django_geo_db_location" VALUES(5763,NULL,'Pedricktown, NJ',2335,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5764,NULL,'Pedricktown, NJ 8067',2335,222,NULL,30,3136,0);
INSERT INTO "django_geo_db_location" VALUES(5765,NULL,'Pemberton, NJ',2336,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5766,NULL,'Pemberton, NJ 8068',2336,222,NULL,30,3137,0);
INSERT INTO "django_geo_db_location" VALUES(5767,NULL,'Penns Grove, NJ',2337,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5768,NULL,'Penns Grove, NJ 8069',2337,222,NULL,30,3138,0);
INSERT INTO "django_geo_db_location" VALUES(5769,NULL,'Pennsville, NJ',2338,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5770,NULL,'Pennsville, NJ 8070',2338,222,NULL,30,3139,0);
INSERT INTO "django_geo_db_location" VALUES(5771,NULL,'Pitman, NJ',2339,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5772,NULL,'Pitman, NJ 8071',2339,222,NULL,30,3140,0);
INSERT INTO "django_geo_db_location" VALUES(5773,NULL,'Quinton, NJ',2340,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5774,NULL,'Quinton, NJ 8072',2340,222,NULL,30,3141,0);
INSERT INTO "django_geo_db_location" VALUES(5775,NULL,'Rancocas, NJ',2341,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5776,NULL,'Rancocas, NJ 8073',2341,222,NULL,30,3142,0);
INSERT INTO "django_geo_db_location" VALUES(5777,NULL,'Richwood, NJ',2342,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5778,NULL,'Richwood, NJ 8074',2342,222,NULL,30,3143,0);
INSERT INTO "django_geo_db_location" VALUES(5779,NULL,'Riverside, NJ',2343,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5780,NULL,'Riverside, NJ 8075',2343,222,NULL,30,3144,0);
INSERT INTO "django_geo_db_location" VALUES(5781,NULL,'Riverton, NJ',2344,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5782,NULL,'Riverton, NJ 8076',2344,222,NULL,30,3145,0);
INSERT INTO "django_geo_db_location" VALUES(5783,NULL,'Riverton, NJ 8077',2344,222,NULL,30,3146,0);
INSERT INTO "django_geo_db_location" VALUES(5784,NULL,'Runnemede, NJ',2345,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5785,NULL,'Runnemede, NJ 8078',2345,222,NULL,30,3147,0);
INSERT INTO "django_geo_db_location" VALUES(5786,NULL,'Salem, NJ',2346,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5787,NULL,'Salem, NJ 8079',2346,222,NULL,30,3148,0);
INSERT INTO "django_geo_db_location" VALUES(5788,NULL,'Sewell, NJ',2347,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5789,NULL,'Sewell, NJ 8080',2347,222,NULL,30,3149,0);
INSERT INTO "django_geo_db_location" VALUES(5790,NULL,'Sicklerville, NJ',2348,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5791,NULL,'Sicklerville, NJ 8081',2348,222,NULL,30,3150,0);
INSERT INTO "django_geo_db_location" VALUES(5792,NULL,'Somerdale, NJ',2349,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5793,NULL,'Somerdale, NJ 8083',2349,222,NULL,30,3151,0);
INSERT INTO "django_geo_db_location" VALUES(5794,NULL,'Stratford, NJ',2350,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5795,NULL,'Stratford, NJ 8084',2350,222,NULL,30,3152,0);
INSERT INTO "django_geo_db_location" VALUES(5796,NULL,'Swedesboro, NJ',2351,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5797,NULL,'Swedesboro, NJ 8085',2351,222,NULL,30,3153,0);
INSERT INTO "django_geo_db_location" VALUES(5798,NULL,'Thorofare, NJ',2352,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5799,NULL,'Thorofare, NJ 8086',2352,222,NULL,30,3154,0);
INSERT INTO "django_geo_db_location" VALUES(5800,NULL,'Tuckerton, NJ',2353,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5801,NULL,'Tuckerton, NJ 8087',2353,222,NULL,30,3155,0);
INSERT INTO "django_geo_db_location" VALUES(5802,NULL,'Vincentown, NJ',2354,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5803,NULL,'Vincentown, NJ 8088',2354,222,NULL,30,3156,0);
INSERT INTO "django_geo_db_location" VALUES(5804,NULL,'Waterford Works, NJ',2355,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5805,NULL,'Waterford Works, NJ 8089',2355,222,NULL,30,3157,0);
INSERT INTO "django_geo_db_location" VALUES(5806,NULL,'Wenonah, NJ',2356,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5807,NULL,'Wenonah, NJ 8090',2356,222,NULL,30,3158,0);
INSERT INTO "django_geo_db_location" VALUES(5808,NULL,'West Berlin, NJ',2357,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5809,NULL,'West Berlin, NJ 8091',2357,222,NULL,30,3159,0);
INSERT INTO "django_geo_db_location" VALUES(5810,NULL,'West Creek, NJ',2358,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5811,NULL,'West Creek, NJ 8092',2358,222,NULL,30,3160,0);
INSERT INTO "django_geo_db_location" VALUES(5812,NULL,'Westville, NJ',2359,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5813,NULL,'Westville, NJ 8093',2359,222,NULL,30,3161,0);
INSERT INTO "django_geo_db_location" VALUES(5814,NULL,'Williamstown, NJ',2360,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5815,NULL,'Williamstown, NJ 8094',2360,222,NULL,30,3162,0);
INSERT INTO "django_geo_db_location" VALUES(5816,NULL,'Winslow, NJ',2361,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5817,NULL,'Winslow, NJ 8095',2361,222,NULL,30,3163,0);
INSERT INTO "django_geo_db_location" VALUES(5818,NULL,'Woodbury, NJ',2362,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5819,NULL,'Woodbury, NJ 8096',2362,222,NULL,30,3164,0);
INSERT INTO "django_geo_db_location" VALUES(5820,NULL,'Woodbury Heights, NJ',2363,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5821,NULL,'Woodbury Heights, NJ 8097',2363,222,NULL,30,3165,0);
INSERT INTO "django_geo_db_location" VALUES(5822,NULL,'Woodstown, NJ',2364,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5823,NULL,'Woodstown, NJ 8098',2364,222,NULL,30,3166,0);
INSERT INTO "django_geo_db_location" VALUES(5824,NULL,'Bellmawr, NJ 8099',2304,222,NULL,30,3167,0);
INSERT INTO "django_geo_db_location" VALUES(5825,NULL,'Camden, NJ',2365,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5826,NULL,'Camden, NJ 8101',2365,222,NULL,30,3168,0);
INSERT INTO "django_geo_db_location" VALUES(5827,NULL,'Camden, NJ 8102',2365,222,NULL,30,3169,0);
INSERT INTO "django_geo_db_location" VALUES(5828,NULL,'Camden, NJ 8103',2365,222,NULL,30,3170,0);
INSERT INTO "django_geo_db_location" VALUES(5829,NULL,'Camden, NJ 8104',2365,222,NULL,30,3171,0);
INSERT INTO "django_geo_db_location" VALUES(5830,NULL,'Camden, NJ 8105',2365,222,NULL,30,3172,0);
INSERT INTO "django_geo_db_location" VALUES(5831,NULL,'Audubon, NJ',2366,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5832,NULL,'Audubon, NJ 8106',2366,222,NULL,30,3173,0);
INSERT INTO "django_geo_db_location" VALUES(5833,NULL,'Oaklyn, NJ',2367,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5834,NULL,'Oaklyn, NJ 8107',2367,222,NULL,30,3174,0);
INSERT INTO "django_geo_db_location" VALUES(5835,NULL,'Collingswood, NJ',2368,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5836,NULL,'Collingswood, NJ 8108',2368,222,NULL,30,3175,0);
INSERT INTO "django_geo_db_location" VALUES(5837,NULL,'Merchantville, NJ',2369,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5838,NULL,'Merchantville, NJ 8109',2369,222,NULL,30,3176,0);
INSERT INTO "django_geo_db_location" VALUES(5839,NULL,'Pennsauken, NJ',2370,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5840,NULL,'Pennsauken, NJ 8110',2370,222,NULL,30,3177,0);
INSERT INTO "django_geo_db_location" VALUES(5841,NULL,'Absecon, NJ',2371,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5842,NULL,'Absecon, NJ 8201',2371,222,NULL,30,3178,0);
INSERT INTO "django_geo_db_location" VALUES(5843,NULL,'Avalon, NJ',2372,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5844,NULL,'Avalon, NJ 8202',2372,222,NULL,30,3179,0);
INSERT INTO "django_geo_db_location" VALUES(5845,NULL,'Brigantine, NJ',2373,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5846,NULL,'Brigantine, NJ 8203',2373,222,NULL,30,3180,0);
INSERT INTO "django_geo_db_location" VALUES(5847,NULL,'Cape May, NJ',2374,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5848,NULL,'Cape May, NJ 8204',2374,222,NULL,30,3181,0);
INSERT INTO "django_geo_db_location" VALUES(5849,NULL,'Absecon, NJ 8205',2371,222,NULL,30,3182,0);
INSERT INTO "django_geo_db_location" VALUES(5850,NULL,'Cape May Court House, NJ',2375,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5851,NULL,'Cape May Court House, NJ 8210',2375,222,NULL,30,3183,0);
INSERT INTO "django_geo_db_location" VALUES(5852,NULL,'Cape May Point, NJ',2376,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5853,NULL,'Cape May Point, NJ 8212',2376,222,NULL,30,3184,0);
INSERT INTO "django_geo_db_location" VALUES(5854,NULL,'Cologne, NJ',2377,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5855,NULL,'Cologne, NJ 8213',2377,222,NULL,30,3185,0);
INSERT INTO "django_geo_db_location" VALUES(5856,NULL,'Dennisville, NJ',2378,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5857,NULL,'Dennisville, NJ 8214',2378,222,NULL,30,3186,0);
INSERT INTO "django_geo_db_location" VALUES(5858,NULL,'Egg Harbor City, NJ',2379,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5859,NULL,'Egg Harbor City, NJ 8215',2379,222,NULL,30,3187,0);
INSERT INTO "django_geo_db_location" VALUES(5860,NULL,'Elwood, NJ',2380,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5861,NULL,'Elwood, NJ 8217',2380,222,NULL,30,3188,0);
INSERT INTO "django_geo_db_location" VALUES(5862,NULL,'Goshen, NJ',2381,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5863,NULL,'Goshen, NJ 8218',2381,222,NULL,30,3189,0);
INSERT INTO "django_geo_db_location" VALUES(5864,NULL,'Green Creek, NJ',2382,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5865,NULL,'Green Creek, NJ 8219',2382,222,NULL,30,3190,0);
INSERT INTO "django_geo_db_location" VALUES(5866,NULL,'Leeds Point, NJ',2383,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5867,NULL,'Leeds Point, NJ 8220',2383,222,NULL,30,3191,0);
INSERT INTO "django_geo_db_location" VALUES(5868,NULL,'Linwood, NJ',2384,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5869,NULL,'Linwood, NJ 8221',2384,222,NULL,30,3192,0);
INSERT INTO "django_geo_db_location" VALUES(5870,NULL,'Marmora, NJ',2385,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5871,NULL,'Marmora, NJ 8223',2385,222,NULL,30,3193,0);
INSERT INTO "django_geo_db_location" VALUES(5872,NULL,'New Gretna, NJ',2386,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5873,NULL,'New Gretna, NJ 8224',2386,222,NULL,30,3194,0);
INSERT INTO "django_geo_db_location" VALUES(5874,NULL,'Northfield, NJ',2387,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5875,NULL,'Northfield, NJ 8225',2387,222,NULL,30,3195,0);
INSERT INTO "django_geo_db_location" VALUES(5876,NULL,'Ocean City, NJ',2388,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5877,NULL,'Ocean City, NJ 8226',2388,222,NULL,30,3196,0);
INSERT INTO "django_geo_db_location" VALUES(5878,NULL,'Bass River, NJ',2389,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5879,NULL,'Bass River, NJ 8227',2389,222,NULL,30,3197,0);
INSERT INTO "django_geo_db_location" VALUES(5880,NULL,'Ocean View, NJ',2390,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5881,NULL,'Ocean View, NJ 8230',2390,222,NULL,30,3198,0);
INSERT INTO "django_geo_db_location" VALUES(5882,NULL,'Oceanville, NJ',2391,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5883,NULL,'Oceanville, NJ 8231',2391,222,NULL,30,3199,0);
INSERT INTO "django_geo_db_location" VALUES(5884,NULL,'Pleasantville, NJ',2392,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5885,NULL,'Pleasantville, NJ 8232',2392,222,NULL,30,3200,0);
INSERT INTO "django_geo_db_location" VALUES(5886,NULL,'Egg Harbor Township, NJ',2393,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5887,NULL,'Egg Harbor Township, NJ 8234',2393,222,NULL,30,3201,0);
INSERT INTO "django_geo_db_location" VALUES(5888,NULL,'Maurice River, NJ',2394,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5889,NULL,'Maurice River, NJ 8237',2394,222,NULL,30,3202,0);
INSERT INTO "django_geo_db_location" VALUES(5890,NULL,'Pomona, NJ',2395,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5891,NULL,'Pomona, NJ 8240',2395,222,NULL,30,3203,0);
INSERT INTO "django_geo_db_location" VALUES(5892,NULL,'Port Republic, NJ',2396,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5893,NULL,'Port Republic, NJ 8241',2396,222,NULL,30,3204,0);
INSERT INTO "django_geo_db_location" VALUES(5894,NULL,'Rio Grande, NJ',2397,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5895,NULL,'Rio Grande, NJ 8242',2397,222,NULL,30,3205,0);
INSERT INTO "django_geo_db_location" VALUES(5896,NULL,'Sea Isle City, NJ',2398,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5897,NULL,'Sea Isle City, NJ 8243',2398,222,NULL,30,3206,0);
INSERT INTO "django_geo_db_location" VALUES(5898,NULL,'Somers Point, NJ',2399,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5899,NULL,'Somers Point, NJ 8244',2399,222,NULL,30,3207,0);
INSERT INTO "django_geo_db_location" VALUES(5900,NULL,'South Dennis, NJ',2400,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5901,NULL,'South Dennis, NJ 8245',2400,222,NULL,30,3208,0);
INSERT INTO "django_geo_db_location" VALUES(5902,NULL,'South Seaville, NJ',2401,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5903,NULL,'South Seaville, NJ 8246',2401,222,NULL,30,3209,0);
INSERT INTO "django_geo_db_location" VALUES(5904,NULL,'Stone Harbor, NJ',2402,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5905,NULL,'Stone Harbor, NJ 8247',2402,222,NULL,30,3210,0);
INSERT INTO "django_geo_db_location" VALUES(5906,NULL,'Strathmere, NJ',2403,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5907,NULL,'Strathmere, NJ 8248',2403,222,NULL,30,3211,0);
INSERT INTO "django_geo_db_location" VALUES(5908,NULL,'Tuckahoe, NJ',2404,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5909,NULL,'Tuckahoe, NJ 8250',2404,222,NULL,30,3212,0);
INSERT INTO "django_geo_db_location" VALUES(5910,NULL,'Villas, NJ',2405,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5911,NULL,'Villas, NJ 8251',2405,222,NULL,30,3213,0);
INSERT INTO "django_geo_db_location" VALUES(5912,NULL,'Whitesboro, NJ',2406,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5913,NULL,'Whitesboro, NJ 8252',2406,222,NULL,30,3214,0);
INSERT INTO "django_geo_db_location" VALUES(5914,NULL,'Shiloh, NJ',2407,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5915,NULL,'Shiloh, NJ 8253',2407,222,NULL,30,3215,0);
INSERT INTO "django_geo_db_location" VALUES(5916,NULL,'Wildwood, NJ',2408,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5917,NULL,'Wildwood, NJ 8260',2408,222,NULL,30,3216,0);
INSERT INTO "django_geo_db_location" VALUES(5918,NULL,'Woodbine, NJ',2409,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5919,NULL,'Woodbine, NJ 8270',2409,222,NULL,30,3217,0);
INSERT INTO "django_geo_db_location" VALUES(5920,NULL,'Sea Isle City, NJ 8283',2398,222,NULL,30,3218,0);
INSERT INTO "django_geo_db_location" VALUES(5921,NULL,'Bridgeton, NJ',2410,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5922,NULL,'Bridgeton, NJ 8302',2410,222,NULL,30,3219,0);
INSERT INTO "django_geo_db_location" VALUES(5923,NULL,'Buena, NJ',2411,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5924,NULL,'Buena, NJ 8310',2411,222,NULL,30,3220,0);
INSERT INTO "django_geo_db_location" VALUES(5925,NULL,'Cedarville, NJ',2412,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5926,NULL,'Cedarville, NJ 8311',2412,222,NULL,30,3221,0);
INSERT INTO "django_geo_db_location" VALUES(5927,NULL,'Clayton, NJ',2413,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5928,NULL,'Clayton, NJ 8312',2413,222,NULL,30,3222,0);
INSERT INTO "django_geo_db_location" VALUES(5929,NULL,'Deerfield Street, NJ',2414,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5930,NULL,'Deerfield Street, NJ 8313',2414,222,NULL,30,3223,0);
INSERT INTO "django_geo_db_location" VALUES(5931,NULL,'Delmont, NJ',2415,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5932,NULL,'Delmont, NJ 8314',2415,222,NULL,30,3224,0);
INSERT INTO "django_geo_db_location" VALUES(5933,NULL,'Dividing Creek, NJ',2416,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5934,NULL,'Dividing Creek, NJ 8315',2416,222,NULL,30,3225,0);
INSERT INTO "django_geo_db_location" VALUES(5935,NULL,'Dorchester, NJ',2417,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5936,NULL,'Dorchester, NJ 8316',2417,222,NULL,30,3226,0);
INSERT INTO "django_geo_db_location" VALUES(5937,NULL,'Dorothy, NJ',2418,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5938,NULL,'Dorothy, NJ 8317',2418,222,NULL,30,3227,0);
INSERT INTO "django_geo_db_location" VALUES(5939,NULL,'Elmer, NJ',2419,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5940,NULL,'Elmer, NJ 8318',2419,222,NULL,30,3228,0);
INSERT INTO "django_geo_db_location" VALUES(5941,NULL,'Estell Manor, NJ',2420,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5942,NULL,'Estell Manor, NJ 8319',2420,222,NULL,30,3229,0);
INSERT INTO "django_geo_db_location" VALUES(5943,NULL,'Fairton, NJ',2421,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5944,NULL,'Fairton, NJ 8320',2421,222,NULL,30,3230,0);
INSERT INTO "django_geo_db_location" VALUES(5945,NULL,'Fortescue, NJ',2422,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5946,NULL,'Fortescue, NJ 8321',2422,222,NULL,30,3231,0);
INSERT INTO "django_geo_db_location" VALUES(5947,NULL,'Franklinville, NJ',2423,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5948,NULL,'Franklinville, NJ 8322',2423,222,NULL,30,3232,0);
INSERT INTO "django_geo_db_location" VALUES(5949,NULL,'Greenwich, NJ',2424,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5950,NULL,'Greenwich, NJ 8323',2424,222,NULL,30,3233,0);
INSERT INTO "django_geo_db_location" VALUES(5951,NULL,'Heislerville, NJ',2425,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5952,NULL,'Heislerville, NJ 8324',2425,222,NULL,30,3234,0);
INSERT INTO "django_geo_db_location" VALUES(5953,NULL,'Landisville, NJ',2426,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5954,NULL,'Landisville, NJ 8326',2426,222,NULL,30,3235,0);
INSERT INTO "django_geo_db_location" VALUES(5955,NULL,'Leesburg, NJ',2427,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5956,NULL,'Leesburg, NJ 8327',2427,222,NULL,30,3236,0);
INSERT INTO "django_geo_db_location" VALUES(5957,NULL,'Malaga, NJ',2428,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5958,NULL,'Malaga, NJ 8328',2428,222,NULL,30,3237,0);
INSERT INTO "django_geo_db_location" VALUES(5959,NULL,'Mauricetown, NJ',2429,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5960,NULL,'Mauricetown, NJ 8329',2429,222,NULL,30,3238,0);
INSERT INTO "django_geo_db_location" VALUES(5961,NULL,'Mays Landing, NJ',2430,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5962,NULL,'Mays Landing, NJ 8330',2430,222,NULL,30,3239,0);
INSERT INTO "django_geo_db_location" VALUES(5963,NULL,'Millville, NJ',2431,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5964,NULL,'Millville, NJ 8332',2431,222,NULL,30,3240,0);
INSERT INTO "django_geo_db_location" VALUES(5965,NULL,'Downe, NJ',2432,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5966,NULL,'Downe, NJ 8334',2432,222,NULL,30,3241,0);
INSERT INTO "django_geo_db_location" VALUES(5967,NULL,'Milmay, NJ',2433,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5968,NULL,'Milmay, NJ 8340',2433,222,NULL,30,3242,0);
INSERT INTO "django_geo_db_location" VALUES(5969,NULL,'Minotola, NJ',2434,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5970,NULL,'Minotola, NJ 8341',2434,222,NULL,30,3243,0);
INSERT INTO "django_geo_db_location" VALUES(5971,NULL,'Mizpah, NJ',2435,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5972,NULL,'Mizpah, NJ 8342',2435,222,NULL,30,3244,0);
INSERT INTO "django_geo_db_location" VALUES(5973,NULL,'Monroeville, NJ',2436,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5974,NULL,'Monroeville, NJ 8343',2436,222,NULL,30,3245,0);
INSERT INTO "django_geo_db_location" VALUES(5975,NULL,'Newfield, NJ',2437,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5976,NULL,'Newfield, NJ 8344',2437,222,NULL,30,3246,0);
INSERT INTO "django_geo_db_location" VALUES(5977,NULL,'Newport, NJ',2438,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5978,NULL,'Newport, NJ 8345',2438,222,NULL,30,3247,0);
INSERT INTO "django_geo_db_location" VALUES(5979,NULL,'Newtonville, NJ',2439,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5980,NULL,'Newtonville, NJ 8346',2439,222,NULL,30,3248,0);
INSERT INTO "django_geo_db_location" VALUES(5981,NULL,'Norma, NJ',2440,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5982,NULL,'Norma, NJ 8347',2440,222,NULL,30,3249,0);
INSERT INTO "django_geo_db_location" VALUES(5983,NULL,'Port Elizabeth, NJ',2441,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5984,NULL,'Port Elizabeth, NJ 8348',2441,222,NULL,30,3250,0);
INSERT INTO "django_geo_db_location" VALUES(5985,NULL,'Port Norris, NJ',2442,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5986,NULL,'Port Norris, NJ 8349',2442,222,NULL,30,3251,0);
INSERT INTO "django_geo_db_location" VALUES(5987,NULL,'Richland, NJ',2443,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5988,NULL,'Richland, NJ 8350',2443,222,NULL,30,3252,0);
INSERT INTO "django_geo_db_location" VALUES(5989,NULL,'Rosenhayn, NJ',2444,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5990,NULL,'Rosenhayn, NJ 8352',2444,222,NULL,30,3253,0);
INSERT INTO "django_geo_db_location" VALUES(5991,NULL,'Shiloh, NJ 8353',2407,222,NULL,30,3254,0);
INSERT INTO "django_geo_db_location" VALUES(5992,NULL,'Vineland, NJ',2445,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5993,NULL,'Vineland, NJ 8360',2445,222,NULL,30,3255,0);
INSERT INTO "django_geo_db_location" VALUES(5994,NULL,'Vineland, NJ 8361',2445,222,NULL,30,3256,0);
INSERT INTO "django_geo_db_location" VALUES(5995,NULL,'Vineland, NJ 8362',2445,222,NULL,30,3257,0);
INSERT INTO "django_geo_db_location" VALUES(5996,NULL,'Riverside, NJ 8370',2343,222,NULL,30,3258,0);
INSERT INTO "django_geo_db_location" VALUES(5997,NULL,'Atlantic City, NJ',2446,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(5998,NULL,'Atlantic City, NJ 8401',2446,222,NULL,30,3259,0);
INSERT INTO "django_geo_db_location" VALUES(5999,NULL,'Margate City, NJ',2447,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6000,NULL,'Margate City, NJ 8402',2447,222,NULL,30,3260,0);
INSERT INTO "django_geo_db_location" VALUES(6001,NULL,'Longport, NJ',2448,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6002,NULL,'Longport, NJ 8403',2448,222,NULL,30,3261,0);
INSERT INTO "django_geo_db_location" VALUES(6003,NULL,'Atlantic City, NJ 8404',2446,222,NULL,30,3262,0);
INSERT INTO "django_geo_db_location" VALUES(6004,NULL,'Atlantic City, NJ 8405',2446,222,NULL,30,3263,0);
INSERT INTO "django_geo_db_location" VALUES(6005,NULL,'Ventnor City, NJ',2449,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6006,NULL,'Ventnor City, NJ 8406',2449,222,NULL,30,3264,0);
INSERT INTO "django_geo_db_location" VALUES(6007,NULL,'Allentown, NJ',2450,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6008,NULL,'Allentown, NJ 8501',2450,222,NULL,30,3265,0);
INSERT INTO "django_geo_db_location" VALUES(6009,NULL,'Belle Mead, NJ',2451,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6010,NULL,'Belle Mead, NJ 8502',2451,222,NULL,30,3266,0);
INSERT INTO "django_geo_db_location" VALUES(6011,NULL,'Blawenburg, NJ',2452,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6012,NULL,'Blawenburg, NJ 8504',2452,222,NULL,30,3267,0);
INSERT INTO "django_geo_db_location" VALUES(6013,NULL,'Bordentown, NJ',2453,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6014,NULL,'Bordentown, NJ 8505',2453,222,NULL,30,3268,0);
INSERT INTO "django_geo_db_location" VALUES(6015,NULL,'Clarksburg, NJ',2454,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6016,NULL,'Clarksburg, NJ 8510',2454,222,NULL,30,3269,0);
INSERT INTO "django_geo_db_location" VALUES(6017,NULL,'Cookstown, NJ',2455,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6018,NULL,'Cookstown, NJ 8511',2455,222,NULL,30,3270,0);
INSERT INTO "django_geo_db_location" VALUES(6019,NULL,'Cranbury, NJ',2456,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6020,NULL,'Cranbury, NJ 8512',2456,222,NULL,30,3271,0);
INSERT INTO "django_geo_db_location" VALUES(6021,NULL,'Cream Ridge, NJ',2457,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6022,NULL,'Cream Ridge, NJ 8514',2457,222,NULL,30,3272,0);
INSERT INTO "django_geo_db_location" VALUES(6023,NULL,'Crosswicks, NJ',2458,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6024,NULL,'Crosswicks, NJ 8515',2458,222,NULL,30,3273,0);
INSERT INTO "django_geo_db_location" VALUES(6025,NULL,'Florence, NJ',2459,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6026,NULL,'Florence, NJ 8518',2459,222,NULL,30,3274,0);
INSERT INTO "django_geo_db_location" VALUES(6027,NULL,'Hightstown, NJ',2460,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6028,NULL,'Hightstown, NJ 8520',2460,222,NULL,30,3275,0);
INSERT INTO "django_geo_db_location" VALUES(6029,NULL,'Hopewell, NJ',2461,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6030,NULL,'Hopewell, NJ 8525',2461,222,NULL,30,3276,0);
INSERT INTO "django_geo_db_location" VALUES(6031,NULL,'Imlaystown, NJ',2462,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6032,NULL,'Imlaystown, NJ 8526',2462,222,NULL,30,3277,0);
INSERT INTO "django_geo_db_location" VALUES(6033,NULL,'Jackson, NJ',2463,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6034,NULL,'Jackson, NJ 8527',2463,222,NULL,30,3278,0);
INSERT INTO "django_geo_db_location" VALUES(6035,NULL,'Kingston, NJ',2464,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6036,NULL,'Kingston, NJ 8528',2464,222,NULL,30,3279,0);
INSERT INTO "django_geo_db_location" VALUES(6037,NULL,'Lambertville, NJ',2465,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6038,NULL,'Lambertville, NJ 8530',2465,222,NULL,30,3280,0);
INSERT INTO "django_geo_db_location" VALUES(6039,NULL,'New Egypt, NJ',2466,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6040,NULL,'New Egypt, NJ 8533',2466,222,NULL,30,3281,0);
INSERT INTO "django_geo_db_location" VALUES(6041,NULL,'Pennington, NJ',2467,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6042,NULL,'Pennington, NJ 8534',2467,222,NULL,30,3282,0);
INSERT INTO "django_geo_db_location" VALUES(6043,NULL,'Perrineville, NJ',2468,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6044,NULL,'Perrineville, NJ 8535',2468,222,NULL,30,3283,0);
INSERT INTO "django_geo_db_location" VALUES(6045,NULL,'Plainsboro, NJ',2469,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6046,NULL,'Plainsboro, NJ 8536',2469,222,NULL,30,3284,0);
INSERT INTO "django_geo_db_location" VALUES(6047,NULL,'Princeton, NJ',2470,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6048,NULL,'Princeton, NJ 8540',2470,222,NULL,30,3285,0);
INSERT INTO "django_geo_db_location" VALUES(6049,NULL,'Princeton, NJ 8541',2470,222,NULL,30,3286,0);
INSERT INTO "django_geo_db_location" VALUES(6050,NULL,'Princeton, NJ 8542',2470,222,NULL,30,3287,0);
INSERT INTO "django_geo_db_location" VALUES(6051,NULL,'Princeton, NJ 8543',2470,222,NULL,30,3288,0);
INSERT INTO "django_geo_db_location" VALUES(6052,NULL,'Princeton, NJ 8544',2470,222,NULL,30,3289,0);
INSERT INTO "django_geo_db_location" VALUES(6053,NULL,'Princeton Junction, NJ',2471,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6054,NULL,'Princeton Junction, NJ 8550',2471,222,NULL,30,3290,0);
INSERT INTO "django_geo_db_location" VALUES(6055,NULL,'Ringoes, NJ',2472,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6056,NULL,'Ringoes, NJ 8551',2472,222,NULL,30,3291,0);
INSERT INTO "django_geo_db_location" VALUES(6057,NULL,'Rocky Hill, NJ',2473,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6058,NULL,'Rocky Hill, NJ 8553',2473,222,NULL,30,3292,0);
INSERT INTO "django_geo_db_location" VALUES(6059,NULL,'Roebling, NJ',2474,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6060,NULL,'Roebling, NJ 8554',2474,222,NULL,30,3293,0);
INSERT INTO "django_geo_db_location" VALUES(6061,NULL,'Roosevelt, NJ',2475,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6062,NULL,'Roosevelt, NJ 8555',2475,222,NULL,30,3294,0);
INSERT INTO "django_geo_db_location" VALUES(6063,NULL,'Rosemont, NJ',2476,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6064,NULL,'Rosemont, NJ 8556',2476,222,NULL,30,3295,0);
INSERT INTO "django_geo_db_location" VALUES(6065,NULL,'Sergeantsville, NJ',2477,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6066,NULL,'Sergeantsville, NJ 8557',2477,222,NULL,30,3296,0);
INSERT INTO "django_geo_db_location" VALUES(6067,NULL,'Skillman, NJ',2478,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6068,NULL,'Skillman, NJ 8558',2478,222,NULL,30,3297,0);
INSERT INTO "django_geo_db_location" VALUES(6069,NULL,'Stockton, NJ',2479,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6070,NULL,'Stockton, NJ 8559',2479,222,NULL,30,3298,0);
INSERT INTO "django_geo_db_location" VALUES(6071,NULL,'Titusville, NJ',2480,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6072,NULL,'Titusville, NJ 8560',2480,222,NULL,30,3299,0);
INSERT INTO "django_geo_db_location" VALUES(6073,NULL,'Windsor, NJ',2481,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6074,NULL,'Windsor, NJ 8561',2481,222,NULL,30,3300,0);
INSERT INTO "django_geo_db_location" VALUES(6075,NULL,'Wrightstown, NJ',2482,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6076,NULL,'Wrightstown, NJ 8562',2482,222,NULL,30,3301,0);
INSERT INTO "django_geo_db_location" VALUES(6077,NULL,'Cranbury, NJ 8570',2456,222,NULL,30,3302,0);
INSERT INTO "django_geo_db_location" VALUES(6078,NULL,'Trenton, NJ',2483,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6079,NULL,'Trenton, NJ 8601',2483,222,NULL,30,3303,0);
INSERT INTO "django_geo_db_location" VALUES(6080,NULL,'Trenton, NJ 8602',2483,222,NULL,30,3304,0);
INSERT INTO "django_geo_db_location" VALUES(6081,NULL,'Trenton, NJ 8603',2483,222,NULL,30,3305,0);
INSERT INTO "django_geo_db_location" VALUES(6082,NULL,'Trenton, NJ 8604',2483,222,NULL,30,3306,0);
INSERT INTO "django_geo_db_location" VALUES(6083,NULL,'Trenton, NJ 8605',2483,222,NULL,30,3307,0);
INSERT INTO "django_geo_db_location" VALUES(6084,NULL,'Trenton, NJ 8606',2483,222,NULL,30,3308,0);
INSERT INTO "django_geo_db_location" VALUES(6085,NULL,'Trenton, NJ 8607',2483,222,NULL,30,3309,0);
INSERT INTO "django_geo_db_location" VALUES(6086,NULL,'Trenton, NJ 8608',2483,222,NULL,30,3310,0);
INSERT INTO "django_geo_db_location" VALUES(6087,NULL,'Trenton, NJ 8609',2483,222,NULL,30,3311,0);
INSERT INTO "django_geo_db_location" VALUES(6088,NULL,'Trenton, NJ 8610',2483,222,NULL,30,3312,0);
INSERT INTO "django_geo_db_location" VALUES(6089,NULL,'Trenton, NJ 8611',2483,222,NULL,30,3313,0);
INSERT INTO "django_geo_db_location" VALUES(6090,NULL,'Trenton, NJ 8618',2483,222,NULL,30,3314,0);
INSERT INTO "django_geo_db_location" VALUES(6091,NULL,'Trenton, NJ 8619',2483,222,NULL,30,3315,0);
INSERT INTO "django_geo_db_location" VALUES(6092,NULL,'Trenton, NJ 8620',2483,222,NULL,30,3316,0);
INSERT INTO "django_geo_db_location" VALUES(6093,NULL,'Trenton, NJ 8625',2483,222,NULL,30,3317,0);
INSERT INTO "django_geo_db_location" VALUES(6094,NULL,'Trenton, NJ 8628',2483,222,NULL,30,3318,0);
INSERT INTO "django_geo_db_location" VALUES(6095,NULL,'Trenton, NJ 8629',2483,222,NULL,30,3319,0);
INSERT INTO "django_geo_db_location" VALUES(6096,NULL,'Trenton, NJ 8638',2483,222,NULL,30,3320,0);
INSERT INTO "django_geo_db_location" VALUES(6097,NULL,'Trenton, NJ 8640',2483,222,NULL,30,3321,0);
INSERT INTO "django_geo_db_location" VALUES(6098,NULL,'Trenton, NJ 8641',2483,222,NULL,30,3322,0);
INSERT INTO "django_geo_db_location" VALUES(6099,NULL,'Trenton, NJ 8645',2483,222,NULL,30,3323,0);
INSERT INTO "django_geo_db_location" VALUES(6100,NULL,'Trenton, NJ 8646',2483,222,NULL,30,3324,0);
INSERT INTO "django_geo_db_location" VALUES(6101,NULL,'Trenton, NJ 8647',2483,222,NULL,30,3325,0);
INSERT INTO "django_geo_db_location" VALUES(6102,NULL,'Trenton, NJ 8648',2483,222,NULL,30,3326,0);
INSERT INTO "django_geo_db_location" VALUES(6103,NULL,'Trenton, NJ 8650',2483,222,NULL,30,3327,0);
INSERT INTO "django_geo_db_location" VALUES(6104,NULL,'Trenton, NJ 8666',2483,222,NULL,30,3328,0);
INSERT INTO "django_geo_db_location" VALUES(6105,NULL,'Trenton, NJ 8677',2483,222,NULL,30,3329,0);
INSERT INTO "django_geo_db_location" VALUES(6106,NULL,'Trenton, NJ 8690',2483,222,NULL,30,3330,0);
INSERT INTO "django_geo_db_location" VALUES(6107,NULL,'Trenton, NJ 8691',2483,222,NULL,30,3331,0);
INSERT INTO "django_geo_db_location" VALUES(6108,NULL,'Trenton, NJ 8695',2483,222,NULL,30,3332,0);
INSERT INTO "django_geo_db_location" VALUES(6109,NULL,'Lakewood, NJ',2484,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6110,NULL,'Lakewood, NJ 8701',2484,222,NULL,30,3333,0);
INSERT INTO "django_geo_db_location" VALUES(6111,NULL,'Allenwood, NJ',2485,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6112,NULL,'Allenwood, NJ 8720',2485,222,NULL,30,3334,0);
INSERT INTO "django_geo_db_location" VALUES(6113,NULL,'Bayville, NJ',2486,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6114,NULL,'Bayville, NJ 8721',2486,222,NULL,30,3335,0);
INSERT INTO "django_geo_db_location" VALUES(6115,NULL,'Beachwood, NJ',2487,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6116,NULL,'Beachwood, NJ 8722',2487,222,NULL,30,3336,0);
INSERT INTO "django_geo_db_location" VALUES(6117,NULL,'Brick, NJ',2488,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6118,NULL,'Brick, NJ 8723',2488,222,NULL,30,3337,0);
INSERT INTO "django_geo_db_location" VALUES(6119,NULL,'Brick, NJ 8724',2488,222,NULL,30,3338,0);
INSERT INTO "django_geo_db_location" VALUES(6120,NULL,'Brielle, NJ',2489,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6121,NULL,'Brielle, NJ 8730',2489,222,NULL,30,3339,0);
INSERT INTO "django_geo_db_location" VALUES(6122,NULL,'Forked River, NJ',2490,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6123,NULL,'Forked River, NJ 8731',2490,222,NULL,30,3340,0);
INSERT INTO "django_geo_db_location" VALUES(6124,NULL,'Island Heights, NJ',2491,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6125,NULL,'Island Heights, NJ 8732',2491,222,NULL,30,3341,0);
INSERT INTO "django_geo_db_location" VALUES(6126,NULL,'Lakehurst, NJ',2492,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6127,NULL,'Lakehurst, NJ 8733',2492,222,NULL,30,3342,0);
INSERT INTO "django_geo_db_location" VALUES(6128,NULL,'Lanoka Harbor, NJ',2493,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6129,NULL,'Lanoka Harbor, NJ 8734',2493,222,NULL,30,3343,0);
INSERT INTO "django_geo_db_location" VALUES(6130,NULL,'Lavallette, NJ',2494,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6131,NULL,'Lavallette, NJ 8735',2494,222,NULL,30,3344,0);
INSERT INTO "django_geo_db_location" VALUES(6132,NULL,'Manasquan, NJ',2495,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6133,NULL,'Manasquan, NJ 8736',2495,222,NULL,30,3345,0);
INSERT INTO "django_geo_db_location" VALUES(6134,NULL,'Mantoloking, NJ',2496,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6135,NULL,'Mantoloking, NJ 8738',2496,222,NULL,30,3346,0);
INSERT INTO "django_geo_db_location" VALUES(6136,NULL,'Normandy Beach, NJ',2497,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6137,NULL,'Normandy Beach, NJ 8739',2497,222,NULL,30,3347,0);
INSERT INTO "django_geo_db_location" VALUES(6138,NULL,'Ocean Gate, NJ',2498,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6139,NULL,'Ocean Gate, NJ 8740',2498,222,NULL,30,3348,0);
INSERT INTO "django_geo_db_location" VALUES(6140,NULL,'Pine Beach, NJ',2499,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6141,NULL,'Pine Beach, NJ 8741',2499,222,NULL,30,3349,0);
INSERT INTO "django_geo_db_location" VALUES(6142,NULL,'Point Pleasant Beach, NJ',2500,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6143,NULL,'Point Pleasant Beach, NJ 8742',2500,222,NULL,30,3350,0);
INSERT INTO "django_geo_db_location" VALUES(6144,NULL,'Sea Girt, NJ',2501,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6145,NULL,'Sea Girt, NJ 8750',2501,222,NULL,30,3351,0);
INSERT INTO "django_geo_db_location" VALUES(6146,NULL,'Seaside Heights, NJ',2502,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6147,NULL,'Seaside Heights, NJ 8751',2502,222,NULL,30,3352,0);
INSERT INTO "django_geo_db_location" VALUES(6148,NULL,'Seaside Park, NJ',2503,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6149,NULL,'Seaside Park, NJ 8752',2503,222,NULL,30,3353,0);
INSERT INTO "django_geo_db_location" VALUES(6150,NULL,'Toms River, NJ',2504,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6151,NULL,'Toms River, NJ 8753',2504,222,NULL,30,3354,0);
INSERT INTO "django_geo_db_location" VALUES(6152,NULL,'Toms River, NJ 8754',2504,222,NULL,30,3355,0);
INSERT INTO "django_geo_db_location" VALUES(6153,NULL,'Toms River, NJ 8755',2504,222,NULL,30,3356,0);
INSERT INTO "django_geo_db_location" VALUES(6154,NULL,'Toms River, NJ 8756',2504,222,NULL,30,3357,0);
INSERT INTO "django_geo_db_location" VALUES(6155,NULL,'Toms River, NJ 8757',2504,222,NULL,30,3358,0);
INSERT INTO "django_geo_db_location" VALUES(6156,NULL,'Waretown, NJ',2505,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6157,NULL,'Waretown, NJ 8758',2505,222,NULL,30,3359,0);
INSERT INTO "django_geo_db_location" VALUES(6158,NULL,'Whiting, NJ',2506,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6159,NULL,'Whiting, NJ 8759',2506,222,NULL,30,3360,0);
INSERT INTO "django_geo_db_location" VALUES(6160,NULL,'Berkeley, NJ',2507,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6161,NULL,'Berkeley, NJ 8792',2507,222,NULL,30,3361,0);
INSERT INTO "django_geo_db_location" VALUES(6162,NULL,'Annandale, NJ',2508,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6163,NULL,'Annandale, NJ 8801',2508,222,NULL,30,3362,0);
INSERT INTO "django_geo_db_location" VALUES(6164,NULL,'Asbury, NJ',2509,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6165,NULL,'Asbury, NJ 8802',2509,222,NULL,30,3363,0);
INSERT INTO "django_geo_db_location" VALUES(6166,NULL,'Baptistown, NJ',2510,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6167,NULL,'Baptistown, NJ 8803',2510,222,NULL,30,3364,0);
INSERT INTO "django_geo_db_location" VALUES(6168,NULL,'Bloomsbury, NJ',2511,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6169,NULL,'Bloomsbury, NJ 8804',2511,222,NULL,30,3365,0);
INSERT INTO "django_geo_db_location" VALUES(6170,NULL,'Bound Brook, NJ',2512,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6171,NULL,'Bound Brook, NJ 8805',2512,222,NULL,30,3366,0);
INSERT INTO "django_geo_db_location" VALUES(6172,NULL,'Bridgewater, NJ',2513,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6173,NULL,'Bridgewater, NJ 8807',2513,222,NULL,30,3367,0);
INSERT INTO "django_geo_db_location" VALUES(6174,NULL,'Broadway, NJ',2514,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6175,NULL,'Broadway, NJ 8808',2514,222,NULL,30,3368,0);
INSERT INTO "django_geo_db_location" VALUES(6176,NULL,'Clinton, NJ',2515,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6177,NULL,'Clinton, NJ 8809',2515,222,NULL,30,3369,0);
INSERT INTO "django_geo_db_location" VALUES(6178,NULL,'Dayton, NJ',2516,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6179,NULL,'Dayton, NJ 8810',2516,222,NULL,30,3370,0);
INSERT INTO "django_geo_db_location" VALUES(6180,NULL,'Dunellen, NJ',2517,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6181,NULL,'Dunellen, NJ 8812',2517,222,NULL,30,3371,0);
INSERT INTO "django_geo_db_location" VALUES(6182,NULL,'East Brunswick, NJ',2518,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6183,NULL,'East Brunswick, NJ 8816',2518,222,NULL,30,3372,0);
INSERT INTO "django_geo_db_location" VALUES(6184,NULL,'Edison, NJ',2519,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6185,NULL,'Edison, NJ 8817',2519,222,NULL,30,3373,0);
INSERT INTO "django_geo_db_location" VALUES(6186,NULL,'Edison, NJ 8818',2519,222,NULL,30,3374,0);
INSERT INTO "django_geo_db_location" VALUES(6187,NULL,'Edison, NJ 8820',2519,222,NULL,30,3375,0);
INSERT INTO "django_geo_db_location" VALUES(6188,NULL,'Flagtown, NJ',2520,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6189,NULL,'Flagtown, NJ 8821',2520,222,NULL,30,3376,0);
INSERT INTO "django_geo_db_location" VALUES(6190,NULL,'Flemington, NJ',2521,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6191,NULL,'Flemington, NJ 8822',2521,222,NULL,30,3377,0);
INSERT INTO "django_geo_db_location" VALUES(6192,NULL,'Franklin Park, NJ',2522,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6193,NULL,'Franklin Park, NJ 8823',2522,222,NULL,30,3378,0);
INSERT INTO "django_geo_db_location" VALUES(6194,NULL,'Kendall Park, NJ',2523,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6195,NULL,'Kendall Park, NJ 8824',2523,222,NULL,30,3379,0);
INSERT INTO "django_geo_db_location" VALUES(6196,NULL,'Frenchtown, NJ',2524,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6197,NULL,'Frenchtown, NJ 8825',2524,222,NULL,30,3380,0);
INSERT INTO "django_geo_db_location" VALUES(6198,NULL,'Glen Gardner, NJ',2525,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6199,NULL,'Glen Gardner, NJ 8826',2525,222,NULL,30,3381,0);
INSERT INTO "django_geo_db_location" VALUES(6200,NULL,'Hampton, NJ',2526,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6201,NULL,'Hampton, NJ 8827',2526,222,NULL,30,3382,0);
INSERT INTO "django_geo_db_location" VALUES(6202,NULL,'Helmetta, NJ',2527,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6203,NULL,'Helmetta, NJ 8828',2527,222,NULL,30,3383,0);
INSERT INTO "django_geo_db_location" VALUES(6204,NULL,'High Bridge, NJ',2528,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6205,NULL,'High Bridge, NJ 8829',2528,222,NULL,30,3384,0);
INSERT INTO "django_geo_db_location" VALUES(6206,NULL,'Iselin, NJ',2529,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6207,NULL,'Iselin, NJ 8830',2529,222,NULL,30,3385,0);
INSERT INTO "django_geo_db_location" VALUES(6208,NULL,'Jamesburg, NJ',2530,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6209,NULL,'Jamesburg, NJ 8831',2530,222,NULL,30,3386,0);
INSERT INTO "django_geo_db_location" VALUES(6210,NULL,'Keasbey, NJ',2531,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6211,NULL,'Keasbey, NJ 8832',2531,222,NULL,30,3387,0);
INSERT INTO "django_geo_db_location" VALUES(6212,NULL,'Lebanon, NJ',2532,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6213,NULL,'Lebanon, NJ 8833',2532,222,NULL,30,3388,0);
INSERT INTO "django_geo_db_location" VALUES(6214,NULL,'Little York, NJ',2533,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6215,NULL,'Little York, NJ 8834',2533,222,NULL,30,3389,0);
INSERT INTO "django_geo_db_location" VALUES(6216,NULL,'Manville, NJ',2534,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6217,NULL,'Manville, NJ 8835',2534,222,NULL,30,3390,0);
INSERT INTO "django_geo_db_location" VALUES(6218,NULL,'Martinsville, NJ',2535,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6219,NULL,'Martinsville, NJ 8836',2535,222,NULL,30,3391,0);
INSERT INTO "django_geo_db_location" VALUES(6220,NULL,'Edison, NJ 8837',2519,222,NULL,30,3392,0);
INSERT INTO "django_geo_db_location" VALUES(6221,NULL,'Metuchen, NJ',2536,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6222,NULL,'Metuchen, NJ 8840',2536,222,NULL,30,3393,0);
INSERT INTO "django_geo_db_location" VALUES(6223,NULL,'Millstone, NJ',2537,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6224,NULL,'Millstone, NJ 8844',2537,222,NULL,30,3394,0);
INSERT INTO "django_geo_db_location" VALUES(6225,NULL,'Middlesex, NJ',2538,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6226,NULL,'Middlesex, NJ 8846',2538,222,NULL,30,3395,0);
INSERT INTO "django_geo_db_location" VALUES(6227,NULL,'Milford, NJ',2539,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6228,NULL,'Milford, NJ 8848',2539,222,NULL,30,3396,0);
INSERT INTO "django_geo_db_location" VALUES(6229,NULL,'Milltown, NJ',2540,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6230,NULL,'Milltown, NJ 8850',2540,222,NULL,30,3397,0);
INSERT INTO "django_geo_db_location" VALUES(6231,NULL,'East Amwell, NJ',2541,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6232,NULL,'East Amwell, NJ 8851',2541,222,NULL,30,3398,0);
INSERT INTO "django_geo_db_location" VALUES(6233,NULL,'Monmouth Junction, NJ',2542,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6234,NULL,'Monmouth Junction, NJ 8852',2542,222,NULL,30,3399,0);
INSERT INTO "django_geo_db_location" VALUES(6235,NULL,'Neshanic Station, NJ',2543,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6236,NULL,'Neshanic Station, NJ 8853',2543,222,NULL,30,3400,0);
INSERT INTO "django_geo_db_location" VALUES(6237,NULL,'Piscataway, NJ',2544,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6238,NULL,'Piscataway, NJ 8854',2544,222,NULL,30,3401,0);
INSERT INTO "django_geo_db_location" VALUES(6239,NULL,'Piscataway, NJ 8855',2544,222,NULL,30,3402,0);
INSERT INTO "django_geo_db_location" VALUES(6240,NULL,'Old Bridge, NJ',2545,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6241,NULL,'Old Bridge, NJ 8857',2545,222,NULL,30,3403,0);
INSERT INTO "django_geo_db_location" VALUES(6242,NULL,'Oldwick, NJ',2546,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6243,NULL,'Oldwick, NJ 8858',2546,222,NULL,30,3404,0);
INSERT INTO "django_geo_db_location" VALUES(6244,NULL,'Parlin, NJ',2547,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6245,NULL,'Parlin, NJ 8859',2547,222,NULL,30,3405,0);
INSERT INTO "django_geo_db_location" VALUES(6246,NULL,'Perth Amboy, NJ',2548,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6247,NULL,'Perth Amboy, NJ 8861',2548,222,NULL,30,3406,0);
INSERT INTO "django_geo_db_location" VALUES(6248,NULL,'Perth Amboy, NJ 8862',2548,222,NULL,30,3407,0);
INSERT INTO "django_geo_db_location" VALUES(6249,NULL,'Fords, NJ',2549,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6250,NULL,'Fords, NJ 8863',2549,222,NULL,30,3408,0);
INSERT INTO "django_geo_db_location" VALUES(6251,NULL,'Phillipsburg, NJ',2550,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6252,NULL,'Phillipsburg, NJ 8865',2550,222,NULL,30,3409,0);
INSERT INTO "django_geo_db_location" VALUES(6253,NULL,'Pittstown, NJ',2551,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6254,NULL,'Pittstown, NJ 8867',2551,222,NULL,30,3410,0);
INSERT INTO "django_geo_db_location" VALUES(6255,NULL,'Quakertown, NJ',2552,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6256,NULL,'Quakertown, NJ 8868',2552,222,NULL,30,3411,0);
INSERT INTO "django_geo_db_location" VALUES(6257,NULL,'Raritan, NJ',2553,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6258,NULL,'Raritan, NJ 8869',2553,222,NULL,30,3412,0);
INSERT INTO "django_geo_db_location" VALUES(6259,NULL,'Readington, NJ',2554,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6260,NULL,'Readington, NJ 8870',2554,222,NULL,30,3413,0);
INSERT INTO "django_geo_db_location" VALUES(6261,NULL,'Sayreville, NJ',2555,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6262,NULL,'Sayreville, NJ 8871',2555,222,NULL,30,3414,0);
INSERT INTO "django_geo_db_location" VALUES(6263,NULL,'Sayreville, NJ 8872',2555,222,NULL,30,3415,0);
INSERT INTO "django_geo_db_location" VALUES(6264,NULL,'Somerset, NJ',2556,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6265,NULL,'Somerset, NJ 8873',2556,222,NULL,30,3416,0);
INSERT INTO "django_geo_db_location" VALUES(6266,NULL,'Somerset, NJ 8875',2556,222,NULL,30,3417,0);
INSERT INTO "django_geo_db_location" VALUES(6267,NULL,'Somerville, NJ',2557,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6268,NULL,'Somerville, NJ 8876',2557,222,NULL,30,3418,0);
INSERT INTO "django_geo_db_location" VALUES(6269,NULL,'South River, NJ',2558,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6270,NULL,'South River, NJ 8877',2558,222,NULL,30,3419,0);
INSERT INTO "django_geo_db_location" VALUES(6271,NULL,'South Amboy, NJ',2559,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6272,NULL,'South Amboy, NJ 8878',2559,222,NULL,30,3420,0);
INSERT INTO "django_geo_db_location" VALUES(6273,NULL,'South Amboy, NJ 8879',2559,222,NULL,30,3421,0);
INSERT INTO "django_geo_db_location" VALUES(6274,NULL,'South Bound Brook, NJ',2560,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6275,NULL,'South Bound Brook, NJ 8880',2560,222,NULL,30,3422,0);
INSERT INTO "django_geo_db_location" VALUES(6276,NULL,'South River, NJ 8882',2558,222,NULL,30,3423,0);
INSERT INTO "django_geo_db_location" VALUES(6277,NULL,'Spotswood, NJ',2561,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6278,NULL,'Spotswood, NJ 8884',2561,222,NULL,30,3424,0);
INSERT INTO "django_geo_db_location" VALUES(6279,NULL,'Stanton, NJ',2562,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6280,NULL,'Stanton, NJ 8885',2562,222,NULL,30,3425,0);
INSERT INTO "django_geo_db_location" VALUES(6281,NULL,'Stewartsville, NJ',2563,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6282,NULL,'Stewartsville, NJ 8886',2563,222,NULL,30,3426,0);
INSERT INTO "django_geo_db_location" VALUES(6283,NULL,'Three Bridges, NJ',2564,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6284,NULL,'Three Bridges, NJ 8887',2564,222,NULL,30,3427,0);
INSERT INTO "django_geo_db_location" VALUES(6285,NULL,'Whitehouse, NJ',2565,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6286,NULL,'Whitehouse, NJ 8888',2565,222,NULL,30,3428,0);
INSERT INTO "django_geo_db_location" VALUES(6287,NULL,'Whitehouse Station, NJ',2566,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6288,NULL,'Whitehouse Station, NJ 8889',2566,222,NULL,30,3429,0);
INSERT INTO "django_geo_db_location" VALUES(6289,NULL,'Zarephath, NJ',2567,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6290,NULL,'Zarephath, NJ 8890',2567,222,NULL,30,3430,0);
INSERT INTO "django_geo_db_location" VALUES(6291,NULL,'Raritan, NJ 8896',2553,222,NULL,30,3431,0);
INSERT INTO "django_geo_db_location" VALUES(6292,NULL,'Edison, NJ 8899',2519,222,NULL,30,3432,0);
INSERT INTO "django_geo_db_location" VALUES(6293,NULL,'New Brunswick, NJ',2568,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6294,NULL,'New Brunswick, NJ 8901',2568,222,NULL,30,3433,0);
INSERT INTO "django_geo_db_location" VALUES(6295,NULL,'North Brunswick, NJ',2569,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6296,NULL,'North Brunswick, NJ 8902',2569,222,NULL,30,3434,0);
INSERT INTO "django_geo_db_location" VALUES(6297,NULL,'New Brunswick, NJ 8903',2568,222,NULL,30,3435,0);
INSERT INTO "django_geo_db_location" VALUES(6298,NULL,'Highland Park, NJ',2570,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6299,NULL,'Highland Park, NJ 8904',2570,222,NULL,30,3436,0);
INSERT INTO "django_geo_db_location" VALUES(6300,NULL,'New Brunswick, NJ 8905',2568,222,NULL,30,3437,0);
INSERT INTO "django_geo_db_location" VALUES(6301,NULL,'New Brunswick, NJ 8906',2568,222,NULL,30,3438,0);
INSERT INTO "django_geo_db_location" VALUES(6302,NULL,'New Brunswick, NJ 8907',2568,222,NULL,30,3439,0);
INSERT INTO "django_geo_db_location" VALUES(6303,NULL,'New Brunswick, NJ 8922',2568,222,NULL,30,3440,0);
INSERT INTO "django_geo_db_location" VALUES(6304,NULL,'New Brunswick, NJ 8933',2568,222,NULL,30,3441,0);
INSERT INTO "django_geo_db_location" VALUES(6305,NULL,'New Brunswick, NJ 8988',2568,222,NULL,30,3442,0);
INSERT INTO "django_geo_db_location" VALUES(6306,NULL,'New Brunswick, NJ 8989',2568,222,NULL,30,3443,0);
INSERT INTO "django_geo_db_location" VALUES(6307,NULL,'New York, NY',2571,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6308,NULL,'New York, NY 10001',2571,222,NULL,32,3444,0);
INSERT INTO "django_geo_db_location" VALUES(6309,NULL,'New York, NY 10002',2571,222,NULL,32,3445,0);
INSERT INTO "django_geo_db_location" VALUES(6310,NULL,'New York, NY 10003',2571,222,NULL,32,3446,0);
INSERT INTO "django_geo_db_location" VALUES(6311,NULL,'New York, NJ',2572,222,NULL,30,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6312,NULL,'New York, NJ 10004',2572,222,NULL,30,3447,0);
INSERT INTO "django_geo_db_location" VALUES(6313,NULL,'New York, NY 10005',2571,222,NULL,32,3448,0);
INSERT INTO "django_geo_db_location" VALUES(6314,NULL,'New York, NY 10006',2571,222,NULL,32,3449,0);
INSERT INTO "django_geo_db_location" VALUES(6315,NULL,'New York, NY 10007',2571,222,NULL,32,3450,0);
INSERT INTO "django_geo_db_location" VALUES(6316,NULL,'New York, NY 10008',2571,222,NULL,32,3451,0);
INSERT INTO "django_geo_db_location" VALUES(6317,NULL,'New York, NY 10009',2571,222,NULL,32,3452,0);
INSERT INTO "django_geo_db_location" VALUES(6318,NULL,'New York, NY 10010',2571,222,NULL,32,3453,0);
INSERT INTO "django_geo_db_location" VALUES(6319,NULL,'New York, NY 10011',2571,222,NULL,32,3454,0);
INSERT INTO "django_geo_db_location" VALUES(6320,NULL,'New York, NY 10012',2571,222,NULL,32,3455,0);
INSERT INTO "django_geo_db_location" VALUES(6321,NULL,'New York, NY 10013',2571,222,NULL,32,3456,0);
INSERT INTO "django_geo_db_location" VALUES(6322,NULL,'New York, NY 10014',2571,222,NULL,32,3457,0);
INSERT INTO "django_geo_db_location" VALUES(6323,NULL,'New York, NY 10015',2571,222,NULL,32,3458,0);
INSERT INTO "django_geo_db_location" VALUES(6324,NULL,'New York, NY 10016',2571,222,NULL,32,3459,0);
INSERT INTO "django_geo_db_location" VALUES(6325,NULL,'New York, NY 10017',2571,222,NULL,32,3460,0);
INSERT INTO "django_geo_db_location" VALUES(6326,NULL,'New York, NY 10018',2571,222,NULL,32,3461,0);
INSERT INTO "django_geo_db_location" VALUES(6327,NULL,'New York, NY 10019',2571,222,NULL,32,3462,0);
INSERT INTO "django_geo_db_location" VALUES(6328,NULL,'New York, NY 10020',2571,222,NULL,32,3463,0);
INSERT INTO "django_geo_db_location" VALUES(6329,NULL,'New York, NY 10021',2571,222,NULL,32,3464,0);
INSERT INTO "django_geo_db_location" VALUES(6330,NULL,'New York, NY 10022',2571,222,NULL,32,3465,0);
INSERT INTO "django_geo_db_location" VALUES(6331,NULL,'New York, NY 10023',2571,222,NULL,32,3466,0);
INSERT INTO "django_geo_db_location" VALUES(6332,NULL,'New York, NY 10024',2571,222,NULL,32,3467,0);
INSERT INTO "django_geo_db_location" VALUES(6333,NULL,'New York, NY 10025',2571,222,NULL,32,3468,0);
INSERT INTO "django_geo_db_location" VALUES(6334,NULL,'New York, NY 10026',2571,222,NULL,32,3469,0);
INSERT INTO "django_geo_db_location" VALUES(6335,NULL,'New York, NY 10027',2571,222,NULL,32,3470,0);
INSERT INTO "django_geo_db_location" VALUES(6336,NULL,'New York, NY 10028',2571,222,NULL,32,3471,0);
INSERT INTO "django_geo_db_location" VALUES(6337,NULL,'New York, NY 10029',2571,222,NULL,32,3472,0);
INSERT INTO "django_geo_db_location" VALUES(6338,NULL,'New York, NY 10030',2571,222,NULL,32,3473,0);
INSERT INTO "django_geo_db_location" VALUES(6339,NULL,'New York, NY 10031',2571,222,NULL,32,3474,0);
INSERT INTO "django_geo_db_location" VALUES(6340,NULL,'New York, NY 10032',2571,222,NULL,32,3475,0);
INSERT INTO "django_geo_db_location" VALUES(6341,NULL,'New York, NY 10033',2571,222,NULL,32,3476,0);
INSERT INTO "django_geo_db_location" VALUES(6342,NULL,'New York, NY 10034',2571,222,NULL,32,3477,0);
INSERT INTO "django_geo_db_location" VALUES(6343,NULL,'New York, NY 10035',2571,222,NULL,32,3478,0);
INSERT INTO "django_geo_db_location" VALUES(6344,NULL,'New York, NY 10036',2571,222,NULL,32,3479,0);
INSERT INTO "django_geo_db_location" VALUES(6345,NULL,'New York, NY 10037',2571,222,NULL,32,3480,0);
INSERT INTO "django_geo_db_location" VALUES(6346,NULL,'New York, NY 10038',2571,222,NULL,32,3481,0);
INSERT INTO "django_geo_db_location" VALUES(6347,NULL,'New York, NY 10039',2571,222,NULL,32,3482,0);
INSERT INTO "django_geo_db_location" VALUES(6348,NULL,'New York, NY 10040',2571,222,NULL,32,3483,0);
INSERT INTO "django_geo_db_location" VALUES(6349,NULL,'New York, NY 10041',2571,222,NULL,32,3484,0);
INSERT INTO "django_geo_db_location" VALUES(6350,NULL,'New York, NY 10043',2571,222,NULL,32,3485,0);
INSERT INTO "django_geo_db_location" VALUES(6351,NULL,'New York, NY 10044',2571,222,NULL,32,3486,0);
INSERT INTO "django_geo_db_location" VALUES(6352,NULL,'New York, NY 10045',2571,222,NULL,32,3487,0);
INSERT INTO "django_geo_db_location" VALUES(6353,NULL,'New York, NY 10046',2571,222,NULL,32,3488,0);
INSERT INTO "django_geo_db_location" VALUES(6354,NULL,'New York, NY 10047',2571,222,NULL,32,3489,0);
INSERT INTO "django_geo_db_location" VALUES(6355,NULL,'New York, NY 10048',2571,222,NULL,32,3490,0);
INSERT INTO "django_geo_db_location" VALUES(6356,NULL,'New York, NY 10055',2571,222,NULL,32,3491,0);
INSERT INTO "django_geo_db_location" VALUES(6357,NULL,'New York, NY 10060',2571,222,NULL,32,3492,0);
INSERT INTO "django_geo_db_location" VALUES(6358,NULL,'New York, NY 10069',2571,222,NULL,32,3493,0);
INSERT INTO "django_geo_db_location" VALUES(6359,NULL,'New York, NY 10072',2571,222,NULL,32,3494,0);
INSERT INTO "django_geo_db_location" VALUES(6360,NULL,'New York, NY 10079',2571,222,NULL,32,3495,0);
INSERT INTO "django_geo_db_location" VALUES(6361,NULL,'New York, NY 10080',2571,222,NULL,32,3496,0);
INSERT INTO "django_geo_db_location" VALUES(6362,NULL,'New York, NY 10081',2571,222,NULL,32,3497,0);
INSERT INTO "django_geo_db_location" VALUES(6363,NULL,'New York, NY 10082',2571,222,NULL,32,3498,0);
INSERT INTO "django_geo_db_location" VALUES(6364,NULL,'New York, NY 10087',2571,222,NULL,32,3499,0);
INSERT INTO "django_geo_db_location" VALUES(6365,NULL,'New York, NY 10090',2571,222,NULL,32,3500,0);
INSERT INTO "django_geo_db_location" VALUES(6366,NULL,'New York, NY 10094',2571,222,NULL,32,3501,0);
INSERT INTO "django_geo_db_location" VALUES(6367,NULL,'New York, NY 10095',2571,222,NULL,32,3502,0);
INSERT INTO "django_geo_db_location" VALUES(6368,NULL,'New York, NY 10096',2571,222,NULL,32,3503,0);
INSERT INTO "django_geo_db_location" VALUES(6369,NULL,'New York, NY 10098',2571,222,NULL,32,3504,0);
INSERT INTO "django_geo_db_location" VALUES(6370,NULL,'New York, NY 10099',2571,222,NULL,32,3505,0);
INSERT INTO "django_geo_db_location" VALUES(6371,NULL,'New York, NY 10101',2571,222,NULL,32,3506,0);
INSERT INTO "django_geo_db_location" VALUES(6372,NULL,'New York, NY 10102',2571,222,NULL,32,3507,0);
INSERT INTO "django_geo_db_location" VALUES(6373,NULL,'New York, NY 10103',2571,222,NULL,32,3508,0);
INSERT INTO "django_geo_db_location" VALUES(6374,NULL,'New York, NY 10104',2571,222,NULL,32,3509,0);
INSERT INTO "django_geo_db_location" VALUES(6375,NULL,'New York, NY 10105',2571,222,NULL,32,3510,0);
INSERT INTO "django_geo_db_location" VALUES(6376,NULL,'New York, NY 10106',2571,222,NULL,32,3511,0);
INSERT INTO "django_geo_db_location" VALUES(6377,NULL,'New York, NY 10107',2571,222,NULL,32,3512,0);
INSERT INTO "django_geo_db_location" VALUES(6378,NULL,'New York, NY 10108',2571,222,NULL,32,3513,0);
INSERT INTO "django_geo_db_location" VALUES(6379,NULL,'New York, NY 10109',2571,222,NULL,32,3514,0);
INSERT INTO "django_geo_db_location" VALUES(6380,NULL,'New York, NY 10110',2571,222,NULL,32,3515,0);
INSERT INTO "django_geo_db_location" VALUES(6381,NULL,'New York, NY 10111',2571,222,NULL,32,3516,0);
INSERT INTO "django_geo_db_location" VALUES(6382,NULL,'New York, NY 10112',2571,222,NULL,32,3517,0);
INSERT INTO "django_geo_db_location" VALUES(6383,NULL,'New York, NY 10113',2571,222,NULL,32,3518,0);
INSERT INTO "django_geo_db_location" VALUES(6384,NULL,'New York, NY 10114',2571,222,NULL,32,3519,0);
INSERT INTO "django_geo_db_location" VALUES(6385,NULL,'New York, NY 10115',2571,222,NULL,32,3520,0);
INSERT INTO "django_geo_db_location" VALUES(6386,NULL,'New York, NY 10116',2571,222,NULL,32,3521,0);
INSERT INTO "django_geo_db_location" VALUES(6387,NULL,'New York, NY 10117',2571,222,NULL,32,3522,0);
INSERT INTO "django_geo_db_location" VALUES(6388,NULL,'New York, NY 10118',2571,222,NULL,32,3523,0);
INSERT INTO "django_geo_db_location" VALUES(6389,NULL,'New York, NY 10119',2571,222,NULL,32,3524,0);
INSERT INTO "django_geo_db_location" VALUES(6390,NULL,'New York, NY 10120',2571,222,NULL,32,3525,0);
INSERT INTO "django_geo_db_location" VALUES(6391,NULL,'New York, NY 10121',2571,222,NULL,32,3526,0);
INSERT INTO "django_geo_db_location" VALUES(6392,NULL,'New York, NY 10122',2571,222,NULL,32,3527,0);
INSERT INTO "django_geo_db_location" VALUES(6393,NULL,'New York, NY 10123',2571,222,NULL,32,3528,0);
INSERT INTO "django_geo_db_location" VALUES(6394,NULL,'New York, NY 10124',2571,222,NULL,32,3529,0);
INSERT INTO "django_geo_db_location" VALUES(6395,NULL,'New York, NY 10125',2571,222,NULL,32,3530,0);
INSERT INTO "django_geo_db_location" VALUES(6396,NULL,'New York, NY 10126',2571,222,NULL,32,3531,0);
INSERT INTO "django_geo_db_location" VALUES(6397,NULL,'New York, NY 10128',2571,222,NULL,32,3532,0);
INSERT INTO "django_geo_db_location" VALUES(6398,NULL,'New York, NY 10129',2571,222,NULL,32,3533,0);
INSERT INTO "django_geo_db_location" VALUES(6399,NULL,'New York, NY 10130',2571,222,NULL,32,3534,0);
INSERT INTO "django_geo_db_location" VALUES(6400,NULL,'New York, NY 10131',2571,222,NULL,32,3535,0);
INSERT INTO "django_geo_db_location" VALUES(6401,NULL,'New York, NY 10132',2571,222,NULL,32,3536,0);
INSERT INTO "django_geo_db_location" VALUES(6402,NULL,'New York, NY 10133',2571,222,NULL,32,3537,0);
INSERT INTO "django_geo_db_location" VALUES(6403,NULL,'New York, NY 10138',2571,222,NULL,32,3538,0);
INSERT INTO "django_geo_db_location" VALUES(6404,NULL,'New York, NY 10149',2571,222,NULL,32,3539,0);
INSERT INTO "django_geo_db_location" VALUES(6405,NULL,'New York, NY 10150',2571,222,NULL,32,3540,0);
INSERT INTO "django_geo_db_location" VALUES(6406,NULL,'New York, NY 10151',2571,222,NULL,32,3541,0);
INSERT INTO "django_geo_db_location" VALUES(6407,NULL,'New York, NY 10152',2571,222,NULL,32,3542,0);
INSERT INTO "django_geo_db_location" VALUES(6408,NULL,'New York, NY 10153',2571,222,NULL,32,3543,0);
INSERT INTO "django_geo_db_location" VALUES(6409,NULL,'New York, NY 10154',2571,222,NULL,32,3544,0);
INSERT INTO "django_geo_db_location" VALUES(6410,NULL,'New York, NY 10155',2571,222,NULL,32,3545,0);
INSERT INTO "django_geo_db_location" VALUES(6411,NULL,'New York, NY 10156',2571,222,NULL,32,3546,0);
INSERT INTO "django_geo_db_location" VALUES(6412,NULL,'New York, NY 10157',2571,222,NULL,32,3547,0);
INSERT INTO "django_geo_db_location" VALUES(6413,NULL,'New York, NY 10158',2571,222,NULL,32,3548,0);
INSERT INTO "django_geo_db_location" VALUES(6414,NULL,'New York, NY 10159',2571,222,NULL,32,3549,0);
INSERT INTO "django_geo_db_location" VALUES(6415,NULL,'New York, NY 10160',2571,222,NULL,32,3550,0);
INSERT INTO "django_geo_db_location" VALUES(6416,NULL,'New York, NY 10161',2571,222,NULL,32,3551,0);
INSERT INTO "django_geo_db_location" VALUES(6417,NULL,'New York, NY 10162',2571,222,NULL,32,3552,0);
INSERT INTO "django_geo_db_location" VALUES(6418,NULL,'New York, NY 10163',2571,222,NULL,32,3553,0);
INSERT INTO "django_geo_db_location" VALUES(6419,NULL,'New York, NY 10164',2571,222,NULL,32,3554,0);
INSERT INTO "django_geo_db_location" VALUES(6420,NULL,'New York, NY 10165',2571,222,NULL,32,3555,0);
INSERT INTO "django_geo_db_location" VALUES(6421,NULL,'New York, NY 10166',2571,222,NULL,32,3556,0);
INSERT INTO "django_geo_db_location" VALUES(6422,NULL,'New York, NY 10167',2571,222,NULL,32,3557,0);
INSERT INTO "django_geo_db_location" VALUES(6423,NULL,'New York, NY 10168',2571,222,NULL,32,3558,0);
INSERT INTO "django_geo_db_location" VALUES(6424,NULL,'New York, NY 10169',2571,222,NULL,32,3559,0);
INSERT INTO "django_geo_db_location" VALUES(6425,NULL,'New York, NY 10170',2571,222,NULL,32,3560,0);
INSERT INTO "django_geo_db_location" VALUES(6426,NULL,'New York, NY 10171',2571,222,NULL,32,3561,0);
INSERT INTO "django_geo_db_location" VALUES(6427,NULL,'New York, NY 10172',2571,222,NULL,32,3562,0);
INSERT INTO "django_geo_db_location" VALUES(6428,NULL,'New York, NY 10173',2571,222,NULL,32,3563,0);
INSERT INTO "django_geo_db_location" VALUES(6429,NULL,'New York, NY 10174',2571,222,NULL,32,3564,0);
INSERT INTO "django_geo_db_location" VALUES(6430,NULL,'New York, NY 10175',2571,222,NULL,32,3565,0);
INSERT INTO "django_geo_db_location" VALUES(6431,NULL,'New York, NY 10176',2571,222,NULL,32,3566,0);
INSERT INTO "django_geo_db_location" VALUES(6432,NULL,'New York, NY 10177',2571,222,NULL,32,3567,0);
INSERT INTO "django_geo_db_location" VALUES(6433,NULL,'New York, NY 10178',2571,222,NULL,32,3568,0);
INSERT INTO "django_geo_db_location" VALUES(6434,NULL,'New York, NY 10179',2571,222,NULL,32,3569,0);
INSERT INTO "django_geo_db_location" VALUES(6435,NULL,'New York, NY 10184',2571,222,NULL,32,3570,0);
INSERT INTO "django_geo_db_location" VALUES(6436,NULL,'New York, NY 10185',2571,222,NULL,32,3571,0);
INSERT INTO "django_geo_db_location" VALUES(6437,NULL,'New York, NY 10196',2571,222,NULL,32,3572,0);
INSERT INTO "django_geo_db_location" VALUES(6438,NULL,'New York, NY 10197',2571,222,NULL,32,3573,0);
INSERT INTO "django_geo_db_location" VALUES(6439,NULL,'New York, NY 10199',2571,222,NULL,32,3574,0);
INSERT INTO "django_geo_db_location" VALUES(6440,NULL,'New York, NY 10203',2571,222,NULL,32,3575,0);
INSERT INTO "django_geo_db_location" VALUES(6441,NULL,'New York, NY 10211',2571,222,NULL,32,3576,0);
INSERT INTO "django_geo_db_location" VALUES(6442,NULL,'New York, NY 10212',2571,222,NULL,32,3577,0);
INSERT INTO "django_geo_db_location" VALUES(6443,NULL,'New York, NY 10213',2571,222,NULL,32,3578,0);
INSERT INTO "django_geo_db_location" VALUES(6444,NULL,'New York, NY 10242',2571,222,NULL,32,3579,0);
INSERT INTO "django_geo_db_location" VALUES(6445,NULL,'New York, NY 10249',2571,222,NULL,32,3580,0);
INSERT INTO "django_geo_db_location" VALUES(6446,NULL,'New York, NY 10250',2571,222,NULL,32,3581,0);
INSERT INTO "django_geo_db_location" VALUES(6447,NULL,'New York, NY 10256',2571,222,NULL,32,3582,0);
INSERT INTO "django_geo_db_location" VALUES(6448,NULL,'New York, NY 10257',2571,222,NULL,32,3583,0);
INSERT INTO "django_geo_db_location" VALUES(6449,NULL,'New York, NY 10258',2571,222,NULL,32,3584,0);
INSERT INTO "django_geo_db_location" VALUES(6450,NULL,'New York, NY 10259',2571,222,NULL,32,3585,0);
INSERT INTO "django_geo_db_location" VALUES(6451,NULL,'New York, NY 10260',2571,222,NULL,32,3586,0);
INSERT INTO "django_geo_db_location" VALUES(6452,NULL,'New York, NY 10261',2571,222,NULL,32,3587,0);
INSERT INTO "django_geo_db_location" VALUES(6453,NULL,'New York, NY 10265',2571,222,NULL,32,3588,0);
INSERT INTO "django_geo_db_location" VALUES(6454,NULL,'New York, NY 10268',2571,222,NULL,32,3589,0);
INSERT INTO "django_geo_db_location" VALUES(6455,NULL,'New York, NY 10269',2571,222,NULL,32,3590,0);
INSERT INTO "django_geo_db_location" VALUES(6456,NULL,'New York, NY 10270',2571,222,NULL,32,3591,0);
INSERT INTO "django_geo_db_location" VALUES(6457,NULL,'New York, NY 10271',2571,222,NULL,32,3592,0);
INSERT INTO "django_geo_db_location" VALUES(6458,NULL,'New York, NY 10272',2571,222,NULL,32,3593,0);
INSERT INTO "django_geo_db_location" VALUES(6459,NULL,'New York, NY 10273',2571,222,NULL,32,3594,0);
INSERT INTO "django_geo_db_location" VALUES(6460,NULL,'New York, NY 10274',2571,222,NULL,32,3595,0);
INSERT INTO "django_geo_db_location" VALUES(6461,NULL,'New York, NY 10275',2571,222,NULL,32,3596,0);
INSERT INTO "django_geo_db_location" VALUES(6462,NULL,'New York, NY 10276',2571,222,NULL,32,3597,0);
INSERT INTO "django_geo_db_location" VALUES(6463,NULL,'New York, NY 10277',2571,222,NULL,32,3598,0);
INSERT INTO "django_geo_db_location" VALUES(6464,NULL,'New York, NY 10278',2571,222,NULL,32,3599,0);
INSERT INTO "django_geo_db_location" VALUES(6465,NULL,'New York, NY 10279',2571,222,NULL,32,3600,0);
INSERT INTO "django_geo_db_location" VALUES(6466,NULL,'New York, NY 10280',2571,222,NULL,32,3601,0);
INSERT INTO "django_geo_db_location" VALUES(6467,NULL,'New York, NY 10281',2571,222,NULL,32,3602,0);
INSERT INTO "django_geo_db_location" VALUES(6468,NULL,'New York, NY 10282',2571,222,NULL,32,3603,0);
INSERT INTO "django_geo_db_location" VALUES(6469,NULL,'New York, NY 10285',2571,222,NULL,32,3604,0);
INSERT INTO "django_geo_db_location" VALUES(6470,NULL,'New York, NY 10286',2571,222,NULL,32,3605,0);
INSERT INTO "django_geo_db_location" VALUES(6471,NULL,'New York, NY 10292',2571,222,NULL,32,3606,0);
INSERT INTO "django_geo_db_location" VALUES(6472,NULL,'Staten Island, NY',2573,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6473,NULL,'Staten Island, NY 10301',2573,222,NULL,32,3607,0);
INSERT INTO "django_geo_db_location" VALUES(6474,NULL,'Staten Island, NY 10302',2573,222,NULL,32,3608,0);
INSERT INTO "django_geo_db_location" VALUES(6475,NULL,'Staten Island, NY 10303',2573,222,NULL,32,3609,0);
INSERT INTO "django_geo_db_location" VALUES(6476,NULL,'Staten Island, NY 10304',2573,222,NULL,32,3610,0);
INSERT INTO "django_geo_db_location" VALUES(6477,NULL,'Staten Island, NY 10305',2573,222,NULL,32,3611,0);
INSERT INTO "django_geo_db_location" VALUES(6478,NULL,'Staten Island, NY 10306',2573,222,NULL,32,3612,0);
INSERT INTO "django_geo_db_location" VALUES(6479,NULL,'Staten Island, NY 10307',2573,222,NULL,32,3613,0);
INSERT INTO "django_geo_db_location" VALUES(6480,NULL,'Staten Island, NY 10308',2573,222,NULL,32,3614,0);
INSERT INTO "django_geo_db_location" VALUES(6481,NULL,'Staten Island, NY 10309',2573,222,NULL,32,3615,0);
INSERT INTO "django_geo_db_location" VALUES(6482,NULL,'Staten Island, NY 10310',2573,222,NULL,32,3616,0);
INSERT INTO "django_geo_db_location" VALUES(6483,NULL,'Staten Island, NY 10311',2573,222,NULL,32,3617,0);
INSERT INTO "django_geo_db_location" VALUES(6484,NULL,'Staten Island, NY 10312',2573,222,NULL,32,3618,0);
INSERT INTO "django_geo_db_location" VALUES(6485,NULL,'Staten Island, NY 10313',2573,222,NULL,32,3619,0);
INSERT INTO "django_geo_db_location" VALUES(6486,NULL,'Staten Island, NY 10314',2573,222,NULL,32,3620,0);
INSERT INTO "django_geo_db_location" VALUES(6487,NULL,'New York, NY 10422',2571,222,NULL,32,3621,0);
INSERT INTO "django_geo_db_location" VALUES(6488,NULL,'Bronx, NY',2574,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6489,NULL,'Bronx, NY 10451',2574,222,NULL,32,3622,0);
INSERT INTO "django_geo_db_location" VALUES(6490,NULL,'Bronx, NY 10452',2574,222,NULL,32,3623,0);
INSERT INTO "django_geo_db_location" VALUES(6491,NULL,'Bronx, NY 10453',2574,222,NULL,32,3624,0);
INSERT INTO "django_geo_db_location" VALUES(6492,NULL,'Bronx, NY 10454',2574,222,NULL,32,3625,0);
INSERT INTO "django_geo_db_location" VALUES(6493,NULL,'Bronx, NY 10455',2574,222,NULL,32,3626,0);
INSERT INTO "django_geo_db_location" VALUES(6494,NULL,'Bronx, NY 10456',2574,222,NULL,32,3627,0);
INSERT INTO "django_geo_db_location" VALUES(6495,NULL,'Bronx, NY 10457',2574,222,NULL,32,3628,0);
INSERT INTO "django_geo_db_location" VALUES(6496,NULL,'Bronx, NY 10458',2574,222,NULL,32,3629,0);
INSERT INTO "django_geo_db_location" VALUES(6497,NULL,'Bronx, NY 10459',2574,222,NULL,32,3630,0);
INSERT INTO "django_geo_db_location" VALUES(6498,NULL,'Bronx, NY 10460',2574,222,NULL,32,3631,0);
INSERT INTO "django_geo_db_location" VALUES(6499,NULL,'Bronx, NY 10461',2574,222,NULL,32,3632,0);
INSERT INTO "django_geo_db_location" VALUES(6500,NULL,'Bronx, NY 10462',2574,222,NULL,32,3633,0);
INSERT INTO "django_geo_db_location" VALUES(6501,NULL,'Bronx, NY 10463',2574,222,NULL,32,3634,0);
INSERT INTO "django_geo_db_location" VALUES(6502,NULL,'Bronx, NY 10464',2574,222,NULL,32,3635,0);
INSERT INTO "django_geo_db_location" VALUES(6503,NULL,'Bronx, NY 10465',2574,222,NULL,32,3636,0);
INSERT INTO "django_geo_db_location" VALUES(6504,NULL,'Bronx, NY 10466',2574,222,NULL,32,3637,0);
INSERT INTO "django_geo_db_location" VALUES(6505,NULL,'Bronx, NY 10467',2574,222,NULL,32,3638,0);
INSERT INTO "django_geo_db_location" VALUES(6506,NULL,'Bronx, NY 10468',2574,222,NULL,32,3639,0);
INSERT INTO "django_geo_db_location" VALUES(6507,NULL,'Bronx, NY 10469',2574,222,NULL,32,3640,0);
INSERT INTO "django_geo_db_location" VALUES(6508,NULL,'Bronx, NY 10470',2574,222,NULL,32,3641,0);
INSERT INTO "django_geo_db_location" VALUES(6509,NULL,'Bronx, NY 10471',2574,222,NULL,32,3642,0);
INSERT INTO "django_geo_db_location" VALUES(6510,NULL,'Bronx, NY 10472',2574,222,NULL,32,3643,0);
INSERT INTO "django_geo_db_location" VALUES(6511,NULL,'Bronx, NY 10473',2574,222,NULL,32,3644,0);
INSERT INTO "django_geo_db_location" VALUES(6512,NULL,'Bronx, NY 10474',2574,222,NULL,32,3645,0);
INSERT INTO "django_geo_db_location" VALUES(6513,NULL,'Bronx, NY 10475',2574,222,NULL,32,3646,0);
INSERT INTO "django_geo_db_location" VALUES(6514,NULL,'Bronx, NY 10499',2574,222,NULL,32,3647,0);
INSERT INTO "django_geo_db_location" VALUES(6515,NULL,'Amawalk, NY',2575,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6516,NULL,'Amawalk, NY 10501',2575,222,NULL,32,3648,0);
INSERT INTO "django_geo_db_location" VALUES(6517,NULL,'Ardsley, NY',2576,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6518,NULL,'Ardsley, NY 10502',2576,222,NULL,32,3649,0);
INSERT INTO "django_geo_db_location" VALUES(6519,NULL,'Ardsley On Hudson, NY',2577,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6520,NULL,'Ardsley On Hudson, NY 10503',2577,222,NULL,32,3650,0);
INSERT INTO "django_geo_db_location" VALUES(6521,NULL,'Armonk, NY',2578,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6522,NULL,'Armonk, NY 10504',2578,222,NULL,32,3651,0);
INSERT INTO "django_geo_db_location" VALUES(6523,NULL,'Baldwin Place, NY',2579,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6524,NULL,'Baldwin Place, NY 10505',2579,222,NULL,32,3652,0);
INSERT INTO "django_geo_db_location" VALUES(6525,NULL,'Bedford, NY',2580,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6526,NULL,'Bedford, NY 10506',2580,222,NULL,32,3653,0);
INSERT INTO "django_geo_db_location" VALUES(6527,NULL,'Bedford Hills, NY',2581,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6528,NULL,'Bedford Hills, NY 10507',2581,222,NULL,32,3654,0);
INSERT INTO "django_geo_db_location" VALUES(6529,NULL,'Brewster, NY',2582,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6530,NULL,'Brewster, NY 10509',2582,222,NULL,32,3655,0);
INSERT INTO "django_geo_db_location" VALUES(6531,NULL,'Briarcliff Manor, NY',2583,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6532,NULL,'Briarcliff Manor, NY 10510',2583,222,NULL,32,3656,0);
INSERT INTO "django_geo_db_location" VALUES(6533,NULL,'Buchanan, NY',2584,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6534,NULL,'Buchanan, NY 10511',2584,222,NULL,32,3657,0);
INSERT INTO "django_geo_db_location" VALUES(6535,NULL,'Carmel, NY',2585,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6536,NULL,'Carmel, NY 10512',2585,222,NULL,32,3658,0);
INSERT INTO "django_geo_db_location" VALUES(6537,NULL,'Chappaqua, NY',2586,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6538,NULL,'Chappaqua, NY 10514',2586,222,NULL,32,3659,0);
INSERT INTO "django_geo_db_location" VALUES(6539,NULL,'Cold Spring, NY',2587,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6540,NULL,'Cold Spring, NY 10516',2587,222,NULL,32,3660,0);
INSERT INTO "django_geo_db_location" VALUES(6541,NULL,'Crompond, NY',2588,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6542,NULL,'Crompond, NY 10517',2588,222,NULL,32,3661,0);
INSERT INTO "django_geo_db_location" VALUES(6543,NULL,'Cross River, NY',2589,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6544,NULL,'Cross River, NY 10518',2589,222,NULL,32,3662,0);
INSERT INTO "django_geo_db_location" VALUES(6545,NULL,'Croton Falls, NY',2590,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6546,NULL,'Croton Falls, NY 10519',2590,222,NULL,32,3663,0);
INSERT INTO "django_geo_db_location" VALUES(6547,NULL,'Croton On Hudson, NY',2591,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6548,NULL,'Croton On Hudson, NY 10520',2591,222,NULL,32,3664,0);
INSERT INTO "django_geo_db_location" VALUES(6549,NULL,'Croton On Hudson, NY 10521',2591,222,NULL,32,3665,0);
INSERT INTO "django_geo_db_location" VALUES(6550,NULL,'Dobbs Ferry, NY',2592,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6551,NULL,'Dobbs Ferry, NY 10522',2592,222,NULL,32,3666,0);
INSERT INTO "django_geo_db_location" VALUES(6552,NULL,'Elmsford, NY',2593,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6553,NULL,'Elmsford, NY 10523',2593,222,NULL,32,3667,0);
INSERT INTO "django_geo_db_location" VALUES(6554,NULL,'Garrison, NY',2594,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6555,NULL,'Garrison, NY 10524',2594,222,NULL,32,3668,0);
INSERT INTO "django_geo_db_location" VALUES(6556,NULL,'Goldens Bridge, NY',2595,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6557,NULL,'Goldens Bridge, NY 10526',2595,222,NULL,32,3669,0);
INSERT INTO "django_geo_db_location" VALUES(6558,NULL,'Granite Springs, NY',2596,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6559,NULL,'Granite Springs, NY 10527',2596,222,NULL,32,3670,0);
INSERT INTO "django_geo_db_location" VALUES(6560,NULL,'Harrison, NY',2597,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6561,NULL,'Harrison, NY 10528',2597,222,NULL,32,3671,0);
INSERT INTO "django_geo_db_location" VALUES(6562,NULL,'Hartsdale, NY',2598,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6563,NULL,'Hartsdale, NY 10530',2598,222,NULL,32,3672,0);
INSERT INTO "django_geo_db_location" VALUES(6564,NULL,'Hawthorne, NY',2599,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6565,NULL,'Hawthorne, NY 10532',2599,222,NULL,32,3673,0);
INSERT INTO "django_geo_db_location" VALUES(6566,NULL,'Irvington, NY',2600,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6567,NULL,'Irvington, NY 10533',2600,222,NULL,32,3674,0);
INSERT INTO "django_geo_db_location" VALUES(6568,NULL,'Jefferson Valley, NY',2601,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6569,NULL,'Jefferson Valley, NY 10535',2601,222,NULL,32,3675,0);
INSERT INTO "django_geo_db_location" VALUES(6570,NULL,'Katonah, NY',2602,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6571,NULL,'Katonah, NY 10536',2602,222,NULL,32,3676,0);
INSERT INTO "django_geo_db_location" VALUES(6572,NULL,'Lake Peekskill, NY',2603,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6573,NULL,'Lake Peekskill, NY 10537',2603,222,NULL,32,3677,0);
INSERT INTO "django_geo_db_location" VALUES(6574,NULL,'Larchmont, NY',2604,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6575,NULL,'Larchmont, NY 10538',2604,222,NULL,32,3678,0);
INSERT INTO "django_geo_db_location" VALUES(6576,NULL,'Lincolndale, NY',2605,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6577,NULL,'Lincolndale, NY 10540',2605,222,NULL,32,3679,0);
INSERT INTO "django_geo_db_location" VALUES(6578,NULL,'Mahopac, NY',2606,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6579,NULL,'Mahopac, NY 10541',2606,222,NULL,32,3680,0);
INSERT INTO "django_geo_db_location" VALUES(6580,NULL,'Mahopac Falls, NY',2607,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6581,NULL,'Mahopac Falls, NY 10542',2607,222,NULL,32,3681,0);
INSERT INTO "django_geo_db_location" VALUES(6582,NULL,'Mamaroneck, NY',2608,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6583,NULL,'Mamaroneck, NY 10543',2608,222,NULL,32,3682,0);
INSERT INTO "django_geo_db_location" VALUES(6584,NULL,'Maryknoll, NY',2609,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6585,NULL,'Maryknoll, NY 10545',2609,222,NULL,32,3683,0);
INSERT INTO "django_geo_db_location" VALUES(6586,NULL,'Millwood, NY',2610,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6587,NULL,'Millwood, NY 10546',2610,222,NULL,32,3684,0);
INSERT INTO "django_geo_db_location" VALUES(6588,NULL,'Mohegan Lake, NY',2611,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6589,NULL,'Mohegan Lake, NY 10547',2611,222,NULL,32,3685,0);
INSERT INTO "django_geo_db_location" VALUES(6590,NULL,'Montrose, NY',2612,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6591,NULL,'Montrose, NY 10548',2612,222,NULL,32,3686,0);
INSERT INTO "django_geo_db_location" VALUES(6592,NULL,'Mount Kisco, NY',2613,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6593,NULL,'Mount Kisco, NY 10549',2613,222,NULL,32,3687,0);
INSERT INTO "django_geo_db_location" VALUES(6594,NULL,'Mount Vernon, NY',2614,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6595,NULL,'Mount Vernon, NY 10550',2614,222,NULL,32,3688,0);
INSERT INTO "django_geo_db_location" VALUES(6596,NULL,'Mount Vernon, NY 10551',2614,222,NULL,32,3689,0);
INSERT INTO "django_geo_db_location" VALUES(6597,NULL,'Mount Vernon, NY 10552',2614,222,NULL,32,3690,0);
INSERT INTO "django_geo_db_location" VALUES(6598,NULL,'Mount Vernon, NY 10553',2614,222,NULL,32,3691,0);
INSERT INTO "django_geo_db_location" VALUES(6599,NULL,'Mount Vernon, NY 10557',2614,222,NULL,32,3692,0);
INSERT INTO "django_geo_db_location" VALUES(6600,NULL,'Mount Vernon, NY 10558',2614,222,NULL,32,3693,0);
INSERT INTO "django_geo_db_location" VALUES(6601,NULL,'Mount Vernon, NY 10559',2614,222,NULL,32,3694,0);
INSERT INTO "django_geo_db_location" VALUES(6602,NULL,'North Salem, NY',2615,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6603,NULL,'North Salem, NY 10560',2615,222,NULL,32,3695,0);
INSERT INTO "django_geo_db_location" VALUES(6604,NULL,'Ossining, NY',2616,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6605,NULL,'Ossining, NY 10562',2616,222,NULL,32,3696,0);
INSERT INTO "django_geo_db_location" VALUES(6606,NULL,'Peekskill, NY',2617,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6607,NULL,'Peekskill, NY 10566',2617,222,NULL,32,3697,0);
INSERT INTO "django_geo_db_location" VALUES(6608,NULL,'Cortlandt Manor, NY',2618,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6609,NULL,'Cortlandt Manor, NY 10567',2618,222,NULL,32,3698,0);
INSERT INTO "django_geo_db_location" VALUES(6610,NULL,'Pleasantville, NY',2619,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6611,NULL,'Pleasantville, NY 10570',2619,222,NULL,32,3699,0);
INSERT INTO "django_geo_db_location" VALUES(6612,NULL,'Pleasantville, NY 10571',2619,222,NULL,32,3700,0);
INSERT INTO "django_geo_db_location" VALUES(6613,NULL,'Pleasantville, NY 10572',2619,222,NULL,32,3701,0);
INSERT INTO "django_geo_db_location" VALUES(6614,NULL,'Port Chester, NY',2620,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6615,NULL,'Port Chester, NY 10573',2620,222,NULL,32,3702,0);
INSERT INTO "django_geo_db_location" VALUES(6616,NULL,'Pound Ridge, NY',2621,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6617,NULL,'Pound Ridge, NY 10576',2621,222,NULL,32,3703,0);
INSERT INTO "django_geo_db_location" VALUES(6618,NULL,'Purchase, NY',2622,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6619,NULL,'Purchase, NY 10577',2622,222,NULL,32,3704,0);
INSERT INTO "django_geo_db_location" VALUES(6620,NULL,'Purdys, NY',2623,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6621,NULL,'Purdys, NY 10578',2623,222,NULL,32,3705,0);
INSERT INTO "django_geo_db_location" VALUES(6622,NULL,'Putnam Valley, NY',2624,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6623,NULL,'Putnam Valley, NY 10579',2624,222,NULL,32,3706,0);
INSERT INTO "django_geo_db_location" VALUES(6624,NULL,'Rye, NY',2625,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6625,NULL,'Rye, NY 10580',2625,222,NULL,32,3707,0);
INSERT INTO "django_geo_db_location" VALUES(6626,NULL,'Rye, NY 10581',2625,222,NULL,32,3708,0);
INSERT INTO "django_geo_db_location" VALUES(6627,NULL,'Scarsdale, NY',2626,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6628,NULL,'Scarsdale, NY 10583',2626,222,NULL,32,3709,0);
INSERT INTO "django_geo_db_location" VALUES(6629,NULL,'Greenville, NY',2627,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6630,NULL,'Greenville, NY 10586',2627,222,NULL,32,3710,0);
INSERT INTO "django_geo_db_location" VALUES(6631,NULL,'Shenorock, NY',2628,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6632,NULL,'Shenorock, NY 10587',2628,222,NULL,32,3711,0);
INSERT INTO "django_geo_db_location" VALUES(6633,NULL,'Shrub Oak, NY',2629,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6634,NULL,'Shrub Oak, NY 10588',2629,222,NULL,32,3712,0);
INSERT INTO "django_geo_db_location" VALUES(6635,NULL,'Somers, NY',2630,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6636,NULL,'Somers, NY 10589',2630,222,NULL,32,3713,0);
INSERT INTO "django_geo_db_location" VALUES(6637,NULL,'South Salem, NY',2631,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6638,NULL,'South Salem, NY 10590',2631,222,NULL,32,3714,0);
INSERT INTO "django_geo_db_location" VALUES(6639,NULL,'Tarrytown, NY',2632,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6640,NULL,'Tarrytown, NY 10591',2632,222,NULL,32,3715,0);
INSERT INTO "django_geo_db_location" VALUES(6641,NULL,'Tarrytown, NY 10592',2632,222,NULL,32,3716,0);
INSERT INTO "django_geo_db_location" VALUES(6642,NULL,'Thornwood, NY',2633,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6643,NULL,'Thornwood, NY 10594',2633,222,NULL,32,3717,0);
INSERT INTO "django_geo_db_location" VALUES(6644,NULL,'Valhalla, NY',2634,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6645,NULL,'Valhalla, NY 10595',2634,222,NULL,32,3718,0);
INSERT INTO "django_geo_db_location" VALUES(6646,NULL,'Verplanck, NY',2635,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6647,NULL,'Verplanck, NY 10596',2635,222,NULL,32,3719,0);
INSERT INTO "django_geo_db_location" VALUES(6648,NULL,'Waccabuc, NY',2636,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6649,NULL,'Waccabuc, NY 10597',2636,222,NULL,32,3720,0);
INSERT INTO "django_geo_db_location" VALUES(6650,NULL,'Yorktown Heights, NY',2637,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6651,NULL,'Yorktown Heights, NY 10598',2637,222,NULL,32,3721,0);
INSERT INTO "django_geo_db_location" VALUES(6652,NULL,'White Plains, NY',2638,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6653,NULL,'White Plains, NY 10601',2638,222,NULL,32,3722,0);
INSERT INTO "django_geo_db_location" VALUES(6654,NULL,'White Plains, NY 10602',2638,222,NULL,32,3723,0);
INSERT INTO "django_geo_db_location" VALUES(6655,NULL,'White Plains, NY 10603',2638,222,NULL,32,3724,0);
INSERT INTO "django_geo_db_location" VALUES(6656,NULL,'West Harrison, NY',2639,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6657,NULL,'West Harrison, NY 10604',2639,222,NULL,32,3725,0);
INSERT INTO "django_geo_db_location" VALUES(6658,NULL,'White Plains, NY 10605',2638,222,NULL,32,3726,0);
INSERT INTO "django_geo_db_location" VALUES(6659,NULL,'White Plains, NY 10606',2638,222,NULL,32,3727,0);
INSERT INTO "django_geo_db_location" VALUES(6660,NULL,'White Plains, NY 10607',2638,222,NULL,32,3728,0);
INSERT INTO "django_geo_db_location" VALUES(6661,NULL,'White Plains, NY 10610',2638,222,NULL,32,3729,0);
INSERT INTO "django_geo_db_location" VALUES(6662,NULL,'White Plains, NY 10625',2638,222,NULL,32,3730,0);
INSERT INTO "django_geo_db_location" VALUES(6663,NULL,'White Plains, NY 10629',2638,222,NULL,32,3731,0);
INSERT INTO "django_geo_db_location" VALUES(6664,NULL,'White Plains, NY 10633',2638,222,NULL,32,3732,0);
INSERT INTO "django_geo_db_location" VALUES(6665,NULL,'White Plains, NY 10650',2638,222,NULL,32,3733,0);
INSERT INTO "django_geo_db_location" VALUES(6666,NULL,'Yonkers, NY',2640,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6667,NULL,'Yonkers, NY 10701',2640,222,NULL,32,3734,0);
INSERT INTO "django_geo_db_location" VALUES(6668,NULL,'Yonkers, NY 10702',2640,222,NULL,32,3735,0);
INSERT INTO "django_geo_db_location" VALUES(6669,NULL,'Yonkers, NY 10703',2640,222,NULL,32,3736,0);
INSERT INTO "django_geo_db_location" VALUES(6670,NULL,'Yonkers, NY 10704',2640,222,NULL,32,3737,0);
INSERT INTO "django_geo_db_location" VALUES(6671,NULL,'Yonkers, NY 10705',2640,222,NULL,32,3738,0);
INSERT INTO "django_geo_db_location" VALUES(6672,NULL,'Hastings On Hudson, NY',2641,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6673,NULL,'Hastings On Hudson, NY 10706',2641,222,NULL,32,3739,0);
INSERT INTO "django_geo_db_location" VALUES(6674,NULL,'Tuckahoe, NY',2642,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6675,NULL,'Tuckahoe, NY 10707',2642,222,NULL,32,3740,0);
INSERT INTO "django_geo_db_location" VALUES(6676,NULL,'Bronxville, NY',2643,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6677,NULL,'Bronxville, NY 10708',2643,222,NULL,32,3741,0);
INSERT INTO "django_geo_db_location" VALUES(6678,NULL,'Eastchester, NY',2644,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6679,NULL,'Eastchester, NY 10709',2644,222,NULL,32,3742,0);
INSERT INTO "django_geo_db_location" VALUES(6680,NULL,'Yonkers, NY 10710',2640,222,NULL,32,3743,0);
INSERT INTO "django_geo_db_location" VALUES(6681,NULL,'Woodbury, NY',2645,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6682,NULL,'Woodbury, NY 10730',2645,222,NULL,32,3744,0);
INSERT INTO "django_geo_db_location" VALUES(6683,NULL,'New Rochelle, NY',2646,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6684,NULL,'New Rochelle, NY 10801',2646,222,NULL,32,3745,0);
INSERT INTO "django_geo_db_location" VALUES(6685,NULL,'New Rochelle, NY 10802',2646,222,NULL,32,3746,0);
INSERT INTO "django_geo_db_location" VALUES(6686,NULL,'Pelham, NY',2647,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6687,NULL,'Pelham, NY 10803',2647,222,NULL,32,3747,0);
INSERT INTO "django_geo_db_location" VALUES(6688,NULL,'Wykagyl, NY',2648,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6689,NULL,'Wykagyl, NY 10804',2648,222,NULL,32,3748,0);
INSERT INTO "django_geo_db_location" VALUES(6690,NULL,'New Rochelle, NY 10805',2646,222,NULL,32,3749,0);
INSERT INTO "django_geo_db_location" VALUES(6691,NULL,'Suffern, NY',2649,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6692,NULL,'Suffern, NY 10901',2649,222,NULL,32,3750,0);
INSERT INTO "django_geo_db_location" VALUES(6693,NULL,'Arden, NY',2650,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6694,NULL,'Arden, NY 10910',2650,222,NULL,32,3751,0);
INSERT INTO "django_geo_db_location" VALUES(6695,NULL,'Bear Mountain, NY',2651,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6696,NULL,'Bear Mountain, NY 10911',2651,222,NULL,32,3752,0);
INSERT INTO "django_geo_db_location" VALUES(6697,NULL,'Bellvale, NY',2652,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6698,NULL,'Bellvale, NY 10912',2652,222,NULL,32,3753,0);
INSERT INTO "django_geo_db_location" VALUES(6699,NULL,'Blauvelt, NY',2653,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6700,NULL,'Blauvelt, NY 10913',2653,222,NULL,32,3754,0);
INSERT INTO "django_geo_db_location" VALUES(6701,NULL,'Blooming Grove, NY',2654,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6702,NULL,'Blooming Grove, NY 10914',2654,222,NULL,32,3755,0);
INSERT INTO "django_geo_db_location" VALUES(6703,NULL,'Bullville, NY',2655,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6704,NULL,'Bullville, NY 10915',2655,222,NULL,32,3756,0);
INSERT INTO "django_geo_db_location" VALUES(6705,NULL,'Campbell Hall, NY',2656,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6706,NULL,'Campbell Hall, NY 10916',2656,222,NULL,32,3757,0);
INSERT INTO "django_geo_db_location" VALUES(6707,NULL,'Central Valley, NY',2657,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6708,NULL,'Central Valley, NY 10917',2657,222,NULL,32,3758,0);
INSERT INTO "django_geo_db_location" VALUES(6709,NULL,'Chester, NY',2658,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6710,NULL,'Chester, NY 10918',2658,222,NULL,32,3759,0);
INSERT INTO "django_geo_db_location" VALUES(6711,NULL,'Circleville, NY',2659,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6712,NULL,'Circleville, NY 10919',2659,222,NULL,32,3760,0);
INSERT INTO "django_geo_db_location" VALUES(6713,NULL,'Congers, NY',2660,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6714,NULL,'Congers, NY 10920',2660,222,NULL,32,3761,0);
INSERT INTO "django_geo_db_location" VALUES(6715,NULL,'Florida, NY',2661,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6716,NULL,'Florida, NY 10921',2661,222,NULL,32,3762,0);
INSERT INTO "django_geo_db_location" VALUES(6717,NULL,'Fort Montgomery, NY',2662,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6718,NULL,'Fort Montgomery, NY 10922',2662,222,NULL,32,3763,0);
INSERT INTO "django_geo_db_location" VALUES(6719,NULL,'Garnerville, NY',2663,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6720,NULL,'Garnerville, NY 10923',2663,222,NULL,32,3764,0);
INSERT INTO "django_geo_db_location" VALUES(6721,NULL,'Goshen, NY',2664,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6722,NULL,'Goshen, NY 10924',2664,222,NULL,32,3765,0);
INSERT INTO "django_geo_db_location" VALUES(6723,NULL,'Greenwood Lake, NY',2665,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6724,NULL,'Greenwood Lake, NY 10925',2665,222,NULL,32,3766,0);
INSERT INTO "django_geo_db_location" VALUES(6725,NULL,'Harriman, NY',2666,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6726,NULL,'Harriman, NY 10926',2666,222,NULL,32,3767,0);
INSERT INTO "django_geo_db_location" VALUES(6727,NULL,'Haverstraw, NY',2667,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6728,NULL,'Haverstraw, NY 10927',2667,222,NULL,32,3768,0);
INSERT INTO "django_geo_db_location" VALUES(6729,NULL,'Highland Falls, NY',2668,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6730,NULL,'Highland Falls, NY 10928',2668,222,NULL,32,3769,0);
INSERT INTO "django_geo_db_location" VALUES(6731,NULL,'Highland Mills, NY',2669,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6732,NULL,'Highland Mills, NY 10930',2669,222,NULL,32,3770,0);
INSERT INTO "django_geo_db_location" VALUES(6733,NULL,'Hillburn, NY',2670,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6734,NULL,'Hillburn, NY 10931',2670,222,NULL,32,3771,0);
INSERT INTO "django_geo_db_location" VALUES(6735,NULL,'Howells, NY',2671,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6736,NULL,'Howells, NY 10932',2671,222,NULL,32,3772,0);
INSERT INTO "django_geo_db_location" VALUES(6737,NULL,'Johnson, NY',2672,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6738,NULL,'Johnson, NY 10933',2672,222,NULL,32,3773,0);
INSERT INTO "django_geo_db_location" VALUES(6739,NULL,'Middletown, NY',2673,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6740,NULL,'Middletown, NY 10940',2673,222,NULL,32,3774,0);
INSERT INTO "django_geo_db_location" VALUES(6741,NULL,'Middletown, NY 10941',2673,222,NULL,32,3775,0);
INSERT INTO "django_geo_db_location" VALUES(6742,NULL,'Middletown, NY 10943',2673,222,NULL,32,3776,0);
INSERT INTO "django_geo_db_location" VALUES(6743,NULL,'Wallkill, NY',2674,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6744,NULL,'Wallkill, NY 10946',2674,222,NULL,32,3777,0);
INSERT INTO "django_geo_db_location" VALUES(6745,NULL,'Monroe, NY',2675,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6746,NULL,'Monroe, NY 10950',2675,222,NULL,32,3778,0);
INSERT INTO "django_geo_db_location" VALUES(6747,NULL,'Monsey, NY',2676,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6748,NULL,'Monsey, NY 10952',2676,222,NULL,32,3779,0);
INSERT INTO "django_geo_db_location" VALUES(6749,NULL,'Mountainville, NY',2677,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6750,NULL,'Mountainville, NY 10953',2677,222,NULL,32,3780,0);
INSERT INTO "django_geo_db_location" VALUES(6751,NULL,'Nanuet, NY',2678,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6752,NULL,'Nanuet, NY 10954',2678,222,NULL,32,3781,0);
INSERT INTO "django_geo_db_location" VALUES(6753,NULL,'New City, NY',2679,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6754,NULL,'New City, NY 10956',2679,222,NULL,32,3782,0);
INSERT INTO "django_geo_db_location" VALUES(6755,NULL,'Lewisboro, NY',2680,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6756,NULL,'Lewisboro, NY 10957',2680,222,NULL,32,3783,0);
INSERT INTO "django_geo_db_location" VALUES(6757,NULL,'New Hampton, NY',2681,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6758,NULL,'New Hampton, NY 10958',2681,222,NULL,32,3784,0);
INSERT INTO "django_geo_db_location" VALUES(6759,NULL,'New Milford, NY',2682,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6760,NULL,'New Milford, NY 10959',2682,222,NULL,32,3785,0);
INSERT INTO "django_geo_db_location" VALUES(6761,NULL,'Nyack, NY',2683,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6762,NULL,'Nyack, NY 10960',2683,222,NULL,32,3786,0);
INSERT INTO "django_geo_db_location" VALUES(6763,NULL,'Orangeburg, NY',2684,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6764,NULL,'Orangeburg, NY 10962',2684,222,NULL,32,3787,0);
INSERT INTO "django_geo_db_location" VALUES(6765,NULL,'Otisville, NY',2685,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6766,NULL,'Otisville, NY 10963',2685,222,NULL,32,3788,0);
INSERT INTO "django_geo_db_location" VALUES(6767,NULL,'Palisades, NY',2686,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6768,NULL,'Palisades, NY 10964',2686,222,NULL,32,3789,0);
INSERT INTO "django_geo_db_location" VALUES(6769,NULL,'Pearl River, NY',2687,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6770,NULL,'Pearl River, NY 10965',2687,222,NULL,32,3790,0);
INSERT INTO "django_geo_db_location" VALUES(6771,NULL,'Piermont, NY',2688,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6772,NULL,'Piermont, NY 10968',2688,222,NULL,32,3791,0);
INSERT INTO "django_geo_db_location" VALUES(6773,NULL,'Pine Island, NY',2689,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6774,NULL,'Pine Island, NY 10969',2689,222,NULL,32,3792,0);
INSERT INTO "django_geo_db_location" VALUES(6775,NULL,'Pomona, NY',2690,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6776,NULL,'Pomona, NY 10970',2690,222,NULL,32,3793,0);
INSERT INTO "django_geo_db_location" VALUES(6777,NULL,'Slate Hill, NY',2691,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6778,NULL,'Slate Hill, NY 10973',2691,222,NULL,32,3794,0);
INSERT INTO "django_geo_db_location" VALUES(6779,NULL,'Sloatsburg, NY',2692,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6780,NULL,'Sloatsburg, NY 10974',2692,222,NULL,32,3795,0);
INSERT INTO "django_geo_db_location" VALUES(6781,NULL,'Southfields, NY',2693,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6782,NULL,'Southfields, NY 10975',2693,222,NULL,32,3796,0);
INSERT INTO "django_geo_db_location" VALUES(6783,NULL,'Sparkill, NY',2694,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6784,NULL,'Sparkill, NY 10976',2694,222,NULL,32,3797,0);
INSERT INTO "django_geo_db_location" VALUES(6785,NULL,'Spring Valley, NY',2695,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6786,NULL,'Spring Valley, NY 10977',2695,222,NULL,32,3798,0);
INSERT INTO "django_geo_db_location" VALUES(6787,NULL,'Sterling Forest, NY',2696,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6788,NULL,'Sterling Forest, NY 10979',2696,222,NULL,32,3799,0);
INSERT INTO "django_geo_db_location" VALUES(6789,NULL,'Stony Point, NY',2697,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6790,NULL,'Stony Point, NY 10980',2697,222,NULL,32,3800,0);
INSERT INTO "django_geo_db_location" VALUES(6791,NULL,'Sugar Loaf, NY',2698,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6792,NULL,'Sugar Loaf, NY 10981',2698,222,NULL,32,3801,0);
INSERT INTO "django_geo_db_location" VALUES(6793,NULL,'Tallman, NY',2699,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6794,NULL,'Tallman, NY 10982',2699,222,NULL,32,3802,0);
INSERT INTO "django_geo_db_location" VALUES(6795,NULL,'Tappan, NY',2700,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6796,NULL,'Tappan, NY 10983',2700,222,NULL,32,3803,0);
INSERT INTO "django_geo_db_location" VALUES(6797,NULL,'Thiells, NY',2701,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6798,NULL,'Thiells, NY 10984',2701,222,NULL,32,3804,0);
INSERT INTO "django_geo_db_location" VALUES(6799,NULL,'Thompson Ridge, NY',2702,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6800,NULL,'Thompson Ridge, NY 10985',2702,222,NULL,32,3805,0);
INSERT INTO "django_geo_db_location" VALUES(6801,NULL,'Tomkins Cove, NY',2703,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6802,NULL,'Tomkins Cove, NY 10986',2703,222,NULL,32,3806,0);
INSERT INTO "django_geo_db_location" VALUES(6803,NULL,'Tuxedo Park, NY',2704,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6804,NULL,'Tuxedo Park, NY 10987',2704,222,NULL,32,3807,0);
INSERT INTO "django_geo_db_location" VALUES(6805,NULL,'Unionville, NY',2705,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6806,NULL,'Unionville, NY 10988',2705,222,NULL,32,3808,0);
INSERT INTO "django_geo_db_location" VALUES(6807,NULL,'Valley Cottage, NY',2706,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6808,NULL,'Valley Cottage, NY 10989',2706,222,NULL,32,3809,0);
INSERT INTO "django_geo_db_location" VALUES(6809,NULL,'Warwick, NY',2707,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6810,NULL,'Warwick, NY 10990',2707,222,NULL,32,3810,0);
INSERT INTO "django_geo_db_location" VALUES(6811,NULL,'Washingtonville, NY',2708,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6812,NULL,'Washingtonville, NY 10992',2708,222,NULL,32,3811,0);
INSERT INTO "django_geo_db_location" VALUES(6813,NULL,'West Haverstraw, NY',2709,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6814,NULL,'West Haverstraw, NY 10993',2709,222,NULL,32,3812,0);
INSERT INTO "django_geo_db_location" VALUES(6815,NULL,'West Nyack, NY',2710,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6816,NULL,'West Nyack, NY 10994',2710,222,NULL,32,3813,0);
INSERT INTO "django_geo_db_location" VALUES(6817,NULL,'West Nyack, NY 10995',2710,222,NULL,32,3814,0);
INSERT INTO "django_geo_db_location" VALUES(6818,NULL,'West Point, NY',2711,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6819,NULL,'West Point, NY 10996',2711,222,NULL,32,3815,0);
INSERT INTO "django_geo_db_location" VALUES(6820,NULL,'West Point, NY 10997',2711,222,NULL,32,3816,0);
INSERT INTO "django_geo_db_location" VALUES(6821,NULL,'Westtown, NY',2712,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6822,NULL,'Westtown, NY 10998',2712,222,NULL,32,3817,0);
INSERT INTO "django_geo_db_location" VALUES(6823,NULL,'Floral Park, NY',2713,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6824,NULL,'Floral Park, NY 11001',2713,222,NULL,32,3818,0);
INSERT INTO "django_geo_db_location" VALUES(6825,NULL,'Floral Park, NY 11002',2713,222,NULL,32,3819,0);
INSERT INTO "django_geo_db_location" VALUES(6826,NULL,'Elmont, NY',2714,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6827,NULL,'Elmont, NY 11003',2714,222,NULL,32,3820,0);
INSERT INTO "django_geo_db_location" VALUES(6828,NULL,'Glen Oaks, NY',2715,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6829,NULL,'Glen Oaks, NY 11004',2715,222,NULL,32,3821,0);
INSERT INTO "django_geo_db_location" VALUES(6830,NULL,'Floral Park, NY 11005',2713,222,NULL,32,3822,0);
INSERT INTO "django_geo_db_location" VALUES(6831,NULL,'Franklin Square, NY',2716,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6832,NULL,'Franklin Square, NY 11010',2716,222,NULL,32,3823,0);
INSERT INTO "django_geo_db_location" VALUES(6833,NULL,'Great Neck, NY',2717,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6834,NULL,'Great Neck, NY 11020',2717,222,NULL,32,3824,0);
INSERT INTO "django_geo_db_location" VALUES(6835,NULL,'Great Neck, NY 11021',2717,222,NULL,32,3825,0);
INSERT INTO "django_geo_db_location" VALUES(6836,NULL,'Great Neck, NY 11022',2717,222,NULL,32,3826,0);
INSERT INTO "django_geo_db_location" VALUES(6837,NULL,'Great Neck, NY 11023',2717,222,NULL,32,3827,0);
INSERT INTO "django_geo_db_location" VALUES(6838,NULL,'Great Neck, NY 11024',2717,222,NULL,32,3828,0);
INSERT INTO "django_geo_db_location" VALUES(6839,NULL,'Great Neck, NY 11025',2717,222,NULL,32,3829,0);
INSERT INTO "django_geo_db_location" VALUES(6840,NULL,'Great Neck, NY 11026',2717,222,NULL,32,3830,0);
INSERT INTO "django_geo_db_location" VALUES(6841,NULL,'Great Neck, NY 11027',2717,222,NULL,32,3831,0);
INSERT INTO "django_geo_db_location" VALUES(6842,NULL,'Manhasset, NY',2718,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6843,NULL,'Manhasset, NY 11030',2718,222,NULL,32,3832,0);
INSERT INTO "django_geo_db_location" VALUES(6844,NULL,'New Hyde Park, NY',2719,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6845,NULL,'New Hyde Park, NY 11040',2719,222,NULL,32,3833,0);
INSERT INTO "django_geo_db_location" VALUES(6846,NULL,'New Hyde Park, NY 11041',2719,222,NULL,32,3834,0);
INSERT INTO "django_geo_db_location" VALUES(6847,NULL,'New Hyde Park, NY 11042',2719,222,NULL,32,3835,0);
INSERT INTO "django_geo_db_location" VALUES(6848,NULL,'New Hyde Park, NY 11043',2719,222,NULL,32,3836,0);
INSERT INTO "django_geo_db_location" VALUES(6849,NULL,'New Hyde Park, NY 11044',2719,222,NULL,32,3837,0);
INSERT INTO "django_geo_db_location" VALUES(6850,NULL,'Port Washington, NY',2720,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6851,NULL,'Port Washington, NY 11050',2720,222,NULL,32,3838,0);
INSERT INTO "django_geo_db_location" VALUES(6852,NULL,'Port Washington, NY 11051',2720,222,NULL,32,3839,0);
INSERT INTO "django_geo_db_location" VALUES(6853,NULL,'Port Washington, NY 11052',2720,222,NULL,32,3840,0);
INSERT INTO "django_geo_db_location" VALUES(6854,NULL,'Port Washington, NY 11053',2720,222,NULL,32,3841,0);
INSERT INTO "django_geo_db_location" VALUES(6855,NULL,'Port Washington, NY 11054',2720,222,NULL,32,3842,0);
INSERT INTO "django_geo_db_location" VALUES(6856,NULL,'Port Washington, NY 11055',2720,222,NULL,32,3843,0);
INSERT INTO "django_geo_db_location" VALUES(6857,NULL,'Inwood, NY',2721,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6858,NULL,'Inwood, NY 11096',2721,222,NULL,32,3844,0);
INSERT INTO "django_geo_db_location" VALUES(6859,NULL,'New Hyde Park, NY 11099',2719,222,NULL,32,3845,0);
INSERT INTO "django_geo_db_location" VALUES(6860,NULL,'Long Island City, NY',2722,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6861,NULL,'Long Island City, NY 11101',2722,222,NULL,32,3846,0);
INSERT INTO "django_geo_db_location" VALUES(6862,NULL,'Astoria, NY',2723,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6863,NULL,'Astoria, NY 11102',2723,222,NULL,32,3847,0);
INSERT INTO "django_geo_db_location" VALUES(6864,NULL,'Astoria, NY 11103',2723,222,NULL,32,3848,0);
INSERT INTO "django_geo_db_location" VALUES(6865,NULL,'Sunnyside, NY',2724,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6866,NULL,'Sunnyside, NY 11104',2724,222,NULL,32,3849,0);
INSERT INTO "django_geo_db_location" VALUES(6867,NULL,'Astoria, NY 11105',2723,222,NULL,32,3850,0);
INSERT INTO "django_geo_db_location" VALUES(6868,NULL,'Astoria, NY 11106',2723,222,NULL,32,3851,0);
INSERT INTO "django_geo_db_location" VALUES(6869,NULL,'Long Island City, NY 11109',2722,222,NULL,32,3852,0);
INSERT INTO "django_geo_db_location" VALUES(6870,NULL,'Long Island City, NY 11120',2722,222,NULL,32,3853,0);
INSERT INTO "django_geo_db_location" VALUES(6871,NULL,'Brooklyn, NY',2725,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6872,NULL,'Brooklyn, NY 11201',2725,222,NULL,32,3854,0);
INSERT INTO "django_geo_db_location" VALUES(6873,NULL,'Brooklyn, NY 11202',2725,222,NULL,32,3855,0);
INSERT INTO "django_geo_db_location" VALUES(6874,NULL,'Brooklyn, NY 11203',2725,222,NULL,32,3856,0);
INSERT INTO "django_geo_db_location" VALUES(6875,NULL,'Brooklyn, NY 11204',2725,222,NULL,32,3857,0);
INSERT INTO "django_geo_db_location" VALUES(6876,NULL,'Brooklyn, NY 11205',2725,222,NULL,32,3858,0);
INSERT INTO "django_geo_db_location" VALUES(6877,NULL,'Brooklyn, NY 11206',2725,222,NULL,32,3859,0);
INSERT INTO "django_geo_db_location" VALUES(6878,NULL,'Brooklyn, NY 11207',2725,222,NULL,32,3860,0);
INSERT INTO "django_geo_db_location" VALUES(6879,NULL,'Brooklyn, NY 11208',2725,222,NULL,32,3861,0);
INSERT INTO "django_geo_db_location" VALUES(6880,NULL,'Brooklyn, NY 11209',2725,222,NULL,32,3862,0);
INSERT INTO "django_geo_db_location" VALUES(6881,NULL,'Brooklyn, NY 11210',2725,222,NULL,32,3863,0);
INSERT INTO "django_geo_db_location" VALUES(6882,NULL,'Brooklyn, NY 11211',2725,222,NULL,32,3864,0);
INSERT INTO "django_geo_db_location" VALUES(6883,NULL,'Brooklyn, NY 11212',2725,222,NULL,32,3865,0);
INSERT INTO "django_geo_db_location" VALUES(6884,NULL,'Brooklyn, NY 11213',2725,222,NULL,32,3866,0);
INSERT INTO "django_geo_db_location" VALUES(6885,NULL,'Brooklyn, NY 11214',2725,222,NULL,32,3867,0);
INSERT INTO "django_geo_db_location" VALUES(6886,NULL,'Brooklyn, NY 11215',2725,222,NULL,32,3868,0);
INSERT INTO "django_geo_db_location" VALUES(6887,NULL,'Brooklyn, NY 11216',2725,222,NULL,32,3869,0);
INSERT INTO "django_geo_db_location" VALUES(6888,NULL,'Brooklyn, NY 11217',2725,222,NULL,32,3870,0);
INSERT INTO "django_geo_db_location" VALUES(6889,NULL,'Brooklyn, NY 11218',2725,222,NULL,32,3871,0);
INSERT INTO "django_geo_db_location" VALUES(6890,NULL,'Brooklyn, NY 11219',2725,222,NULL,32,3872,0);
INSERT INTO "django_geo_db_location" VALUES(6891,NULL,'Brooklyn, NY 11220',2725,222,NULL,32,3873,0);
INSERT INTO "django_geo_db_location" VALUES(6892,NULL,'Brooklyn, NY 11221',2725,222,NULL,32,3874,0);
INSERT INTO "django_geo_db_location" VALUES(6893,NULL,'Brooklyn, NY 11222',2725,222,NULL,32,3875,0);
INSERT INTO "django_geo_db_location" VALUES(6894,NULL,'Brooklyn, NY 11223',2725,222,NULL,32,3876,0);
INSERT INTO "django_geo_db_location" VALUES(6895,NULL,'Brooklyn, NY 11224',2725,222,NULL,32,3877,0);
INSERT INTO "django_geo_db_location" VALUES(6896,NULL,'Brooklyn, NY 11225',2725,222,NULL,32,3878,0);
INSERT INTO "django_geo_db_location" VALUES(6897,NULL,'Brooklyn, NY 11226',2725,222,NULL,32,3879,0);
INSERT INTO "django_geo_db_location" VALUES(6898,NULL,'Brooklyn, NY 11228',2725,222,NULL,32,3880,0);
INSERT INTO "django_geo_db_location" VALUES(6899,NULL,'Brooklyn, NY 11229',2725,222,NULL,32,3881,0);
INSERT INTO "django_geo_db_location" VALUES(6900,NULL,'Brooklyn, NY 11230',2725,222,NULL,32,3882,0);
INSERT INTO "django_geo_db_location" VALUES(6901,NULL,'Brooklyn, NY 11231',2725,222,NULL,32,3883,0);
INSERT INTO "django_geo_db_location" VALUES(6902,NULL,'Brooklyn, NY 11232',2725,222,NULL,32,3884,0);
INSERT INTO "django_geo_db_location" VALUES(6903,NULL,'Brooklyn, NY 11233',2725,222,NULL,32,3885,0);
INSERT INTO "django_geo_db_location" VALUES(6904,NULL,'Brooklyn, NY 11234',2725,222,NULL,32,3886,0);
INSERT INTO "django_geo_db_location" VALUES(6905,NULL,'Brooklyn, NY 11235',2725,222,NULL,32,3887,0);
INSERT INTO "django_geo_db_location" VALUES(6906,NULL,'Brooklyn, NY 11236',2725,222,NULL,32,3888,0);
INSERT INTO "django_geo_db_location" VALUES(6907,NULL,'Brooklyn, NY 11237',2725,222,NULL,32,3889,0);
INSERT INTO "django_geo_db_location" VALUES(6908,NULL,'Brooklyn, NY 11238',2725,222,NULL,32,3890,0);
INSERT INTO "django_geo_db_location" VALUES(6909,NULL,'Brooklyn, NY 11239',2725,222,NULL,32,3891,0);
INSERT INTO "django_geo_db_location" VALUES(6910,NULL,'Brooklyn, NY 11240',2725,222,NULL,32,3892,0);
INSERT INTO "django_geo_db_location" VALUES(6911,NULL,'Brooklyn, NY 11241',2725,222,NULL,32,3893,0);
INSERT INTO "django_geo_db_location" VALUES(6912,NULL,'Brooklyn, NY 11242',2725,222,NULL,32,3894,0);
INSERT INTO "django_geo_db_location" VALUES(6913,NULL,'Brooklyn, NY 11243',2725,222,NULL,32,3895,0);
INSERT INTO "django_geo_db_location" VALUES(6914,NULL,'Brooklyn, NY 11244',2725,222,NULL,32,3896,0);
INSERT INTO "django_geo_db_location" VALUES(6915,NULL,'Brooklyn, NY 11245',2725,222,NULL,32,3897,0);
INSERT INTO "django_geo_db_location" VALUES(6916,NULL,'Brooklyn, NY 11247',2725,222,NULL,32,3898,0);
INSERT INTO "django_geo_db_location" VALUES(6917,NULL,'Brooklyn, NY 11248',2725,222,NULL,32,3899,0);
INSERT INTO "django_geo_db_location" VALUES(6918,NULL,'Brooklyn, NY 11249',2725,222,NULL,32,3900,0);
INSERT INTO "django_geo_db_location" VALUES(6919,NULL,'Brooklyn, NY 11251',2725,222,NULL,32,3901,0);
INSERT INTO "django_geo_db_location" VALUES(6920,NULL,'Brooklyn, NY 11252',2725,222,NULL,32,3902,0);
INSERT INTO "django_geo_db_location" VALUES(6921,NULL,'Brooklyn, NY 11254',2725,222,NULL,32,3903,0);
INSERT INTO "django_geo_db_location" VALUES(6922,NULL,'Brooklyn, NY 11255',2725,222,NULL,32,3904,0);
INSERT INTO "django_geo_db_location" VALUES(6923,NULL,'Brooklyn, NY 11256',2725,222,NULL,32,3905,0);
INSERT INTO "django_geo_db_location" VALUES(6924,NULL,'New York, NY 11286',2571,222,NULL,32,3906,0);
INSERT INTO "django_geo_db_location" VALUES(6925,NULL,'New York, NY 11302',2571,222,NULL,32,3907,0);
INSERT INTO "django_geo_db_location" VALUES(6926,NULL,'Flushing, NY',2726,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6927,NULL,'Flushing, NY 11351',2726,222,NULL,32,3908,0);
INSERT INTO "django_geo_db_location" VALUES(6928,NULL,'Flushing, NY 11352',2726,222,NULL,32,3909,0);
INSERT INTO "django_geo_db_location" VALUES(6929,NULL,'Flushing, NY 11353',2726,222,NULL,32,3910,0);
INSERT INTO "django_geo_db_location" VALUES(6930,NULL,'Flushing, NY 11354',2726,222,NULL,32,3911,0);
INSERT INTO "django_geo_db_location" VALUES(6931,NULL,'Flushing, NY 11355',2726,222,NULL,32,3912,0);
INSERT INTO "django_geo_db_location" VALUES(6932,NULL,'College Point, NY',2727,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6933,NULL,'College Point, NY 11356',2727,222,NULL,32,3913,0);
INSERT INTO "django_geo_db_location" VALUES(6934,NULL,'Whitestone, NY',2728,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6935,NULL,'Whitestone, NY 11357',2728,222,NULL,32,3914,0);
INSERT INTO "django_geo_db_location" VALUES(6936,NULL,'Flushing, NY 11358',2726,222,NULL,32,3915,0);
INSERT INTO "django_geo_db_location" VALUES(6937,NULL,'Bayside, NY',2729,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6938,NULL,'Bayside, NY 11359',2729,222,NULL,32,3916,0);
INSERT INTO "django_geo_db_location" VALUES(6939,NULL,'Bayside, NY 11360',2729,222,NULL,32,3917,0);
INSERT INTO "django_geo_db_location" VALUES(6940,NULL,'Bayside, NY 11361',2729,222,NULL,32,3918,0);
INSERT INTO "django_geo_db_location" VALUES(6941,NULL,'Little Neck, NY',2730,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6942,NULL,'Little Neck, NY 11362',2730,222,NULL,32,3919,0);
INSERT INTO "django_geo_db_location" VALUES(6943,NULL,'Little Neck, NY 11363',2730,222,NULL,32,3920,0);
INSERT INTO "django_geo_db_location" VALUES(6944,NULL,'Oakland Gardens, NY',2731,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6945,NULL,'Oakland Gardens, NY 11364',2731,222,NULL,32,3921,0);
INSERT INTO "django_geo_db_location" VALUES(6946,NULL,'Fresh Meadows, NY',2732,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6947,NULL,'Fresh Meadows, NY 11365',2732,222,NULL,32,3922,0);
INSERT INTO "django_geo_db_location" VALUES(6948,NULL,'Fresh Meadows, NY 11366',2732,222,NULL,32,3923,0);
INSERT INTO "django_geo_db_location" VALUES(6949,NULL,'Flushing, NY 11367',2726,222,NULL,32,3924,0);
INSERT INTO "django_geo_db_location" VALUES(6950,NULL,'Corona, NY',2733,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6951,NULL,'Corona, NY 11368',2733,222,NULL,32,3925,0);
INSERT INTO "django_geo_db_location" VALUES(6952,NULL,'East Elmhurst, NY',2734,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6953,NULL,'East Elmhurst, NY 11369',2734,222,NULL,32,3926,0);
INSERT INTO "django_geo_db_location" VALUES(6954,NULL,'East Elmhurst, NY 11370',2734,222,NULL,32,3927,0);
INSERT INTO "django_geo_db_location" VALUES(6955,NULL,'Flushing, NY 11371',2726,222,NULL,32,3928,0);
INSERT INTO "django_geo_db_location" VALUES(6956,NULL,'Jackson Heights, NY',2735,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6957,NULL,'Jackson Heights, NY 11372',2735,222,NULL,32,3929,0);
INSERT INTO "django_geo_db_location" VALUES(6958,NULL,'Elmhurst, NY',2736,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6959,NULL,'Elmhurst, NY 11373',2736,222,NULL,32,3930,0);
INSERT INTO "django_geo_db_location" VALUES(6960,NULL,'Rego Park, NY',2737,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6961,NULL,'Rego Park, NY 11374',2737,222,NULL,32,3931,0);
INSERT INTO "django_geo_db_location" VALUES(6962,NULL,'Forest Hills, NY',2738,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6963,NULL,'Forest Hills, NY 11375',2738,222,NULL,32,3932,0);
INSERT INTO "django_geo_db_location" VALUES(6964,NULL,'Woodside, NY',2739,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6965,NULL,'Woodside, NY 11377',2739,222,NULL,32,3933,0);
INSERT INTO "django_geo_db_location" VALUES(6966,NULL,'Maspeth, NY',2740,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6967,NULL,'Maspeth, NY 11378',2740,222,NULL,32,3934,0);
INSERT INTO "django_geo_db_location" VALUES(6968,NULL,'Middle Village, NY',2741,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6969,NULL,'Middle Village, NY 11379',2741,222,NULL,32,3935,0);
INSERT INTO "django_geo_db_location" VALUES(6970,NULL,'Elmhurst, NY 11380',2736,222,NULL,32,3936,0);
INSERT INTO "django_geo_db_location" VALUES(6971,NULL,'Flushing, NY 11381',2726,222,NULL,32,3937,0);
INSERT INTO "django_geo_db_location" VALUES(6972,NULL,'Ridgewood, NY',2742,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6973,NULL,'Ridgewood, NY 11385',2742,222,NULL,32,3938,0);
INSERT INTO "django_geo_db_location" VALUES(6974,NULL,'Ridgewood, NY 11386',2742,222,NULL,32,3939,0);
INSERT INTO "django_geo_db_location" VALUES(6975,NULL,'Flushing, NY 11388',2726,222,NULL,32,3940,0);
INSERT INTO "django_geo_db_location" VALUES(6976,NULL,'Flushing, NY 11390',2726,222,NULL,32,3941,0);
INSERT INTO "django_geo_db_location" VALUES(6977,NULL,'Jamaica, NY',2743,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6978,NULL,'Jamaica, NY 11405',2743,222,NULL,32,3942,0);
INSERT INTO "django_geo_db_location" VALUES(6979,NULL,'Cambria Heights, NY',2744,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6980,NULL,'Cambria Heights, NY 11411',2744,222,NULL,32,3943,0);
INSERT INTO "django_geo_db_location" VALUES(6981,NULL,'Saint Albans, NY',2745,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6982,NULL,'Saint Albans, NY 11412',2745,222,NULL,32,3944,0);
INSERT INTO "django_geo_db_location" VALUES(6983,NULL,'Springfield Gardens, NY',2746,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6984,NULL,'Springfield Gardens, NY 11413',2746,222,NULL,32,3945,0);
INSERT INTO "django_geo_db_location" VALUES(6985,NULL,'Howard Beach, NY',2747,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6986,NULL,'Howard Beach, NY 11414',2747,222,NULL,32,3946,0);
INSERT INTO "django_geo_db_location" VALUES(6987,NULL,'Kew Gardens, NY',2748,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6988,NULL,'Kew Gardens, NY 11415',2748,222,NULL,32,3947,0);
INSERT INTO "django_geo_db_location" VALUES(6989,NULL,'Ozone Park, NY',2749,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6990,NULL,'Ozone Park, NY 11416',2749,222,NULL,32,3948,0);
INSERT INTO "django_geo_db_location" VALUES(6991,NULL,'Ozone Park, NY 11417',2749,222,NULL,32,3949,0);
INSERT INTO "django_geo_db_location" VALUES(6992,NULL,'Richmond Hill, NY',2750,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6993,NULL,'Richmond Hill, NY 11418',2750,222,NULL,32,3950,0);
INSERT INTO "django_geo_db_location" VALUES(6994,NULL,'South Richmond Hill, NY',2751,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6995,NULL,'South Richmond Hill, NY 11419',2751,222,NULL,32,3951,0);
INSERT INTO "django_geo_db_location" VALUES(6996,NULL,'South Ozone Park, NY',2752,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6997,NULL,'South Ozone Park, NY 11420',2752,222,NULL,32,3952,0);
INSERT INTO "django_geo_db_location" VALUES(6998,NULL,'Woodhaven, NY',2753,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(6999,NULL,'Woodhaven, NY 11421',2753,222,NULL,32,3953,0);
INSERT INTO "django_geo_db_location" VALUES(7000,NULL,'Rosedale, NY',2754,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7001,NULL,'Rosedale, NY 11422',2754,222,NULL,32,3954,0);
INSERT INTO "django_geo_db_location" VALUES(7002,NULL,'Hollis, NY',2755,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7003,NULL,'Hollis, NY 11423',2755,222,NULL,32,3955,0);
INSERT INTO "django_geo_db_location" VALUES(7004,NULL,'Jamaica, NY 11424',2743,222,NULL,32,3956,0);
INSERT INTO "django_geo_db_location" VALUES(7005,NULL,'Jamaica, NY 11425',2743,222,NULL,32,3957,0);
INSERT INTO "django_geo_db_location" VALUES(7006,NULL,'Bellerose, NY',2756,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7007,NULL,'Bellerose, NY 11426',2756,222,NULL,32,3958,0);
INSERT INTO "django_geo_db_location" VALUES(7008,NULL,'Queens Village, NY',2757,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7009,NULL,'Queens Village, NY 11427',2757,222,NULL,32,3959,0);
INSERT INTO "django_geo_db_location" VALUES(7010,NULL,'Queens Village, NY 11428',2757,222,NULL,32,3960,0);
INSERT INTO "django_geo_db_location" VALUES(7011,NULL,'Queens Village, NY 11429',2757,222,NULL,32,3961,0);
INSERT INTO "django_geo_db_location" VALUES(7012,NULL,'Jamaica, NY 11430',2743,222,NULL,32,3962,0);
INSERT INTO "django_geo_db_location" VALUES(7013,NULL,'Jamaica, NY 11431',2743,222,NULL,32,3963,0);
INSERT INTO "django_geo_db_location" VALUES(7014,NULL,'Jamaica, NY 11432',2743,222,NULL,32,3964,0);
INSERT INTO "django_geo_db_location" VALUES(7015,NULL,'Jamaica, NY 11433',2743,222,NULL,32,3965,0);
INSERT INTO "django_geo_db_location" VALUES(7016,NULL,'Jamaica, NY 11434',2743,222,NULL,32,3966,0);
INSERT INTO "django_geo_db_location" VALUES(7017,NULL,'Jamaica, NY 11435',2743,222,NULL,32,3967,0);
INSERT INTO "django_geo_db_location" VALUES(7018,NULL,'Jamaica, NY 11436',2743,222,NULL,32,3968,0);
INSERT INTO "django_geo_db_location" VALUES(7019,NULL,'Jamaica, NY 11439',2743,222,NULL,32,3969,0);
INSERT INTO "django_geo_db_location" VALUES(7020,NULL,'Jamaica, NY 11451',2743,222,NULL,32,3970,0);
INSERT INTO "django_geo_db_location" VALUES(7021,NULL,'Jamaica, NY 11484',2743,222,NULL,32,3971,0);
INSERT INTO "django_geo_db_location" VALUES(7022,NULL,'Jamaica, NY 11499',2743,222,NULL,32,3972,0);
INSERT INTO "django_geo_db_location" VALUES(7023,NULL,'Mineola, NY',2758,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7024,NULL,'Mineola, NY 11501',2758,222,NULL,32,3973,0);
INSERT INTO "django_geo_db_location" VALUES(7025,NULL,'Albertson, NY',2759,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7026,NULL,'Albertson, NY 11507',2759,222,NULL,32,3974,0);
INSERT INTO "django_geo_db_location" VALUES(7027,NULL,'Atlantic Beach, NY',2760,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7028,NULL,'Atlantic Beach, NY 11509',2760,222,NULL,32,3975,0);
INSERT INTO "django_geo_db_location" VALUES(7029,NULL,'Baldwin, NY',2761,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7030,NULL,'Baldwin, NY 11510',2761,222,NULL,32,3976,0);
INSERT INTO "django_geo_db_location" VALUES(7031,NULL,'Carle Place, NY',2762,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7032,NULL,'Carle Place, NY 11514',2762,222,NULL,32,3977,0);
INSERT INTO "django_geo_db_location" VALUES(7033,NULL,'Cedarhurst, NY',2763,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7034,NULL,'Cedarhurst, NY 11516',2763,222,NULL,32,3978,0);
INSERT INTO "django_geo_db_location" VALUES(7035,NULL,'New York, NY 11517',2571,222,NULL,32,3979,0);
INSERT INTO "django_geo_db_location" VALUES(7036,NULL,'East Rockaway, NY',2764,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7037,NULL,'East Rockaway, NY 11518',2764,222,NULL,32,3980,0);
INSERT INTO "django_geo_db_location" VALUES(7038,NULL,'Freeport, NY',2765,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7039,NULL,'Freeport, NY 11520',2765,222,NULL,32,3981,0);
INSERT INTO "django_geo_db_location" VALUES(7040,NULL,'Garden City, NY',2766,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7041,NULL,'Garden City, NY 11530',2766,222,NULL,32,3982,0);
INSERT INTO "django_geo_db_location" VALUES(7042,NULL,'Garden City, NY 11531',2766,222,NULL,32,3983,0);
INSERT INTO "django_geo_db_location" VALUES(7043,NULL,'Garden City, NY 11535',2766,222,NULL,32,3984,0);
INSERT INTO "django_geo_db_location" VALUES(7044,NULL,'Garden City, NY 11536',2766,222,NULL,32,3985,0);
INSERT INTO "django_geo_db_location" VALUES(7045,NULL,'Glen Cove, NY',2767,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7046,NULL,'Glen Cove, NY 11542',2767,222,NULL,32,3986,0);
INSERT INTO "django_geo_db_location" VALUES(7047,NULL,'Glen Head, NY',2768,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7048,NULL,'Glen Head, NY 11545',2768,222,NULL,32,3987,0);
INSERT INTO "django_geo_db_location" VALUES(7049,NULL,'Glenwood Landing, NY',2769,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7050,NULL,'Glenwood Landing, NY 11547',2769,222,NULL,32,3988,0);
INSERT INTO "django_geo_db_location" VALUES(7051,NULL,'Greenvale, NY',2770,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7052,NULL,'Greenvale, NY 11548',2770,222,NULL,32,3989,0);
INSERT INTO "django_geo_db_location" VALUES(7053,NULL,'Hempstead, NY',2771,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7054,NULL,'Hempstead, NY 11549',2771,222,NULL,32,3990,0);
INSERT INTO "django_geo_db_location" VALUES(7055,NULL,'Hempstead, NY 11550',2771,222,NULL,32,3991,0);
INSERT INTO "django_geo_db_location" VALUES(7056,NULL,'Hempstead, NY 11551',2771,222,NULL,32,3992,0);
INSERT INTO "django_geo_db_location" VALUES(7057,NULL,'West Hempstead, NY',2772,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7058,NULL,'West Hempstead, NY 11552',2772,222,NULL,32,3993,0);
INSERT INTO "django_geo_db_location" VALUES(7059,NULL,'Uniondale, NY',2773,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7060,NULL,'Uniondale, NY 11553',2773,222,NULL,32,3994,0);
INSERT INTO "django_geo_db_location" VALUES(7061,NULL,'East Meadow, NY',2774,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7062,NULL,'East Meadow, NY 11554',2774,222,NULL,32,3995,0);
INSERT INTO "django_geo_db_location" VALUES(7063,NULL,'Uniondale, NY 11555',2773,222,NULL,32,3996,0);
INSERT INTO "django_geo_db_location" VALUES(7064,NULL,'Uniondale, NY 11556',2773,222,NULL,32,3997,0);
INSERT INTO "django_geo_db_location" VALUES(7065,NULL,'Hewlett, NY',2775,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7066,NULL,'Hewlett, NY 11557',2775,222,NULL,32,3998,0);
INSERT INTO "django_geo_db_location" VALUES(7067,NULL,'Island Park, NY',2776,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7068,NULL,'Island Park, NY 11558',2776,222,NULL,32,3999,0);
INSERT INTO "django_geo_db_location" VALUES(7069,NULL,'Lawrence, NY',2777,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7070,NULL,'Lawrence, NY 11559',2777,222,NULL,32,4000,0);
INSERT INTO "django_geo_db_location" VALUES(7071,NULL,'Locust Valley, NY',2778,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7072,NULL,'Locust Valley, NY 11560',2778,222,NULL,32,4001,0);
INSERT INTO "django_geo_db_location" VALUES(7073,NULL,'Long Beach, NY',2779,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7074,NULL,'Long Beach, NY 11561',2779,222,NULL,32,4002,0);
INSERT INTO "django_geo_db_location" VALUES(7075,NULL,'Lynbrook, NY',2780,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7076,NULL,'Lynbrook, NY 11562',2780,222,NULL,32,4003,0);
INSERT INTO "django_geo_db_location" VALUES(7077,NULL,'Lynbrook, NY 11563',2780,222,NULL,32,4004,0);
INSERT INTO "django_geo_db_location" VALUES(7078,NULL,'Lynbrook, NY 11564',2780,222,NULL,32,4005,0);
INSERT INTO "django_geo_db_location" VALUES(7079,NULL,'Malverne, NY',2781,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7080,NULL,'Malverne, NY 11565',2781,222,NULL,32,4006,0);
INSERT INTO "django_geo_db_location" VALUES(7081,NULL,'Merrick, NY',2782,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7082,NULL,'Merrick, NY 11566',2782,222,NULL,32,4007,0);
INSERT INTO "django_geo_db_location" VALUES(7083,NULL,'Old Westbury, NY',2783,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7084,NULL,'Old Westbury, NY 11568',2783,222,NULL,32,4008,0);
INSERT INTO "django_geo_db_location" VALUES(7085,NULL,'Point Lookout, NY',2784,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7086,NULL,'Point Lookout, NY 11569',2784,222,NULL,32,4009,0);
INSERT INTO "django_geo_db_location" VALUES(7087,NULL,'Rockville Centre, NY',2785,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7088,NULL,'Rockville Centre, NY 11570',2785,222,NULL,32,4010,0);
INSERT INTO "django_geo_db_location" VALUES(7089,NULL,'Rockville Centre, NY 11571',2785,222,NULL,32,4011,0);
INSERT INTO "django_geo_db_location" VALUES(7090,NULL,'Oceanside, NY',2786,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7091,NULL,'Oceanside, NY 11572',2786,222,NULL,32,4012,0);
INSERT INTO "django_geo_db_location" VALUES(7092,NULL,'Roosevelt, NY',2787,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7093,NULL,'Roosevelt, NY 11575',2787,222,NULL,32,4013,0);
INSERT INTO "django_geo_db_location" VALUES(7094,NULL,'Roslyn, NY',2788,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7095,NULL,'Roslyn, NY 11576',2788,222,NULL,32,4014,0);
INSERT INTO "django_geo_db_location" VALUES(7096,NULL,'Roslyn Heights, NY',2789,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7097,NULL,'Roslyn Heights, NY 11577',2789,222,NULL,32,4015,0);
INSERT INTO "django_geo_db_location" VALUES(7098,NULL,'Sea Cliff, NY',2790,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7099,NULL,'Sea Cliff, NY 11579',2790,222,NULL,32,4016,0);
INSERT INTO "django_geo_db_location" VALUES(7100,NULL,'Valley Stream, NY',2791,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7101,NULL,'Valley Stream, NY 11580',2791,222,NULL,32,4017,0);
INSERT INTO "django_geo_db_location" VALUES(7102,NULL,'Valley Stream, NY 11581',2791,222,NULL,32,4018,0);
INSERT INTO "django_geo_db_location" VALUES(7103,NULL,'Valley Stream, NY 11582',2791,222,NULL,32,4019,0);
INSERT INTO "django_geo_db_location" VALUES(7104,NULL,'Valley Stream, NY 11583',2791,222,NULL,32,4020,0);
INSERT INTO "django_geo_db_location" VALUES(7105,NULL,'Uniondale, NY 11588',2773,222,NULL,32,4021,0);
INSERT INTO "django_geo_db_location" VALUES(7106,NULL,'Westbury, NY',2792,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7107,NULL,'Westbury, NY 11590',2792,222,NULL,32,4022,0);
INSERT INTO "django_geo_db_location" VALUES(7108,NULL,'Rockville Centre, NY 11592',2785,222,NULL,32,4023,0);
INSERT INTO "django_geo_db_location" VALUES(7109,NULL,'Westbury, NY 11593',2792,222,NULL,32,4024,0);
INSERT INTO "django_geo_db_location" VALUES(7110,NULL,'Westbury, NY 11594',2792,222,NULL,32,4025,0);
INSERT INTO "django_geo_db_location" VALUES(7111,NULL,'Westbury, NY 11595',2792,222,NULL,32,4026,0);
INSERT INTO "django_geo_db_location" VALUES(7112,NULL,'Williston Park, NY',2793,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7113,NULL,'Williston Park, NY 11596',2793,222,NULL,32,4027,0);
INSERT INTO "django_geo_db_location" VALUES(7114,NULL,'Westbury, NY 11597',2792,222,NULL,32,4028,0);
INSERT INTO "django_geo_db_location" VALUES(7115,NULL,'Woodmere, NY',2794,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7116,NULL,'Woodmere, NY 11598',2794,222,NULL,32,4029,0);
INSERT INTO "django_geo_db_location" VALUES(7117,NULL,'Garden City, NY 11599',2766,222,NULL,32,4030,0);
INSERT INTO "django_geo_db_location" VALUES(7118,NULL,'Far Rockaway, NY',2795,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7119,NULL,'Far Rockaway, NY 11690',2795,222,NULL,32,4031,0);
INSERT INTO "django_geo_db_location" VALUES(7120,NULL,'Far Rockaway, NY 11691',2795,222,NULL,32,4032,0);
INSERT INTO "django_geo_db_location" VALUES(7121,NULL,'Arverne, NY',2796,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7122,NULL,'Arverne, NY 11692',2796,222,NULL,32,4033,0);
INSERT INTO "django_geo_db_location" VALUES(7123,NULL,'Far Rockaway, NY 11693',2795,222,NULL,32,4034,0);
INSERT INTO "django_geo_db_location" VALUES(7124,NULL,'Rockaway Park, NY',2797,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7125,NULL,'Rockaway Park, NY 11694',2797,222,NULL,32,4035,0);
INSERT INTO "django_geo_db_location" VALUES(7126,NULL,'Far Rockaway, NY 11695',2795,222,NULL,32,4036,0);
INSERT INTO "django_geo_db_location" VALUES(7127,NULL,'Inwood, NY 11696',2721,222,NULL,32,4037,0);
INSERT INTO "django_geo_db_location" VALUES(7128,NULL,'Breezy Point, NY',2798,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7129,NULL,'Breezy Point, NY 11697',2798,222,NULL,32,4038,0);
INSERT INTO "django_geo_db_location" VALUES(7130,NULL,'Amityville, NY',2799,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7131,NULL,'Amityville, NY 11701',2799,222,NULL,32,4039,0);
INSERT INTO "django_geo_db_location" VALUES(7132,NULL,'Babylon, NY',2800,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7133,NULL,'Babylon, NY 11702',2800,222,NULL,32,4040,0);
INSERT INTO "django_geo_db_location" VALUES(7134,NULL,'North Babylon, NY',2801,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7135,NULL,'North Babylon, NY 11703',2801,222,NULL,32,4041,0);
INSERT INTO "django_geo_db_location" VALUES(7136,NULL,'West Babylon, NY',2802,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7137,NULL,'West Babylon, NY 11704',2802,222,NULL,32,4042,0);
INSERT INTO "django_geo_db_location" VALUES(7138,NULL,'Bayport, NY',2803,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7139,NULL,'Bayport, NY 11705',2803,222,NULL,32,4043,0);
INSERT INTO "django_geo_db_location" VALUES(7140,NULL,'Bay Shore, NY',2804,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7141,NULL,'Bay Shore, NY 11706',2804,222,NULL,32,4044,0);
INSERT INTO "django_geo_db_location" VALUES(7142,NULL,'West Babylon, NY 11707',2802,222,NULL,32,4045,0);
INSERT INTO "django_geo_db_location" VALUES(7143,NULL,'Amityville, NY 11708',2799,222,NULL,32,4046,0);
INSERT INTO "django_geo_db_location" VALUES(7144,NULL,'Bayville, NY',2805,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7145,NULL,'Bayville, NY 11709',2805,222,NULL,32,4047,0);
INSERT INTO "django_geo_db_location" VALUES(7146,NULL,'Bellmore, NY',2806,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7147,NULL,'Bellmore, NY 11710',2806,222,NULL,32,4048,0);
INSERT INTO "django_geo_db_location" VALUES(7148,NULL,'Bellport, NY',2807,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7149,NULL,'Bellport, NY 11713',2807,222,NULL,32,4049,0);
INSERT INTO "django_geo_db_location" VALUES(7150,NULL,'Bethpage, NY',2808,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7151,NULL,'Bethpage, NY 11714',2808,222,NULL,32,4050,0);
INSERT INTO "django_geo_db_location" VALUES(7152,NULL,'Blue Point, NY',2809,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7153,NULL,'Blue Point, NY 11715',2809,222,NULL,32,4051,0);
INSERT INTO "django_geo_db_location" VALUES(7154,NULL,'Bohemia, NY',2810,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7155,NULL,'Bohemia, NY 11716',2810,222,NULL,32,4052,0);
INSERT INTO "django_geo_db_location" VALUES(7156,NULL,'Brentwood, NY',2811,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7157,NULL,'Brentwood, NY 11717',2811,222,NULL,32,4053,0);
INSERT INTO "django_geo_db_location" VALUES(7158,NULL,'Brightwaters, NY',2812,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7159,NULL,'Brightwaters, NY 11718',2812,222,NULL,32,4054,0);
INSERT INTO "django_geo_db_location" VALUES(7160,NULL,'Brookhaven, NY',2813,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7161,NULL,'Brookhaven, NY 11719',2813,222,NULL,32,4055,0);
INSERT INTO "django_geo_db_location" VALUES(7162,NULL,'Centereach, NY',2814,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7163,NULL,'Centereach, NY 11720',2814,222,NULL,32,4056,0);
INSERT INTO "django_geo_db_location" VALUES(7164,NULL,'Centerport, NY',2815,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7165,NULL,'Centerport, NY 11721',2815,222,NULL,32,4057,0);
INSERT INTO "django_geo_db_location" VALUES(7166,NULL,'Central Islip, NY',2816,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7167,NULL,'Central Islip, NY 11722',2816,222,NULL,32,4058,0);
INSERT INTO "django_geo_db_location" VALUES(7168,NULL,'Cold Spring Harbor, NY',2817,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7169,NULL,'Cold Spring Harbor, NY 11724',2817,222,NULL,32,4059,0);
INSERT INTO "django_geo_db_location" VALUES(7170,NULL,'Commack, NY',2818,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7171,NULL,'Commack, NY 11725',2818,222,NULL,32,4060,0);
INSERT INTO "django_geo_db_location" VALUES(7172,NULL,'Copiague, NY',2819,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7173,NULL,'Copiague, NY 11726',2819,222,NULL,32,4061,0);
INSERT INTO "django_geo_db_location" VALUES(7174,NULL,'Coram, NY',2820,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7175,NULL,'Coram, NY 11727',2820,222,NULL,32,4062,0);
INSERT INTO "django_geo_db_location" VALUES(7176,NULL,'Deer Park, NY',2821,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7177,NULL,'Deer Park, NY 11729',2821,222,NULL,32,4063,0);
INSERT INTO "django_geo_db_location" VALUES(7178,NULL,'East Islip, NY',2822,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7179,NULL,'East Islip, NY 11730',2822,222,NULL,32,4064,0);
INSERT INTO "django_geo_db_location" VALUES(7180,NULL,'East Northport, NY',2823,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7181,NULL,'East Northport, NY 11731',2823,222,NULL,32,4065,0);
INSERT INTO "django_geo_db_location" VALUES(7182,NULL,'East Norwich, NY',2824,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7183,NULL,'East Norwich, NY 11732',2824,222,NULL,32,4066,0);
INSERT INTO "django_geo_db_location" VALUES(7184,NULL,'East Setauket, NY',2825,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7185,NULL,'East Setauket, NY 11733',2825,222,NULL,32,4067,0);
INSERT INTO "django_geo_db_location" VALUES(7186,NULL,'Farmingdale, NY',2826,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7187,NULL,'Farmingdale, NY 11735',2826,222,NULL,32,4068,0);
INSERT INTO "django_geo_db_location" VALUES(7188,NULL,'Farmingdale, NY 11736',2826,222,NULL,32,4069,0);
INSERT INTO "django_geo_db_location" VALUES(7189,NULL,'Farmingdale, NY 11737',2826,222,NULL,32,4070,0);
INSERT INTO "django_geo_db_location" VALUES(7190,NULL,'Farmingville, NY',2827,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7191,NULL,'Farmingville, NY 11738',2827,222,NULL,32,4071,0);
INSERT INTO "django_geo_db_location" VALUES(7192,NULL,'Great River, NY',2828,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7193,NULL,'Great River, NY 11739',2828,222,NULL,32,4072,0);
INSERT INTO "django_geo_db_location" VALUES(7194,NULL,'Greenlawn, NY',2829,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7195,NULL,'Greenlawn, NY 11740',2829,222,NULL,32,4073,0);
INSERT INTO "django_geo_db_location" VALUES(7196,NULL,'Holbrook, NY',2830,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7197,NULL,'Holbrook, NY 11741',2830,222,NULL,32,4074,0);
INSERT INTO "django_geo_db_location" VALUES(7198,NULL,'Holtsville, NY 11742',2,222,NULL,32,4075,0);
INSERT INTO "django_geo_db_location" VALUES(7199,NULL,'Huntington, NY',2831,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7200,NULL,'Huntington, NY 11743',2831,222,NULL,32,4076,0);
INSERT INTO "django_geo_db_location" VALUES(7201,NULL,'Smithtown, NY',2832,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7202,NULL,'Smithtown, NY 11745',2832,222,NULL,32,4077,0);
INSERT INTO "django_geo_db_location" VALUES(7203,NULL,'Huntington Station, NY',2833,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7204,NULL,'Huntington Station, NY 11746',2833,222,NULL,32,4078,0);
INSERT INTO "django_geo_db_location" VALUES(7205,NULL,'Melville, NY',2834,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7206,NULL,'Melville, NY 11747',2834,222,NULL,32,4079,0);
INSERT INTO "django_geo_db_location" VALUES(7207,NULL,'Islandia, NY',2835,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7208,NULL,'Islandia, NY 11749',2835,222,NULL,32,4080,0);
INSERT INTO "django_geo_db_location" VALUES(7209,NULL,'Huntington Station, NY 11750',2833,222,NULL,32,4081,0);
INSERT INTO "django_geo_db_location" VALUES(7210,NULL,'Islip, NY',2836,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7211,NULL,'Islip, NY 11751',2836,222,NULL,32,4082,0);
INSERT INTO "django_geo_db_location" VALUES(7212,NULL,'Islip Terrace, NY',2837,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7213,NULL,'Islip Terrace, NY 11752',2837,222,NULL,32,4083,0);
INSERT INTO "django_geo_db_location" VALUES(7214,NULL,'Jericho, NY',2838,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7215,NULL,'Jericho, NY 11753',2838,222,NULL,32,4084,0);
INSERT INTO "django_geo_db_location" VALUES(7216,NULL,'Kings Park, NY',2839,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7217,NULL,'Kings Park, NY 11754',2839,222,NULL,32,4085,0);
INSERT INTO "django_geo_db_location" VALUES(7218,NULL,'Lake Grove, NY',2840,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7219,NULL,'Lake Grove, NY 11755',2840,222,NULL,32,4086,0);
INSERT INTO "django_geo_db_location" VALUES(7220,NULL,'Levittown, NY',2841,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7221,NULL,'Levittown, NY 11756',2841,222,NULL,32,4087,0);
INSERT INTO "django_geo_db_location" VALUES(7222,NULL,'Lindenhurst, NY',2842,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7223,NULL,'Lindenhurst, NY 11757',2842,222,NULL,32,4088,0);
INSERT INTO "django_geo_db_location" VALUES(7224,NULL,'Massapequa, NY',2843,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7225,NULL,'Massapequa, NY 11758',2843,222,NULL,32,4089,0);
INSERT INTO "django_geo_db_location" VALUES(7226,NULL,'Hauppauge, NY',2844,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7227,NULL,'Hauppauge, NY 11760',2844,222,NULL,32,4090,0);
INSERT INTO "django_geo_db_location" VALUES(7228,NULL,'Massapequa Park, NY',2845,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7229,NULL,'Massapequa Park, NY 11762',2845,222,NULL,32,4091,0);
INSERT INTO "django_geo_db_location" VALUES(7230,NULL,'Medford, NY',2846,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7231,NULL,'Medford, NY 11763',2846,222,NULL,32,4092,0);
INSERT INTO "django_geo_db_location" VALUES(7232,NULL,'Miller Place, NY',2847,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7233,NULL,'Miller Place, NY 11764',2847,222,NULL,32,4093,0);
INSERT INTO "django_geo_db_location" VALUES(7234,NULL,'Mill Neck, NY',2848,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7235,NULL,'Mill Neck, NY 11765',2848,222,NULL,32,4094,0);
INSERT INTO "django_geo_db_location" VALUES(7236,NULL,'Mount Sinai, NY',2849,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7237,NULL,'Mount Sinai, NY 11766',2849,222,NULL,32,4095,0);
INSERT INTO "django_geo_db_location" VALUES(7238,NULL,'Nesconset, NY',2850,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7239,NULL,'Nesconset, NY 11767',2850,222,NULL,32,4096,0);
INSERT INTO "django_geo_db_location" VALUES(7240,NULL,'Northport, NY',2851,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7241,NULL,'Northport, NY 11768',2851,222,NULL,32,4097,0);
INSERT INTO "django_geo_db_location" VALUES(7242,NULL,'Oakdale, NY',2852,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7243,NULL,'Oakdale, NY 11769',2852,222,NULL,32,4098,0);
INSERT INTO "django_geo_db_location" VALUES(7244,NULL,'Ocean Beach, NY',2853,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7245,NULL,'Ocean Beach, NY 11770',2853,222,NULL,32,4099,0);
INSERT INTO "django_geo_db_location" VALUES(7246,NULL,'Oyster Bay, NY',2854,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7247,NULL,'Oyster Bay, NY 11771',2854,222,NULL,32,4100,0);
INSERT INTO "django_geo_db_location" VALUES(7248,NULL,'Patchogue, NY',2855,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7249,NULL,'Patchogue, NY 11772',2855,222,NULL,32,4101,0);
INSERT INTO "django_geo_db_location" VALUES(7250,NULL,'Syosset, NY',2856,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7251,NULL,'Syosset, NY 11773',2856,222,NULL,32,4102,0);
INSERT INTO "django_geo_db_location" VALUES(7252,NULL,'Farmingdale, NY 11774',2826,222,NULL,32,4103,0);
INSERT INTO "django_geo_db_location" VALUES(7253,NULL,'Melville, NY 11775',2834,222,NULL,32,4104,0);
INSERT INTO "django_geo_db_location" VALUES(7254,NULL,'Port Jefferson Station, NY',2857,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7255,NULL,'Port Jefferson Station, NY 11776',2857,222,NULL,32,4105,0);
INSERT INTO "django_geo_db_location" VALUES(7256,NULL,'Port Jefferson, NY',2858,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7257,NULL,'Port Jefferson, NY 11777',2858,222,NULL,32,4106,0);
INSERT INTO "django_geo_db_location" VALUES(7258,NULL,'Rocky Point, NY',2859,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7259,NULL,'Rocky Point, NY 11778',2859,222,NULL,32,4107,0);
INSERT INTO "django_geo_db_location" VALUES(7260,NULL,'Ronkonkoma, NY',2860,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7261,NULL,'Ronkonkoma, NY 11779',2860,222,NULL,32,4108,0);
INSERT INTO "django_geo_db_location" VALUES(7262,NULL,'Saint James, NY',2861,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7263,NULL,'Saint James, NY 11780',2861,222,NULL,32,4109,0);
INSERT INTO "django_geo_db_location" VALUES(7264,NULL,'Sayville, NY',2862,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7265,NULL,'Sayville, NY 11782',2862,222,NULL,32,4110,0);
INSERT INTO "django_geo_db_location" VALUES(7266,NULL,'Seaford, NY',2863,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7267,NULL,'Seaford, NY 11783',2863,222,NULL,32,4111,0);
INSERT INTO "django_geo_db_location" VALUES(7268,NULL,'Selden, NY',2864,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7269,NULL,'Selden, NY 11784',2864,222,NULL,32,4112,0);
INSERT INTO "django_geo_db_location" VALUES(7270,NULL,'Shoreham, NY',2865,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7271,NULL,'Shoreham, NY 11786',2865,222,NULL,32,4113,0);
INSERT INTO "django_geo_db_location" VALUES(7272,NULL,'Smithtown, NY 11787',2832,222,NULL,32,4114,0);
INSERT INTO "django_geo_db_location" VALUES(7273,NULL,'Hauppauge, NY 11788',2844,222,NULL,32,4115,0);
INSERT INTO "django_geo_db_location" VALUES(7274,NULL,'Sound Beach, NY',2866,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7275,NULL,'Sound Beach, NY 11789',2866,222,NULL,32,4116,0);
INSERT INTO "django_geo_db_location" VALUES(7276,NULL,'Stony Brook, NY',2867,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7277,NULL,'Stony Brook, NY 11790',2867,222,NULL,32,4117,0);
INSERT INTO "django_geo_db_location" VALUES(7278,NULL,'Syosset, NY 11791',2856,222,NULL,32,4118,0);
INSERT INTO "django_geo_db_location" VALUES(7279,NULL,'Wading River, NY',2868,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7280,NULL,'Wading River, NY 11792',2868,222,NULL,32,4119,0);
INSERT INTO "django_geo_db_location" VALUES(7281,NULL,'Wantagh, NY',2869,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7282,NULL,'Wantagh, NY 11793',2869,222,NULL,32,4120,0);
INSERT INTO "django_geo_db_location" VALUES(7283,NULL,'Stony Brook, NY 11794',2867,222,NULL,32,4121,0);
INSERT INTO "django_geo_db_location" VALUES(7284,NULL,'West Islip, NY',2870,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7285,NULL,'West Islip, NY 11795',2870,222,NULL,32,4122,0);
INSERT INTO "django_geo_db_location" VALUES(7286,NULL,'West Sayville, NY',2871,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7287,NULL,'West Sayville, NY 11796',2871,222,NULL,32,4123,0);
INSERT INTO "django_geo_db_location" VALUES(7288,NULL,'Woodbury, NY 11797',2645,222,NULL,32,4124,0);
INSERT INTO "django_geo_db_location" VALUES(7289,NULL,'Wyandanch, NY',2872,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7290,NULL,'Wyandanch, NY 11798',2872,222,NULL,32,4125,0);
INSERT INTO "django_geo_db_location" VALUES(7291,NULL,'Hicksville, NY',2873,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7292,NULL,'Hicksville, NY 11801',2873,222,NULL,32,4126,0);
INSERT INTO "django_geo_db_location" VALUES(7293,NULL,'Hicksville, NY 11802',2873,222,NULL,32,4127,0);
INSERT INTO "django_geo_db_location" VALUES(7294,NULL,'Plainview, NY',2874,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7295,NULL,'Plainview, NY 11803',2874,222,NULL,32,4128,0);
INSERT INTO "django_geo_db_location" VALUES(7296,NULL,'Old Bethpage, NY',2875,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7297,NULL,'Old Bethpage, NY 11804',2875,222,NULL,32,4129,0);
INSERT INTO "django_geo_db_location" VALUES(7298,NULL,'Mid Island, NY',2876,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7299,NULL,'Mid Island, NY 11805',2876,222,NULL,32,4130,0);
INSERT INTO "django_geo_db_location" VALUES(7300,NULL,'Hicksville, NY 11815',2873,222,NULL,32,4131,0);
INSERT INTO "django_geo_db_location" VALUES(7301,NULL,'Hicksville, NY 11819',2873,222,NULL,32,4132,0);
INSERT INTO "django_geo_db_location" VALUES(7302,NULL,'Jericho, NY 11853',2838,222,NULL,32,4133,0);
INSERT INTO "django_geo_db_location" VALUES(7303,NULL,'Hicksville, NY 11854',2873,222,NULL,32,4134,0);
INSERT INTO "django_geo_db_location" VALUES(7304,NULL,'Hicksville, NY 11855',2873,222,NULL,32,4135,0);
INSERT INTO "django_geo_db_location" VALUES(7305,NULL,'Riverhead, NY',2877,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7306,NULL,'Riverhead, NY 11901',2877,222,NULL,32,4136,0);
INSERT INTO "django_geo_db_location" VALUES(7307,NULL,'Amagansett, NY',2878,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7308,NULL,'Amagansett, NY 11930',2878,222,NULL,32,4137,0);
INSERT INTO "django_geo_db_location" VALUES(7309,NULL,'Aquebogue, NY',2879,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7310,NULL,'Aquebogue, NY 11931',2879,222,NULL,32,4138,0);
INSERT INTO "django_geo_db_location" VALUES(7311,NULL,'Bridgehampton, NY',2880,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7312,NULL,'Bridgehampton, NY 11932',2880,222,NULL,32,4139,0);
INSERT INTO "django_geo_db_location" VALUES(7313,NULL,'Calverton, NY',2881,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7314,NULL,'Calverton, NY 11933',2881,222,NULL,32,4140,0);
INSERT INTO "django_geo_db_location" VALUES(7315,NULL,'Center Moriches, NY',2882,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7316,NULL,'Center Moriches, NY 11934',2882,222,NULL,32,4141,0);
INSERT INTO "django_geo_db_location" VALUES(7317,NULL,'Cutchogue, NY',2883,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7318,NULL,'Cutchogue, NY 11935',2883,222,NULL,32,4142,0);
INSERT INTO "django_geo_db_location" VALUES(7319,NULL,'East Hampton, NY',2884,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7320,NULL,'East Hampton, NY 11937',2884,222,NULL,32,4143,0);
INSERT INTO "django_geo_db_location" VALUES(7321,NULL,'East Marion, NY',2885,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7322,NULL,'East Marion, NY 11939',2885,222,NULL,32,4144,0);
INSERT INTO "django_geo_db_location" VALUES(7323,NULL,'East Moriches, NY',2886,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7324,NULL,'East Moriches, NY 11940',2886,222,NULL,32,4145,0);
INSERT INTO "django_geo_db_location" VALUES(7325,NULL,'Eastport, NY',2887,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7326,NULL,'Eastport, NY 11941',2887,222,NULL,32,4146,0);
INSERT INTO "django_geo_db_location" VALUES(7327,NULL,'East Quogue, NY',2888,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7328,NULL,'East Quogue, NY 11942',2888,222,NULL,32,4147,0);
INSERT INTO "django_geo_db_location" VALUES(7329,NULL,'Greenport, NY',2889,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7330,NULL,'Greenport, NY 11944',2889,222,NULL,32,4148,0);
INSERT INTO "django_geo_db_location" VALUES(7331,NULL,'Hampton Bays, NY',2890,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7332,NULL,'Hampton Bays, NY 11946',2890,222,NULL,32,4149,0);
INSERT INTO "django_geo_db_location" VALUES(7333,NULL,'Jamesport, NY',2891,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7334,NULL,'Jamesport, NY 11947',2891,222,NULL,32,4150,0);
INSERT INTO "django_geo_db_location" VALUES(7335,NULL,'Laurel, NY',2892,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7336,NULL,'Laurel, NY 11948',2892,222,NULL,32,4151,0);
INSERT INTO "django_geo_db_location" VALUES(7337,NULL,'Manorville, NY',2893,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7338,NULL,'Manorville, NY 11949',2893,222,NULL,32,4152,0);
INSERT INTO "django_geo_db_location" VALUES(7339,NULL,'Mastic, NY',2894,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7340,NULL,'Mastic, NY 11950',2894,222,NULL,32,4153,0);
INSERT INTO "django_geo_db_location" VALUES(7341,NULL,'Mastic Beach, NY',2895,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7342,NULL,'Mastic Beach, NY 11951',2895,222,NULL,32,4154,0);
INSERT INTO "django_geo_db_location" VALUES(7343,NULL,'Mattituck, NY',2896,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7344,NULL,'Mattituck, NY 11952',2896,222,NULL,32,4155,0);
INSERT INTO "django_geo_db_location" VALUES(7345,NULL,'Middle Island, NY',2897,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7346,NULL,'Middle Island, NY 11953',2897,222,NULL,32,4156,0);
INSERT INTO "django_geo_db_location" VALUES(7347,NULL,'Montauk, NY',2898,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7348,NULL,'Montauk, NY 11954',2898,222,NULL,32,4157,0);
INSERT INTO "django_geo_db_location" VALUES(7349,NULL,'Moriches, NY',2899,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7350,NULL,'Moriches, NY 11955',2899,222,NULL,32,4158,0);
INSERT INTO "django_geo_db_location" VALUES(7351,NULL,'New Suffolk, NY',2900,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7352,NULL,'New Suffolk, NY 11956',2900,222,NULL,32,4159,0);
INSERT INTO "django_geo_db_location" VALUES(7353,NULL,'Orient, NY',2901,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7354,NULL,'Orient, NY 11957',2901,222,NULL,32,4160,0);
INSERT INTO "django_geo_db_location" VALUES(7355,NULL,'Peconic, NY',2902,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7356,NULL,'Peconic, NY 11958',2902,222,NULL,32,4161,0);
INSERT INTO "django_geo_db_location" VALUES(7357,NULL,'Quogue, NY',2903,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7358,NULL,'Quogue, NY 11959',2903,222,NULL,32,4162,0);
INSERT INTO "django_geo_db_location" VALUES(7359,NULL,'Remsenburg, NY',2904,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7360,NULL,'Remsenburg, NY 11960',2904,222,NULL,32,4163,0);
INSERT INTO "django_geo_db_location" VALUES(7361,NULL,'Ridge, NY',2905,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7362,NULL,'Ridge, NY 11961',2905,222,NULL,32,4164,0);
INSERT INTO "django_geo_db_location" VALUES(7363,NULL,'Sagaponack, NY',2906,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7364,NULL,'Sagaponack, NY 11962',2906,222,NULL,32,4165,0);
INSERT INTO "django_geo_db_location" VALUES(7365,NULL,'Sag Harbor, NY',2907,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7366,NULL,'Sag Harbor, NY 11963',2907,222,NULL,32,4166,0);
INSERT INTO "django_geo_db_location" VALUES(7367,NULL,'Shelter Island, NY',2908,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7368,NULL,'Shelter Island, NY 11964',2908,222,NULL,32,4167,0);
INSERT INTO "django_geo_db_location" VALUES(7369,NULL,'Shelter Island Heights, NY',2909,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7370,NULL,'Shelter Island Heights, NY 11965',2909,222,NULL,32,4168,0);
INSERT INTO "django_geo_db_location" VALUES(7371,NULL,'Shirley, NY',2910,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7372,NULL,'Shirley, NY 11967',2910,222,NULL,32,4169,0);
INSERT INTO "django_geo_db_location" VALUES(7373,NULL,'Southampton, NY',2911,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7374,NULL,'Southampton, NY 11968',2911,222,NULL,32,4170,0);
INSERT INTO "django_geo_db_location" VALUES(7375,NULL,'Southampton, NY 11969',2911,222,NULL,32,4171,0);
INSERT INTO "django_geo_db_location" VALUES(7376,NULL,'South Jamesport, NY',2912,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7377,NULL,'South Jamesport, NY 11970',2912,222,NULL,32,4172,0);
INSERT INTO "django_geo_db_location" VALUES(7378,NULL,'Southold, NY',2913,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7379,NULL,'Southold, NY 11971',2913,222,NULL,32,4173,0);
INSERT INTO "django_geo_db_location" VALUES(7380,NULL,'Speonk, NY',2914,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7381,NULL,'Speonk, NY 11972',2914,222,NULL,32,4174,0);
INSERT INTO "django_geo_db_location" VALUES(7382,NULL,'Upton, NY',2915,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7383,NULL,'Upton, NY 11973',2915,222,NULL,32,4175,0);
INSERT INTO "django_geo_db_location" VALUES(7384,NULL,'Wainscott, NY',2916,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7385,NULL,'Wainscott, NY 11975',2916,222,NULL,32,4176,0);
INSERT INTO "django_geo_db_location" VALUES(7386,NULL,'Water Mill, NY',2917,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7387,NULL,'Water Mill, NY 11976',2917,222,NULL,32,4177,0);
INSERT INTO "django_geo_db_location" VALUES(7388,NULL,'Westhampton, NY',2918,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7389,NULL,'Westhampton, NY 11977',2918,222,NULL,32,4178,0);
INSERT INTO "django_geo_db_location" VALUES(7390,NULL,'Westhampton Beach, NY',2919,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7391,NULL,'Westhampton Beach, NY 11978',2919,222,NULL,32,4179,0);
INSERT INTO "django_geo_db_location" VALUES(7392,NULL,'Yaphank, NY',2920,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7393,NULL,'Yaphank, NY 11980',2920,222,NULL,32,4180,0);
INSERT INTO "django_geo_db_location" VALUES(7394,NULL,'Alcove, NY',2921,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7395,NULL,'Alcove, NY 12007',2921,222,NULL,32,4181,0);
INSERT INTO "django_geo_db_location" VALUES(7396,NULL,'Alplaus, NY',2922,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7397,NULL,'Alplaus, NY 12008',2922,222,NULL,32,4182,0);
INSERT INTO "django_geo_db_location" VALUES(7398,NULL,'Altamont, NY',2923,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7399,NULL,'Altamont, NY 12009',2923,222,NULL,32,4183,0);
INSERT INTO "django_geo_db_location" VALUES(7400,NULL,'Amsterdam, NY',2924,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7401,NULL,'Amsterdam, NY 12010',2924,222,NULL,32,4184,0);
INSERT INTO "django_geo_db_location" VALUES(7402,NULL,'Athens, NY',2925,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7403,NULL,'Athens, NY 12015',2925,222,NULL,32,4185,0);
INSERT INTO "django_geo_db_location" VALUES(7404,NULL,'Auriesville, NY',2926,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7405,NULL,'Auriesville, NY 12016',2926,222,NULL,32,4186,0);
INSERT INTO "django_geo_db_location" VALUES(7406,NULL,'Austerlitz, NY',2927,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7407,NULL,'Austerlitz, NY 12017',2927,222,NULL,32,4187,0);
INSERT INTO "django_geo_db_location" VALUES(7408,NULL,'Averill Park, NY',2928,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7409,NULL,'Averill Park, NY 12018',2928,222,NULL,32,4188,0);
INSERT INTO "django_geo_db_location" VALUES(7410,NULL,'Ballston Lake, NY',2929,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7411,NULL,'Ballston Lake, NY 12019',2929,222,NULL,32,4189,0);
INSERT INTO "django_geo_db_location" VALUES(7412,NULL,'Ballston Spa, NY',2930,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7413,NULL,'Ballston Spa, NY 12020',2930,222,NULL,32,4190,0);
INSERT INTO "django_geo_db_location" VALUES(7414,NULL,'Berlin, NY',2931,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7415,NULL,'Berlin, NY 12022',2931,222,NULL,32,4191,0);
INSERT INTO "django_geo_db_location" VALUES(7416,NULL,'Berne, NY',2932,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7417,NULL,'Berne, NY 12023',2932,222,NULL,32,4192,0);
INSERT INTO "django_geo_db_location" VALUES(7418,NULL,'Brainard, NY',2933,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7419,NULL,'Brainard, NY 12024',2933,222,NULL,32,4193,0);
INSERT INTO "django_geo_db_location" VALUES(7420,NULL,'Broadalbin, NY',2934,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7421,NULL,'Broadalbin, NY 12025',2934,222,NULL,32,4194,0);
INSERT INTO "django_geo_db_location" VALUES(7422,NULL,'Burnt Hills, NY',2935,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7423,NULL,'Burnt Hills, NY 12027',2935,222,NULL,32,4195,0);
INSERT INTO "django_geo_db_location" VALUES(7424,NULL,'Buskirk, NY',2936,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7425,NULL,'Buskirk, NY 12028',2936,222,NULL,32,4196,0);
INSERT INTO "django_geo_db_location" VALUES(7426,NULL,'Canaan, NY',2937,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7427,NULL,'Canaan, NY 12029',2937,222,NULL,32,4197,0);
INSERT INTO "django_geo_db_location" VALUES(7428,NULL,'Carlisle, NY',2938,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7429,NULL,'Carlisle, NY 12031',2938,222,NULL,32,4198,0);
INSERT INTO "django_geo_db_location" VALUES(7430,NULL,'Caroga Lake, NY',2939,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7431,NULL,'Caroga Lake, NY 12032',2939,222,NULL,32,4199,0);
INSERT INTO "django_geo_db_location" VALUES(7432,NULL,'Castleton On Hudson, NY',2940,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7433,NULL,'Castleton On Hudson, NY 12033',2940,222,NULL,32,4200,0);
INSERT INTO "django_geo_db_location" VALUES(7434,NULL,'Central Bridge, NY',2941,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7435,NULL,'Central Bridge, NY 12035',2941,222,NULL,32,4201,0);
INSERT INTO "django_geo_db_location" VALUES(7436,NULL,'Charlotteville, NY',2942,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7437,NULL,'Charlotteville, NY 12036',2942,222,NULL,32,4202,0);
INSERT INTO "django_geo_db_location" VALUES(7438,NULL,'Chatham, NY',2943,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7439,NULL,'Chatham, NY 12037',2943,222,NULL,32,4203,0);
INSERT INTO "django_geo_db_location" VALUES(7440,NULL,'Cherry Plain, NY',2944,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7441,NULL,'Cherry Plain, NY 12040',2944,222,NULL,32,4204,0);
INSERT INTO "django_geo_db_location" VALUES(7442,NULL,'Clarksville, NY',2945,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7443,NULL,'Clarksville, NY 12041',2945,222,NULL,32,4205,0);
INSERT INTO "django_geo_db_location" VALUES(7444,NULL,'Climax, NY',2946,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7445,NULL,'Climax, NY 12042',2946,222,NULL,32,4206,0);
INSERT INTO "django_geo_db_location" VALUES(7446,NULL,'Cobleskill, NY',2947,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7447,NULL,'Cobleskill, NY 12043',2947,222,NULL,32,4207,0);
INSERT INTO "django_geo_db_location" VALUES(7448,NULL,'Coeymans, NY',2948,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7449,NULL,'Coeymans, NY 12045',2948,222,NULL,32,4208,0);
INSERT INTO "django_geo_db_location" VALUES(7450,NULL,'Coeymans Hollow, NY',2949,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7451,NULL,'Coeymans Hollow, NY 12046',2949,222,NULL,32,4209,0);
INSERT INTO "django_geo_db_location" VALUES(7452,NULL,'Cohoes, NY',2950,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7453,NULL,'Cohoes, NY 12047',2950,222,NULL,32,4210,0);
INSERT INTO "django_geo_db_location" VALUES(7454,NULL,'Columbiaville, NY',2951,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7455,NULL,'Columbiaville, NY 12050',2951,222,NULL,32,4211,0);
INSERT INTO "django_geo_db_location" VALUES(7456,NULL,'Coxsackie, NY',2952,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7457,NULL,'Coxsackie, NY 12051',2952,222,NULL,32,4212,0);
INSERT INTO "django_geo_db_location" VALUES(7458,NULL,'Cropseyville, NY',2953,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7459,NULL,'Cropseyville, NY 12052',2953,222,NULL,32,4213,0);
INSERT INTO "django_geo_db_location" VALUES(7460,NULL,'Delanson, NY',2954,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7461,NULL,'Delanson, NY 12053',2954,222,NULL,32,4214,0);
INSERT INTO "django_geo_db_location" VALUES(7462,NULL,'Delmar, NY',2955,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7463,NULL,'Delmar, NY 12054',2955,222,NULL,32,4215,0);
INSERT INTO "django_geo_db_location" VALUES(7464,NULL,'Dormansville, NY',2956,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7465,NULL,'Dormansville, NY 12055',2956,222,NULL,32,4216,0);
INSERT INTO "django_geo_db_location" VALUES(7466,NULL,'Duanesburg, NY',2957,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7467,NULL,'Duanesburg, NY 12056',2957,222,NULL,32,4217,0);
INSERT INTO "django_geo_db_location" VALUES(7468,NULL,'Eagle Bridge, NY',2958,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7469,NULL,'Eagle Bridge, NY 12057',2958,222,NULL,32,4218,0);
INSERT INTO "django_geo_db_location" VALUES(7470,NULL,'Earlton, NY',2959,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7471,NULL,'Earlton, NY 12058',2959,222,NULL,32,4219,0);
INSERT INTO "django_geo_db_location" VALUES(7472,NULL,'East Berne, NY',2960,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7473,NULL,'East Berne, NY 12059',2960,222,NULL,32,4220,0);
INSERT INTO "django_geo_db_location" VALUES(7474,NULL,'East Chatham, NY',2961,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7475,NULL,'East Chatham, NY 12060',2961,222,NULL,32,4221,0);
INSERT INTO "django_geo_db_location" VALUES(7476,NULL,'East Greenbush, NY',2962,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7477,NULL,'East Greenbush, NY 12061',2962,222,NULL,32,4222,0);
INSERT INTO "django_geo_db_location" VALUES(7478,NULL,'East Nassau, NY',2963,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7479,NULL,'East Nassau, NY 12062',2963,222,NULL,32,4223,0);
INSERT INTO "django_geo_db_location" VALUES(7480,NULL,'East Schodack, NY',2964,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7481,NULL,'East Schodack, NY 12063',2964,222,NULL,32,4224,0);
INSERT INTO "django_geo_db_location" VALUES(7482,NULL,'East Worcester, NY',2965,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7483,NULL,'East Worcester, NY 12064',2965,222,NULL,32,4225,0);
INSERT INTO "django_geo_db_location" VALUES(7484,NULL,'Clifton Park, NY',2966,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7485,NULL,'Clifton Park, NY 12065',2966,222,NULL,32,4226,0);
INSERT INTO "django_geo_db_location" VALUES(7486,NULL,'Esperance, NY',2967,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7487,NULL,'Esperance, NY 12066',2967,222,NULL,32,4227,0);
INSERT INTO "django_geo_db_location" VALUES(7488,NULL,'Feura Bush, NY',2968,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7489,NULL,'Feura Bush, NY 12067',2968,222,NULL,32,4228,0);
INSERT INTO "django_geo_db_location" VALUES(7490,NULL,'Fonda, NY',2969,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7491,NULL,'Fonda, NY 12068',2969,222,NULL,32,4229,0);
INSERT INTO "django_geo_db_location" VALUES(7492,NULL,'Fort Hunter, NY',2970,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7493,NULL,'Fort Hunter, NY 12069',2970,222,NULL,32,4230,0);
INSERT INTO "django_geo_db_location" VALUES(7494,NULL,'Fort Johnson, NY',2971,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7495,NULL,'Fort Johnson, NY 12070',2971,222,NULL,32,4231,0);
INSERT INTO "django_geo_db_location" VALUES(7496,NULL,'Fultonham, NY',2972,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7497,NULL,'Fultonham, NY 12071',2972,222,NULL,32,4232,0);
INSERT INTO "django_geo_db_location" VALUES(7498,NULL,'Fultonville, NY',2973,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7499,NULL,'Fultonville, NY 12072',2973,222,NULL,32,4233,0);
INSERT INTO "django_geo_db_location" VALUES(7500,NULL,'Gallupville, NY',2974,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7501,NULL,'Gallupville, NY 12073',2974,222,NULL,32,4234,0);
INSERT INTO "django_geo_db_location" VALUES(7502,NULL,'Galway, NY',2975,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7503,NULL,'Galway, NY 12074',2975,222,NULL,32,4235,0);
INSERT INTO "django_geo_db_location" VALUES(7504,NULL,'Ghent, NY',2976,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7505,NULL,'Ghent, NY 12075',2976,222,NULL,32,4236,0);
INSERT INTO "django_geo_db_location" VALUES(7506,NULL,'Gilboa, NY',2977,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7507,NULL,'Gilboa, NY 12076',2977,222,NULL,32,4237,0);
INSERT INTO "django_geo_db_location" VALUES(7508,NULL,'Glenmont, NY',2978,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7509,NULL,'Glenmont, NY 12077',2978,222,NULL,32,4238,0);
INSERT INTO "django_geo_db_location" VALUES(7510,NULL,'Gloversville, NY',2979,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7511,NULL,'Gloversville, NY 12078',2979,222,NULL,32,4239,0);
INSERT INTO "django_geo_db_location" VALUES(7512,NULL,'Nassau, NY',2980,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7513,NULL,'Nassau, NY 12081',2980,222,NULL,32,4240,0);
INSERT INTO "django_geo_db_location" VALUES(7514,NULL,'Grafton, NY',2981,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7515,NULL,'Grafton, NY 12082',2981,222,NULL,32,4241,0);
INSERT INTO "django_geo_db_location" VALUES(7516,NULL,'Greenville, NY 12083',2627,222,NULL,32,4242,0);
INSERT INTO "django_geo_db_location" VALUES(7517,NULL,'Guilderland, NY',2982,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7518,NULL,'Guilderland, NY 12084',2982,222,NULL,32,4243,0);
INSERT INTO "django_geo_db_location" VALUES(7519,NULL,'Guilderland Center, NY',2983,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7520,NULL,'Guilderland Center, NY 12085',2983,222,NULL,32,4244,0);
INSERT INTO "django_geo_db_location" VALUES(7521,NULL,'Hagaman, NY',2984,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7522,NULL,'Hagaman, NY 12086',2984,222,NULL,32,4245,0);
INSERT INTO "django_geo_db_location" VALUES(7523,NULL,'Hannacroix, NY',2985,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7524,NULL,'Hannacroix, NY 12087',2985,222,NULL,32,4246,0);
INSERT INTO "django_geo_db_location" VALUES(7525,NULL,'Hoosick, NY',2986,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7526,NULL,'Hoosick, NY 12089',2986,222,NULL,32,4247,0);
INSERT INTO "django_geo_db_location" VALUES(7527,NULL,'Hoosick Falls, NY',2987,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7528,NULL,'Hoosick Falls, NY 12090',2987,222,NULL,32,4248,0);
INSERT INTO "django_geo_db_location" VALUES(7529,NULL,'Howes Cave, NY',2988,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7530,NULL,'Howes Cave, NY 12092',2988,222,NULL,32,4249,0);
INSERT INTO "django_geo_db_location" VALUES(7531,NULL,'Jefferson, NY',2989,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7532,NULL,'Jefferson, NY 12093',2989,222,NULL,32,4250,0);
INSERT INTO "django_geo_db_location" VALUES(7533,NULL,'Johnsonville, NY',2990,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7534,NULL,'Johnsonville, NY 12094',2990,222,NULL,32,4251,0);
INSERT INTO "django_geo_db_location" VALUES(7535,NULL,'Johnstown, NY',2991,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7536,NULL,'Johnstown, NY 12095',2991,222,NULL,32,4252,0);
INSERT INTO "django_geo_db_location" VALUES(7537,NULL,'Knox, NY',2992,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7538,NULL,'Knox, NY 12103',2992,222,NULL,32,4253,0);
INSERT INTO "django_geo_db_location" VALUES(7539,NULL,'Kinderhook, NY',2993,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7540,NULL,'Kinderhook, NY 12106',2993,222,NULL,32,4254,0);
INSERT INTO "django_geo_db_location" VALUES(7541,NULL,'Knox, NY 12107',2992,222,NULL,32,4255,0);
INSERT INTO "django_geo_db_location" VALUES(7542,NULL,'Lake Pleasant, NY',2994,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7543,NULL,'Lake Pleasant, NY 12108',2994,222,NULL,32,4256,0);
INSERT INTO "django_geo_db_location" VALUES(7544,NULL,'Latham, NY',2995,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7545,NULL,'Latham, NY 12110',2995,222,NULL,32,4257,0);
INSERT INTO "django_geo_db_location" VALUES(7546,NULL,'Latham, NY 12111',2995,222,NULL,32,4258,0);
INSERT INTO "django_geo_db_location" VALUES(7547,NULL,'Malden Bridge, NY',2996,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7548,NULL,'Malden Bridge, NY 12115',2996,222,NULL,32,4259,0);
INSERT INTO "django_geo_db_location" VALUES(7549,NULL,'Maryland, NY',2997,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7550,NULL,'Maryland, NY 12116',2997,222,NULL,32,4260,0);
INSERT INTO "django_geo_db_location" VALUES(7551,NULL,'Mayfield, NY',2998,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7552,NULL,'Mayfield, NY 12117',2998,222,NULL,32,4261,0);
INSERT INTO "django_geo_db_location" VALUES(7553,NULL,'Mechanicville, NY',2999,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7554,NULL,'Mechanicville, NY 12118',2999,222,NULL,32,4262,0);
INSERT INTO "django_geo_db_location" VALUES(7555,NULL,'Medusa, NY',3000,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7556,NULL,'Medusa, NY 12120',3000,222,NULL,32,4263,0);
INSERT INTO "django_geo_db_location" VALUES(7557,NULL,'Melrose, NY',3001,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7558,NULL,'Melrose, NY 12121',3001,222,NULL,32,4264,0);
INSERT INTO "django_geo_db_location" VALUES(7559,NULL,'Middleburgh, NY',3002,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7560,NULL,'Middleburgh, NY 12122',3002,222,NULL,32,4265,0);
INSERT INTO "django_geo_db_location" VALUES(7561,NULL,'Nassau, NY 12123',2980,222,NULL,32,4266,0);
INSERT INTO "django_geo_db_location" VALUES(7562,NULL,'New Baltimore, NY',3003,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7563,NULL,'New Baltimore, NY 12124',3003,222,NULL,32,4267,0);
INSERT INTO "django_geo_db_location" VALUES(7564,NULL,'New Lebanon, NY',3004,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7565,NULL,'New Lebanon, NY 12125',3004,222,NULL,32,4268,0);
INSERT INTO "django_geo_db_location" VALUES(7566,NULL,'Newtonville, NY',3005,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7567,NULL,'Newtonville, NY 12128',3005,222,NULL,32,4269,0);
INSERT INTO "django_geo_db_location" VALUES(7568,NULL,'Niverville, NY',3006,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7569,NULL,'Niverville, NY 12130',3006,222,NULL,32,4270,0);
INSERT INTO "django_geo_db_location" VALUES(7570,NULL,'North Blenheim, NY',3007,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7571,NULL,'North Blenheim, NY 12131',3007,222,NULL,32,4271,0);
INSERT INTO "django_geo_db_location" VALUES(7572,NULL,'North Chatham, NY',3008,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7573,NULL,'North Chatham, NY 12132',3008,222,NULL,32,4272,0);
INSERT INTO "django_geo_db_location" VALUES(7574,NULL,'North Hoosick, NY',3009,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7575,NULL,'North Hoosick, NY 12133',3009,222,NULL,32,4273,0);
INSERT INTO "django_geo_db_location" VALUES(7576,NULL,'Northville, NY',3010,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7577,NULL,'Northville, NY 12134',3010,222,NULL,32,4274,0);
INSERT INTO "django_geo_db_location" VALUES(7578,NULL,'Old Chatham, NY',3011,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7579,NULL,'Old Chatham, NY 12136',3011,222,NULL,32,4275,0);
INSERT INTO "django_geo_db_location" VALUES(7580,NULL,'Pattersonville, NY',3012,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7581,NULL,'Pattersonville, NY 12137',3012,222,NULL,32,4276,0);
INSERT INTO "django_geo_db_location" VALUES(7582,NULL,'Petersburg, NY',3013,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7583,NULL,'Petersburg, NY 12138',3013,222,NULL,32,4277,0);
INSERT INTO "django_geo_db_location" VALUES(7584,NULL,'Piseco, NY',3014,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7585,NULL,'Piseco, NY 12139',3014,222,NULL,32,4278,0);
INSERT INTO "django_geo_db_location" VALUES(7586,NULL,'Poestenkill, NY',3015,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7587,NULL,'Poestenkill, NY 12140',3015,222,NULL,32,4279,0);
INSERT INTO "django_geo_db_location" VALUES(7588,NULL,'Quaker Street, NY',3016,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7589,NULL,'Quaker Street, NY 12141',3016,222,NULL,32,4280,0);
INSERT INTO "django_geo_db_location" VALUES(7590,NULL,'Ravena, NY',3017,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7591,NULL,'Ravena, NY 12143',3017,222,NULL,32,4281,0);
INSERT INTO "django_geo_db_location" VALUES(7592,NULL,'Rensselaer, NY',3018,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7593,NULL,'Rensselaer, NY 12144',3018,222,NULL,32,4282,0);
INSERT INTO "django_geo_db_location" VALUES(7594,NULL,'Rensselaerville, NY',3019,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7595,NULL,'Rensselaerville, NY 12147',3019,222,NULL,32,4283,0);
INSERT INTO "django_geo_db_location" VALUES(7596,NULL,'Rexford, NY',3020,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7597,NULL,'Rexford, NY 12148',3020,222,NULL,32,4284,0);
INSERT INTO "django_geo_db_location" VALUES(7598,NULL,'Richmondville, NY',3021,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7599,NULL,'Richmondville, NY 12149',3021,222,NULL,32,4285,0);
INSERT INTO "django_geo_db_location" VALUES(7600,NULL,'Rotterdam Junction, NY',3022,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7601,NULL,'Rotterdam Junction, NY 12150',3022,222,NULL,32,4286,0);
INSERT INTO "django_geo_db_location" VALUES(7602,NULL,'Round Lake, NY',3023,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7603,NULL,'Round Lake, NY 12151',3023,222,NULL,32,4287,0);
INSERT INTO "django_geo_db_location" VALUES(7604,NULL,'Sand Lake, NY',3024,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7605,NULL,'Sand Lake, NY 12153',3024,222,NULL,32,4288,0);
INSERT INTO "django_geo_db_location" VALUES(7606,NULL,'Schaghticoke, NY',3025,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7607,NULL,'Schaghticoke, NY 12154',3025,222,NULL,32,4289,0);
INSERT INTO "django_geo_db_location" VALUES(7608,NULL,'Schenevus, NY',3026,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7609,NULL,'Schenevus, NY 12155',3026,222,NULL,32,4290,0);
INSERT INTO "django_geo_db_location" VALUES(7610,NULL,'Schodack Landing, NY',3027,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7611,NULL,'Schodack Landing, NY 12156',3027,222,NULL,32,4291,0);
INSERT INTO "django_geo_db_location" VALUES(7612,NULL,'Schoharie, NY',3028,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7613,NULL,'Schoharie, NY 12157',3028,222,NULL,32,4292,0);
INSERT INTO "django_geo_db_location" VALUES(7614,NULL,'Selkirk, NY',3029,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7615,NULL,'Selkirk, NY 12158',3029,222,NULL,32,4293,0);
INSERT INTO "django_geo_db_location" VALUES(7616,NULL,'Slingerlands, NY',3030,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7617,NULL,'Slingerlands, NY 12159',3030,222,NULL,32,4294,0);
INSERT INTO "django_geo_db_location" VALUES(7618,NULL,'Sloansville, NY',3031,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7619,NULL,'Sloansville, NY 12160',3031,222,NULL,32,4295,0);
INSERT INTO "django_geo_db_location" VALUES(7620,NULL,'South Bethlehem, NY',3032,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7621,NULL,'South Bethlehem, NY 12161',3032,222,NULL,32,4296,0);
INSERT INTO "django_geo_db_location" VALUES(7622,NULL,'South Schodack, NY',3033,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7623,NULL,'South Schodack, NY 12162',3033,222,NULL,32,4297,0);
INSERT INTO "django_geo_db_location" VALUES(7624,NULL,'Speculator, NY',3034,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7625,NULL,'Speculator, NY 12164',3034,222,NULL,32,4298,0);
INSERT INTO "django_geo_db_location" VALUES(7626,NULL,'Spencertown, NY',3035,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7627,NULL,'Spencertown, NY 12165',3035,222,NULL,32,4299,0);
INSERT INTO "django_geo_db_location" VALUES(7628,NULL,'Sprakers, NY',3036,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7629,NULL,'Sprakers, NY 12166',3036,222,NULL,32,4300,0);
INSERT INTO "django_geo_db_location" VALUES(7630,NULL,'Stamford, NY',3037,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7631,NULL,'Stamford, NY 12167',3037,222,NULL,32,4301,0);
INSERT INTO "django_geo_db_location" VALUES(7632,NULL,'Stephentown, NY',3038,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7633,NULL,'Stephentown, NY 12168',3038,222,NULL,32,4302,0);
INSERT INTO "django_geo_db_location" VALUES(7634,NULL,'Stephentown, NY 12169',3038,222,NULL,32,4303,0);
INSERT INTO "django_geo_db_location" VALUES(7635,NULL,'Stillwater, NY',3039,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7636,NULL,'Stillwater, NY 12170',3039,222,NULL,32,4304,0);
INSERT INTO "django_geo_db_location" VALUES(7637,NULL,'Stottville, NY',3040,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7638,NULL,'Stottville, NY 12172',3040,222,NULL,32,4305,0);
INSERT INTO "django_geo_db_location" VALUES(7639,NULL,'Stuyvesant, NY',3041,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7640,NULL,'Stuyvesant, NY 12173',3041,222,NULL,32,4306,0);
INSERT INTO "django_geo_db_location" VALUES(7641,NULL,'Stuyvesant Falls, NY',3042,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7642,NULL,'Stuyvesant Falls, NY 12174',3042,222,NULL,32,4307,0);
INSERT INTO "django_geo_db_location" VALUES(7643,NULL,'Summit, NY',3043,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7644,NULL,'Summit, NY 12175',3043,222,NULL,32,4308,0);
INSERT INTO "django_geo_db_location" VALUES(7645,NULL,'Surprise, NY',3044,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7646,NULL,'Surprise, NY 12176',3044,222,NULL,32,4309,0);
INSERT INTO "django_geo_db_location" VALUES(7647,NULL,'Tribes Hill, NY',3045,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7648,NULL,'Tribes Hill, NY 12177',3045,222,NULL,32,4310,0);
INSERT INTO "django_geo_db_location" VALUES(7649,NULL,'Troy, NY',3046,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7650,NULL,'Troy, NY 12179',3046,222,NULL,32,4311,0);
INSERT INTO "django_geo_db_location" VALUES(7651,NULL,'Troy, NY 12180',3046,222,NULL,32,4312,0);
INSERT INTO "django_geo_db_location" VALUES(7652,NULL,'Troy, NY 12181',3046,222,NULL,32,4313,0);
INSERT INTO "django_geo_db_location" VALUES(7653,NULL,'Troy, NY 12182',3046,222,NULL,32,4314,0);
INSERT INTO "django_geo_db_location" VALUES(7654,NULL,'Troy, NY 12183',3046,222,NULL,32,4315,0);
INSERT INTO "django_geo_db_location" VALUES(7655,NULL,'Valatie, NY',3047,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7656,NULL,'Valatie, NY 12184',3047,222,NULL,32,4316,0);
INSERT INTO "django_geo_db_location" VALUES(7657,NULL,'Valley Falls, NY',3048,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7658,NULL,'Valley Falls, NY 12185',3048,222,NULL,32,4317,0);
INSERT INTO "django_geo_db_location" VALUES(7659,NULL,'Voorheesville, NY',3049,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7660,NULL,'Voorheesville, NY 12186',3049,222,NULL,32,4318,0);
INSERT INTO "django_geo_db_location" VALUES(7661,NULL,'Warnerville, NY',3050,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7662,NULL,'Warnerville, NY 12187',3050,222,NULL,32,4319,0);
INSERT INTO "django_geo_db_location" VALUES(7663,NULL,'Waterford, NY',3051,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7664,NULL,'Waterford, NY 12188',3051,222,NULL,32,4320,0);
INSERT INTO "django_geo_db_location" VALUES(7665,NULL,'Watervliet, NY',3052,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7666,NULL,'Watervliet, NY 12189',3052,222,NULL,32,4321,0);
INSERT INTO "django_geo_db_location" VALUES(7667,NULL,'Wells, NY',3053,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7668,NULL,'Wells, NY 12190',3053,222,NULL,32,4322,0);
INSERT INTO "django_geo_db_location" VALUES(7669,NULL,'West Coxsackie, NY',3054,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7670,NULL,'West Coxsackie, NY 12192',3054,222,NULL,32,4323,0);
INSERT INTO "django_geo_db_location" VALUES(7671,NULL,'Westerlo, NY',3055,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7672,NULL,'Westerlo, NY 12193',3055,222,NULL,32,4324,0);
INSERT INTO "django_geo_db_location" VALUES(7673,NULL,'West Fulton, NY',3056,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7674,NULL,'West Fulton, NY 12194',3056,222,NULL,32,4325,0);
INSERT INTO "django_geo_db_location" VALUES(7675,NULL,'West Lebanon, NY',3057,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7676,NULL,'West Lebanon, NY 12195',3057,222,NULL,32,4326,0);
INSERT INTO "django_geo_db_location" VALUES(7677,NULL,'West Sand Lake, NY',3058,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7678,NULL,'West Sand Lake, NY 12196',3058,222,NULL,32,4327,0);
INSERT INTO "django_geo_db_location" VALUES(7679,NULL,'Worcester, NY',3059,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7680,NULL,'Worcester, NY 12197',3059,222,NULL,32,4328,0);
INSERT INTO "django_geo_db_location" VALUES(7681,NULL,'Wynantskill, NY',3060,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7682,NULL,'Wynantskill, NY 12198',3060,222,NULL,32,4329,0);
INSERT INTO "django_geo_db_location" VALUES(7683,NULL,'Albany, NY',3061,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7684,NULL,'Albany, NY 12201',3061,222,NULL,32,4330,0);
INSERT INTO "django_geo_db_location" VALUES(7685,NULL,'Albany, NY 12202',3061,222,NULL,32,4331,0);
INSERT INTO "django_geo_db_location" VALUES(7686,NULL,'Albany, NY 12203',3061,222,NULL,32,4332,0);
INSERT INTO "django_geo_db_location" VALUES(7687,NULL,'Albany, NY 12204',3061,222,NULL,32,4333,0);
INSERT INTO "django_geo_db_location" VALUES(7688,NULL,'Albany, NY 12205',3061,222,NULL,32,4334,0);
INSERT INTO "django_geo_db_location" VALUES(7689,NULL,'Albany, NY 12206',3061,222,NULL,32,4335,0);
INSERT INTO "django_geo_db_location" VALUES(7690,NULL,'Albany, NY 12207',3061,222,NULL,32,4336,0);
INSERT INTO "django_geo_db_location" VALUES(7691,NULL,'Albany, NY 12208',3061,222,NULL,32,4337,0);
INSERT INTO "django_geo_db_location" VALUES(7692,NULL,'Albany, NY 12209',3061,222,NULL,32,4338,0);
INSERT INTO "django_geo_db_location" VALUES(7693,NULL,'Albany, NY 12210',3061,222,NULL,32,4339,0);
INSERT INTO "django_geo_db_location" VALUES(7694,NULL,'Albany, NY 12211',3061,222,NULL,32,4340,0);
INSERT INTO "django_geo_db_location" VALUES(7695,NULL,'Albany, NY 12212',3061,222,NULL,32,4341,0);
INSERT INTO "django_geo_db_location" VALUES(7696,NULL,'Albany, NY 12214',3061,222,NULL,32,4342,0);
INSERT INTO "django_geo_db_location" VALUES(7697,NULL,'Albany, NY 12220',3061,222,NULL,32,4343,0);
INSERT INTO "django_geo_db_location" VALUES(7698,NULL,'Albany, NY 12222',3061,222,NULL,32,4344,0);
INSERT INTO "django_geo_db_location" VALUES(7699,NULL,'Albany, NY 12223',3061,222,NULL,32,4345,0);
INSERT INTO "django_geo_db_location" VALUES(7700,NULL,'Albany, NY 12224',3061,222,NULL,32,4346,0);
INSERT INTO "django_geo_db_location" VALUES(7701,NULL,'Albany, NY 12225',3061,222,NULL,32,4347,0);
INSERT INTO "django_geo_db_location" VALUES(7702,NULL,'Albany, NY 12226',3061,222,NULL,32,4348,0);
INSERT INTO "django_geo_db_location" VALUES(7703,NULL,'Albany, NY 12227',3061,222,NULL,32,4349,0);
INSERT INTO "django_geo_db_location" VALUES(7704,NULL,'Albany, NY 12228',3061,222,NULL,32,4350,0);
INSERT INTO "django_geo_db_location" VALUES(7705,NULL,'Albany, NY 12229',3061,222,NULL,32,4351,0);
INSERT INTO "django_geo_db_location" VALUES(7706,NULL,'Albany, NY 12230',3061,222,NULL,32,4352,0);
INSERT INTO "django_geo_db_location" VALUES(7707,NULL,'Albany, NY 12231',3061,222,NULL,32,4353,0);
INSERT INTO "django_geo_db_location" VALUES(7708,NULL,'Albany, NY 12232',3061,222,NULL,32,4354,0);
INSERT INTO "django_geo_db_location" VALUES(7709,NULL,'Albany, NY 12233',3061,222,NULL,32,4355,0);
INSERT INTO "django_geo_db_location" VALUES(7710,NULL,'Albany, NY 12234',3061,222,NULL,32,4356,0);
INSERT INTO "django_geo_db_location" VALUES(7711,NULL,'Albany, NY 12235',3061,222,NULL,32,4357,0);
INSERT INTO "django_geo_db_location" VALUES(7712,NULL,'Albany, NY 12236',3061,222,NULL,32,4358,0);
INSERT INTO "django_geo_db_location" VALUES(7713,NULL,'Albany, NY 12237',3061,222,NULL,32,4359,0);
INSERT INTO "django_geo_db_location" VALUES(7714,NULL,'Albany, NY 12238',3061,222,NULL,32,4360,0);
INSERT INTO "django_geo_db_location" VALUES(7715,NULL,'Albany, NY 12239',3061,222,NULL,32,4361,0);
INSERT INTO "django_geo_db_location" VALUES(7716,NULL,'Albany, NY 12240',3061,222,NULL,32,4362,0);
INSERT INTO "django_geo_db_location" VALUES(7717,NULL,'Albany, NY 12241',3061,222,NULL,32,4363,0);
INSERT INTO "django_geo_db_location" VALUES(7718,NULL,'Albany, NY 12242',3061,222,NULL,32,4364,0);
INSERT INTO "django_geo_db_location" VALUES(7719,NULL,'Albany, NY 12243',3061,222,NULL,32,4365,0);
INSERT INTO "django_geo_db_location" VALUES(7720,NULL,'Albany, NY 12244',3061,222,NULL,32,4366,0);
INSERT INTO "django_geo_db_location" VALUES(7721,NULL,'Albany, NY 12245',3061,222,NULL,32,4367,0);
INSERT INTO "django_geo_db_location" VALUES(7722,NULL,'Albany, NY 12246',3061,222,NULL,32,4368,0);
INSERT INTO "django_geo_db_location" VALUES(7723,NULL,'Albany, NY 12247',3061,222,NULL,32,4369,0);
INSERT INTO "django_geo_db_location" VALUES(7724,NULL,'Albany, NY 12248',3061,222,NULL,32,4370,0);
INSERT INTO "django_geo_db_location" VALUES(7725,NULL,'Albany, NY 12249',3061,222,NULL,32,4371,0);
INSERT INTO "django_geo_db_location" VALUES(7726,NULL,'Albany, NY 12250',3061,222,NULL,32,4372,0);
INSERT INTO "django_geo_db_location" VALUES(7727,NULL,'Albany, NY 12252',3061,222,NULL,32,4373,0);
INSERT INTO "django_geo_db_location" VALUES(7728,NULL,'Albany, NY 12255',3061,222,NULL,32,4374,0);
INSERT INTO "django_geo_db_location" VALUES(7729,NULL,'Albany, NY 12256',3061,222,NULL,32,4375,0);
INSERT INTO "django_geo_db_location" VALUES(7730,NULL,'Albany, NY 12257',3061,222,NULL,32,4376,0);
INSERT INTO "django_geo_db_location" VALUES(7731,NULL,'Albany, NY 12260',3061,222,NULL,32,4377,0);
INSERT INTO "django_geo_db_location" VALUES(7732,NULL,'Albany, NY 12261',3061,222,NULL,32,4378,0);
INSERT INTO "django_geo_db_location" VALUES(7733,NULL,'Albany, NY 12262',3061,222,NULL,32,4379,0);
INSERT INTO "django_geo_db_location" VALUES(7734,NULL,'Albany, NY 12288',3061,222,NULL,32,4380,0);
INSERT INTO "django_geo_db_location" VALUES(7735,NULL,'Schenectady, NY',3062,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7736,NULL,'Schenectady, NY 12301',3062,222,NULL,32,4381,0);
INSERT INTO "django_geo_db_location" VALUES(7737,NULL,'Schenectady, NY 12302',3062,222,NULL,32,4382,0);
INSERT INTO "django_geo_db_location" VALUES(7738,NULL,'Schenectady, NY 12303',3062,222,NULL,32,4383,0);
INSERT INTO "django_geo_db_location" VALUES(7739,NULL,'Schenectady, NY 12304',3062,222,NULL,32,4384,0);
INSERT INTO "django_geo_db_location" VALUES(7740,NULL,'Schenectady, NY 12305',3062,222,NULL,32,4385,0);
INSERT INTO "django_geo_db_location" VALUES(7741,NULL,'Schenectady, NY 12306',3062,222,NULL,32,4386,0);
INSERT INTO "django_geo_db_location" VALUES(7742,NULL,'Schenectady, NY 12307',3062,222,NULL,32,4387,0);
INSERT INTO "django_geo_db_location" VALUES(7743,NULL,'Schenectady, NY 12308',3062,222,NULL,32,4388,0);
INSERT INTO "django_geo_db_location" VALUES(7744,NULL,'Schenectady, NY 12309',3062,222,NULL,32,4389,0);
INSERT INTO "django_geo_db_location" VALUES(7745,NULL,'Schenectady, NY 12325',3062,222,NULL,32,4390,0);
INSERT INTO "django_geo_db_location" VALUES(7746,NULL,'Schenectady, NY 12345',3062,222,NULL,32,4391,0);
INSERT INTO "django_geo_db_location" VALUES(7747,NULL,'Kingston, NY',3063,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7748,NULL,'Kingston, NY 12401',3063,222,NULL,32,4392,0);
INSERT INTO "django_geo_db_location" VALUES(7749,NULL,'Kingston, NY 12402',3063,222,NULL,32,4393,0);
INSERT INTO "django_geo_db_location" VALUES(7750,NULL,'Accord, NY',3064,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7751,NULL,'Accord, NY 12404',3064,222,NULL,32,4394,0);
INSERT INTO "django_geo_db_location" VALUES(7752,NULL,'Acra, NY',3065,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7753,NULL,'Acra, NY 12405',3065,222,NULL,32,4395,0);
INSERT INTO "django_geo_db_location" VALUES(7754,NULL,'Arkville, NY',3066,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7755,NULL,'Arkville, NY 12406',3066,222,NULL,32,4396,0);
INSERT INTO "django_geo_db_location" VALUES(7756,NULL,'Ashland, NY',3067,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7757,NULL,'Ashland, NY 12407',3067,222,NULL,32,4397,0);
INSERT INTO "django_geo_db_location" VALUES(7758,NULL,'Bearsville, NY',3068,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7759,NULL,'Bearsville, NY 12409',3068,222,NULL,32,4398,0);
INSERT INTO "django_geo_db_location" VALUES(7760,NULL,'Big Indian, NY',3069,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7761,NULL,'Big Indian, NY 12410',3069,222,NULL,32,4399,0);
INSERT INTO "django_geo_db_location" VALUES(7762,NULL,'Bloomington, NY',3070,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7763,NULL,'Bloomington, NY 12411',3070,222,NULL,32,4400,0);
INSERT INTO "django_geo_db_location" VALUES(7764,NULL,'Boiceville, NY',3071,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7765,NULL,'Boiceville, NY 12412',3071,222,NULL,32,4401,0);
INSERT INTO "django_geo_db_location" VALUES(7766,NULL,'Cairo, NY',3072,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7767,NULL,'Cairo, NY 12413',3072,222,NULL,32,4402,0);
INSERT INTO "django_geo_db_location" VALUES(7768,NULL,'Catskill, NY',3073,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7769,NULL,'Catskill, NY 12414',3073,222,NULL,32,4403,0);
INSERT INTO "django_geo_db_location" VALUES(7770,NULL,'Chichester, NY',3074,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7771,NULL,'Chichester, NY 12416',3074,222,NULL,32,4404,0);
INSERT INTO "django_geo_db_location" VALUES(7772,NULL,'Connelly, NY',3075,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7773,NULL,'Connelly, NY 12417',3075,222,NULL,32,4405,0);
INSERT INTO "django_geo_db_location" VALUES(7774,NULL,'Cornwallville, NY',3076,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7775,NULL,'Cornwallville, NY 12418',3076,222,NULL,32,4406,0);
INSERT INTO "django_geo_db_location" VALUES(7776,NULL,'Cottekill, NY',3077,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7777,NULL,'Cottekill, NY 12419',3077,222,NULL,32,4407,0);
INSERT INTO "django_geo_db_location" VALUES(7778,NULL,'Cragsmoor, NY',3078,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7779,NULL,'Cragsmoor, NY 12420',3078,222,NULL,32,4408,0);
INSERT INTO "django_geo_db_location" VALUES(7780,NULL,'Denver, NY',3079,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7781,NULL,'Denver, NY 12421',3079,222,NULL,32,4409,0);
INSERT INTO "django_geo_db_location" VALUES(7782,NULL,'Durham, NY',3080,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7783,NULL,'Durham, NY 12422',3080,222,NULL,32,4410,0);
INSERT INTO "django_geo_db_location" VALUES(7784,NULL,'East Durham, NY',3081,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7785,NULL,'East Durham, NY 12423',3081,222,NULL,32,4411,0);
INSERT INTO "django_geo_db_location" VALUES(7786,NULL,'East Jewett, NY',3082,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7787,NULL,'East Jewett, NY 12424',3082,222,NULL,32,4412,0);
INSERT INTO "django_geo_db_location" VALUES(7788,NULL,'Elka Park, NY',3083,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7789,NULL,'Elka Park, NY 12427',3083,222,NULL,32,4413,0);
INSERT INTO "django_geo_db_location" VALUES(7790,NULL,'Ellenville, NY',3084,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7791,NULL,'Ellenville, NY 12428',3084,222,NULL,32,4414,0);
INSERT INTO "django_geo_db_location" VALUES(7792,NULL,'Esopus, NY',3085,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7793,NULL,'Esopus, NY 12429',3085,222,NULL,32,4415,0);
INSERT INTO "django_geo_db_location" VALUES(7794,NULL,'Fleischmanns, NY',3086,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7795,NULL,'Fleischmanns, NY 12430',3086,222,NULL,32,4416,0);
INSERT INTO "django_geo_db_location" VALUES(7796,NULL,'Freehold, NY',3087,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7797,NULL,'Freehold, NY 12431',3087,222,NULL,32,4417,0);
INSERT INTO "django_geo_db_location" VALUES(7798,NULL,'Glasco, NY',3088,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7799,NULL,'Glasco, NY 12432',3088,222,NULL,32,4418,0);
INSERT INTO "django_geo_db_location" VALUES(7800,NULL,'Glenford, NY',3089,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7801,NULL,'Glenford, NY 12433',3089,222,NULL,32,4419,0);
INSERT INTO "django_geo_db_location" VALUES(7802,NULL,'Grand Gorge, NY',3090,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7803,NULL,'Grand Gorge, NY 12434',3090,222,NULL,32,4420,0);
INSERT INTO "django_geo_db_location" VALUES(7804,NULL,'Greenfield Park, NY',3091,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7805,NULL,'Greenfield Park, NY 12435',3091,222,NULL,32,4421,0);
INSERT INTO "django_geo_db_location" VALUES(7806,NULL,'Haines Falls, NY',3092,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7807,NULL,'Haines Falls, NY 12436',3092,222,NULL,32,4422,0);
INSERT INTO "django_geo_db_location" VALUES(7808,NULL,'Halcottsville, NY',3093,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7809,NULL,'Halcottsville, NY 12438',3093,222,NULL,32,4423,0);
INSERT INTO "django_geo_db_location" VALUES(7810,NULL,'Hensonville, NY',3094,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7811,NULL,'Hensonville, NY 12439',3094,222,NULL,32,4424,0);
INSERT INTO "django_geo_db_location" VALUES(7812,NULL,'High Falls, NY',3095,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7813,NULL,'High Falls, NY 12440',3095,222,NULL,32,4425,0);
INSERT INTO "django_geo_db_location" VALUES(7814,NULL,'Highmount, NY',3096,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7815,NULL,'Highmount, NY 12441',3096,222,NULL,32,4426,0);
INSERT INTO "django_geo_db_location" VALUES(7816,NULL,'Hunter, NY',3097,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7817,NULL,'Hunter, NY 12442',3097,222,NULL,32,4427,0);
INSERT INTO "django_geo_db_location" VALUES(7818,NULL,'Hurley, NY',3098,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7819,NULL,'Hurley, NY 12443',3098,222,NULL,32,4428,0);
INSERT INTO "django_geo_db_location" VALUES(7820,NULL,'Jewett, NY',3099,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7821,NULL,'Jewett, NY 12444',3099,222,NULL,32,4429,0);
INSERT INTO "django_geo_db_location" VALUES(7822,NULL,'Kerhonkson, NY',3100,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7823,NULL,'Kerhonkson, NY 12446',3100,222,NULL,32,4430,0);
INSERT INTO "django_geo_db_location" VALUES(7824,NULL,'Saugerties, NY',3101,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7825,NULL,'Saugerties, NY 12447',3101,222,NULL,32,4431,0);
INSERT INTO "django_geo_db_location" VALUES(7826,NULL,'Lake Hill, NY',3102,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7827,NULL,'Lake Hill, NY 12448',3102,222,NULL,32,4432,0);
INSERT INTO "django_geo_db_location" VALUES(7828,NULL,'Lake Katrine, NY',3103,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7829,NULL,'Lake Katrine, NY 12449',3103,222,NULL,32,4433,0);
INSERT INTO "django_geo_db_location" VALUES(7830,NULL,'Lanesville, NY',3104,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7831,NULL,'Lanesville, NY 12450',3104,222,NULL,32,4434,0);
INSERT INTO "django_geo_db_location" VALUES(7832,NULL,'Leeds, NY',3105,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7833,NULL,'Leeds, NY 12451',3105,222,NULL,32,4435,0);
INSERT INTO "django_geo_db_location" VALUES(7834,NULL,'Lexington, NY',3106,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7835,NULL,'Lexington, NY 12452',3106,222,NULL,32,4436,0);
INSERT INTO "django_geo_db_location" VALUES(7836,NULL,'Malden On Hudson, NY',3107,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7837,NULL,'Malden On Hudson, NY 12453',3107,222,NULL,32,4437,0);
INSERT INTO "django_geo_db_location" VALUES(7838,NULL,'Maplecrest, NY',3108,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7839,NULL,'Maplecrest, NY 12454',3108,222,NULL,32,4438,0);
INSERT INTO "django_geo_db_location" VALUES(7840,NULL,'Margaretville, NY',3109,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7841,NULL,'Margaretville, NY 12455',3109,222,NULL,32,4439,0);
INSERT INTO "django_geo_db_location" VALUES(7842,NULL,'Mount Marion, NY',3110,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7843,NULL,'Mount Marion, NY 12456',3110,222,NULL,32,4440,0);
INSERT INTO "django_geo_db_location" VALUES(7844,NULL,'Mount Tremper, NY',3111,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7845,NULL,'Mount Tremper, NY 12457',3111,222,NULL,32,4441,0);
INSERT INTO "django_geo_db_location" VALUES(7846,NULL,'Napanoch, NY',3112,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7847,NULL,'Napanoch, NY 12458',3112,222,NULL,32,4442,0);
INSERT INTO "django_geo_db_location" VALUES(7848,NULL,'New Kingston, NY',3113,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7849,NULL,'New Kingston, NY 12459',3113,222,NULL,32,4443,0);
INSERT INTO "django_geo_db_location" VALUES(7850,NULL,'Oak Hill, NY',3114,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7851,NULL,'Oak Hill, NY 12460',3114,222,NULL,32,4444,0);
INSERT INTO "django_geo_db_location" VALUES(7852,NULL,'Olivebridge, NY',3115,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7853,NULL,'Olivebridge, NY 12461',3115,222,NULL,32,4445,0);
INSERT INTO "django_geo_db_location" VALUES(7854,NULL,'Palenville, NY',3116,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7855,NULL,'Palenville, NY 12463',3116,222,NULL,32,4446,0);
INSERT INTO "django_geo_db_location" VALUES(7856,NULL,'Phoenicia, NY',3117,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7857,NULL,'Phoenicia, NY 12464',3117,222,NULL,32,4447,0);
INSERT INTO "django_geo_db_location" VALUES(7858,NULL,'Pine Hill, NY',3118,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7859,NULL,'Pine Hill, NY 12465',3118,222,NULL,32,4448,0);
INSERT INTO "django_geo_db_location" VALUES(7860,NULL,'Port Ewen, NY',3119,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7861,NULL,'Port Ewen, NY 12466',3119,222,NULL,32,4449,0);
INSERT INTO "django_geo_db_location" VALUES(7862,NULL,'Prattsville, NY',3120,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7863,NULL,'Prattsville, NY 12468',3120,222,NULL,32,4450,0);
INSERT INTO "django_geo_db_location" VALUES(7864,NULL,'Preston Hollow, NY',3121,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7865,NULL,'Preston Hollow, NY 12469',3121,222,NULL,32,4451,0);
INSERT INTO "django_geo_db_location" VALUES(7866,NULL,'Purling, NY',3122,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7867,NULL,'Purling, NY 12470',3122,222,NULL,32,4452,0);
INSERT INTO "django_geo_db_location" VALUES(7868,NULL,'Rifton, NY',3123,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7869,NULL,'Rifton, NY 12471',3123,222,NULL,32,4453,0);
INSERT INTO "django_geo_db_location" VALUES(7870,NULL,'Rosendale, NY',3124,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7871,NULL,'Rosendale, NY 12472',3124,222,NULL,32,4454,0);
INSERT INTO "django_geo_db_location" VALUES(7872,NULL,'Round Top, NY',3125,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7873,NULL,'Round Top, NY 12473',3125,222,NULL,32,4455,0);
INSERT INTO "django_geo_db_location" VALUES(7874,NULL,'Roxbury, NY',3126,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7875,NULL,'Roxbury, NY 12474',3126,222,NULL,32,4456,0);
INSERT INTO "django_geo_db_location" VALUES(7876,NULL,'Ruby, NY',3127,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7877,NULL,'Ruby, NY 12475',3127,222,NULL,32,4457,0);
INSERT INTO "django_geo_db_location" VALUES(7878,NULL,'Saugerties, NY 12477',3101,222,NULL,32,4458,0);
INSERT INTO "django_geo_db_location" VALUES(7879,NULL,'Shandaken, NY',3128,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7880,NULL,'Shandaken, NY 12480',3128,222,NULL,32,4459,0);
INSERT INTO "django_geo_db_location" VALUES(7881,NULL,'Shokan, NY',3129,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7882,NULL,'Shokan, NY 12481',3129,222,NULL,32,4460,0);
INSERT INTO "django_geo_db_location" VALUES(7883,NULL,'South Cairo, NY',3130,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7884,NULL,'South Cairo, NY 12482',3130,222,NULL,32,4461,0);
INSERT INTO "django_geo_db_location" VALUES(7885,NULL,'Spring Glen, NY',3131,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7886,NULL,'Spring Glen, NY 12483',3131,222,NULL,32,4462,0);
INSERT INTO "django_geo_db_location" VALUES(7887,NULL,'Stone Ridge, NY',3132,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7888,NULL,'Stone Ridge, NY 12484',3132,222,NULL,32,4463,0);
INSERT INTO "django_geo_db_location" VALUES(7889,NULL,'Tannersville, NY',3133,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7890,NULL,'Tannersville, NY 12485',3133,222,NULL,32,4464,0);
INSERT INTO "django_geo_db_location" VALUES(7891,NULL,'Tillson, NY',3134,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7892,NULL,'Tillson, NY 12486',3134,222,NULL,32,4465,0);
INSERT INTO "django_geo_db_location" VALUES(7893,NULL,'Ulster Park, NY',3135,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7894,NULL,'Ulster Park, NY 12487',3135,222,NULL,32,4466,0);
INSERT INTO "django_geo_db_location" VALUES(7895,NULL,'Wawarsing, NY',3136,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7896,NULL,'Wawarsing, NY 12489',3136,222,NULL,32,4467,0);
INSERT INTO "django_geo_db_location" VALUES(7897,NULL,'West Camp, NY',3137,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7898,NULL,'West Camp, NY 12490',3137,222,NULL,32,4468,0);
INSERT INTO "django_geo_db_location" VALUES(7899,NULL,'West Hurley, NY',3138,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7900,NULL,'West Hurley, NY 12491',3138,222,NULL,32,4469,0);
INSERT INTO "django_geo_db_location" VALUES(7901,NULL,'West Kill, NY',3139,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7902,NULL,'West Kill, NY 12492',3139,222,NULL,32,4470,0);
INSERT INTO "django_geo_db_location" VALUES(7903,NULL,'West Park, NY',3140,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7904,NULL,'West Park, NY 12493',3140,222,NULL,32,4471,0);
INSERT INTO "django_geo_db_location" VALUES(7905,NULL,'West Shokan, NY',3141,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7906,NULL,'West Shokan, NY 12494',3141,222,NULL,32,4472,0);
INSERT INTO "django_geo_db_location" VALUES(7907,NULL,'Willow, NY',3142,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7908,NULL,'Willow, NY 12495',3142,222,NULL,32,4473,0);
INSERT INTO "django_geo_db_location" VALUES(7909,NULL,'Windham, NY',3143,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7910,NULL,'Windham, NY 12496',3143,222,NULL,32,4474,0);
INSERT INTO "django_geo_db_location" VALUES(7911,NULL,'Woodstock, NY',3144,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7912,NULL,'Woodstock, NY 12498',3144,222,NULL,32,4475,0);
INSERT INTO "django_geo_db_location" VALUES(7913,NULL,'Amenia, NY',3145,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7914,NULL,'Amenia, NY 12501',3145,222,NULL,32,4476,0);
INSERT INTO "django_geo_db_location" VALUES(7915,NULL,'Ancram, NY',3146,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7916,NULL,'Ancram, NY 12502',3146,222,NULL,32,4477,0);
INSERT INTO "django_geo_db_location" VALUES(7917,NULL,'Ancramdale, NY',3147,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7918,NULL,'Ancramdale, NY 12503',3147,222,NULL,32,4478,0);
INSERT INTO "django_geo_db_location" VALUES(7919,NULL,'Annandale On Hudson, NY',3148,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7920,NULL,'Annandale On Hudson, NY 12504',3148,222,NULL,32,4479,0);
INSERT INTO "django_geo_db_location" VALUES(7921,NULL,'Bangall, NY',3149,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7922,NULL,'Bangall, NY 12506',3149,222,NULL,32,4480,0);
INSERT INTO "django_geo_db_location" VALUES(7923,NULL,'Barrytown, NY',3150,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7924,NULL,'Barrytown, NY 12507',3150,222,NULL,32,4481,0);
INSERT INTO "django_geo_db_location" VALUES(7925,NULL,'Beacon, NY',3151,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7926,NULL,'Beacon, NY 12508',3151,222,NULL,32,4482,0);
INSERT INTO "django_geo_db_location" VALUES(7927,NULL,'La Grange, NY',3152,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7928,NULL,'La Grange, NY 12509',3152,222,NULL,32,4483,0);
INSERT INTO "django_geo_db_location" VALUES(7929,NULL,'Billings, NY',3153,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7930,NULL,'Billings, NY 12510',3153,222,NULL,32,4484,0);
INSERT INTO "django_geo_db_location" VALUES(7931,NULL,'Castle Point, NY',3154,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7932,NULL,'Castle Point, NY 12511',3154,222,NULL,32,4485,0);
INSERT INTO "django_geo_db_location" VALUES(7933,NULL,'Chelsea, NY',3155,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7934,NULL,'Chelsea, NY 12512',3155,222,NULL,32,4486,0);
INSERT INTO "django_geo_db_location" VALUES(7935,NULL,'Claverack, NY',3156,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7936,NULL,'Claverack, NY 12513',3156,222,NULL,32,4487,0);
INSERT INTO "django_geo_db_location" VALUES(7937,NULL,'Clinton Corners, NY',3157,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7938,NULL,'Clinton Corners, NY 12514',3157,222,NULL,32,4488,0);
INSERT INTO "django_geo_db_location" VALUES(7939,NULL,'Clintondale, NY',3158,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7940,NULL,'Clintondale, NY 12515',3158,222,NULL,32,4489,0);
INSERT INTO "django_geo_db_location" VALUES(7941,NULL,'Copake, NY',3159,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7942,NULL,'Copake, NY 12516',3159,222,NULL,32,4490,0);
INSERT INTO "django_geo_db_location" VALUES(7943,NULL,'Copake Falls, NY',3160,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7944,NULL,'Copake Falls, NY 12517',3160,222,NULL,32,4491,0);
INSERT INTO "django_geo_db_location" VALUES(7945,NULL,'Cornwall, NY',3161,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7946,NULL,'Cornwall, NY 12518',3161,222,NULL,32,4492,0);
INSERT INTO "django_geo_db_location" VALUES(7947,NULL,'Cornwall On Hudson, NY',3162,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7948,NULL,'Cornwall On Hudson, NY 12520',3162,222,NULL,32,4493,0);
INSERT INTO "django_geo_db_location" VALUES(7949,NULL,'Craryville, NY',3163,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7950,NULL,'Craryville, NY 12521',3163,222,NULL,32,4494,0);
INSERT INTO "django_geo_db_location" VALUES(7951,NULL,'Dover Plains, NY',3164,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7952,NULL,'Dover Plains, NY 12522',3164,222,NULL,32,4495,0);
INSERT INTO "django_geo_db_location" VALUES(7953,NULL,'Elizaville, NY',3165,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7954,NULL,'Elizaville, NY 12523',3165,222,NULL,32,4496,0);
INSERT INTO "django_geo_db_location" VALUES(7955,NULL,'Fishkill, NY',3166,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7956,NULL,'Fishkill, NY 12524',3166,222,NULL,32,4497,0);
INSERT INTO "django_geo_db_location" VALUES(7957,NULL,'Gardiner, NY',3167,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7958,NULL,'Gardiner, NY 12525',3167,222,NULL,32,4498,0);
INSERT INTO "django_geo_db_location" VALUES(7959,NULL,'Germantown, NY',3168,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7960,NULL,'Germantown, NY 12526',3168,222,NULL,32,4499,0);
INSERT INTO "django_geo_db_location" VALUES(7961,NULL,'Glenham, NY',3169,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7962,NULL,'Glenham, NY 12527',3169,222,NULL,32,4500,0);
INSERT INTO "django_geo_db_location" VALUES(7963,NULL,'Highland, NY',3170,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7964,NULL,'Highland, NY 12528',3170,222,NULL,32,4501,0);
INSERT INTO "django_geo_db_location" VALUES(7965,NULL,'Hillsdale, NY',3171,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7966,NULL,'Hillsdale, NY 12529',3171,222,NULL,32,4502,0);
INSERT INTO "django_geo_db_location" VALUES(7967,NULL,'Hollowville, NY',3172,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7968,NULL,'Hollowville, NY 12530',3172,222,NULL,32,4503,0);
INSERT INTO "django_geo_db_location" VALUES(7969,NULL,'Holmes, NY',3173,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7970,NULL,'Holmes, NY 12531',3173,222,NULL,32,4504,0);
INSERT INTO "django_geo_db_location" VALUES(7971,NULL,'Hopewell Junction, NY',3174,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7972,NULL,'Hopewell Junction, NY 12533',3174,222,NULL,32,4505,0);
INSERT INTO "django_geo_db_location" VALUES(7973,NULL,'Hudson, NY',3175,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7974,NULL,'Hudson, NY 12534',3175,222,NULL,32,4506,0);
INSERT INTO "django_geo_db_location" VALUES(7975,NULL,'Hughsonville, NY',3176,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7976,NULL,'Hughsonville, NY 12537',3176,222,NULL,32,4507,0);
INSERT INTO "django_geo_db_location" VALUES(7977,NULL,'Hyde Park, NY',3177,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7978,NULL,'Hyde Park, NY 12538',3177,222,NULL,32,4508,0);
INSERT INTO "django_geo_db_location" VALUES(7979,NULL,'Lagrangeville, NY',3178,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7980,NULL,'Lagrangeville, NY 12540',3178,222,NULL,32,4509,0);
INSERT INTO "django_geo_db_location" VALUES(7981,NULL,'Livingston, NY',3179,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7982,NULL,'Livingston, NY 12541',3179,222,NULL,32,4510,0);
INSERT INTO "django_geo_db_location" VALUES(7983,NULL,'Marlboro, NY',3180,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7984,NULL,'Marlboro, NY 12542',3180,222,NULL,32,4511,0);
INSERT INTO "django_geo_db_location" VALUES(7985,NULL,'Maybrook, NY',3181,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7986,NULL,'Maybrook, NY 12543',3181,222,NULL,32,4512,0);
INSERT INTO "django_geo_db_location" VALUES(7987,NULL,'Mellenville, NY',3182,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7988,NULL,'Mellenville, NY 12544',3182,222,NULL,32,4513,0);
INSERT INTO "django_geo_db_location" VALUES(7989,NULL,'Millbrook, NY',3183,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7990,NULL,'Millbrook, NY 12545',3183,222,NULL,32,4514,0);
INSERT INTO "django_geo_db_location" VALUES(7991,NULL,'Millerton, NY',3184,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7992,NULL,'Millerton, NY 12546',3184,222,NULL,32,4515,0);
INSERT INTO "django_geo_db_location" VALUES(7993,NULL,'Milton, NY',3185,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7994,NULL,'Milton, NY 12547',3185,222,NULL,32,4516,0);
INSERT INTO "django_geo_db_location" VALUES(7995,NULL,'Modena, NY',3186,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7996,NULL,'Modena, NY 12548',3186,222,NULL,32,4517,0);
INSERT INTO "django_geo_db_location" VALUES(7997,NULL,'Montgomery, NY',3187,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(7998,NULL,'Montgomery, NY 12549',3187,222,NULL,32,4518,0);
INSERT INTO "django_geo_db_location" VALUES(7999,NULL,'Newburgh, NY',3188,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8000,NULL,'Newburgh, NY 12550',3188,222,NULL,32,4519,0);
INSERT INTO "django_geo_db_location" VALUES(8001,NULL,'Newburgh, NY 12551',3188,222,NULL,32,4520,0);
INSERT INTO "django_geo_db_location" VALUES(8002,NULL,'Newburgh, NY 12552',3188,222,NULL,32,4521,0);
INSERT INTO "django_geo_db_location" VALUES(8003,NULL,'New Windsor, NY',3189,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8004,NULL,'New Windsor, NY 12553',3189,222,NULL,32,4522,0);
INSERT INTO "django_geo_db_location" VALUES(8005,NULL,'Mid Hudson, NY',3190,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8006,NULL,'Mid Hudson, NY 12555',3190,222,NULL,32,4523,0);
INSERT INTO "django_geo_db_location" VALUES(8007,NULL,'Newburgh, NY 12557',3188,222,NULL,32,4524,0);
INSERT INTO "django_geo_db_location" VALUES(8008,NULL,'New Paltz, NY',3191,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8009,NULL,'New Paltz, NY 12561',3191,222,NULL,32,4525,0);
INSERT INTO "django_geo_db_location" VALUES(8010,NULL,'Patterson, NY',3192,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8011,NULL,'Patterson, NY 12563',3192,222,NULL,32,4526,0);
INSERT INTO "django_geo_db_location" VALUES(8012,NULL,'Pawling, NY',3193,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8013,NULL,'Pawling, NY 12564',3193,222,NULL,32,4527,0);
INSERT INTO "django_geo_db_location" VALUES(8014,NULL,'Philmont, NY',3194,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8015,NULL,'Philmont, NY 12565',3194,222,NULL,32,4528,0);
INSERT INTO "django_geo_db_location" VALUES(8016,NULL,'Pine Bush, NY',3195,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8017,NULL,'Pine Bush, NY 12566',3195,222,NULL,32,4529,0);
INSERT INTO "django_geo_db_location" VALUES(8018,NULL,'Pine Plains, NY',3196,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8019,NULL,'Pine Plains, NY 12567',3196,222,NULL,32,4530,0);
INSERT INTO "django_geo_db_location" VALUES(8020,NULL,'Plattekill, NY',3197,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8021,NULL,'Plattekill, NY 12568',3197,222,NULL,32,4531,0);
INSERT INTO "django_geo_db_location" VALUES(8022,NULL,'Pleasant Valley, NY',3198,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8023,NULL,'Pleasant Valley, NY 12569',3198,222,NULL,32,4532,0);
INSERT INTO "django_geo_db_location" VALUES(8024,NULL,'Poughquag, NY',3199,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8025,NULL,'Poughquag, NY 12570',3199,222,NULL,32,4533,0);
INSERT INTO "django_geo_db_location" VALUES(8026,NULL,'Red Hook, NY',3200,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8027,NULL,'Red Hook, NY 12571',3200,222,NULL,32,4534,0);
INSERT INTO "django_geo_db_location" VALUES(8028,NULL,'Rhinebeck, NY',3201,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8029,NULL,'Rhinebeck, NY 12572',3201,222,NULL,32,4535,0);
INSERT INTO "django_geo_db_location" VALUES(8030,NULL,'Rhinecliff, NY',3202,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8031,NULL,'Rhinecliff, NY 12574',3202,222,NULL,32,4536,0);
INSERT INTO "django_geo_db_location" VALUES(8032,NULL,'Rock Tavern, NY',3203,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8033,NULL,'Rock Tavern, NY 12575',3203,222,NULL,32,4537,0);
INSERT INTO "django_geo_db_location" VALUES(8034,NULL,'Salisbury Mills, NY',3204,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8035,NULL,'Salisbury Mills, NY 12577',3204,222,NULL,32,4538,0);
INSERT INTO "django_geo_db_location" VALUES(8036,NULL,'Salt Point, NY',3205,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8037,NULL,'Salt Point, NY 12578',3205,222,NULL,32,4539,0);
INSERT INTO "django_geo_db_location" VALUES(8038,NULL,'Staatsburg, NY',3206,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8039,NULL,'Staatsburg, NY 12580',3206,222,NULL,32,4540,0);
INSERT INTO "django_geo_db_location" VALUES(8040,NULL,'Stanfordville, NY',3207,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8041,NULL,'Stanfordville, NY 12581',3207,222,NULL,32,4541,0);
INSERT INTO "django_geo_db_location" VALUES(8042,NULL,'Stormville, NY',3208,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8043,NULL,'Stormville, NY 12582',3208,222,NULL,32,4542,0);
INSERT INTO "django_geo_db_location" VALUES(8044,NULL,'Tivoli, NY',3209,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8045,NULL,'Tivoli, NY 12583',3209,222,NULL,32,4543,0);
INSERT INTO "django_geo_db_location" VALUES(8046,NULL,'Vails Gate, NY',3210,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8047,NULL,'Vails Gate, NY 12584',3210,222,NULL,32,4544,0);
INSERT INTO "django_geo_db_location" VALUES(8048,NULL,'Verbank, NY',3211,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8049,NULL,'Verbank, NY 12585',3211,222,NULL,32,4545,0);
INSERT INTO "django_geo_db_location" VALUES(8050,NULL,'Walden, NY',3212,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8051,NULL,'Walden, NY 12586',3212,222,NULL,32,4546,0);
INSERT INTO "django_geo_db_location" VALUES(8052,NULL,'Walker Valley, NY',3213,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8053,NULL,'Walker Valley, NY 12588',3213,222,NULL,32,4547,0);
INSERT INTO "django_geo_db_location" VALUES(8054,NULL,'Wallkill, NY 12589',2674,222,NULL,32,4548,0);
INSERT INTO "django_geo_db_location" VALUES(8055,NULL,'Wappingers Falls, NY',3214,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8056,NULL,'Wappingers Falls, NY 12590',3214,222,NULL,32,4549,0);
INSERT INTO "django_geo_db_location" VALUES(8057,NULL,'Wassaic, NY',3215,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8058,NULL,'Wassaic, NY 12592',3215,222,NULL,32,4550,0);
INSERT INTO "django_geo_db_location" VALUES(8059,NULL,'West Copake, NY',3216,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8060,NULL,'West Copake, NY 12593',3216,222,NULL,32,4551,0);
INSERT INTO "django_geo_db_location" VALUES(8061,NULL,'Wingdale, NY',3217,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8062,NULL,'Wingdale, NY 12594',3217,222,NULL,32,4552,0);
INSERT INTO "django_geo_db_location" VALUES(8063,NULL,'Poughkeepsie, NY',3218,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8064,NULL,'Poughkeepsie, NY 12601',3218,222,NULL,32,4553,0);
INSERT INTO "django_geo_db_location" VALUES(8065,NULL,'Poughkeepsie, NY 12602',3218,222,NULL,32,4554,0);
INSERT INTO "django_geo_db_location" VALUES(8066,NULL,'Poughkeepsie, NY 12603',3218,222,NULL,32,4555,0);
INSERT INTO "django_geo_db_location" VALUES(8067,NULL,'Poughkeepsie, NY 12604',3218,222,NULL,32,4556,0);
INSERT INTO "django_geo_db_location" VALUES(8068,NULL,'Moira, NY',3219,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8069,NULL,'Moira, NY 12697',3219,222,NULL,32,4557,0);
INSERT INTO "django_geo_db_location" VALUES(8070,NULL,'Monticello, NY',3220,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8071,NULL,'Monticello, NY 12701',3220,222,NULL,32,4558,0);
INSERT INTO "django_geo_db_location" VALUES(8072,NULL,'Neversink, NY',3221,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8073,NULL,'Neversink, NY 12710',3221,222,NULL,32,4559,0);
INSERT INTO "django_geo_db_location" VALUES(8074,NULL,'Barryville, NY',3222,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8075,NULL,'Barryville, NY 12719',3222,222,NULL,32,4560,0);
INSERT INTO "django_geo_db_location" VALUES(8076,NULL,'Bethel, NY',3223,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8077,NULL,'Bethel, NY 12720',3223,222,NULL,32,4561,0);
INSERT INTO "django_geo_db_location" VALUES(8078,NULL,'Bloomingburg, NY',3224,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8079,NULL,'Bloomingburg, NY 12721',3224,222,NULL,32,4562,0);
INSERT INTO "django_geo_db_location" VALUES(8080,NULL,'Burlingham, NY',3225,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8081,NULL,'Burlingham, NY 12722',3225,222,NULL,32,4563,0);
INSERT INTO "django_geo_db_location" VALUES(8082,NULL,'Callicoon, NY',3226,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8083,NULL,'Callicoon, NY 12723',3226,222,NULL,32,4564,0);
INSERT INTO "django_geo_db_location" VALUES(8084,NULL,'Callicoon Center, NY',3227,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8085,NULL,'Callicoon Center, NY 12724',3227,222,NULL,32,4565,0);
INSERT INTO "django_geo_db_location" VALUES(8086,NULL,'Claryville, NY',3228,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8087,NULL,'Claryville, NY 12725',3228,222,NULL,32,4566,0);
INSERT INTO "django_geo_db_location" VALUES(8088,NULL,'Cochecton, NY',3229,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8089,NULL,'Cochecton, NY 12726',3229,222,NULL,32,4567,0);
INSERT INTO "django_geo_db_location" VALUES(8090,NULL,'Cochecton Center, NY',3230,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8091,NULL,'Cochecton Center, NY 12727',3230,222,NULL,32,4568,0);
INSERT INTO "django_geo_db_location" VALUES(8092,NULL,'Cuddebackville, NY',3231,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8093,NULL,'Cuddebackville, NY 12729',3231,222,NULL,32,4569,0);
INSERT INTO "django_geo_db_location" VALUES(8094,NULL,'Eldred, NY',3232,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8095,NULL,'Eldred, NY 12732',3232,222,NULL,32,4570,0);
INSERT INTO "django_geo_db_location" VALUES(8096,NULL,'Fallsburg, NY',3233,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8097,NULL,'Fallsburg, NY 12733',3233,222,NULL,32,4571,0);
INSERT INTO "django_geo_db_location" VALUES(8098,NULL,'Ferndale, NY',3234,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8099,NULL,'Ferndale, NY 12734',3234,222,NULL,32,4572,0);
INSERT INTO "django_geo_db_location" VALUES(8100,NULL,'Fremont Center, NY',3235,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8101,NULL,'Fremont Center, NY 12736',3235,222,NULL,32,4573,0);
INSERT INTO "django_geo_db_location" VALUES(8102,NULL,'Glen Spey, NY',3236,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8103,NULL,'Glen Spey, NY 12737',3236,222,NULL,32,4574,0);
INSERT INTO "django_geo_db_location" VALUES(8104,NULL,'Glen Wild, NY',3237,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8105,NULL,'Glen Wild, NY 12738',3237,222,NULL,32,4575,0);
INSERT INTO "django_geo_db_location" VALUES(8106,NULL,'Godeffroy, NY',3238,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8107,NULL,'Godeffroy, NY 12739',3238,222,NULL,32,4576,0);
INSERT INTO "django_geo_db_location" VALUES(8108,NULL,'Grahamsville, NY',3239,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8109,NULL,'Grahamsville, NY 12740',3239,222,NULL,32,4577,0);
INSERT INTO "django_geo_db_location" VALUES(8110,NULL,'Hankins, NY',3240,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8111,NULL,'Hankins, NY 12741',3240,222,NULL,32,4578,0);
INSERT INTO "django_geo_db_location" VALUES(8112,NULL,'Harris, NY',3241,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8113,NULL,'Harris, NY 12742',3241,222,NULL,32,4579,0);
INSERT INTO "django_geo_db_location" VALUES(8114,NULL,'Highland Lake, NY',3242,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8115,NULL,'Highland Lake, NY 12743',3242,222,NULL,32,4580,0);
INSERT INTO "django_geo_db_location" VALUES(8116,NULL,'Hortonville, NY',3243,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8117,NULL,'Hortonville, NY 12745',3243,222,NULL,32,4581,0);
INSERT INTO "django_geo_db_location" VALUES(8118,NULL,'Huguenot, NY',3244,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8119,NULL,'Huguenot, NY 12746',3244,222,NULL,32,4582,0);
INSERT INTO "django_geo_db_location" VALUES(8120,NULL,'Hurleyville, NY',3245,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8121,NULL,'Hurleyville, NY 12747',3245,222,NULL,32,4583,0);
INSERT INTO "django_geo_db_location" VALUES(8122,NULL,'Jeffersonville, NY',3246,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8123,NULL,'Jeffersonville, NY 12748',3246,222,NULL,32,4584,0);
INSERT INTO "django_geo_db_location" VALUES(8124,NULL,'Kauneonga Lake, NY',3247,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8125,NULL,'Kauneonga Lake, NY 12749',3247,222,NULL,32,4585,0);
INSERT INTO "django_geo_db_location" VALUES(8126,NULL,'Kenoza Lake, NY',3248,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8127,NULL,'Kenoza Lake, NY 12750',3248,222,NULL,32,4586,0);
INSERT INTO "django_geo_db_location" VALUES(8128,NULL,'Kiamesha Lake, NY',3249,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8129,NULL,'Kiamesha Lake, NY 12751',3249,222,NULL,32,4587,0);
INSERT INTO "django_geo_db_location" VALUES(8130,NULL,'Lake Huntington, NY',3250,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8131,NULL,'Lake Huntington, NY 12752',3250,222,NULL,32,4588,0);
INSERT INTO "django_geo_db_location" VALUES(8132,NULL,'Liberty, NY',3251,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8133,NULL,'Liberty, NY 12754',3251,222,NULL,32,4589,0);
INSERT INTO "django_geo_db_location" VALUES(8134,NULL,'Ellenburg, NY',3252,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8135,NULL,'Ellenburg, NY 12755',3252,222,NULL,32,4590,0);
INSERT INTO "django_geo_db_location" VALUES(8136,NULL,'Livingston Manor, NY',3253,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8137,NULL,'Livingston Manor, NY 12756',3253,222,NULL,32,4591,0);
INSERT INTO "django_geo_db_location" VALUES(8138,NULL,'Livingston Manor, NY 12758',3253,222,NULL,32,4592,0);
INSERT INTO "django_geo_db_location" VALUES(8139,NULL,'Loch Sheldrake, NY',3254,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8140,NULL,'Loch Sheldrake, NY 12759',3254,222,NULL,32,4593,0);
INSERT INTO "django_geo_db_location" VALUES(8141,NULL,'Long Eddy, NY',3255,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8142,NULL,'Long Eddy, NY 12760',3255,222,NULL,32,4594,0);
INSERT INTO "django_geo_db_location" VALUES(8143,NULL,'Mongaup Valley, NY',3256,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8144,NULL,'Mongaup Valley, NY 12762',3256,222,NULL,32,4595,0);
INSERT INTO "django_geo_db_location" VALUES(8145,NULL,'Mountain Dale, NY',3257,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8146,NULL,'Mountain Dale, NY 12763',3257,222,NULL,32,4596,0);
INSERT INTO "django_geo_db_location" VALUES(8147,NULL,'Narrowsburg, NY',3258,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8148,NULL,'Narrowsburg, NY 12764',3258,222,NULL,32,4597,0);
INSERT INTO "django_geo_db_location" VALUES(8149,NULL,'Neversink, NY 12765',3221,222,NULL,32,4598,0);
INSERT INTO "django_geo_db_location" VALUES(8150,NULL,'North Branch, NY',3259,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8151,NULL,'North Branch, NY 12766',3259,222,NULL,32,4599,0);
INSERT INTO "django_geo_db_location" VALUES(8152,NULL,'Obernburg, NY',3260,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8153,NULL,'Obernburg, NY 12767',3260,222,NULL,32,4600,0);
INSERT INTO "django_geo_db_location" VALUES(8154,NULL,'Parksville, NY',3261,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8155,NULL,'Parksville, NY 12768',3261,222,NULL,32,4601,0);
INSERT INTO "django_geo_db_location" VALUES(8156,NULL,'Phillipsport, NY',3262,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8157,NULL,'Phillipsport, NY 12769',3262,222,NULL,32,4602,0);
INSERT INTO "django_geo_db_location" VALUES(8158,NULL,'Pond Eddy, NY',3263,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8159,NULL,'Pond Eddy, NY 12770',3263,222,NULL,32,4603,0);
INSERT INTO "django_geo_db_location" VALUES(8160,NULL,'Port Jervis, NY',3264,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8161,NULL,'Port Jervis, NY 12771',3264,222,NULL,32,4604,0);
INSERT INTO "django_geo_db_location" VALUES(8162,NULL,'Rock Hill, NY',3265,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8163,NULL,'Rock Hill, NY 12775',3265,222,NULL,32,4605,0);
INSERT INTO "django_geo_db_location" VALUES(8164,NULL,'Roscoe, NY',3266,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8165,NULL,'Roscoe, NY 12776',3266,222,NULL,32,4606,0);
INSERT INTO "django_geo_db_location" VALUES(8166,NULL,'Forestburgh, NY',3267,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8167,NULL,'Forestburgh, NY 12777',3267,222,NULL,32,4607,0);
INSERT INTO "django_geo_db_location" VALUES(8168,NULL,'Smallwood, NY',3268,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8169,NULL,'Smallwood, NY 12778',3268,222,NULL,32,4608,0);
INSERT INTO "django_geo_db_location" VALUES(8170,NULL,'South Fallsburg, NY',3269,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8171,NULL,'South Fallsburg, NY 12779',3269,222,NULL,32,4609,0);
INSERT INTO "django_geo_db_location" VALUES(8172,NULL,'Sparrow Bush, NY',3270,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8173,NULL,'Sparrow Bush, NY 12780',3270,222,NULL,32,4610,0);
INSERT INTO "django_geo_db_location" VALUES(8174,NULL,'Summitville, NY',3271,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8175,NULL,'Summitville, NY 12781',3271,222,NULL,32,4611,0);
INSERT INTO "django_geo_db_location" VALUES(8176,NULL,'Sundown, NY',3272,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8177,NULL,'Sundown, NY 12782',3272,222,NULL,32,4612,0);
INSERT INTO "django_geo_db_location" VALUES(8178,NULL,'Swan Lake, NY',3273,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8179,NULL,'Swan Lake, NY 12783',3273,222,NULL,32,4613,0);
INSERT INTO "django_geo_db_location" VALUES(8180,NULL,'Thompsonville, NY',3274,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8181,NULL,'Thompsonville, NY 12784',3274,222,NULL,32,4614,0);
INSERT INTO "django_geo_db_location" VALUES(8182,NULL,'Westbrookville, NY',3275,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8183,NULL,'Westbrookville, NY 12785',3275,222,NULL,32,4615,0);
INSERT INTO "django_geo_db_location" VALUES(8184,NULL,'White Lake, NY',3276,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8185,NULL,'White Lake, NY 12786',3276,222,NULL,32,4616,0);
INSERT INTO "django_geo_db_location" VALUES(8186,NULL,'White Sulphur Springs, NY',3277,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8187,NULL,'White Sulphur Springs, NY 12787',3277,222,NULL,32,4617,0);
INSERT INTO "django_geo_db_location" VALUES(8188,NULL,'Woodbourne, NY',3278,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8189,NULL,'Woodbourne, NY 12788',3278,222,NULL,32,4618,0);
INSERT INTO "django_geo_db_location" VALUES(8190,NULL,'Woodridge, NY',3279,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8191,NULL,'Woodridge, NY 12789',3279,222,NULL,32,4619,0);
INSERT INTO "django_geo_db_location" VALUES(8192,NULL,'Wurtsboro, NY',3280,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8193,NULL,'Wurtsboro, NY 12790',3280,222,NULL,32,4620,0);
INSERT INTO "django_geo_db_location" VALUES(8194,NULL,'Youngsville, NY',3281,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8195,NULL,'Youngsville, NY 12791',3281,222,NULL,32,4621,0);
INSERT INTO "django_geo_db_location" VALUES(8196,NULL,'Yulan, NY',3282,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8197,NULL,'Yulan, NY 12792',3282,222,NULL,32,4622,0);
INSERT INTO "django_geo_db_location" VALUES(8198,NULL,'Bethel, NY 12793',3223,222,NULL,32,4623,0);
INSERT INTO "django_geo_db_location" VALUES(8199,NULL,'Glens Falls, NY',3283,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8200,NULL,'Glens Falls, NY 12801',3283,222,NULL,32,4624,0);
INSERT INTO "django_geo_db_location" VALUES(8201,NULL,'South Glens Falls, NY',3284,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8202,NULL,'South Glens Falls, NY 12803',3284,222,NULL,32,4625,0);
INSERT INTO "django_geo_db_location" VALUES(8203,NULL,'Queensbury, NY',3285,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8204,NULL,'Queensbury, NY 12804',3285,222,NULL,32,4626,0);
INSERT INTO "django_geo_db_location" VALUES(8205,NULL,'Argyle, NY',3286,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8206,NULL,'Argyle, NY 12805',3286,222,NULL,32,4627,0);
INSERT INTO "django_geo_db_location" VALUES(8207,NULL,'New Baltimore, NY 12807',3003,222,NULL,32,4628,0);
INSERT INTO "django_geo_db_location" VALUES(8208,NULL,'Adirondack, NY',3287,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8209,NULL,'Adirondack, NY 12808',3287,222,NULL,32,4629,0);
INSERT INTO "django_geo_db_location" VALUES(8210,NULL,'Argyle, NY 12809',3286,222,NULL,32,4630,0);
INSERT INTO "django_geo_db_location" VALUES(8211,NULL,'Athol, NY',3288,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8212,NULL,'Athol, NY 12810',3288,222,NULL,32,4631,0);
INSERT INTO "django_geo_db_location" VALUES(8213,NULL,'Bakers Mills, NY',3289,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8214,NULL,'Bakers Mills, NY 12811',3289,222,NULL,32,4632,0);
INSERT INTO "django_geo_db_location" VALUES(8215,NULL,'Blue Mountain Lake, NY',3290,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8216,NULL,'Blue Mountain Lake, NY 12812',3290,222,NULL,32,4633,0);
INSERT INTO "django_geo_db_location" VALUES(8217,NULL,'Bolton Landing, NY',3291,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8218,NULL,'Bolton Landing, NY 12814',3291,222,NULL,32,4634,0);
INSERT INTO "django_geo_db_location" VALUES(8219,NULL,'Brant Lake, NY',3292,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8220,NULL,'Brant Lake, NY 12815',3292,222,NULL,32,4635,0);
INSERT INTO "django_geo_db_location" VALUES(8221,NULL,'Cambridge, NY',3293,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8222,NULL,'Cambridge, NY 12816',3293,222,NULL,32,4636,0);
INSERT INTO "django_geo_db_location" VALUES(8223,NULL,'Chestertown, NY',3294,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8224,NULL,'Chestertown, NY 12817',3294,222,NULL,32,4637,0);
INSERT INTO "django_geo_db_location" VALUES(8225,NULL,'Clemons, NY',3295,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8226,NULL,'Clemons, NY 12819',3295,222,NULL,32,4638,0);
INSERT INTO "django_geo_db_location" VALUES(8227,NULL,'Cleverdale, NY',3296,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8228,NULL,'Cleverdale, NY 12820',3296,222,NULL,32,4639,0);
INSERT INTO "django_geo_db_location" VALUES(8229,NULL,'Comstock, NY',3297,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8230,NULL,'Comstock, NY 12821',3297,222,NULL,32,4640,0);
INSERT INTO "django_geo_db_location" VALUES(8231,NULL,'Corinth, NY',3298,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8232,NULL,'Corinth, NY 12822',3298,222,NULL,32,4641,0);
INSERT INTO "django_geo_db_location" VALUES(8233,NULL,'Cossayuna, NY',3299,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8234,NULL,'Cossayuna, NY 12823',3299,222,NULL,32,4642,0);
INSERT INTO "django_geo_db_location" VALUES(8235,NULL,'Diamond Point, NY',3300,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8236,NULL,'Diamond Point, NY 12824',3300,222,NULL,32,4643,0);
INSERT INTO "django_geo_db_location" VALUES(8237,NULL,'Queensbury, NY 12825',3285,222,NULL,32,4644,0);
INSERT INTO "django_geo_db_location" VALUES(8238,NULL,'Fort Ann, NY',3301,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8239,NULL,'Fort Ann, NY 12827',3301,222,NULL,32,4645,0);
INSERT INTO "django_geo_db_location" VALUES(8240,NULL,'Fort Edward, NY',3302,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8241,NULL,'Fort Edward, NY 12828',3302,222,NULL,32,4646,0);
INSERT INTO "django_geo_db_location" VALUES(8242,NULL,'Wilton, NY',3303,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8243,NULL,'Wilton, NY 12830',3303,222,NULL,32,4647,0);
INSERT INTO "django_geo_db_location" VALUES(8244,NULL,'Gansevoort, NY',3304,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8245,NULL,'Gansevoort, NY 12831',3304,222,NULL,32,4648,0);
INSERT INTO "django_geo_db_location" VALUES(8246,NULL,'Granville, NY',3305,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8247,NULL,'Granville, NY 12832',3305,222,NULL,32,4649,0);
INSERT INTO "django_geo_db_location" VALUES(8248,NULL,'Greenfield Center, NY',3306,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8249,NULL,'Greenfield Center, NY 12833',3306,222,NULL,32,4650,0);
INSERT INTO "django_geo_db_location" VALUES(8250,NULL,'Greenwich, NY',3307,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8251,NULL,'Greenwich, NY 12834',3307,222,NULL,32,4651,0);
INSERT INTO "django_geo_db_location" VALUES(8252,NULL,'Hadley, NY',3308,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8253,NULL,'Hadley, NY 12835',3308,222,NULL,32,4652,0);
INSERT INTO "django_geo_db_location" VALUES(8254,NULL,'Hague, NY',3309,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8255,NULL,'Hague, NY 12836',3309,222,NULL,32,4653,0);
INSERT INTO "django_geo_db_location" VALUES(8256,NULL,'Hampton, NY',3310,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8257,NULL,'Hampton, NY 12837',3310,222,NULL,32,4654,0);
INSERT INTO "django_geo_db_location" VALUES(8258,NULL,'Hartford, NY',3311,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8259,NULL,'Hartford, NY 12838',3311,222,NULL,32,4655,0);
INSERT INTO "django_geo_db_location" VALUES(8260,NULL,'Hudson Falls, NY',3312,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8261,NULL,'Hudson Falls, NY 12839',3312,222,NULL,32,4656,0);
INSERT INTO "django_geo_db_location" VALUES(8262,NULL,'Huletts Landing, NY',3313,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8263,NULL,'Huletts Landing, NY 12841',3313,222,NULL,32,4657,0);
INSERT INTO "django_geo_db_location" VALUES(8264,NULL,'Indian Lake, NY',3314,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8265,NULL,'Indian Lake, NY 12842',3314,222,NULL,32,4658,0);
INSERT INTO "django_geo_db_location" VALUES(8266,NULL,'Johnsburg, NY',3315,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8267,NULL,'Johnsburg, NY 12843',3315,222,NULL,32,4659,0);
INSERT INTO "django_geo_db_location" VALUES(8268,NULL,'Kattskill Bay, NY',3316,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8269,NULL,'Kattskill Bay, NY 12844',3316,222,NULL,32,4660,0);
INSERT INTO "django_geo_db_location" VALUES(8270,NULL,'Lake George, NY',3317,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8271,NULL,'Lake George, NY 12845',3317,222,NULL,32,4661,0);
INSERT INTO "django_geo_db_location" VALUES(8272,NULL,'Lake Luzerne, NY',3318,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8273,NULL,'Lake Luzerne, NY 12846',3318,222,NULL,32,4662,0);
INSERT INTO "django_geo_db_location" VALUES(8274,NULL,'Long Lake, NY',3319,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8275,NULL,'Long Lake, NY 12847',3319,222,NULL,32,4663,0);
INSERT INTO "django_geo_db_location" VALUES(8276,NULL,'Middle Falls, NY',3320,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8277,NULL,'Middle Falls, NY 12848',3320,222,NULL,32,4664,0);
INSERT INTO "django_geo_db_location" VALUES(8278,NULL,'Middle Granville, NY',3321,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8279,NULL,'Middle Granville, NY 12849',3321,222,NULL,32,4665,0);
INSERT INTO "django_geo_db_location" VALUES(8280,NULL,'Middle Grove, NY',3322,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8281,NULL,'Middle Grove, NY 12850',3322,222,NULL,32,4666,0);
INSERT INTO "django_geo_db_location" VALUES(8282,NULL,'Minerva, NY',3323,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8283,NULL,'Minerva, NY 12851',3323,222,NULL,32,4667,0);
INSERT INTO "django_geo_db_location" VALUES(8284,NULL,'Newcomb, NY',3324,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8285,NULL,'Newcomb, NY 12852',3324,222,NULL,32,4668,0);
INSERT INTO "django_geo_db_location" VALUES(8286,NULL,'North Creek, NY',3325,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8287,NULL,'North Creek, NY 12853',3325,222,NULL,32,4669,0);
INSERT INTO "django_geo_db_location" VALUES(8288,NULL,'North Granville, NY',3326,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8289,NULL,'North Granville, NY 12854',3326,222,NULL,32,4670,0);
INSERT INTO "django_geo_db_location" VALUES(8290,NULL,'North Hudson, NY',3327,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8291,NULL,'North Hudson, NY 12855',3327,222,NULL,32,4671,0);
INSERT INTO "django_geo_db_location" VALUES(8292,NULL,'North River, NY',3328,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8293,NULL,'North River, NY 12856',3328,222,NULL,32,4672,0);
INSERT INTO "django_geo_db_location" VALUES(8294,NULL,'Olmstedville, NY',3329,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8295,NULL,'Olmstedville, NY 12857',3329,222,NULL,32,4673,0);
INSERT INTO "django_geo_db_location" VALUES(8296,NULL,'Paradox, NY',3330,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8297,NULL,'Paradox, NY 12858',3330,222,NULL,32,4674,0);
INSERT INTO "django_geo_db_location" VALUES(8298,NULL,'Porter Corners, NY',3331,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8299,NULL,'Porter Corners, NY 12859',3331,222,NULL,32,4675,0);
INSERT INTO "django_geo_db_location" VALUES(8300,NULL,'Pottersville, NY',3332,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8301,NULL,'Pottersville, NY 12860',3332,222,NULL,32,4676,0);
INSERT INTO "django_geo_db_location" VALUES(8302,NULL,'Putnam Station, NY',3333,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8303,NULL,'Putnam Station, NY 12861',3333,222,NULL,32,4677,0);
INSERT INTO "django_geo_db_location" VALUES(8304,NULL,'Riparius, NY',3334,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8305,NULL,'Riparius, NY 12862',3334,222,NULL,32,4678,0);
INSERT INTO "django_geo_db_location" VALUES(8306,NULL,'Rock City Falls, NY',3335,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8307,NULL,'Rock City Falls, NY 12863',3335,222,NULL,32,4679,0);
INSERT INTO "django_geo_db_location" VALUES(8308,NULL,'Sabael, NY',3336,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8309,NULL,'Sabael, NY 12864',3336,222,NULL,32,4680,0);
INSERT INTO "django_geo_db_location" VALUES(8310,NULL,'Salem, NY',3337,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8311,NULL,'Salem, NY 12865',3337,222,NULL,32,4681,0);
INSERT INTO "django_geo_db_location" VALUES(8312,NULL,'Saratoga Springs, NY',3338,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8313,NULL,'Saratoga Springs, NY 12866',3338,222,NULL,32,4682,0);
INSERT INTO "django_geo_db_location" VALUES(8314,NULL,'Schroon Lake, NY',3339,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8315,NULL,'Schroon Lake, NY 12870',3339,222,NULL,32,4683,0);
INSERT INTO "django_geo_db_location" VALUES(8316,NULL,'Schuylerville, NY',3340,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8317,NULL,'Schuylerville, NY 12871',3340,222,NULL,32,4684,0);
INSERT INTO "django_geo_db_location" VALUES(8318,NULL,'Severance, NY',3341,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8319,NULL,'Severance, NY 12872',3341,222,NULL,32,4685,0);
INSERT INTO "django_geo_db_location" VALUES(8320,NULL,'Shushan, NY',3342,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8321,NULL,'Shushan, NY 12873',3342,222,NULL,32,4686,0);
INSERT INTO "django_geo_db_location" VALUES(8322,NULL,'Silver Bay, NY',3343,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8323,NULL,'Silver Bay, NY 12874',3343,222,NULL,32,4687,0);
INSERT INTO "django_geo_db_location" VALUES(8324,NULL,'Whitehall, NY',3344,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8325,NULL,'Whitehall, NY 12877',3344,222,NULL,32,4688,0);
INSERT INTO "django_geo_db_location" VALUES(8326,NULL,'Stony Creek, NY',3345,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8327,NULL,'Stony Creek, NY 12878',3345,222,NULL,32,4689,0);
INSERT INTO "django_geo_db_location" VALUES(8328,NULL,'Newcomb, NY 12879',3324,222,NULL,32,4690,0);
INSERT INTO "django_geo_db_location" VALUES(8329,NULL,'Ticonderoga, NY',3346,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8330,NULL,'Ticonderoga, NY 12883',3346,222,NULL,32,4691,0);
INSERT INTO "django_geo_db_location" VALUES(8331,NULL,'Victory Mills, NY',3347,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8332,NULL,'Victory Mills, NY 12884',3347,222,NULL,32,4692,0);
INSERT INTO "django_geo_db_location" VALUES(8333,NULL,'Warrensburg, NY',3348,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8334,NULL,'Warrensburg, NY 12885',3348,222,NULL,32,4693,0);
INSERT INTO "django_geo_db_location" VALUES(8335,NULL,'Wevertown, NY',3349,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8336,NULL,'Wevertown, NY 12886',3349,222,NULL,32,4694,0);
INSERT INTO "django_geo_db_location" VALUES(8337,NULL,'Whitehall, NY 12887',3344,222,NULL,32,4695,0);
INSERT INTO "django_geo_db_location" VALUES(8338,NULL,'Plattsburgh, NY',3350,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8339,NULL,'Plattsburgh, NY 12901',3350,222,NULL,32,4696,0);
INSERT INTO "django_geo_db_location" VALUES(8340,NULL,'Plattsburgh, NY 12903',3350,222,NULL,32,4697,0);
INSERT INTO "django_geo_db_location" VALUES(8341,NULL,'Altona, NY',3351,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8342,NULL,'Altona, NY 12910',3351,222,NULL,32,4698,0);
INSERT INTO "django_geo_db_location" VALUES(8343,NULL,'Keeseville, NY',3352,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8344,NULL,'Keeseville, NY 12911',3352,222,NULL,32,4699,0);
INSERT INTO "django_geo_db_location" VALUES(8345,NULL,'Au Sable Forks, NY',3353,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8346,NULL,'Au Sable Forks, NY 12912',3353,222,NULL,32,4700,0);
INSERT INTO "django_geo_db_location" VALUES(8347,NULL,'Bloomingdale, NY',3354,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8348,NULL,'Bloomingdale, NY 12913',3354,222,NULL,32,4701,0);
INSERT INTO "django_geo_db_location" VALUES(8349,NULL,'Bombay, NY',3355,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8350,NULL,'Bombay, NY 12914',3355,222,NULL,32,4702,0);
INSERT INTO "django_geo_db_location" VALUES(8351,NULL,'Brainardsville, NY',3356,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8352,NULL,'Brainardsville, NY 12915',3356,222,NULL,32,4703,0);
INSERT INTO "django_geo_db_location" VALUES(8353,NULL,'Brushton, NY',3357,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8354,NULL,'Brushton, NY 12916',3357,222,NULL,32,4704,0);
INSERT INTO "django_geo_db_location" VALUES(8355,NULL,'Burke, NY',3358,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8356,NULL,'Burke, NY 12917',3358,222,NULL,32,4705,0);
INSERT INTO "django_geo_db_location" VALUES(8357,NULL,'Cadyville, NY',3359,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8358,NULL,'Cadyville, NY 12918',3359,222,NULL,32,4706,0);
INSERT INTO "django_geo_db_location" VALUES(8359,NULL,'Champlain, NY',3360,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8360,NULL,'Champlain, NY 12919',3360,222,NULL,32,4707,0);
INSERT INTO "django_geo_db_location" VALUES(8361,NULL,'Chateaugay, NY',3361,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8362,NULL,'Chateaugay, NY 12920',3361,222,NULL,32,4708,0);
INSERT INTO "django_geo_db_location" VALUES(8363,NULL,'Chazy, NY',3362,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8364,NULL,'Chazy, NY 12921',3362,222,NULL,32,4709,0);
INSERT INTO "django_geo_db_location" VALUES(8365,NULL,'Childwold, NY',3363,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8366,NULL,'Childwold, NY 12922',3363,222,NULL,32,4710,0);
INSERT INTO "django_geo_db_location" VALUES(8367,NULL,'Churubusco, NY',3364,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8368,NULL,'Churubusco, NY 12923',3364,222,NULL,32,4711,0);
INSERT INTO "django_geo_db_location" VALUES(8369,NULL,'Keeseville, NY 12924',3352,222,NULL,32,4712,0);
INSERT INTO "django_geo_db_location" VALUES(8370,NULL,'Constable, NY',3365,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8371,NULL,'Constable, NY 12926',3365,222,NULL,32,4713,0);
INSERT INTO "django_geo_db_location" VALUES(8372,NULL,'Cranberry Lake, NY',3366,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8373,NULL,'Cranberry Lake, NY 12927',3366,222,NULL,32,4714,0);
INSERT INTO "django_geo_db_location" VALUES(8374,NULL,'Crown Point, NY',3367,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8375,NULL,'Crown Point, NY 12928',3367,222,NULL,32,4715,0);
INSERT INTO "django_geo_db_location" VALUES(8376,NULL,'Dannemora, NY',3368,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8377,NULL,'Dannemora, NY 12929',3368,222,NULL,32,4716,0);
INSERT INTO "django_geo_db_location" VALUES(8378,NULL,'Dickinson Center, NY',3369,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8379,NULL,'Dickinson Center, NY 12930',3369,222,NULL,32,4717,0);
INSERT INTO "django_geo_db_location" VALUES(8380,NULL,'Elizabethtown, NY',3370,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8381,NULL,'Elizabethtown, NY 12932',3370,222,NULL,32,4718,0);
INSERT INTO "django_geo_db_location" VALUES(8382,NULL,'Ellenburg, NY 12933',3252,222,NULL,32,4719,0);
INSERT INTO "django_geo_db_location" VALUES(8383,NULL,'Ellenburg Center, NY',3371,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8384,NULL,'Ellenburg Center, NY 12934',3371,222,NULL,32,4720,0);
INSERT INTO "django_geo_db_location" VALUES(8385,NULL,'Ellenburg Depot, NY',3372,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8386,NULL,'Ellenburg Depot, NY 12935',3372,222,NULL,32,4721,0);
INSERT INTO "django_geo_db_location" VALUES(8387,NULL,'Essex, NY',3373,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8388,NULL,'Essex, NY 12936',3373,222,NULL,32,4722,0);
INSERT INTO "django_geo_db_location" VALUES(8389,NULL,'Fort Covington, NY',3374,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8390,NULL,'Fort Covington, NY 12937',3374,222,NULL,32,4723,0);
INSERT INTO "django_geo_db_location" VALUES(8391,NULL,'Pleasant Valley, NY 12938',3198,222,NULL,32,4724,0);
INSERT INTO "django_geo_db_location" VALUES(8392,NULL,'Gabriels, NY',3375,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8393,NULL,'Gabriels, NY 12939',3375,222,NULL,32,4725,0);
INSERT INTO "django_geo_db_location" VALUES(8394,NULL,'Jay, NY',3376,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8395,NULL,'Jay, NY 12941',3376,222,NULL,32,4726,0);
INSERT INTO "django_geo_db_location" VALUES(8396,NULL,'Keene, NY',3377,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8397,NULL,'Keene, NY 12942',3377,222,NULL,32,4727,0);
INSERT INTO "django_geo_db_location" VALUES(8398,NULL,'Keene Valley, NY',3378,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8399,NULL,'Keene Valley, NY 12943',3378,222,NULL,32,4728,0);
INSERT INTO "django_geo_db_location" VALUES(8400,NULL,'Keeseville, NY 12944',3352,222,NULL,32,4729,0);
INSERT INTO "django_geo_db_location" VALUES(8401,NULL,'Lake Clear, NY',3379,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8402,NULL,'Lake Clear, NY 12945',3379,222,NULL,32,4730,0);
INSERT INTO "django_geo_db_location" VALUES(8403,NULL,'Lake Placid, NY',3380,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8404,NULL,'Lake Placid, NY 12946',3380,222,NULL,32,4731,0);
INSERT INTO "django_geo_db_location" VALUES(8405,NULL,'Lawrenceville, NY',3381,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8406,NULL,'Lawrenceville, NY 12949',3381,222,NULL,32,4732,0);
INSERT INTO "django_geo_db_location" VALUES(8407,NULL,'Lewis, NY',3382,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8408,NULL,'Lewis, NY 12950',3382,222,NULL,32,4733,0);
INSERT INTO "django_geo_db_location" VALUES(8409,NULL,'Lyon Mountain, NY',3383,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8410,NULL,'Lyon Mountain, NY 12952',3383,222,NULL,32,4734,0);
INSERT INTO "django_geo_db_location" VALUES(8411,NULL,'Malone, NY',3384,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8412,NULL,'Malone, NY 12953',3384,222,NULL,32,4735,0);
INSERT INTO "django_geo_db_location" VALUES(8413,NULL,'Lyon Mountain, NY 12955',3383,222,NULL,32,4736,0);
INSERT INTO "django_geo_db_location" VALUES(8414,NULL,'Mineville, NY',3385,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8415,NULL,'Mineville, NY 12956',3385,222,NULL,32,4737,0);
INSERT INTO "django_geo_db_location" VALUES(8416,NULL,'Moira, NY 12957',3219,222,NULL,32,4738,0);
INSERT INTO "django_geo_db_location" VALUES(8417,NULL,'Mooers, NY',3386,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8418,NULL,'Mooers, NY 12958',3386,222,NULL,32,4739,0);
INSERT INTO "django_geo_db_location" VALUES(8419,NULL,'Mooers Forks, NY',3387,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8420,NULL,'Mooers Forks, NY 12959',3387,222,NULL,32,4740,0);
INSERT INTO "django_geo_db_location" VALUES(8421,NULL,'Moriah, NY',3388,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8422,NULL,'Moriah, NY 12960',3388,222,NULL,32,4741,0);
INSERT INTO "django_geo_db_location" VALUES(8423,NULL,'Moriah Center, NY',3389,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8424,NULL,'Moriah Center, NY 12961',3389,222,NULL,32,4742,0);
INSERT INTO "django_geo_db_location" VALUES(8425,NULL,'Morrisonville, NY',3390,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8426,NULL,'Morrisonville, NY 12962',3390,222,NULL,32,4743,0);
INSERT INTO "django_geo_db_location" VALUES(8427,NULL,'New Russia, NY',3391,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8428,NULL,'New Russia, NY 12964',3391,222,NULL,32,4744,0);
INSERT INTO "django_geo_db_location" VALUES(8429,NULL,'Nicholville, NY',3392,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8430,NULL,'Nicholville, NY 12965',3392,222,NULL,32,4745,0);
INSERT INTO "django_geo_db_location" VALUES(8431,NULL,'North Bangor, NY',3393,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8432,NULL,'North Bangor, NY 12966',3393,222,NULL,32,4746,0);
INSERT INTO "django_geo_db_location" VALUES(8433,NULL,'North Lawrence, NY',3394,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8434,NULL,'North Lawrence, NY 12967',3394,222,NULL,32,4747,0);
INSERT INTO "django_geo_db_location" VALUES(8435,NULL,'Owls Head, NY',3395,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8436,NULL,'Owls Head, NY 12969',3395,222,NULL,32,4748,0);
INSERT INTO "django_geo_db_location" VALUES(8437,NULL,'Paul Smiths, NY',3396,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8438,NULL,'Paul Smiths, NY 12970',3396,222,NULL,32,4749,0);
INSERT INTO "django_geo_db_location" VALUES(8439,NULL,'Peru, NY',3397,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8440,NULL,'Peru, NY 12972',3397,222,NULL,32,4750,0);
INSERT INTO "django_geo_db_location" VALUES(8441,NULL,'Piercefield, NY',3398,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8442,NULL,'Piercefield, NY 12973',3398,222,NULL,32,4751,0);
INSERT INTO "django_geo_db_location" VALUES(8443,NULL,'Port Henry, NY',3399,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8444,NULL,'Port Henry, NY 12974',3399,222,NULL,32,4752,0);
INSERT INTO "django_geo_db_location" VALUES(8445,NULL,'Port Kent, NY',3400,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8446,NULL,'Port Kent, NY 12975',3400,222,NULL,32,4753,0);
INSERT INTO "django_geo_db_location" VALUES(8447,NULL,'Rainbow Lake, NY',3401,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8448,NULL,'Rainbow Lake, NY 12976',3401,222,NULL,32,4754,0);
INSERT INTO "django_geo_db_location" VALUES(8449,NULL,'Ray Brook, NY',3402,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8450,NULL,'Ray Brook, NY 12977',3402,222,NULL,32,4755,0);
INSERT INTO "django_geo_db_location" VALUES(8451,NULL,'Redford, NY',3403,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8452,NULL,'Redford, NY 12978',3403,222,NULL,32,4756,0);
INSERT INTO "django_geo_db_location" VALUES(8453,NULL,'Rouses Point, NY',3404,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8454,NULL,'Rouses Point, NY 12979',3404,222,NULL,32,4757,0);
INSERT INTO "django_geo_db_location" VALUES(8455,NULL,'Saint Regis Falls, NY',3405,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8456,NULL,'Saint Regis Falls, NY 12980',3405,222,NULL,32,4758,0);
INSERT INTO "django_geo_db_location" VALUES(8457,NULL,'Saranac, NY',3406,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8458,NULL,'Saranac, NY 12981',3406,222,NULL,32,4759,0);
INSERT INTO "django_geo_db_location" VALUES(8459,NULL,'Saranac Lake, NY',3407,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8460,NULL,'Saranac Lake, NY 12983',3407,222,NULL,32,4760,0);
INSERT INTO "django_geo_db_location" VALUES(8461,NULL,'Schuyler Falls, NY',3408,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8462,NULL,'Schuyler Falls, NY 12985',3408,222,NULL,32,4761,0);
INSERT INTO "django_geo_db_location" VALUES(8463,NULL,'Tupper Lake, NY',3409,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8464,NULL,'Tupper Lake, NY 12986',3409,222,NULL,32,4762,0);
INSERT INTO "django_geo_db_location" VALUES(8465,NULL,'Upper Jay, NY',3410,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8466,NULL,'Upper Jay, NY 12987',3410,222,NULL,32,4763,0);
INSERT INTO "django_geo_db_location" VALUES(8467,NULL,'Vermontville, NY',3411,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8468,NULL,'Vermontville, NY 12989',3411,222,NULL,32,4764,0);
INSERT INTO "django_geo_db_location" VALUES(8469,NULL,'West Chazy, NY',3412,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8470,NULL,'West Chazy, NY 12992',3412,222,NULL,32,4765,0);
INSERT INTO "django_geo_db_location" VALUES(8471,NULL,'Westport, NY',3413,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8472,NULL,'Westport, NY 12993',3413,222,NULL,32,4766,0);
INSERT INTO "django_geo_db_location" VALUES(8473,NULL,'Whippleville, NY',3414,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8474,NULL,'Whippleville, NY 12995',3414,222,NULL,32,4767,0);
INSERT INTO "django_geo_db_location" VALUES(8475,NULL,'Willsboro, NY',3415,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8476,NULL,'Willsboro, NY 12996',3415,222,NULL,32,4768,0);
INSERT INTO "django_geo_db_location" VALUES(8477,NULL,'Wilmington, NY',3416,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8478,NULL,'Wilmington, NY 12997',3416,222,NULL,32,4769,0);
INSERT INTO "django_geo_db_location" VALUES(8479,NULL,'Witherbee, NY',3417,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8480,NULL,'Witherbee, NY 12998',3417,222,NULL,32,4770,0);
INSERT INTO "django_geo_db_location" VALUES(8481,NULL,'Apulia Station, NY',3418,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8482,NULL,'Apulia Station, NY 13020',3418,222,NULL,32,4771,0);
INSERT INTO "django_geo_db_location" VALUES(8483,NULL,'Auburn, NY',3419,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8484,NULL,'Auburn, NY 13021',3419,222,NULL,32,4772,0);
INSERT INTO "django_geo_db_location" VALUES(8485,NULL,'Auburn, NY 13022',3419,222,NULL,32,4773,0);
INSERT INTO "django_geo_db_location" VALUES(8486,NULL,'Auburn, NY 13024',3419,222,NULL,32,4774,0);
INSERT INTO "django_geo_db_location" VALUES(8487,NULL,'Aurora, NY',3420,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8488,NULL,'Aurora, NY 13026',3420,222,NULL,32,4775,0);
INSERT INTO "django_geo_db_location" VALUES(8489,NULL,'Baldwinsville, NY',3421,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8490,NULL,'Baldwinsville, NY 13027',3421,222,NULL,32,4776,0);
INSERT INTO "django_geo_db_location" VALUES(8491,NULL,'Bernhards Bay, NY',3422,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8492,NULL,'Bernhards Bay, NY 13028',3422,222,NULL,32,4777,0);
INSERT INTO "django_geo_db_location" VALUES(8493,NULL,'Brewerton, NY',3423,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8494,NULL,'Brewerton, NY 13029',3423,222,NULL,32,4778,0);
INSERT INTO "django_geo_db_location" VALUES(8495,NULL,'Bridgeport, NY',3424,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8496,NULL,'Bridgeport, NY 13030',3424,222,NULL,32,4779,0);
INSERT INTO "django_geo_db_location" VALUES(8497,NULL,'Camillus, NY',3425,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8498,NULL,'Camillus, NY 13031',3425,222,NULL,32,4780,0);
INSERT INTO "django_geo_db_location" VALUES(8499,NULL,'Canastota, NY',3426,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8500,NULL,'Canastota, NY 13032',3426,222,NULL,32,4781,0);
INSERT INTO "django_geo_db_location" VALUES(8501,NULL,'Cato, NY',3427,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8502,NULL,'Cato, NY 13033',3427,222,NULL,32,4782,0);
INSERT INTO "django_geo_db_location" VALUES(8503,NULL,'Cayuga, NY',3428,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8504,NULL,'Cayuga, NY 13034',3428,222,NULL,32,4783,0);
INSERT INTO "django_geo_db_location" VALUES(8505,NULL,'Cazenovia, NY',3429,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8506,NULL,'Cazenovia, NY 13035',3429,222,NULL,32,4784,0);
INSERT INTO "django_geo_db_location" VALUES(8507,NULL,'Central Square, NY',3430,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8508,NULL,'Central Square, NY 13036',3430,222,NULL,32,4785,0);
INSERT INTO "django_geo_db_location" VALUES(8509,NULL,'Chittenango, NY',3431,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8510,NULL,'Chittenango, NY 13037',3431,222,NULL,32,4786,0);
INSERT INTO "django_geo_db_location" VALUES(8511,NULL,'Cicero, NY',3432,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8512,NULL,'Cicero, NY 13039',3432,222,NULL,32,4787,0);
INSERT INTO "django_geo_db_location" VALUES(8513,NULL,'Cincinnatus, NY',3433,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8514,NULL,'Cincinnatus, NY 13040',3433,222,NULL,32,4788,0);
INSERT INTO "django_geo_db_location" VALUES(8515,NULL,'Clay, NY',3434,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8516,NULL,'Clay, NY 13041',3434,222,NULL,32,4789,0);
INSERT INTO "django_geo_db_location" VALUES(8517,NULL,'Cleveland, NY',3435,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8518,NULL,'Cleveland, NY 13042',3435,222,NULL,32,4790,0);
INSERT INTO "django_geo_db_location" VALUES(8519,NULL,'Clockville, NY',3436,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8520,NULL,'Clockville, NY 13043',3436,222,NULL,32,4791,0);
INSERT INTO "django_geo_db_location" VALUES(8521,NULL,'Constantia, NY',3437,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8522,NULL,'Constantia, NY 13044',3437,222,NULL,32,4792,0);
INSERT INTO "django_geo_db_location" VALUES(8523,NULL,'Cortland, NY',3438,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8524,NULL,'Cortland, NY 13045',3438,222,NULL,32,4793,0);
INSERT INTO "django_geo_db_location" VALUES(8525,NULL,'Delphi Falls, NY',3439,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8526,NULL,'Delphi Falls, NY 13051',3439,222,NULL,32,4794,0);
INSERT INTO "django_geo_db_location" VALUES(8527,NULL,'De Ruyter, NY',3440,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8528,NULL,'De Ruyter, NY 13052',3440,222,NULL,32,4795,0);
INSERT INTO "django_geo_db_location" VALUES(8529,NULL,'Dryden, NY',3441,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8530,NULL,'Dryden, NY 13053',3441,222,NULL,32,4796,0);
INSERT INTO "django_geo_db_location" VALUES(8531,NULL,'Durhamville, NY',3442,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8532,NULL,'Durhamville, NY 13054',3442,222,NULL,32,4797,0);
INSERT INTO "django_geo_db_location" VALUES(8533,NULL,'East Homer, NY',3443,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8534,NULL,'East Homer, NY 13056',3443,222,NULL,32,4798,0);
INSERT INTO "django_geo_db_location" VALUES(8535,NULL,'East Syracuse, NY',3444,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8536,NULL,'East Syracuse, NY 13057',3444,222,NULL,32,4799,0);
INSERT INTO "django_geo_db_location" VALUES(8537,NULL,'Elbridge, NY',3445,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8538,NULL,'Elbridge, NY 13060',3445,222,NULL,32,4800,0);
INSERT INTO "django_geo_db_location" VALUES(8539,NULL,'Erieville, NY',3446,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8540,NULL,'Erieville, NY 13061',3446,222,NULL,32,4801,0);
INSERT INTO "django_geo_db_location" VALUES(8541,NULL,'Etna, NY',3447,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8542,NULL,'Etna, NY 13062',3447,222,NULL,32,4802,0);
INSERT INTO "django_geo_db_location" VALUES(8543,NULL,'Fabius, NY',3448,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8544,NULL,'Fabius, NY 13063',3448,222,NULL,32,4803,0);
INSERT INTO "django_geo_db_location" VALUES(8545,NULL,'Fair Haven, NY',3449,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8546,NULL,'Fair Haven, NY 13064',3449,222,NULL,32,4804,0);
INSERT INTO "django_geo_db_location" VALUES(8547,NULL,'Fayette, NY',3450,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8548,NULL,'Fayette, NY 13065',3450,222,NULL,32,4805,0);
INSERT INTO "django_geo_db_location" VALUES(8549,NULL,'Fayetteville, NY',3451,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8550,NULL,'Fayetteville, NY 13066',3451,222,NULL,32,4806,0);
INSERT INTO "django_geo_db_location" VALUES(8551,NULL,'Freeville, NY',3452,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8552,NULL,'Freeville, NY 13068',3452,222,NULL,32,4807,0);
INSERT INTO "django_geo_db_location" VALUES(8553,NULL,'Fulton, NY',3453,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8554,NULL,'Fulton, NY 13069',3453,222,NULL,32,4808,0);
INSERT INTO "django_geo_db_location" VALUES(8555,NULL,'Genoa, NY',3454,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8556,NULL,'Genoa, NY 13071',3454,222,NULL,32,4809,0);
INSERT INTO "django_geo_db_location" VALUES(8557,NULL,'Georgetown, NY',3455,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8558,NULL,'Georgetown, NY 13072',3455,222,NULL,32,4810,0);
INSERT INTO "django_geo_db_location" VALUES(8559,NULL,'Groton, NY',3456,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8560,NULL,'Groton, NY 13073',3456,222,NULL,32,4811,0);
INSERT INTO "django_geo_db_location" VALUES(8561,NULL,'Hannibal, NY',3457,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8562,NULL,'Hannibal, NY 13074',3457,222,NULL,32,4812,0);
INSERT INTO "django_geo_db_location" VALUES(8563,NULL,'Hastings, NY',3458,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8564,NULL,'Hastings, NY 13076',3458,222,NULL,32,4813,0);
INSERT INTO "django_geo_db_location" VALUES(8565,NULL,'Homer, NY',3459,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8566,NULL,'Homer, NY 13077',3459,222,NULL,32,4814,0);
INSERT INTO "django_geo_db_location" VALUES(8567,NULL,'Jamesville, NY',3460,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8568,NULL,'Jamesville, NY 13078',3460,222,NULL,32,4815,0);
INSERT INTO "django_geo_db_location" VALUES(8569,NULL,'Jordan, NY',3461,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8570,NULL,'Jordan, NY 13080',3461,222,NULL,32,4816,0);
INSERT INTO "django_geo_db_location" VALUES(8571,NULL,'King Ferry, NY',3462,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8572,NULL,'King Ferry, NY 13081',3462,222,NULL,32,4817,0);
INSERT INTO "django_geo_db_location" VALUES(8573,NULL,'Kirkville, NY',3463,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8574,NULL,'Kirkville, NY 13082',3463,222,NULL,32,4818,0);
INSERT INTO "django_geo_db_location" VALUES(8575,NULL,'Lacona, NY',3464,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8576,NULL,'Lacona, NY 13083',3464,222,NULL,32,4819,0);
INSERT INTO "django_geo_db_location" VALUES(8577,NULL,'La Fayette, NY',3465,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8578,NULL,'La Fayette, NY 13084',3465,222,NULL,32,4820,0);
INSERT INTO "django_geo_db_location" VALUES(8579,NULL,'Little York, NY',3466,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8580,NULL,'Little York, NY 13087',3466,222,NULL,32,4821,0);
INSERT INTO "django_geo_db_location" VALUES(8581,NULL,'Liverpool, NY',3467,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8582,NULL,'Liverpool, NY 13088',3467,222,NULL,32,4822,0);
INSERT INTO "django_geo_db_location" VALUES(8583,NULL,'Liverpool, NY 13089',3467,222,NULL,32,4823,0);
INSERT INTO "django_geo_db_location" VALUES(8584,NULL,'Liverpool, NY 13090',3467,222,NULL,32,4824,0);
INSERT INTO "django_geo_db_location" VALUES(8585,NULL,'Locke, NY',3468,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8586,NULL,'Locke, NY 13092',3468,222,NULL,32,4825,0);
INSERT INTO "django_geo_db_location" VALUES(8587,NULL,'Lycoming, NY',3469,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8588,NULL,'Lycoming, NY 13093',3469,222,NULL,32,4826,0);
INSERT INTO "django_geo_db_location" VALUES(8589,NULL,'McGraw, NY',3470,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8590,NULL,'McGraw, NY 13101',3470,222,NULL,32,4827,0);
INSERT INTO "django_geo_db_location" VALUES(8591,NULL,'McLean, NY',3471,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8592,NULL,'McLean, NY 13102',3471,222,NULL,32,4828,0);
INSERT INTO "django_geo_db_location" VALUES(8593,NULL,'Mallory, NY',3472,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8594,NULL,'Mallory, NY 13103',3472,222,NULL,32,4829,0);
INSERT INTO "django_geo_db_location" VALUES(8595,NULL,'Manlius, NY',3473,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8596,NULL,'Manlius, NY 13104',3473,222,NULL,32,4830,0);
INSERT INTO "django_geo_db_location" VALUES(8597,NULL,'Maple View, NY',3474,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8598,NULL,'Maple View, NY 13107',3474,222,NULL,32,4831,0);
INSERT INTO "django_geo_db_location" VALUES(8599,NULL,'Marcellus, NY',3475,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8600,NULL,'Marcellus, NY 13108',3475,222,NULL,32,4832,0);
INSERT INTO "django_geo_db_location" VALUES(8601,NULL,'Marietta, NY',3476,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8602,NULL,'Marietta, NY 13110',3476,222,NULL,32,4833,0);
INSERT INTO "django_geo_db_location" VALUES(8603,NULL,'Martville, NY',3477,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8604,NULL,'Martville, NY 13111',3477,222,NULL,32,4834,0);
INSERT INTO "django_geo_db_location" VALUES(8605,NULL,'Memphis, NY',3478,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8606,NULL,'Memphis, NY 13112',3478,222,NULL,32,4835,0);
INSERT INTO "django_geo_db_location" VALUES(8607,NULL,'Meridian, NY',3479,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8608,NULL,'Meridian, NY 13113',3479,222,NULL,32,4836,0);
INSERT INTO "django_geo_db_location" VALUES(8609,NULL,'Mexico, NY',3480,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8610,NULL,'Mexico, NY 13114',3480,222,NULL,32,4837,0);
INSERT INTO "django_geo_db_location" VALUES(8611,NULL,'Minetto, NY',3481,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8612,NULL,'Minetto, NY 13115',3481,222,NULL,32,4838,0);
INSERT INTO "django_geo_db_location" VALUES(8613,NULL,'Minoa, NY',3482,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8614,NULL,'Minoa, NY 13116',3482,222,NULL,32,4839,0);
INSERT INTO "django_geo_db_location" VALUES(8615,NULL,'Montezuma, NY',3483,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8616,NULL,'Montezuma, NY 13117',3483,222,NULL,32,4840,0);
INSERT INTO "django_geo_db_location" VALUES(8617,NULL,'Moravia, NY',3484,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8618,NULL,'Moravia, NY 13118',3484,222,NULL,32,4841,0);
INSERT INTO "django_geo_db_location" VALUES(8619,NULL,'Mottville, NY',3485,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8620,NULL,'Mottville, NY 13119',3485,222,NULL,32,4842,0);
INSERT INTO "django_geo_db_location" VALUES(8621,NULL,'Nedrow, NY',3486,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8622,NULL,'Nedrow, NY 13120',3486,222,NULL,32,4843,0);
INSERT INTO "django_geo_db_location" VALUES(8623,NULL,'New Haven, NY',3487,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8624,NULL,'New Haven, NY 13121',3487,222,NULL,32,4844,0);
INSERT INTO "django_geo_db_location" VALUES(8625,NULL,'New Woodstock, NY',3488,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8626,NULL,'New Woodstock, NY 13122',3488,222,NULL,32,4845,0);
INSERT INTO "django_geo_db_location" VALUES(8627,NULL,'North Bay, NY',3489,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8628,NULL,'North Bay, NY 13123',3489,222,NULL,32,4846,0);
INSERT INTO "django_geo_db_location" VALUES(8629,NULL,'North Pitcher, NY',3490,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8630,NULL,'North Pitcher, NY 13124',3490,222,NULL,32,4847,0);
INSERT INTO "django_geo_db_location" VALUES(8631,NULL,'Oswego, NY',3491,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8632,NULL,'Oswego, NY 13126',3491,222,NULL,32,4848,0);
INSERT INTO "django_geo_db_location" VALUES(8633,NULL,'Georgetown, NY 13129',3455,222,NULL,32,4849,0);
INSERT INTO "django_geo_db_location" VALUES(8634,NULL,'Parish, NY',3492,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8635,NULL,'Parish, NY 13131',3492,222,NULL,32,4850,0);
INSERT INTO "django_geo_db_location" VALUES(8636,NULL,'Pennellville, NY',3493,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8637,NULL,'Pennellville, NY 13132',3493,222,NULL,32,4851,0);
INSERT INTO "django_geo_db_location" VALUES(8638,NULL,'Colesville, NY',3494,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8639,NULL,'Colesville, NY 13133',3494,222,NULL,32,4852,0);
INSERT INTO "django_geo_db_location" VALUES(8640,NULL,'Peterboro, NY',3495,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8641,NULL,'Peterboro, NY 13134',3495,222,NULL,32,4853,0);
INSERT INTO "django_geo_db_location" VALUES(8642,NULL,'Phoenix, NY',3496,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8643,NULL,'Phoenix, NY 13135',3496,222,NULL,32,4854,0);
INSERT INTO "django_geo_db_location" VALUES(8644,NULL,'Pitcher, NY',3497,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8645,NULL,'Pitcher, NY 13136',3497,222,NULL,32,4855,0);
INSERT INTO "django_geo_db_location" VALUES(8646,NULL,'Plainville, NY',3498,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8647,NULL,'Plainville, NY 13137',3498,222,NULL,32,4856,0);
INSERT INTO "django_geo_db_location" VALUES(8648,NULL,'Pompey, NY',3499,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8649,NULL,'Pompey, NY 13138',3499,222,NULL,32,4857,0);
INSERT INTO "django_geo_db_location" VALUES(8650,NULL,'Poplar Ridge, NY',3500,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8651,NULL,'Poplar Ridge, NY 13139',3500,222,NULL,32,4858,0);
INSERT INTO "django_geo_db_location" VALUES(8652,NULL,'Port Byron, NY',3501,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8653,NULL,'Port Byron, NY 13140',3501,222,NULL,32,4859,0);
INSERT INTO "django_geo_db_location" VALUES(8654,NULL,'Preble, NY',3502,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8655,NULL,'Preble, NY 13141',3502,222,NULL,32,4860,0);
INSERT INTO "django_geo_db_location" VALUES(8656,NULL,'Pulaski, NY',3503,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8657,NULL,'Pulaski, NY 13142',3503,222,NULL,32,4861,0);
INSERT INTO "django_geo_db_location" VALUES(8658,NULL,'Red Creek, NY',3504,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8659,NULL,'Red Creek, NY 13143',3504,222,NULL,32,4862,0);
INSERT INTO "django_geo_db_location" VALUES(8660,NULL,'Richland, NY',3505,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8661,NULL,'Richland, NY 13144',3505,222,NULL,32,4863,0);
INSERT INTO "django_geo_db_location" VALUES(8662,NULL,'Sandy Creek, NY',3506,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8663,NULL,'Sandy Creek, NY 13145',3506,222,NULL,32,4864,0);
INSERT INTO "django_geo_db_location" VALUES(8664,NULL,'Savannah, NY',3507,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8665,NULL,'Savannah, NY 13146',3507,222,NULL,32,4865,0);
INSERT INTO "django_geo_db_location" VALUES(8666,NULL,'Scipio Center, NY',3508,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8667,NULL,'Scipio Center, NY 13147',3508,222,NULL,32,4866,0);
INSERT INTO "django_geo_db_location" VALUES(8668,NULL,'Seneca Falls, NY',3509,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8669,NULL,'Seneca Falls, NY 13148',3509,222,NULL,32,4867,0);
INSERT INTO "django_geo_db_location" VALUES(8670,NULL,'Preble, NY 13149',3502,222,NULL,32,4868,0);
INSERT INTO "django_geo_db_location" VALUES(8671,NULL,'Skaneateles, NY',3510,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8672,NULL,'Skaneateles, NY 13152',3510,222,NULL,32,4869,0);
INSERT INTO "django_geo_db_location" VALUES(8673,NULL,'Skaneateles Falls, NY',3511,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8674,NULL,'Skaneateles Falls, NY 13153',3511,222,NULL,32,4870,0);
INSERT INTO "django_geo_db_location" VALUES(8675,NULL,'South Butler, NY',3512,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8676,NULL,'South Butler, NY 13154',3512,222,NULL,32,4871,0);
INSERT INTO "django_geo_db_location" VALUES(8677,NULL,'South Otselic, NY',3513,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8678,NULL,'South Otselic, NY 13155',3513,222,NULL,32,4872,0);
INSERT INTO "django_geo_db_location" VALUES(8679,NULL,'Sterling, NY',3514,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8680,NULL,'Sterling, NY 13156',3514,222,NULL,32,4873,0);
INSERT INTO "django_geo_db_location" VALUES(8681,NULL,'Sylvan Beach, NY',3515,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8682,NULL,'Sylvan Beach, NY 13157',3515,222,NULL,32,4874,0);
INSERT INTO "django_geo_db_location" VALUES(8683,NULL,'Truxton, NY',3516,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8684,NULL,'Truxton, NY 13158',3516,222,NULL,32,4875,0);
INSERT INTO "django_geo_db_location" VALUES(8685,NULL,'Tully, NY',3517,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8686,NULL,'Tully, NY 13159',3517,222,NULL,32,4876,0);
INSERT INTO "django_geo_db_location" VALUES(8687,NULL,'Union Springs, NY',3518,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8688,NULL,'Union Springs, NY 13160',3518,222,NULL,32,4877,0);
INSERT INTO "django_geo_db_location" VALUES(8689,NULL,'Verona Beach, NY',3519,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8690,NULL,'Verona Beach, NY 13162',3519,222,NULL,32,4878,0);
INSERT INTO "django_geo_db_location" VALUES(8691,NULL,'Wampsville, NY',3520,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8692,NULL,'Wampsville, NY 13163',3520,222,NULL,32,4879,0);
INSERT INTO "django_geo_db_location" VALUES(8693,NULL,'Warners, NY',3521,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8694,NULL,'Warners, NY 13164',3521,222,NULL,32,4880,0);
INSERT INTO "django_geo_db_location" VALUES(8695,NULL,'Waterloo, NY',3522,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8696,NULL,'Waterloo, NY 13165',3522,222,NULL,32,4881,0);
INSERT INTO "django_geo_db_location" VALUES(8697,NULL,'Weedsport, NY',3523,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8698,NULL,'Weedsport, NY 13166',3523,222,NULL,32,4882,0);
INSERT INTO "django_geo_db_location" VALUES(8699,NULL,'West Monroe, NY',3524,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8700,NULL,'West Monroe, NY 13167',3524,222,NULL,32,4883,0);
INSERT INTO "django_geo_db_location" VALUES(8701,NULL,'Syracuse, NY',3525,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8702,NULL,'Syracuse, NY 13201',3525,222,NULL,32,4884,0);
INSERT INTO "django_geo_db_location" VALUES(8703,NULL,'Syracuse, NY 13202',3525,222,NULL,32,4885,0);
INSERT INTO "django_geo_db_location" VALUES(8704,NULL,'Syracuse, NY 13203',3525,222,NULL,32,4886,0);
INSERT INTO "django_geo_db_location" VALUES(8705,NULL,'Syracuse, NY 13204',3525,222,NULL,32,4887,0);
INSERT INTO "django_geo_db_location" VALUES(8706,NULL,'Syracuse, NY 13205',3525,222,NULL,32,4888,0);
INSERT INTO "django_geo_db_location" VALUES(8707,NULL,'Syracuse, NY 13206',3525,222,NULL,32,4889,0);
INSERT INTO "django_geo_db_location" VALUES(8708,NULL,'Syracuse, NY 13207',3525,222,NULL,32,4890,0);
INSERT INTO "django_geo_db_location" VALUES(8709,NULL,'Syracuse, NY 13208',3525,222,NULL,32,4891,0);
INSERT INTO "django_geo_db_location" VALUES(8710,NULL,'Syracuse, NY 13209',3525,222,NULL,32,4892,0);
INSERT INTO "django_geo_db_location" VALUES(8711,NULL,'Syracuse, NY 13210',3525,222,NULL,32,4893,0);
INSERT INTO "django_geo_db_location" VALUES(8712,NULL,'Syracuse, NY 13211',3525,222,NULL,32,4894,0);
INSERT INTO "django_geo_db_location" VALUES(8713,NULL,'Syracuse, NY 13212',3525,222,NULL,32,4895,0);
INSERT INTO "django_geo_db_location" VALUES(8714,NULL,'Syracuse, NY 13214',3525,222,NULL,32,4896,0);
INSERT INTO "django_geo_db_location" VALUES(8715,NULL,'Syracuse, NY 13215',3525,222,NULL,32,4897,0);
INSERT INTO "django_geo_db_location" VALUES(8716,NULL,'Syracuse, NY 13217',3525,222,NULL,32,4898,0);
INSERT INTO "django_geo_db_location" VALUES(8717,NULL,'Syracuse, NY 13218',3525,222,NULL,32,4899,0);
INSERT INTO "django_geo_db_location" VALUES(8718,NULL,'Syracuse, NY 13219',3525,222,NULL,32,4900,0);
INSERT INTO "django_geo_db_location" VALUES(8719,NULL,'Syracuse, NY 13220',3525,222,NULL,32,4901,0);
INSERT INTO "django_geo_db_location" VALUES(8720,NULL,'Syracuse, NY 13221',3525,222,NULL,32,4902,0);
INSERT INTO "django_geo_db_location" VALUES(8721,NULL,'Syracuse, NY 13224',3525,222,NULL,32,4903,0);
INSERT INTO "django_geo_db_location" VALUES(8722,NULL,'Syracuse, NY 13225',3525,222,NULL,32,4904,0);
INSERT INTO "django_geo_db_location" VALUES(8723,NULL,'Syracuse, NY 13244',3525,222,NULL,32,4905,0);
INSERT INTO "django_geo_db_location" VALUES(8724,NULL,'Syracuse, NY 13250',3525,222,NULL,32,4906,0);
INSERT INTO "django_geo_db_location" VALUES(8725,NULL,'Syracuse, NY 13251',3525,222,NULL,32,4907,0);
INSERT INTO "django_geo_db_location" VALUES(8726,NULL,'Syracuse, NY 13252',3525,222,NULL,32,4908,0);
INSERT INTO "django_geo_db_location" VALUES(8727,NULL,'Syracuse, NY 13260',3525,222,NULL,32,4909,0);
INSERT INTO "django_geo_db_location" VALUES(8728,NULL,'Syracuse, NY 13261',3525,222,NULL,32,4910,0);
INSERT INTO "django_geo_db_location" VALUES(8729,NULL,'Syracuse, NY 13290',3525,222,NULL,32,4911,0);
INSERT INTO "django_geo_db_location" VALUES(8730,NULL,'Alder Creek, NY',3526,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8731,NULL,'Alder Creek, NY 13301',3526,222,NULL,32,4912,0);
INSERT INTO "django_geo_db_location" VALUES(8732,NULL,'Altmar, NY',3527,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8733,NULL,'Altmar, NY 13302',3527,222,NULL,32,4913,0);
INSERT INTO "django_geo_db_location" VALUES(8734,NULL,'Ava, NY',3528,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8735,NULL,'Ava, NY 13303',3528,222,NULL,32,4914,0);
INSERT INTO "django_geo_db_location" VALUES(8736,NULL,'Barneveld, NY',3529,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8737,NULL,'Barneveld, NY 13304',3529,222,NULL,32,4915,0);
INSERT INTO "django_geo_db_location" VALUES(8738,NULL,'Beaver Falls, NY',3530,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8739,NULL,'Beaver Falls, NY 13305',3530,222,NULL,32,4916,0);
INSERT INTO "django_geo_db_location" VALUES(8740,NULL,'Blossvale, NY',3531,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8741,NULL,'Blossvale, NY 13308',3531,222,NULL,32,4917,0);
INSERT INTO "django_geo_db_location" VALUES(8742,NULL,'Boonville, NY',3532,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8743,NULL,'Boonville, NY 13309',3532,222,NULL,32,4918,0);
INSERT INTO "django_geo_db_location" VALUES(8744,NULL,'Bouckville, NY',3533,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8745,NULL,'Bouckville, NY 13310',3533,222,NULL,32,4919,0);
INSERT INTO "django_geo_db_location" VALUES(8746,NULL,'Brantingham, NY',3534,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8747,NULL,'Brantingham, NY 13312',3534,222,NULL,32,4920,0);
INSERT INTO "django_geo_db_location" VALUES(8748,NULL,'Bridgewater, NY',3535,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8749,NULL,'Bridgewater, NY 13313',3535,222,NULL,32,4921,0);
INSERT INTO "django_geo_db_location" VALUES(8750,NULL,'Brookfield, NY',3536,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8751,NULL,'Brookfield, NY 13314',3536,222,NULL,32,4922,0);
INSERT INTO "django_geo_db_location" VALUES(8752,NULL,'Burlington Flats, NY',3537,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8753,NULL,'Burlington Flats, NY 13315',3537,222,NULL,32,4923,0);
INSERT INTO "django_geo_db_location" VALUES(8754,NULL,'Camden, NY',3538,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8755,NULL,'Camden, NY 13316',3538,222,NULL,32,4924,0);
INSERT INTO "django_geo_db_location" VALUES(8756,NULL,'Canajoharie, NY',3539,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8757,NULL,'Canajoharie, NY 13317',3539,222,NULL,32,4925,0);
INSERT INTO "django_geo_db_location" VALUES(8758,NULL,'Cassville, NY',3540,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8759,NULL,'Cassville, NY 13318',3540,222,NULL,32,4926,0);
INSERT INTO "django_geo_db_location" VALUES(8760,NULL,'Chadwicks, NY',3541,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8761,NULL,'Chadwicks, NY 13319',3541,222,NULL,32,4927,0);
INSERT INTO "django_geo_db_location" VALUES(8762,NULL,'Cherry Valley, NY',3542,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8763,NULL,'Cherry Valley, NY 13320',3542,222,NULL,32,4928,0);
INSERT INTO "django_geo_db_location" VALUES(8764,NULL,'Clark Mills, NY',3543,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8765,NULL,'Clark Mills, NY 13321',3543,222,NULL,32,4929,0);
INSERT INTO "django_geo_db_location" VALUES(8766,NULL,'Clayville, NY',3544,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8767,NULL,'Clayville, NY 13322',3544,222,NULL,32,4930,0);
INSERT INTO "django_geo_db_location" VALUES(8768,NULL,'Clinton, NY',3545,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8769,NULL,'Clinton, NY 13323',3545,222,NULL,32,4931,0);
INSERT INTO "django_geo_db_location" VALUES(8770,NULL,'Cold Brook, NY',3546,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8771,NULL,'Cold Brook, NY 13324',3546,222,NULL,32,4932,0);
INSERT INTO "django_geo_db_location" VALUES(8772,NULL,'Constableville, NY',3547,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8773,NULL,'Constableville, NY 13325',3547,222,NULL,32,4933,0);
INSERT INTO "django_geo_db_location" VALUES(8774,NULL,'Cooperstown, NY',3548,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8775,NULL,'Cooperstown, NY 13326',3548,222,NULL,32,4934,0);
INSERT INTO "django_geo_db_location" VALUES(8776,NULL,'Croghan, NY',3549,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8777,NULL,'Croghan, NY 13327',3549,222,NULL,32,4935,0);
INSERT INTO "django_geo_db_location" VALUES(8778,NULL,'Deansboro, NY',3550,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8779,NULL,'Deansboro, NY 13328',3550,222,NULL,32,4936,0);
INSERT INTO "django_geo_db_location" VALUES(8780,NULL,'Dolgeville, NY',3551,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8781,NULL,'Dolgeville, NY 13329',3551,222,NULL,32,4937,0);
INSERT INTO "django_geo_db_location" VALUES(8782,NULL,'Eagle Bay, NY',3552,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8783,NULL,'Eagle Bay, NY 13331',3552,222,NULL,32,4938,0);
INSERT INTO "django_geo_db_location" VALUES(8784,NULL,'Earlville, NY',3553,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8785,NULL,'Earlville, NY 13332',3553,222,NULL,32,4939,0);
INSERT INTO "django_geo_db_location" VALUES(8786,NULL,'East Springfield, NY',3554,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8787,NULL,'East Springfield, NY 13333',3554,222,NULL,32,4940,0);
INSERT INTO "django_geo_db_location" VALUES(8788,NULL,'Eaton, NY',3555,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8789,NULL,'Eaton, NY 13334',3555,222,NULL,32,4941,0);
INSERT INTO "django_geo_db_location" VALUES(8790,NULL,'Edmeston, NY',3556,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8791,NULL,'Edmeston, NY 13335',3556,222,NULL,32,4942,0);
INSERT INTO "django_geo_db_location" VALUES(8792,NULL,'Fly Creek, NY',3557,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8793,NULL,'Fly Creek, NY 13337',3557,222,NULL,32,4943,0);
INSERT INTO "django_geo_db_location" VALUES(8794,NULL,'Forestport, NY',3558,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8795,NULL,'Forestport, NY 13338',3558,222,NULL,32,4944,0);
INSERT INTO "django_geo_db_location" VALUES(8796,NULL,'Fort Plain, NY',3559,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8797,NULL,'Fort Plain, NY 13339',3559,222,NULL,32,4945,0);
INSERT INTO "django_geo_db_location" VALUES(8798,NULL,'Frankfort, NY',3560,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8799,NULL,'Frankfort, NY 13340',3560,222,NULL,32,4946,0);
INSERT INTO "django_geo_db_location" VALUES(8800,NULL,'Franklin Springs, NY',3561,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8801,NULL,'Franklin Springs, NY 13341',3561,222,NULL,32,4947,0);
INSERT INTO "django_geo_db_location" VALUES(8802,NULL,'Garrattsville, NY',3562,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8803,NULL,'Garrattsville, NY 13342',3562,222,NULL,32,4948,0);
INSERT INTO "django_geo_db_location" VALUES(8804,NULL,'Glenfield, NY',3563,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8805,NULL,'Glenfield, NY 13343',3563,222,NULL,32,4949,0);
INSERT INTO "django_geo_db_location" VALUES(8806,NULL,'Greig, NY',3564,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8807,NULL,'Greig, NY 13345',3564,222,NULL,32,4950,0);
INSERT INTO "django_geo_db_location" VALUES(8808,NULL,'Hamilton, NY',3565,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8809,NULL,'Hamilton, NY 13346',3565,222,NULL,32,4951,0);
INSERT INTO "django_geo_db_location" VALUES(8810,NULL,'Hartwick, NY',3566,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8811,NULL,'Hartwick, NY 13348',3566,222,NULL,32,4952,0);
INSERT INTO "django_geo_db_location" VALUES(8812,NULL,'Herkimer, NY',3567,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8813,NULL,'Herkimer, NY 13350',3567,222,NULL,32,4953,0);
INSERT INTO "django_geo_db_location" VALUES(8814,NULL,'Hinckley, NY',3568,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8815,NULL,'Hinckley, NY 13352',3568,222,NULL,32,4954,0);
INSERT INTO "django_geo_db_location" VALUES(8816,NULL,'Hoffmeister, NY',3569,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8817,NULL,'Hoffmeister, NY 13353',3569,222,NULL,32,4955,0);
INSERT INTO "django_geo_db_location" VALUES(8818,NULL,'Holland Patent, NY',3570,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8819,NULL,'Holland Patent, NY 13354',3570,222,NULL,32,4956,0);
INSERT INTO "django_geo_db_location" VALUES(8820,NULL,'Hubbardsville, NY',3571,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8821,NULL,'Hubbardsville, NY 13355',3571,222,NULL,32,4957,0);
INSERT INTO "django_geo_db_location" VALUES(8822,NULL,'Ilion, NY',3572,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8823,NULL,'Ilion, NY 13357',3572,222,NULL,32,4958,0);
INSERT INTO "django_geo_db_location" VALUES(8824,NULL,'Inlet, NY',3573,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8825,NULL,'Inlet, NY 13360',3573,222,NULL,32,4959,0);
INSERT INTO "django_geo_db_location" VALUES(8826,NULL,'Jordanville, NY',3574,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8827,NULL,'Jordanville, NY 13361',3574,222,NULL,32,4960,0);
INSERT INTO "django_geo_db_location" VALUES(8828,NULL,'Knoxboro, NY',3575,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8829,NULL,'Knoxboro, NY 13362',3575,222,NULL,32,4961,0);
INSERT INTO "django_geo_db_location" VALUES(8830,NULL,'Lee Center, NY',3576,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8831,NULL,'Lee Center, NY 13363',3576,222,NULL,32,4962,0);
INSERT INTO "django_geo_db_location" VALUES(8832,NULL,'Leonardsville, NY',3577,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8833,NULL,'Leonardsville, NY 13364',3577,222,NULL,32,4963,0);
INSERT INTO "django_geo_db_location" VALUES(8834,NULL,'Little Falls, NY',3578,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8835,NULL,'Little Falls, NY 13365',3578,222,NULL,32,4964,0);
INSERT INTO "django_geo_db_location" VALUES(8836,NULL,'Lowville, NY',3579,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8837,NULL,'Lowville, NY 13367',3579,222,NULL,32,4965,0);
INSERT INTO "django_geo_db_location" VALUES(8838,NULL,'Lyons Falls, NY',3580,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8839,NULL,'Lyons Falls, NY 13368',3580,222,NULL,32,4966,0);
INSERT INTO "django_geo_db_location" VALUES(8840,NULL,'Webb, NY',3581,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8841,NULL,'Webb, NY 13388',3581,222,NULL,32,4967,0);
INSERT INTO "django_geo_db_location" VALUES(8842,NULL,'Madison, NY',3582,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8843,NULL,'Madison, NY 13396',3582,222,NULL,32,4968,0);
INSERT INTO "django_geo_db_location" VALUES(8844,NULL,'McConnellsville, NY',3583,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8845,NULL,'McConnellsville, NY 13401',3583,222,NULL,32,4969,0);
INSERT INTO "django_geo_db_location" VALUES(8846,NULL,'Madison, NY 13402',3582,222,NULL,32,4970,0);
INSERT INTO "django_geo_db_location" VALUES(8847,NULL,'Marcy, NY',3584,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8848,NULL,'Marcy, NY 13403',3584,222,NULL,32,4971,0);
INSERT INTO "django_geo_db_location" VALUES(8849,NULL,'Martinsburg, NY',3585,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8850,NULL,'Martinsburg, NY 13404',3585,222,NULL,32,4972,0);
INSERT INTO "django_geo_db_location" VALUES(8851,NULL,'Middleville, NY',3586,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8852,NULL,'Middleville, NY 13406',3586,222,NULL,32,4973,0);
INSERT INTO "django_geo_db_location" VALUES(8853,NULL,'Mohawk, NY',3587,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8854,NULL,'Mohawk, NY 13407',3587,222,NULL,32,4974,0);
INSERT INTO "django_geo_db_location" VALUES(8855,NULL,'Morrisville, NY',3588,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8856,NULL,'Morrisville, NY 13408',3588,222,NULL,32,4975,0);
INSERT INTO "django_geo_db_location" VALUES(8857,NULL,'Munnsville, NY',3589,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8858,NULL,'Munnsville, NY 13409',3589,222,NULL,32,4976,0);
INSERT INTO "django_geo_db_location" VALUES(8859,NULL,'Nelliston, NY',3590,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8860,NULL,'Nelliston, NY 13410',3590,222,NULL,32,4977,0);
INSERT INTO "django_geo_db_location" VALUES(8861,NULL,'New Berlin, NY',3591,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8862,NULL,'New Berlin, NY 13411',3591,222,NULL,32,4978,0);
INSERT INTO "django_geo_db_location" VALUES(8863,NULL,'New Hartford, NY',3592,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8864,NULL,'New Hartford, NY 13413',3592,222,NULL,32,4979,0);
INSERT INTO "django_geo_db_location" VALUES(8865,NULL,'New Lisbon, NY',3593,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8866,NULL,'New Lisbon, NY 13415',3593,222,NULL,32,4980,0);
INSERT INTO "django_geo_db_location" VALUES(8867,NULL,'Newport, NY',3594,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8868,NULL,'Newport, NY 13416',3594,222,NULL,32,4981,0);
INSERT INTO "django_geo_db_location" VALUES(8869,NULL,'New York Mills, NY',3595,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8870,NULL,'New York Mills, NY 13417',3595,222,NULL,32,4982,0);
INSERT INTO "django_geo_db_location" VALUES(8871,NULL,'North Brookfield, NY',3596,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8872,NULL,'North Brookfield, NY 13418',3596,222,NULL,32,4983,0);
INSERT INTO "django_geo_db_location" VALUES(8873,NULL,'Old Forge, NY',3597,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8874,NULL,'Old Forge, NY 13420',3597,222,NULL,32,4984,0);
INSERT INTO "django_geo_db_location" VALUES(8875,NULL,'Oneida, NY',3598,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8876,NULL,'Oneida, NY 13421',3598,222,NULL,32,4985,0);
INSERT INTO "django_geo_db_location" VALUES(8877,NULL,'Oriskany, NY',3599,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8878,NULL,'Oriskany, NY 13424',3599,222,NULL,32,4986,0);
INSERT INTO "django_geo_db_location" VALUES(8879,NULL,'Oriskany Falls, NY',3600,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8880,NULL,'Oriskany Falls, NY 13425',3600,222,NULL,32,4987,0);
INSERT INTO "django_geo_db_location" VALUES(8881,NULL,'Orwell, NY',3601,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8882,NULL,'Orwell, NY 13426',3601,222,NULL,32,4988,0);
INSERT INTO "django_geo_db_location" VALUES(8883,NULL,'Palatine Bridge, NY',3602,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8884,NULL,'Palatine Bridge, NY 13428',3602,222,NULL,32,4989,0);
INSERT INTO "django_geo_db_location" VALUES(8885,NULL,'Poland, NY',3603,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8886,NULL,'Poland, NY 13431',3603,222,NULL,32,4990,0);
INSERT INTO "django_geo_db_location" VALUES(8887,NULL,'Port Leyden, NY',3604,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8888,NULL,'Port Leyden, NY 13433',3604,222,NULL,32,4991,0);
INSERT INTO "django_geo_db_location" VALUES(8889,NULL,'Prospect, NY',3605,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8890,NULL,'Prospect, NY 13435',3605,222,NULL,32,4992,0);
INSERT INTO "django_geo_db_location" VALUES(8891,NULL,'Raquette Lake, NY',3606,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8892,NULL,'Raquette Lake, NY 13436',3606,222,NULL,32,4993,0);
INSERT INTO "django_geo_db_location" VALUES(8893,NULL,'Redfield, NY',3607,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8894,NULL,'Redfield, NY 13437',3607,222,NULL,32,4994,0);
INSERT INTO "django_geo_db_location" VALUES(8895,NULL,'Remsen, NY',3608,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8896,NULL,'Remsen, NY 13438',3608,222,NULL,32,4995,0);
INSERT INTO "django_geo_db_location" VALUES(8897,NULL,'Richfield Springs, NY',3609,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8898,NULL,'Richfield Springs, NY 13439',3609,222,NULL,32,4996,0);
INSERT INTO "django_geo_db_location" VALUES(8899,NULL,'Rome, NY',3610,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8900,NULL,'Rome, NY 13440',3610,222,NULL,32,4997,0);
INSERT INTO "django_geo_db_location" VALUES(8901,NULL,'Rome, NY 13441',3610,222,NULL,32,4998,0);
INSERT INTO "django_geo_db_location" VALUES(8902,NULL,'Rome, NY 13442',3610,222,NULL,32,4999,0);
INSERT INTO "django_geo_db_location" VALUES(8903,NULL,'Plymouth, NY',3611,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8904,NULL,'Plymouth, NY 13444',3611,222,NULL,32,5000,0);
INSERT INTO "django_geo_db_location" VALUES(8905,NULL,'Rome, NY 13449',3610,222,NULL,32,5001,0);
INSERT INTO "django_geo_db_location" VALUES(8906,NULL,'Roseboom, NY',3612,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8907,NULL,'Roseboom, NY 13450',3612,222,NULL,32,5002,0);
INSERT INTO "django_geo_db_location" VALUES(8908,NULL,'Saint Johnsville, NY',3613,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8909,NULL,'Saint Johnsville, NY 13452',3613,222,NULL,32,5003,0);
INSERT INTO "django_geo_db_location" VALUES(8910,NULL,'Williamstown, NY',3614,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8911,NULL,'Williamstown, NY 13453',3614,222,NULL,32,5004,0);
INSERT INTO "django_geo_db_location" VALUES(8912,NULL,'Salisbury Center, NY',3615,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8913,NULL,'Salisbury Center, NY 13454',3615,222,NULL,32,5005,0);
INSERT INTO "django_geo_db_location" VALUES(8914,NULL,'Sangerfield, NY',3616,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8915,NULL,'Sangerfield, NY 13455',3616,222,NULL,32,5006,0);
INSERT INTO "django_geo_db_location" VALUES(8916,NULL,'Sauquoit, NY',3617,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8917,NULL,'Sauquoit, NY 13456',3617,222,NULL,32,5007,0);
INSERT INTO "django_geo_db_location" VALUES(8918,NULL,'Schuyler Lake, NY',3618,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8919,NULL,'Schuyler Lake, NY 13457',3618,222,NULL,32,5008,0);
INSERT INTO "django_geo_db_location" VALUES(8920,NULL,'Sharon Springs, NY',3619,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8921,NULL,'Sharon Springs, NY 13459',3619,222,NULL,32,5009,0);
INSERT INTO "django_geo_db_location" VALUES(8922,NULL,'Sherburne, NY',3620,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8923,NULL,'Sherburne, NY 13460',3620,222,NULL,32,5010,0);
INSERT INTO "django_geo_db_location" VALUES(8924,NULL,'Sherrill, NY',3621,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8925,NULL,'Sherrill, NY 13461',3621,222,NULL,32,5011,0);
INSERT INTO "django_geo_db_location" VALUES(8926,NULL,'Smyrna, NY',3622,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8927,NULL,'Smyrna, NY 13464',3622,222,NULL,32,5012,0);
INSERT INTO "django_geo_db_location" VALUES(8928,NULL,'Solsville, NY',3623,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8929,NULL,'Solsville, NY 13465',3623,222,NULL,32,5013,0);
INSERT INTO "django_geo_db_location" VALUES(8930,NULL,'Springfield Center, NY',3624,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8931,NULL,'Springfield Center, NY 13468',3624,222,NULL,32,5014,0);
INSERT INTO "django_geo_db_location" VALUES(8932,NULL,'Stittville, NY',3625,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8933,NULL,'Stittville, NY 13469',3625,222,NULL,32,5015,0);
INSERT INTO "django_geo_db_location" VALUES(8934,NULL,'Stratford, NY',3626,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8935,NULL,'Stratford, NY 13470',3626,222,NULL,32,5016,0);
INSERT INTO "django_geo_db_location" VALUES(8936,NULL,'Taberg, NY',3627,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8937,NULL,'Taberg, NY 13471',3627,222,NULL,32,5017,0);
INSERT INTO "django_geo_db_location" VALUES(8938,NULL,'Thendara, NY',3628,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8939,NULL,'Thendara, NY 13472',3628,222,NULL,32,5018,0);
INSERT INTO "django_geo_db_location" VALUES(8940,NULL,'Turin, NY',3629,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8941,NULL,'Turin, NY 13473',3629,222,NULL,32,5019,0);
INSERT INTO "django_geo_db_location" VALUES(8942,NULL,'Van Hornesville, NY',3630,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8943,NULL,'Van Hornesville, NY 13475',3630,222,NULL,32,5020,0);
INSERT INTO "django_geo_db_location" VALUES(8944,NULL,'Vernon, NY',3631,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8945,NULL,'Vernon, NY 13476',3631,222,NULL,32,5021,0);
INSERT INTO "django_geo_db_location" VALUES(8946,NULL,'Vernon Center, NY',3632,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8947,NULL,'Vernon Center, NY 13477',3632,222,NULL,32,5022,0);
INSERT INTO "django_geo_db_location" VALUES(8948,NULL,'Verona, NY',3633,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8949,NULL,'Verona, NY 13478',3633,222,NULL,32,5023,0);
INSERT INTO "django_geo_db_location" VALUES(8950,NULL,'Washington Mills, NY',3634,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8951,NULL,'Washington Mills, NY 13479',3634,222,NULL,32,5024,0);
INSERT INTO "django_geo_db_location" VALUES(8952,NULL,'Waterville, NY',3635,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8953,NULL,'Waterville, NY 13480',3635,222,NULL,32,5025,0);
INSERT INTO "django_geo_db_location" VALUES(8954,NULL,'West Burlington, NY',3636,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8955,NULL,'West Burlington, NY 13482',3636,222,NULL,32,5026,0);
INSERT INTO "django_geo_db_location" VALUES(8956,NULL,'Westdale, NY',3637,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8957,NULL,'Westdale, NY 13483',3637,222,NULL,32,5027,0);
INSERT INTO "django_geo_db_location" VALUES(8958,NULL,'West Eaton, NY',3638,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8959,NULL,'West Eaton, NY 13484',3638,222,NULL,32,5028,0);
INSERT INTO "django_geo_db_location" VALUES(8960,NULL,'West Edmeston, NY',3639,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8961,NULL,'West Edmeston, NY 13485',3639,222,NULL,32,5029,0);
INSERT INTO "django_geo_db_location" VALUES(8962,NULL,'Westernville, NY',3640,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8963,NULL,'Westernville, NY 13486',3640,222,NULL,32,5030,0);
INSERT INTO "django_geo_db_location" VALUES(8964,NULL,'Westford, NY',3641,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8965,NULL,'Westford, NY 13488',3641,222,NULL,32,5031,0);
INSERT INTO "django_geo_db_location" VALUES(8966,NULL,'West Leyden, NY',3642,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8967,NULL,'West Leyden, NY 13489',3642,222,NULL,32,5032,0);
INSERT INTO "django_geo_db_location" VALUES(8968,NULL,'Westmoreland, NY',3643,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8969,NULL,'Westmoreland, NY 13490',3643,222,NULL,32,5033,0);
INSERT INTO "django_geo_db_location" VALUES(8970,NULL,'West Winfield, NY',3644,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8971,NULL,'West Winfield, NY 13491',3644,222,NULL,32,5034,0);
INSERT INTO "django_geo_db_location" VALUES(8972,NULL,'Whitesboro, NY',3645,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8973,NULL,'Whitesboro, NY 13492',3645,222,NULL,32,5035,0);
INSERT INTO "django_geo_db_location" VALUES(8974,NULL,'Williamstown, NY 13493',3614,222,NULL,32,5036,0);
INSERT INTO "django_geo_db_location" VALUES(8975,NULL,'Woodgate, NY',3646,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8976,NULL,'Woodgate, NY 13494',3646,222,NULL,32,5037,0);
INSERT INTO "django_geo_db_location" VALUES(8977,NULL,'Yorkville, NY',3647,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8978,NULL,'Yorkville, NY 13495',3647,222,NULL,32,5038,0);
INSERT INTO "django_geo_db_location" VALUES(8979,NULL,'Utica, NY',3648,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8980,NULL,'Utica, NY 13501',3648,222,NULL,32,5039,0);
INSERT INTO "django_geo_db_location" VALUES(8981,NULL,'Utica, NY 13502',3648,222,NULL,32,5040,0);
INSERT INTO "django_geo_db_location" VALUES(8982,NULL,'Utica, NY 13503',3648,222,NULL,32,5041,0);
INSERT INTO "django_geo_db_location" VALUES(8983,NULL,'Utica, NY 13504',3648,222,NULL,32,5042,0);
INSERT INTO "django_geo_db_location" VALUES(8984,NULL,'Utica, NY 13505',3648,222,NULL,32,5043,0);
INSERT INTO "django_geo_db_location" VALUES(8985,NULL,'Herkimer, NY 13550',3567,222,NULL,32,5044,0);
INSERT INTO "django_geo_db_location" VALUES(8986,NULL,'Hermon, NY',3649,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8987,NULL,'Hermon, NY 13562',3649,222,NULL,32,5045,0);
INSERT INTO "django_geo_db_location" VALUES(8988,NULL,'Pharsalia, NY',3650,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8989,NULL,'Pharsalia, NY 13578',3650,222,NULL,32,5046,0);
INSERT INTO "django_geo_db_location" VALUES(8990,NULL,'Utica, NY 13599',3648,222,NULL,32,5047,0);
INSERT INTO "django_geo_db_location" VALUES(8991,NULL,'Watertown, NY',3651,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8992,NULL,'Watertown, NY 13601',3651,222,NULL,32,5048,0);
INSERT INTO "django_geo_db_location" VALUES(8993,NULL,'Fort Drum, NY',3652,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8994,NULL,'Fort Drum, NY 13602',3652,222,NULL,32,5049,0);
INSERT INTO "django_geo_db_location" VALUES(8995,NULL,'Watertown, NY 13603',3651,222,NULL,32,5050,0);
INSERT INTO "django_geo_db_location" VALUES(8996,NULL,'Adams, NY',3653,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8997,NULL,'Adams, NY 13605',3653,222,NULL,32,5051,0);
INSERT INTO "django_geo_db_location" VALUES(8998,NULL,'Adams Center, NY',3654,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(8999,NULL,'Adams Center, NY 13606',3654,222,NULL,32,5052,0);
INSERT INTO "django_geo_db_location" VALUES(9000,NULL,'Alexandria Bay, NY',3655,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9001,NULL,'Alexandria Bay, NY 13607',3655,222,NULL,32,5053,0);
INSERT INTO "django_geo_db_location" VALUES(9002,NULL,'Antwerp, NY',3656,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9003,NULL,'Antwerp, NY 13608',3656,222,NULL,32,5054,0);
INSERT INTO "django_geo_db_location" VALUES(9004,NULL,'Rodman, NY',3657,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9005,NULL,'Rodman, NY 13610',3657,222,NULL,32,5055,0);
INSERT INTO "django_geo_db_location" VALUES(9006,NULL,'Belleville, NY',3658,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9007,NULL,'Belleville, NY 13611',3658,222,NULL,32,5056,0);
INSERT INTO "django_geo_db_location" VALUES(9008,NULL,'Black River, NY',3659,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9009,NULL,'Black River, NY 13612',3659,222,NULL,32,5057,0);
INSERT INTO "django_geo_db_location" VALUES(9010,NULL,'Brasher Falls, NY',3660,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9011,NULL,'Brasher Falls, NY 13613',3660,222,NULL,32,5058,0);
INSERT INTO "django_geo_db_location" VALUES(9012,NULL,'Brier Hill, NY',3661,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9013,NULL,'Brier Hill, NY 13614',3661,222,NULL,32,5059,0);
INSERT INTO "django_geo_db_location" VALUES(9014,NULL,'Brownville, NY',3662,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9015,NULL,'Brownville, NY 13615',3662,222,NULL,32,5060,0);
INSERT INTO "django_geo_db_location" VALUES(9016,NULL,'Calcium, NY',3663,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9017,NULL,'Calcium, NY 13616',3663,222,NULL,32,5061,0);
INSERT INTO "django_geo_db_location" VALUES(9018,NULL,'Canton, NY',3664,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9019,NULL,'Canton, NY 13617',3664,222,NULL,32,5062,0);
INSERT INTO "django_geo_db_location" VALUES(9020,NULL,'Cape Vincent, NY',3665,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9021,NULL,'Cape Vincent, NY 13618',3665,222,NULL,32,5063,0);
INSERT INTO "django_geo_db_location" VALUES(9022,NULL,'Carthage, NY',3666,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9023,NULL,'Carthage, NY 13619',3666,222,NULL,32,5064,0);
INSERT INTO "django_geo_db_location" VALUES(9024,NULL,'Castorland, NY',3667,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9025,NULL,'Castorland, NY 13620',3667,222,NULL,32,5065,0);
INSERT INTO "django_geo_db_location" VALUES(9026,NULL,'Chase Mills, NY',3668,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9027,NULL,'Chase Mills, NY 13621',3668,222,NULL,32,5066,0);
INSERT INTO "django_geo_db_location" VALUES(9028,NULL,'Chaumont, NY',3669,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9029,NULL,'Chaumont, NY 13622',3669,222,NULL,32,5067,0);
INSERT INTO "django_geo_db_location" VALUES(9030,NULL,'Chippewa Bay, NY',3670,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9031,NULL,'Chippewa Bay, NY 13623',3670,222,NULL,32,5068,0);
INSERT INTO "django_geo_db_location" VALUES(9032,NULL,'Clayton, NY',3671,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9033,NULL,'Clayton, NY 13624',3671,222,NULL,32,5069,0);
INSERT INTO "django_geo_db_location" VALUES(9034,NULL,'Colton, NY',3672,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9035,NULL,'Colton, NY 13625',3672,222,NULL,32,5070,0);
INSERT INTO "django_geo_db_location" VALUES(9036,NULL,'Copenhagen, NY',3673,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9037,NULL,'Copenhagen, NY 13626',3673,222,NULL,32,5071,0);
INSERT INTO "django_geo_db_location" VALUES(9038,NULL,'Deer River, NY',3674,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9039,NULL,'Deer River, NY 13627',3674,222,NULL,32,5072,0);
INSERT INTO "django_geo_db_location" VALUES(9040,NULL,'Deferiet, NY',3675,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9041,NULL,'Deferiet, NY 13628',3675,222,NULL,32,5073,0);
INSERT INTO "django_geo_db_location" VALUES(9042,NULL,'De Kalb Junction, NY',3676,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9043,NULL,'De Kalb Junction, NY 13630',3676,222,NULL,32,5074,0);
INSERT INTO "django_geo_db_location" VALUES(9044,NULL,'Denmark, NY',3677,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9045,NULL,'Denmark, NY 13631',3677,222,NULL,32,5075,0);
INSERT INTO "django_geo_db_location" VALUES(9046,NULL,'Depauville, NY',3678,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9047,NULL,'Depauville, NY 13632',3678,222,NULL,32,5076,0);
INSERT INTO "django_geo_db_location" VALUES(9048,NULL,'De Peyster, NY',3679,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9049,NULL,'De Peyster, NY 13633',3679,222,NULL,32,5077,0);
INSERT INTO "django_geo_db_location" VALUES(9050,NULL,'Dexter, NY',3680,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9051,NULL,'Dexter, NY 13634',3680,222,NULL,32,5078,0);
INSERT INTO "django_geo_db_location" VALUES(9052,NULL,'Edwards, NY',3681,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9053,NULL,'Edwards, NY 13635',3681,222,NULL,32,5079,0);
INSERT INTO "django_geo_db_location" VALUES(9054,NULL,'Ellisburg, NY',3682,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9055,NULL,'Ellisburg, NY 13636',3682,222,NULL,32,5080,0);
INSERT INTO "django_geo_db_location" VALUES(9056,NULL,'Evans Mills, NY',3683,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9057,NULL,'Evans Mills, NY 13637',3683,222,NULL,32,5081,0);
INSERT INTO "django_geo_db_location" VALUES(9058,NULL,'Felts Mills, NY',3684,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9059,NULL,'Felts Mills, NY 13638',3684,222,NULL,32,5082,0);
INSERT INTO "django_geo_db_location" VALUES(9060,NULL,'Fine, NY',3685,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9061,NULL,'Fine, NY 13639',3685,222,NULL,32,5083,0);
INSERT INTO "django_geo_db_location" VALUES(9062,NULL,'Wellesley Island, NY',3686,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9063,NULL,'Wellesley Island, NY 13640',3686,222,NULL,32,5084,0);
INSERT INTO "django_geo_db_location" VALUES(9064,NULL,'Fishers Landing, NY',3687,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9065,NULL,'Fishers Landing, NY 13641',3687,222,NULL,32,5085,0);
INSERT INTO "django_geo_db_location" VALUES(9066,NULL,'Gouverneur, NY',3688,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9067,NULL,'Gouverneur, NY 13642',3688,222,NULL,32,5086,0);
INSERT INTO "django_geo_db_location" VALUES(9068,NULL,'Great Bend, NY',3689,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9069,NULL,'Great Bend, NY 13643',3689,222,NULL,32,5087,0);
INSERT INTO "django_geo_db_location" VALUES(9070,NULL,'Hailesboro, NY',3690,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9071,NULL,'Hailesboro, NY 13645',3690,222,NULL,32,5088,0);
INSERT INTO "django_geo_db_location" VALUES(9072,NULL,'Hammond, NY',3691,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9073,NULL,'Hammond, NY 13646',3691,222,NULL,32,5089,0);
INSERT INTO "django_geo_db_location" VALUES(9074,NULL,'Hannawa Falls, NY',3692,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9075,NULL,'Hannawa Falls, NY 13647',3692,222,NULL,32,5090,0);
INSERT INTO "django_geo_db_location" VALUES(9076,NULL,'Harrisville, NY',3693,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9077,NULL,'Harrisville, NY 13648',3693,222,NULL,32,5091,0);
INSERT INTO "django_geo_db_location" VALUES(9078,NULL,'Helena, NY',3694,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9079,NULL,'Helena, NY 13649',3694,222,NULL,32,5092,0);
INSERT INTO "django_geo_db_location" VALUES(9080,NULL,'Henderson, NY',3695,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9081,NULL,'Henderson, NY 13650',3695,222,NULL,32,5093,0);
INSERT INTO "django_geo_db_location" VALUES(9082,NULL,'Henderson Harbor, NY',3696,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9083,NULL,'Henderson Harbor, NY 13651',3696,222,NULL,32,5094,0);
INSERT INTO "django_geo_db_location" VALUES(9084,NULL,'Hermon, NY 13652',3649,222,NULL,32,5095,0);
INSERT INTO "django_geo_db_location" VALUES(9085,NULL,'Heuvelton, NY',3697,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9086,NULL,'Heuvelton, NY 13654',3697,222,NULL,32,5096,0);
INSERT INTO "django_geo_db_location" VALUES(9087,NULL,'Hogansburg, NY',3698,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9088,NULL,'Hogansburg, NY 13655',3698,222,NULL,32,5097,0);
INSERT INTO "django_geo_db_location" VALUES(9089,NULL,'La Fargeville, NY',3699,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9090,NULL,'La Fargeville, NY 13656',3699,222,NULL,32,5098,0);
INSERT INTO "django_geo_db_location" VALUES(9091,NULL,'Limerick, NY',3700,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9092,NULL,'Limerick, NY 13657',3700,222,NULL,32,5099,0);
INSERT INTO "django_geo_db_location" VALUES(9093,NULL,'Lisbon, NY',3701,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9094,NULL,'Lisbon, NY 13658',3701,222,NULL,32,5100,0);
INSERT INTO "django_geo_db_location" VALUES(9095,NULL,'Lorraine, NY',3702,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9096,NULL,'Lorraine, NY 13659',3702,222,NULL,32,5101,0);
INSERT INTO "django_geo_db_location" VALUES(9097,NULL,'Madrid, NY',3703,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9098,NULL,'Madrid, NY 13660',3703,222,NULL,32,5102,0);
INSERT INTO "django_geo_db_location" VALUES(9099,NULL,'Mannsville, NY',3704,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9100,NULL,'Mannsville, NY 13661',3704,222,NULL,32,5103,0);
INSERT INTO "django_geo_db_location" VALUES(9101,NULL,'Massena, NY',3705,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9102,NULL,'Massena, NY 13662',3705,222,NULL,32,5104,0);
INSERT INTO "django_geo_db_location" VALUES(9103,NULL,'Morristown, NY',3706,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9104,NULL,'Morristown, NY 13664',3706,222,NULL,32,5105,0);
INSERT INTO "django_geo_db_location" VALUES(9105,NULL,'Natural Bridge, NY',3707,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9106,NULL,'Natural Bridge, NY 13665',3707,222,NULL,32,5106,0);
INSERT INTO "django_geo_db_location" VALUES(9107,NULL,'Newton Falls, NY',3708,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9108,NULL,'Newton Falls, NY 13666',3708,222,NULL,32,5107,0);
INSERT INTO "django_geo_db_location" VALUES(9109,NULL,'Norfolk, NY',3709,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9110,NULL,'Norfolk, NY 13667',3709,222,NULL,32,5108,0);
INSERT INTO "django_geo_db_location" VALUES(9111,NULL,'Norwood, NY',3710,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9112,NULL,'Norwood, NY 13668',3710,222,NULL,32,5109,0);
INSERT INTO "django_geo_db_location" VALUES(9113,NULL,'Ogdensburg, NY',3711,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9114,NULL,'Ogdensburg, NY 13669',3711,222,NULL,32,5110,0);
INSERT INTO "django_geo_db_location" VALUES(9115,NULL,'Oswegatchie, NY',3712,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9116,NULL,'Oswegatchie, NY 13670',3712,222,NULL,32,5111,0);
INSERT INTO "django_geo_db_location" VALUES(9117,NULL,'Oxbow, NY',3713,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9118,NULL,'Oxbow, NY 13671',3713,222,NULL,32,5112,0);
INSERT INTO "django_geo_db_location" VALUES(9119,NULL,'Parishville, NY',3714,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9120,NULL,'Parishville, NY 13672',3714,222,NULL,32,5113,0);
INSERT INTO "django_geo_db_location" VALUES(9121,NULL,'Philadelphia, NY',3715,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9122,NULL,'Philadelphia, NY 13673',3715,222,NULL,32,5114,0);
INSERT INTO "django_geo_db_location" VALUES(9123,NULL,'Pierrepont Manor, NY',3716,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9124,NULL,'Pierrepont Manor, NY 13674',3716,222,NULL,32,5115,0);
INSERT INTO "django_geo_db_location" VALUES(9125,NULL,'Plessis, NY',3717,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9126,NULL,'Plessis, NY 13675',3717,222,NULL,32,5116,0);
INSERT INTO "django_geo_db_location" VALUES(9127,NULL,'Potsdam, NY',3718,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9128,NULL,'Potsdam, NY 13676',3718,222,NULL,32,5117,0);
INSERT INTO "django_geo_db_location" VALUES(9129,NULL,'Pyrites, NY',3719,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9130,NULL,'Pyrites, NY 13677',3719,222,NULL,32,5118,0);
INSERT INTO "django_geo_db_location" VALUES(9131,NULL,'Raymondville, NY',3720,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9132,NULL,'Raymondville, NY 13678',3720,222,NULL,32,5119,0);
INSERT INTO "django_geo_db_location" VALUES(9133,NULL,'Redwood, NY',3721,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9134,NULL,'Redwood, NY 13679',3721,222,NULL,32,5120,0);
INSERT INTO "django_geo_db_location" VALUES(9135,NULL,'Rensselaer Falls, NY',3722,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9136,NULL,'Rensselaer Falls, NY 13680',3722,222,NULL,32,5121,0);
INSERT INTO "django_geo_db_location" VALUES(9137,NULL,'Richville, NY',3723,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9138,NULL,'Richville, NY 13681',3723,222,NULL,32,5122,0);
INSERT INTO "django_geo_db_location" VALUES(9139,NULL,'Rodman, NY 13682',3657,222,NULL,32,5123,0);
INSERT INTO "django_geo_db_location" VALUES(9140,NULL,'Rooseveltown, NY',3724,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9141,NULL,'Rooseveltown, NY 13683',3724,222,NULL,32,5124,0);
INSERT INTO "django_geo_db_location" VALUES(9142,NULL,'Russell, NY',3725,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9143,NULL,'Russell, NY 13684',3725,222,NULL,32,5125,0);
INSERT INTO "django_geo_db_location" VALUES(9144,NULL,'Sackets Harbor, NY',3726,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9145,NULL,'Sackets Harbor, NY 13685',3726,222,NULL,32,5126,0);
INSERT INTO "django_geo_db_location" VALUES(9146,NULL,'South Colton, NY',3727,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9147,NULL,'South Colton, NY 13687',3727,222,NULL,32,5127,0);
INSERT INTO "django_geo_db_location" VALUES(9148,NULL,'South Rutland, NY',3728,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9149,NULL,'South Rutland, NY 13688',3728,222,NULL,32,5128,0);
INSERT INTO "django_geo_db_location" VALUES(9150,NULL,'Star Lake, NY',3729,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9151,NULL,'Star Lake, NY 13690',3729,222,NULL,32,5129,0);
INSERT INTO "django_geo_db_location" VALUES(9152,NULL,'Theresa, NY',3730,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9153,NULL,'Theresa, NY 13691',3730,222,NULL,32,5130,0);
INSERT INTO "django_geo_db_location" VALUES(9154,NULL,'Thousand Island Park, NY',3731,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9155,NULL,'Thousand Island Park, NY 13692',3731,222,NULL,32,5131,0);
INSERT INTO "django_geo_db_location" VALUES(9156,NULL,'Three Mile Bay, NY',3732,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9157,NULL,'Three Mile Bay, NY 13693',3732,222,NULL,32,5132,0);
INSERT INTO "django_geo_db_location" VALUES(9158,NULL,'Waddington, NY',3733,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9159,NULL,'Waddington, NY 13694',3733,222,NULL,32,5133,0);
INSERT INTO "django_geo_db_location" VALUES(9160,NULL,'Wanakena, NY',3734,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9161,NULL,'Wanakena, NY 13695',3734,222,NULL,32,5134,0);
INSERT INTO "django_geo_db_location" VALUES(9162,NULL,'West Stockholm, NY',3735,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9163,NULL,'West Stockholm, NY 13696',3735,222,NULL,32,5135,0);
INSERT INTO "django_geo_db_location" VALUES(9164,NULL,'Winthrop, NY',3736,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9165,NULL,'Winthrop, NY 13697',3736,222,NULL,32,5136,0);
INSERT INTO "django_geo_db_location" VALUES(9166,NULL,'Ellisburg, NY 13698',3682,222,NULL,32,5137,0);
INSERT INTO "django_geo_db_location" VALUES(9167,NULL,'Potsdam, NY 13699',3718,222,NULL,32,5138,0);
INSERT INTO "django_geo_db_location" VALUES(9168,NULL,'Afton, NY',3737,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9169,NULL,'Afton, NY 13730',3737,222,NULL,32,5139,0);
INSERT INTO "django_geo_db_location" VALUES(9170,NULL,'Andes, NY',3738,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9171,NULL,'Andes, NY 13731',3738,222,NULL,32,5140,0);
INSERT INTO "django_geo_db_location" VALUES(9172,NULL,'Apalachin, NY',3739,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9173,NULL,'Apalachin, NY 13732',3739,222,NULL,32,5141,0);
INSERT INTO "django_geo_db_location" VALUES(9174,NULL,'Bainbridge, NY',3740,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9175,NULL,'Bainbridge, NY 13733',3740,222,NULL,32,5142,0);
INSERT INTO "django_geo_db_location" VALUES(9176,NULL,'Barton, NY',3741,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9177,NULL,'Barton, NY 13734',3741,222,NULL,32,5143,0);
INSERT INTO "django_geo_db_location" VALUES(9178,NULL,'Berkshire, NY',3742,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9179,NULL,'Berkshire, NY 13736',3742,222,NULL,32,5144,0);
INSERT INTO "django_geo_db_location" VALUES(9180,NULL,'Bible School Park, NY',3743,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9181,NULL,'Bible School Park, NY 13737',3743,222,NULL,32,5145,0);
INSERT INTO "django_geo_db_location" VALUES(9182,NULL,'Blodgett Mills, NY',3744,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9183,NULL,'Blodgett Mills, NY 13738',3744,222,NULL,32,5146,0);
INSERT INTO "django_geo_db_location" VALUES(9184,NULL,'Bloomville, NY',3745,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9185,NULL,'Bloomville, NY 13739',3745,222,NULL,32,5147,0);
INSERT INTO "django_geo_db_location" VALUES(9186,NULL,'Bovina Center, NY',3746,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9187,NULL,'Bovina Center, NY 13740',3746,222,NULL,32,5148,0);
INSERT INTO "django_geo_db_location" VALUES(9188,NULL,'Candor, NY',3747,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9189,NULL,'Candor, NY 13743',3747,222,NULL,32,5149,0);
INSERT INTO "django_geo_db_location" VALUES(9190,NULL,'Castle Creek, NY',3748,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9191,NULL,'Castle Creek, NY 13744',3748,222,NULL,32,5150,0);
INSERT INTO "django_geo_db_location" VALUES(9192,NULL,'Chenango Bridge, NY',3749,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9193,NULL,'Chenango Bridge, NY 13745',3749,222,NULL,32,5151,0);
INSERT INTO "django_geo_db_location" VALUES(9194,NULL,'Chenango Forks, NY',3750,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9195,NULL,'Chenango Forks, NY 13746',3750,222,NULL,32,5152,0);
INSERT INTO "django_geo_db_location" VALUES(9196,NULL,'Colliersville, NY',3751,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9197,NULL,'Colliersville, NY 13747',3751,222,NULL,32,5153,0);
INSERT INTO "django_geo_db_location" VALUES(9198,NULL,'Conklin, NY',3752,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9199,NULL,'Conklin, NY 13748',3752,222,NULL,32,5154,0);
INSERT INTO "django_geo_db_location" VALUES(9200,NULL,'Corbettsville, NY',3753,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9201,NULL,'Corbettsville, NY 13749',3753,222,NULL,32,5155,0);
INSERT INTO "django_geo_db_location" VALUES(9202,NULL,'Davenport, NY',3754,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9203,NULL,'Davenport, NY 13750',3754,222,NULL,32,5156,0);
INSERT INTO "django_geo_db_location" VALUES(9204,NULL,'Davenport Center, NY',3755,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9205,NULL,'Davenport Center, NY 13751',3755,222,NULL,32,5157,0);
INSERT INTO "django_geo_db_location" VALUES(9206,NULL,'De Lancey, NY',3756,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9207,NULL,'De Lancey, NY 13752',3756,222,NULL,32,5158,0);
INSERT INTO "django_geo_db_location" VALUES(9208,NULL,'Delhi, NY',3757,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9209,NULL,'Delhi, NY 13753',3757,222,NULL,32,5159,0);
INSERT INTO "django_geo_db_location" VALUES(9210,NULL,'Deposit, NY',3758,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9211,NULL,'Deposit, NY 13754',3758,222,NULL,32,5160,0);
INSERT INTO "django_geo_db_location" VALUES(9212,NULL,'Downsville, NY',3759,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9213,NULL,'Downsville, NY 13755',3759,222,NULL,32,5161,0);
INSERT INTO "django_geo_db_location" VALUES(9214,NULL,'East Branch, NY',3760,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9215,NULL,'East Branch, NY 13756',3760,222,NULL,32,5162,0);
INSERT INTO "django_geo_db_location" VALUES(9216,NULL,'East Meredith, NY',3761,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9217,NULL,'East Meredith, NY 13757',3761,222,NULL,32,5163,0);
INSERT INTO "django_geo_db_location" VALUES(9218,NULL,'East Pharsalia, NY',3762,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9219,NULL,'East Pharsalia, NY 13758',3762,222,NULL,32,5164,0);
INSERT INTO "django_geo_db_location" VALUES(9220,NULL,'Endicott, NY',3763,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9221,NULL,'Endicott, NY 13760',3763,222,NULL,32,5165,0);
INSERT INTO "django_geo_db_location" VALUES(9222,NULL,'Endicott, NY 13761',3763,222,NULL,32,5166,0);
INSERT INTO "django_geo_db_location" VALUES(9223,NULL,'Endwell, NY',3764,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9224,NULL,'Endwell, NY 13762',3764,222,NULL,32,5167,0);
INSERT INTO "django_geo_db_location" VALUES(9225,NULL,'Endicott, NY 13763',3763,222,NULL,32,5168,0);
INSERT INTO "django_geo_db_location" VALUES(9226,NULL,'Maine, NY',3765,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9227,NULL,'Maine, NY 13766',3765,222,NULL,32,5169,0);
INSERT INTO "django_geo_db_location" VALUES(9228,NULL,'Fishs Eddy, NY',3766,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9229,NULL,'Fishs Eddy, NY 13774',3766,222,NULL,32,5170,0);
INSERT INTO "django_geo_db_location" VALUES(9230,NULL,'Franklin, NY',3767,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9231,NULL,'Franklin, NY 13775',3767,222,NULL,32,5171,0);
INSERT INTO "django_geo_db_location" VALUES(9232,NULL,'Gilbertsville, NY',3768,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9233,NULL,'Gilbertsville, NY 13776',3768,222,NULL,32,5172,0);
INSERT INTO "django_geo_db_location" VALUES(9234,NULL,'Glen Aubrey, NY',3769,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9235,NULL,'Glen Aubrey, NY 13777',3769,222,NULL,32,5173,0);
INSERT INTO "django_geo_db_location" VALUES(9236,NULL,'Greene, NY',3770,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9237,NULL,'Greene, NY 13778',3770,222,NULL,32,5174,0);
INSERT INTO "django_geo_db_location" VALUES(9238,NULL,'Guilford, NY',3771,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9239,NULL,'Guilford, NY 13780',3771,222,NULL,32,5175,0);
INSERT INTO "django_geo_db_location" VALUES(9240,NULL,'Hamden, NY',3772,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9241,NULL,'Hamden, NY 13782',3772,222,NULL,32,5176,0);
INSERT INTO "django_geo_db_location" VALUES(9242,NULL,'Hancock, NY',3773,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9243,NULL,'Hancock, NY 13783',3773,222,NULL,32,5177,0);
INSERT INTO "django_geo_db_location" VALUES(9244,NULL,'Harford, NY',3774,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9245,NULL,'Harford, NY 13784',3774,222,NULL,32,5178,0);
INSERT INTO "django_geo_db_location" VALUES(9246,NULL,'Harpersfield, NY',3775,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9247,NULL,'Harpersfield, NY 13786',3775,222,NULL,32,5179,0);
INSERT INTO "django_geo_db_location" VALUES(9248,NULL,'Harpursville, NY',3776,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9249,NULL,'Harpursville, NY 13787',3776,222,NULL,32,5180,0);
INSERT INTO "django_geo_db_location" VALUES(9250,NULL,'Hobart, NY',3777,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9251,NULL,'Hobart, NY 13788',3777,222,NULL,32,5181,0);
INSERT INTO "django_geo_db_location" VALUES(9252,NULL,'Johnson City, NY',3778,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9253,NULL,'Johnson City, NY 13790',3778,222,NULL,32,5182,0);
INSERT INTO "django_geo_db_location" VALUES(9254,NULL,'Morris, NY',3779,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9255,NULL,'Morris, NY 13792',3779,222,NULL,32,5183,0);
INSERT INTO "django_geo_db_location" VALUES(9256,NULL,'Killawog, NY',3780,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9257,NULL,'Killawog, NY 13794',3780,222,NULL,32,5184,0);
INSERT INTO "django_geo_db_location" VALUES(9258,NULL,'Kirkwood, NY',3781,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9259,NULL,'Kirkwood, NY 13795',3781,222,NULL,32,5185,0);
INSERT INTO "django_geo_db_location" VALUES(9260,NULL,'Laurens, NY',3782,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9261,NULL,'Laurens, NY 13796',3782,222,NULL,32,5186,0);
INSERT INTO "django_geo_db_location" VALUES(9262,NULL,'Lisle, NY',3783,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9263,NULL,'Lisle, NY 13797',3783,222,NULL,32,5187,0);
INSERT INTO "django_geo_db_location" VALUES(9264,NULL,'McDonough, NY',3784,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9265,NULL,'McDonough, NY 13801',3784,222,NULL,32,5188,0);
INSERT INTO "django_geo_db_location" VALUES(9266,NULL,'Maine, NY 13802',3765,222,NULL,32,5189,0);
INSERT INTO "django_geo_db_location" VALUES(9267,NULL,'Marathon, NY',3785,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9268,NULL,'Marathon, NY 13803',3785,222,NULL,32,5190,0);
INSERT INTO "django_geo_db_location" VALUES(9269,NULL,'Masonville, NY',3786,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9270,NULL,'Masonville, NY 13804',3786,222,NULL,32,5191,0);
INSERT INTO "django_geo_db_location" VALUES(9271,NULL,'Meridale, NY',3787,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9272,NULL,'Meridale, NY 13806',3787,222,NULL,32,5192,0);
INSERT INTO "django_geo_db_location" VALUES(9273,NULL,'Milford, NY',3788,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9274,NULL,'Milford, NY 13807',3788,222,NULL,32,5193,0);
INSERT INTO "django_geo_db_location" VALUES(9275,NULL,'Morris, NY 13808',3779,222,NULL,32,5194,0);
INSERT INTO "django_geo_db_location" VALUES(9276,NULL,'Mount Upton, NY',3789,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9277,NULL,'Mount Upton, NY 13809',3789,222,NULL,32,5195,0);
INSERT INTO "django_geo_db_location" VALUES(9278,NULL,'Mount Vision, NY',3790,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9279,NULL,'Mount Vision, NY 13810',3790,222,NULL,32,5196,0);
INSERT INTO "django_geo_db_location" VALUES(9280,NULL,'Newark Valley, NY',3791,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9281,NULL,'Newark Valley, NY 13811',3791,222,NULL,32,5197,0);
INSERT INTO "django_geo_db_location" VALUES(9282,NULL,'Nichols, NY',3792,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9283,NULL,'Nichols, NY 13812',3792,222,NULL,32,5198,0);
INSERT INTO "django_geo_db_location" VALUES(9284,NULL,'Nineveh, NY',3793,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9285,NULL,'Nineveh, NY 13813',3793,222,NULL,32,5199,0);
INSERT INTO "django_geo_db_location" VALUES(9286,NULL,'North Norwich, NY',3794,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9287,NULL,'North Norwich, NY 13814',3794,222,NULL,32,5200,0);
INSERT INTO "django_geo_db_location" VALUES(9288,NULL,'Norwich, NY',3795,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9289,NULL,'Norwich, NY 13815',3795,222,NULL,32,5201,0);
INSERT INTO "django_geo_db_location" VALUES(9290,NULL,'Oneonta, NY',3796,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9291,NULL,'Oneonta, NY 13820',3796,222,NULL,32,5202,0);
INSERT INTO "django_geo_db_location" VALUES(9292,NULL,'Otego, NY',3797,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9293,NULL,'Otego, NY 13825',3797,222,NULL,32,5203,0);
INSERT INTO "django_geo_db_location" VALUES(9294,NULL,'Ouaquaga, NY',3798,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9295,NULL,'Ouaquaga, NY 13826',3798,222,NULL,32,5204,0);
INSERT INTO "django_geo_db_location" VALUES(9296,NULL,'Owego, NY',3799,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9297,NULL,'Owego, NY 13827',3799,222,NULL,32,5205,0);
INSERT INTO "django_geo_db_location" VALUES(9298,NULL,'Oxford, NY',3800,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9299,NULL,'Oxford, NY 13830',3800,222,NULL,32,5206,0);
INSERT INTO "django_geo_db_location" VALUES(9300,NULL,'Plymouth, NY 13832',3611,222,NULL,32,5207,0);
INSERT INTO "django_geo_db_location" VALUES(9301,NULL,'Port Crane, NY',3801,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9302,NULL,'Port Crane, NY 13833',3801,222,NULL,32,5208,0);
INSERT INTO "django_geo_db_location" VALUES(9303,NULL,'Portlandville, NY',3802,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9304,NULL,'Portlandville, NY 13834',3802,222,NULL,32,5209,0);
INSERT INTO "django_geo_db_location" VALUES(9305,NULL,'Richford, NY',3803,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9306,NULL,'Richford, NY 13835',3803,222,NULL,32,5210,0);
INSERT INTO "django_geo_db_location" VALUES(9307,NULL,'Shinhopple, NY',3804,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9308,NULL,'Shinhopple, NY 13837',3804,222,NULL,32,5211,0);
INSERT INTO "django_geo_db_location" VALUES(9309,NULL,'Sidney, NY',3805,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9310,NULL,'Sidney, NY 13838',3805,222,NULL,32,5212,0);
INSERT INTO "django_geo_db_location" VALUES(9311,NULL,'Sidney Center, NY',3806,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9312,NULL,'Sidney Center, NY 13839',3806,222,NULL,32,5213,0);
INSERT INTO "django_geo_db_location" VALUES(9313,NULL,'Smithboro, NY',3807,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9314,NULL,'Smithboro, NY 13840',3807,222,NULL,32,5214,0);
INSERT INTO "django_geo_db_location" VALUES(9315,NULL,'Smithville Flats, NY',3808,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9316,NULL,'Smithville Flats, NY 13841',3808,222,NULL,32,5215,0);
INSERT INTO "django_geo_db_location" VALUES(9317,NULL,'South Kortright, NY',3809,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9318,NULL,'South Kortright, NY 13842',3809,222,NULL,32,5216,0);
INSERT INTO "django_geo_db_location" VALUES(9319,NULL,'South New Berlin, NY',3810,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9320,NULL,'South New Berlin, NY 13843',3810,222,NULL,32,5217,0);
INSERT INTO "django_geo_db_location" VALUES(9321,NULL,'South Plymouth, NY',3811,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9322,NULL,'South Plymouth, NY 13844',3811,222,NULL,32,5218,0);
INSERT INTO "django_geo_db_location" VALUES(9323,NULL,'Tioga Center, NY',3812,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9324,NULL,'Tioga Center, NY 13845',3812,222,NULL,32,5219,0);
INSERT INTO "django_geo_db_location" VALUES(9325,NULL,'Treadwell, NY',3813,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9326,NULL,'Treadwell, NY 13846',3813,222,NULL,32,5220,0);
INSERT INTO "django_geo_db_location" VALUES(9327,NULL,'Trout Creek, NY',3814,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9328,NULL,'Trout Creek, NY 13847',3814,222,NULL,32,5221,0);
INSERT INTO "django_geo_db_location" VALUES(9329,NULL,'Tunnel, NY',3815,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9330,NULL,'Tunnel, NY 13848',3815,222,NULL,32,5222,0);
INSERT INTO "django_geo_db_location" VALUES(9331,NULL,'Unadilla, NY',3816,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9332,NULL,'Unadilla, NY 13849',3816,222,NULL,32,5223,0);
INSERT INTO "django_geo_db_location" VALUES(9333,NULL,'Vestal, NY',3817,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9334,NULL,'Vestal, NY 13850',3817,222,NULL,32,5224,0);
INSERT INTO "django_geo_db_location" VALUES(9335,NULL,'Vestal, NY 13851',3817,222,NULL,32,5225,0);
INSERT INTO "django_geo_db_location" VALUES(9336,NULL,'Walton, NY',3818,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9337,NULL,'Walton, NY 13856',3818,222,NULL,32,5226,0);
INSERT INTO "django_geo_db_location" VALUES(9338,NULL,'Wells Bridge, NY',3819,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9339,NULL,'Wells Bridge, NY 13859',3819,222,NULL,32,5227,0);
INSERT INTO "django_geo_db_location" VALUES(9340,NULL,'West Davenport, NY',3820,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9341,NULL,'West Davenport, NY 13860',3820,222,NULL,32,5228,0);
INSERT INTO "django_geo_db_location" VALUES(9342,NULL,'West Oneonta, NY',3821,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9343,NULL,'West Oneonta, NY 13861',3821,222,NULL,32,5229,0);
INSERT INTO "django_geo_db_location" VALUES(9344,NULL,'Whitney Point, NY',3822,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9345,NULL,'Whitney Point, NY 13862',3822,222,NULL,32,5230,0);
INSERT INTO "django_geo_db_location" VALUES(9346,NULL,'Willet, NY',3823,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9347,NULL,'Willet, NY 13863',3823,222,NULL,32,5231,0);
INSERT INTO "django_geo_db_location" VALUES(9348,NULL,'Willseyville, NY',3824,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9349,NULL,'Willseyville, NY 13864',3824,222,NULL,32,5232,0);
INSERT INTO "django_geo_db_location" VALUES(9350,NULL,'Windsor, NY',3825,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9351,NULL,'Windsor, NY 13865',3825,222,NULL,32,5233,0);
INSERT INTO "django_geo_db_location" VALUES(9352,NULL,'Binghamton, NY',3826,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9353,NULL,'Binghamton, NY 13901',3826,222,NULL,32,5234,0);
INSERT INTO "django_geo_db_location" VALUES(9354,NULL,'Binghamton, NY 13902',3826,222,NULL,32,5235,0);
INSERT INTO "django_geo_db_location" VALUES(9355,NULL,'Binghamton, NY 13903',3826,222,NULL,32,5236,0);
INSERT INTO "django_geo_db_location" VALUES(9356,NULL,'Binghamton, NY 13904',3826,222,NULL,32,5237,0);
INSERT INTO "django_geo_db_location" VALUES(9357,NULL,'Binghamton, NY 13905',3826,222,NULL,32,5238,0);
INSERT INTO "django_geo_db_location" VALUES(9358,NULL,'Whitestown, NY',3827,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9359,NULL,'Whitestown, NY 13942',3827,222,NULL,32,5239,0);
INSERT INTO "django_geo_db_location" VALUES(9360,NULL,'Akron, NY',3828,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9361,NULL,'Akron, NY 14001',3828,222,NULL,32,5240,0);
INSERT INTO "django_geo_db_location" VALUES(9362,NULL,'Alabama, NY',3829,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9363,NULL,'Alabama, NY 14003',3829,222,NULL,32,5241,0);
INSERT INTO "django_geo_db_location" VALUES(9364,NULL,'Alden, NY',3830,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9365,NULL,'Alden, NY 14004',3830,222,NULL,32,5242,0);
INSERT INTO "django_geo_db_location" VALUES(9366,NULL,'Alexander, NY',3831,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9367,NULL,'Alexander, NY 14005',3831,222,NULL,32,5243,0);
INSERT INTO "django_geo_db_location" VALUES(9368,NULL,'Angola, NY',3832,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9369,NULL,'Angola, NY 14006',3832,222,NULL,32,5244,0);
INSERT INTO "django_geo_db_location" VALUES(9370,NULL,'Appleton, NY',3833,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9371,NULL,'Appleton, NY 14008',3833,222,NULL,32,5245,0);
INSERT INTO "django_geo_db_location" VALUES(9372,NULL,'Arcade, NY',3834,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9373,NULL,'Arcade, NY 14009',3834,222,NULL,32,5246,0);
INSERT INTO "django_geo_db_location" VALUES(9374,NULL,'Athol Springs, NY',3835,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9375,NULL,'Athol Springs, NY 14010',3835,222,NULL,32,5247,0);
INSERT INTO "django_geo_db_location" VALUES(9376,NULL,'Attica, NY',3836,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9377,NULL,'Attica, NY 14011',3836,222,NULL,32,5248,0);
INSERT INTO "django_geo_db_location" VALUES(9378,NULL,'Barker, NY',3837,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9379,NULL,'Barker, NY 14012',3837,222,NULL,32,5249,0);
INSERT INTO "django_geo_db_location" VALUES(9380,NULL,'Basom, NY',3838,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9381,NULL,'Basom, NY 14013',3838,222,NULL,32,5250,0);
INSERT INTO "django_geo_db_location" VALUES(9382,NULL,'Batavia, NY',3839,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9383,NULL,'Batavia, NY 14020',3839,222,NULL,32,5251,0);
INSERT INTO "django_geo_db_location" VALUES(9384,NULL,'Batavia, NY 14021',3839,222,NULL,32,5252,0);
INSERT INTO "django_geo_db_location" VALUES(9385,NULL,'Bliss, NY',3840,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9386,NULL,'Bliss, NY 14024',3840,222,NULL,32,5253,0);
INSERT INTO "django_geo_db_location" VALUES(9387,NULL,'Boston, NY',3841,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9388,NULL,'Boston, NY 14025',3841,222,NULL,32,5254,0);
INSERT INTO "django_geo_db_location" VALUES(9389,NULL,'Bowmansville, NY',3842,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9390,NULL,'Bowmansville, NY 14026',3842,222,NULL,32,5255,0);
INSERT INTO "django_geo_db_location" VALUES(9391,NULL,'Brant, NY',3843,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9392,NULL,'Brant, NY 14027',3843,222,NULL,32,5256,0);
INSERT INTO "django_geo_db_location" VALUES(9393,NULL,'Burt, NY',3844,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9394,NULL,'Burt, NY 14028',3844,222,NULL,32,5257,0);
INSERT INTO "django_geo_db_location" VALUES(9395,NULL,'Centerville, NY',3845,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9396,NULL,'Centerville, NY 14029',3845,222,NULL,32,5258,0);
INSERT INTO "django_geo_db_location" VALUES(9397,NULL,'Chaffee, NY',3846,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9398,NULL,'Chaffee, NY 14030',3846,222,NULL,32,5259,0);
INSERT INTO "django_geo_db_location" VALUES(9399,NULL,'Clarence, NY',3847,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9400,NULL,'Clarence, NY 14031',3847,222,NULL,32,5260,0);
INSERT INTO "django_geo_db_location" VALUES(9401,NULL,'Clarence Center, NY',3848,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9402,NULL,'Clarence Center, NY 14032',3848,222,NULL,32,5261,0);
INSERT INTO "django_geo_db_location" VALUES(9403,NULL,'Colden, NY',3849,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9404,NULL,'Colden, NY 14033',3849,222,NULL,32,5262,0);
INSERT INTO "django_geo_db_location" VALUES(9405,NULL,'Collins, NY',3850,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9406,NULL,'Collins, NY 14034',3850,222,NULL,32,5263,0);
INSERT INTO "django_geo_db_location" VALUES(9407,NULL,'Collins Center, NY',3851,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9408,NULL,'Collins Center, NY 14035',3851,222,NULL,32,5264,0);
INSERT INTO "django_geo_db_location" VALUES(9409,NULL,'Corfu, NY',3852,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9410,NULL,'Corfu, NY 14036',3852,222,NULL,32,5265,0);
INSERT INTO "django_geo_db_location" VALUES(9411,NULL,'Cowlesville, NY',3853,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9412,NULL,'Cowlesville, NY 14037',3853,222,NULL,32,5266,0);
INSERT INTO "django_geo_db_location" VALUES(9413,NULL,'Crittenden, NY',3854,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9414,NULL,'Crittenden, NY 14038',3854,222,NULL,32,5267,0);
INSERT INTO "django_geo_db_location" VALUES(9415,NULL,'Dale, NY',3855,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9416,NULL,'Dale, NY 14039',3855,222,NULL,32,5268,0);
INSERT INTO "django_geo_db_location" VALUES(9417,NULL,'Darien Center, NY',3856,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9418,NULL,'Darien Center, NY 14040',3856,222,NULL,32,5269,0);
INSERT INTO "django_geo_db_location" VALUES(9419,NULL,'Dayton, NY',3857,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9420,NULL,'Dayton, NY 14041',3857,222,NULL,32,5270,0);
INSERT INTO "django_geo_db_location" VALUES(9421,NULL,'Delevan, NY',3858,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9422,NULL,'Delevan, NY 14042',3858,222,NULL,32,5271,0);
INSERT INTO "django_geo_db_location" VALUES(9423,NULL,'Depew, NY',3859,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9424,NULL,'Depew, NY 14043',3859,222,NULL,32,5272,0);
INSERT INTO "django_geo_db_location" VALUES(9425,NULL,'Derby, NY',3860,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9426,NULL,'Derby, NY 14047',3860,222,NULL,32,5273,0);
INSERT INTO "django_geo_db_location" VALUES(9427,NULL,'Dunkirk, NY',3861,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9428,NULL,'Dunkirk, NY 14048',3861,222,NULL,32,5274,0);
INSERT INTO "django_geo_db_location" VALUES(9429,NULL,'East Amherst, NY',3862,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9430,NULL,'East Amherst, NY 14051',3862,222,NULL,32,5275,0);
INSERT INTO "django_geo_db_location" VALUES(9431,NULL,'East Aurora, NY',3863,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9432,NULL,'East Aurora, NY 14052',3863,222,NULL,32,5276,0);
INSERT INTO "django_geo_db_location" VALUES(9433,NULL,'East Bethany, NY',3864,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9434,NULL,'East Bethany, NY 14054',3864,222,NULL,32,5277,0);
INSERT INTO "django_geo_db_location" VALUES(9435,NULL,'East Concord, NY',3865,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9436,NULL,'East Concord, NY 14055',3865,222,NULL,32,5278,0);
INSERT INTO "django_geo_db_location" VALUES(9437,NULL,'East Pembroke, NY',3866,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9438,NULL,'East Pembroke, NY 14056',3866,222,NULL,32,5279,0);
INSERT INTO "django_geo_db_location" VALUES(9439,NULL,'Eden, NY',3867,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9440,NULL,'Eden, NY 14057',3867,222,NULL,32,5280,0);
INSERT INTO "django_geo_db_location" VALUES(9441,NULL,'Elba, NY',3868,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9442,NULL,'Elba, NY 14058',3868,222,NULL,32,5281,0);
INSERT INTO "django_geo_db_location" VALUES(9443,NULL,'Elma, NY',3869,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9444,NULL,'Elma, NY 14059',3869,222,NULL,32,5282,0);
INSERT INTO "django_geo_db_location" VALUES(9445,NULL,'Farmersville Station, NY',3870,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9446,NULL,'Farmersville Station, NY 14060',3870,222,NULL,32,5283,0);
INSERT INTO "django_geo_db_location" VALUES(9447,NULL,'Farnham, NY',3871,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9448,NULL,'Farnham, NY 14061',3871,222,NULL,32,5284,0);
INSERT INTO "django_geo_db_location" VALUES(9449,NULL,'Forestville, NY',3872,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9450,NULL,'Forestville, NY 14062',3872,222,NULL,32,5285,0);
INSERT INTO "django_geo_db_location" VALUES(9451,NULL,'Fredonia, NY',3873,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9452,NULL,'Fredonia, NY 14063',3873,222,NULL,32,5286,0);
INSERT INTO "django_geo_db_location" VALUES(9453,NULL,'Rochester, NY',3874,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9454,NULL,'Rochester, NY 14064',3874,222,NULL,32,5287,0);
INSERT INTO "django_geo_db_location" VALUES(9455,NULL,'Freedom, NY',3875,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9456,NULL,'Freedom, NY 14065',3875,222,NULL,32,5288,0);
INSERT INTO "django_geo_db_location" VALUES(9457,NULL,'Gainesville, NY',3876,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9458,NULL,'Gainesville, NY 14066',3876,222,NULL,32,5289,0);
INSERT INTO "django_geo_db_location" VALUES(9459,NULL,'Gasport, NY',3877,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9460,NULL,'Gasport, NY 14067',3877,222,NULL,32,5290,0);
INSERT INTO "django_geo_db_location" VALUES(9461,NULL,'Getzville, NY',3878,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9462,NULL,'Getzville, NY 14068',3878,222,NULL,32,5291,0);
INSERT INTO "django_geo_db_location" VALUES(9463,NULL,'Glenwood, NY',3879,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9464,NULL,'Glenwood, NY 14069',3879,222,NULL,32,5292,0);
INSERT INTO "django_geo_db_location" VALUES(9465,NULL,'Gowanda, NY',3880,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9466,NULL,'Gowanda, NY 14070',3880,222,NULL,32,5293,0);
INSERT INTO "django_geo_db_location" VALUES(9467,NULL,'Grand Island, NY',3881,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9468,NULL,'Grand Island, NY 14072',3881,222,NULL,32,5294,0);
INSERT INTO "django_geo_db_location" VALUES(9469,NULL,'Hamburg, NY',3882,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9470,NULL,'Hamburg, NY 14075',3882,222,NULL,32,5295,0);
INSERT INTO "django_geo_db_location" VALUES(9471,NULL,'Holland, NY',3883,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9472,NULL,'Holland, NY 14080',3883,222,NULL,32,5296,0);
INSERT INTO "django_geo_db_location" VALUES(9473,NULL,'Irving, NY',3884,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9474,NULL,'Irving, NY 14081',3884,222,NULL,32,5297,0);
INSERT INTO "django_geo_db_location" VALUES(9475,NULL,'Java Center, NY',3885,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9476,NULL,'Java Center, NY 14082',3885,222,NULL,32,5298,0);
INSERT INTO "django_geo_db_location" VALUES(9477,NULL,'Java Village, NY',3886,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9478,NULL,'Java Village, NY 14083',3886,222,NULL,32,5299,0);
INSERT INTO "django_geo_db_location" VALUES(9479,NULL,'Lake View, NY',3887,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9480,NULL,'Lake View, NY 14085',3887,222,NULL,32,5300,0);
INSERT INTO "django_geo_db_location" VALUES(9481,NULL,'Lancaster, NY',3888,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9482,NULL,'Lancaster, NY 14086',3888,222,NULL,32,5301,0);
INSERT INTO "django_geo_db_location" VALUES(9483,NULL,'Lawtons, NY',3889,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9484,NULL,'Lawtons, NY 14091',3889,222,NULL,32,5302,0);
INSERT INTO "django_geo_db_location" VALUES(9485,NULL,'Lewiston, NY',3890,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9486,NULL,'Lewiston, NY 14092',3890,222,NULL,32,5303,0);
INSERT INTO "django_geo_db_location" VALUES(9487,NULL,'Lockport, NY',3891,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9488,NULL,'Lockport, NY 14094',3891,222,NULL,32,5304,0);
INSERT INTO "django_geo_db_location" VALUES(9489,NULL,'Lockport, NY 14095',3891,222,NULL,32,5305,0);
INSERT INTO "django_geo_db_location" VALUES(9490,NULL,'Lyndonville, NY',3892,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9491,NULL,'Lyndonville, NY 14098',3892,222,NULL,32,5306,0);
INSERT INTO "django_geo_db_location" VALUES(9492,NULL,'Machias, NY',3893,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9493,NULL,'Machias, NY 14101',3893,222,NULL,32,5307,0);
INSERT INTO "django_geo_db_location" VALUES(9494,NULL,'Marilla, NY',3894,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9495,NULL,'Marilla, NY 14102',3894,222,NULL,32,5308,0);
INSERT INTO "django_geo_db_location" VALUES(9496,NULL,'Medina, NY',3895,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9497,NULL,'Medina, NY 14103',3895,222,NULL,32,5309,0);
INSERT INTO "django_geo_db_location" VALUES(9498,NULL,'Middleport, NY',3896,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9499,NULL,'Middleport, NY 14105',3896,222,NULL,32,5310,0);
INSERT INTO "django_geo_db_location" VALUES(9500,NULL,'Model City, NY',3897,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9501,NULL,'Model City, NY 14107',3897,222,NULL,32,5311,0);
INSERT INTO "django_geo_db_location" VALUES(9502,NULL,'Newfane, NY',3898,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9503,NULL,'Newfane, NY 14108',3898,222,NULL,32,5312,0);
INSERT INTO "django_geo_db_location" VALUES(9504,NULL,'Niagara University, NY',3899,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9505,NULL,'Niagara University, NY 14109',3899,222,NULL,32,5313,0);
INSERT INTO "django_geo_db_location" VALUES(9506,NULL,'North Boston, NY',3900,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9507,NULL,'North Boston, NY 14110',3900,222,NULL,32,5314,0);
INSERT INTO "django_geo_db_location" VALUES(9508,NULL,'North Collins, NY',3901,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9509,NULL,'North Collins, NY 14111',3901,222,NULL,32,5315,0);
INSERT INTO "django_geo_db_location" VALUES(9510,NULL,'North Evans, NY',3902,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9511,NULL,'North Evans, NY 14112',3902,222,NULL,32,5316,0);
INSERT INTO "django_geo_db_location" VALUES(9512,NULL,'North Java, NY',3903,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9513,NULL,'North Java, NY 14113',3903,222,NULL,32,5317,0);
INSERT INTO "django_geo_db_location" VALUES(9514,NULL,'North Tonawanda, NY',3904,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9515,NULL,'North Tonawanda, NY 14120',3904,222,NULL,32,5318,0);
INSERT INTO "django_geo_db_location" VALUES(9516,NULL,'Oakfield, NY',3905,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9517,NULL,'Oakfield, NY 14125',3905,222,NULL,32,5319,0);
INSERT INTO "django_geo_db_location" VALUES(9518,NULL,'Olcott, NY',3906,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9519,NULL,'Olcott, NY 14126',3906,222,NULL,32,5320,0);
INSERT INTO "django_geo_db_location" VALUES(9520,NULL,'Orchard Park, NY',3907,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9521,NULL,'Orchard Park, NY 14127',3907,222,NULL,32,5321,0);
INSERT INTO "django_geo_db_location" VALUES(9522,NULL,'Perrysburg, NY',3908,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9523,NULL,'Perrysburg, NY 14129',3908,222,NULL,32,5322,0);
INSERT INTO "django_geo_db_location" VALUES(9524,NULL,'Pike, NY',3909,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9525,NULL,'Pike, NY 14130',3909,222,NULL,32,5323,0);
INSERT INTO "django_geo_db_location" VALUES(9526,NULL,'Ransomville, NY',3910,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9527,NULL,'Ransomville, NY 14131',3910,222,NULL,32,5324,0);
INSERT INTO "django_geo_db_location" VALUES(9528,NULL,'Sanborn, NY',3911,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9529,NULL,'Sanborn, NY 14132',3911,222,NULL,32,5325,0);
INSERT INTO "django_geo_db_location" VALUES(9530,NULL,'Sandusky, NY',3912,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9531,NULL,'Sandusky, NY 14133',3912,222,NULL,32,5326,0);
INSERT INTO "django_geo_db_location" VALUES(9532,NULL,'Sardinia, NY',3913,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9533,NULL,'Sardinia, NY 14134',3913,222,NULL,32,5327,0);
INSERT INTO "django_geo_db_location" VALUES(9534,NULL,'Sheridan, NY',3914,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9535,NULL,'Sheridan, NY 14135',3914,222,NULL,32,5328,0);
INSERT INTO "django_geo_db_location" VALUES(9536,NULL,'Silver Creek, NY',3915,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9537,NULL,'Silver Creek, NY 14136',3915,222,NULL,32,5329,0);
INSERT INTO "django_geo_db_location" VALUES(9538,NULL,'South Dayton, NY',3916,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9539,NULL,'South Dayton, NY 14138',3916,222,NULL,32,5330,0);
INSERT INTO "django_geo_db_location" VALUES(9540,NULL,'South Wales, NY',3917,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9541,NULL,'South Wales, NY 14139',3917,222,NULL,32,5331,0);
INSERT INTO "django_geo_db_location" VALUES(9542,NULL,'Spring Brook, NY',3918,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9543,NULL,'Spring Brook, NY 14140',3918,222,NULL,32,5332,0);
INSERT INTO "django_geo_db_location" VALUES(9544,NULL,'Springville, NY',3919,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9545,NULL,'Springville, NY 14141',3919,222,NULL,32,5333,0);
INSERT INTO "django_geo_db_location" VALUES(9546,NULL,'Stafford, NY',3920,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9547,NULL,'Stafford, NY 14143',3920,222,NULL,32,5334,0);
INSERT INTO "django_geo_db_location" VALUES(9548,NULL,'Stella Niagara, NY',3921,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9549,NULL,'Stella Niagara, NY 14144',3921,222,NULL,32,5335,0);
INSERT INTO "django_geo_db_location" VALUES(9550,NULL,'Strykersville, NY',3922,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9551,NULL,'Strykersville, NY 14145',3922,222,NULL,32,5336,0);
INSERT INTO "django_geo_db_location" VALUES(9552,NULL,'Tonawanda, NY',3923,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9553,NULL,'Tonawanda, NY 14150',3923,222,NULL,32,5337,0);
INSERT INTO "django_geo_db_location" VALUES(9554,NULL,'Tonawanda, NY 14151',3923,222,NULL,32,5338,0);
INSERT INTO "django_geo_db_location" VALUES(9555,NULL,'Van Buren Point, NY',3924,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9556,NULL,'Van Buren Point, NY 14166',3924,222,NULL,32,5339,0);
INSERT INTO "django_geo_db_location" VALUES(9557,NULL,'Varysburg, NY',3925,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9558,NULL,'Varysburg, NY 14167',3925,222,NULL,32,5340,0);
INSERT INTO "django_geo_db_location" VALUES(9559,NULL,'Versailles, NY',3926,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9560,NULL,'Versailles, NY 14168',3926,222,NULL,32,5341,0);
INSERT INTO "django_geo_db_location" VALUES(9561,NULL,'Wales Center, NY',3927,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9562,NULL,'Wales Center, NY 14169',3927,222,NULL,32,5342,0);
INSERT INTO "django_geo_db_location" VALUES(9563,NULL,'West Falls, NY',3928,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9564,NULL,'West Falls, NY 14170',3928,222,NULL,32,5343,0);
INSERT INTO "django_geo_db_location" VALUES(9565,NULL,'West Valley, NY',3929,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9566,NULL,'West Valley, NY 14171',3929,222,NULL,32,5344,0);
INSERT INTO "django_geo_db_location" VALUES(9567,NULL,'Wilson, NY',3930,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9568,NULL,'Wilson, NY 14172',3930,222,NULL,32,5345,0);
INSERT INTO "django_geo_db_location" VALUES(9569,NULL,'Yorkshire, NY',3931,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9570,NULL,'Yorkshire, NY 14173',3931,222,NULL,32,5346,0);
INSERT INTO "django_geo_db_location" VALUES(9571,NULL,'Youngstown, NY',3932,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9572,NULL,'Youngstown, NY 14174',3932,222,NULL,32,5347,0);
INSERT INTO "django_geo_db_location" VALUES(9573,NULL,'Buffalo, NY',3933,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9574,NULL,'Buffalo, NY 14201',3933,222,NULL,32,5348,0);
INSERT INTO "django_geo_db_location" VALUES(9575,NULL,'Buffalo, NY 14202',3933,222,NULL,32,5349,0);
INSERT INTO "django_geo_db_location" VALUES(9576,NULL,'Buffalo, NY 14203',3933,222,NULL,32,5350,0);
INSERT INTO "django_geo_db_location" VALUES(9577,NULL,'Buffalo, NY 14204',3933,222,NULL,32,5351,0);
INSERT INTO "django_geo_db_location" VALUES(9578,NULL,'Buffalo, NY 14205',3933,222,NULL,32,5352,0);
INSERT INTO "django_geo_db_location" VALUES(9579,NULL,'Buffalo, NY 14206',3933,222,NULL,32,5353,0);
INSERT INTO "django_geo_db_location" VALUES(9580,NULL,'Buffalo, NY 14207',3933,222,NULL,32,5354,0);
INSERT INTO "django_geo_db_location" VALUES(9581,NULL,'Buffalo, NY 14208',3933,222,NULL,32,5355,0);
INSERT INTO "django_geo_db_location" VALUES(9582,NULL,'Buffalo, NY 14209',3933,222,NULL,32,5356,0);
INSERT INTO "django_geo_db_location" VALUES(9583,NULL,'Buffalo, NY 14210',3933,222,NULL,32,5357,0);
INSERT INTO "django_geo_db_location" VALUES(9584,NULL,'Buffalo, NY 14211',3933,222,NULL,32,5358,0);
INSERT INTO "django_geo_db_location" VALUES(9585,NULL,'Buffalo, NY 14212',3933,222,NULL,32,5359,0);
INSERT INTO "django_geo_db_location" VALUES(9586,NULL,'Buffalo, NY 14213',3933,222,NULL,32,5360,0);
INSERT INTO "django_geo_db_location" VALUES(9587,NULL,'Buffalo, NY 14214',3933,222,NULL,32,5361,0);
INSERT INTO "django_geo_db_location" VALUES(9588,NULL,'Buffalo, NY 14215',3933,222,NULL,32,5362,0);
INSERT INTO "django_geo_db_location" VALUES(9589,NULL,'Buffalo, NY 14216',3933,222,NULL,32,5363,0);
INSERT INTO "django_geo_db_location" VALUES(9590,NULL,'Buffalo, NY 14217',3933,222,NULL,32,5364,0);
INSERT INTO "django_geo_db_location" VALUES(9591,NULL,'Buffalo, NY 14218',3933,222,NULL,32,5365,0);
INSERT INTO "django_geo_db_location" VALUES(9592,NULL,'Buffalo, NY 14219',3933,222,NULL,32,5366,0);
INSERT INTO "django_geo_db_location" VALUES(9593,NULL,'Buffalo, NY 14220',3933,222,NULL,32,5367,0);
INSERT INTO "django_geo_db_location" VALUES(9594,NULL,'Buffalo, NY 14221',3933,222,NULL,32,5368,0);
INSERT INTO "django_geo_db_location" VALUES(9595,NULL,'Buffalo, NY 14222',3933,222,NULL,32,5369,0);
INSERT INTO "django_geo_db_location" VALUES(9596,NULL,'Buffalo, NY 14223',3933,222,NULL,32,5370,0);
INSERT INTO "django_geo_db_location" VALUES(9597,NULL,'Buffalo, NY 14224',3933,222,NULL,32,5371,0);
INSERT INTO "django_geo_db_location" VALUES(9598,NULL,'Buffalo, NY 14225',3933,222,NULL,32,5372,0);
INSERT INTO "django_geo_db_location" VALUES(9599,NULL,'Buffalo, NY 14226',3933,222,NULL,32,5373,0);
INSERT INTO "django_geo_db_location" VALUES(9600,NULL,'Buffalo, NY 14227',3933,222,NULL,32,5374,0);
INSERT INTO "django_geo_db_location" VALUES(9601,NULL,'Buffalo, NY 14228',3933,222,NULL,32,5375,0);
INSERT INTO "django_geo_db_location" VALUES(9602,NULL,'Buffalo, NY 14231',3933,222,NULL,32,5376,0);
INSERT INTO "django_geo_db_location" VALUES(9603,NULL,'Buffalo, NY 14233',3933,222,NULL,32,5377,0);
INSERT INTO "django_geo_db_location" VALUES(9604,NULL,'Buffalo, NY 14240',3933,222,NULL,32,5378,0);
INSERT INTO "django_geo_db_location" VALUES(9605,NULL,'Buffalo, NY 14241',3933,222,NULL,32,5379,0);
INSERT INTO "django_geo_db_location" VALUES(9606,NULL,'Buffalo, NY 14260',3933,222,NULL,32,5380,0);
INSERT INTO "django_geo_db_location" VALUES(9607,NULL,'Buffalo, NY 14261',3933,222,NULL,32,5381,0);
INSERT INTO "django_geo_db_location" VALUES(9608,NULL,'Buffalo, NY 14263',3933,222,NULL,32,5382,0);
INSERT INTO "django_geo_db_location" VALUES(9609,NULL,'Buffalo, NY 14264',3933,222,NULL,32,5383,0);
INSERT INTO "django_geo_db_location" VALUES(9610,NULL,'Buffalo, NY 14265',3933,222,NULL,32,5384,0);
INSERT INTO "django_geo_db_location" VALUES(9611,NULL,'Buffalo, NY 14267',3933,222,NULL,32,5385,0);
INSERT INTO "django_geo_db_location" VALUES(9612,NULL,'Buffalo, NY 14269',3933,222,NULL,32,5386,0);
INSERT INTO "django_geo_db_location" VALUES(9613,NULL,'Buffalo, NY 14270',3933,222,NULL,32,5387,0);
INSERT INTO "django_geo_db_location" VALUES(9614,NULL,'Buffalo, NY 14272',3933,222,NULL,32,5388,0);
INSERT INTO "django_geo_db_location" VALUES(9615,NULL,'Buffalo, NY 14273',3933,222,NULL,32,5389,0);
INSERT INTO "django_geo_db_location" VALUES(9616,NULL,'Buffalo, NY 14276',3933,222,NULL,32,5390,0);
INSERT INTO "django_geo_db_location" VALUES(9617,NULL,'Buffalo, NY 14280',3933,222,NULL,32,5391,0);
INSERT INTO "django_geo_db_location" VALUES(9618,NULL,'Niagara Falls, NY',3934,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9619,NULL,'Niagara Falls, NY 14301',3934,222,NULL,32,5392,0);
INSERT INTO "django_geo_db_location" VALUES(9620,NULL,'Niagara Falls, NY 14302',3934,222,NULL,32,5393,0);
INSERT INTO "django_geo_db_location" VALUES(9621,NULL,'Niagara Falls, NY 14303',3934,222,NULL,32,5394,0);
INSERT INTO "django_geo_db_location" VALUES(9622,NULL,'Niagara Falls, NY 14304',3934,222,NULL,32,5395,0);
INSERT INTO "django_geo_db_location" VALUES(9623,NULL,'Niagara Falls, NY 14305',3934,222,NULL,32,5396,0);
INSERT INTO "django_geo_db_location" VALUES(9624,NULL,'Adams Basin, NY',3935,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9625,NULL,'Adams Basin, NY 14410',3935,222,NULL,32,5397,0);
INSERT INTO "django_geo_db_location" VALUES(9626,NULL,'Albion, NY',3936,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9627,NULL,'Albion, NY 14411',3936,222,NULL,32,5398,0);
INSERT INTO "django_geo_db_location" VALUES(9628,NULL,'Alton, NY',3937,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9629,NULL,'Alton, NY 14413',3937,222,NULL,32,5399,0);
INSERT INTO "django_geo_db_location" VALUES(9630,NULL,'Avon, NY',3938,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9631,NULL,'Avon, NY 14414',3938,222,NULL,32,5400,0);
INSERT INTO "django_geo_db_location" VALUES(9632,NULL,'Bellona, NY',3939,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9633,NULL,'Bellona, NY 14415',3939,222,NULL,32,5401,0);
INSERT INTO "django_geo_db_location" VALUES(9634,NULL,'Bergen, NY',3940,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9635,NULL,'Bergen, NY 14416',3940,222,NULL,32,5402,0);
INSERT INTO "django_geo_db_location" VALUES(9636,NULL,'Geneseo, NY',3941,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9637,NULL,'Geneseo, NY 14417',3941,222,NULL,32,5403,0);
INSERT INTO "django_geo_db_location" VALUES(9638,NULL,'Branchport, NY',3942,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9639,NULL,'Branchport, NY 14418',3942,222,NULL,32,5404,0);
INSERT INTO "django_geo_db_location" VALUES(9640,NULL,'Brockport, NY',3943,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9641,NULL,'Brockport, NY 14420',3943,222,NULL,32,5405,0);
INSERT INTO "django_geo_db_location" VALUES(9642,NULL,'Byron, NY',3944,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9643,NULL,'Byron, NY 14422',3944,222,NULL,32,5406,0);
INSERT INTO "django_geo_db_location" VALUES(9644,NULL,'Caledonia, NY',3945,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9645,NULL,'Caledonia, NY 14423',3945,222,NULL,32,5407,0);
INSERT INTO "django_geo_db_location" VALUES(9646,NULL,'Canandaigua, NY',3946,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9647,NULL,'Canandaigua, NY 14424',3946,222,NULL,32,5408,0);
INSERT INTO "django_geo_db_location" VALUES(9648,NULL,'Farmington, NY',3947,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9649,NULL,'Farmington, NY 14425',3947,222,NULL,32,5409,0);
INSERT INTO "django_geo_db_location" VALUES(9650,NULL,'Castile, NY',3948,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9651,NULL,'Castile, NY 14427',3948,222,NULL,32,5410,0);
INSERT INTO "django_geo_db_location" VALUES(9652,NULL,'Churchville, NY',3949,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9653,NULL,'Churchville, NY 14428',3949,222,NULL,32,5411,0);
INSERT INTO "django_geo_db_location" VALUES(9654,NULL,'Clarendon, NY',3950,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9655,NULL,'Clarendon, NY 14429',3950,222,NULL,32,5412,0);
INSERT INTO "django_geo_db_location" VALUES(9656,NULL,'Clarkson, NY',3951,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9657,NULL,'Clarkson, NY 14430',3951,222,NULL,32,5413,0);
INSERT INTO "django_geo_db_location" VALUES(9658,NULL,'Clifton Springs, NY',3952,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9659,NULL,'Clifton Springs, NY 14432',3952,222,NULL,32,5414,0);
INSERT INTO "django_geo_db_location" VALUES(9660,NULL,'Clyde, NY',3953,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9661,NULL,'Clyde, NY 14433',3953,222,NULL,32,5415,0);
INSERT INTO "django_geo_db_location" VALUES(9662,NULL,'Conesus, NY',3954,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9663,NULL,'Conesus, NY 14435',3954,222,NULL,32,5416,0);
INSERT INTO "django_geo_db_location" VALUES(9664,NULL,'Dansville, NY',3955,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9665,NULL,'Dansville, NY 14437',3955,222,NULL,32,5417,0);
INSERT INTO "django_geo_db_location" VALUES(9666,NULL,'Dresden, NY',3956,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9667,NULL,'Dresden, NY 14441',3956,222,NULL,32,5418,0);
INSERT INTO "django_geo_db_location" VALUES(9668,NULL,'East Bloomfield, NY',3957,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9669,NULL,'East Bloomfield, NY 14443',3957,222,NULL,32,5419,0);
INSERT INTO "django_geo_db_location" VALUES(9670,NULL,'East Rochester, NY',3958,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9671,NULL,'East Rochester, NY 14445',3958,222,NULL,32,5420,0);
INSERT INTO "django_geo_db_location" VALUES(9672,NULL,'East Williamson, NY',3959,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9673,NULL,'East Williamson, NY 14449',3959,222,NULL,32,5421,0);
INSERT INTO "django_geo_db_location" VALUES(9674,NULL,'Fairport, NY',3960,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9675,NULL,'Fairport, NY 14450',3960,222,NULL,32,5422,0);
INSERT INTO "django_geo_db_location" VALUES(9676,NULL,'Fancher, NY',3961,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9677,NULL,'Fancher, NY 14452',3961,222,NULL,32,5423,0);
INSERT INTO "django_geo_db_location" VALUES(9678,NULL,'Fishers, NY',3962,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9679,NULL,'Fishers, NY 14453',3962,222,NULL,32,5424,0);
INSERT INTO "django_geo_db_location" VALUES(9680,NULL,'Geneseo, NY 14454',3941,222,NULL,32,5425,0);
INSERT INTO "django_geo_db_location" VALUES(9681,NULL,'Geneva, NY',3963,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9682,NULL,'Geneva, NY 14456',3963,222,NULL,32,5426,0);
INSERT INTO "django_geo_db_location" VALUES(9683,NULL,'Lima, NY',3964,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9684,NULL,'Lima, NY 14458',3964,222,NULL,32,5427,0);
INSERT INTO "django_geo_db_location" VALUES(9685,NULL,'Gorham, NY',3965,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9686,NULL,'Gorham, NY 14461',3965,222,NULL,32,5428,0);
INSERT INTO "django_geo_db_location" VALUES(9687,NULL,'Groveland, NY',3966,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9688,NULL,'Groveland, NY 14462',3966,222,NULL,32,5429,0);
INSERT INTO "django_geo_db_location" VALUES(9689,NULL,'Hall, NY',3967,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9690,NULL,'Hall, NY 14463',3967,222,NULL,32,5430,0);
INSERT INTO "django_geo_db_location" VALUES(9691,NULL,'Hamlin, NY',3968,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9692,NULL,'Hamlin, NY 14464',3968,222,NULL,32,5431,0);
INSERT INTO "django_geo_db_location" VALUES(9693,NULL,'Hemlock, NY',3969,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9694,NULL,'Hemlock, NY 14466',3969,222,NULL,32,5432,0);
INSERT INTO "django_geo_db_location" VALUES(9695,NULL,'Henrietta, NY',3970,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9696,NULL,'Henrietta, NY 14467',3970,222,NULL,32,5433,0);
INSERT INTO "django_geo_db_location" VALUES(9697,NULL,'Hilton, NY',3971,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9698,NULL,'Hilton, NY 14468',3971,222,NULL,32,5434,0);
INSERT INTO "django_geo_db_location" VALUES(9699,NULL,'Bloomfield, NY',3972,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9700,NULL,'Bloomfield, NY 14469',3972,222,NULL,32,5435,0);
INSERT INTO "django_geo_db_location" VALUES(9701,NULL,'Holley, NY',3973,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9702,NULL,'Holley, NY 14470',3973,222,NULL,32,5436,0);
INSERT INTO "django_geo_db_location" VALUES(9703,NULL,'Honeoye, NY',3974,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9704,NULL,'Honeoye, NY 14471',3974,222,NULL,32,5437,0);
INSERT INTO "django_geo_db_location" VALUES(9705,NULL,'Honeoye Falls, NY',3975,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9706,NULL,'Honeoye Falls, NY 14472',3975,222,NULL,32,5438,0);
INSERT INTO "django_geo_db_location" VALUES(9707,NULL,'Ionia, NY',3976,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9708,NULL,'Ionia, NY 14475',3976,222,NULL,32,5439,0);
INSERT INTO "django_geo_db_location" VALUES(9709,NULL,'Kendall, NY',3977,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9710,NULL,'Kendall, NY 14476',3977,222,NULL,32,5440,0);
INSERT INTO "django_geo_db_location" VALUES(9711,NULL,'Kent, NY',3978,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9712,NULL,'Kent, NY 14477',3978,222,NULL,32,5441,0);
INSERT INTO "django_geo_db_location" VALUES(9713,NULL,'Keuka Park, NY',3979,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9714,NULL,'Keuka Park, NY 14478',3979,222,NULL,32,5442,0);
INSERT INTO "django_geo_db_location" VALUES(9715,NULL,'Knowlesville, NY',3980,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9716,NULL,'Knowlesville, NY 14479',3980,222,NULL,32,5443,0);
INSERT INTO "django_geo_db_location" VALUES(9717,NULL,'Lakeville, NY',3981,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9718,NULL,'Lakeville, NY 14480',3981,222,NULL,32,5444,0);
INSERT INTO "django_geo_db_location" VALUES(9719,NULL,'Leicester, NY',3982,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9720,NULL,'Leicester, NY 14481',3982,222,NULL,32,5445,0);
INSERT INTO "django_geo_db_location" VALUES(9721,NULL,'Le Roy, NY',3983,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9722,NULL,'Le Roy, NY 14482',3983,222,NULL,32,5446,0);
INSERT INTO "django_geo_db_location" VALUES(9723,NULL,'Portage, NY',3984,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9724,NULL,'Portage, NY 14484',3984,222,NULL,32,5447,0);
INSERT INTO "django_geo_db_location" VALUES(9725,NULL,'Lima, NY 14485',3964,222,NULL,32,5448,0);
INSERT INTO "django_geo_db_location" VALUES(9726,NULL,'Linwood, NY',3985,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9727,NULL,'Linwood, NY 14486',3985,222,NULL,32,5449,0);
INSERT INTO "django_geo_db_location" VALUES(9728,NULL,'Livonia, NY',3986,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9729,NULL,'Livonia, NY 14487',3986,222,NULL,32,5450,0);
INSERT INTO "django_geo_db_location" VALUES(9730,NULL,'Livonia Center, NY',3987,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9731,NULL,'Livonia Center, NY 14488',3987,222,NULL,32,5451,0);
INSERT INTO "django_geo_db_location" VALUES(9732,NULL,'Lyons, NY',3988,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9733,NULL,'Lyons, NY 14489',3988,222,NULL,32,5452,0);
INSERT INTO "django_geo_db_location" VALUES(9734,NULL,'Macedon, NY',3989,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9735,NULL,'Macedon, NY 14502',3989,222,NULL,32,5453,0);
INSERT INTO "django_geo_db_location" VALUES(9736,NULL,'Manchester, NY',3990,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9737,NULL,'Manchester, NY 14504',3990,222,NULL,32,5454,0);
INSERT INTO "django_geo_db_location" VALUES(9738,NULL,'Marion, NY',3991,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9739,NULL,'Marion, NY 14505',3991,222,NULL,32,5455,0);
INSERT INTO "django_geo_db_location" VALUES(9740,NULL,'Mendon, NY',3992,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9741,NULL,'Mendon, NY 14506',3992,222,NULL,32,5456,0);
INSERT INTO "django_geo_db_location" VALUES(9742,NULL,'Middlesex, NY',3993,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9743,NULL,'Middlesex, NY 14507',3993,222,NULL,32,5457,0);
INSERT INTO "django_geo_db_location" VALUES(9744,NULL,'Morton, NY',3994,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9745,NULL,'Morton, NY 14508',3994,222,NULL,32,5458,0);
INSERT INTO "django_geo_db_location" VALUES(9746,NULL,'Mount Morris, NY',3995,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9747,NULL,'Mount Morris, NY 14510',3995,222,NULL,32,5459,0);
INSERT INTO "django_geo_db_location" VALUES(9748,NULL,'Mumford, NY',3996,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9749,NULL,'Mumford, NY 14511',3996,222,NULL,32,5460,0);
INSERT INTO "django_geo_db_location" VALUES(9750,NULL,'Naples, NY',3997,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9751,NULL,'Naples, NY 14512',3997,222,NULL,32,5461,0);
INSERT INTO "django_geo_db_location" VALUES(9752,NULL,'Newark, NY',3998,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9753,NULL,'Newark, NY 14513',3998,222,NULL,32,5462,0);
INSERT INTO "django_geo_db_location" VALUES(9754,NULL,'North Chili, NY',3999,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9755,NULL,'North Chili, NY 14514',3999,222,NULL,32,5463,0);
INSERT INTO "django_geo_db_location" VALUES(9756,NULL,'North Greece, NY',4000,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9757,NULL,'North Greece, NY 14515',4000,222,NULL,32,5464,0);
INSERT INTO "django_geo_db_location" VALUES(9758,NULL,'North Rose, NY',4001,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9759,NULL,'North Rose, NY 14516',4001,222,NULL,32,5465,0);
INSERT INTO "django_geo_db_location" VALUES(9760,NULL,'Nunda, NY',4002,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9761,NULL,'Nunda, NY 14517',4002,222,NULL,32,5466,0);
INSERT INTO "django_geo_db_location" VALUES(9762,NULL,'Oaks Corners, NY',4003,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9763,NULL,'Oaks Corners, NY 14518',4003,222,NULL,32,5467,0);
INSERT INTO "django_geo_db_location" VALUES(9764,NULL,'Ontario, NY',4004,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9765,NULL,'Ontario, NY 14519',4004,222,NULL,32,5468,0);
INSERT INTO "django_geo_db_location" VALUES(9766,NULL,'Ontario Center, NY',4005,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9767,NULL,'Ontario Center, NY 14520',4005,222,NULL,32,5469,0);
INSERT INTO "django_geo_db_location" VALUES(9768,NULL,'Ovid, NY',4006,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9769,NULL,'Ovid, NY 14521',4006,222,NULL,32,5470,0);
INSERT INTO "django_geo_db_location" VALUES(9770,NULL,'Palmyra, NY',4007,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9771,NULL,'Palmyra, NY 14522',4007,222,NULL,32,5471,0);
INSERT INTO "django_geo_db_location" VALUES(9772,NULL,'Pavilion, NY',4008,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9773,NULL,'Pavilion, NY 14525',4008,222,NULL,32,5472,0);
INSERT INTO "django_geo_db_location" VALUES(9774,NULL,'Penfield, NY',4009,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9775,NULL,'Penfield, NY 14526',4009,222,NULL,32,5473,0);
INSERT INTO "django_geo_db_location" VALUES(9776,NULL,'Penn Yan, NY',4010,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9777,NULL,'Penn Yan, NY 14527',4010,222,NULL,32,5474,0);
INSERT INTO "django_geo_db_location" VALUES(9778,NULL,'Perkinsville, NY',4011,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9779,NULL,'Perkinsville, NY 14529',4011,222,NULL,32,5475,0);
INSERT INTO "django_geo_db_location" VALUES(9780,NULL,'Perry, NY',4012,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9781,NULL,'Perry, NY 14530',4012,222,NULL,32,5476,0);
INSERT INTO "django_geo_db_location" VALUES(9782,NULL,'Phelps, NY',4013,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9783,NULL,'Phelps, NY 14532',4013,222,NULL,32,5477,0);
INSERT INTO "django_geo_db_location" VALUES(9784,NULL,'Piffard, NY',4014,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9785,NULL,'Piffard, NY 14533',4014,222,NULL,32,5478,0);
INSERT INTO "django_geo_db_location" VALUES(9786,NULL,'Pittsford, NY',4015,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9787,NULL,'Pittsford, NY 14534',4015,222,NULL,32,5479,0);
INSERT INTO "django_geo_db_location" VALUES(9788,NULL,'Portageville, NY',4016,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9789,NULL,'Portageville, NY 14536',4016,222,NULL,32,5480,0);
INSERT INTO "django_geo_db_location" VALUES(9790,NULL,'Port Gibson, NY',4017,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9791,NULL,'Port Gibson, NY 14537',4017,222,NULL,32,5481,0);
INSERT INTO "django_geo_db_location" VALUES(9792,NULL,'Pultneyville, NY',4018,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9793,NULL,'Pultneyville, NY 14538',4018,222,NULL,32,5482,0);
INSERT INTO "django_geo_db_location" VALUES(9794,NULL,'Retsof, NY',4019,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9795,NULL,'Retsof, NY 14539',4019,222,NULL,32,5483,0);
INSERT INTO "django_geo_db_location" VALUES(9796,NULL,'Romulus, NY',4020,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9797,NULL,'Romulus, NY 14541',4020,222,NULL,32,5484,0);
INSERT INTO "django_geo_db_location" VALUES(9798,NULL,'Rose, NY',4021,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9799,NULL,'Rose, NY 14542',4021,222,NULL,32,5485,0);
INSERT INTO "django_geo_db_location" VALUES(9800,NULL,'Rush, NY',4022,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9801,NULL,'Rush, NY 14543',4022,222,NULL,32,5486,0);
INSERT INTO "django_geo_db_location" VALUES(9802,NULL,'Rushville, NY',4023,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9803,NULL,'Rushville, NY 14544',4023,222,NULL,32,5487,0);
INSERT INTO "django_geo_db_location" VALUES(9804,NULL,'Scottsburg, NY',4024,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9805,NULL,'Scottsburg, NY 14545',4024,222,NULL,32,5488,0);
INSERT INTO "django_geo_db_location" VALUES(9806,NULL,'Scottsville, NY',4025,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9807,NULL,'Scottsville, NY 14546',4025,222,NULL,32,5489,0);
INSERT INTO "django_geo_db_location" VALUES(9808,NULL,'Seneca Castle, NY',4026,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9809,NULL,'Seneca Castle, NY 14547',4026,222,NULL,32,5490,0);
INSERT INTO "django_geo_db_location" VALUES(9810,NULL,'Shortsville, NY',4027,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9811,NULL,'Shortsville, NY 14548',4027,222,NULL,32,5491,0);
INSERT INTO "django_geo_db_location" VALUES(9812,NULL,'Silver Lake, NY',4028,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9813,NULL,'Silver Lake, NY 14549',4028,222,NULL,32,5492,0);
INSERT INTO "django_geo_db_location" VALUES(9814,NULL,'Silver Springs, NY',4029,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9815,NULL,'Silver Springs, NY 14550',4029,222,NULL,32,5493,0);
INSERT INTO "django_geo_db_location" VALUES(9816,NULL,'Sodus, NY',4030,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9817,NULL,'Sodus, NY 14551',4030,222,NULL,32,5494,0);
INSERT INTO "django_geo_db_location" VALUES(9818,NULL,'Sodus Point, NY',4031,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9819,NULL,'Sodus Point, NY 14555',4031,222,NULL,32,5495,0);
INSERT INTO "django_geo_db_location" VALUES(9820,NULL,'Sonyea, NY',4032,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9821,NULL,'Sonyea, NY 14556',4032,222,NULL,32,5496,0);
INSERT INTO "django_geo_db_location" VALUES(9822,NULL,'South Byron, NY',4033,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9823,NULL,'South Byron, NY 14557',4033,222,NULL,32,5497,0);
INSERT INTO "django_geo_db_location" VALUES(9824,NULL,'South Lima, NY',4034,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9825,NULL,'South Lima, NY 14558',4034,222,NULL,32,5498,0);
INSERT INTO "django_geo_db_location" VALUES(9826,NULL,'Spencerport, NY',4035,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9827,NULL,'Spencerport, NY 14559',4035,222,NULL,32,5499,0);
INSERT INTO "django_geo_db_location" VALUES(9828,NULL,'Springwater, NY',4036,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9829,NULL,'Springwater, NY 14560',4036,222,NULL,32,5500,0);
INSERT INTO "django_geo_db_location" VALUES(9830,NULL,'Stanley, NY',4037,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9831,NULL,'Stanley, NY 14561',4037,222,NULL,32,5501,0);
INSERT INTO "django_geo_db_location" VALUES(9832,NULL,'Union Hill, NY',4038,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9833,NULL,'Union Hill, NY 14563',4038,222,NULL,32,5502,0);
INSERT INTO "django_geo_db_location" VALUES(9834,NULL,'Victor, NY',4039,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9835,NULL,'Victor, NY 14564',4039,222,NULL,32,5503,0);
INSERT INTO "django_geo_db_location" VALUES(9836,NULL,'Walworth, NY',4040,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9837,NULL,'Walworth, NY 14568',4040,222,NULL,32,5504,0);
INSERT INTO "django_geo_db_location" VALUES(9838,NULL,'Warsaw, NY',4041,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9839,NULL,'Warsaw, NY 14569',4041,222,NULL,32,5505,0);
INSERT INTO "django_geo_db_location" VALUES(9840,NULL,'Waterport, NY',4042,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9841,NULL,'Waterport, NY 14571',4042,222,NULL,32,5506,0);
INSERT INTO "django_geo_db_location" VALUES(9842,NULL,'Wayland, NY',4043,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9843,NULL,'Wayland, NY 14572',4043,222,NULL,32,5507,0);
INSERT INTO "django_geo_db_location" VALUES(9844,NULL,'Webster, NY',4044,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9845,NULL,'Webster, NY 14580',4044,222,NULL,32,5508,0);
INSERT INTO "django_geo_db_location" VALUES(9846,NULL,'West Bloomfield, NY',4045,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9847,NULL,'West Bloomfield, NY 14585',4045,222,NULL,32,5509,0);
INSERT INTO "django_geo_db_location" VALUES(9848,NULL,'West Henrietta, NY',4046,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9849,NULL,'West Henrietta, NY 14586',4046,222,NULL,32,5510,0);
INSERT INTO "django_geo_db_location" VALUES(9850,NULL,'Willard, NY',4047,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9851,NULL,'Willard, NY 14588',4047,222,NULL,32,5511,0);
INSERT INTO "django_geo_db_location" VALUES(9852,NULL,'Williamson, NY',4048,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9853,NULL,'Williamson, NY 14589',4048,222,NULL,32,5512,0);
INSERT INTO "django_geo_db_location" VALUES(9854,NULL,'Wolcott, NY',4049,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9855,NULL,'Wolcott, NY 14590',4049,222,NULL,32,5513,0);
INSERT INTO "django_geo_db_location" VALUES(9856,NULL,'Wyoming, NY',4050,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9857,NULL,'Wyoming, NY 14591',4050,222,NULL,32,5514,0);
INSERT INTO "django_geo_db_location" VALUES(9858,NULL,'York, NY',4051,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9859,NULL,'York, NY 14592',4051,222,NULL,32,5515,0);
INSERT INTO "django_geo_db_location" VALUES(9860,NULL,'Rochester, NY 14601',3874,222,NULL,32,5516,0);
INSERT INTO "django_geo_db_location" VALUES(9861,NULL,'Rochester, NY 14602',3874,222,NULL,32,5517,0);
INSERT INTO "django_geo_db_location" VALUES(9862,NULL,'Rochester, NY 14603',3874,222,NULL,32,5518,0);
INSERT INTO "django_geo_db_location" VALUES(9863,NULL,'Rochester, NY 14604',3874,222,NULL,32,5519,0);
INSERT INTO "django_geo_db_location" VALUES(9864,NULL,'Rochester, NY 14605',3874,222,NULL,32,5520,0);
INSERT INTO "django_geo_db_location" VALUES(9865,NULL,'Rochester, NY 14606',3874,222,NULL,32,5521,0);
INSERT INTO "django_geo_db_location" VALUES(9866,NULL,'Rochester, NY 14607',3874,222,NULL,32,5522,0);
INSERT INTO "django_geo_db_location" VALUES(9867,NULL,'Rochester, NY 14608',3874,222,NULL,32,5523,0);
INSERT INTO "django_geo_db_location" VALUES(9868,NULL,'Rochester, NY 14609',3874,222,NULL,32,5524,0);
INSERT INTO "django_geo_db_location" VALUES(9869,NULL,'Rochester, NY 14610',3874,222,NULL,32,5525,0);
INSERT INTO "django_geo_db_location" VALUES(9870,NULL,'Rochester, NY 14611',3874,222,NULL,32,5526,0);
INSERT INTO "django_geo_db_location" VALUES(9871,NULL,'Rochester, NY 14612',3874,222,NULL,32,5527,0);
INSERT INTO "django_geo_db_location" VALUES(9872,NULL,'Rochester, NY 14613',3874,222,NULL,32,5528,0);
INSERT INTO "django_geo_db_location" VALUES(9873,NULL,'Rochester, NY 14614',3874,222,NULL,32,5529,0);
INSERT INTO "django_geo_db_location" VALUES(9874,NULL,'Rochester, NY 14615',3874,222,NULL,32,5530,0);
INSERT INTO "django_geo_db_location" VALUES(9875,NULL,'Rochester, NY 14616',3874,222,NULL,32,5531,0);
INSERT INTO "django_geo_db_location" VALUES(9876,NULL,'Rochester, NY 14617',3874,222,NULL,32,5532,0);
INSERT INTO "django_geo_db_location" VALUES(9877,NULL,'Rochester, NY 14618',3874,222,NULL,32,5533,0);
INSERT INTO "django_geo_db_location" VALUES(9878,NULL,'Rochester, NY 14619',3874,222,NULL,32,5534,0);
INSERT INTO "django_geo_db_location" VALUES(9879,NULL,'Rochester, NY 14620',3874,222,NULL,32,5535,0);
INSERT INTO "django_geo_db_location" VALUES(9880,NULL,'Rochester, NY 14621',3874,222,NULL,32,5536,0);
INSERT INTO "django_geo_db_location" VALUES(9881,NULL,'Rochester, NY 14622',3874,222,NULL,32,5537,0);
INSERT INTO "django_geo_db_location" VALUES(9882,NULL,'Rochester, NY 14623',3874,222,NULL,32,5538,0);
INSERT INTO "django_geo_db_location" VALUES(9883,NULL,'Rochester, NY 14624',3874,222,NULL,32,5539,0);
INSERT INTO "django_geo_db_location" VALUES(9884,NULL,'Rochester, NY 14625',3874,222,NULL,32,5540,0);
INSERT INTO "django_geo_db_location" VALUES(9885,NULL,'Rochester, NY 14626',3874,222,NULL,32,5541,0);
INSERT INTO "django_geo_db_location" VALUES(9886,NULL,'Rochester, NY 14627',3874,222,NULL,32,5542,0);
INSERT INTO "django_geo_db_location" VALUES(9887,NULL,'Rochester, NY 14638',3874,222,NULL,32,5543,0);
INSERT INTO "django_geo_db_location" VALUES(9888,NULL,'Rochester, NY 14639',3874,222,NULL,32,5544,0);
INSERT INTO "django_geo_db_location" VALUES(9889,NULL,'Rochester, NY 14642',3874,222,NULL,32,5545,0);
INSERT INTO "django_geo_db_location" VALUES(9890,NULL,'Rochester, NY 14643',3874,222,NULL,32,5546,0);
INSERT INTO "django_geo_db_location" VALUES(9891,NULL,'Rochester, NY 14644',3874,222,NULL,32,5547,0);
INSERT INTO "django_geo_db_location" VALUES(9892,NULL,'Rochester, NY 14645',3874,222,NULL,32,5548,0);
INSERT INTO "django_geo_db_location" VALUES(9893,NULL,'Rochester, NY 14646',3874,222,NULL,32,5549,0);
INSERT INTO "django_geo_db_location" VALUES(9894,NULL,'Rochester, NY 14647',3874,222,NULL,32,5550,0);
INSERT INTO "django_geo_db_location" VALUES(9895,NULL,'Rochester, NY 14649',3874,222,NULL,32,5551,0);
INSERT INTO "django_geo_db_location" VALUES(9896,NULL,'Rochester, NY 14650',3874,222,NULL,32,5552,0);
INSERT INTO "django_geo_db_location" VALUES(9897,NULL,'Rochester, NY 14651',3874,222,NULL,32,5553,0);
INSERT INTO "django_geo_db_location" VALUES(9898,NULL,'Rochester, NY 14652',3874,222,NULL,32,5554,0);
INSERT INTO "django_geo_db_location" VALUES(9899,NULL,'Rochester, NY 14653',3874,222,NULL,32,5555,0);
INSERT INTO "django_geo_db_location" VALUES(9900,NULL,'Rochester, NY 14660',3874,222,NULL,32,5556,0);
INSERT INTO "django_geo_db_location" VALUES(9901,NULL,'Rochester, NY 14664',3874,222,NULL,32,5557,0);
INSERT INTO "django_geo_db_location" VALUES(9902,NULL,'Rochester, NY 14673',3874,222,NULL,32,5558,0);
INSERT INTO "django_geo_db_location" VALUES(9903,NULL,'Rochester, NY 14683',3874,222,NULL,32,5559,0);
INSERT INTO "django_geo_db_location" VALUES(9904,NULL,'Rochester, NY 14692',3874,222,NULL,32,5560,0);
INSERT INTO "django_geo_db_location" VALUES(9905,NULL,'Rochester, NY 14694',3874,222,NULL,32,5561,0);
INSERT INTO "django_geo_db_location" VALUES(9906,NULL,'Jamestown, NY',4052,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9907,NULL,'Jamestown, NY 14701',4052,222,NULL,32,5562,0);
INSERT INTO "django_geo_db_location" VALUES(9908,NULL,'Jamestown, NY 14702',4052,222,NULL,32,5563,0);
INSERT INTO "django_geo_db_location" VALUES(9909,NULL,'Jamestown, NY 14703',4052,222,NULL,32,5564,0);
INSERT INTO "django_geo_db_location" VALUES(9910,NULL,'Jamestown, NY 14704',4052,222,NULL,32,5565,0);
INSERT INTO "django_geo_db_location" VALUES(9911,NULL,'Allegany, NY',4053,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9912,NULL,'Allegany, NY 14706',4053,222,NULL,32,5566,0);
INSERT INTO "django_geo_db_location" VALUES(9913,NULL,'Allentown, NY',4054,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9914,NULL,'Allentown, NY 14707',4054,222,NULL,32,5567,0);
INSERT INTO "django_geo_db_location" VALUES(9915,NULL,'Alma, NY',4055,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9916,NULL,'Alma, NY 14708',4055,222,NULL,32,5568,0);
INSERT INTO "django_geo_db_location" VALUES(9917,NULL,'Angelica, NY',4056,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9918,NULL,'Angelica, NY 14709',4056,222,NULL,32,5569,0);
INSERT INTO "django_geo_db_location" VALUES(9919,NULL,'Ashville, NY',4057,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9920,NULL,'Ashville, NY 14710',4057,222,NULL,32,5570,0);
INSERT INTO "django_geo_db_location" VALUES(9921,NULL,'Belfast, NY',4058,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9922,NULL,'Belfast, NY 14711',4058,222,NULL,32,5571,0);
INSERT INTO "django_geo_db_location" VALUES(9923,NULL,'Bemus Point, NY',4059,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9924,NULL,'Bemus Point, NY 14712',4059,222,NULL,32,5572,0);
INSERT INTO "django_geo_db_location" VALUES(9925,NULL,'Black Creek, NY',4060,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9926,NULL,'Black Creek, NY 14714',4060,222,NULL,32,5573,0);
INSERT INTO "django_geo_db_location" VALUES(9927,NULL,'Bolivar, NY',4061,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9928,NULL,'Bolivar, NY 14715',4061,222,NULL,32,5574,0);
INSERT INTO "django_geo_db_location" VALUES(9929,NULL,'Brocton, NY',4062,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9930,NULL,'Brocton, NY 14716',4062,222,NULL,32,5575,0);
INSERT INTO "django_geo_db_location" VALUES(9931,NULL,'Caneadea, NY',4063,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9932,NULL,'Caneadea, NY 14717',4063,222,NULL,32,5576,0);
INSERT INTO "django_geo_db_location" VALUES(9933,NULL,'Cassadaga, NY',4064,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9934,NULL,'Cassadaga, NY 14718',4064,222,NULL,32,5577,0);
INSERT INTO "django_geo_db_location" VALUES(9935,NULL,'Cattaraugus, NY',4065,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9936,NULL,'Cattaraugus, NY 14719',4065,222,NULL,32,5578,0);
INSERT INTO "django_geo_db_location" VALUES(9937,NULL,'Celoron, NY',4066,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9938,NULL,'Celoron, NY 14720',4066,222,NULL,32,5579,0);
INSERT INTO "django_geo_db_location" VALUES(9939,NULL,'Ceres, NY',4067,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9940,NULL,'Ceres, NY 14721',4067,222,NULL,32,5580,0);
INSERT INTO "django_geo_db_location" VALUES(9941,NULL,'Chautauqua, NY',4068,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9942,NULL,'Chautauqua, NY 14722',4068,222,NULL,32,5581,0);
INSERT INTO "django_geo_db_location" VALUES(9943,NULL,'Cherry Creek, NY',4069,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9944,NULL,'Cherry Creek, NY 14723',4069,222,NULL,32,5582,0);
INSERT INTO "django_geo_db_location" VALUES(9945,NULL,'Clymer, NY',4070,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9946,NULL,'Clymer, NY 14724',4070,222,NULL,32,5583,0);
INSERT INTO "django_geo_db_location" VALUES(9947,NULL,'Conewango Valley, NY',4071,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9948,NULL,'Conewango Valley, NY 14726',4071,222,NULL,32,5584,0);
INSERT INTO "django_geo_db_location" VALUES(9949,NULL,'Cuba, NY',4072,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9950,NULL,'Cuba, NY 14727',4072,222,NULL,32,5585,0);
INSERT INTO "django_geo_db_location" VALUES(9951,NULL,'Dewittville, NY',4073,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9952,NULL,'Dewittville, NY 14728',4073,222,NULL,32,5586,0);
INSERT INTO "django_geo_db_location" VALUES(9953,NULL,'East Otto, NY',4074,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9954,NULL,'East Otto, NY 14729',4074,222,NULL,32,5587,0);
INSERT INTO "django_geo_db_location" VALUES(9955,NULL,'East Randolph, NY',4075,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9956,NULL,'East Randolph, NY 14730',4075,222,NULL,32,5588,0);
INSERT INTO "django_geo_db_location" VALUES(9957,NULL,'Ellicottville, NY',4076,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9958,NULL,'Ellicottville, NY 14731',4076,222,NULL,32,5589,0);
INSERT INTO "django_geo_db_location" VALUES(9959,NULL,'Ellington, NY',4077,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9960,NULL,'Ellington, NY 14732',4077,222,NULL,32,5590,0);
INSERT INTO "django_geo_db_location" VALUES(9961,NULL,'Falconer, NY',4078,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9962,NULL,'Falconer, NY 14733',4078,222,NULL,32,5591,0);
INSERT INTO "django_geo_db_location" VALUES(9963,NULL,'Fillmore, NY',4079,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9964,NULL,'Fillmore, NY 14735',4079,222,NULL,32,5592,0);
INSERT INTO "django_geo_db_location" VALUES(9965,NULL,'Findley Lake, NY',4080,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9966,NULL,'Findley Lake, NY 14736',4080,222,NULL,32,5593,0);
INSERT INTO "django_geo_db_location" VALUES(9967,NULL,'Franklinville, NY',4081,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9968,NULL,'Franklinville, NY 14737',4081,222,NULL,32,5594,0);
INSERT INTO "django_geo_db_location" VALUES(9969,NULL,'Frewsburg, NY',4082,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9970,NULL,'Frewsburg, NY 14738',4082,222,NULL,32,5595,0);
INSERT INTO "django_geo_db_location" VALUES(9971,NULL,'Friendship, NY',4083,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9972,NULL,'Friendship, NY 14739',4083,222,NULL,32,5596,0);
INSERT INTO "django_geo_db_location" VALUES(9973,NULL,'Gerry, NY',4084,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9974,NULL,'Gerry, NY 14740',4084,222,NULL,32,5597,0);
INSERT INTO "django_geo_db_location" VALUES(9975,NULL,'Great Valley, NY',4085,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9976,NULL,'Great Valley, NY 14741',4085,222,NULL,32,5598,0);
INSERT INTO "django_geo_db_location" VALUES(9977,NULL,'Greenhurst, NY',4086,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9978,NULL,'Greenhurst, NY 14742',4086,222,NULL,32,5599,0);
INSERT INTO "django_geo_db_location" VALUES(9979,NULL,'Hinsdale, NY',4087,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9980,NULL,'Hinsdale, NY 14743',4087,222,NULL,32,5600,0);
INSERT INTO "django_geo_db_location" VALUES(9981,NULL,'Houghton, NY',4088,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9982,NULL,'Houghton, NY 14744',4088,222,NULL,32,5601,0);
INSERT INTO "django_geo_db_location" VALUES(9983,NULL,'Hume, NY',4089,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9984,NULL,'Hume, NY 14745',4089,222,NULL,32,5602,0);
INSERT INTO "django_geo_db_location" VALUES(9985,NULL,'Kennedy, NY',4090,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9986,NULL,'Kennedy, NY 14747',4090,222,NULL,32,5603,0);
INSERT INTO "django_geo_db_location" VALUES(9987,NULL,'Kill Buck, NY',4091,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9988,NULL,'Kill Buck, NY 14748',4091,222,NULL,32,5604,0);
INSERT INTO "django_geo_db_location" VALUES(9989,NULL,'Lakewood, NY',4092,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9990,NULL,'Lakewood, NY 14750',4092,222,NULL,32,5605,0);
INSERT INTO "django_geo_db_location" VALUES(9991,NULL,'Leon, NY',4093,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9992,NULL,'Leon, NY 14751',4093,222,NULL,32,5606,0);
INSERT INTO "django_geo_db_location" VALUES(9993,NULL,'Lily Dale, NY',4094,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9994,NULL,'Lily Dale, NY 14752',4094,222,NULL,32,5607,0);
INSERT INTO "django_geo_db_location" VALUES(9995,NULL,'Limestone, NY',4095,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9996,NULL,'Limestone, NY 14753',4095,222,NULL,32,5608,0);
INSERT INTO "django_geo_db_location" VALUES(9997,NULL,'Little Genesee, NY',4096,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(9998,NULL,'Little Genesee, NY 14754',4096,222,NULL,32,5609,0);
INSERT INTO "django_geo_db_location" VALUES(9999,NULL,'Little Valley, NY',4097,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10000,NULL,'Little Valley, NY 14755',4097,222,NULL,32,5610,0);
INSERT INTO "django_geo_db_location" VALUES(10001,NULL,'Maple Springs, NY',4098,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10002,NULL,'Maple Springs, NY 14756',4098,222,NULL,32,5611,0);
INSERT INTO "django_geo_db_location" VALUES(10003,NULL,'Mayville, NY',4099,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10004,NULL,'Mayville, NY 14757',4099,222,NULL,32,5612,0);
INSERT INTO "django_geo_db_location" VALUES(10005,NULL,'Niobe, NY',4100,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10006,NULL,'Niobe, NY 14758',4100,222,NULL,32,5613,0);
INSERT INTO "django_geo_db_location" VALUES(10007,NULL,'Olean, NY',4101,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10008,NULL,'Olean, NY 14760',4101,222,NULL,32,5614,0);
INSERT INTO "django_geo_db_location" VALUES(10009,NULL,'Otto, NY',4102,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10010,NULL,'Otto, NY 14766',4102,222,NULL,32,5615,0);
INSERT INTO "django_geo_db_location" VALUES(10011,NULL,'Panama, NY',4103,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10012,NULL,'Panama, NY 14767',4103,222,NULL,32,5616,0);
INSERT INTO "django_geo_db_location" VALUES(10013,NULL,'Portland, NY',4104,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10014,NULL,'Portland, NY 14769',4104,222,NULL,32,5617,0);
INSERT INTO "django_geo_db_location" VALUES(10015,NULL,'Portville, NY',4105,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10016,NULL,'Portville, NY 14770',4105,222,NULL,32,5618,0);
INSERT INTO "django_geo_db_location" VALUES(10017,NULL,'Canadice, NY',4106,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10018,NULL,'Canadice, NY 14771',4106,222,NULL,32,5619,0);
INSERT INTO "django_geo_db_location" VALUES(10019,NULL,'Randolph, NY',4107,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10020,NULL,'Randolph, NY 14772',4107,222,NULL,32,5620,0);
INSERT INTO "django_geo_db_location" VALUES(10021,NULL,'Richburg, NY',4108,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10022,NULL,'Richburg, NY 14774',4108,222,NULL,32,5621,0);
INSERT INTO "django_geo_db_location" VALUES(10023,NULL,'Ripley, NY',4109,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10024,NULL,'Ripley, NY 14775',4109,222,NULL,32,5622,0);
INSERT INTO "django_geo_db_location" VALUES(10025,NULL,'Rossburg, NY',4110,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10026,NULL,'Rossburg, NY 14776',4110,222,NULL,32,5623,0);
INSERT INTO "django_geo_db_location" VALUES(10027,NULL,'Rushford, NY',4111,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10028,NULL,'Rushford, NY 14777',4111,222,NULL,32,5624,0);
INSERT INTO "django_geo_db_location" VALUES(10029,NULL,'Saint Bonaventure, NY',4112,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10030,NULL,'Saint Bonaventure, NY 14778',4112,222,NULL,32,5625,0);
INSERT INTO "django_geo_db_location" VALUES(10031,NULL,'Salamanca, NY',4113,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10032,NULL,'Salamanca, NY 14779',4113,222,NULL,32,5626,0);
INSERT INTO "django_geo_db_location" VALUES(10033,NULL,'Sherman, NY',4114,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10034,NULL,'Sherman, NY 14781',4114,222,NULL,32,5627,0);
INSERT INTO "django_geo_db_location" VALUES(10035,NULL,'Sinclairville, NY',4115,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10036,NULL,'Sinclairville, NY 14782',4115,222,NULL,32,5628,0);
INSERT INTO "django_geo_db_location" VALUES(10037,NULL,'Steamburg, NY',4116,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10038,NULL,'Steamburg, NY 14783',4116,222,NULL,32,5629,0);
INSERT INTO "django_geo_db_location" VALUES(10039,NULL,'Stockton, NY',4117,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10040,NULL,'Stockton, NY 14784',4117,222,NULL,32,5630,0);
INSERT INTO "django_geo_db_location" VALUES(10041,NULL,'Stow, NY',4118,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10042,NULL,'Stow, NY 14785',4118,222,NULL,32,5631,0);
INSERT INTO "django_geo_db_location" VALUES(10043,NULL,'West Clarksville, NY',4119,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10044,NULL,'West Clarksville, NY 14786',4119,222,NULL,32,5632,0);
INSERT INTO "django_geo_db_location" VALUES(10045,NULL,'Westfield, NY',4120,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10046,NULL,'Westfield, NY 14787',4120,222,NULL,32,5633,0);
INSERT INTO "django_geo_db_location" VALUES(10047,NULL,'Westons Mills, NY',4121,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10048,NULL,'Westons Mills, NY 14788',4121,222,NULL,32,5634,0);
INSERT INTO "django_geo_db_location" VALUES(10049,NULL,'Addison, NY',4122,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10050,NULL,'Addison, NY 14801',4122,222,NULL,32,5635,0);
INSERT INTO "django_geo_db_location" VALUES(10051,NULL,'Alfred, NY',4123,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10052,NULL,'Alfred, NY 14802',4123,222,NULL,32,5636,0);
INSERT INTO "django_geo_db_location" VALUES(10053,NULL,'Alfred Station, NY',4124,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10054,NULL,'Alfred Station, NY 14803',4124,222,NULL,32,5637,0);
INSERT INTO "django_geo_db_location" VALUES(10055,NULL,'Almond, NY',4125,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10056,NULL,'Almond, NY 14804',4125,222,NULL,32,5638,0);
INSERT INTO "django_geo_db_location" VALUES(10057,NULL,'Alpine, NY',4126,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10058,NULL,'Alpine, NY 14805',4126,222,NULL,32,5639,0);
INSERT INTO "django_geo_db_location" VALUES(10059,NULL,'Andover, NY',4127,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10060,NULL,'Andover, NY 14806',4127,222,NULL,32,5640,0);
INSERT INTO "django_geo_db_location" VALUES(10061,NULL,'Arkport, NY',4128,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10062,NULL,'Arkport, NY 14807',4128,222,NULL,32,5641,0);
INSERT INTO "django_geo_db_location" VALUES(10063,NULL,'Atlanta, NY',4129,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10064,NULL,'Atlanta, NY 14808',4129,222,NULL,32,5642,0);
INSERT INTO "django_geo_db_location" VALUES(10065,NULL,'Avoca, NY',4130,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10066,NULL,'Avoca, NY 14809',4130,222,NULL,32,5643,0);
INSERT INTO "django_geo_db_location" VALUES(10067,NULL,'Bath, NY',4131,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10068,NULL,'Bath, NY 14810',4131,222,NULL,32,5644,0);
INSERT INTO "django_geo_db_location" VALUES(10069,NULL,'Beaver Dams, NY',4132,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10070,NULL,'Beaver Dams, NY 14812',4132,222,NULL,32,5645,0);
INSERT INTO "django_geo_db_location" VALUES(10071,NULL,'Belmont, NY',4133,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10072,NULL,'Belmont, NY 14813',4133,222,NULL,32,5646,0);
INSERT INTO "django_geo_db_location" VALUES(10073,NULL,'Big Flats, NY',4134,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10074,NULL,'Big Flats, NY 14814',4134,222,NULL,32,5647,0);
INSERT INTO "django_geo_db_location" VALUES(10075,NULL,'Bradford, NY',4135,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10076,NULL,'Bradford, NY 14815',4135,222,NULL,32,5648,0);
INSERT INTO "django_geo_db_location" VALUES(10077,NULL,'Breesport, NY',4136,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10078,NULL,'Breesport, NY 14816',4136,222,NULL,32,5649,0);
INSERT INTO "django_geo_db_location" VALUES(10079,NULL,'Brooktondale, NY',4137,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10080,NULL,'Brooktondale, NY 14817',4137,222,NULL,32,5650,0);
INSERT INTO "django_geo_db_location" VALUES(10081,NULL,'Burdett, NY',4138,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10082,NULL,'Burdett, NY 14818',4138,222,NULL,32,5651,0);
INSERT INTO "django_geo_db_location" VALUES(10083,NULL,'Cameron, NY',4139,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10084,NULL,'Cameron, NY 14819',4139,222,NULL,32,5652,0);
INSERT INTO "django_geo_db_location" VALUES(10085,NULL,'Cameron Mills, NY',4140,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10086,NULL,'Cameron Mills, NY 14820',4140,222,NULL,32,5653,0);
INSERT INTO "django_geo_db_location" VALUES(10087,NULL,'Campbell, NY',4141,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10088,NULL,'Campbell, NY 14821',4141,222,NULL,32,5654,0);
INSERT INTO "django_geo_db_location" VALUES(10089,NULL,'Canaseraga, NY',4142,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10090,NULL,'Canaseraga, NY 14822',4142,222,NULL,32,5655,0);
INSERT INTO "django_geo_db_location" VALUES(10091,NULL,'Canisteo, NY',4143,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10092,NULL,'Canisteo, NY 14823',4143,222,NULL,32,5656,0);
INSERT INTO "django_geo_db_location" VALUES(10093,NULL,'Cayuta, NY',4144,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10094,NULL,'Cayuta, NY 14824',4144,222,NULL,32,5657,0);
INSERT INTO "django_geo_db_location" VALUES(10095,NULL,'Chemung, NY',4145,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10096,NULL,'Chemung, NY 14825',4145,222,NULL,32,5658,0);
INSERT INTO "django_geo_db_location" VALUES(10097,NULL,'Cohocton, NY',4146,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10098,NULL,'Cohocton, NY 14826',4146,222,NULL,32,5659,0);
INSERT INTO "django_geo_db_location" VALUES(10099,NULL,'Coopers Plains, NY',4147,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10100,NULL,'Coopers Plains, NY 14827',4147,222,NULL,32,5660,0);
INSERT INTO "django_geo_db_location" VALUES(10101,NULL,'Corning, NY',4148,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10102,NULL,'Corning, NY 14830',4148,222,NULL,32,5661,0);
INSERT INTO "django_geo_db_location" VALUES(10103,NULL,'Corning, NY 14831',4148,222,NULL,32,5662,0);
INSERT INTO "django_geo_db_location" VALUES(10104,NULL,'Dalton, NY',4149,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10105,NULL,'Dalton, NY 14836',4149,222,NULL,32,5663,0);
INSERT INTO "django_geo_db_location" VALUES(10106,NULL,'Dundee, NY',4150,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10107,NULL,'Dundee, NY 14837',4150,222,NULL,32,5664,0);
INSERT INTO "django_geo_db_location" VALUES(10108,NULL,'Erin, NY',4151,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10109,NULL,'Erin, NY 14838',4151,222,NULL,32,5665,0);
INSERT INTO "django_geo_db_location" VALUES(10110,NULL,'Greenwood, NY',4152,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10111,NULL,'Greenwood, NY 14839',4152,222,NULL,32,5666,0);
INSERT INTO "django_geo_db_location" VALUES(10112,NULL,'Hammondsport, NY',4153,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10113,NULL,'Hammondsport, NY 14840',4153,222,NULL,32,5667,0);
INSERT INTO "django_geo_db_location" VALUES(10114,NULL,'Hector, NY',4154,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10115,NULL,'Hector, NY 14841',4154,222,NULL,32,5668,0);
INSERT INTO "django_geo_db_location" VALUES(10116,NULL,'Himrod, NY',4155,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10117,NULL,'Himrod, NY 14842',4155,222,NULL,32,5669,0);
INSERT INTO "django_geo_db_location" VALUES(10118,NULL,'Hornell, NY',4156,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10119,NULL,'Hornell, NY 14843',4156,222,NULL,32,5670,0);
INSERT INTO "django_geo_db_location" VALUES(10120,NULL,'Horseheads, NY',4157,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10121,NULL,'Horseheads, NY 14844',4157,222,NULL,32,5671,0);
INSERT INTO "django_geo_db_location" VALUES(10122,NULL,'Horseheads, NY 14845',4157,222,NULL,32,5672,0);
INSERT INTO "django_geo_db_location" VALUES(10123,NULL,'Hunt, NY',4158,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10124,NULL,'Hunt, NY 14846',4158,222,NULL,32,5673,0);
INSERT INTO "django_geo_db_location" VALUES(10125,NULL,'Interlaken, NY',4159,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10126,NULL,'Interlaken, NY 14847',4159,222,NULL,32,5674,0);
INSERT INTO "django_geo_db_location" VALUES(10127,NULL,'Ithaca, NY',4160,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10128,NULL,'Ithaca, NY 14850',4160,222,NULL,32,5675,0);
INSERT INTO "django_geo_db_location" VALUES(10129,NULL,'Ithaca, NY 14851',4160,222,NULL,32,5676,0);
INSERT INTO "django_geo_db_location" VALUES(10130,NULL,'Ithaca, NY 14852',4160,222,NULL,32,5677,0);
INSERT INTO "django_geo_db_location" VALUES(10131,NULL,'Ithaca, NY 14853',4160,222,NULL,32,5678,0);
INSERT INTO "django_geo_db_location" VALUES(10132,NULL,'Jacksonville, NY',4161,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10133,NULL,'Jacksonville, NY 14854',4161,222,NULL,32,5679,0);
INSERT INTO "django_geo_db_location" VALUES(10134,NULL,'Jasper, NY',4162,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10135,NULL,'Jasper, NY 14855',4162,222,NULL,32,5680,0);
INSERT INTO "django_geo_db_location" VALUES(10136,NULL,'Kanona, NY',4163,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10137,NULL,'Kanona, NY 14856',4163,222,NULL,32,5681,0);
INSERT INTO "django_geo_db_location" VALUES(10138,NULL,'Lakemont, NY',4164,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10139,NULL,'Lakemont, NY 14857',4164,222,NULL,32,5682,0);
INSERT INTO "django_geo_db_location" VALUES(10140,NULL,'Lindley, NY',4165,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10141,NULL,'Lindley, NY 14858',4165,222,NULL,32,5683,0);
INSERT INTO "django_geo_db_location" VALUES(10142,NULL,'Lockwood, NY',4166,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10143,NULL,'Lockwood, NY 14859',4166,222,NULL,32,5684,0);
INSERT INTO "django_geo_db_location" VALUES(10144,NULL,'Lodi, NY',4167,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10145,NULL,'Lodi, NY 14860',4167,222,NULL,32,5685,0);
INSERT INTO "django_geo_db_location" VALUES(10146,NULL,'Lowman, NY',4168,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10147,NULL,'Lowman, NY 14861',4168,222,NULL,32,5686,0);
INSERT INTO "django_geo_db_location" VALUES(10148,NULL,'Mecklenburg, NY',4169,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10149,NULL,'Mecklenburg, NY 14863',4169,222,NULL,32,5687,0);
INSERT INTO "django_geo_db_location" VALUES(10150,NULL,'Millport, NY',4170,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10151,NULL,'Millport, NY 14864',4170,222,NULL,32,5688,0);
INSERT INTO "django_geo_db_location" VALUES(10152,NULL,'Montour Falls, NY',4171,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10153,NULL,'Montour Falls, NY 14865',4171,222,NULL,32,5689,0);
INSERT INTO "django_geo_db_location" VALUES(10154,NULL,'Newfield, NY',4172,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10155,NULL,'Newfield, NY 14867',4172,222,NULL,32,5690,0);
INSERT INTO "django_geo_db_location" VALUES(10156,NULL,'Odessa, NY',4173,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10157,NULL,'Odessa, NY 14869',4173,222,NULL,32,5691,0);
INSERT INTO "django_geo_db_location" VALUES(10158,NULL,'Painted Post, NY',4174,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10159,NULL,'Painted Post, NY 14870',4174,222,NULL,32,5692,0);
INSERT INTO "django_geo_db_location" VALUES(10160,NULL,'Pine City, NY',4175,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10161,NULL,'Pine City, NY 14871',4175,222,NULL,32,5693,0);
INSERT INTO "django_geo_db_location" VALUES(10162,NULL,'Pine Valley, NY',4176,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10163,NULL,'Pine Valley, NY 14872',4176,222,NULL,32,5694,0);
INSERT INTO "django_geo_db_location" VALUES(10164,NULL,'Prattsburgh, NY',4177,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10165,NULL,'Prattsburgh, NY 14873',4177,222,NULL,32,5695,0);
INSERT INTO "django_geo_db_location" VALUES(10166,NULL,'Pulteney, NY',4178,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10167,NULL,'Pulteney, NY 14874',4178,222,NULL,32,5696,0);
INSERT INTO "django_geo_db_location" VALUES(10168,NULL,'Reading Center, NY',4179,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10169,NULL,'Reading Center, NY 14876',4179,222,NULL,32,5697,0);
INSERT INTO "django_geo_db_location" VALUES(10170,NULL,'Rexville, NY',4180,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10171,NULL,'Rexville, NY 14877',4180,222,NULL,32,5698,0);
INSERT INTO "django_geo_db_location" VALUES(10172,NULL,'Rock Stream, NY',4181,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10173,NULL,'Rock Stream, NY 14878',4181,222,NULL,32,5699,0);
INSERT INTO "django_geo_db_location" VALUES(10174,NULL,'Savona, NY',4182,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10175,NULL,'Savona, NY 14879',4182,222,NULL,32,5700,0);
INSERT INTO "django_geo_db_location" VALUES(10176,NULL,'Scio, NY',4183,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10177,NULL,'Scio, NY 14880',4183,222,NULL,32,5701,0);
INSERT INTO "django_geo_db_location" VALUES(10178,NULL,'Slaterville Springs, NY',4184,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10179,NULL,'Slaterville Springs, NY 14881',4184,222,NULL,32,5702,0);
INSERT INTO "django_geo_db_location" VALUES(10180,NULL,'Lansing, NY',4185,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10181,NULL,'Lansing, NY 14882',4185,222,NULL,32,5703,0);
INSERT INTO "django_geo_db_location" VALUES(10182,NULL,'Spencer, NY',4186,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10183,NULL,'Spencer, NY 14883',4186,222,NULL,32,5704,0);
INSERT INTO "django_geo_db_location" VALUES(10184,NULL,'Swain, NY',4187,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10185,NULL,'Swain, NY 14884',4187,222,NULL,32,5705,0);
INSERT INTO "django_geo_db_location" VALUES(10186,NULL,'Troupsburg, NY',4188,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10187,NULL,'Troupsburg, NY 14885',4188,222,NULL,32,5706,0);
INSERT INTO "django_geo_db_location" VALUES(10188,NULL,'Trumansburg, NY',4189,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10189,NULL,'Trumansburg, NY 14886',4189,222,NULL,32,5707,0);
INSERT INTO "django_geo_db_location" VALUES(10190,NULL,'Tyrone, NY',4190,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10191,NULL,'Tyrone, NY 14887',4190,222,NULL,32,5708,0);
INSERT INTO "django_geo_db_location" VALUES(10192,NULL,'Van Etten, NY',4191,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10193,NULL,'Van Etten, NY 14889',4191,222,NULL,32,5709,0);
INSERT INTO "django_geo_db_location" VALUES(10194,NULL,'Watkins Glen, NY',4192,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10195,NULL,'Watkins Glen, NY 14891',4192,222,NULL,32,5710,0);
INSERT INTO "django_geo_db_location" VALUES(10196,NULL,'Waverly, NY',4193,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10197,NULL,'Waverly, NY 14892',4193,222,NULL,32,5711,0);
INSERT INTO "django_geo_db_location" VALUES(10198,NULL,'Wayne, NY',4194,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10199,NULL,'Wayne, NY 14893',4194,222,NULL,32,5712,0);
INSERT INTO "django_geo_db_location" VALUES(10200,NULL,'Wellsburg, NY',4195,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10201,NULL,'Wellsburg, NY 14894',4195,222,NULL,32,5713,0);
INSERT INTO "django_geo_db_location" VALUES(10202,NULL,'Wellsville, NY',4196,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10203,NULL,'Wellsville, NY 14895',4196,222,NULL,32,5714,0);
INSERT INTO "django_geo_db_location" VALUES(10204,NULL,'Whitesville, NY',4197,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10205,NULL,'Whitesville, NY 14897',4197,222,NULL,32,5715,0);
INSERT INTO "django_geo_db_location" VALUES(10206,NULL,'Woodhull, NY',4198,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10207,NULL,'Woodhull, NY 14898',4198,222,NULL,32,5716,0);
INSERT INTO "django_geo_db_location" VALUES(10208,NULL,'Elmira, NY',4199,222,NULL,32,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10209,NULL,'Elmira, NY 14901',4199,222,NULL,32,5717,0);
INSERT INTO "django_geo_db_location" VALUES(10210,NULL,'Elmira, NY 14902',4199,222,NULL,32,5718,0);
INSERT INTO "django_geo_db_location" VALUES(10211,NULL,'Elmira, NY 14903',4199,222,NULL,32,5719,0);
INSERT INTO "django_geo_db_location" VALUES(10212,NULL,'Elmira, NY 14904',4199,222,NULL,32,5720,0);
INSERT INTO "django_geo_db_location" VALUES(10213,NULL,'Elmira, NY 14905',4199,222,NULL,32,5721,0);
INSERT INTO "django_geo_db_location" VALUES(10214,NULL,'Elmira, NY 14925',4199,222,NULL,32,5722,0);
INSERT INTO "django_geo_db_location" VALUES(10215,NULL,'Aliquippa, PA',4200,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10216,NULL,'Aliquippa, PA 15001',4200,222,NULL,44,5723,0);
INSERT INTO "django_geo_db_location" VALUES(10217,NULL,'Ambridge, PA',4201,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10218,NULL,'Ambridge, PA 15003',4201,222,NULL,44,5724,0);
INSERT INTO "django_geo_db_location" VALUES(10219,NULL,'Atlasburg, PA',4202,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10220,NULL,'Atlasburg, PA 15004',4202,222,NULL,44,5725,0);
INSERT INTO "django_geo_db_location" VALUES(10221,NULL,'Baden, PA',4203,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10222,NULL,'Baden, PA 15005',4203,222,NULL,44,5726,0);
INSERT INTO "django_geo_db_location" VALUES(10223,NULL,'Bairdford, PA',4204,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10224,NULL,'Bairdford, PA 15006',4204,222,NULL,44,5727,0);
INSERT INTO "django_geo_db_location" VALUES(10225,NULL,'Bakerstown, PA',4205,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10226,NULL,'Bakerstown, PA 15007',4205,222,NULL,44,5728,0);
INSERT INTO "django_geo_db_location" VALUES(10227,NULL,'Beaver, PA',4206,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10228,NULL,'Beaver, PA 15009',4206,222,NULL,44,5729,0);
INSERT INTO "django_geo_db_location" VALUES(10229,NULL,'Beaver Falls, PA',4207,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10230,NULL,'Beaver Falls, PA 15010',4207,222,NULL,44,5730,0);
INSERT INTO "django_geo_db_location" VALUES(10231,NULL,'Belle Vernon, PA',4208,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10232,NULL,'Belle Vernon, PA 15012',4208,222,NULL,44,5731,0);
INSERT INTO "django_geo_db_location" VALUES(10233,NULL,'Brackenridge, PA',4209,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10234,NULL,'Brackenridge, PA 15014',4209,222,NULL,44,5732,0);
INSERT INTO "django_geo_db_location" VALUES(10235,NULL,'Bradfordwoods, PA',4210,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10236,NULL,'Bradfordwoods, PA 15015',4210,222,NULL,44,5733,0);
INSERT INTO "django_geo_db_location" VALUES(10237,NULL,'Bridgeville, PA',4211,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10238,NULL,'Bridgeville, PA 15017',4211,222,NULL,44,5734,0);
INSERT INTO "django_geo_db_location" VALUES(10239,NULL,'Buena Vista, PA',4212,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10240,NULL,'Buena Vista, PA 15018',4212,222,NULL,44,5735,0);
INSERT INTO "django_geo_db_location" VALUES(10241,NULL,'Bulger, PA',4213,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10242,NULL,'Bulger, PA 15019',4213,222,NULL,44,5736,0);
INSERT INTO "django_geo_db_location" VALUES(10243,NULL,'Bunola, PA',4214,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10244,NULL,'Bunola, PA 15020',4214,222,NULL,44,5737,0);
INSERT INTO "django_geo_db_location" VALUES(10245,NULL,'Burgettstown, PA',4215,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10246,NULL,'Burgettstown, PA 15021',4215,222,NULL,44,5738,0);
INSERT INTO "django_geo_db_location" VALUES(10247,NULL,'Charleroi, PA',4216,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10248,NULL,'Charleroi, PA 15022',4216,222,NULL,44,5739,0);
INSERT INTO "django_geo_db_location" VALUES(10249,NULL,'Cheswick, PA',4217,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10250,NULL,'Cheswick, PA 15024',4217,222,NULL,44,5740,0);
INSERT INTO "django_geo_db_location" VALUES(10251,NULL,'Clairton, PA',4218,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10252,NULL,'Clairton, PA 15025',4218,222,NULL,44,5741,0);
INSERT INTO "django_geo_db_location" VALUES(10253,NULL,'Clinton, PA',4219,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10254,NULL,'Clinton, PA 15026',4219,222,NULL,44,5742,0);
INSERT INTO "django_geo_db_location" VALUES(10255,NULL,'Conway, PA',4220,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10256,NULL,'Conway, PA 15027',4220,222,NULL,44,5743,0);
INSERT INTO "django_geo_db_location" VALUES(10257,NULL,'Coulters, PA',4221,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10258,NULL,'Coulters, PA 15028',4221,222,NULL,44,5744,0);
INSERT INTO "django_geo_db_location" VALUES(10259,NULL,'Creighton, PA',4222,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10260,NULL,'Creighton, PA 15030',4222,222,NULL,44,5745,0);
INSERT INTO "django_geo_db_location" VALUES(10261,NULL,'Cuddy, PA',4223,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10262,NULL,'Cuddy, PA 15031',4223,222,NULL,44,5746,0);
INSERT INTO "django_geo_db_location" VALUES(10263,NULL,'Curtisville, PA',4224,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10264,NULL,'Curtisville, PA 15032',4224,222,NULL,44,5747,0);
INSERT INTO "django_geo_db_location" VALUES(10265,NULL,'Donora, PA',4225,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10266,NULL,'Donora, PA 15033',4225,222,NULL,44,5748,0);
INSERT INTO "django_geo_db_location" VALUES(10267,NULL,'Dravosburg, PA',4226,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10268,NULL,'Dravosburg, PA 15034',4226,222,NULL,44,5749,0);
INSERT INTO "django_geo_db_location" VALUES(10269,NULL,'East McKeesport, PA',4227,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10270,NULL,'East McKeesport, PA 15035',4227,222,NULL,44,5750,0);
INSERT INTO "django_geo_db_location" VALUES(10271,NULL,'Eldersville, PA',4228,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10272,NULL,'Eldersville, PA 15036',4228,222,NULL,44,5751,0);
INSERT INTO "django_geo_db_location" VALUES(10273,NULL,'Elizabeth, PA',4229,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10274,NULL,'Elizabeth, PA 15037',4229,222,NULL,44,5752,0);
INSERT INTO "django_geo_db_location" VALUES(10275,NULL,'Elrama, PA',4230,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10276,NULL,'Elrama, PA 15038',4230,222,NULL,44,5753,0);
INSERT INTO "django_geo_db_location" VALUES(10277,NULL,'Freedom, PA',4231,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10278,NULL,'Freedom, PA 15042',4231,222,NULL,44,5754,0);
INSERT INTO "django_geo_db_location" VALUES(10279,NULL,'Georgetown, PA',4232,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10280,NULL,'Georgetown, PA 15043',4232,222,NULL,44,5755,0);
INSERT INTO "django_geo_db_location" VALUES(10281,NULL,'Gibsonia, PA',4233,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10282,NULL,'Gibsonia, PA 15044',4233,222,NULL,44,5756,0);
INSERT INTO "django_geo_db_location" VALUES(10283,NULL,'Glassport, PA',4234,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10284,NULL,'Glassport, PA 15045',4234,222,NULL,44,5757,0);
INSERT INTO "django_geo_db_location" VALUES(10285,NULL,'Crescent, PA',4235,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10286,NULL,'Crescent, PA 15046',4235,222,NULL,44,5758,0);
INSERT INTO "django_geo_db_location" VALUES(10287,NULL,'Greenock, PA',4236,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10288,NULL,'Greenock, PA 15047',4236,222,NULL,44,5759,0);
INSERT INTO "django_geo_db_location" VALUES(10289,NULL,'Harwick, PA',4237,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10290,NULL,'Harwick, PA 15049',4237,222,NULL,44,5760,0);
INSERT INTO "django_geo_db_location" VALUES(10291,NULL,'Hookstown, PA',4238,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10292,NULL,'Hookstown, PA 15050',4238,222,NULL,44,5761,0);
INSERT INTO "django_geo_db_location" VALUES(10293,NULL,'Indianola, PA',4239,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10294,NULL,'Indianola, PA 15051',4239,222,NULL,44,5762,0);
INSERT INTO "django_geo_db_location" VALUES(10295,NULL,'Industry, PA',4240,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10296,NULL,'Industry, PA 15052',4240,222,NULL,44,5763,0);
INSERT INTO "django_geo_db_location" VALUES(10297,NULL,'Joffre, PA',4241,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10298,NULL,'Joffre, PA 15053',4241,222,NULL,44,5764,0);
INSERT INTO "django_geo_db_location" VALUES(10299,NULL,'Langeloth, PA',4242,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10300,NULL,'Langeloth, PA 15054',4242,222,NULL,44,5765,0);
INSERT INTO "django_geo_db_location" VALUES(10301,NULL,'Lawrence, PA',4243,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10302,NULL,'Lawrence, PA 15055',4243,222,NULL,44,5766,0);
INSERT INTO "django_geo_db_location" VALUES(10303,NULL,'Leetsdale, PA',4244,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10304,NULL,'Leetsdale, PA 15056',4244,222,NULL,44,5767,0);
INSERT INTO "django_geo_db_location" VALUES(10305,NULL,'McDonald, PA',4245,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10306,NULL,'McDonald, PA 15057',4245,222,NULL,44,5768,0);
INSERT INTO "django_geo_db_location" VALUES(10307,NULL,'Midland, PA',4246,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10308,NULL,'Midland, PA 15059',4246,222,NULL,44,5769,0);
INSERT INTO "django_geo_db_location" VALUES(10309,NULL,'Midway, PA',4247,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10310,NULL,'Midway, PA 15060',4247,222,NULL,44,5770,0);
INSERT INTO "django_geo_db_location" VALUES(10311,NULL,'Monaca, PA',4248,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10312,NULL,'Monaca, PA 15061',4248,222,NULL,44,5771,0);
INSERT INTO "django_geo_db_location" VALUES(10313,NULL,'Monessen, PA',4249,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10314,NULL,'Monessen, PA 15062',4249,222,NULL,44,5772,0);
INSERT INTO "django_geo_db_location" VALUES(10315,NULL,'Monongahela, PA',4250,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10316,NULL,'Monongahela, PA 15063',4250,222,NULL,44,5773,0);
INSERT INTO "django_geo_db_location" VALUES(10317,NULL,'Morgan, PA',4251,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10318,NULL,'Morgan, PA 15064',4251,222,NULL,44,5774,0);
INSERT INTO "django_geo_db_location" VALUES(10319,NULL,'Natrona Heights, PA',4252,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10320,NULL,'Natrona Heights, PA 15065',4252,222,NULL,44,5775,0);
INSERT INTO "django_geo_db_location" VALUES(10321,NULL,'New Brighton, PA',4253,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10322,NULL,'New Brighton, PA 15066',4253,222,NULL,44,5776,0);
INSERT INTO "django_geo_db_location" VALUES(10323,NULL,'New Eagle, PA',4254,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10324,NULL,'New Eagle, PA 15067',4254,222,NULL,44,5777,0);
INSERT INTO "django_geo_db_location" VALUES(10325,NULL,'New Kensington, PA',4255,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10326,NULL,'New Kensington, PA 15068',4255,222,NULL,44,5778,0);
INSERT INTO "django_geo_db_location" VALUES(10327,NULL,'New Kensington, PA 15069',4255,222,NULL,44,5779,0);
INSERT INTO "django_geo_db_location" VALUES(10328,NULL,'Oakdale, PA',4256,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10329,NULL,'Oakdale, PA 15071',4256,222,NULL,44,5780,0);
INSERT INTO "django_geo_db_location" VALUES(10330,NULL,'Pricedale, PA',4257,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10331,NULL,'Pricedale, PA 15072',4257,222,NULL,44,5781,0);
INSERT INTO "django_geo_db_location" VALUES(10332,NULL,'Rochester, PA',4258,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10333,NULL,'Rochester, PA 15074',4258,222,NULL,44,5782,0);
INSERT INTO "django_geo_db_location" VALUES(10334,NULL,'Rural Ridge, PA',4259,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10335,NULL,'Rural Ridge, PA 15075',4259,222,NULL,44,5783,0);
INSERT INTO "django_geo_db_location" VALUES(10336,NULL,'Russellton, PA',4260,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10337,NULL,'Russellton, PA 15076',4260,222,NULL,44,5784,0);
INSERT INTO "django_geo_db_location" VALUES(10338,NULL,'Shippingport, PA',4261,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10339,NULL,'Shippingport, PA 15077',4261,222,NULL,44,5785,0);
INSERT INTO "django_geo_db_location" VALUES(10340,NULL,'Slovan, PA',4262,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10341,NULL,'Slovan, PA 15078',4262,222,NULL,44,5786,0);
INSERT INTO "django_geo_db_location" VALUES(10342,NULL,'South Heights, PA',4263,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10343,NULL,'South Heights, PA 15081',4263,222,NULL,44,5787,0);
INSERT INTO "django_geo_db_location" VALUES(10344,NULL,'Sturgeon, PA',4264,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10345,NULL,'Sturgeon, PA 15082',4264,222,NULL,44,5788,0);
INSERT INTO "django_geo_db_location" VALUES(10346,NULL,'Sutersville, PA',4265,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10347,NULL,'Sutersville, PA 15083',4265,222,NULL,44,5789,0);
INSERT INTO "django_geo_db_location" VALUES(10348,NULL,'Tarentum, PA',4266,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10349,NULL,'Tarentum, PA 15084',4266,222,NULL,44,5790,0);
INSERT INTO "django_geo_db_location" VALUES(10350,NULL,'Trafford, PA',4267,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10351,NULL,'Trafford, PA 15085',4267,222,NULL,44,5791,0);
INSERT INTO "django_geo_db_location" VALUES(10352,NULL,'Warrendale, PA',4268,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10353,NULL,'Warrendale, PA 15086',4268,222,NULL,44,5792,0);
INSERT INTO "django_geo_db_location" VALUES(10354,NULL,'Webster, PA',4269,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10355,NULL,'Webster, PA 15087',4269,222,NULL,44,5793,0);
INSERT INTO "django_geo_db_location" VALUES(10356,NULL,'West Elizabeth, PA',4270,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10357,NULL,'West Elizabeth, PA 15088',4270,222,NULL,44,5794,0);
INSERT INTO "django_geo_db_location" VALUES(10358,NULL,'West Newton, PA',4271,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10359,NULL,'West Newton, PA 15089',4271,222,NULL,44,5795,0);
INSERT INTO "django_geo_db_location" VALUES(10360,NULL,'Wexford, PA',4272,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10361,NULL,'Wexford, PA 15090',4272,222,NULL,44,5796,0);
INSERT INTO "django_geo_db_location" VALUES(10362,NULL,'Wildwood, PA',4273,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10363,NULL,'Wildwood, PA 15091',4273,222,NULL,44,5797,0);
INSERT INTO "django_geo_db_location" VALUES(10364,NULL,'Warrendale, PA 15095',4268,222,NULL,44,5798,0);
INSERT INTO "django_geo_db_location" VALUES(10365,NULL,'Warrendale, PA 15096',4268,222,NULL,44,5799,0);
INSERT INTO "django_geo_db_location" VALUES(10366,NULL,'Allison Park, PA',4274,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10367,NULL,'Allison Park, PA 15101',4274,222,NULL,44,5800,0);
INSERT INTO "django_geo_db_location" VALUES(10368,NULL,'Bethel Park, PA',4275,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10369,NULL,'Bethel Park, PA 15102',4275,222,NULL,44,5801,0);
INSERT INTO "django_geo_db_location" VALUES(10370,NULL,'Braddock, PA',4276,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10371,NULL,'Braddock, PA 15104',4276,222,NULL,44,5802,0);
INSERT INTO "django_geo_db_location" VALUES(10372,NULL,'Carnegie, PA',4277,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10373,NULL,'Carnegie, PA 15106',4277,222,NULL,44,5803,0);
INSERT INTO "django_geo_db_location" VALUES(10374,NULL,'Coraopolis, PA',4278,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10375,NULL,'Coraopolis, PA 15108',4278,222,NULL,44,5804,0);
INSERT INTO "django_geo_db_location" VALUES(10376,NULL,'Duquesne, PA',4279,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10377,NULL,'Duquesne, PA 15110',4279,222,NULL,44,5805,0);
INSERT INTO "django_geo_db_location" VALUES(10378,NULL,'East Pittsburgh, PA',4280,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10379,NULL,'East Pittsburgh, PA 15112',4280,222,NULL,44,5806,0);
INSERT INTO "django_geo_db_location" VALUES(10380,NULL,'Glenshaw, PA',4281,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10381,NULL,'Glenshaw, PA 15116',4281,222,NULL,44,5807,0);
INSERT INTO "django_geo_db_location" VALUES(10382,NULL,'Homestead, PA',4282,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10383,NULL,'Homestead, PA 15120',4282,222,NULL,44,5808,0);
INSERT INTO "django_geo_db_location" VALUES(10384,NULL,'West Mifflin, PA',4283,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10385,NULL,'West Mifflin, PA 15122',4283,222,NULL,44,5809,0);
INSERT INTO "django_geo_db_location" VALUES(10386,NULL,'West Mifflin, PA 15123',4283,222,NULL,44,5810,0);
INSERT INTO "django_geo_db_location" VALUES(10387,NULL,'Imperial, PA',4284,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10388,NULL,'Imperial, PA 15126',4284,222,NULL,44,5811,0);
INSERT INTO "django_geo_db_location" VALUES(10389,NULL,'Ingomar, PA',4285,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10390,NULL,'Ingomar, PA 15127',4285,222,NULL,44,5812,0);
INSERT INTO "django_geo_db_location" VALUES(10391,NULL,'Library, PA',4286,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10392,NULL,'Library, PA 15129',4286,222,NULL,44,5813,0);
INSERT INTO "django_geo_db_location" VALUES(10393,NULL,'McKeesport, PA',4287,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10394,NULL,'McKeesport, PA 15130',4287,222,NULL,44,5814,0);
INSERT INTO "django_geo_db_location" VALUES(10395,NULL,'McKeesport, PA 15131',4287,222,NULL,44,5815,0);
INSERT INTO "django_geo_db_location" VALUES(10396,NULL,'McKeesport, PA 15132',4287,222,NULL,44,5816,0);
INSERT INTO "django_geo_db_location" VALUES(10397,NULL,'McKeesport, PA 15133',4287,222,NULL,44,5817,0);
INSERT INTO "django_geo_db_location" VALUES(10398,NULL,'McKeesport, PA 15134',4287,222,NULL,44,5818,0);
INSERT INTO "django_geo_db_location" VALUES(10399,NULL,'McKeesport, PA 15135',4287,222,NULL,44,5819,0);
INSERT INTO "django_geo_db_location" VALUES(10400,NULL,'McKees Rocks, PA',4288,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10401,NULL,'McKees Rocks, PA 15136',4288,222,NULL,44,5820,0);
INSERT INTO "django_geo_db_location" VALUES(10402,NULL,'North Versailles, PA',4289,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10403,NULL,'North Versailles, PA 15137',4289,222,NULL,44,5821,0);
INSERT INTO "django_geo_db_location" VALUES(10404,NULL,'Oakmont, PA',4290,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10405,NULL,'Oakmont, PA 15139',4290,222,NULL,44,5822,0);
INSERT INTO "django_geo_db_location" VALUES(10406,NULL,'Pitcairn, PA',4291,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10407,NULL,'Pitcairn, PA 15140',4291,222,NULL,44,5823,0);
INSERT INTO "django_geo_db_location" VALUES(10408,NULL,'Presto, PA',4292,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10409,NULL,'Presto, PA 15142',4292,222,NULL,44,5824,0);
INSERT INTO "django_geo_db_location" VALUES(10410,NULL,'Sewickley, PA',4293,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10411,NULL,'Sewickley, PA 15143',4293,222,NULL,44,5825,0);
INSERT INTO "django_geo_db_location" VALUES(10412,NULL,'Springdale, PA',4294,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10413,NULL,'Springdale, PA 15144',4294,222,NULL,44,5826,0);
INSERT INTO "django_geo_db_location" VALUES(10414,NULL,'Turtle Creek, PA',4295,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10415,NULL,'Turtle Creek, PA 15145',4295,222,NULL,44,5827,0);
INSERT INTO "django_geo_db_location" VALUES(10416,NULL,'Monroeville, PA',4296,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10417,NULL,'Monroeville, PA 15146',4296,222,NULL,44,5828,0);
INSERT INTO "django_geo_db_location" VALUES(10418,NULL,'Verona, PA',4297,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10419,NULL,'Verona, PA 15147',4297,222,NULL,44,5829,0);
INSERT INTO "django_geo_db_location" VALUES(10420,NULL,'Wilmerding, PA',4298,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10421,NULL,'Wilmerding, PA 15148',4298,222,NULL,44,5830,0);
INSERT INTO "django_geo_db_location" VALUES(10422,NULL,'North Apollo, PA',4299,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10423,NULL,'North Apollo, PA 15163',4299,222,NULL,44,5831,0);
INSERT INTO "django_geo_db_location" VALUES(10424,NULL,'Sewickley, PA 15189',4293,222,NULL,44,5832,0);
INSERT INTO "django_geo_db_location" VALUES(10425,NULL,'Pittsburgh, PA',4300,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10426,NULL,'Pittsburgh, PA 15201',4300,222,NULL,44,5833,0);
INSERT INTO "django_geo_db_location" VALUES(10427,NULL,'Pittsburgh, PA 15202',4300,222,NULL,44,5834,0);
INSERT INTO "django_geo_db_location" VALUES(10428,NULL,'Pittsburgh, PA 15203',4300,222,NULL,44,5835,0);
INSERT INTO "django_geo_db_location" VALUES(10429,NULL,'Pittsburgh, PA 15204',4300,222,NULL,44,5836,0);
INSERT INTO "django_geo_db_location" VALUES(10430,NULL,'Pittsburgh, PA 15205',4300,222,NULL,44,5837,0);
INSERT INTO "django_geo_db_location" VALUES(10431,NULL,'Pittsburgh, PA 15206',4300,222,NULL,44,5838,0);
INSERT INTO "django_geo_db_location" VALUES(10432,NULL,'Pittsburgh, PA 15207',4300,222,NULL,44,5839,0);
INSERT INTO "django_geo_db_location" VALUES(10433,NULL,'Pittsburgh, PA 15208',4300,222,NULL,44,5840,0);
INSERT INTO "django_geo_db_location" VALUES(10434,NULL,'Pittsburgh, PA 15209',4300,222,NULL,44,5841,0);
INSERT INTO "django_geo_db_location" VALUES(10435,NULL,'Pittsburgh, PA 15210',4300,222,NULL,44,5842,0);
INSERT INTO "django_geo_db_location" VALUES(10436,NULL,'Pittsburgh, PA 15211',4300,222,NULL,44,5843,0);
INSERT INTO "django_geo_db_location" VALUES(10437,NULL,'Pittsburgh, PA 15212',4300,222,NULL,44,5844,0);
INSERT INTO "django_geo_db_location" VALUES(10438,NULL,'Pittsburgh, PA 15213',4300,222,NULL,44,5845,0);
INSERT INTO "django_geo_db_location" VALUES(10439,NULL,'Pittsburgh, PA 15214',4300,222,NULL,44,5846,0);
INSERT INTO "django_geo_db_location" VALUES(10440,NULL,'Pittsburgh, PA 15215',4300,222,NULL,44,5847,0);
INSERT INTO "django_geo_db_location" VALUES(10441,NULL,'Pittsburgh, PA 15216',4300,222,NULL,44,5848,0);
INSERT INTO "django_geo_db_location" VALUES(10442,NULL,'Pittsburgh, PA 15217',4300,222,NULL,44,5849,0);
INSERT INTO "django_geo_db_location" VALUES(10443,NULL,'Pittsburgh, PA 15218',4300,222,NULL,44,5850,0);
INSERT INTO "django_geo_db_location" VALUES(10444,NULL,'Pittsburgh, PA 15219',4300,222,NULL,44,5851,0);
INSERT INTO "django_geo_db_location" VALUES(10445,NULL,'Pittsburgh, PA 15220',4300,222,NULL,44,5852,0);
INSERT INTO "django_geo_db_location" VALUES(10446,NULL,'Pittsburgh, PA 15221',4300,222,NULL,44,5853,0);
INSERT INTO "django_geo_db_location" VALUES(10447,NULL,'Pittsburgh, PA 15222',4300,222,NULL,44,5854,0);
INSERT INTO "django_geo_db_location" VALUES(10448,NULL,'Pittsburgh, PA 15223',4300,222,NULL,44,5855,0);
INSERT INTO "django_geo_db_location" VALUES(10449,NULL,'Pittsburgh, PA 15224',4300,222,NULL,44,5856,0);
INSERT INTO "django_geo_db_location" VALUES(10450,NULL,'Pittsburgh, PA 15225',4300,222,NULL,44,5857,0);
INSERT INTO "django_geo_db_location" VALUES(10451,NULL,'Pittsburgh, PA 15226',4300,222,NULL,44,5858,0);
INSERT INTO "django_geo_db_location" VALUES(10452,NULL,'Pittsburgh, PA 15227',4300,222,NULL,44,5859,0);
INSERT INTO "django_geo_db_location" VALUES(10453,NULL,'Pittsburgh, PA 15228',4300,222,NULL,44,5860,0);
INSERT INTO "django_geo_db_location" VALUES(10454,NULL,'Pittsburgh, PA 15229',4300,222,NULL,44,5861,0);
INSERT INTO "django_geo_db_location" VALUES(10455,NULL,'Pittsburgh, PA 15230',4300,222,NULL,44,5862,0);
INSERT INTO "django_geo_db_location" VALUES(10456,NULL,'Pittsburgh, PA 15231',4300,222,NULL,44,5863,0);
INSERT INTO "django_geo_db_location" VALUES(10457,NULL,'Pittsburgh, PA 15232',4300,222,NULL,44,5864,0);
INSERT INTO "django_geo_db_location" VALUES(10458,NULL,'Pittsburgh, PA 15233',4300,222,NULL,44,5865,0);
INSERT INTO "django_geo_db_location" VALUES(10459,NULL,'Pittsburgh, PA 15234',4300,222,NULL,44,5866,0);
INSERT INTO "django_geo_db_location" VALUES(10460,NULL,'Pittsburgh, PA 15235',4300,222,NULL,44,5867,0);
INSERT INTO "django_geo_db_location" VALUES(10461,NULL,'Pittsburgh, PA 15236',4300,222,NULL,44,5868,0);
INSERT INTO "django_geo_db_location" VALUES(10462,NULL,'Pittsburgh, PA 15237',4300,222,NULL,44,5869,0);
INSERT INTO "django_geo_db_location" VALUES(10463,NULL,'Pittsburgh, PA 15238',4300,222,NULL,44,5870,0);
INSERT INTO "django_geo_db_location" VALUES(10464,NULL,'Pittsburgh, PA 15239',4300,222,NULL,44,5871,0);
INSERT INTO "django_geo_db_location" VALUES(10465,NULL,'Pittsburgh, PA 15240',4300,222,NULL,44,5872,0);
INSERT INTO "django_geo_db_location" VALUES(10466,NULL,'Pittsburgh, PA 15241',4300,222,NULL,44,5873,0);
INSERT INTO "django_geo_db_location" VALUES(10467,NULL,'Pittsburgh, PA 15242',4300,222,NULL,44,5874,0);
INSERT INTO "django_geo_db_location" VALUES(10468,NULL,'Pittsburgh, PA 15243',4300,222,NULL,44,5875,0);
INSERT INTO "django_geo_db_location" VALUES(10469,NULL,'Pittsburgh, PA 15244',4300,222,NULL,44,5876,0);
INSERT INTO "django_geo_db_location" VALUES(10470,NULL,'Pittsburgh, PA 15246',4300,222,NULL,44,5877,0);
INSERT INTO "django_geo_db_location" VALUES(10471,NULL,'Pittsburgh, PA 15250',4300,222,NULL,44,5878,0);
INSERT INTO "django_geo_db_location" VALUES(10472,NULL,'Pittsburgh, PA 15251',4300,222,NULL,44,5879,0);
INSERT INTO "django_geo_db_location" VALUES(10473,NULL,'Pittsburgh, PA 15252',4300,222,NULL,44,5880,0);
INSERT INTO "django_geo_db_location" VALUES(10474,NULL,'Pittsburgh, PA 15253',4300,222,NULL,44,5881,0);
INSERT INTO "django_geo_db_location" VALUES(10475,NULL,'Pittsburgh, PA 15254',4300,222,NULL,44,5882,0);
INSERT INTO "django_geo_db_location" VALUES(10476,NULL,'Pittsburgh, PA 15255',4300,222,NULL,44,5883,0);
INSERT INTO "django_geo_db_location" VALUES(10477,NULL,'Pittsburgh, PA 15257',4300,222,NULL,44,5884,0);
INSERT INTO "django_geo_db_location" VALUES(10478,NULL,'Pittsburgh, PA 15258',4300,222,NULL,44,5885,0);
INSERT INTO "django_geo_db_location" VALUES(10479,NULL,'Pittsburgh, PA 15259',4300,222,NULL,44,5886,0);
INSERT INTO "django_geo_db_location" VALUES(10480,NULL,'Pittsburgh, PA 15260',4300,222,NULL,44,5887,0);
INSERT INTO "django_geo_db_location" VALUES(10481,NULL,'Pittsburgh, PA 15261',4300,222,NULL,44,5888,0);
INSERT INTO "django_geo_db_location" VALUES(10482,NULL,'Pittsburgh, PA 15262',4300,222,NULL,44,5889,0);
INSERT INTO "django_geo_db_location" VALUES(10483,NULL,'Pittsburgh, PA 15263',4300,222,NULL,44,5890,0);
INSERT INTO "django_geo_db_location" VALUES(10484,NULL,'Pittsburgh, PA 15264',4300,222,NULL,44,5891,0);
INSERT INTO "django_geo_db_location" VALUES(10485,NULL,'Pittsburgh, PA 15265',4300,222,NULL,44,5892,0);
INSERT INTO "django_geo_db_location" VALUES(10486,NULL,'Pittsburgh, PA 15266',4300,222,NULL,44,5893,0);
INSERT INTO "django_geo_db_location" VALUES(10487,NULL,'Pittsburgh, PA 15267',4300,222,NULL,44,5894,0);
INSERT INTO "django_geo_db_location" VALUES(10488,NULL,'Pittsburgh, PA 15268',4300,222,NULL,44,5895,0);
INSERT INTO "django_geo_db_location" VALUES(10489,NULL,'Pittsburgh, PA 15270',4300,222,NULL,44,5896,0);
INSERT INTO "django_geo_db_location" VALUES(10490,NULL,'Pittsburgh, PA 15272',4300,222,NULL,44,5897,0);
INSERT INTO "django_geo_db_location" VALUES(10491,NULL,'Pittsburgh, PA 15274',4300,222,NULL,44,5898,0);
INSERT INTO "django_geo_db_location" VALUES(10492,NULL,'Pittsburgh, PA 15275',4300,222,NULL,44,5899,0);
INSERT INTO "django_geo_db_location" VALUES(10493,NULL,'Pittsburgh, PA 15276',4300,222,NULL,44,5900,0);
INSERT INTO "django_geo_db_location" VALUES(10494,NULL,'Pittsburgh, PA 15277',4300,222,NULL,44,5901,0);
INSERT INTO "django_geo_db_location" VALUES(10495,NULL,'Pittsburgh, PA 15278',4300,222,NULL,44,5902,0);
INSERT INTO "django_geo_db_location" VALUES(10496,NULL,'Pittsburgh, PA 15279',4300,222,NULL,44,5903,0);
INSERT INTO "django_geo_db_location" VALUES(10497,NULL,'Pittsburgh, PA 15281',4300,222,NULL,44,5904,0);
INSERT INTO "django_geo_db_location" VALUES(10498,NULL,'Pittsburgh, PA 15282',4300,222,NULL,44,5905,0);
INSERT INTO "django_geo_db_location" VALUES(10499,NULL,'Pittsburgh, PA 15283',4300,222,NULL,44,5906,0);
INSERT INTO "django_geo_db_location" VALUES(10500,NULL,'Pittsburgh, PA 15285',4300,222,NULL,44,5907,0);
INSERT INTO "django_geo_db_location" VALUES(10501,NULL,'Pittsburgh, PA 15286',4300,222,NULL,44,5908,0);
INSERT INTO "django_geo_db_location" VALUES(10502,NULL,'Pittsburgh, PA 15290',4300,222,NULL,44,5909,0);
INSERT INTO "django_geo_db_location" VALUES(10503,NULL,'Pittsburgh, PA 15298',4300,222,NULL,44,5910,0);
INSERT INTO "django_geo_db_location" VALUES(10504,NULL,'Washington, PA',4301,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10505,NULL,'Washington, PA 15301',4301,222,NULL,44,5911,0);
INSERT INTO "django_geo_db_location" VALUES(10506,NULL,'Aleppo, PA',4302,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10507,NULL,'Aleppo, PA 15310',4302,222,NULL,44,5912,0);
INSERT INTO "django_geo_db_location" VALUES(10508,NULL,'Amity, PA',4303,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10509,NULL,'Amity, PA 15311',4303,222,NULL,44,5913,0);
INSERT INTO "django_geo_db_location" VALUES(10510,NULL,'Avella, PA',4304,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10511,NULL,'Avella, PA 15312',4304,222,NULL,44,5914,0);
INSERT INTO "django_geo_db_location" VALUES(10512,NULL,'Beallsville, PA',4305,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10513,NULL,'Beallsville, PA 15313',4305,222,NULL,44,5915,0);
INSERT INTO "django_geo_db_location" VALUES(10514,NULL,'Bentleyville, PA',4306,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10515,NULL,'Bentleyville, PA 15314',4306,222,NULL,44,5916,0);
INSERT INTO "django_geo_db_location" VALUES(10516,NULL,'Bobtown, PA',4307,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10517,NULL,'Bobtown, PA 15315',4307,222,NULL,44,5917,0);
INSERT INTO "django_geo_db_location" VALUES(10518,NULL,'Brave, PA',4308,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10519,NULL,'Brave, PA 15316',4308,222,NULL,44,5918,0);
INSERT INTO "django_geo_db_location" VALUES(10520,NULL,'Canonsburg, PA',4309,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10521,NULL,'Canonsburg, PA 15317',4309,222,NULL,44,5919,0);
INSERT INTO "django_geo_db_location" VALUES(10522,NULL,'Carmichaels, PA',4310,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10523,NULL,'Carmichaels, PA 15320',4310,222,NULL,44,5920,0);
INSERT INTO "django_geo_db_location" VALUES(10524,NULL,'Cecil, PA',4311,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10525,NULL,'Cecil, PA 15321',4311,222,NULL,44,5921,0);
INSERT INTO "django_geo_db_location" VALUES(10526,NULL,'Clarksville, PA',4312,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10527,NULL,'Clarksville, PA 15322',4312,222,NULL,44,5922,0);
INSERT INTO "django_geo_db_location" VALUES(10528,NULL,'Claysville, PA',4313,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10529,NULL,'Claysville, PA 15323',4313,222,NULL,44,5923,0);
INSERT INTO "django_geo_db_location" VALUES(10530,NULL,'Cokeburg, PA',4314,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10531,NULL,'Cokeburg, PA 15324',4314,222,NULL,44,5924,0);
INSERT INTO "django_geo_db_location" VALUES(10532,NULL,'Crucible, PA',4315,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10533,NULL,'Crucible, PA 15325',4315,222,NULL,44,5925,0);
INSERT INTO "django_geo_db_location" VALUES(10534,NULL,'Dilliner, PA',4316,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10535,NULL,'Dilliner, PA 15327',4316,222,NULL,44,5926,0);
INSERT INTO "django_geo_db_location" VALUES(10536,NULL,'Prosperity, PA',4317,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10537,NULL,'Prosperity, PA 15329',4317,222,NULL,44,5927,0);
INSERT INTO "django_geo_db_location" VALUES(10538,NULL,'Eighty Four, PA',4318,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10539,NULL,'Eighty Four, PA 15330',4318,222,NULL,44,5928,0);
INSERT INTO "django_geo_db_location" VALUES(10540,NULL,'Ellsworth, PA',4319,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10541,NULL,'Ellsworth, PA 15331',4319,222,NULL,44,5929,0);
INSERT INTO "django_geo_db_location" VALUES(10542,NULL,'Finleyville, PA',4320,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10543,NULL,'Finleyville, PA 15332',4320,222,NULL,44,5930,0);
INSERT INTO "django_geo_db_location" VALUES(10544,NULL,'Fredericktown, PA',4321,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10545,NULL,'Fredericktown, PA 15333',4321,222,NULL,44,5931,0);
INSERT INTO "django_geo_db_location" VALUES(10546,NULL,'Garards Fort, PA',4322,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10547,NULL,'Garards Fort, PA 15334',4322,222,NULL,44,5932,0);
INSERT INTO "django_geo_db_location" VALUES(10548,NULL,'Gastonville, PA',4323,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10549,NULL,'Gastonville, PA 15336',4323,222,NULL,44,5933,0);
INSERT INTO "django_geo_db_location" VALUES(10550,NULL,'Graysville, PA',4324,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10551,NULL,'Graysville, PA 15337',4324,222,NULL,44,5934,0);
INSERT INTO "django_geo_db_location" VALUES(10552,NULL,'Greensboro, PA',4325,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10553,NULL,'Greensboro, PA 15338',4325,222,NULL,44,5935,0);
INSERT INTO "django_geo_db_location" VALUES(10554,NULL,'Hendersonville, PA',4326,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10555,NULL,'Hendersonville, PA 15339',4326,222,NULL,44,5936,0);
INSERT INTO "django_geo_db_location" VALUES(10556,NULL,'Hickory, PA',4327,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10557,NULL,'Hickory, PA 15340',4327,222,NULL,44,5937,0);
INSERT INTO "django_geo_db_location" VALUES(10558,NULL,'Holbrook, PA',4328,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10559,NULL,'Holbrook, PA 15341',4328,222,NULL,44,5938,0);
INSERT INTO "django_geo_db_location" VALUES(10560,NULL,'Houston, PA',4329,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10561,NULL,'Houston, PA 15342',4329,222,NULL,44,5939,0);
INSERT INTO "django_geo_db_location" VALUES(10562,NULL,'Jefferson, PA',4330,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10563,NULL,'Jefferson, PA 15344',4330,222,NULL,44,5940,0);
INSERT INTO "django_geo_db_location" VALUES(10564,NULL,'Marianna, PA',4331,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10565,NULL,'Marianna, PA 15345',4331,222,NULL,44,5941,0);
INSERT INTO "django_geo_db_location" VALUES(10566,NULL,'Mather, PA',4332,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10567,NULL,'Mather, PA 15346',4332,222,NULL,44,5942,0);
INSERT INTO "django_geo_db_location" VALUES(10568,NULL,'Meadow Lands, PA',4333,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10569,NULL,'Meadow Lands, PA 15347',4333,222,NULL,44,5943,0);
INSERT INTO "django_geo_db_location" VALUES(10570,NULL,'Millsboro, PA',4334,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10571,NULL,'Millsboro, PA 15348',4334,222,NULL,44,5944,0);
INSERT INTO "django_geo_db_location" VALUES(10572,NULL,'Mount Morris, PA',4335,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10573,NULL,'Mount Morris, PA 15349',4335,222,NULL,44,5945,0);
INSERT INTO "django_geo_db_location" VALUES(10574,NULL,'Muse, PA',4336,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10575,NULL,'Muse, PA 15350',4336,222,NULL,44,5946,0);
INSERT INTO "django_geo_db_location" VALUES(10576,NULL,'Nemacolin, PA',4337,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10577,NULL,'Nemacolin, PA 15351',4337,222,NULL,44,5947,0);
INSERT INTO "django_geo_db_location" VALUES(10578,NULL,'New Freeport, PA',4338,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10579,NULL,'New Freeport, PA 15352',4338,222,NULL,44,5948,0);
INSERT INTO "django_geo_db_location" VALUES(10580,NULL,'Nineveh, PA',4339,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10581,NULL,'Nineveh, PA 15353',4339,222,NULL,44,5949,0);
INSERT INTO "django_geo_db_location" VALUES(10582,NULL,'Pine Bank, PA',4340,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10583,NULL,'Pine Bank, PA 15354',4340,222,NULL,44,5950,0);
INSERT INTO "django_geo_db_location" VALUES(10584,NULL,'Centerville, PA',4341,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10585,NULL,'Centerville, PA 15355',4341,222,NULL,44,5951,0);
INSERT INTO "django_geo_db_location" VALUES(10586,NULL,'Rices Landing, PA',4342,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10587,NULL,'Rices Landing, PA 15357',4342,222,NULL,44,5952,0);
INSERT INTO "django_geo_db_location" VALUES(10588,NULL,'Richeyville, PA',4343,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10589,NULL,'Richeyville, PA 15358',4343,222,NULL,44,5953,0);
INSERT INTO "django_geo_db_location" VALUES(10590,NULL,'Rogersville, PA',4344,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10591,NULL,'Rogersville, PA 15359',4344,222,NULL,44,5954,0);
INSERT INTO "django_geo_db_location" VALUES(10592,NULL,'Scenery Hill, PA',4345,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10593,NULL,'Scenery Hill, PA 15360',4345,222,NULL,44,5955,0);
INSERT INTO "django_geo_db_location" VALUES(10594,NULL,'Southview, PA',4346,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10595,NULL,'Southview, PA 15361',4346,222,NULL,44,5956,0);
INSERT INTO "django_geo_db_location" VALUES(10596,NULL,'Spraggs, PA',4347,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10597,NULL,'Spraggs, PA 15362',4347,222,NULL,44,5957,0);
INSERT INTO "django_geo_db_location" VALUES(10598,NULL,'Strabane, PA',4348,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10599,NULL,'Strabane, PA 15363',4348,222,NULL,44,5958,0);
INSERT INTO "django_geo_db_location" VALUES(10600,NULL,'Sycamore, PA',4349,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10601,NULL,'Sycamore, PA 15364',4349,222,NULL,44,5959,0);
INSERT INTO "django_geo_db_location" VALUES(10602,NULL,'Taylorstown, PA',4350,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10603,NULL,'Taylorstown, PA 15365',4350,222,NULL,44,5960,0);
INSERT INTO "django_geo_db_location" VALUES(10604,NULL,'Van Voorhis, PA',4351,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10605,NULL,'Van Voorhis, PA 15366',4351,222,NULL,44,5961,0);
INSERT INTO "django_geo_db_location" VALUES(10606,NULL,'Venetia, PA',4352,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10607,NULL,'Venetia, PA 15367',4352,222,NULL,44,5962,0);
INSERT INTO "django_geo_db_location" VALUES(10608,NULL,'Vestaburg, PA',4353,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10609,NULL,'Vestaburg, PA 15368',4353,222,NULL,44,5963,0);
INSERT INTO "django_geo_db_location" VALUES(10610,NULL,'Waynesburg, PA',4354,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10611,NULL,'Waynesburg, PA 15370',4354,222,NULL,44,5964,0);
INSERT INTO "django_geo_db_location" VALUES(10612,NULL,'West Alexander, PA',4355,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10613,NULL,'West Alexander, PA 15376',4355,222,NULL,44,5965,0);
INSERT INTO "django_geo_db_location" VALUES(10614,NULL,'West Finley, PA',4356,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10615,NULL,'West Finley, PA 15377',4356,222,NULL,44,5966,0);
INSERT INTO "django_geo_db_location" VALUES(10616,NULL,'Westland, PA',4357,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10617,NULL,'Westland, PA 15378',4357,222,NULL,44,5967,0);
INSERT INTO "django_geo_db_location" VALUES(10618,NULL,'West Middletown, PA',4358,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10619,NULL,'West Middletown, PA 15379',4358,222,NULL,44,5968,0);
INSERT INTO "django_geo_db_location" VALUES(10620,NULL,'Wind Ridge, PA',4359,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10621,NULL,'Wind Ridge, PA 15380',4359,222,NULL,44,5969,0);
INSERT INTO "django_geo_db_location" VALUES(10622,NULL,'Uniontown, PA',4360,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10623,NULL,'Uniontown, PA 15401',4360,222,NULL,44,5970,0);
INSERT INTO "django_geo_db_location" VALUES(10624,NULL,'Adah, PA',4361,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10625,NULL,'Adah, PA 15410',4361,222,NULL,44,5971,0);
INSERT INTO "django_geo_db_location" VALUES(10626,NULL,'Addison, PA',4362,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10627,NULL,'Addison, PA 15411',4362,222,NULL,44,5972,0);
INSERT INTO "django_geo_db_location" VALUES(10628,NULL,'Allenport, PA',4363,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10629,NULL,'Allenport, PA 15412',4363,222,NULL,44,5973,0);
INSERT INTO "django_geo_db_location" VALUES(10630,NULL,'Allison, PA',4364,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10631,NULL,'Allison, PA 15413',4364,222,NULL,44,5974,0);
INSERT INTO "django_geo_db_location" VALUES(10632,NULL,'Brier Hill, PA',4365,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10633,NULL,'Brier Hill, PA 15415',4365,222,NULL,44,5975,0);
INSERT INTO "django_geo_db_location" VALUES(10634,NULL,'Brownfield, PA',4366,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10635,NULL,'Brownfield, PA 15416',4366,222,NULL,44,5976,0);
INSERT INTO "django_geo_db_location" VALUES(10636,NULL,'Brownsville, PA',4367,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10637,NULL,'Brownsville, PA 15417',4367,222,NULL,44,5977,0);
INSERT INTO "django_geo_db_location" VALUES(10638,NULL,'California, PA',4368,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10639,NULL,'California, PA 15419',4368,222,NULL,44,5978,0);
INSERT INTO "django_geo_db_location" VALUES(10640,NULL,'Cardale, PA',4369,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10641,NULL,'Cardale, PA 15420',4369,222,NULL,44,5979,0);
INSERT INTO "django_geo_db_location" VALUES(10642,NULL,'Chalk Hill, PA',4370,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10643,NULL,'Chalk Hill, PA 15421',4370,222,NULL,44,5980,0);
INSERT INTO "django_geo_db_location" VALUES(10644,NULL,'Chestnut Ridge, PA',4371,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10645,NULL,'Chestnut Ridge, PA 15422',4371,222,NULL,44,5981,0);
INSERT INTO "django_geo_db_location" VALUES(10646,NULL,'Coal Center, PA',4372,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10647,NULL,'Coal Center, PA 15423',4372,222,NULL,44,5982,0);
INSERT INTO "django_geo_db_location" VALUES(10648,NULL,'Confluence, PA',4373,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10649,NULL,'Confluence, PA 15424',4373,222,NULL,44,5983,0);
INSERT INTO "django_geo_db_location" VALUES(10650,NULL,'Connellsville, PA',4374,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10651,NULL,'Connellsville, PA 15425',4374,222,NULL,44,5984,0);
INSERT INTO "django_geo_db_location" VALUES(10652,NULL,'Daisytown, PA',4375,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10653,NULL,'Daisytown, PA 15427',4375,222,NULL,44,5985,0);
INSERT INTO "django_geo_db_location" VALUES(10654,NULL,'Dawson, PA',4376,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10655,NULL,'Dawson, PA 15428',4376,222,NULL,44,5986,0);
INSERT INTO "django_geo_db_location" VALUES(10656,NULL,'Denbo, PA',4377,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10657,NULL,'Denbo, PA 15429',4377,222,NULL,44,5987,0);
INSERT INTO "django_geo_db_location" VALUES(10658,NULL,'Dickerson Run, PA',4378,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10659,NULL,'Dickerson Run, PA 15430',4378,222,NULL,44,5988,0);
INSERT INTO "django_geo_db_location" VALUES(10660,NULL,'Dunbar, PA',4379,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10661,NULL,'Dunbar, PA 15431',4379,222,NULL,44,5989,0);
INSERT INTO "django_geo_db_location" VALUES(10662,NULL,'Dunlevy, PA',4380,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10663,NULL,'Dunlevy, PA 15432',4380,222,NULL,44,5990,0);
INSERT INTO "django_geo_db_location" VALUES(10664,NULL,'East Millsboro, PA',4381,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10665,NULL,'East Millsboro, PA 15433',4381,222,NULL,44,5991,0);
INSERT INTO "django_geo_db_location" VALUES(10666,NULL,'Elco, PA',4382,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10667,NULL,'Elco, PA 15434',4382,222,NULL,44,5992,0);
INSERT INTO "django_geo_db_location" VALUES(10668,NULL,'Fairbank, PA',4383,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10669,NULL,'Fairbank, PA 15435',4383,222,NULL,44,5993,0);
INSERT INTO "django_geo_db_location" VALUES(10670,NULL,'Fairchance, PA',4384,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10671,NULL,'Fairchance, PA 15436',4384,222,NULL,44,5994,0);
INSERT INTO "django_geo_db_location" VALUES(10672,NULL,'Farmington, PA',4385,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10673,NULL,'Farmington, PA 15437',4385,222,NULL,44,5995,0);
INSERT INTO "django_geo_db_location" VALUES(10674,NULL,'Fayette City, PA',4386,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10675,NULL,'Fayette City, PA 15438',4386,222,NULL,44,5996,0);
INSERT INTO "django_geo_db_location" VALUES(10676,NULL,'Gans, PA',4387,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10677,NULL,'Gans, PA 15439',4387,222,NULL,44,5997,0);
INSERT INTO "django_geo_db_location" VALUES(10678,NULL,'Gibbon Glade, PA',4388,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10679,NULL,'Gibbon Glade, PA 15440',4388,222,NULL,44,5998,0);
INSERT INTO "django_geo_db_location" VALUES(10680,NULL,'Grindstone, PA',4389,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10681,NULL,'Grindstone, PA 15442',4389,222,NULL,44,5999,0);
INSERT INTO "django_geo_db_location" VALUES(10682,NULL,'Hibbs, PA',4390,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10683,NULL,'Hibbs, PA 15443',4390,222,NULL,44,6000,0);
INSERT INTO "django_geo_db_location" VALUES(10684,NULL,'Hiller, PA',4391,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10685,NULL,'Hiller, PA 15444',4391,222,NULL,44,6001,0);
INSERT INTO "django_geo_db_location" VALUES(10686,NULL,'Hopwood, PA',4392,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10687,NULL,'Hopwood, PA 15445',4392,222,NULL,44,6002,0);
INSERT INTO "django_geo_db_location" VALUES(10688,NULL,'Indian Head, PA',4393,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10689,NULL,'Indian Head, PA 15446',4393,222,NULL,44,6003,0);
INSERT INTO "django_geo_db_location" VALUES(10690,NULL,'Isabella, PA',4394,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10691,NULL,'Isabella, PA 15447',4394,222,NULL,44,6004,0);
INSERT INTO "django_geo_db_location" VALUES(10692,NULL,'Jacobs Creek, PA',4395,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10693,NULL,'Jacobs Creek, PA 15448',4395,222,NULL,44,6005,0);
INSERT INTO "django_geo_db_location" VALUES(10694,NULL,'Keisterville, PA',4396,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10695,NULL,'Keisterville, PA 15449',4396,222,NULL,44,6006,0);
INSERT INTO "django_geo_db_location" VALUES(10696,NULL,'La Belle, PA',4397,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10697,NULL,'La Belle, PA 15450',4397,222,NULL,44,6007,0);
INSERT INTO "django_geo_db_location" VALUES(10698,NULL,'Lake Lynn, PA',4398,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10699,NULL,'Lake Lynn, PA 15451',4398,222,NULL,44,6008,0);
INSERT INTO "django_geo_db_location" VALUES(10700,NULL,'Leckrone, PA',4399,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10701,NULL,'Leckrone, PA 15454',4399,222,NULL,44,6009,0);
INSERT INTO "django_geo_db_location" VALUES(10702,NULL,'Leisenring, PA',4400,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10703,NULL,'Leisenring, PA 15455',4400,222,NULL,44,6010,0);
INSERT INTO "django_geo_db_location" VALUES(10704,NULL,'Lemont Furnace, PA',4401,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10705,NULL,'Lemont Furnace, PA 15456',4401,222,NULL,44,6011,0);
INSERT INTO "django_geo_db_location" VALUES(10706,NULL,'McClellandtown, PA',4402,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10707,NULL,'McClellandtown, PA 15458',4402,222,NULL,44,6012,0);
INSERT INTO "django_geo_db_location" VALUES(10708,NULL,'Markleysburg, PA',4403,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10709,NULL,'Markleysburg, PA 15459',4403,222,NULL,44,6013,0);
INSERT INTO "django_geo_db_location" VALUES(10710,NULL,'Martin, PA',4404,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10711,NULL,'Martin, PA 15460',4404,222,NULL,44,6014,0);
INSERT INTO "django_geo_db_location" VALUES(10712,NULL,'Masontown, PA',4405,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10713,NULL,'Masontown, PA 15461',4405,222,NULL,44,6015,0);
INSERT INTO "django_geo_db_location" VALUES(10714,NULL,'Melcroft, PA',4406,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10715,NULL,'Melcroft, PA 15462',4406,222,NULL,44,6016,0);
INSERT INTO "django_geo_db_location" VALUES(10716,NULL,'Merrittstown, PA',4407,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10717,NULL,'Merrittstown, PA 15463',4407,222,NULL,44,6017,0);
INSERT INTO "django_geo_db_location" VALUES(10718,NULL,'Mill Run, PA',4408,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10719,NULL,'Mill Run, PA 15464',4408,222,NULL,44,6018,0);
INSERT INTO "django_geo_db_location" VALUES(10720,NULL,'Mount Braddock, PA',4409,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10721,NULL,'Mount Braddock, PA 15465',4409,222,NULL,44,6019,0);
INSERT INTO "django_geo_db_location" VALUES(10722,NULL,'Newell, PA',4410,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10723,NULL,'Newell, PA 15466',4410,222,NULL,44,6020,0);
INSERT INTO "django_geo_db_location" VALUES(10724,NULL,'New Geneva, PA',4411,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10725,NULL,'New Geneva, PA 15467',4411,222,NULL,44,6021,0);
INSERT INTO "django_geo_db_location" VALUES(10726,NULL,'New Salem, PA',4412,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10727,NULL,'New Salem, PA 15468',4412,222,NULL,44,6022,0);
INSERT INTO "django_geo_db_location" VALUES(10728,NULL,'Normalville, PA',4413,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10729,NULL,'Normalville, PA 15469',4413,222,NULL,44,6023,0);
INSERT INTO "django_geo_db_location" VALUES(10730,NULL,'Ohiopyle, PA',4414,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10731,NULL,'Ohiopyle, PA 15470',4414,222,NULL,44,6024,0);
INSERT INTO "django_geo_db_location" VALUES(10732,NULL,'German, PA',4415,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10733,NULL,'German, PA 15471',4415,222,NULL,44,6025,0);
INSERT INTO "django_geo_db_location" VALUES(10734,NULL,'Oliver, PA',4416,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10735,NULL,'Oliver, PA 15472',4416,222,NULL,44,6026,0);
INSERT INTO "django_geo_db_location" VALUES(10736,NULL,'Perryopolis, PA',4417,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10737,NULL,'Perryopolis, PA 15473',4417,222,NULL,44,6027,0);
INSERT INTO "django_geo_db_location" VALUES(10738,NULL,'Point Marion, PA',4418,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10739,NULL,'Point Marion, PA 15474',4418,222,NULL,44,6028,0);
INSERT INTO "django_geo_db_location" VALUES(10740,NULL,'Republic, PA',4419,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10741,NULL,'Republic, PA 15475',4419,222,NULL,44,6029,0);
INSERT INTO "django_geo_db_location" VALUES(10742,NULL,'Ronco, PA',4420,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10743,NULL,'Ronco, PA 15476',4420,222,NULL,44,6030,0);
INSERT INTO "django_geo_db_location" VALUES(10744,NULL,'Roscoe, PA',4421,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10745,NULL,'Roscoe, PA 15477',4421,222,NULL,44,6031,0);
INSERT INTO "django_geo_db_location" VALUES(10746,NULL,'Smithfield, PA',4422,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10747,NULL,'Smithfield, PA 15478',4422,222,NULL,44,6032,0);
INSERT INTO "django_geo_db_location" VALUES(10748,NULL,'Smithton, PA',4423,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10749,NULL,'Smithton, PA 15479',4423,222,NULL,44,6033,0);
INSERT INTO "django_geo_db_location" VALUES(10750,NULL,'Smock, PA',4424,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10751,NULL,'Smock, PA 15480',4424,222,NULL,44,6034,0);
INSERT INTO "django_geo_db_location" VALUES(10752,NULL,'Star Junction, PA',4425,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10753,NULL,'Star Junction, PA 15482',4425,222,NULL,44,6035,0);
INSERT INTO "django_geo_db_location" VALUES(10754,NULL,'Stockdale, PA',4426,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10755,NULL,'Stockdale, PA 15483',4426,222,NULL,44,6036,0);
INSERT INTO "django_geo_db_location" VALUES(10756,NULL,'Uledi, PA',4427,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10757,NULL,'Uledi, PA 15484',4427,222,NULL,44,6037,0);
INSERT INTO "django_geo_db_location" VALUES(10758,NULL,'Ursina, PA',4428,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10759,NULL,'Ursina, PA 15485',4428,222,NULL,44,6038,0);
INSERT INTO "django_geo_db_location" VALUES(10760,NULL,'Vanderbilt, PA',4429,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10761,NULL,'Vanderbilt, PA 15486',4429,222,NULL,44,6039,0);
INSERT INTO "django_geo_db_location" VALUES(10762,NULL,'Waltersburg, PA',4430,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10763,NULL,'Waltersburg, PA 15488',4430,222,NULL,44,6040,0);
INSERT INTO "django_geo_db_location" VALUES(10764,NULL,'West Leisenring, PA',4431,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10765,NULL,'West Leisenring, PA 15489',4431,222,NULL,44,6041,0);
INSERT INTO "django_geo_db_location" VALUES(10766,NULL,'White, PA',4432,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10767,NULL,'White, PA 15490',4432,222,NULL,44,6042,0);
INSERT INTO "django_geo_db_location" VALUES(10768,NULL,'Wickhaven, PA',4433,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10769,NULL,'Wickhaven, PA 15492',4433,222,NULL,44,6043,0);
INSERT INTO "django_geo_db_location" VALUES(10770,NULL,'Perry, PA',4434,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10771,NULL,'Perry, PA 15493',4434,222,NULL,44,6044,0);
INSERT INTO "django_geo_db_location" VALUES(10772,NULL,'Somerset, PA',4435,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10773,NULL,'Somerset, PA 15501',4435,222,NULL,44,6045,0);
INSERT INTO "django_geo_db_location" VALUES(10774,NULL,'Hidden Valley, PA',4436,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10775,NULL,'Hidden Valley, PA 15502',4436,222,NULL,44,6046,0);
INSERT INTO "django_geo_db_location" VALUES(10776,NULL,'Somerset, PA 15510',4435,222,NULL,44,6047,0);
INSERT INTO "django_geo_db_location" VALUES(10777,NULL,'Acosta, PA',4437,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10778,NULL,'Acosta, PA 15520',4437,222,NULL,44,6048,0);
INSERT INTO "django_geo_db_location" VALUES(10779,NULL,'Alum Bank, PA',4438,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10780,NULL,'Alum Bank, PA 15521',4438,222,NULL,44,6049,0);
INSERT INTO "django_geo_db_location" VALUES(10781,NULL,'Bedford, PA',4439,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10782,NULL,'Bedford, PA 15522',4439,222,NULL,44,6050,0);
INSERT INTO "django_geo_db_location" VALUES(10783,NULL,'Berlin, PA',4440,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10784,NULL,'Berlin, PA 15530',4440,222,NULL,44,6051,0);
INSERT INTO "django_geo_db_location" VALUES(10785,NULL,'Boswell, PA',4441,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10786,NULL,'Boswell, PA 15531',4441,222,NULL,44,6052,0);
INSERT INTO "django_geo_db_location" VALUES(10787,NULL,'Boynton, PA',4442,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10788,NULL,'Boynton, PA 15532',4442,222,NULL,44,6053,0);
INSERT INTO "django_geo_db_location" VALUES(10789,NULL,'Breezewood, PA',4443,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10790,NULL,'Breezewood, PA 15533',4443,222,NULL,44,6054,0);
INSERT INTO "django_geo_db_location" VALUES(10791,NULL,'Buffalo Mills, PA',4444,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10792,NULL,'Buffalo Mills, PA 15534',4444,222,NULL,44,6055,0);
INSERT INTO "django_geo_db_location" VALUES(10793,NULL,'Clearville, PA',4445,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10794,NULL,'Clearville, PA 15535',4445,222,NULL,44,6056,0);
INSERT INTO "django_geo_db_location" VALUES(10795,NULL,'Crystal Spring, PA',4446,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10796,NULL,'Crystal Spring, PA 15536',4446,222,NULL,44,6057,0);
INSERT INTO "django_geo_db_location" VALUES(10797,NULL,'Everett, PA',4447,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10798,NULL,'Everett, PA 15537',4447,222,NULL,44,6058,0);
INSERT INTO "django_geo_db_location" VALUES(10799,NULL,'Fairhope, PA',4448,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10800,NULL,'Fairhope, PA 15538',4448,222,NULL,44,6059,0);
INSERT INTO "django_geo_db_location" VALUES(10801,NULL,'Fishertown, PA',4449,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10802,NULL,'Fishertown, PA 15539',4449,222,NULL,44,6060,0);
INSERT INTO "django_geo_db_location" VALUES(10803,NULL,'Fort Hill, PA',4450,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10804,NULL,'Fort Hill, PA 15540',4450,222,NULL,44,6061,0);
INSERT INTO "django_geo_db_location" VALUES(10805,NULL,'Friedens, PA',4451,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10806,NULL,'Friedens, PA 15541',4451,222,NULL,44,6062,0);
INSERT INTO "django_geo_db_location" VALUES(10807,NULL,'Garrett, PA',4452,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10808,NULL,'Garrett, PA 15542',4452,222,NULL,44,6063,0);
INSERT INTO "django_geo_db_location" VALUES(10809,NULL,'Gray, PA',4453,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10810,NULL,'Gray, PA 15544',4453,222,NULL,44,6064,0);
INSERT INTO "django_geo_db_location" VALUES(10811,NULL,'Hyndman, PA',4454,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10812,NULL,'Hyndman, PA 15545',4454,222,NULL,44,6065,0);
INSERT INTO "django_geo_db_location" VALUES(10813,NULL,'Jenners, PA',4455,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10814,NULL,'Jenners, PA 15546',4455,222,NULL,44,6066,0);
INSERT INTO "django_geo_db_location" VALUES(10815,NULL,'Jennerstown, PA',4456,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10816,NULL,'Jennerstown, PA 15547',4456,222,NULL,44,6067,0);
INSERT INTO "django_geo_db_location" VALUES(10817,NULL,'Kantner, PA',4457,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10818,NULL,'Kantner, PA 15548',4457,222,NULL,44,6068,0);
INSERT INTO "django_geo_db_location" VALUES(10819,NULL,'Listie, PA',4458,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10820,NULL,'Listie, PA 15549',4458,222,NULL,44,6069,0);
INSERT INTO "django_geo_db_location" VALUES(10821,NULL,'Manns Choice, PA',4459,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10822,NULL,'Manns Choice, PA 15550',4459,222,NULL,44,6070,0);
INSERT INTO "django_geo_db_location" VALUES(10823,NULL,'Markleton, PA',4460,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10824,NULL,'Markleton, PA 15551',4460,222,NULL,44,6071,0);
INSERT INTO "django_geo_db_location" VALUES(10825,NULL,'Meyersdale, PA',4461,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10826,NULL,'Meyersdale, PA 15552',4461,222,NULL,44,6072,0);
INSERT INTO "django_geo_db_location" VALUES(10827,NULL,'New Baltimore, PA',4462,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10828,NULL,'New Baltimore, PA 15553',4462,222,NULL,44,6073,0);
INSERT INTO "django_geo_db_location" VALUES(10829,NULL,'New Paris, PA',4463,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10830,NULL,'New Paris, PA 15554',4463,222,NULL,44,6074,0);
INSERT INTO "django_geo_db_location" VALUES(10831,NULL,'Quecreek, PA',4464,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10832,NULL,'Quecreek, PA 15555',4464,222,NULL,44,6075,0);
INSERT INTO "django_geo_db_location" VALUES(10833,NULL,'Rockwood, PA',4465,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10834,NULL,'Rockwood, PA 15557',4465,222,NULL,44,6076,0);
INSERT INTO "django_geo_db_location" VALUES(10835,NULL,'Salisbury, PA',4466,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10836,NULL,'Salisbury, PA 15558',4466,222,NULL,44,6077,0);
INSERT INTO "django_geo_db_location" VALUES(10837,NULL,'Schellsburg, PA',4467,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10838,NULL,'Schellsburg, PA 15559',4467,222,NULL,44,6078,0);
INSERT INTO "django_geo_db_location" VALUES(10839,NULL,'Shanksville, PA',4468,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10840,NULL,'Shanksville, PA 15560',4468,222,NULL,44,6079,0);
INSERT INTO "django_geo_db_location" VALUES(10841,NULL,'Sipesville, PA',4469,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10842,NULL,'Sipesville, PA 15561',4469,222,NULL,44,6080,0);
INSERT INTO "django_geo_db_location" VALUES(10843,NULL,'Springs, PA',4470,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10844,NULL,'Springs, PA 15562',4470,222,NULL,44,6081,0);
INSERT INTO "django_geo_db_location" VALUES(10845,NULL,'Stoystown, PA',4471,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10846,NULL,'Stoystown, PA 15563',4471,222,NULL,44,6082,0);
INSERT INTO "django_geo_db_location" VALUES(10847,NULL,'Wellersburg, PA',4472,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10848,NULL,'Wellersburg, PA 15564',4472,222,NULL,44,6083,0);
INSERT INTO "django_geo_db_location" VALUES(10849,NULL,'West Salisbury, PA',4473,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10850,NULL,'West Salisbury, PA 15565',4473,222,NULL,44,6084,0);
INSERT INTO "django_geo_db_location" VALUES(10851,NULL,'Greensburg, PA',4474,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10852,NULL,'Greensburg, PA 15601',4474,222,NULL,44,6085,0);
INSERT INTO "django_geo_db_location" VALUES(10853,NULL,'Greensburg, PA 15605',4474,222,NULL,44,6086,0);
INSERT INTO "django_geo_db_location" VALUES(10854,NULL,'Greensburg, PA 15606',4474,222,NULL,44,6087,0);
INSERT INTO "django_geo_db_location" VALUES(10855,NULL,'Acme, PA',4475,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10856,NULL,'Acme, PA 15610',4475,222,NULL,44,6088,0);
INSERT INTO "django_geo_db_location" VALUES(10857,NULL,'Adamsburg, PA',4476,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10858,NULL,'Adamsburg, PA 15611',4476,222,NULL,44,6089,0);
INSERT INTO "django_geo_db_location" VALUES(10859,NULL,'Alverton, PA',4477,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10860,NULL,'Alverton, PA 15612',4477,222,NULL,44,6090,0);
INSERT INTO "django_geo_db_location" VALUES(10861,NULL,'Apollo, PA',4478,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10862,NULL,'Apollo, PA 15613',4478,222,NULL,44,6091,0);
INSERT INTO "django_geo_db_location" VALUES(10863,NULL,'Ardara, PA',4479,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10864,NULL,'Ardara, PA 15615',4479,222,NULL,44,6092,0);
INSERT INTO "django_geo_db_location" VALUES(10865,NULL,'Armbrust, PA',4480,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10866,NULL,'Armbrust, PA 15616',4480,222,NULL,44,6093,0);
INSERT INTO "django_geo_db_location" VALUES(10867,NULL,'Arona, PA',4481,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10868,NULL,'Arona, PA 15617',4481,222,NULL,44,6094,0);
INSERT INTO "django_geo_db_location" VALUES(10869,NULL,'Avonmore, PA',4482,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10870,NULL,'Avonmore, PA 15618',4482,222,NULL,44,6095,0);
INSERT INTO "django_geo_db_location" VALUES(10871,NULL,'Bovard, PA',4483,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10872,NULL,'Bovard, PA 15619',4483,222,NULL,44,6096,0);
INSERT INTO "django_geo_db_location" VALUES(10873,NULL,'Bradenville, PA',4484,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10874,NULL,'Bradenville, PA 15620',4484,222,NULL,44,6097,0);
INSERT INTO "django_geo_db_location" VALUES(10875,NULL,'Calumet, PA',4485,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10876,NULL,'Calumet, PA 15621',4485,222,NULL,44,6098,0);
INSERT INTO "django_geo_db_location" VALUES(10877,NULL,'Champion, PA',4486,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10878,NULL,'Champion, PA 15622',4486,222,NULL,44,6099,0);
INSERT INTO "django_geo_db_location" VALUES(10879,NULL,'Claridge, PA',4487,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10880,NULL,'Claridge, PA 15623',4487,222,NULL,44,6100,0);
INSERT INTO "django_geo_db_location" VALUES(10881,NULL,'Crabtree, PA',4488,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10882,NULL,'Crabtree, PA 15624',4488,222,NULL,44,6101,0);
INSERT INTO "django_geo_db_location" VALUES(10883,NULL,'Darragh, PA',4489,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10884,NULL,'Darragh, PA 15625',4489,222,NULL,44,6102,0);
INSERT INTO "django_geo_db_location" VALUES(10885,NULL,'Delmont, PA',4490,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10886,NULL,'Delmont, PA 15626',4490,222,NULL,44,6103,0);
INSERT INTO "django_geo_db_location" VALUES(10887,NULL,'Derry, PA',4491,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10888,NULL,'Derry, PA 15627',4491,222,NULL,44,6104,0);
INSERT INTO "django_geo_db_location" VALUES(10889,NULL,'Donegal, PA',4492,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10890,NULL,'Donegal, PA 15628',4492,222,NULL,44,6105,0);
INSERT INTO "django_geo_db_location" VALUES(10891,NULL,'East Vandergrift, PA',4493,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10892,NULL,'East Vandergrift, PA 15629',4493,222,NULL,44,6106,0);
INSERT INTO "django_geo_db_location" VALUES(10893,NULL,'Edmon, PA',4494,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10894,NULL,'Edmon, PA 15630',4494,222,NULL,44,6107,0);
INSERT INTO "django_geo_db_location" VALUES(10895,NULL,'Everson, PA',4495,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10896,NULL,'Everson, PA 15631',4495,222,NULL,44,6108,0);
INSERT INTO "django_geo_db_location" VALUES(10897,NULL,'Export, PA',4496,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10898,NULL,'Export, PA 15632',4496,222,NULL,44,6109,0);
INSERT INTO "django_geo_db_location" VALUES(10899,NULL,'Forbes Road, PA',4497,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10900,NULL,'Forbes Road, PA 15633',4497,222,NULL,44,6110,0);
INSERT INTO "django_geo_db_location" VALUES(10901,NULL,'Grapeville, PA',4498,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10902,NULL,'Grapeville, PA 15634',4498,222,NULL,44,6111,0);
INSERT INTO "django_geo_db_location" VALUES(10903,NULL,'Hannastown, PA',4499,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10904,NULL,'Hannastown, PA 15635',4499,222,NULL,44,6112,0);
INSERT INTO "django_geo_db_location" VALUES(10905,NULL,'Harrison City, PA',4500,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10906,NULL,'Harrison City, PA 15636',4500,222,NULL,44,6113,0);
INSERT INTO "django_geo_db_location" VALUES(10907,NULL,'Herminie, PA',4501,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10908,NULL,'Herminie, PA 15637',4501,222,NULL,44,6114,0);
INSERT INTO "django_geo_db_location" VALUES(10909,NULL,'Hostetter, PA',4502,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10910,NULL,'Hostetter, PA 15638',4502,222,NULL,44,6115,0);
INSERT INTO "django_geo_db_location" VALUES(10911,NULL,'Hunker, PA',4503,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10912,NULL,'Hunker, PA 15639',4503,222,NULL,44,6116,0);
INSERT INTO "django_geo_db_location" VALUES(10913,NULL,'Hutchinson, PA',4504,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10914,NULL,'Hutchinson, PA 15640',4504,222,NULL,44,6117,0);
INSERT INTO "django_geo_db_location" VALUES(10915,NULL,'Hyde Park, PA',4505,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10916,NULL,'Hyde Park, PA 15641',4505,222,NULL,44,6118,0);
INSERT INTO "django_geo_db_location" VALUES(10917,NULL,'Irwin, PA',4506,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10918,NULL,'Irwin, PA 15642',4506,222,NULL,44,6119,0);
INSERT INTO "django_geo_db_location" VALUES(10919,NULL,'Hempfield, PA',4507,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10920,NULL,'Hempfield, PA 15643',4507,222,NULL,44,6120,0);
INSERT INTO "django_geo_db_location" VALUES(10921,NULL,'Jeannette, PA',4508,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10922,NULL,'Jeannette, PA 15644',4508,222,NULL,44,6121,0);
INSERT INTO "django_geo_db_location" VALUES(10923,NULL,'Jones Mills, PA',4509,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10924,NULL,'Jones Mills, PA 15646',4509,222,NULL,44,6122,0);
INSERT INTO "django_geo_db_location" VALUES(10925,NULL,'Larimer, PA',4510,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10926,NULL,'Larimer, PA 15647',4510,222,NULL,44,6123,0);
INSERT INTO "django_geo_db_location" VALUES(10927,NULL,'Latrobe, PA',4511,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10928,NULL,'Latrobe, PA 15650',4511,222,NULL,44,6124,0);
INSERT INTO "django_geo_db_location" VALUES(10929,NULL,'Laughlintown, PA',4512,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10930,NULL,'Laughlintown, PA 15655',4512,222,NULL,44,6125,0);
INSERT INTO "django_geo_db_location" VALUES(10931,NULL,'Leechburg, PA',4513,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10932,NULL,'Leechburg, PA 15656',4513,222,NULL,44,6126,0);
INSERT INTO "django_geo_db_location" VALUES(10933,NULL,'Ligonier, PA',4514,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10934,NULL,'Ligonier, PA 15658',4514,222,NULL,44,6127,0);
INSERT INTO "django_geo_db_location" VALUES(10935,NULL,'Lowber, PA',4515,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10936,NULL,'Lowber, PA 15660',4515,222,NULL,44,6128,0);
INSERT INTO "django_geo_db_location" VALUES(10937,NULL,'Loyalhanna, PA',4516,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10938,NULL,'Loyalhanna, PA 15661',4516,222,NULL,44,6129,0);
INSERT INTO "django_geo_db_location" VALUES(10939,NULL,'Luxor, PA',4517,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10940,NULL,'Luxor, PA 15662',4517,222,NULL,44,6130,0);
INSERT INTO "django_geo_db_location" VALUES(10941,NULL,'Madison, PA',4518,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10942,NULL,'Madison, PA 15663',4518,222,NULL,44,6131,0);
INSERT INTO "django_geo_db_location" VALUES(10943,NULL,'Mammoth, PA',4519,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10944,NULL,'Mammoth, PA 15664',4519,222,NULL,44,6132,0);
INSERT INTO "django_geo_db_location" VALUES(10945,NULL,'Manor, PA',4520,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10946,NULL,'Manor, PA 15665',4520,222,NULL,44,6133,0);
INSERT INTO "django_geo_db_location" VALUES(10947,NULL,'Mount Pleasant, PA',4521,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10948,NULL,'Mount Pleasant, PA 15666',4521,222,NULL,44,6134,0);
INSERT INTO "django_geo_db_location" VALUES(10949,NULL,'Murrysville, PA',4522,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10950,NULL,'Murrysville, PA 15668',4522,222,NULL,44,6135,0);
INSERT INTO "django_geo_db_location" VALUES(10951,NULL,'New Alexandria, PA',4523,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10952,NULL,'New Alexandria, PA 15670',4523,222,NULL,44,6136,0);
INSERT INTO "django_geo_db_location" VALUES(10953,NULL,'New Derry, PA',4524,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10954,NULL,'New Derry, PA 15671',4524,222,NULL,44,6137,0);
INSERT INTO "django_geo_db_location" VALUES(10955,NULL,'New Stanton, PA',4525,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10956,NULL,'New Stanton, PA 15672',4525,222,NULL,44,6138,0);
INSERT INTO "django_geo_db_location" VALUES(10957,NULL,'North Apollo, PA 15673',4299,222,NULL,44,6139,0);
INSERT INTO "django_geo_db_location" VALUES(10958,NULL,'Norvelt, PA',4526,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10959,NULL,'Norvelt, PA 15674',4526,222,NULL,44,6140,0);
INSERT INTO "django_geo_db_location" VALUES(10960,NULL,'Penn, PA',4527,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10961,NULL,'Penn, PA 15675',4527,222,NULL,44,6141,0);
INSERT INTO "django_geo_db_location" VALUES(10962,NULL,'Pleasant Unity, PA',4528,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10963,NULL,'Pleasant Unity, PA 15676',4528,222,NULL,44,6142,0);
INSERT INTO "django_geo_db_location" VALUES(10964,NULL,'Rector, PA',4529,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10965,NULL,'Rector, PA 15677',4529,222,NULL,44,6143,0);
INSERT INTO "django_geo_db_location" VALUES(10966,NULL,'Rillton, PA',4530,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10967,NULL,'Rillton, PA 15678',4530,222,NULL,44,6144,0);
INSERT INTO "django_geo_db_location" VALUES(10968,NULL,'Ruffs Dale, PA',4531,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10969,NULL,'Ruffs Dale, PA 15679',4531,222,NULL,44,6145,0);
INSERT INTO "django_geo_db_location" VALUES(10970,NULL,'Salina, PA',4532,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10971,NULL,'Salina, PA 15680',4532,222,NULL,44,6146,0);
INSERT INTO "django_geo_db_location" VALUES(10972,NULL,'Saltsburg, PA',4533,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10973,NULL,'Saltsburg, PA 15681',4533,222,NULL,44,6147,0);
INSERT INTO "django_geo_db_location" VALUES(10974,NULL,'Schenley, PA',4534,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10975,NULL,'Schenley, PA 15682',4534,222,NULL,44,6148,0);
INSERT INTO "django_geo_db_location" VALUES(10976,NULL,'Scottdale, PA',4535,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10977,NULL,'Scottdale, PA 15683',4535,222,NULL,44,6149,0);
INSERT INTO "django_geo_db_location" VALUES(10978,NULL,'Slickville, PA',4536,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10979,NULL,'Slickville, PA 15684',4536,222,NULL,44,6150,0);
INSERT INTO "django_geo_db_location" VALUES(10980,NULL,'Southwest, PA',4537,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10981,NULL,'Southwest, PA 15685',4537,222,NULL,44,6151,0);
INSERT INTO "django_geo_db_location" VALUES(10982,NULL,'Spring Church, PA',4538,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10983,NULL,'Spring Church, PA 15686',4538,222,NULL,44,6152,0);
INSERT INTO "django_geo_db_location" VALUES(10984,NULL,'Stahlstown, PA',4539,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10985,NULL,'Stahlstown, PA 15687',4539,222,NULL,44,6153,0);
INSERT INTO "django_geo_db_location" VALUES(10986,NULL,'Tarrs, PA',4540,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10987,NULL,'Tarrs, PA 15688',4540,222,NULL,44,6154,0);
INSERT INTO "django_geo_db_location" VALUES(10988,NULL,'United, PA',4541,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10989,NULL,'United, PA 15689',4541,222,NULL,44,6155,0);
INSERT INTO "django_geo_db_location" VALUES(10990,NULL,'Vandergrift, PA',4542,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10991,NULL,'Vandergrift, PA 15690',4542,222,NULL,44,6156,0);
INSERT INTO "django_geo_db_location" VALUES(10992,NULL,'Wendel, PA',4543,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10993,NULL,'Wendel, PA 15691',4543,222,NULL,44,6157,0);
INSERT INTO "django_geo_db_location" VALUES(10994,NULL,'Westmoreland City, PA',4544,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10995,NULL,'Westmoreland City, PA 15692',4544,222,NULL,44,6158,0);
INSERT INTO "django_geo_db_location" VALUES(10996,NULL,'Whitney, PA',4545,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10997,NULL,'Whitney, PA 15693',4545,222,NULL,44,6159,0);
INSERT INTO "django_geo_db_location" VALUES(10998,NULL,'Wyano, PA',4546,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(10999,NULL,'Wyano, PA 15695',4546,222,NULL,44,6160,0);
INSERT INTO "django_geo_db_location" VALUES(11000,NULL,'Youngstown, PA',4547,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11001,NULL,'Youngstown, PA 15696',4547,222,NULL,44,6161,0);
INSERT INTO "django_geo_db_location" VALUES(11002,NULL,'Youngwood, PA',4548,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11003,NULL,'Youngwood, PA 15697',4548,222,NULL,44,6162,0);
INSERT INTO "django_geo_db_location" VALUES(11004,NULL,'Yukon, PA',4549,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11005,NULL,'Yukon, PA 15698',4549,222,NULL,44,6163,0);
INSERT INTO "django_geo_db_location" VALUES(11006,NULL,'Indiana, PA',4550,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11007,NULL,'Indiana, PA 15701',4550,222,NULL,44,6164,0);
INSERT INTO "django_geo_db_location" VALUES(11008,NULL,'Indiana, PA 15705',4550,222,NULL,44,6165,0);
INSERT INTO "django_geo_db_location" VALUES(11009,NULL,'Alverda, PA',4551,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11010,NULL,'Alverda, PA 15710',4551,222,NULL,44,6166,0);
INSERT INTO "django_geo_db_location" VALUES(11011,NULL,'Anita, PA',4552,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11012,NULL,'Anita, PA 15711',4552,222,NULL,44,6167,0);
INSERT INTO "django_geo_db_location" VALUES(11013,NULL,'Arcadia, PA',4553,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11014,NULL,'Arcadia, PA 15712',4553,222,NULL,44,6168,0);
INSERT INTO "django_geo_db_location" VALUES(11015,NULL,'Aultman, PA',4554,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11016,NULL,'Aultman, PA 15713',4554,222,NULL,44,6169,0);
INSERT INTO "django_geo_db_location" VALUES(11017,NULL,'Barnesboro, PA',4555,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11018,NULL,'Barnesboro, PA 15714',4555,222,NULL,44,6170,0);
INSERT INTO "django_geo_db_location" VALUES(11019,NULL,'Big Run, PA',4556,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11020,NULL,'Big Run, PA 15715',4556,222,NULL,44,6171,0);
INSERT INTO "django_geo_db_location" VALUES(11021,NULL,'Black Lick, PA',4557,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11022,NULL,'Black Lick, PA 15716',4557,222,NULL,44,6172,0);
INSERT INTO "django_geo_db_location" VALUES(11023,NULL,'Blairsville, PA',4558,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11024,NULL,'Blairsville, PA 15717',4558,222,NULL,44,6173,0);
INSERT INTO "django_geo_db_location" VALUES(11025,NULL,'Brush Valley, PA',4559,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11026,NULL,'Brush Valley, PA 15720',4559,222,NULL,44,6174,0);
INSERT INTO "django_geo_db_location" VALUES(11027,NULL,'Burnside, PA',4560,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11028,NULL,'Burnside, PA 15721',4560,222,NULL,44,6175,0);
INSERT INTO "django_geo_db_location" VALUES(11029,NULL,'Carrolltown, PA',4561,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11030,NULL,'Carrolltown, PA 15722',4561,222,NULL,44,6176,0);
INSERT INTO "django_geo_db_location" VALUES(11031,NULL,'Chambersville, PA',4562,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11032,NULL,'Chambersville, PA 15723',4562,222,NULL,44,6177,0);
INSERT INTO "django_geo_db_location" VALUES(11033,NULL,'Cherry Tree, PA',4563,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11034,NULL,'Cherry Tree, PA 15724',4563,222,NULL,44,6178,0);
INSERT INTO "django_geo_db_location" VALUES(11035,NULL,'Clarksburg, PA',4564,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11036,NULL,'Clarksburg, PA 15725',4564,222,NULL,44,6179,0);
INSERT INTO "django_geo_db_location" VALUES(11037,NULL,'Clune, PA',4565,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11038,NULL,'Clune, PA 15727',4565,222,NULL,44,6180,0);
INSERT INTO "django_geo_db_location" VALUES(11039,NULL,'Clymer, PA',4566,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11040,NULL,'Clymer, PA 15728',4566,222,NULL,44,6181,0);
INSERT INTO "django_geo_db_location" VALUES(11041,NULL,'Commodore, PA',4567,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11042,NULL,'Commodore, PA 15729',4567,222,NULL,44,6182,0);
INSERT INTO "django_geo_db_location" VALUES(11043,NULL,'Coolspring, PA',4568,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11044,NULL,'Coolspring, PA 15730',4568,222,NULL,44,6183,0);
INSERT INTO "django_geo_db_location" VALUES(11045,NULL,'Coral, PA',4569,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11046,NULL,'Coral, PA 15731',4569,222,NULL,44,6184,0);
INSERT INTO "django_geo_db_location" VALUES(11047,NULL,'Creekside, PA',4570,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11048,NULL,'Creekside, PA 15732',4570,222,NULL,44,6185,0);
INSERT INTO "django_geo_db_location" VALUES(11049,NULL,'De Lancey, PA',4571,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11050,NULL,'De Lancey, PA 15733',4571,222,NULL,44,6186,0);
INSERT INTO "django_geo_db_location" VALUES(11051,NULL,'Dixonville, PA',4572,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11052,NULL,'Dixonville, PA 15734',4572,222,NULL,44,6187,0);
INSERT INTO "django_geo_db_location" VALUES(11053,NULL,'Elderton, PA',4573,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11054,NULL,'Elderton, PA 15736',4573,222,NULL,44,6188,0);
INSERT INTO "django_geo_db_location" VALUES(11055,NULL,'Elmora, PA',4574,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11056,NULL,'Elmora, PA 15737',4574,222,NULL,44,6189,0);
INSERT INTO "django_geo_db_location" VALUES(11057,NULL,'Emeigh, PA',4575,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11058,NULL,'Emeigh, PA 15738',4575,222,NULL,44,6190,0);
INSERT INTO "django_geo_db_location" VALUES(11059,NULL,'Ernest, PA',4576,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11060,NULL,'Ernest, PA 15739',4576,222,NULL,44,6191,0);
INSERT INTO "django_geo_db_location" VALUES(11061,NULL,'Frostburg, PA',4577,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11062,NULL,'Frostburg, PA 15740',4577,222,NULL,44,6192,0);
INSERT INTO "django_geo_db_location" VALUES(11063,NULL,'Gipsy, PA',4578,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11064,NULL,'Gipsy, PA 15741',4578,222,NULL,44,6193,0);
INSERT INTO "django_geo_db_location" VALUES(11065,NULL,'Glen Campbell, PA',4579,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11066,NULL,'Glen Campbell, PA 15742',4579,222,NULL,44,6194,0);
INSERT INTO "django_geo_db_location" VALUES(11067,NULL,'Hamilton, PA',4580,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11068,NULL,'Hamilton, PA 15744',4580,222,NULL,44,6195,0);
INSERT INTO "django_geo_db_location" VALUES(11069,NULL,'Heilwood, PA',4581,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11070,NULL,'Heilwood, PA 15745',4581,222,NULL,44,6196,0);
INSERT INTO "django_geo_db_location" VALUES(11071,NULL,'Hillsdale, PA',4582,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11072,NULL,'Hillsdale, PA 15746',4582,222,NULL,44,6197,0);
INSERT INTO "django_geo_db_location" VALUES(11073,NULL,'Home, PA',4583,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11074,NULL,'Home, PA 15747',4583,222,NULL,44,6198,0);
INSERT INTO "django_geo_db_location" VALUES(11075,NULL,'Homer City, PA',4584,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11076,NULL,'Homer City, PA 15748',4584,222,NULL,44,6199,0);
INSERT INTO "django_geo_db_location" VALUES(11077,NULL,'Josephine, PA',4585,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11078,NULL,'Josephine, PA 15750',4585,222,NULL,44,6200,0);
INSERT INTO "django_geo_db_location" VALUES(11079,NULL,'Juneau, PA',4586,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11080,NULL,'Juneau, PA 15751',4586,222,NULL,44,6201,0);
INSERT INTO "django_geo_db_location" VALUES(11081,NULL,'Kent, PA',4587,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11082,NULL,'Kent, PA 15752',4587,222,NULL,44,6202,0);
INSERT INTO "django_geo_db_location" VALUES(11083,NULL,'La Jose, PA',4588,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11084,NULL,'La Jose, PA 15753',4588,222,NULL,44,6203,0);
INSERT INTO "django_geo_db_location" VALUES(11085,NULL,'Lucernemines, PA',4589,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11086,NULL,'Lucernemines, PA 15754',4589,222,NULL,44,6204,0);
INSERT INTO "django_geo_db_location" VALUES(11087,NULL,'McIntyre, PA',4590,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11088,NULL,'McIntyre, PA 15756',4590,222,NULL,44,6205,0);
INSERT INTO "django_geo_db_location" VALUES(11089,NULL,'Mahaffey, PA',4591,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11090,NULL,'Mahaffey, PA 15757',4591,222,NULL,44,6206,0);
INSERT INTO "django_geo_db_location" VALUES(11091,NULL,'Marchand, PA',4592,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11092,NULL,'Marchand, PA 15758',4592,222,NULL,44,6207,0);
INSERT INTO "django_geo_db_location" VALUES(11093,NULL,'Marion Center, PA',4593,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11094,NULL,'Marion Center, PA 15759',4593,222,NULL,44,6208,0);
INSERT INTO "django_geo_db_location" VALUES(11095,NULL,'Marsteller, PA',4594,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11096,NULL,'Marsteller, PA 15760',4594,222,NULL,44,6209,0);
INSERT INTO "django_geo_db_location" VALUES(11097,NULL,'Mentcle, PA',4595,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11098,NULL,'Mentcle, PA 15761',4595,222,NULL,44,6210,0);
INSERT INTO "django_geo_db_location" VALUES(11099,NULL,'Nicktown, PA',4596,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11100,NULL,'Nicktown, PA 15762',4596,222,NULL,44,6211,0);
INSERT INTO "django_geo_db_location" VALUES(11101,NULL,'Northpoint, PA',4597,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11102,NULL,'Northpoint, PA 15763',4597,222,NULL,44,6212,0);
INSERT INTO "django_geo_db_location" VALUES(11103,NULL,'Oliveburg, PA',4598,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11104,NULL,'Oliveburg, PA 15764',4598,222,NULL,44,6213,0);
INSERT INTO "django_geo_db_location" VALUES(11105,NULL,'Penn Run, PA',4599,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11106,NULL,'Penn Run, PA 15765',4599,222,NULL,44,6214,0);
INSERT INTO "django_geo_db_location" VALUES(11107,NULL,'Punxsutawney, PA',4600,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11108,NULL,'Punxsutawney, PA 15767',4600,222,NULL,44,6215,0);
INSERT INTO "django_geo_db_location" VALUES(11109,NULL,'Ringgold, PA',4601,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11110,NULL,'Ringgold, PA 15770',4601,222,NULL,44,6216,0);
INSERT INTO "django_geo_db_location" VALUES(11111,NULL,'Rochester Mills, PA',4602,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11112,NULL,'Rochester Mills, PA 15771',4602,222,NULL,44,6217,0);
INSERT INTO "django_geo_db_location" VALUES(11113,NULL,'Rossiter, PA',4603,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11114,NULL,'Rossiter, PA 15772',4603,222,NULL,44,6218,0);
INSERT INTO "django_geo_db_location" VALUES(11115,NULL,'Saint Benedict, PA',4604,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11116,NULL,'Saint Benedict, PA 15773',4604,222,NULL,44,6219,0);
INSERT INTO "django_geo_db_location" VALUES(11117,NULL,'Shelocta, PA',4605,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11118,NULL,'Shelocta, PA 15774',4605,222,NULL,44,6220,0);
INSERT INTO "django_geo_db_location" VALUES(11119,NULL,'Spangler, PA',4606,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11120,NULL,'Spangler, PA 15775',4606,222,NULL,44,6221,0);
INSERT INTO "django_geo_db_location" VALUES(11121,NULL,'Sprankle Mills, PA',4607,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11122,NULL,'Sprankle Mills, PA 15776',4607,222,NULL,44,6222,0);
INSERT INTO "django_geo_db_location" VALUES(11123,NULL,'Starford, PA',4608,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11124,NULL,'Starford, PA 15777',4608,222,NULL,44,6223,0);
INSERT INTO "django_geo_db_location" VALUES(11125,NULL,'Timblin, PA',4609,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11126,NULL,'Timblin, PA 15778',4609,222,NULL,44,6224,0);
INSERT INTO "django_geo_db_location" VALUES(11127,NULL,'Torrance, PA',4610,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11128,NULL,'Torrance, PA 15779',4610,222,NULL,44,6225,0);
INSERT INTO "django_geo_db_location" VALUES(11129,NULL,'Valier, PA',4611,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11130,NULL,'Valier, PA 15780',4611,222,NULL,44,6226,0);
INSERT INTO "django_geo_db_location" VALUES(11131,NULL,'Walston, PA',4612,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11132,NULL,'Walston, PA 15781',4612,222,NULL,44,6227,0);
INSERT INTO "django_geo_db_location" VALUES(11133,NULL,'West Lebanon, PA',4613,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11134,NULL,'West Lebanon, PA 15783',4613,222,NULL,44,6228,0);
INSERT INTO "django_geo_db_location" VALUES(11135,NULL,'Worthville, PA',4614,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11136,NULL,'Worthville, PA 15784',4614,222,NULL,44,6229,0);
INSERT INTO "django_geo_db_location" VALUES(11137,NULL,'Du Bois, PA',4615,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11138,NULL,'Du Bois, PA 15801',4615,222,NULL,44,6230,0);
INSERT INTO "django_geo_db_location" VALUES(11139,NULL,'South Fayette, PA',4616,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11140,NULL,'South Fayette, PA 15817',4616,222,NULL,44,6231,0);
INSERT INTO "django_geo_db_location" VALUES(11141,NULL,'Benezett, PA',4617,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11142,NULL,'Benezett, PA 15821',4617,222,NULL,44,6232,0);
INSERT INTO "django_geo_db_location" VALUES(11143,NULL,'Brandy Camp, PA',4618,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11144,NULL,'Brandy Camp, PA 15822',4618,222,NULL,44,6233,0);
INSERT INTO "django_geo_db_location" VALUES(11145,NULL,'Brockport, PA',4619,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11146,NULL,'Brockport, PA 15823',4619,222,NULL,44,6234,0);
INSERT INTO "django_geo_db_location" VALUES(11147,NULL,'Brockway, PA',4620,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11148,NULL,'Brockway, PA 15824',4620,222,NULL,44,6235,0);
INSERT INTO "django_geo_db_location" VALUES(11149,NULL,'Brookville, PA',4621,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11150,NULL,'Brookville, PA 15825',4621,222,NULL,44,6236,0);
INSERT INTO "django_geo_db_location" VALUES(11151,NULL,'Byrnedale, PA',4622,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11152,NULL,'Byrnedale, PA 15827',4622,222,NULL,44,6237,0);
INSERT INTO "django_geo_db_location" VALUES(11153,NULL,'Clarington, PA',4623,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11154,NULL,'Clarington, PA 15828',4623,222,NULL,44,6238,0);
INSERT INTO "django_geo_db_location" VALUES(11155,NULL,'Corsica, PA',4624,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11156,NULL,'Corsica, PA 15829',4624,222,NULL,44,6239,0);
INSERT INTO "django_geo_db_location" VALUES(11157,NULL,'Dagus Mines, PA',4625,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11158,NULL,'Dagus Mines, PA 15831',4625,222,NULL,44,6240,0);
INSERT INTO "django_geo_db_location" VALUES(11159,NULL,'Driftwood, PA',4626,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11160,NULL,'Driftwood, PA 15832',4626,222,NULL,44,6241,0);
INSERT INTO "django_geo_db_location" VALUES(11161,NULL,'Emporium, PA',4627,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11162,NULL,'Emporium, PA 15834',4627,222,NULL,44,6242,0);
INSERT INTO "django_geo_db_location" VALUES(11163,NULL,'Falls Creek, PA',4628,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11164,NULL,'Falls Creek, PA 15840',4628,222,NULL,44,6243,0);
INSERT INTO "django_geo_db_location" VALUES(11165,NULL,'Force, PA',4629,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11166,NULL,'Force, PA 15841',4629,222,NULL,44,6244,0);
INSERT INTO "django_geo_db_location" VALUES(11167,NULL,'Johnsonburg, PA',4630,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11168,NULL,'Johnsonburg, PA 15845',4630,222,NULL,44,6245,0);
INSERT INTO "django_geo_db_location" VALUES(11169,NULL,'Kersey, PA',4631,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11170,NULL,'Kersey, PA 15846',4631,222,NULL,44,6246,0);
INSERT INTO "django_geo_db_location" VALUES(11171,NULL,'Knox Dale, PA',4632,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11172,NULL,'Knox Dale, PA 15847',4632,222,NULL,44,6247,0);
INSERT INTO "django_geo_db_location" VALUES(11173,NULL,'Luthersburg, PA',4633,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11174,NULL,'Luthersburg, PA 15848',4633,222,NULL,44,6248,0);
INSERT INTO "django_geo_db_location" VALUES(11175,NULL,'Penfield, PA',4634,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11176,NULL,'Penfield, PA 15849',4634,222,NULL,44,6249,0);
INSERT INTO "django_geo_db_location" VALUES(11177,NULL,'Reynoldsville, PA',4635,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11178,NULL,'Reynoldsville, PA 15851',4635,222,NULL,44,6250,0);
INSERT INTO "django_geo_db_location" VALUES(11179,NULL,'Ridgway, PA',4636,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11180,NULL,'Ridgway, PA 15853',4636,222,NULL,44,6251,0);
INSERT INTO "django_geo_db_location" VALUES(11181,NULL,'Rockton, PA',4637,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11182,NULL,'Rockton, PA 15856',4637,222,NULL,44,6252,0);
INSERT INTO "django_geo_db_location" VALUES(11183,NULL,'Saint Marys, PA',4638,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11184,NULL,'Saint Marys, PA 15857',4638,222,NULL,44,6253,0);
INSERT INTO "django_geo_db_location" VALUES(11185,NULL,'Sigel, PA',4639,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11186,NULL,'Sigel, PA 15860',4639,222,NULL,44,6254,0);
INSERT INTO "django_geo_db_location" VALUES(11187,NULL,'Sinnamahoning, PA',4640,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11188,NULL,'Sinnamahoning, PA 15861',4640,222,NULL,44,6255,0);
INSERT INTO "django_geo_db_location" VALUES(11189,NULL,'Stump Creek, PA',4641,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11190,NULL,'Stump Creek, PA 15863',4641,222,NULL,44,6256,0);
INSERT INTO "django_geo_db_location" VALUES(11191,NULL,'Summerville, PA',4642,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11192,NULL,'Summerville, PA 15864',4642,222,NULL,44,6257,0);
INSERT INTO "django_geo_db_location" VALUES(11193,NULL,'Sykesville, PA',4643,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11194,NULL,'Sykesville, PA 15865',4643,222,NULL,44,6258,0);
INSERT INTO "django_geo_db_location" VALUES(11195,NULL,'Troutville, PA',4644,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11196,NULL,'Troutville, PA 15866',4644,222,NULL,44,6259,0);
INSERT INTO "django_geo_db_location" VALUES(11197,NULL,'Weedville, PA',4645,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11198,NULL,'Weedville, PA 15868',4645,222,NULL,44,6260,0);
INSERT INTO "django_geo_db_location" VALUES(11199,NULL,'Wilcox, PA',4646,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11200,NULL,'Wilcox, PA 15870',4646,222,NULL,44,6261,0);
INSERT INTO "django_geo_db_location" VALUES(11201,NULL,'Worthville, PA 15874',4614,222,NULL,44,6262,0);
INSERT INTO "django_geo_db_location" VALUES(11202,NULL,'Johnstown, PA',4647,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11203,NULL,'Johnstown, PA 15901',4647,222,NULL,44,6263,0);
INSERT INTO "django_geo_db_location" VALUES(11204,NULL,'Johnstown, PA 15902',4647,222,NULL,44,6264,0);
INSERT INTO "django_geo_db_location" VALUES(11205,NULL,'Johnstown, PA 15904',4647,222,NULL,44,6265,0);
INSERT INTO "django_geo_db_location" VALUES(11206,NULL,'Johnstown, PA 15905',4647,222,NULL,44,6266,0);
INSERT INTO "django_geo_db_location" VALUES(11207,NULL,'Johnstown, PA 15906',4647,222,NULL,44,6267,0);
INSERT INTO "django_geo_db_location" VALUES(11208,NULL,'Johnstown, PA 15907',4647,222,NULL,44,6268,0);
INSERT INTO "django_geo_db_location" VALUES(11209,NULL,'Johnstown, PA 15909',4647,222,NULL,44,6269,0);
INSERT INTO "django_geo_db_location" VALUES(11210,NULL,'Johnstown, PA 15915',4647,222,NULL,44,6270,0);
INSERT INTO "django_geo_db_location" VALUES(11211,NULL,'Armagh, PA',4648,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11212,NULL,'Armagh, PA 15920',4648,222,NULL,44,6271,0);
INSERT INTO "django_geo_db_location" VALUES(11213,NULL,'Beaverdale, PA',4649,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11214,NULL,'Beaverdale, PA 15921',4649,222,NULL,44,6272,0);
INSERT INTO "django_geo_db_location" VALUES(11215,NULL,'Belsano, PA',4650,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11216,NULL,'Belsano, PA 15922',4650,222,NULL,44,6273,0);
INSERT INTO "django_geo_db_location" VALUES(11217,NULL,'Bolivar, PA',4651,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11218,NULL,'Bolivar, PA 15923',4651,222,NULL,44,6274,0);
INSERT INTO "django_geo_db_location" VALUES(11219,NULL,'Cairnbrook, PA',4652,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11220,NULL,'Cairnbrook, PA 15924',4652,222,NULL,44,6275,0);
INSERT INTO "django_geo_db_location" VALUES(11221,NULL,'Cassandra, PA',4653,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11222,NULL,'Cassandra, PA 15925',4653,222,NULL,44,6276,0);
INSERT INTO "django_geo_db_location" VALUES(11223,NULL,'Central City, PA',4654,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11224,NULL,'Central City, PA 15926',4654,222,NULL,44,6277,0);
INSERT INTO "django_geo_db_location" VALUES(11225,NULL,'Colver, PA',4655,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11226,NULL,'Colver, PA 15927',4655,222,NULL,44,6278,0);
INSERT INTO "django_geo_db_location" VALUES(11227,NULL,'Davidsville, PA',4656,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11228,NULL,'Davidsville, PA 15928',4656,222,NULL,44,6279,0);
INSERT INTO "django_geo_db_location" VALUES(11229,NULL,'Dilltown, PA',4657,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11230,NULL,'Dilltown, PA 15929',4657,222,NULL,44,6280,0);
INSERT INTO "django_geo_db_location" VALUES(11231,NULL,'Dunlo, PA',4658,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11232,NULL,'Dunlo, PA 15930',4658,222,NULL,44,6281,0);
INSERT INTO "django_geo_db_location" VALUES(11233,NULL,'Ebensburg, PA',4659,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11234,NULL,'Ebensburg, PA 15931',4659,222,NULL,44,6282,0);
INSERT INTO "django_geo_db_location" VALUES(11235,NULL,'Elton, PA',4660,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11236,NULL,'Elton, PA 15934',4660,222,NULL,44,6283,0);
INSERT INTO "django_geo_db_location" VALUES(11237,NULL,'Hollsopple, PA',4661,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11238,NULL,'Hollsopple, PA 15935',4661,222,NULL,44,6284,0);
INSERT INTO "django_geo_db_location" VALUES(11239,NULL,'Hooversville, PA',4662,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11240,NULL,'Hooversville, PA 15936',4662,222,NULL,44,6285,0);
INSERT INTO "django_geo_db_location" VALUES(11241,NULL,'Jerome, PA',4663,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11242,NULL,'Jerome, PA 15937',4663,222,NULL,44,6286,0);
INSERT INTO "django_geo_db_location" VALUES(11243,NULL,'Lilly, PA',4664,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11244,NULL,'Lilly, PA 15938',4664,222,NULL,44,6287,0);
INSERT INTO "django_geo_db_location" VALUES(11245,NULL,'Loretto, PA',4665,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11246,NULL,'Loretto, PA 15940',4665,222,NULL,44,6288,0);
INSERT INTO "django_geo_db_location" VALUES(11247,NULL,'Mineral Point, PA',4666,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11248,NULL,'Mineral Point, PA 15942',4666,222,NULL,44,6289,0);
INSERT INTO "django_geo_db_location" VALUES(11249,NULL,'Nanty Glo, PA',4667,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11250,NULL,'Nanty Glo, PA 15943',4667,222,NULL,44,6290,0);
INSERT INTO "django_geo_db_location" VALUES(11251,NULL,'New Florence, PA',4668,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11252,NULL,'New Florence, PA 15944',4668,222,NULL,44,6291,0);
INSERT INTO "django_geo_db_location" VALUES(11253,NULL,'Parkhill, PA',4669,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11254,NULL,'Parkhill, PA 15945',4669,222,NULL,44,6292,0);
INSERT INTO "django_geo_db_location" VALUES(11255,NULL,'Portage, PA',4670,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11256,NULL,'Portage, PA 15946',4670,222,NULL,44,6293,0);
INSERT INTO "django_geo_db_location" VALUES(11257,NULL,'Revloc, PA',4671,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11258,NULL,'Revloc, PA 15948',4671,222,NULL,44,6294,0);
INSERT INTO "django_geo_db_location" VALUES(11259,NULL,'Robinson, PA',4672,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11260,NULL,'Robinson, PA 15949',4672,222,NULL,44,6295,0);
INSERT INTO "django_geo_db_location" VALUES(11261,NULL,'Saint Michael, PA',4673,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11262,NULL,'Saint Michael, PA 15951',4673,222,NULL,44,6296,0);
INSERT INTO "django_geo_db_location" VALUES(11263,NULL,'Salix, PA',4674,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11264,NULL,'Salix, PA 15952',4674,222,NULL,44,6297,0);
INSERT INTO "django_geo_db_location" VALUES(11265,NULL,'Seanor, PA',4675,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11266,NULL,'Seanor, PA 15953',4675,222,NULL,44,6298,0);
INSERT INTO "django_geo_db_location" VALUES(11267,NULL,'Seward, PA',4676,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11268,NULL,'Seward, PA 15954',4676,222,NULL,44,6299,0);
INSERT INTO "django_geo_db_location" VALUES(11269,NULL,'Sidman, PA',4677,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11270,NULL,'Sidman, PA 15955',4677,222,NULL,44,6300,0);
INSERT INTO "django_geo_db_location" VALUES(11271,NULL,'South Fork, PA',4678,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11272,NULL,'South Fork, PA 15956',4678,222,NULL,44,6301,0);
INSERT INTO "django_geo_db_location" VALUES(11273,NULL,'Strongstown, PA',4679,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11274,NULL,'Strongstown, PA 15957',4679,222,NULL,44,6302,0);
INSERT INTO "django_geo_db_location" VALUES(11275,NULL,'Summerhill, PA',4680,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11276,NULL,'Summerhill, PA 15958',4680,222,NULL,44,6303,0);
INSERT INTO "django_geo_db_location" VALUES(11277,NULL,'Tire Hill, PA',4681,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11278,NULL,'Tire Hill, PA 15959',4681,222,NULL,44,6304,0);
INSERT INTO "django_geo_db_location" VALUES(11279,NULL,'Twin Rocks, PA',4682,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11280,NULL,'Twin Rocks, PA 15960',4682,222,NULL,44,6305,0);
INSERT INTO "django_geo_db_location" VALUES(11281,NULL,'Vintondale, PA',4683,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11282,NULL,'Vintondale, PA 15961',4683,222,NULL,44,6306,0);
INSERT INTO "django_geo_db_location" VALUES(11283,NULL,'Wilmore, PA',4684,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11284,NULL,'Wilmore, PA 15962',4684,222,NULL,44,6307,0);
INSERT INTO "django_geo_db_location" VALUES(11285,NULL,'Windber, PA',4685,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11286,NULL,'Windber, PA 15963',4685,222,NULL,44,6308,0);
INSERT INTO "django_geo_db_location" VALUES(11287,NULL,'Wilmore, PA 15965',4684,222,NULL,44,6309,0);
INSERT INTO "django_geo_db_location" VALUES(11288,NULL,'Perry, PA 15973',4434,222,NULL,44,6310,0);
INSERT INTO "django_geo_db_location" VALUES(11289,NULL,'Butler, PA',4686,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11290,NULL,'Butler, PA 16001',4686,222,NULL,44,6311,0);
INSERT INTO "django_geo_db_location" VALUES(11291,NULL,'Butler, PA 16002',4686,222,NULL,44,6312,0);
INSERT INTO "django_geo_db_location" VALUES(11292,NULL,'Butler, PA 16003',4686,222,NULL,44,6313,0);
INSERT INTO "django_geo_db_location" VALUES(11293,NULL,'Cranberry, PA',4687,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11294,NULL,'Cranberry, PA 16006',4687,222,NULL,44,6314,0);
INSERT INTO "django_geo_db_location" VALUES(11295,NULL,'Boyers, PA',4688,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11296,NULL,'Boyers, PA 16016',4688,222,NULL,44,6315,0);
INSERT INTO "django_geo_db_location" VALUES(11297,NULL,'Boyers, PA 16017',4688,222,NULL,44,6316,0);
INSERT INTO "django_geo_db_location" VALUES(11298,NULL,'Boyers, PA 16018',4688,222,NULL,44,6317,0);
INSERT INTO "django_geo_db_location" VALUES(11299,NULL,'Boyers, PA 16020',4688,222,NULL,44,6318,0);
INSERT INTO "django_geo_db_location" VALUES(11300,NULL,'Branchton, PA',4689,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11301,NULL,'Branchton, PA 16021',4689,222,NULL,44,6319,0);
INSERT INTO "django_geo_db_location" VALUES(11302,NULL,'Bruin, PA',4690,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11303,NULL,'Bruin, PA 16022',4690,222,NULL,44,6320,0);
INSERT INTO "django_geo_db_location" VALUES(11304,NULL,'Cabot, PA',4691,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11305,NULL,'Cabot, PA 16023',4691,222,NULL,44,6321,0);
INSERT INTO "django_geo_db_location" VALUES(11306,NULL,'Callery, PA',4692,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11307,NULL,'Callery, PA 16024',4692,222,NULL,44,6322,0);
INSERT INTO "django_geo_db_location" VALUES(11308,NULL,'Chicora, PA',4693,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11309,NULL,'Chicora, PA 16025',4693,222,NULL,44,6323,0);
INSERT INTO "django_geo_db_location" VALUES(11310,NULL,'Connoquenessing, PA',4694,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11311,NULL,'Connoquenessing, PA 16027',4694,222,NULL,44,6324,0);
INSERT INTO "django_geo_db_location" VALUES(11312,NULL,'East Brady, PA',4695,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11313,NULL,'East Brady, PA 16028',4695,222,NULL,44,6325,0);
INSERT INTO "django_geo_db_location" VALUES(11314,NULL,'East Butler, PA',4696,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11315,NULL,'East Butler, PA 16029',4696,222,NULL,44,6326,0);
INSERT INTO "django_geo_db_location" VALUES(11316,NULL,'Eau Claire, PA',4697,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11317,NULL,'Eau Claire, PA 16030',4697,222,NULL,44,6327,0);
INSERT INTO "django_geo_db_location" VALUES(11318,NULL,'Evans City, PA',4698,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11319,NULL,'Evans City, PA 16033',4698,222,NULL,44,6328,0);
INSERT INTO "django_geo_db_location" VALUES(11320,NULL,'Fenelton, PA',4699,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11321,NULL,'Fenelton, PA 16034',4699,222,NULL,44,6329,0);
INSERT INTO "django_geo_db_location" VALUES(11322,NULL,'Forestville, PA',4700,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11323,NULL,'Forestville, PA 16035',4700,222,NULL,44,6330,0);
INSERT INTO "django_geo_db_location" VALUES(11324,NULL,'Foxburg, PA',4701,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11325,NULL,'Foxburg, PA 16036',4701,222,NULL,44,6331,0);
INSERT INTO "django_geo_db_location" VALUES(11326,NULL,'Harmony, PA',4702,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11327,NULL,'Harmony, PA 16037',4702,222,NULL,44,6332,0);
INSERT INTO "django_geo_db_location" VALUES(11328,NULL,'Harrisville, PA',4703,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11329,NULL,'Harrisville, PA 16038',4703,222,NULL,44,6333,0);
INSERT INTO "django_geo_db_location" VALUES(11330,NULL,'Herman, PA',4704,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11331,NULL,'Herman, PA 16039',4704,222,NULL,44,6334,0);
INSERT INTO "django_geo_db_location" VALUES(11332,NULL,'Hilliards, PA',4705,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11333,NULL,'Hilliards, PA 16040',4705,222,NULL,44,6335,0);
INSERT INTO "django_geo_db_location" VALUES(11334,NULL,'Karns City, PA',4706,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11335,NULL,'Karns City, PA 16041',4706,222,NULL,44,6336,0);
INSERT INTO "django_geo_db_location" VALUES(11336,NULL,'Lyndora, PA',4707,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11337,NULL,'Lyndora, PA 16045',4707,222,NULL,44,6337,0);
INSERT INTO "django_geo_db_location" VALUES(11338,NULL,'Mars, PA',4708,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11339,NULL,'Mars, PA 16046',4708,222,NULL,44,6338,0);
INSERT INTO "django_geo_db_location" VALUES(11340,NULL,'North Washington, PA',4709,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11341,NULL,'North Washington, PA 16048',4709,222,NULL,44,6339,0);
INSERT INTO "django_geo_db_location" VALUES(11342,NULL,'Parker, PA',4710,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11343,NULL,'Parker, PA 16049',4710,222,NULL,44,6340,0);
INSERT INTO "django_geo_db_location" VALUES(11344,NULL,'Petrolia, PA',4711,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11345,NULL,'Petrolia, PA 16050',4711,222,NULL,44,6341,0);
INSERT INTO "django_geo_db_location" VALUES(11346,NULL,'Portersville, PA',4712,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11347,NULL,'Portersville, PA 16051',4712,222,NULL,44,6342,0);
INSERT INTO "django_geo_db_location" VALUES(11348,NULL,'Prospect, PA',4713,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11349,NULL,'Prospect, PA 16052',4713,222,NULL,44,6343,0);
INSERT INTO "django_geo_db_location" VALUES(11350,NULL,'Renfrew, PA',4714,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11351,NULL,'Renfrew, PA 16053',4714,222,NULL,44,6344,0);
INSERT INTO "django_geo_db_location" VALUES(11352,NULL,'Saint Petersburg, PA',4715,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11353,NULL,'Saint Petersburg, PA 16054',4715,222,NULL,44,6345,0);
INSERT INTO "django_geo_db_location" VALUES(11354,NULL,'Sarver, PA',4716,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11355,NULL,'Sarver, PA 16055',4716,222,NULL,44,6346,0);
INSERT INTO "django_geo_db_location" VALUES(11356,NULL,'Saxonburg, PA',4717,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11357,NULL,'Saxonburg, PA 16056',4717,222,NULL,44,6347,0);
INSERT INTO "django_geo_db_location" VALUES(11358,NULL,'Slippery Rock, PA',4718,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11359,NULL,'Slippery Rock, PA 16057',4718,222,NULL,44,6348,0);
INSERT INTO "django_geo_db_location" VALUES(11360,NULL,'Turkey City, PA',4719,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11361,NULL,'Turkey City, PA 16058',4719,222,NULL,44,6349,0);
INSERT INTO "django_geo_db_location" VALUES(11362,NULL,'Valencia, PA',4720,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11363,NULL,'Valencia, PA 16059',4720,222,NULL,44,6350,0);
INSERT INTO "django_geo_db_location" VALUES(11364,NULL,'West Sunbury, PA',4721,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11365,NULL,'West Sunbury, PA 16061',4721,222,NULL,44,6351,0);
INSERT INTO "django_geo_db_location" VALUES(11366,NULL,'Zelienople, PA',4722,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11367,NULL,'Zelienople, PA 16063',4722,222,NULL,44,6352,0);
INSERT INTO "django_geo_db_location" VALUES(11368,NULL,'Cranberry Twp, PA',4723,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11369,NULL,'Cranberry Twp, PA 16066',4723,222,NULL,44,6353,0);
INSERT INTO "django_geo_db_location" VALUES(11370,NULL,'New Castle, PA',4724,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11371,NULL,'New Castle, PA 16101',4724,222,NULL,44,6354,0);
INSERT INTO "django_geo_db_location" VALUES(11372,NULL,'New Castle, PA 16102',4724,222,NULL,44,6355,0);
INSERT INTO "django_geo_db_location" VALUES(11373,NULL,'New Castle, PA 16103',4724,222,NULL,44,6356,0);
INSERT INTO "django_geo_db_location" VALUES(11374,NULL,'New Castle, PA 16105',4724,222,NULL,44,6357,0);
INSERT INTO "django_geo_db_location" VALUES(11375,NULL,'New Castle, PA 16107',4724,222,NULL,44,6358,0);
INSERT INTO "django_geo_db_location" VALUES(11376,NULL,'New Castle, PA 16108',4724,222,NULL,44,6359,0);
INSERT INTO "django_geo_db_location" VALUES(11377,NULL,'Adamsville, PA',4725,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11378,NULL,'Adamsville, PA 16110',4725,222,NULL,44,6360,0);
INSERT INTO "django_geo_db_location" VALUES(11379,NULL,'Atlantic, PA',4726,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11380,NULL,'Atlantic, PA 16111',4726,222,NULL,44,6361,0);
INSERT INTO "django_geo_db_location" VALUES(11381,NULL,'Bessemer, PA',4727,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11382,NULL,'Bessemer, PA 16112',4727,222,NULL,44,6362,0);
INSERT INTO "django_geo_db_location" VALUES(11383,NULL,'Clark, PA',4728,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11384,NULL,'Clark, PA 16113',4728,222,NULL,44,6363,0);
INSERT INTO "django_geo_db_location" VALUES(11385,NULL,'Clarks Mills, PA',4729,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11386,NULL,'Clarks Mills, PA 16114',4729,222,NULL,44,6364,0);
INSERT INTO "django_geo_db_location" VALUES(11387,NULL,'Darlington, PA',4730,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11388,NULL,'Darlington, PA 16115',4730,222,NULL,44,6365,0);
INSERT INTO "django_geo_db_location" VALUES(11389,NULL,'Edinburg, PA',4731,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11390,NULL,'Edinburg, PA 16116',4731,222,NULL,44,6366,0);
INSERT INTO "django_geo_db_location" VALUES(11391,NULL,'Ellwood City, PA',4732,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11392,NULL,'Ellwood City, PA 16117',4732,222,NULL,44,6367,0);
INSERT INTO "django_geo_db_location" VALUES(11393,NULL,'Enon Valley, PA',4733,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11394,NULL,'Enon Valley, PA 16120',4733,222,NULL,44,6368,0);
INSERT INTO "django_geo_db_location" VALUES(11395,NULL,'Farrell, PA',4734,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11396,NULL,'Farrell, PA 16121',4734,222,NULL,44,6369,0);
INSERT INTO "django_geo_db_location" VALUES(11397,NULL,'Fombell, PA',4735,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11398,NULL,'Fombell, PA 16123',4735,222,NULL,44,6370,0);
INSERT INTO "django_geo_db_location" VALUES(11399,NULL,'Fredonia, PA',4736,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11400,NULL,'Fredonia, PA 16124',4736,222,NULL,44,6371,0);
INSERT INTO "django_geo_db_location" VALUES(11401,NULL,'Greenville, PA',4737,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11402,NULL,'Greenville, PA 16125',4737,222,NULL,44,6372,0);
INSERT INTO "django_geo_db_location" VALUES(11403,NULL,'Grove City, PA',4738,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11404,NULL,'Grove City, PA 16127',4738,222,NULL,44,6373,0);
INSERT INTO "django_geo_db_location" VALUES(11405,NULL,'Hadley, PA',4739,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11406,NULL,'Hadley, PA 16130',4739,222,NULL,44,6374,0);
INSERT INTO "django_geo_db_location" VALUES(11407,NULL,'Hartstown, PA',4740,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11408,NULL,'Hartstown, PA 16131',4740,222,NULL,44,6375,0);
INSERT INTO "django_geo_db_location" VALUES(11409,NULL,'Hillsville, PA',4741,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11410,NULL,'Hillsville, PA 16132',4741,222,NULL,44,6376,0);
INSERT INTO "django_geo_db_location" VALUES(11411,NULL,'Jackson Center, PA',4742,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11412,NULL,'Jackson Center, PA 16133',4742,222,NULL,44,6377,0);
INSERT INTO "django_geo_db_location" VALUES(11413,NULL,'Jamestown, PA',4743,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11414,NULL,'Jamestown, PA 16134',4743,222,NULL,44,6378,0);
INSERT INTO "django_geo_db_location" VALUES(11415,NULL,'Koppel, PA',4744,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11416,NULL,'Koppel, PA 16136',4744,222,NULL,44,6379,0);
INSERT INTO "django_geo_db_location" VALUES(11417,NULL,'Mercer, PA',4745,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11418,NULL,'Mercer, PA 16137',4745,222,NULL,44,6380,0);
INSERT INTO "django_geo_db_location" VALUES(11419,NULL,'New Bedford, PA',4746,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11420,NULL,'New Bedford, PA 16140',4746,222,NULL,44,6381,0);
INSERT INTO "django_geo_db_location" VALUES(11421,NULL,'New Galilee, PA',4747,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11422,NULL,'New Galilee, PA 16141',4747,222,NULL,44,6382,0);
INSERT INTO "django_geo_db_location" VALUES(11423,NULL,'New Wilmington, PA',4748,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11424,NULL,'New Wilmington, PA 16142',4748,222,NULL,44,6383,0);
INSERT INTO "django_geo_db_location" VALUES(11425,NULL,'Pulaski, PA',4749,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11426,NULL,'Pulaski, PA 16143',4749,222,NULL,44,6384,0);
INSERT INTO "django_geo_db_location" VALUES(11427,NULL,'Sandy Lake, PA',4750,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11428,NULL,'Sandy Lake, PA 16145',4750,222,NULL,44,6385,0);
INSERT INTO "django_geo_db_location" VALUES(11429,NULL,'Sharon, PA',4751,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11430,NULL,'Sharon, PA 16146',4751,222,NULL,44,6386,0);
INSERT INTO "django_geo_db_location" VALUES(11431,NULL,'Hermitage, PA',4752,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11432,NULL,'Hermitage, PA 16148',4752,222,NULL,44,6387,0);
INSERT INTO "django_geo_db_location" VALUES(11433,NULL,'Sharpsville, PA',4753,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11434,NULL,'Sharpsville, PA 16150',4753,222,NULL,44,6388,0);
INSERT INTO "django_geo_db_location" VALUES(11435,NULL,'Sheakleyville, PA',4754,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11436,NULL,'Sheakleyville, PA 16151',4754,222,NULL,44,6389,0);
INSERT INTO "django_geo_db_location" VALUES(11437,NULL,'Stoneboro, PA',4755,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11438,NULL,'Stoneboro, PA 16153',4755,222,NULL,44,6390,0);
INSERT INTO "django_geo_db_location" VALUES(11439,NULL,'Transfer, PA',4756,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11440,NULL,'Transfer, PA 16154',4756,222,NULL,44,6391,0);
INSERT INTO "django_geo_db_location" VALUES(11441,NULL,'Villa Maria, PA',4757,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11442,NULL,'Villa Maria, PA 16155',4757,222,NULL,44,6392,0);
INSERT INTO "django_geo_db_location" VALUES(11443,NULL,'Volant, PA',4758,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11444,NULL,'Volant, PA 16156',4758,222,NULL,44,6393,0);
INSERT INTO "django_geo_db_location" VALUES(11445,NULL,'Wampum, PA',4759,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11446,NULL,'Wampum, PA 16157',4759,222,NULL,44,6394,0);
INSERT INTO "django_geo_db_location" VALUES(11447,NULL,'West Middlesex, PA',4760,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11448,NULL,'West Middlesex, PA 16159',4760,222,NULL,44,6395,0);
INSERT INTO "django_geo_db_location" VALUES(11449,NULL,'West Pittsburg, PA',4761,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11450,NULL,'West Pittsburg, PA 16160',4761,222,NULL,44,6396,0);
INSERT INTO "django_geo_db_location" VALUES(11451,NULL,'Wheatland, PA',4762,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11452,NULL,'Wheatland, PA 16161',4762,222,NULL,44,6397,0);
INSERT INTO "django_geo_db_location" VALUES(11453,NULL,'New Wilmington, PA 16172',4748,222,NULL,44,6398,0);
INSERT INTO "django_geo_db_location" VALUES(11454,NULL,'Kittanning, PA',4763,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11455,NULL,'Kittanning, PA 16201',4763,222,NULL,44,6399,0);
INSERT INTO "django_geo_db_location" VALUES(11456,NULL,'Adrian, PA',4764,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11457,NULL,'Adrian, PA 16210',4764,222,NULL,44,6400,0);
INSERT INTO "django_geo_db_location" VALUES(11458,NULL,'Beyer, PA',4765,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11459,NULL,'Beyer, PA 16211',4765,222,NULL,44,6401,0);
INSERT INTO "django_geo_db_location" VALUES(11460,NULL,'Cadogan, PA',4766,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11461,NULL,'Cadogan, PA 16212',4766,222,NULL,44,6402,0);
INSERT INTO "django_geo_db_location" VALUES(11462,NULL,'Callensburg, PA',4767,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11463,NULL,'Callensburg, PA 16213',4767,222,NULL,44,6403,0);
INSERT INTO "django_geo_db_location" VALUES(11464,NULL,'Clarion, PA',4768,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11465,NULL,'Clarion, PA 16214',4768,222,NULL,44,6404,0);
INSERT INTO "django_geo_db_location" VALUES(11466,NULL,'Kittanning, PA 16215',4763,222,NULL,44,6405,0);
INSERT INTO "django_geo_db_location" VALUES(11467,NULL,'Climax, PA',4769,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11468,NULL,'Climax, PA 16216',4769,222,NULL,44,6406,0);
INSERT INTO "django_geo_db_location" VALUES(11469,NULL,'Cooksburg, PA',4770,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11470,NULL,'Cooksburg, PA 16217',4770,222,NULL,44,6407,0);
INSERT INTO "django_geo_db_location" VALUES(11471,NULL,'Cowansville, PA',4771,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11472,NULL,'Cowansville, PA 16218',4771,222,NULL,44,6408,0);
INSERT INTO "django_geo_db_location" VALUES(11473,NULL,'Crown, PA',4772,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11474,NULL,'Crown, PA 16220',4772,222,NULL,44,6409,0);
INSERT INTO "django_geo_db_location" VALUES(11475,NULL,'Curllsville, PA',4773,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11476,NULL,'Curllsville, PA 16221',4773,222,NULL,44,6410,0);
INSERT INTO "django_geo_db_location" VALUES(11477,NULL,'Dayton, PA',4774,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11478,NULL,'Dayton, PA 16222',4774,222,NULL,44,6411,0);
INSERT INTO "django_geo_db_location" VALUES(11479,NULL,'Distant, PA',4775,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11480,NULL,'Distant, PA 16223',4775,222,NULL,44,6412,0);
INSERT INTO "django_geo_db_location" VALUES(11481,NULL,'Fairmount City, PA',4776,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11482,NULL,'Fairmount City, PA 16224',4776,222,NULL,44,6413,0);
INSERT INTO "django_geo_db_location" VALUES(11483,NULL,'Fisher, PA',4777,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11484,NULL,'Fisher, PA 16225',4777,222,NULL,44,6414,0);
INSERT INTO "django_geo_db_location" VALUES(11485,NULL,'Ford City, PA',4778,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11486,NULL,'Ford City, PA 16226',4778,222,NULL,44,6415,0);
INSERT INTO "django_geo_db_location" VALUES(11487,NULL,'Ford Cliff, PA',4779,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11488,NULL,'Ford Cliff, PA 16228',4779,222,NULL,44,6416,0);
INSERT INTO "django_geo_db_location" VALUES(11489,NULL,'Freeport, PA',4780,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11490,NULL,'Freeport, PA 16229',4780,222,NULL,44,6417,0);
INSERT INTO "django_geo_db_location" VALUES(11491,NULL,'Hawthorn, PA',4781,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11492,NULL,'Hawthorn, PA 16230',4781,222,NULL,44,6418,0);
INSERT INTO "django_geo_db_location" VALUES(11493,NULL,'Knox, PA',4782,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11494,NULL,'Knox, PA 16232',4782,222,NULL,44,6419,0);
INSERT INTO "django_geo_db_location" VALUES(11495,NULL,'Leeper, PA',4783,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11496,NULL,'Leeper, PA 16233',4783,222,NULL,44,6420,0);
INSERT INTO "django_geo_db_location" VALUES(11497,NULL,'Limestone, PA',4784,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11498,NULL,'Limestone, PA 16234',4784,222,NULL,44,6421,0);
INSERT INTO "django_geo_db_location" VALUES(11499,NULL,'Lucinda, PA',4785,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11500,NULL,'Lucinda, PA 16235',4785,222,NULL,44,6422,0);
INSERT INTO "django_geo_db_location" VALUES(11501,NULL,'McGrann, PA',4786,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11502,NULL,'McGrann, PA 16236',4786,222,NULL,44,6423,0);
INSERT INTO "django_geo_db_location" VALUES(11503,NULL,'Manorville, PA',4787,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11504,NULL,'Manorville, PA 16238',4787,222,NULL,44,6424,0);
INSERT INTO "django_geo_db_location" VALUES(11505,NULL,'Marienville, PA',4788,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11506,NULL,'Marienville, PA 16239',4788,222,NULL,44,6425,0);
INSERT INTO "django_geo_db_location" VALUES(11507,NULL,'Mayport, PA',4789,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11508,NULL,'Mayport, PA 16240',4789,222,NULL,44,6426,0);
INSERT INTO "django_geo_db_location" VALUES(11509,NULL,'New Bethlehem, PA',4790,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11510,NULL,'New Bethlehem, PA 16242',4790,222,NULL,44,6427,0);
INSERT INTO "django_geo_db_location" VALUES(11511,NULL,'Nu Mine, PA',4791,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11512,NULL,'Nu Mine, PA 16244',4791,222,NULL,44,6428,0);
INSERT INTO "django_geo_db_location" VALUES(11513,NULL,'Oak Ridge, PA',4792,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11514,NULL,'Oak Ridge, PA 16245',4792,222,NULL,44,6429,0);
INSERT INTO "django_geo_db_location" VALUES(11515,NULL,'Plumville, PA',4793,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11516,NULL,'Plumville, PA 16246',4793,222,NULL,44,6430,0);
INSERT INTO "django_geo_db_location" VALUES(11517,NULL,'Rimersburg, PA',4794,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11518,NULL,'Rimersburg, PA 16248',4794,222,NULL,44,6431,0);
INSERT INTO "django_geo_db_location" VALUES(11519,NULL,'Rural Valley, PA',4795,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11520,NULL,'Rural Valley, PA 16249',4795,222,NULL,44,6432,0);
INSERT INTO "django_geo_db_location" VALUES(11521,NULL,'Sagamore, PA',4796,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11522,NULL,'Sagamore, PA 16250',4796,222,NULL,44,6433,0);
INSERT INTO "django_geo_db_location" VALUES(11523,NULL,'Seminole, PA',4797,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11524,NULL,'Seminole, PA 16253',4797,222,NULL,44,6434,0);
INSERT INTO "django_geo_db_location" VALUES(11525,NULL,'Shippenville, PA',4798,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11526,NULL,'Shippenville, PA 16254',4798,222,NULL,44,6435,0);
INSERT INTO "django_geo_db_location" VALUES(11527,NULL,'Sligo, PA',4799,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11528,NULL,'Sligo, PA 16255',4799,222,NULL,44,6436,0);
INSERT INTO "django_geo_db_location" VALUES(11529,NULL,'Smicksburg, PA',4800,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11530,NULL,'Smicksburg, PA 16256',4800,222,NULL,44,6437,0);
INSERT INTO "django_geo_db_location" VALUES(11531,NULL,'Snydersburg, PA',4801,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11532,NULL,'Snydersburg, PA 16257',4801,222,NULL,44,6438,0);
INSERT INTO "django_geo_db_location" VALUES(11533,NULL,'Strattanville, PA',4802,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11534,NULL,'Strattanville, PA 16258',4802,222,NULL,44,6439,0);
INSERT INTO "django_geo_db_location" VALUES(11535,NULL,'Templeton, PA',4803,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11536,NULL,'Templeton, PA 16259',4803,222,NULL,44,6440,0);
INSERT INTO "django_geo_db_location" VALUES(11537,NULL,'Vowinckel, PA',4804,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11538,NULL,'Vowinckel, PA 16260',4804,222,NULL,44,6441,0);
INSERT INTO "django_geo_db_location" VALUES(11539,NULL,'Widnoon, PA',4805,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11540,NULL,'Widnoon, PA 16261',4805,222,NULL,44,6442,0);
INSERT INTO "django_geo_db_location" VALUES(11541,NULL,'Worthington, PA',4806,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11542,NULL,'Worthington, PA 16262',4806,222,NULL,44,6443,0);
INSERT INTO "django_geo_db_location" VALUES(11543,NULL,'Yatesboro, PA',4807,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11544,NULL,'Yatesboro, PA 16263',4807,222,NULL,44,6444,0);
INSERT INTO "django_geo_db_location" VALUES(11545,NULL,'South Buffalo, PA',4808,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11546,NULL,'South Buffalo, PA 16299',4808,222,NULL,44,6445,0);
INSERT INTO "django_geo_db_location" VALUES(11547,NULL,'Oil City, PA',4809,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11548,NULL,'Oil City, PA 16301',4809,222,NULL,44,6446,0);
INSERT INTO "django_geo_db_location" VALUES(11549,NULL,'Oil City, PA 16302',4809,222,NULL,44,6447,0);
INSERT INTO "django_geo_db_location" VALUES(11550,NULL,'Carlton, PA',4810,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11551,NULL,'Carlton, PA 16311',4810,222,NULL,44,6448,0);
INSERT INTO "django_geo_db_location" VALUES(11552,NULL,'Chandlers Valley, PA',4811,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11553,NULL,'Chandlers Valley, PA 16312',4811,222,NULL,44,6449,0);
INSERT INTO "django_geo_db_location" VALUES(11554,NULL,'Clarendon, PA',4812,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11555,NULL,'Clarendon, PA 16313',4812,222,NULL,44,6450,0);
INSERT INTO "django_geo_db_location" VALUES(11556,NULL,'Cochranton, PA',4813,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11557,NULL,'Cochranton, PA 16314',4813,222,NULL,44,6451,0);
INSERT INTO "django_geo_db_location" VALUES(11558,NULL,'Conneaut Lake, PA',4814,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11559,NULL,'Conneaut Lake, PA 16316',4814,222,NULL,44,6452,0);
INSERT INTO "django_geo_db_location" VALUES(11560,NULL,'Cooperstown, PA',4815,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11561,NULL,'Cooperstown, PA 16317',4815,222,NULL,44,6453,0);
INSERT INTO "django_geo_db_location" VALUES(11562,NULL,'Cranberry, PA 16319',4687,222,NULL,44,6454,0);
INSERT INTO "django_geo_db_location" VALUES(11563,NULL,'East Hickory, PA',4816,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11564,NULL,'East Hickory, PA 16321',4816,222,NULL,44,6455,0);
INSERT INTO "django_geo_db_location" VALUES(11565,NULL,'Endeavor, PA',4817,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11566,NULL,'Endeavor, PA 16322',4817,222,NULL,44,6456,0);
INSERT INTO "django_geo_db_location" VALUES(11567,NULL,'Franklin, PA',4818,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11568,NULL,'Franklin, PA 16323',4818,222,NULL,44,6457,0);
INSERT INTO "django_geo_db_location" VALUES(11569,NULL,'Fryburg, PA',4819,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11570,NULL,'Fryburg, PA 16326',4819,222,NULL,44,6458,0);
INSERT INTO "django_geo_db_location" VALUES(11571,NULL,'Guys Mills, PA',4820,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11572,NULL,'Guys Mills, PA 16327',4820,222,NULL,44,6459,0);
INSERT INTO "django_geo_db_location" VALUES(11573,NULL,'Hydetown, PA',4821,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11574,NULL,'Hydetown, PA 16328',4821,222,NULL,44,6460,0);
INSERT INTO "django_geo_db_location" VALUES(11575,NULL,'Irvine, PA',4822,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11576,NULL,'Irvine, PA 16329',4822,222,NULL,44,6461,0);
INSERT INTO "django_geo_db_location" VALUES(11577,NULL,'Kossuth, PA',4823,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11578,NULL,'Kossuth, PA 16331',4823,222,NULL,44,6462,0);
INSERT INTO "django_geo_db_location" VALUES(11579,NULL,'Lickingville, PA',4824,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11580,NULL,'Lickingville, PA 16332',4824,222,NULL,44,6463,0);
INSERT INTO "django_geo_db_location" VALUES(11581,NULL,'Ludlow, PA',4825,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11582,NULL,'Ludlow, PA 16333',4825,222,NULL,44,6464,0);
INSERT INTO "django_geo_db_location" VALUES(11583,NULL,'Marble, PA',4826,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11584,NULL,'Marble, PA 16334',4826,222,NULL,44,6465,0);
INSERT INTO "django_geo_db_location" VALUES(11585,NULL,'Meadville, PA',4827,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11586,NULL,'Meadville, PA 16335',4827,222,NULL,44,6466,0);
INSERT INTO "django_geo_db_location" VALUES(11587,NULL,'Pittsfield, PA',4828,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11588,NULL,'Pittsfield, PA 16340',4828,222,NULL,44,6467,0);
INSERT INTO "django_geo_db_location" VALUES(11589,NULL,'Pleasantville, PA',4829,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11590,NULL,'Pleasantville, PA 16341',4829,222,NULL,44,6468,0);
INSERT INTO "django_geo_db_location" VALUES(11591,NULL,'Polk, PA',4830,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11592,NULL,'Polk, PA 16342',4830,222,NULL,44,6469,0);
INSERT INTO "django_geo_db_location" VALUES(11593,NULL,'Reno, PA',4831,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11594,NULL,'Reno, PA 16343',4831,222,NULL,44,6470,0);
INSERT INTO "django_geo_db_location" VALUES(11595,NULL,'Rouseville, PA',4832,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11596,NULL,'Rouseville, PA 16344',4832,222,NULL,44,6471,0);
INSERT INTO "django_geo_db_location" VALUES(11597,NULL,'Russell, PA',4833,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11598,NULL,'Russell, PA 16345',4833,222,NULL,44,6472,0);
INSERT INTO "django_geo_db_location" VALUES(11599,NULL,'Seneca, PA',4834,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11600,NULL,'Seneca, PA 16346',4834,222,NULL,44,6473,0);
INSERT INTO "django_geo_db_location" VALUES(11601,NULL,'Sheffield, PA',4835,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11602,NULL,'Sheffield, PA 16347',4835,222,NULL,44,6474,0);
INSERT INTO "django_geo_db_location" VALUES(11603,NULL,'Sugar Grove, PA',4836,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11604,NULL,'Sugar Grove, PA 16350',4836,222,NULL,44,6475,0);
INSERT INTO "django_geo_db_location" VALUES(11605,NULL,'Tidioute, PA',4837,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11606,NULL,'Tidioute, PA 16351',4837,222,NULL,44,6476,0);
INSERT INTO "django_geo_db_location" VALUES(11607,NULL,'Tiona, PA',4838,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11608,NULL,'Tiona, PA 16352',4838,222,NULL,44,6477,0);
INSERT INTO "django_geo_db_location" VALUES(11609,NULL,'Tionesta, PA',4839,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11610,NULL,'Tionesta, PA 16353',4839,222,NULL,44,6478,0);
INSERT INTO "django_geo_db_location" VALUES(11611,NULL,'Titusville, PA',4840,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11612,NULL,'Titusville, PA 16354',4840,222,NULL,44,6479,0);
INSERT INTO "django_geo_db_location" VALUES(11613,NULL,'East Fairfield, PA',4841,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11614,NULL,'East Fairfield, PA 16355',4841,222,NULL,44,6480,0);
INSERT INTO "django_geo_db_location" VALUES(11615,NULL,'Townville, PA',4842,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11616,NULL,'Townville, PA 16360',4842,222,NULL,44,6481,0);
INSERT INTO "django_geo_db_location" VALUES(11617,NULL,'Tylersburg, PA',4843,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11618,NULL,'Tylersburg, PA 16361',4843,222,NULL,44,6482,0);
INSERT INTO "django_geo_db_location" VALUES(11619,NULL,'Utica, PA',4844,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11620,NULL,'Utica, PA 16362',4844,222,NULL,44,6483,0);
INSERT INTO "django_geo_db_location" VALUES(11621,NULL,'Venus, PA',4845,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11622,NULL,'Venus, PA 16364',4845,222,NULL,44,6484,0);
INSERT INTO "django_geo_db_location" VALUES(11623,NULL,'Warren, PA',4846,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11624,NULL,'Warren, PA 16365',4846,222,NULL,44,6485,0);
INSERT INTO "django_geo_db_location" VALUES(11625,NULL,'Warren, PA 16366',4846,222,NULL,44,6486,0);
INSERT INTO "django_geo_db_location" VALUES(11626,NULL,'Warren, PA 16367',4846,222,NULL,44,6487,0);
INSERT INTO "django_geo_db_location" VALUES(11627,NULL,'Irvine, PA 16368',4822,222,NULL,44,6488,0);
INSERT INTO "django_geo_db_location" VALUES(11628,NULL,'Irvine, PA 16369',4822,222,NULL,44,6489,0);
INSERT INTO "django_geo_db_location" VALUES(11629,NULL,'West Hickory, PA',4847,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11630,NULL,'West Hickory, PA 16370',4847,222,NULL,44,6490,0);
INSERT INTO "django_geo_db_location" VALUES(11631,NULL,'Youngsville, PA',4848,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11632,NULL,'Youngsville, PA 16371',4848,222,NULL,44,6491,0);
INSERT INTO "django_geo_db_location" VALUES(11633,NULL,'Clintonville, PA',4849,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11634,NULL,'Clintonville, PA 16372',4849,222,NULL,44,6492,0);
INSERT INTO "django_geo_db_location" VALUES(11635,NULL,'Emlenton, PA',4850,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11636,NULL,'Emlenton, PA 16373',4850,222,NULL,44,6493,0);
INSERT INTO "django_geo_db_location" VALUES(11637,NULL,'Kennerdell, PA',4851,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11638,NULL,'Kennerdell, PA 16374',4851,222,NULL,44,6494,0);
INSERT INTO "django_geo_db_location" VALUES(11639,NULL,'Lamartine, PA',4852,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11640,NULL,'Lamartine, PA 16375',4852,222,NULL,44,6495,0);
INSERT INTO "django_geo_db_location" VALUES(11641,NULL,'Meadville, PA 16388',4827,222,NULL,44,6496,0);
INSERT INTO "django_geo_db_location" VALUES(11642,NULL,'Albion, PA',4853,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11643,NULL,'Albion, PA 16401',4853,222,NULL,44,6497,0);
INSERT INTO "django_geo_db_location" VALUES(11644,NULL,'Bear Lake, PA',4854,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11645,NULL,'Bear Lake, PA 16402',4854,222,NULL,44,6498,0);
INSERT INTO "django_geo_db_location" VALUES(11646,NULL,'Cambridge Springs, PA',4855,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11647,NULL,'Cambridge Springs, PA 16403',4855,222,NULL,44,6499,0);
INSERT INTO "django_geo_db_location" VALUES(11648,NULL,'Centerville, PA 16404',4341,222,NULL,44,6500,0);
INSERT INTO "django_geo_db_location" VALUES(11649,NULL,'Columbus, PA',4856,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11650,NULL,'Columbus, PA 16405',4856,222,NULL,44,6501,0);
INSERT INTO "django_geo_db_location" VALUES(11651,NULL,'Conneautville, PA',4857,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11652,NULL,'Conneautville, PA 16406',4857,222,NULL,44,6502,0);
INSERT INTO "django_geo_db_location" VALUES(11653,NULL,'Corry, PA',4858,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11654,NULL,'Corry, PA 16407',4858,222,NULL,44,6503,0);
INSERT INTO "django_geo_db_location" VALUES(11655,NULL,'Cranesville, PA',4859,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11656,NULL,'Cranesville, PA 16410',4859,222,NULL,44,6504,0);
INSERT INTO "django_geo_db_location" VALUES(11657,NULL,'East Springfield, PA',4860,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11658,NULL,'East Springfield, PA 16411',4860,222,NULL,44,6505,0);
INSERT INTO "django_geo_db_location" VALUES(11659,NULL,'Edinboro, PA',4861,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11660,NULL,'Edinboro, PA 16412',4861,222,NULL,44,6506,0);
INSERT INTO "django_geo_db_location" VALUES(11661,NULL,'Elgin, PA',4862,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11662,NULL,'Elgin, PA 16413',4862,222,NULL,44,6507,0);
INSERT INTO "django_geo_db_location" VALUES(11663,NULL,'Bloomfield, PA',4863,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11664,NULL,'Bloomfield, PA 16414',4863,222,NULL,44,6508,0);
INSERT INTO "django_geo_db_location" VALUES(11665,NULL,'Fairview, PA',4864,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11666,NULL,'Fairview, PA 16415',4864,222,NULL,44,6509,0);
INSERT INTO "django_geo_db_location" VALUES(11667,NULL,'Garland, PA',4865,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11668,NULL,'Garland, PA 16416',4865,222,NULL,44,6510,0);
INSERT INTO "django_geo_db_location" VALUES(11669,NULL,'Girard, PA',4866,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11670,NULL,'Girard, PA 16417',4866,222,NULL,44,6511,0);
INSERT INTO "django_geo_db_location" VALUES(11671,NULL,'Grand Valley, PA',4867,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11672,NULL,'Grand Valley, PA 16420',4867,222,NULL,44,6512,0);
INSERT INTO "django_geo_db_location" VALUES(11673,NULL,'Harborcreek, PA',4868,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11674,NULL,'Harborcreek, PA 16421',4868,222,NULL,44,6513,0);
INSERT INTO "django_geo_db_location" VALUES(11675,NULL,'Harmonsburg, PA',4869,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11676,NULL,'Harmonsburg, PA 16422',4869,222,NULL,44,6514,0);
INSERT INTO "django_geo_db_location" VALUES(11677,NULL,'Lake City, PA',4870,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11678,NULL,'Lake City, PA 16423',4870,222,NULL,44,6515,0);
INSERT INTO "django_geo_db_location" VALUES(11679,NULL,'Linesville, PA',4871,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11680,NULL,'Linesville, PA 16424',4871,222,NULL,44,6516,0);
INSERT INTO "django_geo_db_location" VALUES(11681,NULL,'McKean, PA',4872,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11682,NULL,'McKean, PA 16426',4872,222,NULL,44,6517,0);
INSERT INTO "django_geo_db_location" VALUES(11683,NULL,'Mill Village, PA',4873,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11684,NULL,'Mill Village, PA 16427',4873,222,NULL,44,6518,0);
INSERT INTO "django_geo_db_location" VALUES(11685,NULL,'North East, PA',4874,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11686,NULL,'North East, PA 16428',4874,222,NULL,44,6519,0);
INSERT INTO "django_geo_db_location" VALUES(11687,NULL,'North Springfield, PA',4875,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11688,NULL,'North Springfield, PA 16430',4875,222,NULL,44,6520,0);
INSERT INTO "django_geo_db_location" VALUES(11689,NULL,'Riceville, PA',4876,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11690,NULL,'Riceville, PA 16432',4876,222,NULL,44,6521,0);
INSERT INTO "django_geo_db_location" VALUES(11691,NULL,'Saegertown, PA',4877,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11692,NULL,'Saegertown, PA 16433',4877,222,NULL,44,6522,0);
INSERT INTO "django_geo_db_location" VALUES(11693,NULL,'Spartansburg, PA',4878,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11694,NULL,'Spartansburg, PA 16434',4878,222,NULL,44,6523,0);
INSERT INTO "django_geo_db_location" VALUES(11695,NULL,'Springboro, PA',4879,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11696,NULL,'Springboro, PA 16435',4879,222,NULL,44,6524,0);
INSERT INTO "django_geo_db_location" VALUES(11697,NULL,'Spring Creek, PA',4880,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11698,NULL,'Spring Creek, PA 16436',4880,222,NULL,44,6525,0);
INSERT INTO "django_geo_db_location" VALUES(11699,NULL,'Union City, PA',4881,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11700,NULL,'Union City, PA 16438',4881,222,NULL,44,6526,0);
INSERT INTO "django_geo_db_location" VALUES(11701,NULL,'Venango, PA',4882,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11702,NULL,'Venango, PA 16440',4882,222,NULL,44,6527,0);
INSERT INTO "django_geo_db_location" VALUES(11703,NULL,'Waterford, PA',4883,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11704,NULL,'Waterford, PA 16441',4883,222,NULL,44,6528,0);
INSERT INTO "django_geo_db_location" VALUES(11705,NULL,'Wattsburg, PA',4884,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11706,NULL,'Wattsburg, PA 16442',4884,222,NULL,44,6529,0);
INSERT INTO "django_geo_db_location" VALUES(11707,NULL,'West Springfield, PA',4885,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11708,NULL,'West Springfield, PA 16443',4885,222,NULL,44,6530,0);
INSERT INTO "django_geo_db_location" VALUES(11709,NULL,'Edinboro, PA 16444',4861,222,NULL,44,6531,0);
INSERT INTO "django_geo_db_location" VALUES(11710,NULL,'Albion, PA 16475',4853,222,NULL,44,6532,0);
INSERT INTO "django_geo_db_location" VALUES(11711,NULL,'Erie, PA',4886,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11712,NULL,'Erie, PA 16501',4886,222,NULL,44,6533,0);
INSERT INTO "django_geo_db_location" VALUES(11713,NULL,'Erie, PA 16502',4886,222,NULL,44,6534,0);
INSERT INTO "django_geo_db_location" VALUES(11714,NULL,'Erie, PA 16503',4886,222,NULL,44,6535,0);
INSERT INTO "django_geo_db_location" VALUES(11715,NULL,'Erie, PA 16504',4886,222,NULL,44,6536,0);
INSERT INTO "django_geo_db_location" VALUES(11716,NULL,'Erie, PA 16505',4886,222,NULL,44,6537,0);
INSERT INTO "django_geo_db_location" VALUES(11717,NULL,'Erie, PA 16506',4886,222,NULL,44,6538,0);
INSERT INTO "django_geo_db_location" VALUES(11718,NULL,'Erie, PA 16507',4886,222,NULL,44,6539,0);
INSERT INTO "django_geo_db_location" VALUES(11719,NULL,'Erie, PA 16508',4886,222,NULL,44,6540,0);
INSERT INTO "django_geo_db_location" VALUES(11720,NULL,'Erie, PA 16509',4886,222,NULL,44,6541,0);
INSERT INTO "django_geo_db_location" VALUES(11721,NULL,'Erie, PA 16510',4886,222,NULL,44,6542,0);
INSERT INTO "django_geo_db_location" VALUES(11722,NULL,'Erie, PA 16511',4886,222,NULL,44,6543,0);
INSERT INTO "django_geo_db_location" VALUES(11723,NULL,'Erie, PA 16512',4886,222,NULL,44,6544,0);
INSERT INTO "django_geo_db_location" VALUES(11724,NULL,'Erie, PA 16514',4886,222,NULL,44,6545,0);
INSERT INTO "django_geo_db_location" VALUES(11725,NULL,'Erie, PA 16515',4886,222,NULL,44,6546,0);
INSERT INTO "django_geo_db_location" VALUES(11726,NULL,'Erie, PA 16522',4886,222,NULL,44,6547,0);
INSERT INTO "django_geo_db_location" VALUES(11727,NULL,'Erie, PA 16530',4886,222,NULL,44,6548,0);
INSERT INTO "django_geo_db_location" VALUES(11728,NULL,'Erie, PA 16531',4886,222,NULL,44,6549,0);
INSERT INTO "django_geo_db_location" VALUES(11729,NULL,'Erie, PA 16532',4886,222,NULL,44,6550,0);
INSERT INTO "django_geo_db_location" VALUES(11730,NULL,'Erie, PA 16533',4886,222,NULL,44,6551,0);
INSERT INTO "django_geo_db_location" VALUES(11731,NULL,'Erie, PA 16534',4886,222,NULL,44,6552,0);
INSERT INTO "django_geo_db_location" VALUES(11732,NULL,'Erie, PA 16538',4886,222,NULL,44,6553,0);
INSERT INTO "django_geo_db_location" VALUES(11733,NULL,'Erie, PA 16541',4886,222,NULL,44,6554,0);
INSERT INTO "django_geo_db_location" VALUES(11734,NULL,'Erie, PA 16544',4886,222,NULL,44,6555,0);
INSERT INTO "django_geo_db_location" VALUES(11735,NULL,'Erie, PA 16546',4886,222,NULL,44,6556,0);
INSERT INTO "django_geo_db_location" VALUES(11736,NULL,'Erie, PA 16550',4886,222,NULL,44,6557,0);
INSERT INTO "django_geo_db_location" VALUES(11737,NULL,'Erie, PA 16553',4886,222,NULL,44,6558,0);
INSERT INTO "django_geo_db_location" VALUES(11738,NULL,'Erie, PA 16554',4886,222,NULL,44,6559,0);
INSERT INTO "django_geo_db_location" VALUES(11739,NULL,'Erie, PA 16558',4886,222,NULL,44,6560,0);
INSERT INTO "django_geo_db_location" VALUES(11740,NULL,'Erie, PA 16563',4886,222,NULL,44,6561,0);
INSERT INTO "django_geo_db_location" VALUES(11741,NULL,'Erie, PA 16565',4886,222,NULL,44,6562,0);
INSERT INTO "django_geo_db_location" VALUES(11742,NULL,'Altoona, PA',4887,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11743,NULL,'Altoona, PA 16601',4887,222,NULL,44,6563,0);
INSERT INTO "django_geo_db_location" VALUES(11744,NULL,'Altoona, PA 16602',4887,222,NULL,44,6564,0);
INSERT INTO "django_geo_db_location" VALUES(11745,NULL,'Altoona, PA 16603',4887,222,NULL,44,6565,0);
INSERT INTO "django_geo_db_location" VALUES(11746,NULL,'Alexandria, PA',4888,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11747,NULL,'Alexandria, PA 16611',4888,222,NULL,44,6566,0);
INSERT INTO "django_geo_db_location" VALUES(11748,NULL,'Ashville, PA',4889,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11749,NULL,'Ashville, PA 16613',4889,222,NULL,44,6567,0);
INSERT INTO "django_geo_db_location" VALUES(11750,NULL,'Bakers Summit, PA',4890,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11751,NULL,'Bakers Summit, PA 16614',4890,222,NULL,44,6568,0);
INSERT INTO "django_geo_db_location" VALUES(11752,NULL,'Beccaria, PA',4891,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11753,NULL,'Beccaria, PA 16616',4891,222,NULL,44,6569,0);
INSERT INTO "django_geo_db_location" VALUES(11754,NULL,'Bellwood, PA',4892,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11755,NULL,'Bellwood, PA 16617',4892,222,NULL,44,6570,0);
INSERT INTO "django_geo_db_location" VALUES(11756,NULL,'Blandburg, PA',4893,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11757,NULL,'Blandburg, PA 16619',4893,222,NULL,44,6571,0);
INSERT INTO "django_geo_db_location" VALUES(11758,NULL,'Brisbin, PA',4894,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11759,NULL,'Brisbin, PA 16620',4894,222,NULL,44,6572,0);
INSERT INTO "django_geo_db_location" VALUES(11760,NULL,'Broad Top, PA',4895,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11761,NULL,'Broad Top, PA 16621',4895,222,NULL,44,6573,0);
INSERT INTO "django_geo_db_location" VALUES(11762,NULL,'Calvin, PA',4896,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11763,NULL,'Calvin, PA 16622',4896,222,NULL,44,6574,0);
INSERT INTO "django_geo_db_location" VALUES(11764,NULL,'Cassville, PA',4897,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11765,NULL,'Cassville, PA 16623',4897,222,NULL,44,6575,0);
INSERT INTO "django_geo_db_location" VALUES(11766,NULL,'Chest Springs, PA',4898,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11767,NULL,'Chest Springs, PA 16624',4898,222,NULL,44,6576,0);
INSERT INTO "django_geo_db_location" VALUES(11768,NULL,'Claysburg, PA',4899,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11769,NULL,'Claysburg, PA 16625',4899,222,NULL,44,6577,0);
INSERT INTO "django_geo_db_location" VALUES(11770,NULL,'Coalport, PA',4900,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11771,NULL,'Coalport, PA 16627',4900,222,NULL,44,6578,0);
INSERT INTO "django_geo_db_location" VALUES(11772,NULL,'Coupon, PA',4901,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11773,NULL,'Coupon, PA 16629',4901,222,NULL,44,6579,0);
INSERT INTO "django_geo_db_location" VALUES(11774,NULL,'Cresson, PA',4902,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11775,NULL,'Cresson, PA 16630',4902,222,NULL,44,6580,0);
INSERT INTO "django_geo_db_location" VALUES(11776,NULL,'Curryville, PA',4903,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11777,NULL,'Curryville, PA 16631',4903,222,NULL,44,6581,0);
INSERT INTO "django_geo_db_location" VALUES(11778,NULL,'Defiance, PA',4904,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11779,NULL,'Defiance, PA 16633',4904,222,NULL,44,6582,0);
INSERT INTO "django_geo_db_location" VALUES(11780,NULL,'Dudley, PA',4905,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11781,NULL,'Dudley, PA 16634',4905,222,NULL,44,6583,0);
INSERT INTO "django_geo_db_location" VALUES(11782,NULL,'Duncansville, PA',4906,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11783,NULL,'Duncansville, PA 16635',4906,222,NULL,44,6584,0);
INSERT INTO "django_geo_db_location" VALUES(11784,NULL,'Dysart, PA',4907,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11785,NULL,'Dysart, PA 16636',4907,222,NULL,44,6585,0);
INSERT INTO "django_geo_db_location" VALUES(11786,NULL,'East Freedom, PA',4908,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11787,NULL,'East Freedom, PA 16637',4908,222,NULL,44,6586,0);
INSERT INTO "django_geo_db_location" VALUES(11788,NULL,'Entriken, PA',4909,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11789,NULL,'Entriken, PA 16638',4909,222,NULL,44,6587,0);
INSERT INTO "django_geo_db_location" VALUES(11790,NULL,'Fallentimber, PA',4910,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11791,NULL,'Fallentimber, PA 16639',4910,222,NULL,44,6588,0);
INSERT INTO "django_geo_db_location" VALUES(11792,NULL,'Flinton, PA',4911,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11793,NULL,'Flinton, PA 16640',4911,222,NULL,44,6589,0);
INSERT INTO "django_geo_db_location" VALUES(11794,NULL,'Gallitzin, PA',4912,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11795,NULL,'Gallitzin, PA 16641',4912,222,NULL,44,6590,0);
INSERT INTO "django_geo_db_location" VALUES(11796,NULL,'Glasgow, PA',4913,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11797,NULL,'Glasgow, PA 16644',4913,222,NULL,44,6591,0);
INSERT INTO "django_geo_db_location" VALUES(11798,NULL,'Glen Hope, PA',4914,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11799,NULL,'Glen Hope, PA 16645',4914,222,NULL,44,6592,0);
INSERT INTO "django_geo_db_location" VALUES(11800,NULL,'Hastings, PA',4915,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11801,NULL,'Hastings, PA 16646',4915,222,NULL,44,6593,0);
INSERT INTO "django_geo_db_location" VALUES(11802,NULL,'Hesston, PA',4916,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11803,NULL,'Hesston, PA 16647',4916,222,NULL,44,6594,0);
INSERT INTO "django_geo_db_location" VALUES(11804,NULL,'Hollidaysburg, PA',4917,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11805,NULL,'Hollidaysburg, PA 16648',4917,222,NULL,44,6595,0);
INSERT INTO "django_geo_db_location" VALUES(11806,NULL,'Hopewell, PA',4918,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11807,NULL,'Hopewell, PA 16650',4918,222,NULL,44,6596,0);
INSERT INTO "django_geo_db_location" VALUES(11808,NULL,'Houtzdale, PA',4919,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11809,NULL,'Houtzdale, PA 16651',4919,222,NULL,44,6597,0);
INSERT INTO "django_geo_db_location" VALUES(11810,NULL,'Huntingdon, PA',4920,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11811,NULL,'Huntingdon, PA 16652',4920,222,NULL,44,6598,0);
INSERT INTO "django_geo_db_location" VALUES(11812,NULL,'Huntingdon, PA 16654',4920,222,NULL,44,6599,0);
INSERT INTO "django_geo_db_location" VALUES(11813,NULL,'Imler, PA',4921,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11814,NULL,'Imler, PA 16655',4921,222,NULL,44,6600,0);
INSERT INTO "django_geo_db_location" VALUES(11815,NULL,'Irvona, PA',4922,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11816,NULL,'Irvona, PA 16656',4922,222,NULL,44,6601,0);
INSERT INTO "django_geo_db_location" VALUES(11817,NULL,'James Creek, PA',4923,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11818,NULL,'James Creek, PA 16657',4923,222,NULL,44,6602,0);
INSERT INTO "django_geo_db_location" VALUES(11819,NULL,'Loysburg, PA',4924,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11820,NULL,'Loysburg, PA 16659',4924,222,NULL,44,6603,0);
INSERT INTO "django_geo_db_location" VALUES(11821,NULL,'McConnellstown, PA',4925,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11822,NULL,'McConnellstown, PA 16660',4925,222,NULL,44,6604,0);
INSERT INTO "django_geo_db_location" VALUES(11823,NULL,'Madera, PA',4926,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11824,NULL,'Madera, PA 16661',4926,222,NULL,44,6605,0);
INSERT INTO "django_geo_db_location" VALUES(11825,NULL,'Martinsburg, PA',4927,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11826,NULL,'Martinsburg, PA 16662',4927,222,NULL,44,6606,0);
INSERT INTO "django_geo_db_location" VALUES(11827,NULL,'Morann, PA',4928,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11828,NULL,'Morann, PA 16663',4928,222,NULL,44,6607,0);
INSERT INTO "django_geo_db_location" VALUES(11829,NULL,'New Enterprise, PA',4929,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11830,NULL,'New Enterprise, PA 16664',4929,222,NULL,44,6608,0);
INSERT INTO "django_geo_db_location" VALUES(11831,NULL,'Newry, PA',4930,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11832,NULL,'Newry, PA 16665',4930,222,NULL,44,6609,0);
INSERT INTO "django_geo_db_location" VALUES(11833,NULL,'Osceola Mills, PA',4931,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11834,NULL,'Osceola Mills, PA 16666',4931,222,NULL,44,6610,0);
INSERT INTO "django_geo_db_location" VALUES(11835,NULL,'Osterburg, PA',4932,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11836,NULL,'Osterburg, PA 16667',4932,222,NULL,44,6611,0);
INSERT INTO "django_geo_db_location" VALUES(11837,NULL,'Patton, PA',4933,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11838,NULL,'Patton, PA 16668',4933,222,NULL,44,6612,0);
INSERT INTO "django_geo_db_location" VALUES(11839,NULL,'Petersburg, PA',4934,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11840,NULL,'Petersburg, PA 16669',4934,222,NULL,44,6613,0);
INSERT INTO "django_geo_db_location" VALUES(11841,NULL,'Queen, PA',4935,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11842,NULL,'Queen, PA 16670',4935,222,NULL,44,6614,0);
INSERT INTO "django_geo_db_location" VALUES(11843,NULL,'Ramey, PA',4936,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11844,NULL,'Ramey, PA 16671',4936,222,NULL,44,6615,0);
INSERT INTO "django_geo_db_location" VALUES(11845,NULL,'Riddlesburg, PA',4937,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11846,NULL,'Riddlesburg, PA 16672',4937,222,NULL,44,6616,0);
INSERT INTO "django_geo_db_location" VALUES(11847,NULL,'Roaring Spring, PA',4938,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11848,NULL,'Roaring Spring, PA 16673',4938,222,NULL,44,6617,0);
INSERT INTO "django_geo_db_location" VALUES(11849,NULL,'Robertsdale, PA',4939,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11850,NULL,'Robertsdale, PA 16674',4939,222,NULL,44,6618,0);
INSERT INTO "django_geo_db_location" VALUES(11851,NULL,'Saint Boniface, PA',4940,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11852,NULL,'Saint Boniface, PA 16675',4940,222,NULL,44,6619,0);
INSERT INTO "django_geo_db_location" VALUES(11853,NULL,'Sandy Ridge, PA',4941,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11854,NULL,'Sandy Ridge, PA 16677',4941,222,NULL,44,6620,0);
INSERT INTO "django_geo_db_location" VALUES(11855,NULL,'Saxton, PA',4942,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11856,NULL,'Saxton, PA 16678',4942,222,NULL,44,6621,0);
INSERT INTO "django_geo_db_location" VALUES(11857,NULL,'Six Mile Run, PA',4943,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11858,NULL,'Six Mile Run, PA 16679',4943,222,NULL,44,6622,0);
INSERT INTO "django_geo_db_location" VALUES(11859,NULL,'Smithmill, PA',4944,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11860,NULL,'Smithmill, PA 16680',4944,222,NULL,44,6623,0);
INSERT INTO "django_geo_db_location" VALUES(11861,NULL,'Smokerun, PA',4945,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11862,NULL,'Smokerun, PA 16681',4945,222,NULL,44,6624,0);
INSERT INTO "django_geo_db_location" VALUES(11863,NULL,'Sproul, PA',4946,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11864,NULL,'Sproul, PA 16682',4946,222,NULL,44,6625,0);
INSERT INTO "django_geo_db_location" VALUES(11865,NULL,'Spruce Creek, PA',4947,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11866,NULL,'Spruce Creek, PA 16683',4947,222,NULL,44,6626,0);
INSERT INTO "django_geo_db_location" VALUES(11867,NULL,'Tipton, PA',4948,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11868,NULL,'Tipton, PA 16684',4948,222,NULL,44,6627,0);
INSERT INTO "django_geo_db_location" VALUES(11869,NULL,'Todd, PA',4949,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11870,NULL,'Todd, PA 16685',4949,222,NULL,44,6628,0);
INSERT INTO "django_geo_db_location" VALUES(11871,NULL,'Tyrone, PA',4950,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11872,NULL,'Tyrone, PA 16686',4950,222,NULL,44,6629,0);
INSERT INTO "django_geo_db_location" VALUES(11873,NULL,'Waterfall, PA',4951,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11874,NULL,'Waterfall, PA 16689',4951,222,NULL,44,6630,0);
INSERT INTO "django_geo_db_location" VALUES(11875,NULL,'Wells Tannery, PA',4952,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11876,NULL,'Wells Tannery, PA 16691',4952,222,NULL,44,6631,0);
INSERT INTO "django_geo_db_location" VALUES(11877,NULL,'Westover, PA',4953,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11878,NULL,'Westover, PA 16692',4953,222,NULL,44,6632,0);
INSERT INTO "django_geo_db_location" VALUES(11879,NULL,'Williamsburg, PA',4954,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11880,NULL,'Williamsburg, PA 16693',4954,222,NULL,44,6633,0);
INSERT INTO "django_geo_db_location" VALUES(11881,NULL,'Wood, PA',4955,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11882,NULL,'Wood, PA 16694',4955,222,NULL,44,6634,0);
INSERT INTO "django_geo_db_location" VALUES(11883,NULL,'Woodbury, PA',4956,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11884,NULL,'Woodbury, PA 16695',4956,222,NULL,44,6635,0);
INSERT INTO "django_geo_db_location" VALUES(11885,NULL,'Houtzdale, PA 16698',4919,222,NULL,44,6636,0);
INSERT INTO "django_geo_db_location" VALUES(11886,NULL,'Cresson, PA 16699',4902,222,NULL,44,6637,0);
INSERT INTO "django_geo_db_location" VALUES(11887,NULL,'Bradford, PA',4957,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11888,NULL,'Bradford, PA 16701',4957,222,NULL,44,6638,0);
INSERT INTO "django_geo_db_location" VALUES(11889,NULL,'Austin, PA',4958,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11890,NULL,'Austin, PA 16720',4958,222,NULL,44,6639,0);
INSERT INTO "django_geo_db_location" VALUES(11891,NULL,'Crosby, PA',4959,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11892,NULL,'Crosby, PA 16724',4959,222,NULL,44,6640,0);
INSERT INTO "django_geo_db_location" VALUES(11893,NULL,'Custer City, PA',4960,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11894,NULL,'Custer City, PA 16725',4960,222,NULL,44,6641,0);
INSERT INTO "django_geo_db_location" VALUES(11895,NULL,'Cyclone, PA',4961,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11896,NULL,'Cyclone, PA 16726',4961,222,NULL,44,6642,0);
INSERT INTO "django_geo_db_location" VALUES(11897,NULL,'Derrick City, PA',4962,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11898,NULL,'Derrick City, PA 16727',4962,222,NULL,44,6643,0);
INSERT INTO "django_geo_db_location" VALUES(11899,NULL,'De Young, PA',4963,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11900,NULL,'De Young, PA 16728',4963,222,NULL,44,6644,0);
INSERT INTO "django_geo_db_location" VALUES(11901,NULL,'Duke Center, PA',4964,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11902,NULL,'Duke Center, PA 16729',4964,222,NULL,44,6645,0);
INSERT INTO "django_geo_db_location" VALUES(11903,NULL,'East Smethport, PA',4965,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11904,NULL,'East Smethport, PA 16730',4965,222,NULL,44,6646,0);
INSERT INTO "django_geo_db_location" VALUES(11905,NULL,'Eldred, PA',4966,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11906,NULL,'Eldred, PA 16731',4966,222,NULL,44,6647,0);
INSERT INTO "django_geo_db_location" VALUES(11907,NULL,'Gifford, PA',4967,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11908,NULL,'Gifford, PA 16732',4967,222,NULL,44,6648,0);
INSERT INTO "django_geo_db_location" VALUES(11909,NULL,'Hazel Hurst, PA',4968,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11910,NULL,'Hazel Hurst, PA 16733',4968,222,NULL,44,6649,0);
INSERT INTO "django_geo_db_location" VALUES(11911,NULL,'James City, PA',4969,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11912,NULL,'James City, PA 16734',4969,222,NULL,44,6650,0);
INSERT INTO "django_geo_db_location" VALUES(11913,NULL,'Kane, PA',4970,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11914,NULL,'Kane, PA 16735',4970,222,NULL,44,6651,0);
INSERT INTO "django_geo_db_location" VALUES(11915,NULL,'Lewis Run, PA',4971,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11916,NULL,'Lewis Run, PA 16738',4971,222,NULL,44,6652,0);
INSERT INTO "django_geo_db_location" VALUES(11917,NULL,'Mount Jewett, PA',4972,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11918,NULL,'Mount Jewett, PA 16740',4972,222,NULL,44,6653,0);
INSERT INTO "django_geo_db_location" VALUES(11919,NULL,'Port Allegany, PA',4973,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11920,NULL,'Port Allegany, PA 16743',4973,222,NULL,44,6654,0);
INSERT INTO "django_geo_db_location" VALUES(11921,NULL,'Rew, PA',4974,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11922,NULL,'Rew, PA 16744',4974,222,NULL,44,6655,0);
INSERT INTO "django_geo_db_location" VALUES(11923,NULL,'Rixford, PA',4975,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11924,NULL,'Rixford, PA 16745',4975,222,NULL,44,6656,0);
INSERT INTO "django_geo_db_location" VALUES(11925,NULL,'Roulette, PA',4976,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11926,NULL,'Roulette, PA 16746',4976,222,NULL,44,6657,0);
INSERT INTO "django_geo_db_location" VALUES(11927,NULL,'Shinglehouse, PA',4977,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11928,NULL,'Shinglehouse, PA 16748',4977,222,NULL,44,6658,0);
INSERT INTO "django_geo_db_location" VALUES(11929,NULL,'Smethport, PA',4978,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11930,NULL,'Smethport, PA 16749',4978,222,NULL,44,6659,0);
INSERT INTO "django_geo_db_location" VALUES(11931,NULL,'Turtlepoint, PA',4979,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11932,NULL,'Turtlepoint, PA 16750',4979,222,NULL,44,6660,0);
INSERT INTO "django_geo_db_location" VALUES(11933,NULL,'Westline, PA',4980,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11934,NULL,'Westline, PA 16751',4980,222,NULL,44,6661,0);
INSERT INTO "django_geo_db_location" VALUES(11935,NULL,'State College, PA',4981,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11936,NULL,'State College, PA 16801',4981,222,NULL,44,6662,0);
INSERT INTO "django_geo_db_location" VALUES(11937,NULL,'University Park, PA',4982,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11938,NULL,'University Park, PA 16802',4982,222,NULL,44,6663,0);
INSERT INTO "django_geo_db_location" VALUES(11939,NULL,'State College, PA 16803',4981,222,NULL,44,6664,0);
INSERT INTO "django_geo_db_location" VALUES(11940,NULL,'State College, PA 16804',4981,222,NULL,44,6665,0);
INSERT INTO "django_geo_db_location" VALUES(11941,NULL,'State College, PA 16805',4981,222,NULL,44,6666,0);
INSERT INTO "django_geo_db_location" VALUES(11942,NULL,'Potter, PA',4983,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11943,NULL,'Potter, PA 16815',4983,222,NULL,44,6667,0);
INSERT INTO "django_geo_db_location" VALUES(11944,NULL,'Aaronsburg, PA',4984,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11945,NULL,'Aaronsburg, PA 16820',4984,222,NULL,44,6668,0);
INSERT INTO "django_geo_db_location" VALUES(11946,NULL,'Allport, PA',4985,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11947,NULL,'Allport, PA 16821',4985,222,NULL,44,6669,0);
INSERT INTO "django_geo_db_location" VALUES(11948,NULL,'Beech Creek, PA',4986,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11949,NULL,'Beech Creek, PA 16822',4986,222,NULL,44,6670,0);
INSERT INTO "django_geo_db_location" VALUES(11950,NULL,'Bellefonte, PA',4987,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11951,NULL,'Bellefonte, PA 16823',4987,222,NULL,44,6671,0);
INSERT INTO "django_geo_db_location" VALUES(11952,NULL,'Bigler, PA',4988,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11953,NULL,'Bigler, PA 16825',4988,222,NULL,44,6672,0);
INSERT INTO "django_geo_db_location" VALUES(11954,NULL,'Blanchard, PA',4989,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11955,NULL,'Blanchard, PA 16826',4989,222,NULL,44,6673,0);
INSERT INTO "django_geo_db_location" VALUES(11956,NULL,'Boalsburg, PA',4990,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11957,NULL,'Boalsburg, PA 16827',4990,222,NULL,44,6674,0);
INSERT INTO "django_geo_db_location" VALUES(11958,NULL,'Centre Hall, PA',4991,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11959,NULL,'Centre Hall, PA 16828',4991,222,NULL,44,6675,0);
INSERT INTO "django_geo_db_location" VALUES(11960,NULL,'Clarence, PA',4992,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11961,NULL,'Clarence, PA 16829',4992,222,NULL,44,6676,0);
INSERT INTO "django_geo_db_location" VALUES(11962,NULL,'Clearfield, PA',4993,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11963,NULL,'Clearfield, PA 16830',4993,222,NULL,44,6677,0);
INSERT INTO "django_geo_db_location" VALUES(11964,NULL,'Coburn, PA',4994,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11965,NULL,'Coburn, PA 16832',4994,222,NULL,44,6678,0);
INSERT INTO "django_geo_db_location" VALUES(11966,NULL,'Curwensville, PA',4995,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11967,NULL,'Curwensville, PA 16833',4995,222,NULL,44,6679,0);
INSERT INTO "django_geo_db_location" VALUES(11968,NULL,'Drifting, PA',4996,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11969,NULL,'Drifting, PA 16834',4996,222,NULL,44,6680,0);
INSERT INTO "django_geo_db_location" VALUES(11970,NULL,'Fleming, PA',4997,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11971,NULL,'Fleming, PA 16835',4997,222,NULL,44,6681,0);
INSERT INTO "django_geo_db_location" VALUES(11972,NULL,'Frenchville, PA',4998,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11973,NULL,'Frenchville, PA 16836',4998,222,NULL,44,6682,0);
INSERT INTO "django_geo_db_location" VALUES(11974,NULL,'Glen Richey, PA',4999,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11975,NULL,'Glen Richey, PA 16837',4999,222,NULL,44,6683,0);
INSERT INTO "django_geo_db_location" VALUES(11976,NULL,'Grampian, PA',5000,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11977,NULL,'Grampian, PA 16838',5000,222,NULL,44,6684,0);
INSERT INTO "django_geo_db_location" VALUES(11978,NULL,'Grassflat, PA',5001,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11979,NULL,'Grassflat, PA 16839',5001,222,NULL,44,6685,0);
INSERT INTO "django_geo_db_location" VALUES(11980,NULL,'Hawk Run, PA',5002,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11981,NULL,'Hawk Run, PA 16840',5002,222,NULL,44,6686,0);
INSERT INTO "django_geo_db_location" VALUES(11982,NULL,'Howard, PA',5003,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11983,NULL,'Howard, PA 16841',5003,222,NULL,44,6687,0);
INSERT INTO "django_geo_db_location" VALUES(11984,NULL,'Hyde, PA',5004,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11985,NULL,'Hyde, PA 16843',5004,222,NULL,44,6688,0);
INSERT INTO "django_geo_db_location" VALUES(11986,NULL,'Julian, PA',5005,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11987,NULL,'Julian, PA 16844',5005,222,NULL,44,6689,0);
INSERT INTO "django_geo_db_location" VALUES(11988,NULL,'Karthaus, PA',5006,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11989,NULL,'Karthaus, PA 16845',5006,222,NULL,44,6690,0);
INSERT INTO "django_geo_db_location" VALUES(11990,NULL,'Kylertown, PA',5007,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11991,NULL,'Kylertown, PA 16847',5007,222,NULL,44,6691,0);
INSERT INTO "django_geo_db_location" VALUES(11992,NULL,'Lamar, PA',5008,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11993,NULL,'Lamar, PA 16848',5008,222,NULL,44,6692,0);
INSERT INTO "django_geo_db_location" VALUES(11994,NULL,'Lanse, PA',5009,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11995,NULL,'Lanse, PA 16849',5009,222,NULL,44,6693,0);
INSERT INTO "django_geo_db_location" VALUES(11996,NULL,'Lecontes Mills, PA',5010,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11997,NULL,'Lecontes Mills, PA 16850',5010,222,NULL,44,6694,0);
INSERT INTO "django_geo_db_location" VALUES(11998,NULL,'Lemont, PA',5011,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(11999,NULL,'Lemont, PA 16851',5011,222,NULL,44,6695,0);
INSERT INTO "django_geo_db_location" VALUES(12000,NULL,'Madisonburg, PA',5012,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12001,NULL,'Madisonburg, PA 16852',5012,222,NULL,44,6696,0);
INSERT INTO "django_geo_db_location" VALUES(12002,NULL,'Milesburg, PA',5013,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12003,NULL,'Milesburg, PA 16853',5013,222,NULL,44,6697,0);
INSERT INTO "django_geo_db_location" VALUES(12004,NULL,'Millheim, PA',5014,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12005,NULL,'Millheim, PA 16854',5014,222,NULL,44,6698,0);
INSERT INTO "django_geo_db_location" VALUES(12006,NULL,'Mineral Springs, PA',5015,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12007,NULL,'Mineral Springs, PA 16855',5015,222,NULL,44,6699,0);
INSERT INTO "django_geo_db_location" VALUES(12008,NULL,'Mingoville, PA',5016,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12009,NULL,'Mingoville, PA 16856',5016,222,NULL,44,6700,0);
INSERT INTO "django_geo_db_location" VALUES(12010,NULL,'Morrisdale, PA',5017,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12011,NULL,'Morrisdale, PA 16858',5017,222,NULL,44,6701,0);
INSERT INTO "django_geo_db_location" VALUES(12012,NULL,'Moshannon, PA',5018,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12013,NULL,'Moshannon, PA 16859',5018,222,NULL,44,6702,0);
INSERT INTO "django_geo_db_location" VALUES(12014,NULL,'Munson, PA',5019,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12015,NULL,'Munson, PA 16860',5019,222,NULL,44,6703,0);
INSERT INTO "django_geo_db_location" VALUES(12016,NULL,'New Millport, PA',5020,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12017,NULL,'New Millport, PA 16861',5020,222,NULL,44,6704,0);
INSERT INTO "django_geo_db_location" VALUES(12018,NULL,'Olanta, PA',5021,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12019,NULL,'Olanta, PA 16863',5021,222,NULL,44,6705,0);
INSERT INTO "django_geo_db_location" VALUES(12020,NULL,'Orviston, PA',5022,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12021,NULL,'Orviston, PA 16864',5022,222,NULL,44,6706,0);
INSERT INTO "django_geo_db_location" VALUES(12022,NULL,'Pennsylvania Furnace, PA',5023,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12023,NULL,'Pennsylvania Furnace, PA 16865',5023,222,NULL,44,6707,0);
INSERT INTO "django_geo_db_location" VALUES(12024,NULL,'Philipsburg, PA',5024,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12025,NULL,'Philipsburg, PA 16866',5024,222,NULL,44,6708,0);
INSERT INTO "django_geo_db_location" VALUES(12026,NULL,'Pine Grove Mills, PA',5025,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12027,NULL,'Pine Grove Mills, PA 16868',5025,222,NULL,44,6709,0);
INSERT INTO "django_geo_db_location" VALUES(12028,NULL,'Port Matilda, PA',5026,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12029,NULL,'Port Matilda, PA 16870',5026,222,NULL,44,6710,0);
INSERT INTO "django_geo_db_location" VALUES(12030,NULL,'Pottersdale, PA',5027,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12031,NULL,'Pottersdale, PA 16871',5027,222,NULL,44,6711,0);
INSERT INTO "django_geo_db_location" VALUES(12032,NULL,'Rebersburg, PA',5028,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12033,NULL,'Rebersburg, PA 16872',5028,222,NULL,44,6712,0);
INSERT INTO "django_geo_db_location" VALUES(12034,NULL,'Shawville, PA',5029,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12035,NULL,'Shawville, PA 16873',5029,222,NULL,44,6713,0);
INSERT INTO "django_geo_db_location" VALUES(12036,NULL,'Snow Shoe, PA',5030,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12037,NULL,'Snow Shoe, PA 16874',5030,222,NULL,44,6714,0);
INSERT INTO "django_geo_db_location" VALUES(12038,NULL,'Spring Mills, PA',5031,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12039,NULL,'Spring Mills, PA 16875',5031,222,NULL,44,6715,0);
INSERT INTO "django_geo_db_location" VALUES(12040,NULL,'Wallaceton, PA',5032,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12041,NULL,'Wallaceton, PA 16876',5032,222,NULL,44,6716,0);
INSERT INTO "django_geo_db_location" VALUES(12042,NULL,'Warriors Mark, PA',5033,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12043,NULL,'Warriors Mark, PA 16877',5033,222,NULL,44,6717,0);
INSERT INTO "django_geo_db_location" VALUES(12044,NULL,'West Decatur, PA',5034,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12045,NULL,'West Decatur, PA 16878',5034,222,NULL,44,6718,0);
INSERT INTO "django_geo_db_location" VALUES(12046,NULL,'Winburne, PA',5035,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12047,NULL,'Winburne, PA 16879',5035,222,NULL,44,6719,0);
INSERT INTO "django_geo_db_location" VALUES(12048,NULL,'Woodland, PA',5036,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12049,NULL,'Woodland, PA 16881',5036,222,NULL,44,6720,0);
INSERT INTO "django_geo_db_location" VALUES(12050,NULL,'Woodward, PA',5037,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12051,NULL,'Woodward, PA 16882',5037,222,NULL,44,6721,0);
INSERT INTO "django_geo_db_location" VALUES(12052,NULL,'Wellsboro, PA',5038,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12053,NULL,'Wellsboro, PA 16901',5038,222,NULL,44,6722,0);
INSERT INTO "django_geo_db_location" VALUES(12054,NULL,'Alba, PA',5039,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12055,NULL,'Alba, PA 16910',5039,222,NULL,44,6723,0);
INSERT INTO "django_geo_db_location" VALUES(12056,NULL,'Arnot, PA',5040,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12057,NULL,'Arnot, PA 16911',5040,222,NULL,44,6724,0);
INSERT INTO "django_geo_db_location" VALUES(12058,NULL,'Blossburg, PA',5041,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12059,NULL,'Blossburg, PA 16912',5041,222,NULL,44,6725,0);
INSERT INTO "django_geo_db_location" VALUES(12060,NULL,'Columbia Cross Roads, PA',5042,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12061,NULL,'Columbia Cross Roads, PA 16914',5042,222,NULL,44,6726,0);
INSERT INTO "django_geo_db_location" VALUES(12062,NULL,'Coudersport, PA',5043,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12063,NULL,'Coudersport, PA 16915',5043,222,NULL,44,6727,0);
INSERT INTO "django_geo_db_location" VALUES(12064,NULL,'Covington, PA',5044,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12065,NULL,'Covington, PA 16917',5044,222,NULL,44,6728,0);
INSERT INTO "django_geo_db_location" VALUES(12066,NULL,'Cowanesque, PA',5045,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12067,NULL,'Cowanesque, PA 16918',5045,222,NULL,44,6729,0);
INSERT INTO "django_geo_db_location" VALUES(12068,NULL,'Elkland, PA',5046,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12069,NULL,'Elkland, PA 16920',5046,222,NULL,44,6730,0);
INSERT INTO "django_geo_db_location" VALUES(12070,NULL,'Gaines, PA',5047,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12071,NULL,'Gaines, PA 16921',5047,222,NULL,44,6731,0);
INSERT INTO "django_geo_db_location" VALUES(12072,NULL,'Galeton, PA',5048,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12073,NULL,'Galeton, PA 16922',5048,222,NULL,44,6732,0);
INSERT INTO "django_geo_db_location" VALUES(12074,NULL,'Genesee, PA',5049,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12075,NULL,'Genesee, PA 16923',5049,222,NULL,44,6733,0);
INSERT INTO "django_geo_db_location" VALUES(12076,NULL,'Gillett, PA',5050,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12077,NULL,'Gillett, PA 16925',5050,222,NULL,44,6734,0);
INSERT INTO "django_geo_db_location" VALUES(12078,NULL,'Granville Summit, PA',5051,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12079,NULL,'Granville Summit, PA 16926',5051,222,NULL,44,6735,0);
INSERT INTO "django_geo_db_location" VALUES(12080,NULL,'Harrison Valley, PA',5052,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12081,NULL,'Harrison Valley, PA 16927',5052,222,NULL,44,6736,0);
INSERT INTO "django_geo_db_location" VALUES(12082,NULL,'Knoxville, PA',5053,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12083,NULL,'Knoxville, PA 16928',5053,222,NULL,44,6737,0);
INSERT INTO "django_geo_db_location" VALUES(12084,NULL,'Lawrenceville, PA',5054,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12085,NULL,'Lawrenceville, PA 16929',5054,222,NULL,44,6738,0);
INSERT INTO "django_geo_db_location" VALUES(12086,NULL,'Liberty, PA',5055,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12087,NULL,'Liberty, PA 16930',5055,222,NULL,44,6739,0);
INSERT INTO "django_geo_db_location" VALUES(12088,NULL,'Mainesburg, PA',5056,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12089,NULL,'Mainesburg, PA 16932',5056,222,NULL,44,6740,0);
INSERT INTO "django_geo_db_location" VALUES(12090,NULL,'Mansfield, PA',5057,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12091,NULL,'Mansfield, PA 16933',5057,222,NULL,44,6741,0);
INSERT INTO "django_geo_db_location" VALUES(12092,NULL,'Middlebury Center, PA',5058,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12093,NULL,'Middlebury Center, PA 16935',5058,222,NULL,44,6742,0);
INSERT INTO "django_geo_db_location" VALUES(12094,NULL,'Millerton, PA',5059,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12095,NULL,'Millerton, PA 16936',5059,222,NULL,44,6743,0);
INSERT INTO "django_geo_db_location" VALUES(12096,NULL,'Mills, PA',5060,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12097,NULL,'Mills, PA 16937',5060,222,NULL,44,6744,0);
INSERT INTO "django_geo_db_location" VALUES(12098,NULL,'Morris, PA',5061,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12099,NULL,'Morris, PA 16938',5061,222,NULL,44,6745,0);
INSERT INTO "django_geo_db_location" VALUES(12100,NULL,'Morris Run, PA',5062,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12101,NULL,'Morris Run, PA 16939',5062,222,NULL,44,6746,0);
INSERT INTO "django_geo_db_location" VALUES(12102,NULL,'Nelson, PA',5063,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12103,NULL,'Nelson, PA 16940',5063,222,NULL,44,6747,0);
INSERT INTO "django_geo_db_location" VALUES(12104,NULL,'Genesee, PA 16941',5049,222,NULL,44,6748,0);
INSERT INTO "django_geo_db_location" VALUES(12105,NULL,'Osceola, PA',5064,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12106,NULL,'Osceola, PA 16942',5064,222,NULL,44,6749,0);
INSERT INTO "django_geo_db_location" VALUES(12107,NULL,'Sabinsville, PA',5065,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12108,NULL,'Sabinsville, PA 16943',5065,222,NULL,44,6750,0);
INSERT INTO "django_geo_db_location" VALUES(12109,NULL,'Sylvania, PA',5066,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12110,NULL,'Sylvania, PA 16945',5066,222,NULL,44,6751,0);
INSERT INTO "django_geo_db_location" VALUES(12111,NULL,'Tioga, PA',5067,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12112,NULL,'Tioga, PA 16946',5067,222,NULL,44,6752,0);
INSERT INTO "django_geo_db_location" VALUES(12113,NULL,'Troy, PA',5068,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12114,NULL,'Troy, PA 16947',5068,222,NULL,44,6753,0);
INSERT INTO "django_geo_db_location" VALUES(12115,NULL,'Ulysses, PA',5069,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12116,NULL,'Ulysses, PA 16948',5069,222,NULL,44,6754,0);
INSERT INTO "django_geo_db_location" VALUES(12117,NULL,'Westfield, PA',5070,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12118,NULL,'Westfield, PA 16950',5070,222,NULL,44,6755,0);
INSERT INTO "django_geo_db_location" VALUES(12119,NULL,'Camp Hill, PA',5071,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12120,NULL,'Camp Hill, PA 17001',5071,222,NULL,44,6756,0);
INSERT INTO "django_geo_db_location" VALUES(12121,NULL,'Allensville, PA',5072,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12122,NULL,'Allensville, PA 17002',5072,222,NULL,44,6757,0);
INSERT INTO "django_geo_db_location" VALUES(12123,NULL,'Annville, PA',5073,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12124,NULL,'Annville, PA 17003',5073,222,NULL,44,6758,0);
INSERT INTO "django_geo_db_location" VALUES(12125,NULL,'Belleville, PA',5074,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12126,NULL,'Belleville, PA 17004',5074,222,NULL,44,6759,0);
INSERT INTO "django_geo_db_location" VALUES(12127,NULL,'Berrysburg, PA',5075,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12128,NULL,'Berrysburg, PA 17005',5075,222,NULL,44,6760,0);
INSERT INTO "django_geo_db_location" VALUES(12129,NULL,'Blain, PA',5076,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12130,NULL,'Blain, PA 17006',5076,222,NULL,44,6761,0);
INSERT INTO "django_geo_db_location" VALUES(12131,NULL,'Boiling Springs, PA',5077,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12132,NULL,'Boiling Springs, PA 17007',5077,222,NULL,44,6762,0);
INSERT INTO "django_geo_db_location" VALUES(12133,NULL,'Bowmansdale, PA',5078,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12134,NULL,'Bowmansdale, PA 17008',5078,222,NULL,44,6763,0);
INSERT INTO "django_geo_db_location" VALUES(12135,NULL,'Burnham, PA',5079,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12136,NULL,'Burnham, PA 17009',5079,222,NULL,44,6764,0);
INSERT INTO "django_geo_db_location" VALUES(12137,NULL,'Campbelltown, PA',5080,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12138,NULL,'Campbelltown, PA 17010',5080,222,NULL,44,6765,0);
INSERT INTO "django_geo_db_location" VALUES(12139,NULL,'Camp Hill, PA 17011',5071,222,NULL,44,6766,0);
INSERT INTO "django_geo_db_location" VALUES(12140,NULL,'Camp Hill, PA 17012',5071,222,NULL,44,6767,0);
INSERT INTO "django_geo_db_location" VALUES(12141,NULL,'Carlisle, PA',5081,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12142,NULL,'Carlisle, PA 17013',5081,222,NULL,44,6768,0);
INSERT INTO "django_geo_db_location" VALUES(12143,NULL,'Cocolamus, PA',5082,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12144,NULL,'Cocolamus, PA 17014',5082,222,NULL,44,6769,0);
INSERT INTO "django_geo_db_location" VALUES(12145,NULL,'South Londonderry, PA',5083,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12146,NULL,'South Londonderry, PA 17015',5083,222,NULL,44,6770,0);
INSERT INTO "django_geo_db_location" VALUES(12147,NULL,'Cornwall, PA',5084,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12148,NULL,'Cornwall, PA 17016',5084,222,NULL,44,6771,0);
INSERT INTO "django_geo_db_location" VALUES(12149,NULL,'Dalmatia, PA',5085,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12150,NULL,'Dalmatia, PA 17017',5085,222,NULL,44,6772,0);
INSERT INTO "django_geo_db_location" VALUES(12151,NULL,'Dauphin, PA',5086,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12152,NULL,'Dauphin, PA 17018',5086,222,NULL,44,6773,0);
INSERT INTO "django_geo_db_location" VALUES(12153,NULL,'Dillsburg, PA',5087,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12154,NULL,'Dillsburg, PA 17019',5087,222,NULL,44,6774,0);
INSERT INTO "django_geo_db_location" VALUES(12155,NULL,'Duncannon, PA',5088,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12156,NULL,'Duncannon, PA 17020',5088,222,NULL,44,6775,0);
INSERT INTO "django_geo_db_location" VALUES(12157,NULL,'East Waterford, PA',5089,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12158,NULL,'East Waterford, PA 17021',5089,222,NULL,44,6776,0);
INSERT INTO "django_geo_db_location" VALUES(12159,NULL,'Elizabethtown, PA',5090,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12160,NULL,'Elizabethtown, PA 17022',5090,222,NULL,44,6777,0);
INSERT INTO "django_geo_db_location" VALUES(12161,NULL,'Elizabethville, PA',5091,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12162,NULL,'Elizabethville, PA 17023',5091,222,NULL,44,6778,0);
INSERT INTO "django_geo_db_location" VALUES(12163,NULL,'Elliottsburg, PA',5092,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12164,NULL,'Elliottsburg, PA 17024',5092,222,NULL,44,6779,0);
INSERT INTO "django_geo_db_location" VALUES(12165,NULL,'Enola, PA',5093,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12166,NULL,'Enola, PA 17025',5093,222,NULL,44,6780,0);
INSERT INTO "django_geo_db_location" VALUES(12167,NULL,'Fredericksburg, PA',5094,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12168,NULL,'Fredericksburg, PA 17026',5094,222,NULL,44,6781,0);
INSERT INTO "django_geo_db_location" VALUES(12169,NULL,'Grantham, PA',5095,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12170,NULL,'Grantham, PA 17027',5095,222,NULL,44,6782,0);
INSERT INTO "django_geo_db_location" VALUES(12171,NULL,'Grantville, PA',5096,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12172,NULL,'Grantville, PA 17028',5096,222,NULL,44,6783,0);
INSERT INTO "django_geo_db_location" VALUES(12173,NULL,'Granville, PA',5097,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12174,NULL,'Granville, PA 17029',5097,222,NULL,44,6784,0);
INSERT INTO "django_geo_db_location" VALUES(12175,NULL,'Gratz, PA',5098,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12176,NULL,'Gratz, PA 17030',5098,222,NULL,44,6785,0);
INSERT INTO "django_geo_db_location" VALUES(12177,NULL,'Green Park, PA',5099,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12178,NULL,'Green Park, PA 17031',5099,222,NULL,44,6786,0);
INSERT INTO "django_geo_db_location" VALUES(12179,NULL,'Halifax, PA',5100,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12180,NULL,'Halifax, PA 17032',5100,222,NULL,44,6787,0);
INSERT INTO "django_geo_db_location" VALUES(12181,NULL,'Hershey, PA',5101,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12182,NULL,'Hershey, PA 17033',5101,222,NULL,44,6788,0);
INSERT INTO "django_geo_db_location" VALUES(12183,NULL,'Highspire, PA',5102,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12184,NULL,'Highspire, PA 17034',5102,222,NULL,44,6789,0);
INSERT INTO "django_geo_db_location" VALUES(12185,NULL,'Honey Grove, PA',5103,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12186,NULL,'Honey Grove, PA 17035',5103,222,NULL,44,6790,0);
INSERT INTO "django_geo_db_location" VALUES(12187,NULL,'Hummelstown, PA',5104,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12188,NULL,'Hummelstown, PA 17036',5104,222,NULL,44,6791,0);
INSERT INTO "django_geo_db_location" VALUES(12189,NULL,'Ickesburg, PA',5105,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12190,NULL,'Ickesburg, PA 17037',5105,222,NULL,44,6792,0);
INSERT INTO "django_geo_db_location" VALUES(12191,NULL,'Jonestown, PA',5106,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12192,NULL,'Jonestown, PA 17038',5106,222,NULL,44,6793,0);
INSERT INTO "django_geo_db_location" VALUES(12193,NULL,'Kleinfeltersville, PA',5107,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12194,NULL,'Kleinfeltersville, PA 17039',5107,222,NULL,44,6794,0);
INSERT INTO "django_geo_db_location" VALUES(12195,NULL,'Landisburg, PA',5108,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12196,NULL,'Landisburg, PA 17040',5108,222,NULL,44,6795,0);
INSERT INTO "django_geo_db_location" VALUES(12197,NULL,'Lawn, PA',5109,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12198,NULL,'Lawn, PA 17041',5109,222,NULL,44,6796,0);
INSERT INTO "django_geo_db_location" VALUES(12199,NULL,'Lebanon, PA',5110,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12200,NULL,'Lebanon, PA 17042',5110,222,NULL,44,6797,0);
INSERT INTO "django_geo_db_location" VALUES(12201,NULL,'Lemoyne, PA',5111,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12202,NULL,'Lemoyne, PA 17043',5111,222,NULL,44,6798,0);
INSERT INTO "django_geo_db_location" VALUES(12203,NULL,'Lewistown, PA',5112,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12204,NULL,'Lewistown, PA 17044',5112,222,NULL,44,6799,0);
INSERT INTO "django_geo_db_location" VALUES(12205,NULL,'Liverpool, PA',5113,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12206,NULL,'Liverpool, PA 17045',5113,222,NULL,44,6800,0);
INSERT INTO "django_geo_db_location" VALUES(12207,NULL,'Lebanon, PA 17046',5110,222,NULL,44,6801,0);
INSERT INTO "django_geo_db_location" VALUES(12208,NULL,'Loysville, PA',5114,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12209,NULL,'Loysville, PA 17047',5114,222,NULL,44,6802,0);
INSERT INTO "django_geo_db_location" VALUES(12210,NULL,'Lykens, PA',5115,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12211,NULL,'Lykens, PA 17048',5115,222,NULL,44,6803,0);
INSERT INTO "django_geo_db_location" VALUES(12212,NULL,'McAlisterville, PA',5116,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12213,NULL,'McAlisterville, PA 17049',5116,222,NULL,44,6804,0);
INSERT INTO "django_geo_db_location" VALUES(12214,NULL,'Mechanicsburg, PA',5117,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12215,NULL,'Mechanicsburg, PA 17050',5117,222,NULL,44,6805,0);
INSERT INTO "django_geo_db_location" VALUES(12216,NULL,'McVeytown, PA',5118,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12217,NULL,'McVeytown, PA 17051',5118,222,NULL,44,6806,0);
INSERT INTO "django_geo_db_location" VALUES(12218,NULL,'Mapleton Depot, PA',5119,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12219,NULL,'Mapleton Depot, PA 17052',5119,222,NULL,44,6807,0);
INSERT INTO "django_geo_db_location" VALUES(12220,NULL,'Marysville, PA',5120,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12221,NULL,'Marysville, PA 17053',5120,222,NULL,44,6808,0);
INSERT INTO "django_geo_db_location" VALUES(12222,NULL,'Mattawana, PA',5121,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12223,NULL,'Mattawana, PA 17054',5121,222,NULL,44,6809,0);
INSERT INTO "django_geo_db_location" VALUES(12224,NULL,'Mechanicsburg, PA 17055',5117,222,NULL,44,6810,0);
INSERT INTO "django_geo_db_location" VALUES(12225,NULL,'Mexico, PA',5122,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12226,NULL,'Mexico, PA 17056',5122,222,NULL,44,6811,0);
INSERT INTO "django_geo_db_location" VALUES(12227,NULL,'Middletown, PA',5123,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12228,NULL,'Middletown, PA 17057',5123,222,NULL,44,6812,0);
INSERT INTO "django_geo_db_location" VALUES(12229,NULL,'Mifflin, PA',5124,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12230,NULL,'Mifflin, PA 17058',5124,222,NULL,44,6813,0);
INSERT INTO "django_geo_db_location" VALUES(12231,NULL,'Mifflintown, PA',5125,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12232,NULL,'Mifflintown, PA 17059',5125,222,NULL,44,6814,0);
INSERT INTO "django_geo_db_location" VALUES(12233,NULL,'Mill Creek, PA',5126,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12234,NULL,'Mill Creek, PA 17060',5126,222,NULL,44,6815,0);
INSERT INTO "django_geo_db_location" VALUES(12235,NULL,'Millersburg, PA',5127,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12236,NULL,'Millersburg, PA 17061',5127,222,NULL,44,6816,0);
INSERT INTO "django_geo_db_location" VALUES(12237,NULL,'Millerstown, PA',5128,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12238,NULL,'Millerstown, PA 17062',5128,222,NULL,44,6817,0);
INSERT INTO "django_geo_db_location" VALUES(12239,NULL,'Milroy, PA',5129,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12240,NULL,'Milroy, PA 17063',5129,222,NULL,44,6818,0);
INSERT INTO "django_geo_db_location" VALUES(12241,NULL,'Mount Gretna, PA',5130,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12242,NULL,'Mount Gretna, PA 17064',5130,222,NULL,44,6819,0);
INSERT INTO "django_geo_db_location" VALUES(12243,NULL,'Mount Holly Springs, PA',5131,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12244,NULL,'Mount Holly Springs, PA 17065',5131,222,NULL,44,6820,0);
INSERT INTO "django_geo_db_location" VALUES(12245,NULL,'Mount Union, PA',5132,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12246,NULL,'Mount Union, PA 17066',5132,222,NULL,44,6821,0);
INSERT INTO "django_geo_db_location" VALUES(12247,NULL,'Myerstown, PA',5133,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12248,NULL,'Myerstown, PA 17067',5133,222,NULL,44,6822,0);
INSERT INTO "django_geo_db_location" VALUES(12249,NULL,'New Bloomfield, PA',5134,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12250,NULL,'New Bloomfield, PA 17068',5134,222,NULL,44,6823,0);
INSERT INTO "django_geo_db_location" VALUES(12251,NULL,'New Buffalo, PA',5135,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12252,NULL,'New Buffalo, PA 17069',5135,222,NULL,44,6824,0);
INSERT INTO "django_geo_db_location" VALUES(12253,NULL,'New Cumberland, PA',5136,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12254,NULL,'New Cumberland, PA 17070',5136,222,NULL,44,6825,0);
INSERT INTO "django_geo_db_location" VALUES(12255,NULL,'New Germantown, PA',5137,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12256,NULL,'New Germantown, PA 17071',5137,222,NULL,44,6826,0);
INSERT INTO "django_geo_db_location" VALUES(12257,NULL,'New Kingstown, PA',5138,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12258,NULL,'New Kingstown, PA 17072',5138,222,NULL,44,6827,0);
INSERT INTO "django_geo_db_location" VALUES(12259,NULL,'Newmanstown, PA',5139,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12260,NULL,'Newmanstown, PA 17073',5139,222,NULL,44,6828,0);
INSERT INTO "django_geo_db_location" VALUES(12261,NULL,'Newport, PA',5140,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12262,NULL,'Newport, PA 17074',5140,222,NULL,44,6829,0);
INSERT INTO "django_geo_db_location" VALUES(12263,NULL,'Newton Hamilton, PA',5141,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12264,NULL,'Newton Hamilton, PA 17075',5141,222,NULL,44,6830,0);
INSERT INTO "django_geo_db_location" VALUES(12265,NULL,'Oakland Mills, PA',5142,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12266,NULL,'Oakland Mills, PA 17076',5142,222,NULL,44,6831,0);
INSERT INTO "django_geo_db_location" VALUES(12267,NULL,'Ono, PA',5143,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12268,NULL,'Ono, PA 17077',5143,222,NULL,44,6832,0);
INSERT INTO "django_geo_db_location" VALUES(12269,NULL,'Palmyra, PA',5144,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12270,NULL,'Palmyra, PA 17078',5144,222,NULL,44,6833,0);
INSERT INTO "django_geo_db_location" VALUES(12271,NULL,'Pillow, PA',5145,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12272,NULL,'Pillow, PA 17080',5145,222,NULL,44,6834,0);
INSERT INTO "django_geo_db_location" VALUES(12273,NULL,'Plainfield, PA',5146,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12274,NULL,'Plainfield, PA 17081',5146,222,NULL,44,6835,0);
INSERT INTO "django_geo_db_location" VALUES(12275,NULL,'Port Royal, PA',5147,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12276,NULL,'Port Royal, PA 17082',5147,222,NULL,44,6836,0);
INSERT INTO "django_geo_db_location" VALUES(12277,NULL,'Quentin, PA',5148,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12278,NULL,'Quentin, PA 17083',5148,222,NULL,44,6837,0);
INSERT INTO "django_geo_db_location" VALUES(12279,NULL,'Reedsville, PA',5149,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12280,NULL,'Reedsville, PA 17084',5149,222,NULL,44,6838,0);
INSERT INTO "django_geo_db_location" VALUES(12281,NULL,'Rexmont, PA',5150,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12282,NULL,'Rexmont, PA 17085',5150,222,NULL,44,6839,0);
INSERT INTO "django_geo_db_location" VALUES(12283,NULL,'Richfield, PA',5151,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12284,NULL,'Richfield, PA 17086',5151,222,NULL,44,6840,0);
INSERT INTO "django_geo_db_location" VALUES(12285,NULL,'Richland, PA',5152,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12286,NULL,'Richland, PA 17087',5152,222,NULL,44,6841,0);
INSERT INTO "django_geo_db_location" VALUES(12287,NULL,'Schaefferstown, PA',5153,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12288,NULL,'Schaefferstown, PA 17088',5153,222,NULL,44,6842,0);
INSERT INTO "django_geo_db_location" VALUES(12289,NULL,'Camp Hill, PA 17089',5071,222,NULL,44,6843,0);
INSERT INTO "django_geo_db_location" VALUES(12290,NULL,'Shermans Dale, PA',5154,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12291,NULL,'Shermans Dale, PA 17090',5154,222,NULL,44,6844,0);
INSERT INTO "django_geo_db_location" VALUES(12292,NULL,'Camp Hill, PA 17091',5071,222,NULL,44,6845,0);
INSERT INTO "django_geo_db_location" VALUES(12293,NULL,'Summerdale, PA',5155,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12294,NULL,'Summerdale, PA 17093',5155,222,NULL,44,6846,0);
INSERT INTO "django_geo_db_location" VALUES(12295,NULL,'Thompsontown, PA',5156,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12296,NULL,'Thompsontown, PA 17094',5156,222,NULL,44,6847,0);
INSERT INTO "django_geo_db_location" VALUES(12297,NULL,'Wiconisco, PA',5157,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12298,NULL,'Wiconisco, PA 17097',5157,222,NULL,44,6848,0);
INSERT INTO "django_geo_db_location" VALUES(12299,NULL,'Williamstown, PA',5158,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12300,NULL,'Williamstown, PA 17098',5158,222,NULL,44,6849,0);
INSERT INTO "django_geo_db_location" VALUES(12301,NULL,'Yeagertown, PA',5159,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12302,NULL,'Yeagertown, PA 17099',5159,222,NULL,44,6850,0);
INSERT INTO "django_geo_db_location" VALUES(12303,NULL,'Harrisburg, PA',5160,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12304,NULL,'Harrisburg, PA 17101',5160,222,NULL,44,6851,0);
INSERT INTO "django_geo_db_location" VALUES(12305,NULL,'Harrisburg, PA 17102',5160,222,NULL,44,6852,0);
INSERT INTO "django_geo_db_location" VALUES(12306,NULL,'Harrisburg, PA 17103',5160,222,NULL,44,6853,0);
INSERT INTO "django_geo_db_location" VALUES(12307,NULL,'Harrisburg, PA 17104',5160,222,NULL,44,6854,0);
INSERT INTO "django_geo_db_location" VALUES(12308,NULL,'Harrisburg, PA 17105',5160,222,NULL,44,6855,0);
INSERT INTO "django_geo_db_location" VALUES(12309,NULL,'Harrisburg, PA 17106',5160,222,NULL,44,6856,0);
INSERT INTO "django_geo_db_location" VALUES(12310,NULL,'Harrisburg, PA 17107',5160,222,NULL,44,6857,0);
INSERT INTO "django_geo_db_location" VALUES(12311,NULL,'Harrisburg, PA 17108',5160,222,NULL,44,6858,0);
INSERT INTO "django_geo_db_location" VALUES(12312,NULL,'Harrisburg, PA 17109',5160,222,NULL,44,6859,0);
INSERT INTO "django_geo_db_location" VALUES(12313,NULL,'Harrisburg, PA 17110',5160,222,NULL,44,6860,0);
INSERT INTO "django_geo_db_location" VALUES(12314,NULL,'Harrisburg, PA 17111',5160,222,NULL,44,6861,0);
INSERT INTO "django_geo_db_location" VALUES(12315,NULL,'Harrisburg, PA 17112',5160,222,NULL,44,6862,0);
INSERT INTO "django_geo_db_location" VALUES(12316,NULL,'Harrisburg, PA 17113',5160,222,NULL,44,6863,0);
INSERT INTO "django_geo_db_location" VALUES(12317,NULL,'Harrisburg, PA 17120',5160,222,NULL,44,6864,0);
INSERT INTO "django_geo_db_location" VALUES(12318,NULL,'Harrisburg, PA 17121',5160,222,NULL,44,6865,0);
INSERT INTO "django_geo_db_location" VALUES(12319,NULL,'Harrisburg, PA 17122',5160,222,NULL,44,6866,0);
INSERT INTO "django_geo_db_location" VALUES(12320,NULL,'Harrisburg, PA 17123',5160,222,NULL,44,6867,0);
INSERT INTO "django_geo_db_location" VALUES(12321,NULL,'Harrisburg, PA 17124',5160,222,NULL,44,6868,0);
INSERT INTO "django_geo_db_location" VALUES(12322,NULL,'Harrisburg, PA 17125',5160,222,NULL,44,6869,0);
INSERT INTO "django_geo_db_location" VALUES(12323,NULL,'Harrisburg, PA 17126',5160,222,NULL,44,6870,0);
INSERT INTO "django_geo_db_location" VALUES(12324,NULL,'Harrisburg, PA 17127',5160,222,NULL,44,6871,0);
INSERT INTO "django_geo_db_location" VALUES(12325,NULL,'Harrisburg, PA 17128',5160,222,NULL,44,6872,0);
INSERT INTO "django_geo_db_location" VALUES(12326,NULL,'Harrisburg, PA 17129',5160,222,NULL,44,6873,0);
INSERT INTO "django_geo_db_location" VALUES(12327,NULL,'Harrisburg, PA 17130',5160,222,NULL,44,6874,0);
INSERT INTO "django_geo_db_location" VALUES(12328,NULL,'Harrisburg, PA 17140',5160,222,NULL,44,6875,0);
INSERT INTO "django_geo_db_location" VALUES(12329,NULL,'Harrisburg, PA 17177',5160,222,NULL,44,6876,0);
INSERT INTO "django_geo_db_location" VALUES(12330,NULL,'Chambersburg, PA',5161,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12331,NULL,'Chambersburg, PA 17201',5161,222,NULL,44,6877,0);
INSERT INTO "django_geo_db_location" VALUES(12332,NULL,'Amberson, PA',5162,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12333,NULL,'Amberson, PA 17210',5162,222,NULL,44,6878,0);
INSERT INTO "django_geo_db_location" VALUES(12334,NULL,'Artemas, PA',5163,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12335,NULL,'Artemas, PA 17211',5163,222,NULL,44,6879,0);
INSERT INTO "django_geo_db_location" VALUES(12336,NULL,'Big Cove Tannery, PA',5164,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12337,NULL,'Big Cove Tannery, PA 17212',5164,222,NULL,44,6880,0);
INSERT INTO "django_geo_db_location" VALUES(12338,NULL,'Blairs Mills, PA',5165,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12339,NULL,'Blairs Mills, PA 17213',5165,222,NULL,44,6881,0);
INSERT INTO "django_geo_db_location" VALUES(12340,NULL,'Blue Ridge Summit, PA',5166,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12341,NULL,'Blue Ridge Summit, PA 17214',5166,222,NULL,44,6882,0);
INSERT INTO "django_geo_db_location" VALUES(12342,NULL,'Burnt Cabins, PA',5167,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12343,NULL,'Burnt Cabins, PA 17215',5167,222,NULL,44,6883,0);
INSERT INTO "django_geo_db_location" VALUES(12344,NULL,'Concord, PA',5168,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12345,NULL,'Concord, PA 17217',5168,222,NULL,44,6884,0);
INSERT INTO "django_geo_db_location" VALUES(12346,NULL,'Doylesburg, PA',5169,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12347,NULL,'Doylesburg, PA 17219',5169,222,NULL,44,6885,0);
INSERT INTO "django_geo_db_location" VALUES(12348,NULL,'Dry Run, PA',5170,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12349,NULL,'Dry Run, PA 17220',5170,222,NULL,44,6886,0);
INSERT INTO "django_geo_db_location" VALUES(12350,NULL,'Fannettsburg, PA',5171,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12351,NULL,'Fannettsburg, PA 17221',5171,222,NULL,44,6887,0);
INSERT INTO "django_geo_db_location" VALUES(12352,NULL,'Fayetteville, PA',5172,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12353,NULL,'Fayetteville, PA 17222',5172,222,NULL,44,6888,0);
INSERT INTO "django_geo_db_location" VALUES(12354,NULL,'Fort Littleton, PA',5173,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12355,NULL,'Fort Littleton, PA 17223',5173,222,NULL,44,6889,0);
INSERT INTO "django_geo_db_location" VALUES(12356,NULL,'Fort Loudon, PA',5174,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12357,NULL,'Fort Loudon, PA 17224',5174,222,NULL,44,6890,0);
INSERT INTO "django_geo_db_location" VALUES(12358,NULL,'Greencastle, PA',5175,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12359,NULL,'Greencastle, PA 17225',5175,222,NULL,44,6891,0);
INSERT INTO "django_geo_db_location" VALUES(12360,NULL,'Harrisonville, PA',5176,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12361,NULL,'Harrisonville, PA 17228',5176,222,NULL,44,6892,0);
INSERT INTO "django_geo_db_location" VALUES(12362,NULL,'Hustontown, PA',5177,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12363,NULL,'Hustontown, PA 17229',5177,222,NULL,44,6893,0);
INSERT INTO "django_geo_db_location" VALUES(12364,NULL,'Lemasters, PA',5178,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12365,NULL,'Lemasters, PA 17231',5178,222,NULL,44,6894,0);
INSERT INTO "django_geo_db_location" VALUES(12366,NULL,'Lurgan, PA',5179,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12367,NULL,'Lurgan, PA 17232',5179,222,NULL,44,6895,0);
INSERT INTO "django_geo_db_location" VALUES(12368,NULL,'McConnellsburg, PA',5180,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12369,NULL,'McConnellsburg, PA 17233',5180,222,NULL,44,6896,0);
INSERT INTO "django_geo_db_location" VALUES(12370,NULL,'Marion, PA',5181,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12371,NULL,'Marion, PA 17235',5181,222,NULL,44,6897,0);
INSERT INTO "django_geo_db_location" VALUES(12372,NULL,'Mercersburg, PA',5182,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12373,NULL,'Mercersburg, PA 17236',5182,222,NULL,44,6898,0);
INSERT INTO "django_geo_db_location" VALUES(12374,NULL,'Mont Alto, PA',5183,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12375,NULL,'Mont Alto, PA 17237',5183,222,NULL,44,6899,0);
INSERT INTO "django_geo_db_location" VALUES(12376,NULL,'Needmore, PA',5184,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12377,NULL,'Needmore, PA 17238',5184,222,NULL,44,6900,0);
INSERT INTO "django_geo_db_location" VALUES(12378,NULL,'Neelyton, PA',5185,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12379,NULL,'Neelyton, PA 17239',5185,222,NULL,44,6901,0);
INSERT INTO "django_geo_db_location" VALUES(12380,NULL,'Newburg, PA',5186,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12381,NULL,'Newburg, PA 17240',5186,222,NULL,44,6902,0);
INSERT INTO "django_geo_db_location" VALUES(12382,NULL,'Newville, PA',5187,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12383,NULL,'Newville, PA 17241',5187,222,NULL,44,6903,0);
INSERT INTO "django_geo_db_location" VALUES(12384,NULL,'Orbisonia, PA',5188,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12385,NULL,'Orbisonia, PA 17243',5188,222,NULL,44,6904,0);
INSERT INTO "django_geo_db_location" VALUES(12386,NULL,'Orrstown, PA',5189,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12387,NULL,'Orrstown, PA 17244',5189,222,NULL,44,6905,0);
INSERT INTO "django_geo_db_location" VALUES(12388,NULL,'Pleasant Hall, PA',5190,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12389,NULL,'Pleasant Hall, PA 17246',5190,222,NULL,44,6906,0);
INSERT INTO "django_geo_db_location" VALUES(12390,NULL,'Quincy, PA',5191,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12391,NULL,'Quincy, PA 17247',5191,222,NULL,44,6907,0);
INSERT INTO "django_geo_db_location" VALUES(12392,NULL,'Rockhill Furnace, PA',5192,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12393,NULL,'Rockhill Furnace, PA 17249',5192,222,NULL,44,6908,0);
INSERT INTO "django_geo_db_location" VALUES(12394,NULL,'Rouzerville, PA',5193,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12395,NULL,'Rouzerville, PA 17250',5193,222,NULL,44,6909,0);
INSERT INTO "django_geo_db_location" VALUES(12396,NULL,'Roxbury, PA',5194,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12397,NULL,'Roxbury, PA 17251',5194,222,NULL,44,6910,0);
INSERT INTO "django_geo_db_location" VALUES(12398,NULL,'Saint Thomas, PA',5195,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12399,NULL,'Saint Thomas, PA 17252',5195,222,NULL,44,6911,0);
INSERT INTO "django_geo_db_location" VALUES(12400,NULL,'Saltillo, PA',5196,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12401,NULL,'Saltillo, PA 17253',5196,222,NULL,44,6912,0);
INSERT INTO "django_geo_db_location" VALUES(12402,NULL,'Scotland, PA',5197,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12403,NULL,'Scotland, PA 17254',5197,222,NULL,44,6913,0);
INSERT INTO "django_geo_db_location" VALUES(12404,NULL,'Shade Gap, PA',5198,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12405,NULL,'Shade Gap, PA 17255',5198,222,NULL,44,6914,0);
INSERT INTO "django_geo_db_location" VALUES(12406,NULL,'Shady Grove, PA',5199,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12407,NULL,'Shady Grove, PA 17256',5199,222,NULL,44,6915,0);
INSERT INTO "django_geo_db_location" VALUES(12408,NULL,'Shippensburg, PA',5200,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12409,NULL,'Shippensburg, PA 17257',5200,222,NULL,44,6916,0);
INSERT INTO "django_geo_db_location" VALUES(12410,NULL,'Shirleysburg, PA',5201,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12411,NULL,'Shirleysburg, PA 17260',5201,222,NULL,44,6917,0);
INSERT INTO "django_geo_db_location" VALUES(12412,NULL,'South Mountain, PA',5202,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12413,NULL,'South Mountain, PA 17261',5202,222,NULL,44,6918,0);
INSERT INTO "django_geo_db_location" VALUES(12414,NULL,'Spring Run, PA',5203,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12415,NULL,'Spring Run, PA 17262',5203,222,NULL,44,6919,0);
INSERT INTO "django_geo_db_location" VALUES(12416,NULL,'State Line, PA',5204,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12417,NULL,'State Line, PA 17263',5204,222,NULL,44,6920,0);
INSERT INTO "django_geo_db_location" VALUES(12418,NULL,'Three Springs, PA',5205,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12419,NULL,'Three Springs, PA 17264',5205,222,NULL,44,6921,0);
INSERT INTO "django_geo_db_location" VALUES(12420,NULL,'Upperstrasburg, PA',5206,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12421,NULL,'Upperstrasburg, PA 17265',5206,222,NULL,44,6922,0);
INSERT INTO "django_geo_db_location" VALUES(12422,NULL,'Walnut Bottom, PA',5207,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12423,NULL,'Walnut Bottom, PA 17266',5207,222,NULL,44,6923,0);
INSERT INTO "django_geo_db_location" VALUES(12424,NULL,'Warfordsburg, PA',5208,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12425,NULL,'Warfordsburg, PA 17267',5208,222,NULL,44,6924,0);
INSERT INTO "django_geo_db_location" VALUES(12426,NULL,'Waynesboro, PA',5209,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12427,NULL,'Waynesboro, PA 17268',5209,222,NULL,44,6925,0);
INSERT INTO "django_geo_db_location" VALUES(12428,NULL,'Brush Creek, PA',5210,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12429,NULL,'Brush Creek, PA 17269',5210,222,NULL,44,6926,0);
INSERT INTO "django_geo_db_location" VALUES(12430,NULL,'Williamson, PA',5211,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12431,NULL,'Williamson, PA 17270',5211,222,NULL,44,6927,0);
INSERT INTO "django_geo_db_location" VALUES(12432,NULL,'Willow Hill, PA',5212,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12433,NULL,'Willow Hill, PA 17271',5212,222,NULL,44,6928,0);
INSERT INTO "django_geo_db_location" VALUES(12434,NULL,'Zullinger, PA',5213,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12435,NULL,'Zullinger, PA 17272',5213,222,NULL,44,6929,0);
INSERT INTO "django_geo_db_location" VALUES(12436,NULL,'Southampton, PA',5214,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12437,NULL,'Southampton, PA 17275',5214,222,NULL,44,6930,0);
INSERT INTO "django_geo_db_location" VALUES(12438,NULL,'Blue Ridge Summit, PA 17294',5166,222,NULL,44,6931,0);
INSERT INTO "django_geo_db_location" VALUES(12439,NULL,'Abbottstown, PA',5215,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12440,NULL,'Abbottstown, PA 17301',5215,222,NULL,44,6932,0);
INSERT INTO "django_geo_db_location" VALUES(12441,NULL,'Airville, PA',5216,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12442,NULL,'Airville, PA 17302',5216,222,NULL,44,6933,0);
INSERT INTO "django_geo_db_location" VALUES(12443,NULL,'Arendtsville, PA',5217,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12444,NULL,'Arendtsville, PA 17303',5217,222,NULL,44,6934,0);
INSERT INTO "django_geo_db_location" VALUES(12445,NULL,'Aspers, PA',5218,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12446,NULL,'Aspers, PA 17304',5218,222,NULL,44,6935,0);
INSERT INTO "django_geo_db_location" VALUES(12447,NULL,'Bendersville, PA',5219,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12448,NULL,'Bendersville, PA 17306',5219,222,NULL,44,6936,0);
INSERT INTO "django_geo_db_location" VALUES(12449,NULL,'Biglerville, PA',5220,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12450,NULL,'Biglerville, PA 17307',5220,222,NULL,44,6937,0);
INSERT INTO "django_geo_db_location" VALUES(12451,NULL,'Brogue, PA',5221,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12452,NULL,'Brogue, PA 17309',5221,222,NULL,44,6938,0);
INSERT INTO "django_geo_db_location" VALUES(12453,NULL,'Cashtown, PA',5222,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12454,NULL,'Cashtown, PA 17310',5222,222,NULL,44,6939,0);
INSERT INTO "django_geo_db_location" VALUES(12455,NULL,'Codorus, PA',5223,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12456,NULL,'Codorus, PA 17311',5223,222,NULL,44,6940,0);
INSERT INTO "django_geo_db_location" VALUES(12457,NULL,'Craley, PA',5224,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12458,NULL,'Craley, PA 17312',5224,222,NULL,44,6941,0);
INSERT INTO "django_geo_db_location" VALUES(12459,NULL,'Dallastown, PA',5225,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12460,NULL,'Dallastown, PA 17313',5225,222,NULL,44,6942,0);
INSERT INTO "django_geo_db_location" VALUES(12461,NULL,'Delta, PA',5226,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12462,NULL,'Delta, PA 17314',5226,222,NULL,44,6943,0);
INSERT INTO "django_geo_db_location" VALUES(12463,NULL,'Dover, PA',5227,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12464,NULL,'Dover, PA 17315',5227,222,NULL,44,6944,0);
INSERT INTO "django_geo_db_location" VALUES(12465,NULL,'East Berlin, PA',5228,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12466,NULL,'East Berlin, PA 17316',5228,222,NULL,44,6945,0);
INSERT INTO "django_geo_db_location" VALUES(12467,NULL,'East Prospect, PA',5229,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12468,NULL,'East Prospect, PA 17317',5229,222,NULL,44,6946,0);
INSERT INTO "django_geo_db_location" VALUES(12469,NULL,'Emigsville, PA',5230,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12470,NULL,'Emigsville, PA 17318',5230,222,NULL,44,6947,0);
INSERT INTO "django_geo_db_location" VALUES(12471,NULL,'Etters, PA',5231,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12472,NULL,'Etters, PA 17319',5231,222,NULL,44,6948,0);
INSERT INTO "django_geo_db_location" VALUES(12473,NULL,'Fairfield, PA',5232,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12474,NULL,'Fairfield, PA 17320',5232,222,NULL,44,6949,0);
INSERT INTO "django_geo_db_location" VALUES(12475,NULL,'Fawn Grove, PA',5233,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12476,NULL,'Fawn Grove, PA 17321',5233,222,NULL,44,6950,0);
INSERT INTO "django_geo_db_location" VALUES(12477,NULL,'Felton, PA',5234,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12478,NULL,'Felton, PA 17322',5234,222,NULL,44,6951,0);
INSERT INTO "django_geo_db_location" VALUES(12479,NULL,'Franklintown, PA',5235,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12480,NULL,'Franklintown, PA 17323',5235,222,NULL,44,6952,0);
INSERT INTO "django_geo_db_location" VALUES(12481,NULL,'Gardners, PA',5236,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12482,NULL,'Gardners, PA 17324',5236,222,NULL,44,6953,0);
INSERT INTO "django_geo_db_location" VALUES(12483,NULL,'Gettysburg, PA',5237,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12484,NULL,'Gettysburg, PA 17325',5237,222,NULL,44,6954,0);
INSERT INTO "django_geo_db_location" VALUES(12485,NULL,'Gettysburg, PA 17326',5237,222,NULL,44,6955,0);
INSERT INTO "django_geo_db_location" VALUES(12486,NULL,'Glen Rock, PA',5238,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12487,NULL,'Glen Rock, PA 17327',5238,222,NULL,44,6956,0);
INSERT INTO "django_geo_db_location" VALUES(12488,NULL,'Glenville, PA',5239,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12489,NULL,'Glenville, PA 17329',5239,222,NULL,44,6957,0);
INSERT INTO "django_geo_db_location" VALUES(12490,NULL,'Hanover, PA',5240,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12491,NULL,'Hanover, PA 17331',5240,222,NULL,44,6958,0);
INSERT INTO "django_geo_db_location" VALUES(12492,NULL,'Hanover, PA 17332',5240,222,NULL,44,6959,0);
INSERT INTO "django_geo_db_location" VALUES(12493,NULL,'Hanover, PA 17333',5240,222,NULL,44,6960,0);
INSERT INTO "django_geo_db_location" VALUES(12494,NULL,'Idaville, PA',5241,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12495,NULL,'Idaville, PA 17337',5241,222,NULL,44,6961,0);
INSERT INTO "django_geo_db_location" VALUES(12496,NULL,'Lewisberry, PA',5242,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12497,NULL,'Lewisberry, PA 17339',5242,222,NULL,44,6962,0);
INSERT INTO "django_geo_db_location" VALUES(12498,NULL,'Littlestown, PA',5243,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12499,NULL,'Littlestown, PA 17340',5243,222,NULL,44,6963,0);
INSERT INTO "django_geo_db_location" VALUES(12500,NULL,'Loganville, PA',5244,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12501,NULL,'Loganville, PA 17342',5244,222,NULL,44,6964,0);
INSERT INTO "django_geo_db_location" VALUES(12502,NULL,'McKnightstown, PA',5245,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12503,NULL,'McKnightstown, PA 17343',5245,222,NULL,44,6965,0);
INSERT INTO "django_geo_db_location" VALUES(12504,NULL,'McSherrystown, PA',5246,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12505,NULL,'McSherrystown, PA 17344',5246,222,NULL,44,6966,0);
INSERT INTO "django_geo_db_location" VALUES(12506,NULL,'Manchester, PA',5247,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12507,NULL,'Manchester, PA 17345',5247,222,NULL,44,6967,0);
INSERT INTO "django_geo_db_location" VALUES(12508,NULL,'Menges Mills, PA',5248,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12509,NULL,'Menges Mills, PA 17346',5248,222,NULL,44,6968,0);
INSERT INTO "django_geo_db_location" VALUES(12510,NULL,'Mount Wolf, PA',5249,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12511,NULL,'Mount Wolf, PA 17347',5249,222,NULL,44,6969,0);
INSERT INTO "django_geo_db_location" VALUES(12512,NULL,'New Freedom, PA',5250,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12513,NULL,'New Freedom, PA 17349',5250,222,NULL,44,6970,0);
INSERT INTO "django_geo_db_location" VALUES(12514,NULL,'New Oxford, PA',5251,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12515,NULL,'New Oxford, PA 17350',5251,222,NULL,44,6971,0);
INSERT INTO "django_geo_db_location" VALUES(12516,NULL,'New Park, PA',5252,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12517,NULL,'New Park, PA 17352',5252,222,NULL,44,6972,0);
INSERT INTO "django_geo_db_location" VALUES(12518,NULL,'Orrtanna, PA',5253,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12519,NULL,'Orrtanna, PA 17353',5253,222,NULL,44,6973,0);
INSERT INTO "django_geo_db_location" VALUES(12520,NULL,'Porters Sideling, PA',5254,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12521,NULL,'Porters Sideling, PA 17354',5254,222,NULL,44,6974,0);
INSERT INTO "django_geo_db_location" VALUES(12522,NULL,'Railroad, PA',5255,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12523,NULL,'Railroad, PA 17355',5255,222,NULL,44,6975,0);
INSERT INTO "django_geo_db_location" VALUES(12524,NULL,'Red Lion, PA',5256,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12525,NULL,'Red Lion, PA 17356',5256,222,NULL,44,6976,0);
INSERT INTO "django_geo_db_location" VALUES(12526,NULL,'Rossville, PA',5257,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12527,NULL,'Rossville, PA 17358',5257,222,NULL,44,6977,0);
INSERT INTO "django_geo_db_location" VALUES(12528,NULL,'Seven Valleys, PA',5258,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12529,NULL,'Seven Valleys, PA 17360',5258,222,NULL,44,6978,0);
INSERT INTO "django_geo_db_location" VALUES(12530,NULL,'Shrewsbury, PA',5259,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12531,NULL,'Shrewsbury, PA 17361',5259,222,NULL,44,6979,0);
INSERT INTO "django_geo_db_location" VALUES(12532,NULL,'Spring Grove, PA',5260,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12533,NULL,'Spring Grove, PA 17362',5260,222,NULL,44,6980,0);
INSERT INTO "django_geo_db_location" VALUES(12534,NULL,'Stewartstown, PA',5261,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12535,NULL,'Stewartstown, PA 17363',5261,222,NULL,44,6981,0);
INSERT INTO "django_geo_db_location" VALUES(12536,NULL,'Thomasville, PA',5262,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12537,NULL,'Thomasville, PA 17364',5262,222,NULL,44,6982,0);
INSERT INTO "django_geo_db_location" VALUES(12538,NULL,'Wellsville, PA',5263,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12539,NULL,'Wellsville, PA 17365',5263,222,NULL,44,6983,0);
INSERT INTO "django_geo_db_location" VALUES(12540,NULL,'Windsor, PA',5264,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12541,NULL,'Windsor, PA 17366',5264,222,NULL,44,6984,0);
INSERT INTO "django_geo_db_location" VALUES(12542,NULL,'Wrightsville, PA',5265,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12543,NULL,'Wrightsville, PA 17368',5265,222,NULL,44,6985,0);
INSERT INTO "django_geo_db_location" VALUES(12544,NULL,'York Haven, PA',5266,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12545,NULL,'York Haven, PA 17370',5266,222,NULL,44,6986,0);
INSERT INTO "django_geo_db_location" VALUES(12546,NULL,'York New Salem, PA',5267,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12547,NULL,'York New Salem, PA 17371',5267,222,NULL,44,6987,0);
INSERT INTO "django_geo_db_location" VALUES(12548,NULL,'York Springs, PA',5268,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12549,NULL,'York Springs, PA 17372',5268,222,NULL,44,6988,0);
INSERT INTO "django_geo_db_location" VALUES(12550,NULL,'Peach Glen, PA',5269,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12551,NULL,'Peach Glen, PA 17375',5269,222,NULL,44,6989,0);
INSERT INTO "django_geo_db_location" VALUES(12552,NULL,'York, PA',5270,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12553,NULL,'York, PA 17401',5270,222,NULL,44,6990,0);
INSERT INTO "django_geo_db_location" VALUES(12554,NULL,'York, PA 17402',5270,222,NULL,44,6991,0);
INSERT INTO "django_geo_db_location" VALUES(12555,NULL,'York, PA 17403',5270,222,NULL,44,6992,0);
INSERT INTO "django_geo_db_location" VALUES(12556,NULL,'York, PA 17404',5270,222,NULL,44,6993,0);
INSERT INTO "django_geo_db_location" VALUES(12557,NULL,'York, PA 17405',5270,222,NULL,44,6994,0);
INSERT INTO "django_geo_db_location" VALUES(12558,NULL,'York, PA 17406',5270,222,NULL,44,6995,0);
INSERT INTO "django_geo_db_location" VALUES(12559,NULL,'York, PA 17407',5270,222,NULL,44,6996,0);
INSERT INTO "django_geo_db_location" VALUES(12560,NULL,'York, PA 17415',5270,222,NULL,44,6997,0);
INSERT INTO "django_geo_db_location" VALUES(12561,NULL,'Akron, PA',5271,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12562,NULL,'Akron, PA 17501',5271,222,NULL,44,6998,0);
INSERT INTO "django_geo_db_location" VALUES(12563,NULL,'Bainbridge, PA',5272,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12564,NULL,'Bainbridge, PA 17502',5272,222,NULL,44,6999,0);
INSERT INTO "django_geo_db_location" VALUES(12565,NULL,'Bart, PA',5273,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12566,NULL,'Bart, PA 17503',5273,222,NULL,44,7000,0);
INSERT INTO "django_geo_db_location" VALUES(12567,NULL,'Bausman, PA',5274,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12568,NULL,'Bausman, PA 17504',5274,222,NULL,44,7001,0);
INSERT INTO "django_geo_db_location" VALUES(12569,NULL,'Bird In Hand, PA',5275,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12570,NULL,'Bird In Hand, PA 17505',5275,222,NULL,44,7002,0);
INSERT INTO "django_geo_db_location" VALUES(12571,NULL,'Blue Ball, PA',5276,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12572,NULL,'Blue Ball, PA 17506',5276,222,NULL,44,7003,0);
INSERT INTO "django_geo_db_location" VALUES(12573,NULL,'Bowmansville, PA',5277,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12574,NULL,'Bowmansville, PA 17507',5277,222,NULL,44,7004,0);
INSERT INTO "django_geo_db_location" VALUES(12575,NULL,'Brownstown, PA',5278,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12576,NULL,'Brownstown, PA 17508',5278,222,NULL,44,7005,0);
INSERT INTO "django_geo_db_location" VALUES(12577,NULL,'Christiana, PA',5279,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12578,NULL,'Christiana, PA 17509',5279,222,NULL,44,7006,0);
INSERT INTO "django_geo_db_location" VALUES(12579,NULL,'Columbia, PA',5280,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12580,NULL,'Columbia, PA 17511',5280,222,NULL,44,7007,0);
INSERT INTO "django_geo_db_location" VALUES(12581,NULL,'Columbia, PA 17512',5280,222,NULL,44,7008,0);
INSERT INTO "django_geo_db_location" VALUES(12582,NULL,'Conestoga, PA',5281,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12583,NULL,'Conestoga, PA 17516',5281,222,NULL,44,7009,0);
INSERT INTO "django_geo_db_location" VALUES(12584,NULL,'Denver, PA',5282,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12585,NULL,'Denver, PA 17517',5282,222,NULL,44,7010,0);
INSERT INTO "django_geo_db_location" VALUES(12586,NULL,'Drumore, PA',5283,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12587,NULL,'Drumore, PA 17518',5283,222,NULL,44,7011,0);
INSERT INTO "django_geo_db_location" VALUES(12588,NULL,'East Earl, PA',5284,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12589,NULL,'East Earl, PA 17519',5284,222,NULL,44,7012,0);
INSERT INTO "django_geo_db_location" VALUES(12590,NULL,'East Petersburg, PA',5285,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12591,NULL,'East Petersburg, PA 17520',5285,222,NULL,44,7013,0);
INSERT INTO "django_geo_db_location" VALUES(12592,NULL,'Elm, PA',5286,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12593,NULL,'Elm, PA 17521',5286,222,NULL,44,7014,0);
INSERT INTO "django_geo_db_location" VALUES(12594,NULL,'Ephrata, PA',5287,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12595,NULL,'Ephrata, PA 17522',5287,222,NULL,44,7015,0);
INSERT INTO "django_geo_db_location" VALUES(12596,NULL,'Gap, PA',5288,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12597,NULL,'Gap, PA 17527',5288,222,NULL,44,7016,0);
INSERT INTO "django_geo_db_location" VALUES(12598,NULL,'Goodville, PA',5289,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12599,NULL,'Goodville, PA 17528',5289,222,NULL,44,7017,0);
INSERT INTO "django_geo_db_location" VALUES(12600,NULL,'Gordonville, PA',5290,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12601,NULL,'Gordonville, PA 17529',5290,222,NULL,44,7018,0);
INSERT INTO "django_geo_db_location" VALUES(12602,NULL,'Holtwood, PA',5291,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12603,NULL,'Holtwood, PA 17532',5291,222,NULL,44,7019,0);
INSERT INTO "django_geo_db_location" VALUES(12604,NULL,'Hopeland, PA',5292,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12605,NULL,'Hopeland, PA 17533',5292,222,NULL,44,7020,0);
INSERT INTO "django_geo_db_location" VALUES(12606,NULL,'Intercourse, PA',5293,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12607,NULL,'Intercourse, PA 17534',5293,222,NULL,44,7021,0);
INSERT INTO "django_geo_db_location" VALUES(12608,NULL,'Kinzers, PA',5294,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12609,NULL,'Kinzers, PA 17535',5294,222,NULL,44,7022,0);
INSERT INTO "django_geo_db_location" VALUES(12610,NULL,'Kirkwood, PA',5295,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12611,NULL,'Kirkwood, PA 17536',5295,222,NULL,44,7023,0);
INSERT INTO "django_geo_db_location" VALUES(12612,NULL,'Lampeter, PA',5296,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12613,NULL,'Lampeter, PA 17537',5296,222,NULL,44,7024,0);
INSERT INTO "django_geo_db_location" VALUES(12614,NULL,'Landisville, PA',5297,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12615,NULL,'Landisville, PA 17538',5297,222,NULL,44,7025,0);
INSERT INTO "django_geo_db_location" VALUES(12616,NULL,'Leola, PA',5298,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12617,NULL,'Leola, PA 17540',5298,222,NULL,44,7026,0);
INSERT INTO "django_geo_db_location" VALUES(12618,NULL,'Lititz, PA',5299,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12619,NULL,'Lititz, PA 17543',5299,222,NULL,44,7027,0);
INSERT INTO "django_geo_db_location" VALUES(12620,NULL,'Manheim, PA',5300,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12621,NULL,'Manheim, PA 17545',5300,222,NULL,44,7028,0);
INSERT INTO "django_geo_db_location" VALUES(12622,NULL,'Marietta, PA',5301,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12623,NULL,'Marietta, PA 17547',5301,222,NULL,44,7029,0);
INSERT INTO "django_geo_db_location" VALUES(12624,NULL,'Martindale, PA',5302,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12625,NULL,'Martindale, PA 17549',5302,222,NULL,44,7030,0);
INSERT INTO "django_geo_db_location" VALUES(12626,NULL,'Maytown, PA',5303,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12627,NULL,'Maytown, PA 17550',5303,222,NULL,44,7031,0);
INSERT INTO "django_geo_db_location" VALUES(12628,NULL,'Millersville, PA',5304,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12629,NULL,'Millersville, PA 17551',5304,222,NULL,44,7032,0);
INSERT INTO "django_geo_db_location" VALUES(12630,NULL,'Mount Joy, PA',5305,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12631,NULL,'Mount Joy, PA 17552',5305,222,NULL,44,7033,0);
INSERT INTO "django_geo_db_location" VALUES(12632,NULL,'Mountville, PA',5306,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12633,NULL,'Mountville, PA 17554',5306,222,NULL,44,7034,0);
INSERT INTO "django_geo_db_location" VALUES(12634,NULL,'Narvon, PA',5307,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12635,NULL,'Narvon, PA 17555',5307,222,NULL,44,7035,0);
INSERT INTO "django_geo_db_location" VALUES(12636,NULL,'New Holland, PA',5308,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12637,NULL,'New Holland, PA 17557',5308,222,NULL,44,7036,0);
INSERT INTO "django_geo_db_location" VALUES(12638,NULL,'New Providence, PA',5309,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12639,NULL,'New Providence, PA 17560',5309,222,NULL,44,7037,0);
INSERT INTO "django_geo_db_location" VALUES(12640,NULL,'Paradise, PA',5310,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12641,NULL,'Paradise, PA 17562',5310,222,NULL,44,7038,0);
INSERT INTO "django_geo_db_location" VALUES(12642,NULL,'Peach Bottom, PA',5311,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12643,NULL,'Peach Bottom, PA 17563',5311,222,NULL,44,7039,0);
INSERT INTO "django_geo_db_location" VALUES(12644,NULL,'Penryn, PA',5312,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12645,NULL,'Penryn, PA 17564',5312,222,NULL,44,7040,0);
INSERT INTO "django_geo_db_location" VALUES(12646,NULL,'Pequea, PA',5313,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12647,NULL,'Pequea, PA 17565',5313,222,NULL,44,7041,0);
INSERT INTO "django_geo_db_location" VALUES(12648,NULL,'Quarryville, PA',5314,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12649,NULL,'Quarryville, PA 17566',5314,222,NULL,44,7042,0);
INSERT INTO "django_geo_db_location" VALUES(12650,NULL,'Reamstown, PA',5315,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12651,NULL,'Reamstown, PA 17567',5315,222,NULL,44,7043,0);
INSERT INTO "django_geo_db_location" VALUES(12652,NULL,'Refton, PA',5316,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12653,NULL,'Refton, PA 17568',5316,222,NULL,44,7044,0);
INSERT INTO "django_geo_db_location" VALUES(12654,NULL,'Reinholds, PA',5317,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12655,NULL,'Reinholds, PA 17569',5317,222,NULL,44,7045,0);
INSERT INTO "django_geo_db_location" VALUES(12656,NULL,'Rheems, PA',5318,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12657,NULL,'Rheems, PA 17570',5318,222,NULL,44,7046,0);
INSERT INTO "django_geo_db_location" VALUES(12658,NULL,'Ronks, PA',5319,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12659,NULL,'Ronks, PA 17572',5319,222,NULL,44,7047,0);
INSERT INTO "django_geo_db_location" VALUES(12660,NULL,'Ronks, PA 17573',5319,222,NULL,44,7048,0);
INSERT INTO "django_geo_db_location" VALUES(12661,NULL,'Silver Spring, PA',5320,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12662,NULL,'Silver Spring, PA 17575',5320,222,NULL,44,7049,0);
INSERT INTO "django_geo_db_location" VALUES(12663,NULL,'Smoketown, PA',5321,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12664,NULL,'Smoketown, PA 17576',5321,222,NULL,44,7050,0);
INSERT INTO "django_geo_db_location" VALUES(12665,NULL,'Soudersburg, PA',5322,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12666,NULL,'Soudersburg, PA 17577',5322,222,NULL,44,7051,0);
INSERT INTO "django_geo_db_location" VALUES(12667,NULL,'Stevens, PA',5323,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12668,NULL,'Stevens, PA 17578',5323,222,NULL,44,7052,0);
INSERT INTO "django_geo_db_location" VALUES(12669,NULL,'Strasburg, PA',5324,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12670,NULL,'Strasburg, PA 17579',5324,222,NULL,44,7053,0);
INSERT INTO "django_geo_db_location" VALUES(12671,NULL,'Talmage, PA',5325,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12672,NULL,'Talmage, PA 17580',5325,222,NULL,44,7054,0);
INSERT INTO "django_geo_db_location" VALUES(12673,NULL,'Terre Hill, PA',5326,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12674,NULL,'Terre Hill, PA 17581',5326,222,NULL,44,7055,0);
INSERT INTO "django_geo_db_location" VALUES(12675,NULL,'Washington Boro, PA',5327,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12676,NULL,'Washington Boro, PA 17582',5327,222,NULL,44,7056,0);
INSERT INTO "django_geo_db_location" VALUES(12677,NULL,'West Willow, PA',5328,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12678,NULL,'West Willow, PA 17583',5328,222,NULL,44,7057,0);
INSERT INTO "django_geo_db_location" VALUES(12679,NULL,'Willow Street, PA',5329,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12680,NULL,'Willow Street, PA 17584',5329,222,NULL,44,7058,0);
INSERT INTO "django_geo_db_location" VALUES(12681,NULL,'Witmer, PA',5330,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12682,NULL,'Witmer, PA 17585',5330,222,NULL,44,7059,0);
INSERT INTO "django_geo_db_location" VALUES(12683,NULL,'Lancaster, PA',5331,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12684,NULL,'Lancaster, PA 17601',5331,222,NULL,44,7060,0);
INSERT INTO "django_geo_db_location" VALUES(12685,NULL,'Lancaster, PA 17602',5331,222,NULL,44,7061,0);
INSERT INTO "django_geo_db_location" VALUES(12686,NULL,'Lancaster, PA 17603',5331,222,NULL,44,7062,0);
INSERT INTO "django_geo_db_location" VALUES(12687,NULL,'Lancaster, PA 17604',5331,222,NULL,44,7063,0);
INSERT INTO "django_geo_db_location" VALUES(12688,NULL,'Lancaster, PA 17605',5331,222,NULL,44,7064,0);
INSERT INTO "django_geo_db_location" VALUES(12689,NULL,'Lancaster, PA 17606',5331,222,NULL,44,7065,0);
INSERT INTO "django_geo_db_location" VALUES(12690,NULL,'Lancaster, PA 17607',5331,222,NULL,44,7066,0);
INSERT INTO "django_geo_db_location" VALUES(12691,NULL,'Lancaster, PA 17608',5331,222,NULL,44,7067,0);
INSERT INTO "django_geo_db_location" VALUES(12692,NULL,'Lancaster, PA 17699',5331,222,NULL,44,7068,0);
INSERT INTO "django_geo_db_location" VALUES(12693,NULL,'Williamsport, PA',5332,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12694,NULL,'Williamsport, PA 17701',5332,222,NULL,44,7069,0);
INSERT INTO "django_geo_db_location" VALUES(12695,NULL,'Williamsport, PA 17702',5332,222,NULL,44,7070,0);
INSERT INTO "django_geo_db_location" VALUES(12696,NULL,'Williamsport, PA 17703',5332,222,NULL,44,7071,0);
INSERT INTO "django_geo_db_location" VALUES(12697,NULL,'Williamsport, PA 17705',5332,222,NULL,44,7072,0);
INSERT INTO "django_geo_db_location" VALUES(12698,NULL,'Antes Fort, PA',5333,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12699,NULL,'Antes Fort, PA 17720',5333,222,NULL,44,7073,0);
INSERT INTO "django_geo_db_location" VALUES(12700,NULL,'Avis, PA',5334,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12701,NULL,'Avis, PA 17721',5334,222,NULL,44,7074,0);
INSERT INTO "django_geo_db_location" VALUES(12702,NULL,'Bodines, PA',5335,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12703,NULL,'Bodines, PA 17722',5335,222,NULL,44,7075,0);
INSERT INTO "django_geo_db_location" VALUES(12704,NULL,'Jersey Shore, PA',5336,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12705,NULL,'Jersey Shore, PA 17723',5336,222,NULL,44,7076,0);
INSERT INTO "django_geo_db_location" VALUES(12706,NULL,'Canton, PA',5337,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12707,NULL,'Canton, PA 17724',5337,222,NULL,44,7077,0);
INSERT INTO "django_geo_db_location" VALUES(12708,NULL,'Castanea, PA',5338,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12709,NULL,'Castanea, PA 17726',5338,222,NULL,44,7078,0);
INSERT INTO "django_geo_db_location" VALUES(12710,NULL,'Cedar Run, PA',5339,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12711,NULL,'Cedar Run, PA 17727',5339,222,NULL,44,7079,0);
INSERT INTO "django_geo_db_location" VALUES(12712,NULL,'Cogan Station, PA',5340,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12713,NULL,'Cogan Station, PA 17728',5340,222,NULL,44,7080,0);
INSERT INTO "django_geo_db_location" VALUES(12714,NULL,'Cross Fork, PA',5341,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12715,NULL,'Cross Fork, PA 17729',5341,222,NULL,44,7081,0);
INSERT INTO "django_geo_db_location" VALUES(12716,NULL,'Dewart, PA',5342,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12717,NULL,'Dewart, PA 17730',5342,222,NULL,44,7082,0);
INSERT INTO "django_geo_db_location" VALUES(12718,NULL,'Eagles Mere, PA',5343,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12719,NULL,'Eagles Mere, PA 17731',5343,222,NULL,44,7083,0);
INSERT INTO "django_geo_db_location" VALUES(12720,NULL,'Grover, PA',5344,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12721,NULL,'Grover, PA 17735',5344,222,NULL,44,7084,0);
INSERT INTO "django_geo_db_location" VALUES(12722,NULL,'Hughesville, PA',5345,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12723,NULL,'Hughesville, PA 17737',5345,222,NULL,44,7085,0);
INSERT INTO "django_geo_db_location" VALUES(12724,NULL,'Hyner, PA',5346,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12725,NULL,'Hyner, PA 17738',5346,222,NULL,44,7086,0);
INSERT INTO "django_geo_db_location" VALUES(12726,NULL,'Jersey Mills, PA',5347,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12727,NULL,'Jersey Mills, PA 17739',5347,222,NULL,44,7087,0);
INSERT INTO "django_geo_db_location" VALUES(12728,NULL,'Jersey Shore, PA 17740',5336,222,NULL,44,7088,0);
INSERT INTO "django_geo_db_location" VALUES(12729,NULL,'Watson, PA',5348,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12730,NULL,'Watson, PA 17741',5348,222,NULL,44,7089,0);
INSERT INTO "django_geo_db_location" VALUES(12731,NULL,'Lairdsville, PA',5349,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12732,NULL,'Lairdsville, PA 17742',5349,222,NULL,44,7090,0);
INSERT INTO "django_geo_db_location" VALUES(12733,NULL,'Leroy, PA',5350,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12734,NULL,'Leroy, PA 17743',5350,222,NULL,44,7091,0);
INSERT INTO "django_geo_db_location" VALUES(12735,NULL,'Linden, PA',5351,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12736,NULL,'Linden, PA 17744',5351,222,NULL,44,7092,0);
INSERT INTO "django_geo_db_location" VALUES(12737,NULL,'Lock Haven, PA',5352,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12738,NULL,'Lock Haven, PA 17745',5352,222,NULL,44,7093,0);
INSERT INTO "django_geo_db_location" VALUES(12739,NULL,'Loganton, PA',5353,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12740,NULL,'Loganton, PA 17747',5353,222,NULL,44,7094,0);
INSERT INTO "django_geo_db_location" VALUES(12741,NULL,'McElhattan, PA',5354,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12742,NULL,'McElhattan, PA 17748',5354,222,NULL,44,7095,0);
INSERT INTO "django_geo_db_location" VALUES(12743,NULL,'McEwensville, PA',5355,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12744,NULL,'McEwensville, PA 17749',5355,222,NULL,44,7096,0);
INSERT INTO "django_geo_db_location" VALUES(12745,NULL,'Mackeyville, PA',5356,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12746,NULL,'Mackeyville, PA 17750',5356,222,NULL,44,7097,0);
INSERT INTO "django_geo_db_location" VALUES(12747,NULL,'Mill Hall, PA',5357,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12748,NULL,'Mill Hall, PA 17751',5357,222,NULL,44,7098,0);
INSERT INTO "django_geo_db_location" VALUES(12749,NULL,'Montgomery, PA',5358,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12750,NULL,'Montgomery, PA 17752',5358,222,NULL,44,7099,0);
INSERT INTO "django_geo_db_location" VALUES(12751,NULL,'Montoursville, PA',5359,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12752,NULL,'Montoursville, PA 17754',5359,222,NULL,44,7100,0);
INSERT INTO "django_geo_db_location" VALUES(12753,NULL,'Muncy, PA',5360,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12754,NULL,'Muncy, PA 17756',5360,222,NULL,44,7101,0);
INSERT INTO "django_geo_db_location" VALUES(12755,NULL,'Wolf, PA',5361,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12756,NULL,'Wolf, PA 17757',5361,222,NULL,44,7102,0);
INSERT INTO "django_geo_db_location" VALUES(12757,NULL,'Muncy Valley, PA',5362,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12758,NULL,'Muncy Valley, PA 17758',5362,222,NULL,44,7103,0);
INSERT INTO "django_geo_db_location" VALUES(12759,NULL,'Nisbet, PA',5363,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12760,NULL,'Nisbet, PA 17759',5363,222,NULL,44,7104,0);
INSERT INTO "django_geo_db_location" VALUES(12761,NULL,'North Bend, PA',5364,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12762,NULL,'North Bend, PA 17760',5364,222,NULL,44,7105,0);
INSERT INTO "django_geo_db_location" VALUES(12763,NULL,'Picture Rocks, PA',5365,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12764,NULL,'Picture Rocks, PA 17762',5365,222,NULL,44,7106,0);
INSERT INTO "django_geo_db_location" VALUES(12765,NULL,'Ralston, PA',5366,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12766,NULL,'Ralston, PA 17763',5366,222,NULL,44,7107,0);
INSERT INTO "django_geo_db_location" VALUES(12767,NULL,'Renovo, PA',5367,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12768,NULL,'Renovo, PA 17764',5367,222,NULL,44,7108,0);
INSERT INTO "django_geo_db_location" VALUES(12769,NULL,'Roaring Branch, PA',5368,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12770,NULL,'Roaring Branch, PA 17765',5368,222,NULL,44,7109,0);
INSERT INTO "django_geo_db_location" VALUES(12771,NULL,'Salona, PA',5369,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12772,NULL,'Salona, PA 17767',5369,222,NULL,44,7110,0);
INSERT INTO "django_geo_db_location" VALUES(12773,NULL,'Shunk, PA',5370,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12774,NULL,'Shunk, PA 17768',5370,222,NULL,44,7111,0);
INSERT INTO "django_geo_db_location" VALUES(12775,NULL,'Slate Run, PA',5371,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12776,NULL,'Slate Run, PA 17769',5371,222,NULL,44,7112,0);
INSERT INTO "django_geo_db_location" VALUES(12777,NULL,'Trout Run, PA',5372,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12778,NULL,'Trout Run, PA 17771',5372,222,NULL,44,7113,0);
INSERT INTO "django_geo_db_location" VALUES(12779,NULL,'Turbotville, PA',5373,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12780,NULL,'Turbotville, PA 17772',5373,222,NULL,44,7114,0);
INSERT INTO "django_geo_db_location" VALUES(12781,NULL,'Tylersville, PA',5374,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12782,NULL,'Tylersville, PA 17773',5374,222,NULL,44,7115,0);
INSERT INTO "django_geo_db_location" VALUES(12783,NULL,'Unityville, PA',5375,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12784,NULL,'Unityville, PA 17774',5375,222,NULL,44,7116,0);
INSERT INTO "django_geo_db_location" VALUES(12785,NULL,'Waterville, PA',5376,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12786,NULL,'Waterville, PA 17776',5376,222,NULL,44,7117,0);
INSERT INTO "django_geo_db_location" VALUES(12787,NULL,'Watsontown, PA',5377,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12788,NULL,'Watsontown, PA 17777',5377,222,NULL,44,7118,0);
INSERT INTO "django_geo_db_location" VALUES(12789,NULL,'Westport, PA',5378,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12790,NULL,'Westport, PA 17778',5378,222,NULL,44,7119,0);
INSERT INTO "django_geo_db_location" VALUES(12791,NULL,'Woolrich, PA',5379,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12792,NULL,'Woolrich, PA 17779',5379,222,NULL,44,7120,0);
INSERT INTO "django_geo_db_location" VALUES(12793,NULL,'Penn, PA 17786',4527,222,NULL,44,7121,0);
INSERT INTO "django_geo_db_location" VALUES(12794,NULL,'Sunbury, PA',5380,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12795,NULL,'Sunbury, PA 17801',5380,222,NULL,44,7122,0);
INSERT INTO "django_geo_db_location" VALUES(12796,NULL,'Allenwood, PA',5381,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12797,NULL,'Allenwood, PA 17810',5381,222,NULL,44,7123,0);
INSERT INTO "django_geo_db_location" VALUES(12798,NULL,'Beaver Springs, PA',5382,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12799,NULL,'Beaver Springs, PA 17812',5382,222,NULL,44,7124,0);
INSERT INTO "django_geo_db_location" VALUES(12800,NULL,'Beavertown, PA',5383,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12801,NULL,'Beavertown, PA 17813',5383,222,NULL,44,7125,0);
INSERT INTO "django_geo_db_location" VALUES(12802,NULL,'Benton, PA',5384,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12803,NULL,'Benton, PA 17814',5384,222,NULL,44,7126,0);
INSERT INTO "django_geo_db_location" VALUES(12804,NULL,'Bloomsburg, PA',5385,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12805,NULL,'Bloomsburg, PA 17815',5385,222,NULL,44,7127,0);
INSERT INTO "django_geo_db_location" VALUES(12806,NULL,'Catawissa, PA',5386,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12807,NULL,'Catawissa, PA 17820',5386,222,NULL,44,7128,0);
INSERT INTO "django_geo_db_location" VALUES(12808,NULL,'Danville, PA',5387,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12809,NULL,'Danville, PA 17821',5387,222,NULL,44,7129,0);
INSERT INTO "django_geo_db_location" VALUES(12810,NULL,'Danville, PA 17822',5387,222,NULL,44,7130,0);
INSERT INTO "django_geo_db_location" VALUES(12811,NULL,'Dornsife, PA',5388,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12812,NULL,'Dornsife, PA 17823',5388,222,NULL,44,7131,0);
INSERT INTO "django_geo_db_location" VALUES(12813,NULL,'Elysburg, PA',5389,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12814,NULL,'Elysburg, PA 17824',5389,222,NULL,44,7132,0);
INSERT INTO "django_geo_db_location" VALUES(12815,NULL,'Excelsior, PA',5390,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12816,NULL,'Excelsior, PA 17825',5390,222,NULL,44,7133,0);
INSERT INTO "django_geo_db_location" VALUES(12817,NULL,'Freeburg, PA',5391,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12818,NULL,'Freeburg, PA 17827',5391,222,NULL,44,7134,0);
INSERT INTO "django_geo_db_location" VALUES(12819,NULL,'Gowen City, PA',5392,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12820,NULL,'Gowen City, PA 17828',5392,222,NULL,44,7135,0);
INSERT INTO "django_geo_db_location" VALUES(12821,NULL,'Hartleton, PA',5393,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12822,NULL,'Hartleton, PA 17829',5393,222,NULL,44,7136,0);
INSERT INTO "django_geo_db_location" VALUES(12823,NULL,'Herndon, PA',5394,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12824,NULL,'Herndon, PA 17830',5394,222,NULL,44,7137,0);
INSERT INTO "django_geo_db_location" VALUES(12825,NULL,'Hummels Wharf, PA',5395,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12826,NULL,'Hummels Wharf, PA 17831',5395,222,NULL,44,7138,0);
INSERT INTO "django_geo_db_location" VALUES(12827,NULL,'Marion Heights, PA',5396,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12828,NULL,'Marion Heights, PA 17832',5396,222,NULL,44,7139,0);
INSERT INTO "django_geo_db_location" VALUES(12829,NULL,'Kreamer, PA',5397,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12830,NULL,'Kreamer, PA 17833',5397,222,NULL,44,7140,0);
INSERT INTO "django_geo_db_location" VALUES(12831,NULL,'Kulpmont, PA',5398,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12832,NULL,'Kulpmont, PA 17834',5398,222,NULL,44,7141,0);
INSERT INTO "django_geo_db_location" VALUES(12833,NULL,'Laurelton, PA',5399,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12834,NULL,'Laurelton, PA 17835',5399,222,NULL,44,7142,0);
INSERT INTO "django_geo_db_location" VALUES(12835,NULL,'Leck Kill, PA',5400,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12836,NULL,'Leck Kill, PA 17836',5400,222,NULL,44,7143,0);
INSERT INTO "django_geo_db_location" VALUES(12837,NULL,'Lewisburg, PA',5401,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12838,NULL,'Lewisburg, PA 17837',5401,222,NULL,44,7144,0);
INSERT INTO "django_geo_db_location" VALUES(12839,NULL,'Light Street, PA',5402,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12840,NULL,'Light Street, PA 17839',5402,222,NULL,44,7145,0);
INSERT INTO "django_geo_db_location" VALUES(12841,NULL,'Locust Gap, PA',5403,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12842,NULL,'Locust Gap, PA 17840',5403,222,NULL,44,7146,0);
INSERT INTO "django_geo_db_location" VALUES(12843,NULL,'McClure, PA',5404,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12844,NULL,'McClure, PA 17841',5404,222,NULL,44,7147,0);
INSERT INTO "django_geo_db_location" VALUES(12845,NULL,'Middleburg, PA',5405,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12846,NULL,'Middleburg, PA 17842',5405,222,NULL,44,7148,0);
INSERT INTO "django_geo_db_location" VALUES(12847,NULL,'Beaver Springs, PA 17843',5382,222,NULL,44,7149,0);
INSERT INTO "django_geo_db_location" VALUES(12848,NULL,'Mifflinburg, PA',5406,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12849,NULL,'Mifflinburg, PA 17844',5406,222,NULL,44,7150,0);
INSERT INTO "django_geo_db_location" VALUES(12850,NULL,'Millmont, PA',5407,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12851,NULL,'Millmont, PA 17845',5407,222,NULL,44,7151,0);
INSERT INTO "django_geo_db_location" VALUES(12852,NULL,'Millville, PA',5408,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12853,NULL,'Millville, PA 17846',5408,222,NULL,44,7152,0);
INSERT INTO "django_geo_db_location" VALUES(12854,NULL,'Milton, PA',5409,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12855,NULL,'Milton, PA 17847',5409,222,NULL,44,7153,0);
INSERT INTO "django_geo_db_location" VALUES(12856,NULL,'Montandon, PA',5410,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12857,NULL,'Montandon, PA 17850',5410,222,NULL,44,7154,0);
INSERT INTO "django_geo_db_location" VALUES(12858,NULL,'Mount Carmel, PA',5411,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12859,NULL,'Mount Carmel, PA 17851',5411,222,NULL,44,7155,0);
INSERT INTO "django_geo_db_location" VALUES(12860,NULL,'Mount Pleasant Mills, PA',5412,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12861,NULL,'Mount Pleasant Mills, PA 17853',5412,222,NULL,44,7156,0);
INSERT INTO "django_geo_db_location" VALUES(12862,NULL,'New Berlin, PA',5413,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12863,NULL,'New Berlin, PA 17855',5413,222,NULL,44,7157,0);
INSERT INTO "django_geo_db_location" VALUES(12864,NULL,'New Columbia, PA',5414,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12865,NULL,'New Columbia, PA 17856',5414,222,NULL,44,7158,0);
INSERT INTO "django_geo_db_location" VALUES(12866,NULL,'Northumberland, PA',5415,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12867,NULL,'Northumberland, PA 17857',5415,222,NULL,44,7159,0);
INSERT INTO "django_geo_db_location" VALUES(12868,NULL,'Numidia, PA',5416,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12869,NULL,'Numidia, PA 17858',5416,222,NULL,44,7160,0);
INSERT INTO "django_geo_db_location" VALUES(12870,NULL,'Orangeville, PA',5417,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12871,NULL,'Orangeville, PA 17859',5417,222,NULL,44,7161,0);
INSERT INTO "django_geo_db_location" VALUES(12872,NULL,'Paxinos, PA',5418,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12873,NULL,'Paxinos, PA 17860',5418,222,NULL,44,7162,0);
INSERT INTO "django_geo_db_location" VALUES(12874,NULL,'Paxtonville, PA',5419,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12875,NULL,'Paxtonville, PA 17861',5419,222,NULL,44,7163,0);
INSERT INTO "django_geo_db_location" VALUES(12876,NULL,'Penns Creek, PA',5420,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12877,NULL,'Penns Creek, PA 17862',5420,222,NULL,44,7164,0);
INSERT INTO "django_geo_db_location" VALUES(12878,NULL,'Port Trevorton, PA',5421,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12879,NULL,'Port Trevorton, PA 17864',5421,222,NULL,44,7165,0);
INSERT INTO "django_geo_db_location" VALUES(12880,NULL,'Potts Grove, PA',5422,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12881,NULL,'Potts Grove, PA 17865',5422,222,NULL,44,7166,0);
INSERT INTO "django_geo_db_location" VALUES(12882,NULL,'Coal Township, PA',5423,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12883,NULL,'Coal Township, PA 17866',5423,222,NULL,44,7167,0);
INSERT INTO "django_geo_db_location" VALUES(12884,NULL,'Rebuck, PA',5424,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12885,NULL,'Rebuck, PA 17867',5424,222,NULL,44,7168,0);
INSERT INTO "django_geo_db_location" VALUES(12886,NULL,'Riverside, PA',5425,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12887,NULL,'Riverside, PA 17868',5425,222,NULL,44,7169,0);
INSERT INTO "django_geo_db_location" VALUES(12888,NULL,'Selinsgrove, PA',5426,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12889,NULL,'Selinsgrove, PA 17870',5426,222,NULL,44,7170,0);
INSERT INTO "django_geo_db_location" VALUES(12890,NULL,'Shamokin, PA',5427,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12891,NULL,'Shamokin, PA 17872',5427,222,NULL,44,7171,0);
INSERT INTO "django_geo_db_location" VALUES(12892,NULL,'Shamokin Dam, PA',5428,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12893,NULL,'Shamokin Dam, PA 17876',5428,222,NULL,44,7172,0);
INSERT INTO "django_geo_db_location" VALUES(12894,NULL,'Snydertown, PA',5429,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12895,NULL,'Snydertown, PA 17877',5429,222,NULL,44,7173,0);
INSERT INTO "django_geo_db_location" VALUES(12896,NULL,'Stillwater, PA',5430,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12897,NULL,'Stillwater, PA 17878',5430,222,NULL,44,7174,0);
INSERT INTO "django_geo_db_location" VALUES(12898,NULL,'Swengel, PA',5431,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12899,NULL,'Swengel, PA 17880',5431,222,NULL,44,7175,0);
INSERT INTO "django_geo_db_location" VALUES(12900,NULL,'Trevorton, PA',5432,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12901,NULL,'Trevorton, PA 17881',5432,222,NULL,44,7176,0);
INSERT INTO "django_geo_db_location" VALUES(12902,NULL,'Troxelville, PA',5433,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12903,NULL,'Troxelville, PA 17882',5433,222,NULL,44,7177,0);
INSERT INTO "django_geo_db_location" VALUES(12904,NULL,'Vicksburg, PA',5434,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12905,NULL,'Vicksburg, PA 17883',5434,222,NULL,44,7178,0);
INSERT INTO "django_geo_db_location" VALUES(12906,NULL,'Washingtonville, PA',5435,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12907,NULL,'Washingtonville, PA 17884',5435,222,NULL,44,7179,0);
INSERT INTO "django_geo_db_location" VALUES(12908,NULL,'Weikert, PA',5436,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12909,NULL,'Weikert, PA 17885',5436,222,NULL,44,7180,0);
INSERT INTO "django_geo_db_location" VALUES(12910,NULL,'West Milton, PA',5437,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12911,NULL,'West Milton, PA 17886',5437,222,NULL,44,7181,0);
INSERT INTO "django_geo_db_location" VALUES(12912,NULL,'White Deer, PA',5438,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12913,NULL,'White Deer, PA 17887',5438,222,NULL,44,7182,0);
INSERT INTO "django_geo_db_location" VALUES(12914,NULL,'Wilburton, PA',5439,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12915,NULL,'Wilburton, PA 17888',5439,222,NULL,44,7183,0);
INSERT INTO "django_geo_db_location" VALUES(12916,NULL,'Winfield, PA',5440,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12917,NULL,'Winfield, PA 17889',5440,222,NULL,44,7184,0);
INSERT INTO "django_geo_db_location" VALUES(12918,NULL,'Pottsville, PA',5441,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12919,NULL,'Pottsville, PA 17901',5441,222,NULL,44,7185,0);
INSERT INTO "django_geo_db_location" VALUES(12920,NULL,'Aristes, PA',5442,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12921,NULL,'Aristes, PA 17920',5442,222,NULL,44,7186,0);
INSERT INTO "django_geo_db_location" VALUES(12922,NULL,'Ashland, PA',5443,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12923,NULL,'Ashland, PA 17921',5443,222,NULL,44,7187,0);
INSERT INTO "django_geo_db_location" VALUES(12924,NULL,'Auburn, PA',5444,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12925,NULL,'Auburn, PA 17922',5444,222,NULL,44,7188,0);
INSERT INTO "django_geo_db_location" VALUES(12926,NULL,'Branchdale, PA',5445,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12927,NULL,'Branchdale, PA 17923',5445,222,NULL,44,7189,0);
INSERT INTO "django_geo_db_location" VALUES(12928,NULL,'Brockton, PA',5446,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12929,NULL,'Brockton, PA 17925',5446,222,NULL,44,7190,0);
INSERT INTO "django_geo_db_location" VALUES(12930,NULL,'Centralia, PA',5447,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12931,NULL,'Centralia, PA 17927',5447,222,NULL,44,7191,0);
INSERT INTO "django_geo_db_location" VALUES(12932,NULL,'Cressona, PA',5448,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12933,NULL,'Cressona, PA 17929',5448,222,NULL,44,7192,0);
INSERT INTO "django_geo_db_location" VALUES(12934,NULL,'Cumbola, PA',5449,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12935,NULL,'Cumbola, PA 17930',5449,222,NULL,44,7193,0);
INSERT INTO "django_geo_db_location" VALUES(12936,NULL,'Frackville, PA',5450,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12937,NULL,'Frackville, PA 17931',5450,222,NULL,44,7194,0);
INSERT INTO "django_geo_db_location" VALUES(12938,NULL,'Frackville, PA 17932',5450,222,NULL,44,7195,0);
INSERT INTO "django_geo_db_location" VALUES(12939,NULL,'Friedensburg, PA',5451,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12940,NULL,'Friedensburg, PA 17933',5451,222,NULL,44,7196,0);
INSERT INTO "django_geo_db_location" VALUES(12941,NULL,'Gilberton, PA',5452,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12942,NULL,'Gilberton, PA 17934',5452,222,NULL,44,7197,0);
INSERT INTO "django_geo_db_location" VALUES(12943,NULL,'Girardville, PA',5453,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12944,NULL,'Girardville, PA 17935',5453,222,NULL,44,7198,0);
INSERT INTO "django_geo_db_location" VALUES(12945,NULL,'Gordon, PA',5454,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12946,NULL,'Gordon, PA 17936',5454,222,NULL,44,7199,0);
INSERT INTO "django_geo_db_location" VALUES(12947,NULL,'Hegins, PA',5455,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12948,NULL,'Hegins, PA 17938',5455,222,NULL,44,7200,0);
INSERT INTO "django_geo_db_location" VALUES(12949,NULL,'Klingerstown, PA',5456,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12950,NULL,'Klingerstown, PA 17941',5456,222,NULL,44,7201,0);
INSERT INTO "django_geo_db_location" VALUES(12951,NULL,'Landingville, PA',5457,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12952,NULL,'Landingville, PA 17942',5457,222,NULL,44,7202,0);
INSERT INTO "django_geo_db_location" VALUES(12953,NULL,'Lavelle, PA',5458,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12954,NULL,'Lavelle, PA 17943',5458,222,NULL,44,7203,0);
INSERT INTO "django_geo_db_location" VALUES(12955,NULL,'Llewellyn, PA',5459,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12956,NULL,'Llewellyn, PA 17944',5459,222,NULL,44,7204,0);
INSERT INTO "django_geo_db_location" VALUES(12957,NULL,'Locustdale, PA',5460,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12958,NULL,'Locustdale, PA 17945',5460,222,NULL,44,7205,0);
INSERT INTO "django_geo_db_location" VALUES(12959,NULL,'Lost Creek, PA',5461,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12960,NULL,'Lost Creek, PA 17946',5461,222,NULL,44,7206,0);
INSERT INTO "django_geo_db_location" VALUES(12961,NULL,'Mahanoy City, PA',5462,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12962,NULL,'Mahanoy City, PA 17948',5462,222,NULL,44,7207,0);
INSERT INTO "django_geo_db_location" VALUES(12963,NULL,'Mahanoy Plane, PA',5463,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12964,NULL,'Mahanoy Plane, PA 17949',5463,222,NULL,44,7208,0);
INSERT INTO "django_geo_db_location" VALUES(12965,NULL,'Mar Lin, PA',5464,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12966,NULL,'Mar Lin, PA 17951',5464,222,NULL,44,7209,0);
INSERT INTO "django_geo_db_location" VALUES(12967,NULL,'Mary D, PA',5465,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12968,NULL,'Mary D, PA 17952',5465,222,NULL,44,7210,0);
INSERT INTO "django_geo_db_location" VALUES(12969,NULL,'Middleport, PA',5466,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12970,NULL,'Middleport, PA 17953',5466,222,NULL,44,7211,0);
INSERT INTO "django_geo_db_location" VALUES(12971,NULL,'Minersville, PA',5467,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12972,NULL,'Minersville, PA 17954',5467,222,NULL,44,7212,0);
INSERT INTO "django_geo_db_location" VALUES(12973,NULL,'Muir, PA',5468,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12974,NULL,'Muir, PA 17957',5468,222,NULL,44,7213,0);
INSERT INTO "django_geo_db_location" VALUES(12975,NULL,'New Philadelphia, PA',5469,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12976,NULL,'New Philadelphia, PA 17959',5469,222,NULL,44,7214,0);
INSERT INTO "django_geo_db_location" VALUES(12977,NULL,'New Ringgold, PA',5470,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12978,NULL,'New Ringgold, PA 17960',5470,222,NULL,44,7215,0);
INSERT INTO "django_geo_db_location" VALUES(12979,NULL,'Orwigsburg, PA',5471,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12980,NULL,'Orwigsburg, PA 17961',5471,222,NULL,44,7216,0);
INSERT INTO "django_geo_db_location" VALUES(12981,NULL,'Pine Grove, PA',5472,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12982,NULL,'Pine Grove, PA 17963',5472,222,NULL,44,7217,0);
INSERT INTO "django_geo_db_location" VALUES(12983,NULL,'Pitman, PA',5473,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12984,NULL,'Pitman, PA 17964',5473,222,NULL,44,7218,0);
INSERT INTO "django_geo_db_location" VALUES(12985,NULL,'Port Carbon, PA',5474,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12986,NULL,'Port Carbon, PA 17965',5474,222,NULL,44,7219,0);
INSERT INTO "django_geo_db_location" VALUES(12987,NULL,'Ravine, PA',5475,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12988,NULL,'Ravine, PA 17966',5475,222,NULL,44,7220,0);
INSERT INTO "django_geo_db_location" VALUES(12989,NULL,'Ringtown, PA',5476,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12990,NULL,'Ringtown, PA 17967',5476,222,NULL,44,7221,0);
INSERT INTO "django_geo_db_location" VALUES(12991,NULL,'Sacramento, PA',5477,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12992,NULL,'Sacramento, PA 17968',5477,222,NULL,44,7222,0);
INSERT INTO "django_geo_db_location" VALUES(12993,NULL,'Saint Clair, PA',5478,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12994,NULL,'Saint Clair, PA 17970',5478,222,NULL,44,7223,0);
INSERT INTO "django_geo_db_location" VALUES(12995,NULL,'Schuylkill Haven, PA',5479,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12996,NULL,'Schuylkill Haven, PA 17972',5479,222,NULL,44,7224,0);
INSERT INTO "django_geo_db_location" VALUES(12997,NULL,'Seltzer, PA',5480,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(12998,NULL,'Seltzer, PA 17974',5480,222,NULL,44,7225,0);
INSERT INTO "django_geo_db_location" VALUES(12999,NULL,'Shenandoah, PA',5481,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13000,NULL,'Shenandoah, PA 17976',5481,222,NULL,44,7226,0);
INSERT INTO "django_geo_db_location" VALUES(13001,NULL,'Spring Glen, PA',5482,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13002,NULL,'Spring Glen, PA 17978',5482,222,NULL,44,7227,0);
INSERT INTO "django_geo_db_location" VALUES(13003,NULL,'Summit Station, PA',5483,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13004,NULL,'Summit Station, PA 17979',5483,222,NULL,44,7228,0);
INSERT INTO "django_geo_db_location" VALUES(13005,NULL,'Tower City, PA',5484,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13006,NULL,'Tower City, PA 17980',5484,222,NULL,44,7229,0);
INSERT INTO "django_geo_db_location" VALUES(13007,NULL,'Tremont, PA',5485,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13008,NULL,'Tremont, PA 17981',5485,222,NULL,44,7230,0);
INSERT INTO "django_geo_db_location" VALUES(13009,NULL,'Tuscarora, PA',5486,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13010,NULL,'Tuscarora, PA 17982',5486,222,NULL,44,7231,0);
INSERT INTO "django_geo_db_location" VALUES(13011,NULL,'Valley View, PA',5487,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13012,NULL,'Valley View, PA 17983',5487,222,NULL,44,7232,0);
INSERT INTO "django_geo_db_location" VALUES(13013,NULL,'Zion Grove, PA',5488,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13014,NULL,'Zion Grove, PA 17985',5488,222,NULL,44,7233,0);
INSERT INTO "django_geo_db_location" VALUES(13015,NULL,'Lehigh Valley, PA',5489,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13016,NULL,'Lehigh Valley, PA 18001',5489,222,NULL,44,7234,0);
INSERT INTO "django_geo_db_location" VALUES(13017,NULL,'Lehigh Valley, PA 18002',5489,222,NULL,44,7235,0);
INSERT INTO "django_geo_db_location" VALUES(13018,NULL,'Lehigh Valley, PA 18003',5489,222,NULL,44,7236,0);
INSERT INTO "django_geo_db_location" VALUES(13019,NULL,'Ackermanville, PA',5490,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13020,NULL,'Ackermanville, PA 18010',5490,222,NULL,44,7237,0);
INSERT INTO "django_geo_db_location" VALUES(13021,NULL,'Alburtis, PA',5491,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13022,NULL,'Alburtis, PA 18011',5491,222,NULL,44,7238,0);
INSERT INTO "django_geo_db_location" VALUES(13023,NULL,'Aquashicola, PA',5492,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13024,NULL,'Aquashicola, PA 18012',5492,222,NULL,44,7239,0);
INSERT INTO "django_geo_db_location" VALUES(13025,NULL,'Bangor, PA',5493,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13026,NULL,'Bangor, PA 18013',5493,222,NULL,44,7240,0);
INSERT INTO "django_geo_db_location" VALUES(13027,NULL,'Bath, PA',5494,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13028,NULL,'Bath, PA 18014',5494,222,NULL,44,7241,0);
INSERT INTO "django_geo_db_location" VALUES(13029,NULL,'Bethlehem, PA',5495,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13030,NULL,'Bethlehem, PA 18015',5495,222,NULL,44,7242,0);
INSERT INTO "django_geo_db_location" VALUES(13031,NULL,'Bethlehem, PA 18016',5495,222,NULL,44,7243,0);
INSERT INTO "django_geo_db_location" VALUES(13032,NULL,'Bethlehem, PA 18017',5495,222,NULL,44,7244,0);
INSERT INTO "django_geo_db_location" VALUES(13033,NULL,'Bethlehem, PA 18018',5495,222,NULL,44,7245,0);
INSERT INTO "django_geo_db_location" VALUES(13034,NULL,'Bethlehem, PA 18020',5495,222,NULL,44,7246,0);
INSERT INTO "django_geo_db_location" VALUES(13035,NULL,'Hazleton, PA',5496,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13036,NULL,'Hazleton, PA 18021',5496,222,NULL,44,7247,0);
INSERT INTO "django_geo_db_location" VALUES(13037,NULL,'Bethlehem, PA 18024',5495,222,NULL,44,7248,0);
INSERT INTO "django_geo_db_location" VALUES(13038,NULL,'Bethlehem, PA 18025',5495,222,NULL,44,7249,0);
INSERT INTO "django_geo_db_location" VALUES(13039,NULL,'Bowmanstown, PA',5497,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13040,NULL,'Bowmanstown, PA 18030',5497,222,NULL,44,7250,0);
INSERT INTO "django_geo_db_location" VALUES(13041,NULL,'Breinigsville, PA',5498,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13042,NULL,'Breinigsville, PA 18031',5498,222,NULL,44,7251,0);
INSERT INTO "django_geo_db_location" VALUES(13043,NULL,'Catasauqua, PA',5499,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13044,NULL,'Catasauqua, PA 18032',5499,222,NULL,44,7252,0);
INSERT INTO "django_geo_db_location" VALUES(13045,NULL,'Center Valley, PA',5500,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13046,NULL,'Center Valley, PA 18034',5500,222,NULL,44,7253,0);
INSERT INTO "django_geo_db_location" VALUES(13047,NULL,'Cherryville, PA',5501,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13048,NULL,'Cherryville, PA 18035',5501,222,NULL,44,7254,0);
INSERT INTO "django_geo_db_location" VALUES(13049,NULL,'Coopersburg, PA',5502,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13050,NULL,'Coopersburg, PA 18036',5502,222,NULL,44,7255,0);
INSERT INTO "django_geo_db_location" VALUES(13051,NULL,'Coplay, PA',5503,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13052,NULL,'Coplay, PA 18037',5503,222,NULL,44,7256,0);
INSERT INTO "django_geo_db_location" VALUES(13053,NULL,'Danielsville, PA',5504,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13054,NULL,'Danielsville, PA 18038',5504,222,NULL,44,7257,0);
INSERT INTO "django_geo_db_location" VALUES(13055,NULL,'Durham, PA',5505,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13056,NULL,'Durham, PA 18039',5505,222,NULL,44,7258,0);
INSERT INTO "django_geo_db_location" VALUES(13057,NULL,'Easton, PA',5506,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13058,NULL,'Easton, PA 18040',5506,222,NULL,44,7259,0);
INSERT INTO "django_geo_db_location" VALUES(13059,NULL,'East Greenville, PA',5507,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13060,NULL,'East Greenville, PA 18041',5507,222,NULL,44,7260,0);
INSERT INTO "django_geo_db_location" VALUES(13061,NULL,'Easton, PA 18042',5506,222,NULL,44,7261,0);
INSERT INTO "django_geo_db_location" VALUES(13062,NULL,'Easton, PA 18043',5506,222,NULL,44,7262,0);
INSERT INTO "django_geo_db_location" VALUES(13063,NULL,'Easton, PA 18044',5506,222,NULL,44,7263,0);
INSERT INTO "django_geo_db_location" VALUES(13064,NULL,'Easton, PA 18045',5506,222,NULL,44,7264,0);
INSERT INTO "django_geo_db_location" VALUES(13065,NULL,'East Texas, PA',5508,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13066,NULL,'East Texas, PA 18046',5508,222,NULL,44,7265,0);
INSERT INTO "django_geo_db_location" VALUES(13067,NULL,'Emmaus, PA',5509,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13068,NULL,'Emmaus, PA 18049',5509,222,NULL,44,7266,0);
INSERT INTO "django_geo_db_location" VALUES(13069,NULL,'Flicksville, PA',5510,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13070,NULL,'Flicksville, PA 18050',5510,222,NULL,44,7267,0);
INSERT INTO "django_geo_db_location" VALUES(13071,NULL,'Fogelsville, PA',5511,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13072,NULL,'Fogelsville, PA 18051',5511,222,NULL,44,7268,0);
INSERT INTO "django_geo_db_location" VALUES(13073,NULL,'Whitehall, PA',5512,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13074,NULL,'Whitehall, PA 18052',5512,222,NULL,44,7269,0);
INSERT INTO "django_geo_db_location" VALUES(13075,NULL,'Germansville, PA',5513,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13076,NULL,'Germansville, PA 18053',5513,222,NULL,44,7270,0);
INSERT INTO "django_geo_db_location" VALUES(13077,NULL,'Green Lane, PA',5514,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13078,NULL,'Green Lane, PA 18054',5514,222,NULL,44,7271,0);
INSERT INTO "django_geo_db_location" VALUES(13079,NULL,'Hellertown, PA',5515,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13080,NULL,'Hellertown, PA 18055',5515,222,NULL,44,7272,0);
INSERT INTO "django_geo_db_location" VALUES(13081,NULL,'Hereford, PA',5516,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13082,NULL,'Hereford, PA 18056',5516,222,NULL,44,7273,0);
INSERT INTO "django_geo_db_location" VALUES(13083,NULL,'Kunkletown, PA',5517,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13084,NULL,'Kunkletown, PA 18058',5517,222,NULL,44,7274,0);
INSERT INTO "django_geo_db_location" VALUES(13085,NULL,'Laurys Station, PA',5518,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13086,NULL,'Laurys Station, PA 18059',5518,222,NULL,44,7275,0);
INSERT INTO "django_geo_db_location" VALUES(13087,NULL,'Limeport, PA',5519,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13088,NULL,'Limeport, PA 18060',5519,222,NULL,44,7276,0);
INSERT INTO "django_geo_db_location" VALUES(13089,NULL,'Macungie, PA',5520,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13090,NULL,'Macungie, PA 18062',5520,222,NULL,44,7277,0);
INSERT INTO "django_geo_db_location" VALUES(13091,NULL,'Martins Creek, PA',5521,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13092,NULL,'Martins Creek, PA 18063',5521,222,NULL,44,7278,0);
INSERT INTO "django_geo_db_location" VALUES(13093,NULL,'Nazareth, PA',5522,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13094,NULL,'Nazareth, PA 18064',5522,222,NULL,44,7279,0);
INSERT INTO "django_geo_db_location" VALUES(13095,NULL,'Neffs, PA',5523,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13096,NULL,'Neffs, PA 18065',5523,222,NULL,44,7280,0);
INSERT INTO "django_geo_db_location" VALUES(13097,NULL,'New Tripoli, PA',5524,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13098,NULL,'New Tripoli, PA 18066',5524,222,NULL,44,7281,0);
INSERT INTO "django_geo_db_location" VALUES(13099,NULL,'Northampton, PA',5525,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13100,NULL,'Northampton, PA 18067',5525,222,NULL,44,7282,0);
INSERT INTO "django_geo_db_location" VALUES(13101,NULL,'Old Zionsville, PA',5526,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13102,NULL,'Old Zionsville, PA 18068',5526,222,NULL,44,7283,0);
INSERT INTO "django_geo_db_location" VALUES(13103,NULL,'Orefield, PA',5527,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13104,NULL,'Orefield, PA 18069',5527,222,NULL,44,7284,0);
INSERT INTO "django_geo_db_location" VALUES(13105,NULL,'Palm, PA',5528,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13106,NULL,'Palm, PA 18070',5528,222,NULL,44,7285,0);
INSERT INTO "django_geo_db_location" VALUES(13107,NULL,'Palmerton, PA',5529,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13108,NULL,'Palmerton, PA 18071',5529,222,NULL,44,7286,0);
INSERT INTO "django_geo_db_location" VALUES(13109,NULL,'Pen Argyl, PA',5530,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13110,NULL,'Pen Argyl, PA 18072',5530,222,NULL,44,7287,0);
INSERT INTO "django_geo_db_location" VALUES(13111,NULL,'Pennsburg, PA',5531,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13112,NULL,'Pennsburg, PA 18073',5531,222,NULL,44,7288,0);
INSERT INTO "django_geo_db_location" VALUES(13113,NULL,'Perkiomenville, PA',5532,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13114,NULL,'Perkiomenville, PA 18074',5532,222,NULL,44,7289,0);
INSERT INTO "django_geo_db_location" VALUES(13115,NULL,'Red Hill, PA',5533,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13116,NULL,'Red Hill, PA 18076',5533,222,NULL,44,7290,0);
INSERT INTO "django_geo_db_location" VALUES(13117,NULL,'Riegelsville, PA',5534,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13118,NULL,'Riegelsville, PA 18077',5534,222,NULL,44,7291,0);
INSERT INTO "django_geo_db_location" VALUES(13119,NULL,'Schnecksville, PA',5535,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13120,NULL,'Schnecksville, PA 18078',5535,222,NULL,44,7292,0);
INSERT INTO "django_geo_db_location" VALUES(13121,NULL,'Slatedale, PA',5536,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13122,NULL,'Slatedale, PA 18079',5536,222,NULL,44,7293,0);
INSERT INTO "django_geo_db_location" VALUES(13123,NULL,'Slatington, PA',5537,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13124,NULL,'Slatington, PA 18080',5537,222,NULL,44,7294,0);
INSERT INTO "django_geo_db_location" VALUES(13125,NULL,'Springtown, PA',5538,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13126,NULL,'Springtown, PA 18081',5538,222,NULL,44,7295,0);
INSERT INTO "django_geo_db_location" VALUES(13127,NULL,'Stockertown, PA',5539,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13128,NULL,'Stockertown, PA 18083',5539,222,NULL,44,7296,0);
INSERT INTO "django_geo_db_location" VALUES(13129,NULL,'Sumneytown, PA',5540,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13130,NULL,'Sumneytown, PA 18084',5540,222,NULL,44,7297,0);
INSERT INTO "django_geo_db_location" VALUES(13131,NULL,'Tatamy, PA',5541,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13132,NULL,'Tatamy, PA 18085',5541,222,NULL,44,7298,0);
INSERT INTO "django_geo_db_location" VALUES(13133,NULL,'Treichlers, PA',5542,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13134,NULL,'Treichlers, PA 18086',5542,222,NULL,44,7299,0);
INSERT INTO "django_geo_db_location" VALUES(13135,NULL,'Trexlertown, PA',5543,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13136,NULL,'Trexlertown, PA 18087',5543,222,NULL,44,7300,0);
INSERT INTO "django_geo_db_location" VALUES(13137,NULL,'Walnutport, PA',5544,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13138,NULL,'Walnutport, PA 18088',5544,222,NULL,44,7301,0);
INSERT INTO "django_geo_db_location" VALUES(13139,NULL,'Wind Gap, PA',5545,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13140,NULL,'Wind Gap, PA 18091',5545,222,NULL,44,7302,0);
INSERT INTO "django_geo_db_location" VALUES(13141,NULL,'Zionsville, PA',5546,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13142,NULL,'Zionsville, PA 18092',5546,222,NULL,44,7303,0);
INSERT INTO "django_geo_db_location" VALUES(13143,NULL,'South Whitehall, PA',5547,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13144,NULL,'South Whitehall, PA 18096',5547,222,NULL,44,7304,0);
INSERT INTO "django_geo_db_location" VALUES(13145,NULL,'Emmaus, PA 18098',5509,222,NULL,44,7305,0);
INSERT INTO "django_geo_db_location" VALUES(13146,NULL,'Emmaus, PA 18099',5509,222,NULL,44,7306,0);
INSERT INTO "django_geo_db_location" VALUES(13147,NULL,'Allentown, PA',5548,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13148,NULL,'Allentown, PA 18101',5548,222,NULL,44,7307,0);
INSERT INTO "django_geo_db_location" VALUES(13149,NULL,'Allentown, PA 18102',5548,222,NULL,44,7308,0);
INSERT INTO "django_geo_db_location" VALUES(13150,NULL,'Allentown, PA 18103',5548,222,NULL,44,7309,0);
INSERT INTO "django_geo_db_location" VALUES(13151,NULL,'Allentown, PA 18104',5548,222,NULL,44,7310,0);
INSERT INTO "django_geo_db_location" VALUES(13152,NULL,'Allentown, PA 18105',5548,222,NULL,44,7311,0);
INSERT INTO "django_geo_db_location" VALUES(13153,NULL,'Allentown, PA 18106',5548,222,NULL,44,7312,0);
INSERT INTO "django_geo_db_location" VALUES(13154,NULL,'Allentown, PA 18109',5548,222,NULL,44,7313,0);
INSERT INTO "django_geo_db_location" VALUES(13155,NULL,'Tunkhannock, PA',5549,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13156,NULL,'Tunkhannock, PA 18160',5549,222,NULL,44,7314,0);
INSERT INTO "django_geo_db_location" VALUES(13157,NULL,'Allentown, PA 18175',5548,222,NULL,44,7315,0);
INSERT INTO "django_geo_db_location" VALUES(13158,NULL,'Allentown, PA 18195',5548,222,NULL,44,7316,0);
INSERT INTO "django_geo_db_location" VALUES(13159,NULL,'Hazleton, PA 18201',5496,222,NULL,44,7317,0);
INSERT INTO "django_geo_db_location" VALUES(13160,NULL,'Hazleton, PA 18202',5496,222,NULL,44,7318,0);
INSERT INTO "django_geo_db_location" VALUES(13161,NULL,'Albrightsville, PA',5550,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13162,NULL,'Albrightsville, PA 18210',5550,222,NULL,44,7319,0);
INSERT INTO "django_geo_db_location" VALUES(13163,NULL,'Andreas, PA',5551,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13164,NULL,'Andreas, PA 18211',5551,222,NULL,44,7320,0);
INSERT INTO "django_geo_db_location" VALUES(13165,NULL,'Ashfield, PA',5552,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13166,NULL,'Ashfield, PA 18212',5552,222,NULL,44,7321,0);
INSERT INTO "django_geo_db_location" VALUES(13167,NULL,'Barnesville, PA',5553,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13168,NULL,'Barnesville, PA 18214',5553,222,NULL,44,7322,0);
INSERT INTO "django_geo_db_location" VALUES(13169,NULL,'Beaver Meadows, PA',5554,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13170,NULL,'Beaver Meadows, PA 18216',5554,222,NULL,44,7323,0);
INSERT INTO "django_geo_db_location" VALUES(13171,NULL,'Coaldale, PA',5555,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13172,NULL,'Coaldale, PA 18218',5555,222,NULL,44,7324,0);
INSERT INTO "django_geo_db_location" VALUES(13173,NULL,'Conyngham, PA',5556,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13174,NULL,'Conyngham, PA 18219',5556,222,NULL,44,7325,0);
INSERT INTO "django_geo_db_location" VALUES(13175,NULL,'Delano, PA',5557,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13176,NULL,'Delano, PA 18220',5557,222,NULL,44,7326,0);
INSERT INTO "django_geo_db_location" VALUES(13177,NULL,'Drifton, PA',5558,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13178,NULL,'Drifton, PA 18221',5558,222,NULL,44,7327,0);
INSERT INTO "django_geo_db_location" VALUES(13179,NULL,'Drums, PA',5559,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13180,NULL,'Drums, PA 18222',5559,222,NULL,44,7328,0);
INSERT INTO "django_geo_db_location" VALUES(13181,NULL,'Ebervale, PA',5560,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13182,NULL,'Ebervale, PA 18223',5560,222,NULL,44,7329,0);
INSERT INTO "django_geo_db_location" VALUES(13183,NULL,'Freeland, PA',5561,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13184,NULL,'Freeland, PA 18224',5561,222,NULL,44,7330,0);
INSERT INTO "django_geo_db_location" VALUES(13185,NULL,'Harleigh, PA',5562,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13186,NULL,'Harleigh, PA 18225',5562,222,NULL,44,7331,0);
INSERT INTO "django_geo_db_location" VALUES(13187,NULL,'Jim Thorpe, PA',5563,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13188,NULL,'Jim Thorpe, PA 18229',5563,222,NULL,44,7332,0);
INSERT INTO "django_geo_db_location" VALUES(13189,NULL,'Junedale, PA',5564,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13190,NULL,'Junedale, PA 18230',5564,222,NULL,44,7333,0);
INSERT INTO "django_geo_db_location" VALUES(13191,NULL,'Kelayres, PA',5565,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13192,NULL,'Kelayres, PA 18231',5565,222,NULL,44,7334,0);
INSERT INTO "django_geo_db_location" VALUES(13193,NULL,'Lansford, PA',5566,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13194,NULL,'Lansford, PA 18232',5566,222,NULL,44,7335,0);
INSERT INTO "django_geo_db_location" VALUES(13195,NULL,'Lattimer Mines, PA',5567,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13196,NULL,'Lattimer Mines, PA 18234',5567,222,NULL,44,7336,0);
INSERT INTO "django_geo_db_location" VALUES(13197,NULL,'Lehighton, PA',5568,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13198,NULL,'Lehighton, PA 18235',5568,222,NULL,44,7337,0);
INSERT INTO "django_geo_db_location" VALUES(13199,NULL,'Mcadoo, PA',5569,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13200,NULL,'Mcadoo, PA 18237',5569,222,NULL,44,7338,0);
INSERT INTO "django_geo_db_location" VALUES(13201,NULL,'Milnesville, PA',5570,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13202,NULL,'Milnesville, PA 18239',5570,222,NULL,44,7339,0);
INSERT INTO "django_geo_db_location" VALUES(13203,NULL,'Nesquehoning, PA',5571,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13204,NULL,'Nesquehoning, PA 18240',5571,222,NULL,44,7340,0);
INSERT INTO "django_geo_db_location" VALUES(13205,NULL,'Nuremberg, PA',5572,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13206,NULL,'Nuremberg, PA 18241',5572,222,NULL,44,7341,0);
INSERT INTO "django_geo_db_location" VALUES(13207,NULL,'Oneida, PA',5573,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13208,NULL,'Oneida, PA 18242',5573,222,NULL,44,7342,0);
INSERT INTO "django_geo_db_location" VALUES(13209,NULL,'Pardeesville, PA',5574,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13210,NULL,'Pardeesville, PA 18243',5574,222,NULL,44,7343,0);
INSERT INTO "django_geo_db_location" VALUES(13211,NULL,'Parryville, PA',5575,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13212,NULL,'Parryville, PA 18244',5575,222,NULL,44,7344,0);
INSERT INTO "django_geo_db_location" VALUES(13213,NULL,'Quakake, PA',5576,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13214,NULL,'Quakake, PA 18245',5576,222,NULL,44,7345,0);
INSERT INTO "django_geo_db_location" VALUES(13215,NULL,'Rock Glen, PA',5577,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13216,NULL,'Rock Glen, PA 18246',5577,222,NULL,44,7346,0);
INSERT INTO "django_geo_db_location" VALUES(13217,NULL,'Saint Johns, PA',5578,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13218,NULL,'Saint Johns, PA 18247',5578,222,NULL,44,7347,0);
INSERT INTO "django_geo_db_location" VALUES(13219,NULL,'Sheppton, PA',5579,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13220,NULL,'Sheppton, PA 18248',5579,222,NULL,44,7348,0);
INSERT INTO "django_geo_db_location" VALUES(13221,NULL,'Sugarloaf, PA',5580,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13222,NULL,'Sugarloaf, PA 18249',5580,222,NULL,44,7349,0);
INSERT INTO "django_geo_db_location" VALUES(13223,NULL,'Summit Hill, PA',5581,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13224,NULL,'Summit Hill, PA 18250',5581,222,NULL,44,7350,0);
INSERT INTO "django_geo_db_location" VALUES(13225,NULL,'Sybertsville, PA',5582,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13226,NULL,'Sybertsville, PA 18251',5582,222,NULL,44,7351,0);
INSERT INTO "django_geo_db_location" VALUES(13227,NULL,'Tamaqua, PA',5583,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13228,NULL,'Tamaqua, PA 18252',5583,222,NULL,44,7352,0);
INSERT INTO "django_geo_db_location" VALUES(13229,NULL,'Tresckow, PA',5584,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13230,NULL,'Tresckow, PA 18254',5584,222,NULL,44,7353,0);
INSERT INTO "django_geo_db_location" VALUES(13231,NULL,'Weatherly, PA',5585,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13232,NULL,'Weatherly, PA 18255',5585,222,NULL,44,7354,0);
INSERT INTO "django_geo_db_location" VALUES(13233,NULL,'Weston, PA',5586,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13234,NULL,'Weston, PA 18256',5586,222,NULL,44,7355,0);
INSERT INTO "django_geo_db_location" VALUES(13235,NULL,'East Stroudsburg, PA',5587,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13236,NULL,'East Stroudsburg, PA 18301',5587,222,NULL,44,7356,0);
INSERT INTO "django_geo_db_location" VALUES(13237,NULL,'Analomink, PA',5588,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13238,NULL,'Analomink, PA 18320',5588,222,NULL,44,7357,0);
INSERT INTO "django_geo_db_location" VALUES(13239,NULL,'Bartonsville, PA',5589,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13240,NULL,'Bartonsville, PA 18321',5589,222,NULL,44,7358,0);
INSERT INTO "django_geo_db_location" VALUES(13241,NULL,'Brodheadsville, PA',5590,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13242,NULL,'Brodheadsville, PA 18322',5590,222,NULL,44,7359,0);
INSERT INTO "django_geo_db_location" VALUES(13243,NULL,'Buck Hill Falls, PA',5591,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13244,NULL,'Buck Hill Falls, PA 18323',5591,222,NULL,44,7360,0);
INSERT INTO "django_geo_db_location" VALUES(13245,NULL,'Bushkill, PA',5592,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13246,NULL,'Bushkill, PA 18324',5592,222,NULL,44,7361,0);
INSERT INTO "django_geo_db_location" VALUES(13247,NULL,'Canadensis, PA',5593,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13248,NULL,'Canadensis, PA 18325',5593,222,NULL,44,7362,0);
INSERT INTO "django_geo_db_location" VALUES(13249,NULL,'Cresco, PA',5594,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13250,NULL,'Cresco, PA 18326',5594,222,NULL,44,7363,0);
INSERT INTO "django_geo_db_location" VALUES(13251,NULL,'Delaware Water Gap, PA',5595,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13252,NULL,'Delaware Water Gap, PA 18327',5595,222,NULL,44,7364,0);
INSERT INTO "django_geo_db_location" VALUES(13253,NULL,'Dingmans Ferry, PA',5596,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13254,NULL,'Dingmans Ferry, PA 18328',5596,222,NULL,44,7365,0);
INSERT INTO "django_geo_db_location" VALUES(13255,NULL,'Effort, PA',5597,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13256,NULL,'Effort, PA 18330',5597,222,NULL,44,7366,0);
INSERT INTO "django_geo_db_location" VALUES(13257,NULL,'Gilbert, PA',5598,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13258,NULL,'Gilbert, PA 18331',5598,222,NULL,44,7367,0);
INSERT INTO "django_geo_db_location" VALUES(13259,NULL,'Henryville, PA',5599,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13260,NULL,'Henryville, PA 18332',5599,222,NULL,44,7368,0);
INSERT INTO "django_geo_db_location" VALUES(13261,NULL,'Kresgeville, PA',5600,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13262,NULL,'Kresgeville, PA 18333',5600,222,NULL,44,7369,0);
INSERT INTO "django_geo_db_location" VALUES(13263,NULL,'Long Pond, PA',5601,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13264,NULL,'Long Pond, PA 18334',5601,222,NULL,44,7370,0);
INSERT INTO "django_geo_db_location" VALUES(13265,NULL,'Marshalls Creek, PA',5602,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13266,NULL,'Marshalls Creek, PA 18335',5602,222,NULL,44,7371,0);
INSERT INTO "django_geo_db_location" VALUES(13267,NULL,'Matamoras, PA',5603,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13268,NULL,'Matamoras, PA 18336',5603,222,NULL,44,7372,0);
INSERT INTO "django_geo_db_location" VALUES(13269,NULL,'Milford, PA',5604,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13270,NULL,'Milford, PA 18337',5604,222,NULL,44,7373,0);
INSERT INTO "django_geo_db_location" VALUES(13271,NULL,'Millrift, PA',5605,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13272,NULL,'Millrift, PA 18340',5605,222,NULL,44,7374,0);
INSERT INTO "django_geo_db_location" VALUES(13273,NULL,'Minisink Hills, PA',5606,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13274,NULL,'Minisink Hills, PA 18341',5606,222,NULL,44,7375,0);
INSERT INTO "django_geo_db_location" VALUES(13275,NULL,'Mountainhome, PA',5607,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13276,NULL,'Mountainhome, PA 18342',5607,222,NULL,44,7376,0);
INSERT INTO "django_geo_db_location" VALUES(13277,NULL,'Mount Bethel, PA',5608,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13278,NULL,'Mount Bethel, PA 18343',5608,222,NULL,44,7377,0);
INSERT INTO "django_geo_db_location" VALUES(13279,NULL,'Mount Pocono, PA',5609,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13280,NULL,'Mount Pocono, PA 18344',5609,222,NULL,44,7378,0);
INSERT INTO "django_geo_db_location" VALUES(13281,NULL,'Pocono Summit, PA',5610,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13282,NULL,'Pocono Summit, PA 18346',5610,222,NULL,44,7379,0);
INSERT INTO "django_geo_db_location" VALUES(13283,NULL,'Pocono Lake, PA',5611,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13284,NULL,'Pocono Lake, PA 18347',5611,222,NULL,44,7380,0);
INSERT INTO "django_geo_db_location" VALUES(13285,NULL,'Pocono Lake Preserve, PA',5612,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13286,NULL,'Pocono Lake Preserve, PA 18348',5612,222,NULL,44,7381,0);
INSERT INTO "django_geo_db_location" VALUES(13287,NULL,'Pocono Manor, PA',5613,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13288,NULL,'Pocono Manor, PA 18349',5613,222,NULL,44,7382,0);
INSERT INTO "django_geo_db_location" VALUES(13289,NULL,'Pocono Pines, PA',5614,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13290,NULL,'Pocono Pines, PA 18350',5614,222,NULL,44,7383,0);
INSERT INTO "django_geo_db_location" VALUES(13291,NULL,'Portland, PA',5615,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13292,NULL,'Portland, PA 18351',5615,222,NULL,44,7384,0);
INSERT INTO "django_geo_db_location" VALUES(13293,NULL,'Reeders, PA',5616,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13294,NULL,'Reeders, PA 18352',5616,222,NULL,44,7385,0);
INSERT INTO "django_geo_db_location" VALUES(13295,NULL,'Saylorsburg, PA',5617,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13296,NULL,'Saylorsburg, PA 18353',5617,222,NULL,44,7386,0);
INSERT INTO "django_geo_db_location" VALUES(13297,NULL,'Sciota, PA',5618,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13298,NULL,'Sciota, PA 18354',5618,222,NULL,44,7387,0);
INSERT INTO "django_geo_db_location" VALUES(13299,NULL,'Scotrun, PA',5619,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13300,NULL,'Scotrun, PA 18355',5619,222,NULL,44,7388,0);
INSERT INTO "django_geo_db_location" VALUES(13301,NULL,'Shawnee On Delaware, PA',5620,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13302,NULL,'Shawnee On Delaware, PA 18356',5620,222,NULL,44,7389,0);
INSERT INTO "django_geo_db_location" VALUES(13303,NULL,'Skytop, PA',5621,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13304,NULL,'Skytop, PA 18357',5621,222,NULL,44,7390,0);
INSERT INTO "django_geo_db_location" VALUES(13305,NULL,'Stroudsburg, PA',5622,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13306,NULL,'Stroudsburg, PA 18360',5622,222,NULL,44,7391,0);
INSERT INTO "django_geo_db_location" VALUES(13307,NULL,'Swiftwater, PA',5623,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13308,NULL,'Swiftwater, PA 18370',5623,222,NULL,44,7392,0);
INSERT INTO "django_geo_db_location" VALUES(13309,NULL,'Tamiment, PA',5624,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13310,NULL,'Tamiment, PA 18371',5624,222,NULL,44,7393,0);
INSERT INTO "django_geo_db_location" VALUES(13311,NULL,'Tannersville, PA',5625,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13312,NULL,'Tannersville, PA 18372',5625,222,NULL,44,7394,0);
INSERT INTO "django_geo_db_location" VALUES(13313,NULL,'Unity House, PA',5626,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13314,NULL,'Unity House, PA 18373',5626,222,NULL,44,7395,0);
INSERT INTO "django_geo_db_location" VALUES(13315,NULL,'Dingman, PA',5627,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13316,NULL,'Dingman, PA 18377',5627,222,NULL,44,7396,0);
INSERT INTO "django_geo_db_location" VALUES(13317,NULL,'Aldenville, PA',5628,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13318,NULL,'Aldenville, PA 18401',5628,222,NULL,44,7397,0);
INSERT INTO "django_geo_db_location" VALUES(13319,NULL,'Archbald, PA',5629,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13320,NULL,'Archbald, PA 18403',5629,222,NULL,44,7398,0);
INSERT INTO "django_geo_db_location" VALUES(13321,NULL,'Beach Lake, PA',5630,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13322,NULL,'Beach Lake, PA 18405',5630,222,NULL,44,7399,0);
INSERT INTO "django_geo_db_location" VALUES(13323,NULL,'Carbondale, PA',5631,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13324,NULL,'Carbondale, PA 18407',5631,222,NULL,44,7400,0);
INSERT INTO "django_geo_db_location" VALUES(13325,NULL,'Chinchilla, PA',5632,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13326,NULL,'Chinchilla, PA 18410',5632,222,NULL,44,7401,0);
INSERT INTO "django_geo_db_location" VALUES(13327,NULL,'Clarks Summit, PA',5633,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13328,NULL,'Clarks Summit, PA 18411',5633,222,NULL,44,7402,0);
INSERT INTO "django_geo_db_location" VALUES(13329,NULL,'Clifford, PA',5634,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13330,NULL,'Clifford, PA 18413',5634,222,NULL,44,7403,0);
INSERT INTO "django_geo_db_location" VALUES(13331,NULL,'Dalton, PA',5635,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13332,NULL,'Dalton, PA 18414',5635,222,NULL,44,7404,0);
INSERT INTO "django_geo_db_location" VALUES(13333,NULL,'Damascus, PA',5636,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13334,NULL,'Damascus, PA 18415',5636,222,NULL,44,7405,0);
INSERT INTO "django_geo_db_location" VALUES(13335,NULL,'Elmhurst, PA',5637,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13336,NULL,'Elmhurst, PA 18416',5637,222,NULL,44,7406,0);
INSERT INTO "django_geo_db_location" VALUES(13337,NULL,'Equinunk, PA',5638,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13338,NULL,'Equinunk, PA 18417',5638,222,NULL,44,7407,0);
INSERT INTO "django_geo_db_location" VALUES(13339,NULL,'Factoryville, PA',5639,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13340,NULL,'Factoryville, PA 18419',5639,222,NULL,44,7408,0);
INSERT INTO "django_geo_db_location" VALUES(13341,NULL,'Fleetville, PA',5640,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13342,NULL,'Fleetville, PA 18420',5640,222,NULL,44,7409,0);
INSERT INTO "django_geo_db_location" VALUES(13343,NULL,'Forest City, PA',5641,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13344,NULL,'Forest City, PA 18421',5641,222,NULL,44,7410,0);
INSERT INTO "django_geo_db_location" VALUES(13345,NULL,'Gouldsboro, PA',5642,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13346,NULL,'Gouldsboro, PA 18424',5642,222,NULL,44,7411,0);
INSERT INTO "django_geo_db_location" VALUES(13347,NULL,'Greeley, PA',5643,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13348,NULL,'Greeley, PA 18425',5643,222,NULL,44,7412,0);
INSERT INTO "django_geo_db_location" VALUES(13349,NULL,'Greentown, PA',5644,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13350,NULL,'Greentown, PA 18426',5644,222,NULL,44,7413,0);
INSERT INTO "django_geo_db_location" VALUES(13351,NULL,'Hamlin, PA',5645,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13352,NULL,'Hamlin, PA 18427',5645,222,NULL,44,7414,0);
INSERT INTO "django_geo_db_location" VALUES(13353,NULL,'Hawley, PA',5646,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13354,NULL,'Hawley, PA 18428',5646,222,NULL,44,7415,0);
INSERT INTO "django_geo_db_location" VALUES(13355,NULL,'Herrick Center, PA',5647,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13356,NULL,'Herrick Center, PA 18430',5647,222,NULL,44,7416,0);
INSERT INTO "django_geo_db_location" VALUES(13357,NULL,'Honesdale, PA',5648,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13358,NULL,'Honesdale, PA 18431',5648,222,NULL,44,7417,0);
INSERT INTO "django_geo_db_location" VALUES(13359,NULL,'Jermyn, PA',5649,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13360,NULL,'Jermyn, PA 18433',5649,222,NULL,44,7418,0);
INSERT INTO "django_geo_db_location" VALUES(13361,NULL,'Jessup, PA',5650,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13362,NULL,'Jessup, PA 18434',5650,222,NULL,44,7419,0);
INSERT INTO "django_geo_db_location" VALUES(13363,NULL,'Lackawaxen, PA',5651,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13364,NULL,'Lackawaxen, PA 18435',5651,222,NULL,44,7420,0);
INSERT INTO "django_geo_db_location" VALUES(13365,NULL,'Lake Ariel, PA',5652,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13366,NULL,'Lake Ariel, PA 18436',5652,222,NULL,44,7421,0);
INSERT INTO "django_geo_db_location" VALUES(13367,NULL,'Lake Como, PA',5653,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13368,NULL,'Lake Como, PA 18437',5653,222,NULL,44,7422,0);
INSERT INTO "django_geo_db_location" VALUES(13369,NULL,'Lakeville, PA',5654,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13370,NULL,'Lakeville, PA 18438',5654,222,NULL,44,7423,0);
INSERT INTO "django_geo_db_location" VALUES(13371,NULL,'Lakewood, PA',5655,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13372,NULL,'Lakewood, PA 18439',5655,222,NULL,44,7424,0);
INSERT INTO "django_geo_db_location" VALUES(13373,NULL,'La Plume, PA',5656,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13374,NULL,'La Plume, PA 18440',5656,222,NULL,44,7425,0);
INSERT INTO "django_geo_db_location" VALUES(13375,NULL,'Lenoxville, PA',5657,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13376,NULL,'Lenoxville, PA 18441',5657,222,NULL,44,7426,0);
INSERT INTO "django_geo_db_location" VALUES(13377,NULL,'Milanville, PA',5658,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13378,NULL,'Milanville, PA 18443',5658,222,NULL,44,7427,0);
INSERT INTO "django_geo_db_location" VALUES(13379,NULL,'Moscow, PA',5659,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13380,NULL,'Moscow, PA 18444',5659,222,NULL,44,7428,0);
INSERT INTO "django_geo_db_location" VALUES(13381,NULL,'Newfoundland, PA',5660,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13382,NULL,'Newfoundland, PA 18445',5660,222,NULL,44,7429,0);
INSERT INTO "django_geo_db_location" VALUES(13383,NULL,'Nicholson, PA',5661,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13384,NULL,'Nicholson, PA 18446',5661,222,NULL,44,7430,0);
INSERT INTO "django_geo_db_location" VALUES(13385,NULL,'Olyphant, PA',5662,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13386,NULL,'Olyphant, PA 18447',5662,222,NULL,44,7431,0);
INSERT INTO "django_geo_db_location" VALUES(13387,NULL,'Olyphant, PA 18448',5662,222,NULL,44,7432,0);
INSERT INTO "django_geo_db_location" VALUES(13388,NULL,'Orson, PA',5663,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13389,NULL,'Orson, PA 18449',5663,222,NULL,44,7433,0);
INSERT INTO "django_geo_db_location" VALUES(13390,NULL,'Paupack, PA',5664,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13391,NULL,'Paupack, PA 18451',5664,222,NULL,44,7434,0);
INSERT INTO "django_geo_db_location" VALUES(13392,NULL,'Peckville, PA',5665,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13393,NULL,'Peckville, PA 18452',5665,222,NULL,44,7435,0);
INSERT INTO "django_geo_db_location" VALUES(13394,NULL,'Pleasant Mount, PA',5666,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13395,NULL,'Pleasant Mount, PA 18453',5666,222,NULL,44,7436,0);
INSERT INTO "django_geo_db_location" VALUES(13396,NULL,'Poyntelle, PA',5667,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13397,NULL,'Poyntelle, PA 18454',5667,222,NULL,44,7437,0);
INSERT INTO "django_geo_db_location" VALUES(13398,NULL,'Preston Park, PA',5668,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13399,NULL,'Preston Park, PA 18455',5668,222,NULL,44,7438,0);
INSERT INTO "django_geo_db_location" VALUES(13400,NULL,'Prompton, PA',5669,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13401,NULL,'Prompton, PA 18456',5669,222,NULL,44,7439,0);
INSERT INTO "django_geo_db_location" VALUES(13402,NULL,'Rowland, PA',5670,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13403,NULL,'Rowland, PA 18457',5670,222,NULL,44,7440,0);
INSERT INTO "django_geo_db_location" VALUES(13404,NULL,'Shohola, PA',5671,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13405,NULL,'Shohola, PA 18458',5671,222,NULL,44,7441,0);
INSERT INTO "django_geo_db_location" VALUES(13406,NULL,'South Canaan, PA',5672,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13407,NULL,'South Canaan, PA 18459',5672,222,NULL,44,7442,0);
INSERT INTO "django_geo_db_location" VALUES(13408,NULL,'South Sterling, PA',5673,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13409,NULL,'South Sterling, PA 18460',5673,222,NULL,44,7443,0);
INSERT INTO "django_geo_db_location" VALUES(13410,NULL,'Starlight, PA',5674,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13411,NULL,'Starlight, PA 18461',5674,222,NULL,44,7444,0);
INSERT INTO "django_geo_db_location" VALUES(13412,NULL,'Starrucca, PA',5675,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13413,NULL,'Starrucca, PA 18462',5675,222,NULL,44,7445,0);
INSERT INTO "django_geo_db_location" VALUES(13414,NULL,'Sterling, PA',5676,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13415,NULL,'Sterling, PA 18463',5676,222,NULL,44,7446,0);
INSERT INTO "django_geo_db_location" VALUES(13416,NULL,'Tafton, PA',5677,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13417,NULL,'Tafton, PA 18464',5677,222,NULL,44,7447,0);
INSERT INTO "django_geo_db_location" VALUES(13418,NULL,'Thompson, PA',5678,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13419,NULL,'Thompson, PA 18465',5678,222,NULL,44,7448,0);
INSERT INTO "django_geo_db_location" VALUES(13420,NULL,'Tobyhanna, PA',5679,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13421,NULL,'Tobyhanna, PA 18466',5679,222,NULL,44,7449,0);
INSERT INTO "django_geo_db_location" VALUES(13422,NULL,'Tyler Hill, PA',5680,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13423,NULL,'Tyler Hill, PA 18469',5680,222,NULL,44,7450,0);
INSERT INTO "django_geo_db_location" VALUES(13424,NULL,'Union Dale, PA',5681,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13425,NULL,'Union Dale, PA 18470',5681,222,NULL,44,7451,0);
INSERT INTO "django_geo_db_location" VALUES(13426,NULL,'Waverly, PA',5682,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13427,NULL,'Waverly, PA 18471',5682,222,NULL,44,7452,0);
INSERT INTO "django_geo_db_location" VALUES(13428,NULL,'Waymart, PA',5683,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13429,NULL,'Waymart, PA 18472',5683,222,NULL,44,7453,0);
INSERT INTO "django_geo_db_location" VALUES(13430,NULL,'White Mills, PA',5684,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13431,NULL,'White Mills, PA 18473',5684,222,NULL,44,7454,0);
INSERT INTO "django_geo_db_location" VALUES(13432,NULL,'Scranton, PA',5685,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13433,NULL,'Scranton, PA 18501',5685,222,NULL,44,7455,0);
INSERT INTO "django_geo_db_location" VALUES(13434,NULL,'Scranton, PA 18502',5685,222,NULL,44,7456,0);
INSERT INTO "django_geo_db_location" VALUES(13435,NULL,'Scranton, PA 18503',5685,222,NULL,44,7457,0);
INSERT INTO "django_geo_db_location" VALUES(13436,NULL,'Scranton, PA 18504',5685,222,NULL,44,7458,0);
INSERT INTO "django_geo_db_location" VALUES(13437,NULL,'Scranton, PA 18505',5685,222,NULL,44,7459,0);
INSERT INTO "django_geo_db_location" VALUES(13438,NULL,'Moosic, PA',5686,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13439,NULL,'Moosic, PA 18507',5686,222,NULL,44,7460,0);
INSERT INTO "django_geo_db_location" VALUES(13440,NULL,'Scranton, PA 18508',5685,222,NULL,44,7461,0);
INSERT INTO "django_geo_db_location" VALUES(13441,NULL,'Scranton, PA 18509',5685,222,NULL,44,7462,0);
INSERT INTO "django_geo_db_location" VALUES(13442,NULL,'Scranton, PA 18510',5685,222,NULL,44,7463,0);
INSERT INTO "django_geo_db_location" VALUES(13443,NULL,'Scranton, PA 18512',5685,222,NULL,44,7464,0);
INSERT INTO "django_geo_db_location" VALUES(13444,NULL,'Scranton, PA 18514',5685,222,NULL,44,7465,0);
INSERT INTO "django_geo_db_location" VALUES(13445,NULL,'Scranton, PA 18515',5685,222,NULL,44,7466,0);
INSERT INTO "django_geo_db_location" VALUES(13446,NULL,'Taylor, PA',5687,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13447,NULL,'Taylor, PA 18517',5687,222,NULL,44,7467,0);
INSERT INTO "django_geo_db_location" VALUES(13448,NULL,'Old Forge, PA',5688,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13449,NULL,'Old Forge, PA 18518',5688,222,NULL,44,7468,0);
INSERT INTO "django_geo_db_location" VALUES(13450,NULL,'Dickson City, PA',5689,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13451,NULL,'Dickson City, PA 18519',5689,222,NULL,44,7469,0);
INSERT INTO "django_geo_db_location" VALUES(13452,NULL,'Scranton, PA 18522',5685,222,NULL,44,7470,0);
INSERT INTO "django_geo_db_location" VALUES(13453,NULL,'Scranton, PA 18540',5685,222,NULL,44,7471,0);
INSERT INTO "django_geo_db_location" VALUES(13454,NULL,'Scranton, PA 18577',5685,222,NULL,44,7472,0);
INSERT INTO "django_geo_db_location" VALUES(13455,NULL,'Beach Haven, PA',5690,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13456,NULL,'Beach Haven, PA 18601',5690,222,NULL,44,7473,0);
INSERT INTO "django_geo_db_location" VALUES(13457,NULL,'Bear Creek, PA',5691,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13458,NULL,'Bear Creek, PA 18602',5691,222,NULL,44,7474,0);
INSERT INTO "django_geo_db_location" VALUES(13459,NULL,'Berwick, PA',5692,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13460,NULL,'Berwick, PA 18603',5692,222,NULL,44,7475,0);
INSERT INTO "django_geo_db_location" VALUES(13461,NULL,'Blakeslee, PA',5693,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13462,NULL,'Blakeslee, PA 18610',5693,222,NULL,44,7476,0);
INSERT INTO "django_geo_db_location" VALUES(13463,NULL,'Cambra, PA',5694,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13464,NULL,'Cambra, PA 18611',5694,222,NULL,44,7477,0);
INSERT INTO "django_geo_db_location" VALUES(13465,NULL,'Dallas, PA',5695,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13466,NULL,'Dallas, PA 18612',5695,222,NULL,44,7478,0);
INSERT INTO "django_geo_db_location" VALUES(13467,NULL,'Dushore, PA',5696,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13468,NULL,'Dushore, PA 18614',5696,222,NULL,44,7479,0);
INSERT INTO "django_geo_db_location" VALUES(13469,NULL,'Falls, PA',5697,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13470,NULL,'Falls, PA 18615',5697,222,NULL,44,7480,0);
INSERT INTO "django_geo_db_location" VALUES(13471,NULL,'Forksville, PA',5698,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13472,NULL,'Forksville, PA 18616',5698,222,NULL,44,7481,0);
INSERT INTO "django_geo_db_location" VALUES(13473,NULL,'Glen Lyon, PA',5699,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13474,NULL,'Glen Lyon, PA 18617',5699,222,NULL,44,7482,0);
INSERT INTO "django_geo_db_location" VALUES(13475,NULL,'Harveys Lake, PA',5700,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13476,NULL,'Harveys Lake, PA 18618',5700,222,NULL,44,7483,0);
INSERT INTO "django_geo_db_location" VALUES(13477,NULL,'Hillsgrove, PA',5701,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13478,NULL,'Hillsgrove, PA 18619',5701,222,NULL,44,7484,0);
INSERT INTO "django_geo_db_location" VALUES(13479,NULL,'Hunlock Creek, PA',5702,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13480,NULL,'Hunlock Creek, PA 18621',5702,222,NULL,44,7485,0);
INSERT INTO "django_geo_db_location" VALUES(13481,NULL,'Huntington Mills, PA',5703,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13482,NULL,'Huntington Mills, PA 18622',5703,222,NULL,44,7486,0);
INSERT INTO "django_geo_db_location" VALUES(13483,NULL,'Laceyville, PA',5704,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13484,NULL,'Laceyville, PA 18623',5704,222,NULL,44,7487,0);
INSERT INTO "django_geo_db_location" VALUES(13485,NULL,'Lake Harmony, PA',5705,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13486,NULL,'Lake Harmony, PA 18624',5705,222,NULL,44,7488,0);
INSERT INTO "django_geo_db_location" VALUES(13487,NULL,'Lake Winola, PA',5706,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13488,NULL,'Lake Winola, PA 18625',5706,222,NULL,44,7489,0);
INSERT INTO "django_geo_db_location" VALUES(13489,NULL,'Laporte, PA',5707,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13490,NULL,'Laporte, PA 18626',5707,222,NULL,44,7490,0);
INSERT INTO "django_geo_db_location" VALUES(13491,NULL,'Lehman, PA',5708,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13492,NULL,'Lehman, PA 18627',5708,222,NULL,44,7491,0);
INSERT INTO "django_geo_db_location" VALUES(13493,NULL,'Lopez, PA',5709,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13494,NULL,'Lopez, PA 18628',5709,222,NULL,44,7492,0);
INSERT INTO "django_geo_db_location" VALUES(13495,NULL,'Mehoopany, PA',5710,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13496,NULL,'Mehoopany, PA 18629',5710,222,NULL,44,7493,0);
INSERT INTO "django_geo_db_location" VALUES(13497,NULL,'Meshoppen, PA',5711,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13498,NULL,'Meshoppen, PA 18630',5711,222,NULL,44,7494,0);
INSERT INTO "django_geo_db_location" VALUES(13499,NULL,'Mifflinville, PA',5712,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13500,NULL,'Mifflinville, PA 18631',5712,222,NULL,44,7495,0);
INSERT INTO "django_geo_db_location" VALUES(13501,NULL,'Mildred, PA',5713,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13502,NULL,'Mildred, PA 18632',5713,222,NULL,44,7496,0);
INSERT INTO "django_geo_db_location" VALUES(13503,NULL,'Nanticoke, PA',5714,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13504,NULL,'Nanticoke, PA 18634',5714,222,NULL,44,7497,0);
INSERT INTO "django_geo_db_location" VALUES(13505,NULL,'Nescopeck, PA',5715,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13506,NULL,'Nescopeck, PA 18635',5715,222,NULL,44,7498,0);
INSERT INTO "django_geo_db_location" VALUES(13507,NULL,'Noxen, PA',5716,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13508,NULL,'Noxen, PA 18636',5716,222,NULL,44,7499,0);
INSERT INTO "django_geo_db_location" VALUES(13509,NULL,'Solebury, PA',5717,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13510,NULL,'Solebury, PA 18638',5717,222,NULL,44,7500,0);
INSERT INTO "django_geo_db_location" VALUES(13511,NULL,'Pittston, PA',5718,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13512,NULL,'Pittston, PA 18640',5718,222,NULL,44,7501,0);
INSERT INTO "django_geo_db_location" VALUES(13513,NULL,'Pittston, PA 18641',5718,222,NULL,44,7502,0);
INSERT INTO "django_geo_db_location" VALUES(13514,NULL,'Duryea, PA',5719,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13515,NULL,'Duryea, PA 18642',5719,222,NULL,44,7503,0);
INSERT INTO "django_geo_db_location" VALUES(13516,NULL,'Pittston, PA 18643',5718,222,NULL,44,7504,0);
INSERT INTO "django_geo_db_location" VALUES(13517,NULL,'Wyoming, PA',5720,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13518,NULL,'Wyoming, PA 18644',5720,222,NULL,44,7505,0);
INSERT INTO "django_geo_db_location" VALUES(13519,NULL,'Plymouth, PA',5721,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13520,NULL,'Plymouth, PA 18651',5721,222,NULL,44,7506,0);
INSERT INTO "django_geo_db_location" VALUES(13521,NULL,'Ransom, PA',5722,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13522,NULL,'Ransom, PA 18653',5722,222,NULL,44,7507,0);
INSERT INTO "django_geo_db_location" VALUES(13523,NULL,'Shawanese, PA',5723,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13524,NULL,'Shawanese, PA 18654',5723,222,NULL,44,7508,0);
INSERT INTO "django_geo_db_location" VALUES(13525,NULL,'Shickshinny, PA',5724,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13526,NULL,'Shickshinny, PA 18655',5724,222,NULL,44,7509,0);
INSERT INTO "django_geo_db_location" VALUES(13527,NULL,'Sweet Valley, PA',5725,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13528,NULL,'Sweet Valley, PA 18656',5725,222,NULL,44,7510,0);
INSERT INTO "django_geo_db_location" VALUES(13529,NULL,'Tunkhannock, PA 18657',5549,222,NULL,44,7511,0);
INSERT INTO "django_geo_db_location" VALUES(13530,NULL,'Wapwallopen, PA',5726,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13531,NULL,'Wapwallopen, PA 18660',5726,222,NULL,44,7512,0);
INSERT INTO "django_geo_db_location" VALUES(13532,NULL,'White Haven, PA',5727,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13533,NULL,'White Haven, PA 18661',5727,222,NULL,44,7513,0);
INSERT INTO "django_geo_db_location" VALUES(13534,NULL,'Bridgeton, PA',5728,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13535,NULL,'Bridgeton, PA 18672',5728,222,NULL,44,7514,0);
INSERT INTO "django_geo_db_location" VALUES(13536,NULL,'Dallas, PA 18690',5695,222,NULL,44,7515,0);
INSERT INTO "django_geo_db_location" VALUES(13537,NULL,'Wilkes Barre, PA',5729,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13538,NULL,'Wilkes Barre, PA 18701',5729,222,NULL,44,7516,0);
INSERT INTO "django_geo_db_location" VALUES(13539,NULL,'Wilkes Barre, PA 18702',5729,222,NULL,44,7517,0);
INSERT INTO "django_geo_db_location" VALUES(13540,NULL,'Wilkes Barre, PA 18703',5729,222,NULL,44,7518,0);
INSERT INTO "django_geo_db_location" VALUES(13541,NULL,'Kingston, PA',5730,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13542,NULL,'Kingston, PA 18704',5730,222,NULL,44,7519,0);
INSERT INTO "django_geo_db_location" VALUES(13543,NULL,'Wilkes Barre, PA 18705',5729,222,NULL,44,7520,0);
INSERT INTO "django_geo_db_location" VALUES(13544,NULL,'Wilkes Barre, PA 18706',5729,222,NULL,44,7521,0);
INSERT INTO "django_geo_db_location" VALUES(13545,NULL,'Mountain Top, PA',5731,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13546,NULL,'Mountain Top, PA 18707',5731,222,NULL,44,7522,0);
INSERT INTO "django_geo_db_location" VALUES(13547,NULL,'Shavertown, PA',5732,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13548,NULL,'Shavertown, PA 18708',5732,222,NULL,44,7523,0);
INSERT INTO "django_geo_db_location" VALUES(13549,NULL,'Luzerne, PA',5733,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13550,NULL,'Luzerne, PA 18709',5733,222,NULL,44,7524,0);
INSERT INTO "django_geo_db_location" VALUES(13551,NULL,'Wilkes Barre, PA 18710',5729,222,NULL,44,7525,0);
INSERT INTO "django_geo_db_location" VALUES(13552,NULL,'Wilkes Barre, PA 18711',5729,222,NULL,44,7526,0);
INSERT INTO "django_geo_db_location" VALUES(13553,NULL,'Almedia, PA',5734,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13554,NULL,'Almedia, PA 18715',5734,222,NULL,44,7527,0);
INSERT INTO "django_geo_db_location" VALUES(13555,NULL,'Wilkes Barre, PA 18761',5729,222,NULL,44,7528,0);
INSERT INTO "django_geo_db_location" VALUES(13556,NULL,'Wilkes Barre, PA 18762',5729,222,NULL,44,7529,0);
INSERT INTO "django_geo_db_location" VALUES(13557,NULL,'Wilkes Barre, PA 18763',5729,222,NULL,44,7530,0);
INSERT INTO "django_geo_db_location" VALUES(13558,NULL,'Wilkes Barre, PA 18764',5729,222,NULL,44,7531,0);
INSERT INTO "django_geo_db_location" VALUES(13559,NULL,'Wilkes Barre, PA 18765',5729,222,NULL,44,7532,0);
INSERT INTO "django_geo_db_location" VALUES(13560,NULL,'Wilkes Barre, PA 18766',5729,222,NULL,44,7533,0);
INSERT INTO "django_geo_db_location" VALUES(13561,NULL,'Wilkes Barre, PA 18767',5729,222,NULL,44,7534,0);
INSERT INTO "django_geo_db_location" VALUES(13562,NULL,'Wilkes Barre, PA 18768',5729,222,NULL,44,7535,0);
INSERT INTO "django_geo_db_location" VALUES(13563,NULL,'Wilkes Barre, PA 18769',5729,222,NULL,44,7536,0);
INSERT INTO "django_geo_db_location" VALUES(13564,NULL,'Wilkes Barre, PA 18773',5729,222,NULL,44,7537,0);
INSERT INTO "django_geo_db_location" VALUES(13565,NULL,'Wilkes Barre, PA 18774',5729,222,NULL,44,7538,0);
INSERT INTO "django_geo_db_location" VALUES(13566,NULL,'Montrose, PA',5735,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13567,NULL,'Montrose, PA 18801',5735,222,NULL,44,7539,0);
INSERT INTO "django_geo_db_location" VALUES(13568,NULL,'Athens, PA',5736,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13569,NULL,'Athens, PA 18810',5736,222,NULL,44,7540,0);
INSERT INTO "django_geo_db_location" VALUES(13570,NULL,'Brackney, PA',5737,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13571,NULL,'Brackney, PA 18812',5737,222,NULL,44,7541,0);
INSERT INTO "django_geo_db_location" VALUES(13572,NULL,'Brooklyn, PA',5738,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13573,NULL,'Brooklyn, PA 18813',5738,222,NULL,44,7542,0);
INSERT INTO "django_geo_db_location" VALUES(13574,NULL,'Burlington, PA',5739,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13575,NULL,'Burlington, PA 18814',5739,222,NULL,44,7543,0);
INSERT INTO "django_geo_db_location" VALUES(13576,NULL,'Camptown, PA',5740,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13577,NULL,'Camptown, PA 18815',5740,222,NULL,44,7544,0);
INSERT INTO "django_geo_db_location" VALUES(13578,NULL,'Dimock, PA',5741,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13579,NULL,'Dimock, PA 18816',5741,222,NULL,44,7545,0);
INSERT INTO "django_geo_db_location" VALUES(13580,NULL,'East Smithfield, PA',5742,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13581,NULL,'East Smithfield, PA 18817',5742,222,NULL,44,7546,0);
INSERT INTO "django_geo_db_location" VALUES(13582,NULL,'Friendsville, PA',5743,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13583,NULL,'Friendsville, PA 18818',5743,222,NULL,44,7547,0);
INSERT INTO "django_geo_db_location" VALUES(13584,NULL,'Gibson, PA',5744,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13585,NULL,'Gibson, PA 18820',5744,222,NULL,44,7548,0);
INSERT INTO "django_geo_db_location" VALUES(13586,NULL,'Great Bend, PA',5745,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13587,NULL,'Great Bend, PA 18821',5745,222,NULL,44,7549,0);
INSERT INTO "django_geo_db_location" VALUES(13588,NULL,'Hallstead, PA',5746,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13589,NULL,'Hallstead, PA 18822',5746,222,NULL,44,7550,0);
INSERT INTO "django_geo_db_location" VALUES(13590,NULL,'Harford, PA',5747,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13591,NULL,'Harford, PA 18823',5747,222,NULL,44,7551,0);
INSERT INTO "django_geo_db_location" VALUES(13592,NULL,'Hop Bottom, PA',5748,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13593,NULL,'Hop Bottom, PA 18824',5748,222,NULL,44,7552,0);
INSERT INTO "django_geo_db_location" VALUES(13594,NULL,'Jackson, PA',5749,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13595,NULL,'Jackson, PA 18825',5749,222,NULL,44,7553,0);
INSERT INTO "django_geo_db_location" VALUES(13596,NULL,'Kingsley, PA',5750,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13597,NULL,'Kingsley, PA 18826',5750,222,NULL,44,7554,0);
INSERT INTO "django_geo_db_location" VALUES(13598,NULL,'Lanesboro, PA',5751,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13599,NULL,'Lanesboro, PA 18827',5751,222,NULL,44,7555,0);
INSERT INTO "django_geo_db_location" VALUES(13600,NULL,'Lawton, PA',5752,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13601,NULL,'Lawton, PA 18828',5752,222,NULL,44,7556,0);
INSERT INTO "django_geo_db_location" VALUES(13602,NULL,'Le Raysville, PA',5753,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13603,NULL,'Le Raysville, PA 18829',5753,222,NULL,44,7557,0);
INSERT INTO "django_geo_db_location" VALUES(13604,NULL,'Little Meadows, PA',5754,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13605,NULL,'Little Meadows, PA 18830',5754,222,NULL,44,7558,0);
INSERT INTO "django_geo_db_location" VALUES(13606,NULL,'Milan, PA',5755,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13607,NULL,'Milan, PA 18831',5755,222,NULL,44,7559,0);
INSERT INTO "django_geo_db_location" VALUES(13608,NULL,'Monroeton, PA',5756,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13609,NULL,'Monroeton, PA 18832',5756,222,NULL,44,7560,0);
INSERT INTO "django_geo_db_location" VALUES(13610,NULL,'New Albany, PA',5757,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13611,NULL,'New Albany, PA 18833',5757,222,NULL,44,7561,0);
INSERT INTO "django_geo_db_location" VALUES(13612,NULL,'New Milford, PA',5758,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13613,NULL,'New Milford, PA 18834',5758,222,NULL,44,7562,0);
INSERT INTO "django_geo_db_location" VALUES(13614,NULL,'Rome, PA',5759,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13615,NULL,'Rome, PA 18837',5759,222,NULL,44,7563,0);
INSERT INTO "django_geo_db_location" VALUES(13616,NULL,'Rushville, PA',5760,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13617,NULL,'Rushville, PA 18839',5760,222,NULL,44,7564,0);
INSERT INTO "django_geo_db_location" VALUES(13618,NULL,'Sayre, PA',5761,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13619,NULL,'Sayre, PA 18840',5761,222,NULL,44,7565,0);
INSERT INTO "django_geo_db_location" VALUES(13620,NULL,'South Gibson, PA',5762,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13621,NULL,'South Gibson, PA 18842',5762,222,NULL,44,7566,0);
INSERT INTO "django_geo_db_location" VALUES(13622,NULL,'South Montrose, PA',5763,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13623,NULL,'South Montrose, PA 18843',5763,222,NULL,44,7567,0);
INSERT INTO "django_geo_db_location" VALUES(13624,NULL,'Springville, PA',5764,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13625,NULL,'Springville, PA 18844',5764,222,NULL,44,7568,0);
INSERT INTO "django_geo_db_location" VALUES(13626,NULL,'Stevensville, PA',5765,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13627,NULL,'Stevensville, PA 18845',5765,222,NULL,44,7569,0);
INSERT INTO "django_geo_db_location" VALUES(13628,NULL,'Sugar Run, PA',5766,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13629,NULL,'Sugar Run, PA 18846',5766,222,NULL,44,7570,0);
INSERT INTO "django_geo_db_location" VALUES(13630,NULL,'Susquehanna, PA',5767,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13631,NULL,'Susquehanna, PA 18847',5767,222,NULL,44,7571,0);
INSERT INTO "django_geo_db_location" VALUES(13632,NULL,'Towanda, PA',5768,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13633,NULL,'Towanda, PA 18848',5768,222,NULL,44,7572,0);
INSERT INTO "django_geo_db_location" VALUES(13634,NULL,'Ulster, PA',5769,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13635,NULL,'Ulster, PA 18850',5769,222,NULL,44,7573,0);
INSERT INTO "django_geo_db_location" VALUES(13636,NULL,'Warren Center, PA',5770,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13637,NULL,'Warren Center, PA 18851',5770,222,NULL,44,7574,0);
INSERT INTO "django_geo_db_location" VALUES(13638,NULL,'Wyalusing, PA',5771,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13639,NULL,'Wyalusing, PA 18853',5771,222,NULL,44,7575,0);
INSERT INTO "django_geo_db_location" VALUES(13640,NULL,'Wysox, PA',5772,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13641,NULL,'Wysox, PA 18854',5772,222,NULL,44,7576,0);
INSERT INTO "django_geo_db_location" VALUES(13642,NULL,'Doylestown, PA',5773,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13643,NULL,'Doylestown, PA 18901',5773,222,NULL,44,7577,0);
INSERT INTO "django_geo_db_location" VALUES(13644,NULL,'Doylestown, PA 18903',5773,222,NULL,44,7578,0);
INSERT INTO "django_geo_db_location" VALUES(13645,NULL,'Bedminster, PA',5774,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13646,NULL,'Bedminster, PA 18910',5774,222,NULL,44,7579,0);
INSERT INTO "django_geo_db_location" VALUES(13647,NULL,'Blooming Glen, PA',5775,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13648,NULL,'Blooming Glen, PA 18911',5775,222,NULL,44,7580,0);
INSERT INTO "django_geo_db_location" VALUES(13649,NULL,'Buckingham, PA',5776,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13650,NULL,'Buckingham, PA 18912',5776,222,NULL,44,7581,0);
INSERT INTO "django_geo_db_location" VALUES(13651,NULL,'Carversville, PA',5777,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13652,NULL,'Carversville, PA 18913',5777,222,NULL,44,7582,0);
INSERT INTO "django_geo_db_location" VALUES(13653,NULL,'Chalfont, PA',5778,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13654,NULL,'Chalfont, PA 18914',5778,222,NULL,44,7583,0);
INSERT INTO "django_geo_db_location" VALUES(13655,NULL,'Colmar, PA',5779,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13656,NULL,'Colmar, PA 18915',5779,222,NULL,44,7584,0);
INSERT INTO "django_geo_db_location" VALUES(13657,NULL,'Danboro, PA',5780,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13658,NULL,'Danboro, PA 18916',5780,222,NULL,44,7585,0);
INSERT INTO "django_geo_db_location" VALUES(13659,NULL,'Dublin, PA',5781,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13660,NULL,'Dublin, PA 18917',5781,222,NULL,44,7586,0);
INSERT INTO "django_geo_db_location" VALUES(13661,NULL,'Earlington, PA',5782,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13662,NULL,'Earlington, PA 18918',5782,222,NULL,44,7587,0);
INSERT INTO "django_geo_db_location" VALUES(13663,NULL,'Erwinna, PA',5783,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13664,NULL,'Erwinna, PA 18920',5783,222,NULL,44,7588,0);
INSERT INTO "django_geo_db_location" VALUES(13665,NULL,'Ferndale, PA',5784,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13666,NULL,'Ferndale, PA 18921',5784,222,NULL,44,7589,0);
INSERT INTO "django_geo_db_location" VALUES(13667,NULL,'Forest Grove, PA',5785,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13668,NULL,'Forest Grove, PA 18922',5785,222,NULL,44,7590,0);
INSERT INTO "django_geo_db_location" VALUES(13669,NULL,'Fountainville, PA',5786,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13670,NULL,'Fountainville, PA 18923',5786,222,NULL,44,7591,0);
INSERT INTO "django_geo_db_location" VALUES(13671,NULL,'Franconia, PA',5787,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13672,NULL,'Franconia, PA 18924',5787,222,NULL,44,7592,0);
INSERT INTO "django_geo_db_location" VALUES(13673,NULL,'Furlong, PA',5788,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13674,NULL,'Furlong, PA 18925',5788,222,NULL,44,7593,0);
INSERT INTO "django_geo_db_location" VALUES(13675,NULL,'Gardenville, PA',5789,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13676,NULL,'Gardenville, PA 18926',5789,222,NULL,44,7594,0);
INSERT INTO "django_geo_db_location" VALUES(13677,NULL,'Hilltown, PA',5790,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13678,NULL,'Hilltown, PA 18927',5790,222,NULL,44,7595,0);
INSERT INTO "django_geo_db_location" VALUES(13679,NULL,'Holicong, PA',5791,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13680,NULL,'Holicong, PA 18928',5791,222,NULL,44,7596,0);
INSERT INTO "django_geo_db_location" VALUES(13681,NULL,'Jamison, PA',5792,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13682,NULL,'Jamison, PA 18929',5792,222,NULL,44,7597,0);
INSERT INTO "django_geo_db_location" VALUES(13683,NULL,'Kintnersville, PA',5793,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13684,NULL,'Kintnersville, PA 18930',5793,222,NULL,44,7598,0);
INSERT INTO "django_geo_db_location" VALUES(13685,NULL,'Lahaska, PA',5794,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13686,NULL,'Lahaska, PA 18931',5794,222,NULL,44,7599,0);
INSERT INTO "django_geo_db_location" VALUES(13687,NULL,'Line Lexington, PA',5795,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13688,NULL,'Line Lexington, PA 18932',5795,222,NULL,44,7600,0);
INSERT INTO "django_geo_db_location" VALUES(13689,NULL,'Lumberville, PA',5796,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13690,NULL,'Lumberville, PA 18933',5796,222,NULL,44,7601,0);
INSERT INTO "django_geo_db_location" VALUES(13691,NULL,'Mechanicsville, PA',5797,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13692,NULL,'Mechanicsville, PA 18934',5797,222,NULL,44,7602,0);
INSERT INTO "django_geo_db_location" VALUES(13693,NULL,'Milford Square, PA',5798,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13694,NULL,'Milford Square, PA 18935',5798,222,NULL,44,7603,0);
INSERT INTO "django_geo_db_location" VALUES(13695,NULL,'Montgomeryville, PA',5799,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13696,NULL,'Montgomeryville, PA 18936',5799,222,NULL,44,7604,0);
INSERT INTO "django_geo_db_location" VALUES(13697,NULL,'New Hope, PA',5800,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13698,NULL,'New Hope, PA 18938',5800,222,NULL,44,7605,0);
INSERT INTO "django_geo_db_location" VALUES(13699,NULL,'Newtown, PA',5801,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13700,NULL,'Newtown, PA 18940',5801,222,NULL,44,7606,0);
INSERT INTO "django_geo_db_location" VALUES(13701,NULL,'Ottsville, PA',5802,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13702,NULL,'Ottsville, PA 18942',5802,222,NULL,44,7607,0);
INSERT INTO "django_geo_db_location" VALUES(13703,NULL,'Penns Park, PA',5803,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13704,NULL,'Penns Park, PA 18943',5803,222,NULL,44,7608,0);
INSERT INTO "django_geo_db_location" VALUES(13705,NULL,'Perkasie, PA',5804,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13706,NULL,'Perkasie, PA 18944',5804,222,NULL,44,7609,0);
INSERT INTO "django_geo_db_location" VALUES(13707,NULL,'Plumstead, PA',5805,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13708,NULL,'Plumstead, PA 18945',5805,222,NULL,44,7610,0);
INSERT INTO "django_geo_db_location" VALUES(13709,NULL,'Pineville, PA',5806,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13710,NULL,'Pineville, PA 18946',5806,222,NULL,44,7611,0);
INSERT INTO "django_geo_db_location" VALUES(13711,NULL,'Pipersville, PA',5807,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13712,NULL,'Pipersville, PA 18947',5807,222,NULL,44,7612,0);
INSERT INTO "django_geo_db_location" VALUES(13713,NULL,'Plumsteadville, PA',5808,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13714,NULL,'Plumsteadville, PA 18949',5808,222,NULL,44,7613,0);
INSERT INTO "django_geo_db_location" VALUES(13715,NULL,'Point Pleasant, PA',5809,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13716,NULL,'Point Pleasant, PA 18950',5809,222,NULL,44,7614,0);
INSERT INTO "django_geo_db_location" VALUES(13717,NULL,'Quakertown, PA',5810,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13718,NULL,'Quakertown, PA 18951',5810,222,NULL,44,7615,0);
INSERT INTO "django_geo_db_location" VALUES(13719,NULL,'Revere, PA',5811,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13720,NULL,'Revere, PA 18953',5811,222,NULL,44,7616,0);
INSERT INTO "django_geo_db_location" VALUES(13721,NULL,'Richboro, PA',5812,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13722,NULL,'Richboro, PA 18954',5812,222,NULL,44,7617,0);
INSERT INTO "django_geo_db_location" VALUES(13723,NULL,'Richlandtown, PA',5813,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13724,NULL,'Richlandtown, PA 18955',5813,222,NULL,44,7618,0);
INSERT INTO "django_geo_db_location" VALUES(13725,NULL,'Rushland, PA',5814,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13726,NULL,'Rushland, PA 18956',5814,222,NULL,44,7619,0);
INSERT INTO "django_geo_db_location" VALUES(13727,NULL,'Salford, PA',5815,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13728,NULL,'Salford, PA 18957',5815,222,NULL,44,7620,0);
INSERT INTO "django_geo_db_location" VALUES(13729,NULL,'Salfordville, PA',5816,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13730,NULL,'Salfordville, PA 18958',5816,222,NULL,44,7621,0);
INSERT INTO "django_geo_db_location" VALUES(13731,NULL,'Sellersville, PA',5817,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13732,NULL,'Sellersville, PA 18960',5817,222,NULL,44,7622,0);
INSERT INTO "django_geo_db_location" VALUES(13733,NULL,'Silverdale, PA',5818,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13734,NULL,'Silverdale, PA 18962',5818,222,NULL,44,7623,0);
INSERT INTO "django_geo_db_location" VALUES(13735,NULL,'Solebury, PA 18963',5717,222,NULL,44,7624,0);
INSERT INTO "django_geo_db_location" VALUES(13736,NULL,'Souderton, PA',5819,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13737,NULL,'Souderton, PA 18964',5819,222,NULL,44,7625,0);
INSERT INTO "django_geo_db_location" VALUES(13738,NULL,'Southampton, PA 18966',5214,222,NULL,44,7626,0);
INSERT INTO "django_geo_db_location" VALUES(13739,NULL,'Spinnerstown, PA',5820,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13740,NULL,'Spinnerstown, PA 18968',5820,222,NULL,44,7627,0);
INSERT INTO "django_geo_db_location" VALUES(13741,NULL,'Telford, PA',5821,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13742,NULL,'Telford, PA 18969',5821,222,NULL,44,7628,0);
INSERT INTO "django_geo_db_location" VALUES(13743,NULL,'Trumbauersville, PA',5822,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13744,NULL,'Trumbauersville, PA 18970',5822,222,NULL,44,7629,0);
INSERT INTO "django_geo_db_location" VALUES(13745,NULL,'Tylersport, PA',5823,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13746,NULL,'Tylersport, PA 18971',5823,222,NULL,44,7630,0);
INSERT INTO "django_geo_db_location" VALUES(13747,NULL,'Upper Black Eddy, PA',5824,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13748,NULL,'Upper Black Eddy, PA 18972',5824,222,NULL,44,7631,0);
INSERT INTO "django_geo_db_location" VALUES(13749,NULL,'Warminster, PA',5825,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13750,NULL,'Warminster, PA 18974',5825,222,NULL,44,7632,0);
INSERT INTO "django_geo_db_location" VALUES(13751,NULL,'Warrington, PA',5826,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13752,NULL,'Warrington, PA 18976',5826,222,NULL,44,7633,0);
INSERT INTO "django_geo_db_location" VALUES(13753,NULL,'Washington Crossing, PA',5827,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13754,NULL,'Washington Crossing, PA 18977',5827,222,NULL,44,7634,0);
INSERT INTO "django_geo_db_location" VALUES(13755,NULL,'Woxall, PA',5828,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13756,NULL,'Woxall, PA 18979',5828,222,NULL,44,7635,0);
INSERT INTO "django_geo_db_location" VALUES(13757,NULL,'Wycombe, PA',5829,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13758,NULL,'Wycombe, PA 18980',5829,222,NULL,44,7636,0);
INSERT INTO "django_geo_db_location" VALUES(13759,NULL,'Zionhill, PA',5830,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13760,NULL,'Zionhill, PA 18981',5830,222,NULL,44,7637,0);
INSERT INTO "django_geo_db_location" VALUES(13761,NULL,'Warminster, PA 18991',5825,222,NULL,44,7638,0);
INSERT INTO "django_geo_db_location" VALUES(13762,NULL,'Abington, PA',5831,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13763,NULL,'Abington, PA 19001',5831,222,NULL,44,7639,0);
INSERT INTO "django_geo_db_location" VALUES(13764,NULL,'Ambler, PA',5832,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13765,NULL,'Ambler, PA 19002',5832,222,NULL,44,7640,0);
INSERT INTO "django_geo_db_location" VALUES(13766,NULL,'Ardmore, PA',5833,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13767,NULL,'Ardmore, PA 19003',5833,222,NULL,44,7641,0);
INSERT INTO "django_geo_db_location" VALUES(13768,NULL,'Bala Cynwyd, PA',5834,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13769,NULL,'Bala Cynwyd, PA 19004',5834,222,NULL,44,7642,0);
INSERT INTO "django_geo_db_location" VALUES(13770,NULL,'Huntingdon Valley, PA',5835,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13771,NULL,'Huntingdon Valley, PA 19006',5835,222,NULL,44,7643,0);
INSERT INTO "django_geo_db_location" VALUES(13772,NULL,'Bristol, PA',5836,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13773,NULL,'Bristol, PA 19007',5836,222,NULL,44,7644,0);
INSERT INTO "django_geo_db_location" VALUES(13774,NULL,'Broomall, PA',5837,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13775,NULL,'Broomall, PA 19008',5837,222,NULL,44,7645,0);
INSERT INTO "django_geo_db_location" VALUES(13776,NULL,'Bryn Athyn, PA',5838,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13777,NULL,'Bryn Athyn, PA 19009',5838,222,NULL,44,7646,0);
INSERT INTO "django_geo_db_location" VALUES(13778,NULL,'Bryn Mawr, PA',5839,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13779,NULL,'Bryn Mawr, PA 19010',5839,222,NULL,44,7647,0);
INSERT INTO "django_geo_db_location" VALUES(13780,NULL,'Cheltenham, PA',5840,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13781,NULL,'Cheltenham, PA 19012',5840,222,NULL,44,7648,0);
INSERT INTO "django_geo_db_location" VALUES(13782,NULL,'Chester, PA',5841,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13783,NULL,'Chester, PA 19013',5841,222,NULL,44,7649,0);
INSERT INTO "django_geo_db_location" VALUES(13784,NULL,'Aston, PA',5842,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13785,NULL,'Aston, PA 19014',5842,222,NULL,44,7650,0);
INSERT INTO "django_geo_db_location" VALUES(13786,NULL,'Brookhaven, PA',5843,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13787,NULL,'Brookhaven, PA 19015',5843,222,NULL,44,7651,0);
INSERT INTO "django_geo_db_location" VALUES(13788,NULL,'Chester, PA 19016',5841,222,NULL,44,7652,0);
INSERT INTO "django_geo_db_location" VALUES(13789,NULL,'Chester Heights, PA',5844,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13790,NULL,'Chester Heights, PA 19017',5844,222,NULL,44,7653,0);
INSERT INTO "django_geo_db_location" VALUES(13791,NULL,'Primos, PA',5845,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13792,NULL,'Primos, PA 19018',5845,222,NULL,44,7654,0);
INSERT INTO "django_geo_db_location" VALUES(13793,NULL,'Philadelphia, PA',5846,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13794,NULL,'Philadelphia, PA 19019',5846,222,NULL,44,7655,0);
INSERT INTO "django_geo_db_location" VALUES(13795,NULL,'Bensalem, PA',5847,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13796,NULL,'Bensalem, PA 19020',5847,222,NULL,44,7656,0);
INSERT INTO "django_geo_db_location" VALUES(13797,NULL,'Croydon, PA',5848,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13798,NULL,'Croydon, PA 19021',5848,222,NULL,44,7657,0);
INSERT INTO "django_geo_db_location" VALUES(13799,NULL,'Crum Lynne, PA',5849,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13800,NULL,'Crum Lynne, PA 19022',5849,222,NULL,44,7658,0);
INSERT INTO "django_geo_db_location" VALUES(13801,NULL,'Darby, PA',5850,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13802,NULL,'Darby, PA 19023',5850,222,NULL,44,7659,0);
INSERT INTO "django_geo_db_location" VALUES(13803,NULL,'Dresher, PA',5851,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13804,NULL,'Dresher, PA 19025',5851,222,NULL,44,7660,0);
INSERT INTO "django_geo_db_location" VALUES(13805,NULL,'Drexel Hill, PA',5852,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13806,NULL,'Drexel Hill, PA 19026',5852,222,NULL,44,7661,0);
INSERT INTO "django_geo_db_location" VALUES(13807,NULL,'Elkins Park, PA',5853,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13808,NULL,'Elkins Park, PA 19027',5853,222,NULL,44,7662,0);
INSERT INTO "django_geo_db_location" VALUES(13809,NULL,'Edgemont, PA',5854,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13810,NULL,'Edgemont, PA 19028',5854,222,NULL,44,7663,0);
INSERT INTO "django_geo_db_location" VALUES(13811,NULL,'Essington, PA',5855,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13812,NULL,'Essington, PA 19029',5855,222,NULL,44,7664,0);
INSERT INTO "django_geo_db_location" VALUES(13813,NULL,'Fairless Hills, PA',5856,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13814,NULL,'Fairless Hills, PA 19030',5856,222,NULL,44,7665,0);
INSERT INTO "django_geo_db_location" VALUES(13815,NULL,'Flourtown, PA',5857,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13816,NULL,'Flourtown, PA 19031',5857,222,NULL,44,7666,0);
INSERT INTO "django_geo_db_location" VALUES(13817,NULL,'Folcroft, PA',5858,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13818,NULL,'Folcroft, PA 19032',5858,222,NULL,44,7667,0);
INSERT INTO "django_geo_db_location" VALUES(13819,NULL,'Folsom, PA',5859,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13820,NULL,'Folsom, PA 19033',5859,222,NULL,44,7668,0);
INSERT INTO "django_geo_db_location" VALUES(13821,NULL,'Fort Washington, PA',5860,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13822,NULL,'Fort Washington, PA 19034',5860,222,NULL,44,7669,0);
INSERT INTO "django_geo_db_location" VALUES(13823,NULL,'Gladwyne, PA',5861,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13824,NULL,'Gladwyne, PA 19035',5861,222,NULL,44,7670,0);
INSERT INTO "django_geo_db_location" VALUES(13825,NULL,'Glenolden, PA',5862,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13826,NULL,'Glenolden, PA 19036',5862,222,NULL,44,7671,0);
INSERT INTO "django_geo_db_location" VALUES(13827,NULL,'Glen Riddle Lima, PA',5863,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13828,NULL,'Glen Riddle Lima, PA 19037',5863,222,NULL,44,7672,0);
INSERT INTO "django_geo_db_location" VALUES(13829,NULL,'Glenside, PA',5864,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13830,NULL,'Glenside, PA 19038',5864,222,NULL,44,7673,0);
INSERT INTO "django_geo_db_location" VALUES(13831,NULL,'Gradyville, PA',5865,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13832,NULL,'Gradyville, PA 19039',5865,222,NULL,44,7674,0);
INSERT INTO "django_geo_db_location" VALUES(13833,NULL,'Hatboro, PA',5866,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13834,NULL,'Hatboro, PA 19040',5866,222,NULL,44,7675,0);
INSERT INTO "django_geo_db_location" VALUES(13835,NULL,'Haverford, PA',5867,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13836,NULL,'Haverford, PA 19041',5867,222,NULL,44,7676,0);
INSERT INTO "django_geo_db_location" VALUES(13837,NULL,'Holmes, PA',5868,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13838,NULL,'Holmes, PA 19043',5868,222,NULL,44,7677,0);
INSERT INTO "django_geo_db_location" VALUES(13839,NULL,'Horsham, PA',5869,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13840,NULL,'Horsham, PA 19044',5869,222,NULL,44,7678,0);
INSERT INTO "django_geo_db_location" VALUES(13841,NULL,'Jenkintown, PA',5870,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13842,NULL,'Jenkintown, PA 19046',5870,222,NULL,44,7679,0);
INSERT INTO "django_geo_db_location" VALUES(13843,NULL,'Langhorne, PA',5871,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13844,NULL,'Langhorne, PA 19047',5871,222,NULL,44,7680,0);
INSERT INTO "django_geo_db_location" VALUES(13845,NULL,'Langhorne, PA 19048',5871,222,NULL,44,7681,0);
INSERT INTO "django_geo_db_location" VALUES(13846,NULL,'Langhorne, PA 19049',5871,222,NULL,44,7682,0);
INSERT INTO "django_geo_db_location" VALUES(13847,NULL,'Lansdowne, PA',5872,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13848,NULL,'Lansdowne, PA 19050',5872,222,NULL,44,7683,0);
INSERT INTO "django_geo_db_location" VALUES(13849,NULL,'Lenni, PA',5873,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13850,NULL,'Lenni, PA 19052',5873,222,NULL,44,7684,0);
INSERT INTO "django_geo_db_location" VALUES(13851,NULL,'Feasterville Trevose, PA',5874,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13852,NULL,'Feasterville Trevose, PA 19053',5874,222,NULL,44,7685,0);
INSERT INTO "django_geo_db_location" VALUES(13853,NULL,'Levittown, PA',5875,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13854,NULL,'Levittown, PA 19054',5875,222,NULL,44,7686,0);
INSERT INTO "django_geo_db_location" VALUES(13855,NULL,'Levittown, PA 19055',5875,222,NULL,44,7687,0);
INSERT INTO "django_geo_db_location" VALUES(13856,NULL,'Levittown, PA 19056',5875,222,NULL,44,7688,0);
INSERT INTO "django_geo_db_location" VALUES(13857,NULL,'Levittown, PA 19057',5875,222,NULL,44,7689,0);
INSERT INTO "django_geo_db_location" VALUES(13858,NULL,'Levittown, PA 19058',5875,222,NULL,44,7690,0);
INSERT INTO "django_geo_db_location" VALUES(13859,NULL,'Levittown, PA 19059',5875,222,NULL,44,7691,0);
INSERT INTO "django_geo_db_location" VALUES(13860,NULL,'Marcus Hook, PA',5876,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13861,NULL,'Marcus Hook, PA 19061',5876,222,NULL,44,7692,0);
INSERT INTO "django_geo_db_location" VALUES(13862,NULL,'Media, PA',5877,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13863,NULL,'Media, PA 19063',5877,222,NULL,44,7693,0);
INSERT INTO "django_geo_db_location" VALUES(13864,NULL,'Springfield, PA',5878,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13865,NULL,'Springfield, PA 19064',5878,222,NULL,44,7694,0);
INSERT INTO "django_geo_db_location" VALUES(13866,NULL,'Media, PA 19065',5877,222,NULL,44,7695,0);
INSERT INTO "django_geo_db_location" VALUES(13867,NULL,'Merion Station, PA',5879,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13868,NULL,'Merion Station, PA 19066',5879,222,NULL,44,7696,0);
INSERT INTO "django_geo_db_location" VALUES(13869,NULL,'Morrisville, PA',5880,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13870,NULL,'Morrisville, PA 19067',5880,222,NULL,44,7697,0);
INSERT INTO "django_geo_db_location" VALUES(13871,NULL,'Morton, PA',5881,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13872,NULL,'Morton, PA 19070',5881,222,NULL,44,7698,0);
INSERT INTO "django_geo_db_location" VALUES(13873,NULL,'Narberth, PA',5882,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13874,NULL,'Narberth, PA 19072',5882,222,NULL,44,7699,0);
INSERT INTO "django_geo_db_location" VALUES(13875,NULL,'Newtown Square, PA',5883,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13876,NULL,'Newtown Square, PA 19073',5883,222,NULL,44,7700,0);
INSERT INTO "django_geo_db_location" VALUES(13877,NULL,'Norwood, PA',5884,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13878,NULL,'Norwood, PA 19074',5884,222,NULL,44,7701,0);
INSERT INTO "django_geo_db_location" VALUES(13879,NULL,'Oreland, PA',5885,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13880,NULL,'Oreland, PA 19075',5885,222,NULL,44,7702,0);
INSERT INTO "django_geo_db_location" VALUES(13881,NULL,'Prospect Park, PA',5886,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13882,NULL,'Prospect Park, PA 19076',5886,222,NULL,44,7703,0);
INSERT INTO "django_geo_db_location" VALUES(13883,NULL,'Ridley Park, PA',5887,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13884,NULL,'Ridley Park, PA 19078',5887,222,NULL,44,7704,0);
INSERT INTO "django_geo_db_location" VALUES(13885,NULL,'Sharon Hill, PA',5888,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13886,NULL,'Sharon Hill, PA 19079',5888,222,NULL,44,7705,0);
INSERT INTO "django_geo_db_location" VALUES(13887,NULL,'Wayne, PA',5889,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13888,NULL,'Wayne, PA 19080',5889,222,NULL,44,7706,0);
INSERT INTO "django_geo_db_location" VALUES(13889,NULL,'Swarthmore, PA',5890,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13890,NULL,'Swarthmore, PA 19081',5890,222,NULL,44,7707,0);
INSERT INTO "django_geo_db_location" VALUES(13891,NULL,'Upper Darby, PA',5891,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13892,NULL,'Upper Darby, PA 19082',5891,222,NULL,44,7708,0);
INSERT INTO "django_geo_db_location" VALUES(13893,NULL,'Havertown, PA',5892,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13894,NULL,'Havertown, PA 19083',5892,222,NULL,44,7709,0);
INSERT INTO "django_geo_db_location" VALUES(13895,NULL,'Villanova, PA',5893,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13896,NULL,'Villanova, PA 19085',5893,222,NULL,44,7710,0);
INSERT INTO "django_geo_db_location" VALUES(13897,NULL,'Wallingford, PA',5894,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13898,NULL,'Wallingford, PA 19086',5894,222,NULL,44,7711,0);
INSERT INTO "django_geo_db_location" VALUES(13899,NULL,'Wayne, PA 19087',5889,222,NULL,44,7712,0);
INSERT INTO "django_geo_db_location" VALUES(13900,NULL,'Wayne, PA 19088',5889,222,NULL,44,7713,0);
INSERT INTO "django_geo_db_location" VALUES(13901,NULL,'Wayne, PA 19089',5889,222,NULL,44,7714,0);
INSERT INTO "django_geo_db_location" VALUES(13902,NULL,'Willow Grove, PA',5895,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13903,NULL,'Willow Grove, PA 19090',5895,222,NULL,44,7715,0);
INSERT INTO "django_geo_db_location" VALUES(13904,NULL,'Media, PA 19091',5877,222,NULL,44,7716,0);
INSERT INTO "django_geo_db_location" VALUES(13905,NULL,'Philadelphia, PA 19092',5846,222,NULL,44,7717,0);
INSERT INTO "django_geo_db_location" VALUES(13906,NULL,'Philadelphia, PA 19093',5846,222,NULL,44,7718,0);
INSERT INTO "django_geo_db_location" VALUES(13907,NULL,'Woodlyn, PA',5896,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13908,NULL,'Woodlyn, PA 19094',5896,222,NULL,44,7719,0);
INSERT INTO "django_geo_db_location" VALUES(13909,NULL,'Wyncote, PA',5897,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13910,NULL,'Wyncote, PA 19095',5897,222,NULL,44,7720,0);
INSERT INTO "django_geo_db_location" VALUES(13911,NULL,'Wynnewood, PA',5898,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13912,NULL,'Wynnewood, PA 19096',5898,222,NULL,44,7721,0);
INSERT INTO "django_geo_db_location" VALUES(13913,NULL,'Holmes, PA 19098',5868,222,NULL,44,7722,0);
INSERT INTO "django_geo_db_location" VALUES(13914,NULL,'Philadelphia, PA 19099',5846,222,NULL,44,7723,0);
INSERT INTO "django_geo_db_location" VALUES(13915,NULL,'Philadelphia, PA 19101',5846,222,NULL,44,7724,0);
INSERT INTO "django_geo_db_location" VALUES(13916,NULL,'Philadelphia, PA 19102',5846,222,NULL,44,7725,0);
INSERT INTO "django_geo_db_location" VALUES(13917,NULL,'Philadelphia, PA 19103',5846,222,NULL,44,7726,0);
INSERT INTO "django_geo_db_location" VALUES(13918,NULL,'Philadelphia, PA 19104',5846,222,NULL,44,7727,0);
INSERT INTO "django_geo_db_location" VALUES(13919,NULL,'Philadelphia, PA 19105',5846,222,NULL,44,7728,0);
INSERT INTO "django_geo_db_location" VALUES(13920,NULL,'Philadelphia, PA 19106',5846,222,NULL,44,7729,0);
INSERT INTO "django_geo_db_location" VALUES(13921,NULL,'Philadelphia, PA 19107',5846,222,NULL,44,7730,0);
INSERT INTO "django_geo_db_location" VALUES(13922,NULL,'Philadelphia, PA 19108',5846,222,NULL,44,7731,0);
INSERT INTO "django_geo_db_location" VALUES(13923,NULL,'Philadelphia, PA 19109',5846,222,NULL,44,7732,0);
INSERT INTO "django_geo_db_location" VALUES(13924,NULL,'Philadelphia, PA 19110',5846,222,NULL,44,7733,0);
INSERT INTO "django_geo_db_location" VALUES(13925,NULL,'Philadelphia, PA 19111',5846,222,NULL,44,7734,0);
INSERT INTO "django_geo_db_location" VALUES(13926,NULL,'Philadelphia, PA 19112',5846,222,NULL,44,7735,0);
INSERT INTO "django_geo_db_location" VALUES(13927,NULL,'Philadelphia, PA 19113',5846,222,NULL,44,7736,0);
INSERT INTO "django_geo_db_location" VALUES(13928,NULL,'Philadelphia, PA 19114',5846,222,NULL,44,7737,0);
INSERT INTO "django_geo_db_location" VALUES(13929,NULL,'Philadelphia, PA 19115',5846,222,NULL,44,7738,0);
INSERT INTO "django_geo_db_location" VALUES(13930,NULL,'Philadelphia, PA 19116',5846,222,NULL,44,7739,0);
INSERT INTO "django_geo_db_location" VALUES(13931,NULL,'Philadelphia, PA 19118',5846,222,NULL,44,7740,0);
INSERT INTO "django_geo_db_location" VALUES(13932,NULL,'Philadelphia, PA 19119',5846,222,NULL,44,7741,0);
INSERT INTO "django_geo_db_location" VALUES(13933,NULL,'Philadelphia, PA 19120',5846,222,NULL,44,7742,0);
INSERT INTO "django_geo_db_location" VALUES(13934,NULL,'Philadelphia, PA 19121',5846,222,NULL,44,7743,0);
INSERT INTO "django_geo_db_location" VALUES(13935,NULL,'Philadelphia, PA 19122',5846,222,NULL,44,7744,0);
INSERT INTO "django_geo_db_location" VALUES(13936,NULL,'Philadelphia, PA 19123',5846,222,NULL,44,7745,0);
INSERT INTO "django_geo_db_location" VALUES(13937,NULL,'Philadelphia, PA 19124',5846,222,NULL,44,7746,0);
INSERT INTO "django_geo_db_location" VALUES(13938,NULL,'Philadelphia, PA 19125',5846,222,NULL,44,7747,0);
INSERT INTO "django_geo_db_location" VALUES(13939,NULL,'Philadelphia, PA 19126',5846,222,NULL,44,7748,0);
INSERT INTO "django_geo_db_location" VALUES(13940,NULL,'Philadelphia, PA 19127',5846,222,NULL,44,7749,0);
INSERT INTO "django_geo_db_location" VALUES(13941,NULL,'Philadelphia, PA 19128',5846,222,NULL,44,7750,0);
INSERT INTO "django_geo_db_location" VALUES(13942,NULL,'Philadelphia, PA 19129',5846,222,NULL,44,7751,0);
INSERT INTO "django_geo_db_location" VALUES(13943,NULL,'Philadelphia, PA 19130',5846,222,NULL,44,7752,0);
INSERT INTO "django_geo_db_location" VALUES(13944,NULL,'Philadelphia, PA 19131',5846,222,NULL,44,7753,0);
INSERT INTO "django_geo_db_location" VALUES(13945,NULL,'Philadelphia, PA 19132',5846,222,NULL,44,7754,0);
INSERT INTO "django_geo_db_location" VALUES(13946,NULL,'Philadelphia, PA 19133',5846,222,NULL,44,7755,0);
INSERT INTO "django_geo_db_location" VALUES(13947,NULL,'Philadelphia, PA 19134',5846,222,NULL,44,7756,0);
INSERT INTO "django_geo_db_location" VALUES(13948,NULL,'Philadelphia, PA 19135',5846,222,NULL,44,7757,0);
INSERT INTO "django_geo_db_location" VALUES(13949,NULL,'Philadelphia, PA 19136',5846,222,NULL,44,7758,0);
INSERT INTO "django_geo_db_location" VALUES(13950,NULL,'Philadelphia, PA 19137',5846,222,NULL,44,7759,0);
INSERT INTO "django_geo_db_location" VALUES(13951,NULL,'Philadelphia, PA 19138',5846,222,NULL,44,7760,0);
INSERT INTO "django_geo_db_location" VALUES(13952,NULL,'Philadelphia, PA 19139',5846,222,NULL,44,7761,0);
INSERT INTO "django_geo_db_location" VALUES(13953,NULL,'Philadelphia, PA 19140',5846,222,NULL,44,7762,0);
INSERT INTO "django_geo_db_location" VALUES(13954,NULL,'Philadelphia, PA 19141',5846,222,NULL,44,7763,0);
INSERT INTO "django_geo_db_location" VALUES(13955,NULL,'Philadelphia, PA 19142',5846,222,NULL,44,7764,0);
INSERT INTO "django_geo_db_location" VALUES(13956,NULL,'Philadelphia, PA 19143',5846,222,NULL,44,7765,0);
INSERT INTO "django_geo_db_location" VALUES(13957,NULL,'Philadelphia, PA 19144',5846,222,NULL,44,7766,0);
INSERT INTO "django_geo_db_location" VALUES(13958,NULL,'Philadelphia, PA 19145',5846,222,NULL,44,7767,0);
INSERT INTO "django_geo_db_location" VALUES(13959,NULL,'Philadelphia, PA 19146',5846,222,NULL,44,7768,0);
INSERT INTO "django_geo_db_location" VALUES(13960,NULL,'Philadelphia, PA 19147',5846,222,NULL,44,7769,0);
INSERT INTO "django_geo_db_location" VALUES(13961,NULL,'Philadelphia, PA 19148',5846,222,NULL,44,7770,0);
INSERT INTO "django_geo_db_location" VALUES(13962,NULL,'Philadelphia, PA 19149',5846,222,NULL,44,7771,0);
INSERT INTO "django_geo_db_location" VALUES(13963,NULL,'Philadelphia, PA 19150',5846,222,NULL,44,7772,0);
INSERT INTO "django_geo_db_location" VALUES(13964,NULL,'Philadelphia, PA 19151',5846,222,NULL,44,7773,0);
INSERT INTO "django_geo_db_location" VALUES(13965,NULL,'Philadelphia, PA 19152',5846,222,NULL,44,7774,0);
INSERT INTO "django_geo_db_location" VALUES(13966,NULL,'Philadelphia, PA 19153',5846,222,NULL,44,7775,0);
INSERT INTO "django_geo_db_location" VALUES(13967,NULL,'Philadelphia, PA 19154',5846,222,NULL,44,7776,0);
INSERT INTO "django_geo_db_location" VALUES(13968,NULL,'Philadelphia, PA 19155',5846,222,NULL,44,7777,0);
INSERT INTO "django_geo_db_location" VALUES(13969,NULL,'Centerport, PA',5899,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13970,NULL,'Centerport, PA 19156',5899,222,NULL,44,7778,0);
INSERT INTO "django_geo_db_location" VALUES(13971,NULL,'Philadelphia, PA 19160',5846,222,NULL,44,7779,0);
INSERT INTO "django_geo_db_location" VALUES(13972,NULL,'Philadelphia, PA 19161',5846,222,NULL,44,7780,0);
INSERT INTO "django_geo_db_location" VALUES(13973,NULL,'Philadelphia, PA 19162',5846,222,NULL,44,7781,0);
INSERT INTO "django_geo_db_location" VALUES(13974,NULL,'Philadelphia, PA 19170',5846,222,NULL,44,7782,0);
INSERT INTO "django_geo_db_location" VALUES(13975,NULL,'Philadelphia, PA 19171',5846,222,NULL,44,7783,0);
INSERT INTO "django_geo_db_location" VALUES(13976,NULL,'Philadelphia, PA 19172',5846,222,NULL,44,7784,0);
INSERT INTO "django_geo_db_location" VALUES(13977,NULL,'Philadelphia, PA 19173',5846,222,NULL,44,7785,0);
INSERT INTO "django_geo_db_location" VALUES(13978,NULL,'Philadelphia, PA 19175',5846,222,NULL,44,7786,0);
INSERT INTO "django_geo_db_location" VALUES(13979,NULL,'Philadelphia, PA 19177',5846,222,NULL,44,7787,0);
INSERT INTO "django_geo_db_location" VALUES(13980,NULL,'Philadelphia, PA 19178',5846,222,NULL,44,7788,0);
INSERT INTO "django_geo_db_location" VALUES(13981,NULL,'Philadelphia, PA 19179',5846,222,NULL,44,7789,0);
INSERT INTO "django_geo_db_location" VALUES(13982,NULL,'Philadelphia, PA 19181',5846,222,NULL,44,7790,0);
INSERT INTO "django_geo_db_location" VALUES(13983,NULL,'Philadelphia, PA 19182',5846,222,NULL,44,7791,0);
INSERT INTO "django_geo_db_location" VALUES(13984,NULL,'Philadelphia, PA 19183',5846,222,NULL,44,7792,0);
INSERT INTO "django_geo_db_location" VALUES(13985,NULL,'Philadelphia, PA 19184',5846,222,NULL,44,7793,0);
INSERT INTO "django_geo_db_location" VALUES(13986,NULL,'Philadelphia, PA 19185',5846,222,NULL,44,7794,0);
INSERT INTO "django_geo_db_location" VALUES(13987,NULL,'Philadelphia, PA 19187',5846,222,NULL,44,7795,0);
INSERT INTO "django_geo_db_location" VALUES(13988,NULL,'Philadelphia, PA 19188',5846,222,NULL,44,7796,0);
INSERT INTO "django_geo_db_location" VALUES(13989,NULL,'Philadelphia, PA 19191',5846,222,NULL,44,7797,0);
INSERT INTO "django_geo_db_location" VALUES(13990,NULL,'Philadelphia, PA 19192',5846,222,NULL,44,7798,0);
INSERT INTO "django_geo_db_location" VALUES(13991,NULL,'Philadelphia, PA 19193',5846,222,NULL,44,7799,0);
INSERT INTO "django_geo_db_location" VALUES(13992,NULL,'Philadelphia, PA 19194',5846,222,NULL,44,7800,0);
INSERT INTO "django_geo_db_location" VALUES(13993,NULL,'Philadelphia, PA 19196',5846,222,NULL,44,7801,0);
INSERT INTO "django_geo_db_location" VALUES(13994,NULL,'Philadelphia, PA 19197',5846,222,NULL,44,7802,0);
INSERT INTO "django_geo_db_location" VALUES(13995,NULL,'Philadelphia, PA 19244',5846,222,NULL,44,7803,0);
INSERT INTO "django_geo_db_location" VALUES(13996,NULL,'Philadelphia, PA 19255',5846,222,NULL,44,7804,0);
INSERT INTO "django_geo_db_location" VALUES(13997,NULL,'Paoli, PA',5900,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(13998,NULL,'Paoli, PA 19301',5900,222,NULL,44,7805,0);
INSERT INTO "django_geo_db_location" VALUES(13999,NULL,'Atglen, PA',5901,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14000,NULL,'Atglen, PA 19310',5901,222,NULL,44,7806,0);
INSERT INTO "django_geo_db_location" VALUES(14001,NULL,'Avondale, PA',5902,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14002,NULL,'Avondale, PA 19311',5902,222,NULL,44,7807,0);
INSERT INTO "django_geo_db_location" VALUES(14003,NULL,'Berwyn, PA',5903,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14004,NULL,'Berwyn, PA 19312',5903,222,NULL,44,7808,0);
INSERT INTO "django_geo_db_location" VALUES(14005,NULL,'Brandamore, PA',5904,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14006,NULL,'Brandamore, PA 19316',5904,222,NULL,44,7809,0);
INSERT INTO "django_geo_db_location" VALUES(14007,NULL,'Chadds Ford, PA',5905,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14008,NULL,'Chadds Ford, PA 19317',5905,222,NULL,44,7810,0);
INSERT INTO "django_geo_db_location" VALUES(14009,NULL,'Chatham, PA',5906,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14010,NULL,'Chatham, PA 19318',5906,222,NULL,44,7811,0);
INSERT INTO "django_geo_db_location" VALUES(14011,NULL,'Cheyney, PA',5907,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14012,NULL,'Cheyney, PA 19319',5907,222,NULL,44,7812,0);
INSERT INTO "django_geo_db_location" VALUES(14013,NULL,'Coatesville, PA',5908,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14014,NULL,'Coatesville, PA 19320',5908,222,NULL,44,7813,0);
INSERT INTO "django_geo_db_location" VALUES(14015,NULL,'Cochranville, PA',5909,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14016,NULL,'Cochranville, PA 19330',5909,222,NULL,44,7814,0);
INSERT INTO "django_geo_db_location" VALUES(14017,NULL,'Concordville, PA',5910,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14018,NULL,'Concordville, PA 19331',5910,222,NULL,44,7815,0);
INSERT INTO "django_geo_db_location" VALUES(14019,NULL,'Devon, PA',5911,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14020,NULL,'Devon, PA 19333',5911,222,NULL,44,7816,0);
INSERT INTO "django_geo_db_location" VALUES(14021,NULL,'Downingtown, PA',5912,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14022,NULL,'Downingtown, PA 19335',5912,222,NULL,44,7817,0);
INSERT INTO "django_geo_db_location" VALUES(14023,NULL,'Concordville, PA 19339',5910,222,NULL,44,7818,0);
INSERT INTO "django_geo_db_location" VALUES(14024,NULL,'Concordville, PA 19340',5910,222,NULL,44,7819,0);
INSERT INTO "django_geo_db_location" VALUES(14025,NULL,'Exton, PA',5913,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14026,NULL,'Exton, PA 19341',5913,222,NULL,44,7820,0);
INSERT INTO "django_geo_db_location" VALUES(14027,NULL,'Glen Mills, PA',5914,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14028,NULL,'Glen Mills, PA 19342',5914,222,NULL,44,7821,0);
INSERT INTO "django_geo_db_location" VALUES(14029,NULL,'Glenmoore, PA',5915,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14030,NULL,'Glenmoore, PA 19343',5915,222,NULL,44,7822,0);
INSERT INTO "django_geo_db_location" VALUES(14031,NULL,'Honey Brook, PA',5916,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14032,NULL,'Honey Brook, PA 19344',5916,222,NULL,44,7823,0);
INSERT INTO "django_geo_db_location" VALUES(14033,NULL,'Immaculata, PA',5917,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14034,NULL,'Immaculata, PA 19345',5917,222,NULL,44,7824,0);
INSERT INTO "django_geo_db_location" VALUES(14035,NULL,'Kelton, PA',5918,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14036,NULL,'Kelton, PA 19346',5918,222,NULL,44,7825,0);
INSERT INTO "django_geo_db_location" VALUES(14037,NULL,'Kemblesville, PA',5919,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14038,NULL,'Kemblesville, PA 19347',5919,222,NULL,44,7826,0);
INSERT INTO "django_geo_db_location" VALUES(14039,NULL,'Kennett Square, PA',5920,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14040,NULL,'Kennett Square, PA 19348',5920,222,NULL,44,7827,0);
INSERT INTO "django_geo_db_location" VALUES(14041,NULL,'Landenberg, PA',5921,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14042,NULL,'Landenberg, PA 19350',5921,222,NULL,44,7828,0);
INSERT INTO "django_geo_db_location" VALUES(14043,NULL,'Lewisville, PA',5922,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14044,NULL,'Lewisville, PA 19351',5922,222,NULL,44,7829,0);
INSERT INTO "django_geo_db_location" VALUES(14045,NULL,'Lincoln University, PA',5923,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14046,NULL,'Lincoln University, PA 19352',5923,222,NULL,44,7830,0);
INSERT INTO "django_geo_db_location" VALUES(14047,NULL,'Lionville, PA',5924,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14048,NULL,'Lionville, PA 19353',5924,222,NULL,44,7831,0);
INSERT INTO "django_geo_db_location" VALUES(14049,NULL,'Lyndell, PA',5925,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14050,NULL,'Lyndell, PA 19354',5925,222,NULL,44,7832,0);
INSERT INTO "django_geo_db_location" VALUES(14051,NULL,'Malvern, PA',5926,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14052,NULL,'Malvern, PA 19355',5926,222,NULL,44,7833,0);
INSERT INTO "django_geo_db_location" VALUES(14053,NULL,'Mendenhall, PA',5927,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14054,NULL,'Mendenhall, PA 19357',5927,222,NULL,44,7834,0);
INSERT INTO "django_geo_db_location" VALUES(14055,NULL,'Modena, PA',5928,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14056,NULL,'Modena, PA 19358',5928,222,NULL,44,7835,0);
INSERT INTO "django_geo_db_location" VALUES(14057,NULL,'New London, PA',5929,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14058,NULL,'New London, PA 19360',5929,222,NULL,44,7836,0);
INSERT INTO "django_geo_db_location" VALUES(14059,NULL,'Nottingham, PA',5930,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14060,NULL,'Nottingham, PA 19362',5930,222,NULL,44,7837,0);
INSERT INTO "django_geo_db_location" VALUES(14061,NULL,'Oxford, PA',5931,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14062,NULL,'Oxford, PA 19363',5931,222,NULL,44,7838,0);
INSERT INTO "django_geo_db_location" VALUES(14063,NULL,'Parkesburg, PA',5932,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14064,NULL,'Parkesburg, PA 19365',5932,222,NULL,44,7839,0);
INSERT INTO "django_geo_db_location" VALUES(14065,NULL,'Pocopson, PA',5933,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14066,NULL,'Pocopson, PA 19366',5933,222,NULL,44,7840,0);
INSERT INTO "django_geo_db_location" VALUES(14067,NULL,'Pomeroy, PA',5934,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14068,NULL,'Pomeroy, PA 19367',5934,222,NULL,44,7841,0);
INSERT INTO "django_geo_db_location" VALUES(14069,NULL,'Sadsburyville, PA',5935,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14070,NULL,'Sadsburyville, PA 19369',5935,222,NULL,44,7842,0);
INSERT INTO "django_geo_db_location" VALUES(14071,NULL,'Steelville, PA',5936,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14072,NULL,'Steelville, PA 19370',5936,222,NULL,44,7843,0);
INSERT INTO "django_geo_db_location" VALUES(14073,NULL,'Suplee, PA',5937,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14074,NULL,'Suplee, PA 19371',5937,222,NULL,44,7844,0);
INSERT INTO "django_geo_db_location" VALUES(14075,NULL,'Thorndale, PA',5938,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14076,NULL,'Thorndale, PA 19372',5938,222,NULL,44,7845,0);
INSERT INTO "django_geo_db_location" VALUES(14077,NULL,'Thornton, PA',5939,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14078,NULL,'Thornton, PA 19373',5939,222,NULL,44,7846,0);
INSERT INTO "django_geo_db_location" VALUES(14079,NULL,'Toughkenamon, PA',5940,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14080,NULL,'Toughkenamon, PA 19374',5940,222,NULL,44,7847,0);
INSERT INTO "django_geo_db_location" VALUES(14081,NULL,'Unionville, PA',5941,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14082,NULL,'Unionville, PA 19375',5941,222,NULL,44,7848,0);
INSERT INTO "django_geo_db_location" VALUES(14083,NULL,'Wagontown, PA',5942,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14084,NULL,'Wagontown, PA 19376',5942,222,NULL,44,7849,0);
INSERT INTO "django_geo_db_location" VALUES(14085,NULL,'West Chester, PA',5943,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14086,NULL,'West Chester, PA 19380',5943,222,NULL,44,7850,0);
INSERT INTO "django_geo_db_location" VALUES(14087,NULL,'West Chester, PA 19381',5943,222,NULL,44,7851,0);
INSERT INTO "django_geo_db_location" VALUES(14088,NULL,'West Chester, PA 19382',5943,222,NULL,44,7852,0);
INSERT INTO "django_geo_db_location" VALUES(14089,NULL,'West Chester, PA 19383',5943,222,NULL,44,7853,0);
INSERT INTO "django_geo_db_location" VALUES(14090,NULL,'West Grove, PA',5944,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14091,NULL,'West Grove, PA 19390',5944,222,NULL,44,7854,0);
INSERT INTO "django_geo_db_location" VALUES(14092,NULL,'Westtown, PA',5945,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14093,NULL,'Westtown, PA 19395',5945,222,NULL,44,7855,0);
INSERT INTO "django_geo_db_location" VALUES(14094,NULL,'Southeastern, PA',5946,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14095,NULL,'Southeastern, PA 19397',5946,222,NULL,44,7856,0);
INSERT INTO "django_geo_db_location" VALUES(14096,NULL,'Southeastern, PA 19398',5946,222,NULL,44,7857,0);
INSERT INTO "django_geo_db_location" VALUES(14097,NULL,'Southeastern, PA 19399',5946,222,NULL,44,7858,0);
INSERT INTO "django_geo_db_location" VALUES(14098,NULL,'Norristown, PA',5947,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14099,NULL,'Norristown, PA 19401',5947,222,NULL,44,7859,0);
INSERT INTO "django_geo_db_location" VALUES(14100,NULL,'Norristown, PA 19403',5947,222,NULL,44,7860,0);
INSERT INTO "django_geo_db_location" VALUES(14101,NULL,'Norristown, PA 19404',5947,222,NULL,44,7861,0);
INSERT INTO "django_geo_db_location" VALUES(14102,NULL,'Bridgeport, PA',5948,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14103,NULL,'Bridgeport, PA 19405',5948,222,NULL,44,7862,0);
INSERT INTO "django_geo_db_location" VALUES(14104,NULL,'King Of Prussia, PA',5949,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14105,NULL,'King Of Prussia, PA 19406',5949,222,NULL,44,7863,0);
INSERT INTO "django_geo_db_location" VALUES(14106,NULL,'Audubon, PA',5950,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14107,NULL,'Audubon, PA 19407',5950,222,NULL,44,7864,0);
INSERT INTO "django_geo_db_location" VALUES(14108,NULL,'Eagleville, PA',5951,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14109,NULL,'Eagleville, PA 19408',5951,222,NULL,44,7865,0);
INSERT INTO "django_geo_db_location" VALUES(14110,NULL,'Fairview Village, PA',5952,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14111,NULL,'Fairview Village, PA 19409',5952,222,NULL,44,7866,0);
INSERT INTO "django_geo_db_location" VALUES(14112,NULL,'Arcola, PA',5953,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14113,NULL,'Arcola, PA 19420',5953,222,NULL,44,7867,0);
INSERT INTO "django_geo_db_location" VALUES(14114,NULL,'Birchrunville, PA',5954,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14115,NULL,'Birchrunville, PA 19421',5954,222,NULL,44,7868,0);
INSERT INTO "django_geo_db_location" VALUES(14116,NULL,'Blue Bell, PA',5955,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14117,NULL,'Blue Bell, PA 19422',5955,222,NULL,44,7869,0);
INSERT INTO "django_geo_db_location" VALUES(14118,NULL,'Cedars, PA',5956,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14119,NULL,'Cedars, PA 19423',5956,222,NULL,44,7870,0);
INSERT INTO "django_geo_db_location" VALUES(14120,NULL,'Blue Bell, PA 19424',5955,222,NULL,44,7871,0);
INSERT INTO "django_geo_db_location" VALUES(14121,NULL,'Chester Springs, PA',5957,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14122,NULL,'Chester Springs, PA 19425',5957,222,NULL,44,7872,0);
INSERT INTO "django_geo_db_location" VALUES(14123,NULL,'Collegeville, PA',5958,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14124,NULL,'Collegeville, PA 19426',5958,222,NULL,44,7873,0);
INSERT INTO "django_geo_db_location" VALUES(14125,NULL,'Conshohocken, PA',5959,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14126,NULL,'Conshohocken, PA 19428',5959,222,NULL,44,7874,0);
INSERT INTO "django_geo_db_location" VALUES(14127,NULL,'Conshohocken, PA 19429',5959,222,NULL,44,7875,0);
INSERT INTO "django_geo_db_location" VALUES(14128,NULL,'Creamery, PA',5960,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14129,NULL,'Creamery, PA 19430',5960,222,NULL,44,7876,0);
INSERT INTO "django_geo_db_location" VALUES(14130,NULL,'Devault, PA',5961,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14131,NULL,'Devault, PA 19432',5961,222,NULL,44,7877,0);
INSERT INTO "django_geo_db_location" VALUES(14132,NULL,'Frederick, PA',5962,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14133,NULL,'Frederick, PA 19435',5962,222,NULL,44,7878,0);
INSERT INTO "django_geo_db_location" VALUES(14134,NULL,'Gwynedd, PA',5963,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14135,NULL,'Gwynedd, PA 19436',5963,222,NULL,44,7879,0);
INSERT INTO "django_geo_db_location" VALUES(14136,NULL,'Gwynedd Valley, PA',5964,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14137,NULL,'Gwynedd Valley, PA 19437',5964,222,NULL,44,7880,0);
INSERT INTO "django_geo_db_location" VALUES(14138,NULL,'Harleysville, PA',5965,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14139,NULL,'Harleysville, PA 19438',5965,222,NULL,44,7881,0);
INSERT INTO "django_geo_db_location" VALUES(14140,NULL,'Hatfield, PA',5966,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14141,NULL,'Hatfield, PA 19440',5966,222,NULL,44,7882,0);
INSERT INTO "django_geo_db_location" VALUES(14142,NULL,'Harleysville, PA 19441',5965,222,NULL,44,7883,0);
INSERT INTO "django_geo_db_location" VALUES(14143,NULL,'Kimberton, PA',5967,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14144,NULL,'Kimberton, PA 19442',5967,222,NULL,44,7884,0);
INSERT INTO "django_geo_db_location" VALUES(14145,NULL,'Kulpsville, PA',5968,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14146,NULL,'Kulpsville, PA 19443',5968,222,NULL,44,7885,0);
INSERT INTO "django_geo_db_location" VALUES(14147,NULL,'Lafayette Hill, PA',5969,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14148,NULL,'Lafayette Hill, PA 19444',5969,222,NULL,44,7886,0);
INSERT INTO "django_geo_db_location" VALUES(14149,NULL,'Lansdale, PA',5970,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14150,NULL,'Lansdale, PA 19446',5970,222,NULL,44,7887,0);
INSERT INTO "django_geo_db_location" VALUES(14151,NULL,'Lederach, PA',5971,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14152,NULL,'Lederach, PA 19450',5971,222,NULL,44,7888,0);
INSERT INTO "django_geo_db_location" VALUES(14153,NULL,'Mainland, PA',5972,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14154,NULL,'Mainland, PA 19451',5972,222,NULL,44,7889,0);
INSERT INTO "django_geo_db_location" VALUES(14155,NULL,'Miquon, PA',5973,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14156,NULL,'Miquon, PA 19452',5973,222,NULL,44,7890,0);
INSERT INTO "django_geo_db_location" VALUES(14157,NULL,'Mont Clare, PA',5974,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14158,NULL,'Mont Clare, PA 19453',5974,222,NULL,44,7891,0);
INSERT INTO "django_geo_db_location" VALUES(14159,NULL,'North Wales, PA',5975,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14160,NULL,'North Wales, PA 19454',5975,222,NULL,44,7892,0);
INSERT INTO "django_geo_db_location" VALUES(14161,NULL,'North Wales, PA 19455',5975,222,NULL,44,7893,0);
INSERT INTO "django_geo_db_location" VALUES(14162,NULL,'Oaks, PA',5976,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14163,NULL,'Oaks, PA 19456',5976,222,NULL,44,7894,0);
INSERT INTO "django_geo_db_location" VALUES(14164,NULL,'Parker Ford, PA',5977,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14165,NULL,'Parker Ford, PA 19457',5977,222,NULL,44,7895,0);
INSERT INTO "django_geo_db_location" VALUES(14166,NULL,'Phoenixville, PA',5978,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14167,NULL,'Phoenixville, PA 19460',5978,222,NULL,44,7896,0);
INSERT INTO "django_geo_db_location" VALUES(14168,NULL,'Plymouth Meeting, PA',5979,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14169,NULL,'Plymouth Meeting, PA 19462',5979,222,NULL,44,7897,0);
INSERT INTO "django_geo_db_location" VALUES(14170,NULL,'Pottstown, PA',5980,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14171,NULL,'Pottstown, PA 19464',5980,222,NULL,44,7898,0);
INSERT INTO "django_geo_db_location" VALUES(14172,NULL,'Pottstown, PA 19465',5980,222,NULL,44,7899,0);
INSERT INTO "django_geo_db_location" VALUES(14173,NULL,'Royersford, PA',5981,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14174,NULL,'Royersford, PA 19468',5981,222,NULL,44,7900,0);
INSERT INTO "django_geo_db_location" VALUES(14175,NULL,'Saint Peters, PA',5982,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14176,NULL,'Saint Peters, PA 19470',5982,222,NULL,44,7901,0);
INSERT INTO "django_geo_db_location" VALUES(14177,NULL,'Sassamansville, PA',5983,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14178,NULL,'Sassamansville, PA 19472',5983,222,NULL,44,7902,0);
INSERT INTO "django_geo_db_location" VALUES(14179,NULL,'Schwenksville, PA',5984,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14180,NULL,'Schwenksville, PA 19473',5984,222,NULL,44,7903,0);
INSERT INTO "django_geo_db_location" VALUES(14181,NULL,'Skippack, PA',5985,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14182,NULL,'Skippack, PA 19474',5985,222,NULL,44,7904,0);
INSERT INTO "django_geo_db_location" VALUES(14183,NULL,'Spring City, PA',5986,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14184,NULL,'Spring City, PA 19475',5986,222,NULL,44,7905,0);
INSERT INTO "django_geo_db_location" VALUES(14185,NULL,'Spring House, PA',5987,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14186,NULL,'Spring House, PA 19477',5987,222,NULL,44,7906,0);
INSERT INTO "django_geo_db_location" VALUES(14187,NULL,'Spring Mount, PA',5988,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14188,NULL,'Spring Mount, PA 19478',5988,222,NULL,44,7907,0);
INSERT INTO "django_geo_db_location" VALUES(14189,NULL,'Uwchland, PA',5989,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14190,NULL,'Uwchland, PA 19480',5989,222,NULL,44,7908,0);
INSERT INTO "django_geo_db_location" VALUES(14191,NULL,'Valley Forge, PA',5990,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14192,NULL,'Valley Forge, PA 19481',5990,222,NULL,44,7909,0);
INSERT INTO "django_geo_db_location" VALUES(14193,NULL,'Valley Forge, PA 19482',5990,222,NULL,44,7910,0);
INSERT INTO "django_geo_db_location" VALUES(14194,NULL,'Valley Forge, PA 19483',5990,222,NULL,44,7911,0);
INSERT INTO "django_geo_db_location" VALUES(14195,NULL,'Valley Forge, PA 19484',5990,222,NULL,44,7912,0);
INSERT INTO "django_geo_db_location" VALUES(14196,NULL,'Valley Forge, PA 19485',5990,222,NULL,44,7913,0);
INSERT INTO "django_geo_db_location" VALUES(14197,NULL,'West Point, PA',5991,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14198,NULL,'West Point, PA 19486',5991,222,NULL,44,7914,0);
INSERT INTO "django_geo_db_location" VALUES(14199,NULL,'King Of Prussia, PA 19487',5949,222,NULL,44,7915,0);
INSERT INTO "django_geo_db_location" VALUES(14200,NULL,'Norristown, PA 19488',5947,222,NULL,44,7916,0);
INSERT INTO "django_geo_db_location" VALUES(14201,NULL,'Norristown, PA 19489',5947,222,NULL,44,7917,0);
INSERT INTO "django_geo_db_location" VALUES(14202,NULL,'Worcester, PA',5992,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14203,NULL,'Worcester, PA 19490',5992,222,NULL,44,7918,0);
INSERT INTO "django_geo_db_location" VALUES(14204,NULL,'Zieglerville, PA',5993,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14205,NULL,'Zieglerville, PA 19492',5993,222,NULL,44,7919,0);
INSERT INTO "django_geo_db_location" VALUES(14206,NULL,'Valley Forge, PA 19493',5990,222,NULL,44,7920,0);
INSERT INTO "django_geo_db_location" VALUES(14207,NULL,'Valley Forge, PA 19494',5990,222,NULL,44,7921,0);
INSERT INTO "django_geo_db_location" VALUES(14208,NULL,'Valley Forge, PA 19495',5990,222,NULL,44,7922,0);
INSERT INTO "django_geo_db_location" VALUES(14209,NULL,'Valley Forge, PA 19496',5990,222,NULL,44,7923,0);
INSERT INTO "django_geo_db_location" VALUES(14210,NULL,'Adamstown, PA',5994,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14211,NULL,'Adamstown, PA 19501',5994,222,NULL,44,7924,0);
INSERT INTO "django_geo_db_location" VALUES(14212,NULL,'Bally, PA',5995,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14213,NULL,'Bally, PA 19503',5995,222,NULL,44,7925,0);
INSERT INTO "django_geo_db_location" VALUES(14214,NULL,'Barto, PA',5996,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14215,NULL,'Barto, PA 19504',5996,222,NULL,44,7926,0);
INSERT INTO "django_geo_db_location" VALUES(14216,NULL,'Bechtelsville, PA',5997,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14217,NULL,'Bechtelsville, PA 19505',5997,222,NULL,44,7927,0);
INSERT INTO "django_geo_db_location" VALUES(14218,NULL,'Bernville, PA',5998,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14219,NULL,'Bernville, PA 19506',5998,222,NULL,44,7928,0);
INSERT INTO "django_geo_db_location" VALUES(14220,NULL,'Bethel, PA',5999,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14221,NULL,'Bethel, PA 19507',5999,222,NULL,44,7929,0);
INSERT INTO "django_geo_db_location" VALUES(14222,NULL,'Birdsboro, PA',6000,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14223,NULL,'Birdsboro, PA 19508',6000,222,NULL,44,7930,0);
INSERT INTO "django_geo_db_location" VALUES(14224,NULL,'Blandon, PA',6001,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14225,NULL,'Blandon, PA 19510',6001,222,NULL,44,7931,0);
INSERT INTO "django_geo_db_location" VALUES(14226,NULL,'Bowers, PA',6002,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14227,NULL,'Bowers, PA 19511',6002,222,NULL,44,7932,0);
INSERT INTO "django_geo_db_location" VALUES(14228,NULL,'Boyertown, PA',6003,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14229,NULL,'Boyertown, PA 19512',6003,222,NULL,44,7933,0);
INSERT INTO "django_geo_db_location" VALUES(14230,NULL,'Centerport, PA 19516',5899,222,NULL,44,7934,0);
INSERT INTO "django_geo_db_location" VALUES(14231,NULL,'Dauberville, PA',6004,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14232,NULL,'Dauberville, PA 19517',6004,222,NULL,44,7935,0);
INSERT INTO "django_geo_db_location" VALUES(14233,NULL,'Douglassville, PA',6005,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14234,NULL,'Douglassville, PA 19518',6005,222,NULL,44,7936,0);
INSERT INTO "django_geo_db_location" VALUES(14235,NULL,'Earlville, PA',6006,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14236,NULL,'Earlville, PA 19519',6006,222,NULL,44,7937,0);
INSERT INTO "django_geo_db_location" VALUES(14237,NULL,'Elverson, PA',6007,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14238,NULL,'Elverson, PA 19520',6007,222,NULL,44,7938,0);
INSERT INTO "django_geo_db_location" VALUES(14239,NULL,'Fleetwood, PA',6008,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14240,NULL,'Fleetwood, PA 19522',6008,222,NULL,44,7939,0);
INSERT INTO "django_geo_db_location" VALUES(14241,NULL,'Geigertown, PA',6009,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14242,NULL,'Geigertown, PA 19523',6009,222,NULL,44,7940,0);
INSERT INTO "django_geo_db_location" VALUES(14243,NULL,'Robeson, PA',6010,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14244,NULL,'Robeson, PA 19524',6010,222,NULL,44,7941,0);
INSERT INTO "django_geo_db_location" VALUES(14245,NULL,'Gilbertsville, PA',6011,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14246,NULL,'Gilbertsville, PA 19525',6011,222,NULL,44,7942,0);
INSERT INTO "django_geo_db_location" VALUES(14247,NULL,'Hamburg, PA',6012,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14248,NULL,'Hamburg, PA 19526',6012,222,NULL,44,7943,0);
INSERT INTO "django_geo_db_location" VALUES(14249,NULL,'Kempton, PA',6013,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14250,NULL,'Kempton, PA 19529',6013,222,NULL,44,7944,0);
INSERT INTO "django_geo_db_location" VALUES(14251,NULL,'Kutztown, PA',6014,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14252,NULL,'Kutztown, PA 19530',6014,222,NULL,44,7945,0);
INSERT INTO "django_geo_db_location" VALUES(14253,NULL,'Leesport, PA',6015,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14254,NULL,'Leesport, PA 19533',6015,222,NULL,44,7946,0);
INSERT INTO "django_geo_db_location" VALUES(14255,NULL,'Lenhartsville, PA',6016,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14256,NULL,'Lenhartsville, PA 19534',6016,222,NULL,44,7947,0);
INSERT INTO "django_geo_db_location" VALUES(14257,NULL,'Limekiln, PA',6017,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14258,NULL,'Limekiln, PA 19535',6017,222,NULL,44,7948,0);
INSERT INTO "django_geo_db_location" VALUES(14259,NULL,'Lyon Station, PA',6018,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14260,NULL,'Lyon Station, PA 19536',6018,222,NULL,44,7949,0);
INSERT INTO "django_geo_db_location" VALUES(14261,NULL,'Maxatawny, PA',6019,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14262,NULL,'Maxatawny, PA 19538',6019,222,NULL,44,7950,0);
INSERT INTO "django_geo_db_location" VALUES(14263,NULL,'Mertztown, PA',6020,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14264,NULL,'Mertztown, PA 19539',6020,222,NULL,44,7951,0);
INSERT INTO "django_geo_db_location" VALUES(14265,NULL,'Mohnton, PA',6021,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14266,NULL,'Mohnton, PA 19540',6021,222,NULL,44,7952,0);
INSERT INTO "django_geo_db_location" VALUES(14267,NULL,'Mohrsville, PA',6022,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14268,NULL,'Mohrsville, PA 19541',6022,222,NULL,44,7953,0);
INSERT INTO "django_geo_db_location" VALUES(14269,NULL,'Monocacy Station, PA',6023,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14270,NULL,'Monocacy Station, PA 19542',6023,222,NULL,44,7954,0);
INSERT INTO "django_geo_db_location" VALUES(14271,NULL,'Morgantown, PA',6024,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14272,NULL,'Morgantown, PA 19543',6024,222,NULL,44,7955,0);
INSERT INTO "django_geo_db_location" VALUES(14273,NULL,'Mount Aetna, PA',6025,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14274,NULL,'Mount Aetna, PA 19544',6025,222,NULL,44,7956,0);
INSERT INTO "django_geo_db_location" VALUES(14275,NULL,'New Berlinville, PA',6026,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14276,NULL,'New Berlinville, PA 19545',6026,222,NULL,44,7957,0);
INSERT INTO "django_geo_db_location" VALUES(14277,NULL,'Cumru, PA',6027,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14278,NULL,'Cumru, PA 19546',6027,222,NULL,44,7958,0);
INSERT INTO "django_geo_db_location" VALUES(14279,NULL,'Oley, PA',6028,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14280,NULL,'Oley, PA 19547',6028,222,NULL,44,7959,0);
INSERT INTO "django_geo_db_location" VALUES(14281,NULL,'Pine Forge, PA',6029,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14282,NULL,'Pine Forge, PA 19548',6029,222,NULL,44,7960,0);
INSERT INTO "django_geo_db_location" VALUES(14283,NULL,'Port Clinton, PA',6030,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14284,NULL,'Port Clinton, PA 19549',6030,222,NULL,44,7961,0);
INSERT INTO "django_geo_db_location" VALUES(14285,NULL,'Rehrersburg, PA',6031,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14286,NULL,'Rehrersburg, PA 19550',6031,222,NULL,44,7962,0);
INSERT INTO "django_geo_db_location" VALUES(14287,NULL,'Robesonia, PA',6032,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14288,NULL,'Robesonia, PA 19551',6032,222,NULL,44,7963,0);
INSERT INTO "django_geo_db_location" VALUES(14289,NULL,'Shartlesville, PA',6033,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14290,NULL,'Shartlesville, PA 19554',6033,222,NULL,44,7964,0);
INSERT INTO "django_geo_db_location" VALUES(14291,NULL,'Shoemakersville, PA',6034,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14292,NULL,'Shoemakersville, PA 19555',6034,222,NULL,44,7965,0);
INSERT INTO "django_geo_db_location" VALUES(14293,NULL,'Stony Run, PA',6035,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14294,NULL,'Stony Run, PA 19557',6035,222,NULL,44,7966,0);
INSERT INTO "django_geo_db_location" VALUES(14295,NULL,'Strausstown, PA',6036,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14296,NULL,'Strausstown, PA 19559',6036,222,NULL,44,7967,0);
INSERT INTO "django_geo_db_location" VALUES(14297,NULL,'Temple, PA',6037,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14298,NULL,'Temple, PA 19560',6037,222,NULL,44,7968,0);
INSERT INTO "django_geo_db_location" VALUES(14299,NULL,'Topton, PA',6038,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14300,NULL,'Topton, PA 19562',6038,222,NULL,44,7969,0);
INSERT INTO "django_geo_db_location" VALUES(14301,NULL,'Virginville, PA',6039,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14302,NULL,'Virginville, PA 19564',6039,222,NULL,44,7970,0);
INSERT INTO "django_geo_db_location" VALUES(14303,NULL,'Wernersville, PA',6040,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14304,NULL,'Wernersville, PA 19565',6040,222,NULL,44,7971,0);
INSERT INTO "django_geo_db_location" VALUES(14305,NULL,'Womelsdorf, PA',6041,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14306,NULL,'Womelsdorf, PA 19567',6041,222,NULL,44,7972,0);
INSERT INTO "django_geo_db_location" VALUES(14307,NULL,'Reading, PA',6042,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14308,NULL,'Reading, PA 19601',6042,222,NULL,44,7973,0);
INSERT INTO "django_geo_db_location" VALUES(14309,NULL,'Reading, PA 19602',6042,222,NULL,44,7974,0);
INSERT INTO "django_geo_db_location" VALUES(14310,NULL,'Reading, PA 19603',6042,222,NULL,44,7975,0);
INSERT INTO "django_geo_db_location" VALUES(14311,NULL,'Reading, PA 19604',6042,222,NULL,44,7976,0);
INSERT INTO "django_geo_db_location" VALUES(14312,NULL,'Reading, PA 19605',6042,222,NULL,44,7977,0);
INSERT INTO "django_geo_db_location" VALUES(14313,NULL,'Reading, PA 19606',6042,222,NULL,44,7978,0);
INSERT INTO "django_geo_db_location" VALUES(14314,NULL,'Reading, PA 19607',6042,222,NULL,44,7979,0);
INSERT INTO "django_geo_db_location" VALUES(14315,NULL,'Reading, PA 19608',6042,222,NULL,44,7980,0);
INSERT INTO "django_geo_db_location" VALUES(14316,NULL,'Reading, PA 19609',6042,222,NULL,44,7981,0);
INSERT INTO "django_geo_db_location" VALUES(14317,NULL,'Reading, PA 19610',6042,222,NULL,44,7982,0);
INSERT INTO "django_geo_db_location" VALUES(14318,NULL,'Reading, PA 19611',6042,222,NULL,44,7983,0);
INSERT INTO "django_geo_db_location" VALUES(14319,NULL,'Reading, PA 19612',6042,222,NULL,44,7984,0);
INSERT INTO "django_geo_db_location" VALUES(14320,NULL,'Reading, PA 19640',6042,222,NULL,44,7985,0);
INSERT INTO "django_geo_db_location" VALUES(14321,NULL,'Alsace, PA',6043,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14322,NULL,'Alsace, PA 19650',6043,222,NULL,44,7986,0);
INSERT INTO "django_geo_db_location" VALUES(14323,NULL,'Muhlenberg, PA',6044,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14324,NULL,'Muhlenberg, PA 19685',6044,222,NULL,44,7987,0);
INSERT INTO "django_geo_db_location" VALUES(14325,NULL,'Delaware City, DE',6045,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14326,NULL,'Delaware City, DE 19700',6045,222,NULL,9,7988,0);
INSERT INTO "django_geo_db_location" VALUES(14327,NULL,'Bear, DE',6046,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14328,NULL,'Bear, DE 19701',6046,222,NULL,9,7989,0);
INSERT INTO "django_geo_db_location" VALUES(14329,NULL,'Newark, DE',6047,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14330,NULL,'Newark, DE 19702',6047,222,NULL,9,7990,0);
INSERT INTO "django_geo_db_location" VALUES(14331,NULL,'Claymont, DE',6048,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14332,NULL,'Claymont, DE 19703',6048,222,NULL,9,7991,0);
INSERT INTO "django_geo_db_location" VALUES(14333,NULL,'Delaware City, DE 19706',6045,222,NULL,9,7992,0);
INSERT INTO "django_geo_db_location" VALUES(14334,NULL,'Hockessin, DE',6049,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14335,NULL,'Hockessin, DE 19707',6049,222,NULL,9,7993,0);
INSERT INTO "django_geo_db_location" VALUES(14336,NULL,'Kirkwood, DE',6050,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14337,NULL,'Kirkwood, DE 19708',6050,222,NULL,9,7994,0);
INSERT INTO "django_geo_db_location" VALUES(14338,NULL,'Middletown, DE',6051,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14339,NULL,'Middletown, DE 19709',6051,222,NULL,9,7995,0);
INSERT INTO "django_geo_db_location" VALUES(14340,NULL,'Montchanin, DE',6052,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14341,NULL,'Montchanin, DE 19710',6052,222,NULL,9,7996,0);
INSERT INTO "django_geo_db_location" VALUES(14342,NULL,'Newark, DE 19711',6047,222,NULL,9,7997,0);
INSERT INTO "django_geo_db_location" VALUES(14343,NULL,'Newark, DE 19712',6047,222,NULL,9,7998,0);
INSERT INTO "django_geo_db_location" VALUES(14344,NULL,'Newark, DE 19713',6047,222,NULL,9,7999,0);
INSERT INTO "django_geo_db_location" VALUES(14345,NULL,'Newark, DE 19714',6047,222,NULL,9,8000,0);
INSERT INTO "django_geo_db_location" VALUES(14346,NULL,'Newark, DE 19715',6047,222,NULL,9,8001,0);
INSERT INTO "django_geo_db_location" VALUES(14347,NULL,'Newark, DE 19716',6047,222,NULL,9,8002,0);
INSERT INTO "django_geo_db_location" VALUES(14348,NULL,'Newark, DE 19717',6047,222,NULL,9,8003,0);
INSERT INTO "django_geo_db_location" VALUES(14349,NULL,'Newark, DE 19718',6047,222,NULL,9,8004,0);
INSERT INTO "django_geo_db_location" VALUES(14350,NULL,'New Castle, DE',6053,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14351,NULL,'New Castle, DE 19720',6053,222,NULL,9,8005,0);
INSERT INTO "django_geo_db_location" VALUES(14352,NULL,'New Castle, DE 19721',6053,222,NULL,9,8006,0);
INSERT INTO "django_geo_db_location" VALUES(14353,NULL,'Newark, DE 19725',6047,222,NULL,9,8007,0);
INSERT INTO "django_geo_db_location" VALUES(14354,NULL,'Newark, DE 19726',6047,222,NULL,9,8008,0);
INSERT INTO "django_geo_db_location" VALUES(14355,NULL,'Odessa, DE',6054,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14356,NULL,'Odessa, DE 19730',6054,222,NULL,9,8009,0);
INSERT INTO "django_geo_db_location" VALUES(14357,NULL,'Port Penn, DE',6055,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14358,NULL,'Port Penn, DE 19731',6055,222,NULL,9,8010,0);
INSERT INTO "django_geo_db_location" VALUES(14359,NULL,'Rockland, DE',6056,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14360,NULL,'Rockland, DE 19732',6056,222,NULL,9,8011,0);
INSERT INTO "django_geo_db_location" VALUES(14361,NULL,'Saint Georges, DE',6057,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14362,NULL,'Saint Georges, DE 19733',6057,222,NULL,9,8012,0);
INSERT INTO "django_geo_db_location" VALUES(14363,NULL,'Townsend, DE',6058,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14364,NULL,'Townsend, DE 19734',6058,222,NULL,9,8013,0);
INSERT INTO "django_geo_db_location" VALUES(14365,NULL,'Winterthur, DE',6059,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14366,NULL,'Winterthur, DE 19735',6059,222,NULL,9,8014,0);
INSERT INTO "django_geo_db_location" VALUES(14367,NULL,'Yorklyn, DE',6060,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14368,NULL,'Yorklyn, DE 19736',6060,222,NULL,9,8015,0);
INSERT INTO "django_geo_db_location" VALUES(14369,NULL,'Spring Mount, PA 19743',5988,222,NULL,44,8016,0);
INSERT INTO "django_geo_db_location" VALUES(14370,NULL,'Delaware City, DE 19766',6045,222,NULL,9,8017,0);
INSERT INTO "django_geo_db_location" VALUES(14371,NULL,'Wilmington, DE',6061,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14372,NULL,'Wilmington, DE 19801',6061,222,NULL,9,8018,0);
INSERT INTO "django_geo_db_location" VALUES(14373,NULL,'Wilmington, DE 19802',6061,222,NULL,9,8019,0);
INSERT INTO "django_geo_db_location" VALUES(14374,NULL,'Wilmington, DE 19803',6061,222,NULL,9,8020,0);
INSERT INTO "django_geo_db_location" VALUES(14375,NULL,'Wilmington, DE 19804',6061,222,NULL,9,8021,0);
INSERT INTO "django_geo_db_location" VALUES(14376,NULL,'Wilmington, DE 19805',6061,222,NULL,9,8022,0);
INSERT INTO "django_geo_db_location" VALUES(14377,NULL,'Wilmington, DE 19806',6061,222,NULL,9,8023,0);
INSERT INTO "django_geo_db_location" VALUES(14378,NULL,'Wilmington, DE 19807',6061,222,NULL,9,8024,0);
INSERT INTO "django_geo_db_location" VALUES(14379,NULL,'Wilmington, DE 19808',6061,222,NULL,9,8025,0);
INSERT INTO "django_geo_db_location" VALUES(14380,NULL,'Wilmington, DE 19809',6061,222,NULL,9,8026,0);
INSERT INTO "django_geo_db_location" VALUES(14381,NULL,'Wilmington, DE 19810',6061,222,NULL,9,8027,0);
INSERT INTO "django_geo_db_location" VALUES(14382,NULL,'Newport, DE',6062,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14383,NULL,'Newport, DE 19814',6062,222,NULL,9,8028,0);
INSERT INTO "django_geo_db_location" VALUES(14384,NULL,'Amity, PA 19815',4303,222,NULL,44,8029,0);
INSERT INTO "django_geo_db_location" VALUES(14385,NULL,'Wilmington, DE 19850',6061,222,NULL,9,8030,0);
INSERT INTO "django_geo_db_location" VALUES(14386,NULL,'Schuylkill, PA',6063,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14387,NULL,'Schuylkill, PA 19853',6063,222,NULL,44,8031,0);
INSERT INTO "django_geo_db_location" VALUES(14388,NULL,'Wilmington, DE 19880',6061,222,NULL,9,8032,0);
INSERT INTO "django_geo_db_location" VALUES(14389,NULL,'Wilmington, DE 19884',6061,222,NULL,9,8033,0);
INSERT INTO "django_geo_db_location" VALUES(14390,NULL,'Wilmington, DE 19885',6061,222,NULL,9,8034,0);
INSERT INTO "django_geo_db_location" VALUES(14391,NULL,'Wilmington, DE 19886',6061,222,NULL,9,8035,0);
INSERT INTO "django_geo_db_location" VALUES(14392,NULL,'Wilmington, DE 19887',6061,222,NULL,9,8036,0);
INSERT INTO "django_geo_db_location" VALUES(14393,NULL,'Wilmington, DE 19889',6061,222,NULL,9,8037,0);
INSERT INTO "django_geo_db_location" VALUES(14394,NULL,'Wilmington, DE 19890',6061,222,NULL,9,8038,0);
INSERT INTO "django_geo_db_location" VALUES(14395,NULL,'Wilmington, DE 19891',6061,222,NULL,9,8039,0);
INSERT INTO "django_geo_db_location" VALUES(14396,NULL,'Wilmington, DE 19892',6061,222,NULL,9,8040,0);
INSERT INTO "django_geo_db_location" VALUES(14397,NULL,'Wilmington, DE 19893',6061,222,NULL,9,8041,0);
INSERT INTO "django_geo_db_location" VALUES(14398,NULL,'Wilmington, DE 19894',6061,222,NULL,9,8042,0);
INSERT INTO "django_geo_db_location" VALUES(14399,NULL,'Wilmington, DE 19895',6061,222,NULL,9,8043,0);
INSERT INTO "django_geo_db_location" VALUES(14400,NULL,'Wilmington, DE 19896',6061,222,NULL,9,8044,0);
INSERT INTO "django_geo_db_location" VALUES(14401,NULL,'Wilmington, DE 19897',6061,222,NULL,9,8045,0);
INSERT INTO "django_geo_db_location" VALUES(14402,NULL,'Wilmington, DE 19898',6061,222,NULL,9,8046,0);
INSERT INTO "django_geo_db_location" VALUES(14403,NULL,'Wilmington, DE 19899',6061,222,NULL,9,8047,0);
INSERT INTO "django_geo_db_location" VALUES(14404,NULL,'Dover, DE',6064,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14405,NULL,'Dover, DE 19901',6064,222,NULL,9,8048,0);
INSERT INTO "django_geo_db_location" VALUES(14406,NULL,'Dover AFB, DE',6065,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14407,NULL,'Dover AFB, DE 19902',6065,222,NULL,9,8049,0);
INSERT INTO "django_geo_db_location" VALUES(14408,NULL,'Dover, DE 19903',6064,222,NULL,9,8050,0);
INSERT INTO "django_geo_db_location" VALUES(14409,NULL,'Dover, DE 19904',6064,222,NULL,9,8051,0);
INSERT INTO "django_geo_db_location" VALUES(14410,NULL,'Dover, DE 19905',6064,222,NULL,9,8052,0);
INSERT INTO "django_geo_db_location" VALUES(14411,NULL,'Upper Uwchlan, PA',6066,222,NULL,44,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14412,NULL,'Upper Uwchlan, PA 19925',6066,222,NULL,44,8053,0);
INSERT INTO "django_geo_db_location" VALUES(14413,NULL,'Bethany Beach, DE',6067,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14414,NULL,'Bethany Beach, DE 19930',6067,222,NULL,9,8054,0);
INSERT INTO "django_geo_db_location" VALUES(14415,NULL,'Bethel, DE',6068,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14416,NULL,'Bethel, DE 19931',6068,222,NULL,9,8055,0);
INSERT INTO "django_geo_db_location" VALUES(14417,NULL,'Bridgeville, DE',6069,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14418,NULL,'Bridgeville, DE 19933',6069,222,NULL,9,8056,0);
INSERT INTO "django_geo_db_location" VALUES(14419,NULL,'Camden Wyoming, DE',6070,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14420,NULL,'Camden Wyoming, DE 19934',6070,222,NULL,9,8057,0);
INSERT INTO "django_geo_db_location" VALUES(14421,NULL,'Cheswold, DE',6071,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14422,NULL,'Cheswold, DE 19936',6071,222,NULL,9,8058,0);
INSERT INTO "django_geo_db_location" VALUES(14423,NULL,'Clayton, DE',6072,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14424,NULL,'Clayton, DE 19938',6072,222,NULL,9,8059,0);
INSERT INTO "django_geo_db_location" VALUES(14425,NULL,'Dagsboro, DE',6073,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14426,NULL,'Dagsboro, DE 19939',6073,222,NULL,9,8060,0);
INSERT INTO "django_geo_db_location" VALUES(14427,NULL,'Delmar, DE',6074,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14428,NULL,'Delmar, DE 19940',6074,222,NULL,9,8061,0);
INSERT INTO "django_geo_db_location" VALUES(14429,NULL,'Ellendale, DE',6075,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14430,NULL,'Ellendale, DE 19941',6075,222,NULL,9,8062,0);
INSERT INTO "django_geo_db_location" VALUES(14431,NULL,'Farmington, DE',6076,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14432,NULL,'Farmington, DE 19942',6076,222,NULL,9,8063,0);
INSERT INTO "django_geo_db_location" VALUES(14433,NULL,'Felton, DE',6077,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14434,NULL,'Felton, DE 19943',6077,222,NULL,9,8064,0);
INSERT INTO "django_geo_db_location" VALUES(14435,NULL,'Fenwick Island, DE',6078,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14436,NULL,'Fenwick Island, DE 19944',6078,222,NULL,9,8065,0);
INSERT INTO "django_geo_db_location" VALUES(14437,NULL,'Frankford, DE',6079,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14438,NULL,'Frankford, DE 19945',6079,222,NULL,9,8066,0);
INSERT INTO "django_geo_db_location" VALUES(14439,NULL,'Frederica, DE',6080,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14440,NULL,'Frederica, DE 19946',6080,222,NULL,9,8067,0);
INSERT INTO "django_geo_db_location" VALUES(14441,NULL,'Georgetown, DE',6081,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14442,NULL,'Georgetown, DE 19947',6081,222,NULL,9,8068,0);
INSERT INTO "django_geo_db_location" VALUES(14443,NULL,'Greenwood, DE',6082,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14444,NULL,'Greenwood, DE 19950',6082,222,NULL,9,8069,0);
INSERT INTO "django_geo_db_location" VALUES(14445,NULL,'Harbeson, DE',6083,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14446,NULL,'Harbeson, DE 19951',6083,222,NULL,9,8070,0);
INSERT INTO "django_geo_db_location" VALUES(14447,NULL,'Harrington, DE',6084,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14448,NULL,'Harrington, DE 19952',6084,222,NULL,9,8071,0);
INSERT INTO "django_geo_db_location" VALUES(14449,NULL,'Hartly, DE',6085,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14450,NULL,'Hartly, DE 19953',6085,222,NULL,9,8072,0);
INSERT INTO "django_geo_db_location" VALUES(14451,NULL,'Houston, DE',6086,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14452,NULL,'Houston, DE 19954',6086,222,NULL,9,8073,0);
INSERT INTO "django_geo_db_location" VALUES(14453,NULL,'Kenton, DE',6087,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14454,NULL,'Kenton, DE 19955',6087,222,NULL,9,8074,0);
INSERT INTO "django_geo_db_location" VALUES(14455,NULL,'Laurel, DE',6088,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14456,NULL,'Laurel, DE 19956',6088,222,NULL,9,8075,0);
INSERT INTO "django_geo_db_location" VALUES(14457,NULL,'Lewes, DE',6089,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14458,NULL,'Lewes, DE 19958',6089,222,NULL,9,8076,0);
INSERT INTO "django_geo_db_location" VALUES(14459,NULL,'Lincoln, DE',6090,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14460,NULL,'Lincoln, DE 19960',6090,222,NULL,9,8077,0);
INSERT INTO "django_geo_db_location" VALUES(14461,NULL,'Little Creek, DE',6091,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14462,NULL,'Little Creek, DE 19961',6091,222,NULL,9,8078,0);
INSERT INTO "django_geo_db_location" VALUES(14463,NULL,'Magnolia, DE',6092,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14464,NULL,'Magnolia, DE 19962',6092,222,NULL,9,8079,0);
INSERT INTO "django_geo_db_location" VALUES(14465,NULL,'Milford, DE',6093,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14466,NULL,'Milford, DE 19963',6093,222,NULL,9,8080,0);
INSERT INTO "django_geo_db_location" VALUES(14467,NULL,'Marydel, DE',6094,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14468,NULL,'Marydel, DE 19964',6094,222,NULL,9,8081,0);
INSERT INTO "django_geo_db_location" VALUES(14469,NULL,'Millsboro, DE',6095,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14470,NULL,'Millsboro, DE 19966',6095,222,NULL,9,8082,0);
INSERT INTO "django_geo_db_location" VALUES(14471,NULL,'Millville, DE',6096,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14472,NULL,'Millville, DE 19967',6096,222,NULL,9,8083,0);
INSERT INTO "django_geo_db_location" VALUES(14473,NULL,'Milton, DE',6097,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14474,NULL,'Milton, DE 19968',6097,222,NULL,9,8084,0);
INSERT INTO "django_geo_db_location" VALUES(14475,NULL,'Nassau, DE',6098,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14476,NULL,'Nassau, DE 19969',6098,222,NULL,9,8085,0);
INSERT INTO "django_geo_db_location" VALUES(14477,NULL,'Ocean View, DE',6099,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14478,NULL,'Ocean View, DE 19970',6099,222,NULL,9,8086,0);
INSERT INTO "django_geo_db_location" VALUES(14479,NULL,'Rehoboth Beach, DE',6100,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14480,NULL,'Rehoboth Beach, DE 19971',6100,222,NULL,9,8087,0);
INSERT INTO "django_geo_db_location" VALUES(14481,NULL,'Seaford, DE',6101,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14482,NULL,'Seaford, DE 19973',6101,222,NULL,9,8088,0);
INSERT INTO "django_geo_db_location" VALUES(14483,NULL,'Selbyville, DE',6102,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14484,NULL,'Selbyville, DE 19975',6102,222,NULL,9,8089,0);
INSERT INTO "django_geo_db_location" VALUES(14485,NULL,'Smyrna, DE',6103,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14486,NULL,'Smyrna, DE 19977',6103,222,NULL,9,8090,0);
INSERT INTO "django_geo_db_location" VALUES(14487,NULL,'Viola, DE',6104,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14488,NULL,'Viola, DE 19979',6104,222,NULL,9,8091,0);
INSERT INTO "django_geo_db_location" VALUES(14489,NULL,'Woodside, DE',6105,222,NULL,9,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14490,NULL,'Woodside, DE 19980',6105,222,NULL,9,8092,0);
INSERT INTO "django_geo_db_location" VALUES(14491,NULL,'Bethany Beach, DE 19999',6067,222,NULL,9,8093,0);
INSERT INTO "django_geo_db_location" VALUES(14492,NULL,'Washington, DC',6106,222,NULL,10,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14493,NULL,'Washington, DC 20001',6106,222,NULL,10,8094,0);
INSERT INTO "django_geo_db_location" VALUES(14494,NULL,'Washington, DC 20002',6106,222,NULL,10,8095,0);
INSERT INTO "django_geo_db_location" VALUES(14495,NULL,'Washington, DC 20003',6106,222,NULL,10,8096,0);
INSERT INTO "django_geo_db_location" VALUES(14496,NULL,'Washington, DC 20004',6106,222,NULL,10,8097,0);
INSERT INTO "django_geo_db_location" VALUES(14497,NULL,'Washington, DC 20005',6106,222,NULL,10,8098,0);
INSERT INTO "django_geo_db_location" VALUES(14498,NULL,'Washington, DC 20006',6106,222,NULL,10,8099,0);
INSERT INTO "django_geo_db_location" VALUES(14499,NULL,'Washington, DC 20007',6106,222,NULL,10,8100,0);
INSERT INTO "django_geo_db_location" VALUES(14500,NULL,'Washington, DC 20008',6106,222,NULL,10,8101,0);
INSERT INTO "django_geo_db_location" VALUES(14501,NULL,'Washington, DC 20009',6106,222,NULL,10,8102,0);
INSERT INTO "django_geo_db_location" VALUES(14502,NULL,'Washington, DC 20010',6106,222,NULL,10,8103,0);
INSERT INTO "django_geo_db_location" VALUES(14503,NULL,'Washington, DC 20011',6106,222,NULL,10,8104,0);
INSERT INTO "django_geo_db_location" VALUES(14504,NULL,'Washington, DC 20012',6106,222,NULL,10,8105,0);
INSERT INTO "django_geo_db_location" VALUES(14505,NULL,'Washington, DC 20013',6106,222,NULL,10,8106,0);
INSERT INTO "django_geo_db_location" VALUES(14506,NULL,'Washington, DC 20015',6106,222,NULL,10,8107,0);
INSERT INTO "django_geo_db_location" VALUES(14507,NULL,'Washington, DC 20016',6106,222,NULL,10,8108,0);
INSERT INTO "django_geo_db_location" VALUES(14508,NULL,'Washington, DC 20017',6106,222,NULL,10,8109,0);
INSERT INTO "django_geo_db_location" VALUES(14509,NULL,'Washington, DC 20018',6106,222,NULL,10,8110,0);
INSERT INTO "django_geo_db_location" VALUES(14510,NULL,'Washington, DC 20019',6106,222,NULL,10,8111,0);
INSERT INTO "django_geo_db_location" VALUES(14511,NULL,'Washington, DC 20020',6106,222,NULL,10,8112,0);
INSERT INTO "django_geo_db_location" VALUES(14512,NULL,'Washington, DC 20024',6106,222,NULL,10,8113,0);
INSERT INTO "django_geo_db_location" VALUES(14513,NULL,'Washington, DC 20026',6106,222,NULL,10,8114,0);
INSERT INTO "django_geo_db_location" VALUES(14514,NULL,'Washington, DC 20029',6106,222,NULL,10,8115,0);
INSERT INTO "django_geo_db_location" VALUES(14515,NULL,'Washington, DC 20030',6106,222,NULL,10,8116,0);
INSERT INTO "django_geo_db_location" VALUES(14516,NULL,'Washington, DC 20032',6106,222,NULL,10,8117,0);
INSERT INTO "django_geo_db_location" VALUES(14517,NULL,'Washington, DC 20033',6106,222,NULL,10,8118,0);
INSERT INTO "django_geo_db_location" VALUES(14518,NULL,'Washington, DC 20035',6106,222,NULL,10,8119,0);
INSERT INTO "django_geo_db_location" VALUES(14519,NULL,'Washington, DC 20036',6106,222,NULL,10,8120,0);
INSERT INTO "django_geo_db_location" VALUES(14520,NULL,'Washington, DC 20037',6106,222,NULL,10,8121,0);
INSERT INTO "django_geo_db_location" VALUES(14521,NULL,'Washington, DC 20038',6106,222,NULL,10,8122,0);
INSERT INTO "django_geo_db_location" VALUES(14522,NULL,'Washington, DC 20039',6106,222,NULL,10,8123,0);
INSERT INTO "django_geo_db_location" VALUES(14523,NULL,'Washington, DC 20040',6106,222,NULL,10,8124,0);
INSERT INTO "django_geo_db_location" VALUES(14524,NULL,'Washington, DC 20041',6106,222,NULL,10,8125,0);
INSERT INTO "django_geo_db_location" VALUES(14525,NULL,'Washington, DC 20042',6106,222,NULL,10,8126,0);
INSERT INTO "django_geo_db_location" VALUES(14526,NULL,'Washington, DC 20043',6106,222,NULL,10,8127,0);
INSERT INTO "django_geo_db_location" VALUES(14527,NULL,'Washington, DC 20044',6106,222,NULL,10,8128,0);
INSERT INTO "django_geo_db_location" VALUES(14528,NULL,'Washington, DC 20045',6106,222,NULL,10,8129,0);
INSERT INTO "django_geo_db_location" VALUES(14529,NULL,'Washington, DC 20046',6106,222,NULL,10,8130,0);
INSERT INTO "django_geo_db_location" VALUES(14530,NULL,'Washington, DC 20047',6106,222,NULL,10,8131,0);
INSERT INTO "django_geo_db_location" VALUES(14531,NULL,'Washington, DC 20049',6106,222,NULL,10,8132,0);
INSERT INTO "django_geo_db_location" VALUES(14532,NULL,'Washington, DC 20050',6106,222,NULL,10,8133,0);
INSERT INTO "django_geo_db_location" VALUES(14533,NULL,'Washington, DC 20051',6106,222,NULL,10,8134,0);
INSERT INTO "django_geo_db_location" VALUES(14534,NULL,'Washington, DC 20052',6106,222,NULL,10,8135,0);
INSERT INTO "django_geo_db_location" VALUES(14535,NULL,'Washington, DC 20053',6106,222,NULL,10,8136,0);
INSERT INTO "django_geo_db_location" VALUES(14536,NULL,'Washington, DC 20055',6106,222,NULL,10,8137,0);
INSERT INTO "django_geo_db_location" VALUES(14537,NULL,'Washington, DC 20056',6106,222,NULL,10,8138,0);
INSERT INTO "django_geo_db_location" VALUES(14538,NULL,'Washington, DC 20057',6106,222,NULL,10,8139,0);
INSERT INTO "django_geo_db_location" VALUES(14539,NULL,'Washington, DC 20058',6106,222,NULL,10,8140,0);
INSERT INTO "django_geo_db_location" VALUES(14540,NULL,'Washington, DC 20059',6106,222,NULL,10,8141,0);
INSERT INTO "django_geo_db_location" VALUES(14541,NULL,'Washington, DC 20060',6106,222,NULL,10,8142,0);
INSERT INTO "django_geo_db_location" VALUES(14542,NULL,'Washington, DC 20061',6106,222,NULL,10,8143,0);
INSERT INTO "django_geo_db_location" VALUES(14543,NULL,'Washington, DC 20062',6106,222,NULL,10,8144,0);
INSERT INTO "django_geo_db_location" VALUES(14544,NULL,'Washington, DC 20063',6106,222,NULL,10,8145,0);
INSERT INTO "django_geo_db_location" VALUES(14545,NULL,'Washington, DC 20064',6106,222,NULL,10,8146,0);
INSERT INTO "django_geo_db_location" VALUES(14546,NULL,'Washington, DC 20065',6106,222,NULL,10,8147,0);
INSERT INTO "django_geo_db_location" VALUES(14547,NULL,'Washington, DC 20066',6106,222,NULL,10,8148,0);
INSERT INTO "django_geo_db_location" VALUES(14548,NULL,'Washington, DC 20067',6106,222,NULL,10,8149,0);
INSERT INTO "django_geo_db_location" VALUES(14549,NULL,'Washington, DC 20068',6106,222,NULL,10,8150,0);
INSERT INTO "django_geo_db_location" VALUES(14550,NULL,'Washington, DC 20069',6106,222,NULL,10,8151,0);
INSERT INTO "django_geo_db_location" VALUES(14551,NULL,'Washington, DC 20070',6106,222,NULL,10,8152,0);
INSERT INTO "django_geo_db_location" VALUES(14552,NULL,'Washington, DC 20071',6106,222,NULL,10,8153,0);
INSERT INTO "django_geo_db_location" VALUES(14553,NULL,'Washington, DC 20073',6106,222,NULL,10,8154,0);
INSERT INTO "django_geo_db_location" VALUES(14554,NULL,'Washington, DC 20074',6106,222,NULL,10,8155,0);
INSERT INTO "django_geo_db_location" VALUES(14555,NULL,'Washington, DC 20075',6106,222,NULL,10,8156,0);
INSERT INTO "django_geo_db_location" VALUES(14556,NULL,'Washington, DC 20076',6106,222,NULL,10,8157,0);
INSERT INTO "django_geo_db_location" VALUES(14557,NULL,'Washington, DC 20077',6106,222,NULL,10,8158,0);
INSERT INTO "django_geo_db_location" VALUES(14558,NULL,'Washington, DC 20078',6106,222,NULL,10,8159,0);
INSERT INTO "django_geo_db_location" VALUES(14559,NULL,'Washington, DC 20080',6106,222,NULL,10,8160,0);
INSERT INTO "django_geo_db_location" VALUES(14560,NULL,'Washington, DC 20081',6106,222,NULL,10,8161,0);
INSERT INTO "django_geo_db_location" VALUES(14561,NULL,'Washington, DC 20082',6106,222,NULL,10,8162,0);
INSERT INTO "django_geo_db_location" VALUES(14562,NULL,'Washington, DC 20088',6106,222,NULL,10,8163,0);
INSERT INTO "django_geo_db_location" VALUES(14563,NULL,'Washington, DC 20090',6106,222,NULL,10,8164,0);
INSERT INTO "django_geo_db_location" VALUES(14564,NULL,'Washington, DC 20091',6106,222,NULL,10,8165,0);
INSERT INTO "django_geo_db_location" VALUES(14565,NULL,'Washington, DC 20097',6106,222,NULL,10,8166,0);
INSERT INTO "django_geo_db_location" VALUES(14566,NULL,'Washington, DC 20098',6106,222,NULL,10,8167,0);
INSERT INTO "django_geo_db_location" VALUES(14567,NULL,'Washington, DC 20099',6106,222,NULL,10,8168,0);
INSERT INTO "django_geo_db_location" VALUES(14568,NULL,'Dulles, VA',6107,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14569,NULL,'Dulles, VA 20101',6107,222,NULL,54,8169,0);
INSERT INTO "django_geo_db_location" VALUES(14570,NULL,'Dulles, VA 20102',6107,222,NULL,54,8170,0);
INSERT INTO "django_geo_db_location" VALUES(14571,NULL,'Dulles, VA 20103',6107,222,NULL,54,8171,0);
INSERT INTO "django_geo_db_location" VALUES(14572,NULL,'Dulles, VA 20104',6107,222,NULL,54,8172,0);
INSERT INTO "django_geo_db_location" VALUES(14573,NULL,'Aldie, VA',6108,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14574,NULL,'Aldie, VA 20105',6108,222,NULL,54,8173,0);
INSERT INTO "django_geo_db_location" VALUES(14575,NULL,'Amissville, VA',6109,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14576,NULL,'Amissville, VA 20106',6109,222,NULL,54,8174,0);
INSERT INTO "django_geo_db_location" VALUES(14577,NULL,'Arcola, VA',6110,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14578,NULL,'Arcola, VA 20107',6110,222,NULL,54,8175,0);
INSERT INTO "django_geo_db_location" VALUES(14579,NULL,'Manassas, VA',6111,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14580,NULL,'Manassas, VA 20108',6111,222,NULL,54,8176,0);
INSERT INTO "django_geo_db_location" VALUES(14581,NULL,'Manassas, VA 20109',6111,222,NULL,54,8177,0);
INSERT INTO "django_geo_db_location" VALUES(14582,NULL,'Manassas, VA 20110',6111,222,NULL,54,8178,0);
INSERT INTO "django_geo_db_location" VALUES(14583,NULL,'Manassas, VA 20111',6111,222,NULL,54,8179,0);
INSERT INTO "django_geo_db_location" VALUES(14584,NULL,'Manassas, VA 20112',6111,222,NULL,54,8180,0);
INSERT INTO "django_geo_db_location" VALUES(14585,NULL,'Manassas, VA 20113',6111,222,NULL,54,8181,0);
INSERT INTO "django_geo_db_location" VALUES(14586,NULL,'Marshall, VA',6112,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14587,NULL,'Marshall, VA 20115',6112,222,NULL,54,8182,0);
INSERT INTO "django_geo_db_location" VALUES(14588,NULL,'Marshall, VA 20116',6112,222,NULL,54,8183,0);
INSERT INTO "django_geo_db_location" VALUES(14589,NULL,'Middleburg, VA',6113,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14590,NULL,'Middleburg, VA 20117',6113,222,NULL,54,8184,0);
INSERT INTO "django_geo_db_location" VALUES(14591,NULL,'Middleburg, VA 20118',6113,222,NULL,54,8185,0);
INSERT INTO "django_geo_db_location" VALUES(14592,NULL,'Catlett, VA',6114,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14593,NULL,'Catlett, VA 20119',6114,222,NULL,54,8186,0);
INSERT INTO "django_geo_db_location" VALUES(14594,NULL,'Centreville, VA',6115,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14595,NULL,'Centreville, VA 20120',6115,222,NULL,54,8187,0);
INSERT INTO "django_geo_db_location" VALUES(14596,NULL,'Centreville, VA 20121',6115,222,NULL,54,8188,0);
INSERT INTO "django_geo_db_location" VALUES(14597,NULL,'Centreville, VA 20122',6115,222,NULL,54,8189,0);
INSERT INTO "django_geo_db_location" VALUES(14598,NULL,'Clifton, VA',6116,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14599,NULL,'Clifton, VA 20124',6116,222,NULL,54,8190,0);
INSERT INTO "django_geo_db_location" VALUES(14600,NULL,'Orlean, VA',6117,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14601,NULL,'Orlean, VA 20128',6117,222,NULL,54,8191,0);
INSERT INTO "django_geo_db_location" VALUES(14602,NULL,'Paeonian Springs, VA',6118,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14603,NULL,'Paeonian Springs, VA 20129',6118,222,NULL,54,8192,0);
INSERT INTO "django_geo_db_location" VALUES(14604,NULL,'Paris, VA',6119,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14605,NULL,'Paris, VA 20130',6119,222,NULL,54,8193,0);
INSERT INTO "django_geo_db_location" VALUES(14606,NULL,'Philomont, VA',6120,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14607,NULL,'Philomont, VA 20131',6120,222,NULL,54,8194,0);
INSERT INTO "django_geo_db_location" VALUES(14608,NULL,'Purcellville, VA',6121,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14609,NULL,'Purcellville, VA 20132',6121,222,NULL,54,8195,0);
INSERT INTO "django_geo_db_location" VALUES(14610,NULL,'Purcellville, VA 20134',6121,222,NULL,54,8196,0);
INSERT INTO "django_geo_db_location" VALUES(14611,NULL,'Bluemont, VA',6122,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14612,NULL,'Bluemont, VA 20135',6122,222,NULL,54,8197,0);
INSERT INTO "django_geo_db_location" VALUES(14613,NULL,'Bristow, VA',6123,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14614,NULL,'Bristow, VA 20136',6123,222,NULL,54,8198,0);
INSERT INTO "django_geo_db_location" VALUES(14615,NULL,'Broad Run, VA',6124,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14616,NULL,'Broad Run, VA 20137',6124,222,NULL,54,8199,0);
INSERT INTO "django_geo_db_location" VALUES(14617,NULL,'Calverton, VA',6125,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14618,NULL,'Calverton, VA 20138',6125,222,NULL,54,8200,0);
INSERT INTO "django_geo_db_location" VALUES(14619,NULL,'Casanova, VA',6126,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14620,NULL,'Casanova, VA 20139',6126,222,NULL,54,8201,0);
INSERT INTO "django_geo_db_location" VALUES(14621,NULL,'Rectortown, VA',6127,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14622,NULL,'Rectortown, VA 20140',6127,222,NULL,54,8202,0);
INSERT INTO "django_geo_db_location" VALUES(14623,NULL,'Round Hill, VA',6128,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14624,NULL,'Round Hill, VA 20141',6128,222,NULL,54,8203,0);
INSERT INTO "django_geo_db_location" VALUES(14625,NULL,'Round Hill, VA 20142',6128,222,NULL,54,8204,0);
INSERT INTO "django_geo_db_location" VALUES(14626,NULL,'Catharpin, VA',6129,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14627,NULL,'Catharpin, VA 20143',6129,222,NULL,54,8205,0);
INSERT INTO "django_geo_db_location" VALUES(14628,NULL,'Delaplane, VA',6130,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14629,NULL,'Delaplane, VA 20144',6130,222,NULL,54,8206,0);
INSERT INTO "django_geo_db_location" VALUES(14630,NULL,'Ashburn, VA',6131,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14631,NULL,'Ashburn, VA 20146',6131,222,NULL,54,8207,0);
INSERT INTO "django_geo_db_location" VALUES(14632,NULL,'Ashburn, VA 20147',6131,222,NULL,54,8208,0);
INSERT INTO "django_geo_db_location" VALUES(14633,NULL,'Ashburn, VA 20148',6131,222,NULL,54,8209,0);
INSERT INTO "django_geo_db_location" VALUES(14634,NULL,'Ashburn, VA 20149',6131,222,NULL,54,8210,0);
INSERT INTO "django_geo_db_location" VALUES(14635,NULL,'Chantilly, VA',6132,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14636,NULL,'Chantilly, VA 20151',6132,222,NULL,54,8211,0);
INSERT INTO "django_geo_db_location" VALUES(14637,NULL,'Chantilly, VA 20152',6132,222,NULL,54,8212,0);
INSERT INTO "django_geo_db_location" VALUES(14638,NULL,'Chantilly, VA 20153',6132,222,NULL,54,8213,0);
INSERT INTO "django_geo_db_location" VALUES(14639,NULL,'Gainesville, VA',6133,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14640,NULL,'Gainesville, VA 20155',6133,222,NULL,54,8214,0);
INSERT INTO "django_geo_db_location" VALUES(14641,NULL,'Gainesville, VA 20156',6133,222,NULL,54,8215,0);
INSERT INTO "django_geo_db_location" VALUES(14642,NULL,'Hamilton, VA',6134,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14643,NULL,'Hamilton, VA 20158',6134,222,NULL,54,8216,0);
INSERT INTO "django_geo_db_location" VALUES(14644,NULL,'Hamilton, VA 20159',6134,222,NULL,54,8217,0);
INSERT INTO "django_geo_db_location" VALUES(14645,NULL,'Lincoln, VA',6135,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14646,NULL,'Lincoln, VA 20160',6135,222,NULL,54,8218,0);
INSERT INTO "django_geo_db_location" VALUES(14647,NULL,'Sterling, VA',6136,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14648,NULL,'Sterling, VA 20163',6136,222,NULL,54,8219,0);
INSERT INTO "django_geo_db_location" VALUES(14649,NULL,'Sterling, VA 20164',6136,222,NULL,54,8220,0);
INSERT INTO "django_geo_db_location" VALUES(14650,NULL,'Sterling, VA 20165',6136,222,NULL,54,8221,0);
INSERT INTO "django_geo_db_location" VALUES(14651,NULL,'Sterling, VA 20166',6136,222,NULL,54,8222,0);
INSERT INTO "django_geo_db_location" VALUES(14652,NULL,'Sterling, VA 20167',6136,222,NULL,54,8223,0);
INSERT INTO "django_geo_db_location" VALUES(14653,NULL,'Haymarket, VA',6137,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14654,NULL,'Haymarket, VA 20168',6137,222,NULL,54,8224,0);
INSERT INTO "django_geo_db_location" VALUES(14655,NULL,'Haymarket, VA 20169',6137,222,NULL,54,8225,0);
INSERT INTO "django_geo_db_location" VALUES(14656,NULL,'Herndon, VA',6138,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14657,NULL,'Herndon, VA 20170',6138,222,NULL,54,8226,0);
INSERT INTO "django_geo_db_location" VALUES(14658,NULL,'Herndon, VA 20171',6138,222,NULL,54,8227,0);
INSERT INTO "django_geo_db_location" VALUES(14659,NULL,'Herndon, VA 20172',6138,222,NULL,54,8228,0);
INSERT INTO "django_geo_db_location" VALUES(14660,NULL,'Leesburg, VA',6139,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14661,NULL,'Leesburg, VA 20175',6139,222,NULL,54,8229,0);
INSERT INTO "django_geo_db_location" VALUES(14662,NULL,'Leesburg, VA 20176',6139,222,NULL,54,8230,0);
INSERT INTO "django_geo_db_location" VALUES(14663,NULL,'Leesburg, VA 20177',6139,222,NULL,54,8231,0);
INSERT INTO "django_geo_db_location" VALUES(14664,NULL,'Leesburg, VA 20178',6139,222,NULL,54,8232,0);
INSERT INTO "django_geo_db_location" VALUES(14665,NULL,'Lovettsville, VA',6140,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14666,NULL,'Lovettsville, VA 20180',6140,222,NULL,54,8233,0);
INSERT INTO "django_geo_db_location" VALUES(14667,NULL,'Nokesville, VA',6141,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14668,NULL,'Nokesville, VA 20181',6141,222,NULL,54,8234,0);
INSERT INTO "django_geo_db_location" VALUES(14669,NULL,'Nokesville, VA 20182',6141,222,NULL,54,8235,0);
INSERT INTO "django_geo_db_location" VALUES(14670,NULL,'Upperville, VA',6142,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14671,NULL,'Upperville, VA 20184',6142,222,NULL,54,8236,0);
INSERT INTO "django_geo_db_location" VALUES(14672,NULL,'Upperville, VA 20185',6142,222,NULL,54,8237,0);
INSERT INTO "django_geo_db_location" VALUES(14673,NULL,'Warrenton, VA',6143,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14674,NULL,'Warrenton, VA 20186',6143,222,NULL,54,8238,0);
INSERT INTO "django_geo_db_location" VALUES(14675,NULL,'Warrenton, VA 20187',6143,222,NULL,54,8239,0);
INSERT INTO "django_geo_db_location" VALUES(14676,NULL,'Warrenton, VA 20188',6143,222,NULL,54,8240,0);
INSERT INTO "django_geo_db_location" VALUES(14677,NULL,'Reston, VA',6144,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14678,NULL,'Reston, VA 20190',6144,222,NULL,54,8241,0);
INSERT INTO "django_geo_db_location" VALUES(14679,NULL,'Reston, VA 20191',6144,222,NULL,54,8242,0);
INSERT INTO "django_geo_db_location" VALUES(14680,NULL,'Herndon, VA 20192',6138,222,NULL,54,8243,0);
INSERT INTO "django_geo_db_location" VALUES(14681,NULL,'Reston, VA 20193',6144,222,NULL,54,8244,0);
INSERT INTO "django_geo_db_location" VALUES(14682,NULL,'Reston, VA 20194',6144,222,NULL,54,8245,0);
INSERT INTO "django_geo_db_location" VALUES(14683,NULL,'Reston, VA 20195',6144,222,NULL,54,8246,0);
INSERT INTO "django_geo_db_location" VALUES(14684,NULL,'Reston, VA 20196',6144,222,NULL,54,8247,0);
INSERT INTO "django_geo_db_location" VALUES(14685,NULL,'Waterford, VA',6145,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14686,NULL,'Waterford, VA 20197',6145,222,NULL,54,8248,0);
INSERT INTO "django_geo_db_location" VALUES(14687,NULL,'The Plains, VA',6146,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14688,NULL,'The Plains, VA 20198',6146,222,NULL,54,8249,0);
INSERT INTO "django_geo_db_location" VALUES(14689,NULL,'Dulles, VA 20199',6107,222,NULL,54,8250,0);
INSERT INTO "django_geo_db_location" VALUES(14690,NULL,'Washington, DC 20201',6106,222,NULL,10,8251,0);
INSERT INTO "django_geo_db_location" VALUES(14691,NULL,'Washington, DC 20202',6106,222,NULL,10,8252,0);
INSERT INTO "django_geo_db_location" VALUES(14692,NULL,'Washington, DC 20203',6106,222,NULL,10,8253,0);
INSERT INTO "django_geo_db_location" VALUES(14693,NULL,'Washington, DC 20204',6106,222,NULL,10,8254,0);
INSERT INTO "django_geo_db_location" VALUES(14694,NULL,'Washington, DC 20206',6106,222,NULL,10,8255,0);
INSERT INTO "django_geo_db_location" VALUES(14695,NULL,'Washington, DC 20207',6106,222,NULL,10,8256,0);
INSERT INTO "django_geo_db_location" VALUES(14696,NULL,'Washington, DC 20208',6106,222,NULL,10,8257,0);
INSERT INTO "django_geo_db_location" VALUES(14697,NULL,'Washington, DC 20210',6106,222,NULL,10,8258,0);
INSERT INTO "django_geo_db_location" VALUES(14698,NULL,'Washington, DC 20211',6106,222,NULL,10,8259,0);
INSERT INTO "django_geo_db_location" VALUES(14699,NULL,'Washington, DC 20212',6106,222,NULL,10,8260,0);
INSERT INTO "django_geo_db_location" VALUES(14700,NULL,'Washington, DC 20213',6106,222,NULL,10,8261,0);
INSERT INTO "django_geo_db_location" VALUES(14701,NULL,'Washington, DC 20214',6106,222,NULL,10,8262,0);
INSERT INTO "django_geo_db_location" VALUES(14702,NULL,'Washington, DC 20215',6106,222,NULL,10,8263,0);
INSERT INTO "django_geo_db_location" VALUES(14703,NULL,'Washington, DC 20216',6106,222,NULL,10,8264,0);
INSERT INTO "django_geo_db_location" VALUES(14704,NULL,'Washington, DC 20217',6106,222,NULL,10,8265,0);
INSERT INTO "django_geo_db_location" VALUES(14705,NULL,'Washington, DC 20218',6106,222,NULL,10,8266,0);
INSERT INTO "django_geo_db_location" VALUES(14706,NULL,'Washington, DC 20219',6106,222,NULL,10,8267,0);
INSERT INTO "django_geo_db_location" VALUES(14707,NULL,'Washington, DC 20220',6106,222,NULL,10,8268,0);
INSERT INTO "django_geo_db_location" VALUES(14708,NULL,'Washington, DC 20221',6106,222,NULL,10,8269,0);
INSERT INTO "django_geo_db_location" VALUES(14709,NULL,'Washington, DC 20222',6106,222,NULL,10,8270,0);
INSERT INTO "django_geo_db_location" VALUES(14710,NULL,'Washington, DC 20223',6106,222,NULL,10,8271,0);
INSERT INTO "django_geo_db_location" VALUES(14711,NULL,'Washington, DC 20224',6106,222,NULL,10,8272,0);
INSERT INTO "django_geo_db_location" VALUES(14712,NULL,'Washington, DC 20226',6106,222,NULL,10,8273,0);
INSERT INTO "django_geo_db_location" VALUES(14713,NULL,'Washington, DC 20227',6106,222,NULL,10,8274,0);
INSERT INTO "django_geo_db_location" VALUES(14714,NULL,'Washington, DC 20228',6106,222,NULL,10,8275,0);
INSERT INTO "django_geo_db_location" VALUES(14715,NULL,'Washington, DC 20229',6106,222,NULL,10,8276,0);
INSERT INTO "django_geo_db_location" VALUES(14716,NULL,'Washington, DC 20230',6106,222,NULL,10,8277,0);
INSERT INTO "django_geo_db_location" VALUES(14717,NULL,'Washington, DC 20231',6106,222,NULL,10,8278,0);
INSERT INTO "django_geo_db_location" VALUES(14718,NULL,'Washington, DC 20232',6106,222,NULL,10,8279,0);
INSERT INTO "django_geo_db_location" VALUES(14719,NULL,'Washington, DC 20233',6106,222,NULL,10,8280,0);
INSERT INTO "django_geo_db_location" VALUES(14720,NULL,'Washington, DC 20235',6106,222,NULL,10,8281,0);
INSERT INTO "django_geo_db_location" VALUES(14721,NULL,'Washington, DC 20238',6106,222,NULL,10,8282,0);
INSERT INTO "django_geo_db_location" VALUES(14722,NULL,'Washington, DC 20239',6106,222,NULL,10,8283,0);
INSERT INTO "django_geo_db_location" VALUES(14723,NULL,'Washington, DC 20240',6106,222,NULL,10,8284,0);
INSERT INTO "django_geo_db_location" VALUES(14724,NULL,'Washington, DC 20241',6106,222,NULL,10,8285,0);
INSERT INTO "django_geo_db_location" VALUES(14725,NULL,'Washington, DC 20242',6106,222,NULL,10,8286,0);
INSERT INTO "django_geo_db_location" VALUES(14726,NULL,'Washington, DC 20244',6106,222,NULL,10,8287,0);
INSERT INTO "django_geo_db_location" VALUES(14727,NULL,'Washington, DC 20245',6106,222,NULL,10,8288,0);
INSERT INTO "django_geo_db_location" VALUES(14728,NULL,'Washington, DC 20250',6106,222,NULL,10,8289,0);
INSERT INTO "django_geo_db_location" VALUES(14729,NULL,'Washington, DC 20251',6106,222,NULL,10,8290,0);
INSERT INTO "django_geo_db_location" VALUES(14730,NULL,'Washington, DC 20254',6106,222,NULL,10,8291,0);
INSERT INTO "django_geo_db_location" VALUES(14731,NULL,'Washington, DC 20260',6106,222,NULL,10,8292,0);
INSERT INTO "django_geo_db_location" VALUES(14732,NULL,'Washington, DC 20261',6106,222,NULL,10,8293,0);
INSERT INTO "django_geo_db_location" VALUES(14733,NULL,'Washington, DC 20262',6106,222,NULL,10,8294,0);
INSERT INTO "django_geo_db_location" VALUES(14734,NULL,'Washington, DC 20265',6106,222,NULL,10,8295,0);
INSERT INTO "django_geo_db_location" VALUES(14735,NULL,'Washington, DC 20266',6106,222,NULL,10,8296,0);
INSERT INTO "django_geo_db_location" VALUES(14736,NULL,'Washington, DC 20268',6106,222,NULL,10,8297,0);
INSERT INTO "django_geo_db_location" VALUES(14737,NULL,'Washington, DC 20270',6106,222,NULL,10,8298,0);
INSERT INTO "django_geo_db_location" VALUES(14738,NULL,'Washington, DC 20277',6106,222,NULL,10,8299,0);
INSERT INTO "django_geo_db_location" VALUES(14739,NULL,'Washington, DC 20289',6106,222,NULL,10,8300,0);
INSERT INTO "django_geo_db_location" VALUES(14740,NULL,'Washington, DC 20299',6106,222,NULL,10,8301,0);
INSERT INTO "django_geo_db_location" VALUES(14741,NULL,'Washington, DC 20301',6106,222,NULL,10,8302,0);
INSERT INTO "django_geo_db_location" VALUES(14742,NULL,'Washington, DC 20303',6106,222,NULL,10,8303,0);
INSERT INTO "django_geo_db_location" VALUES(14743,NULL,'Washington, DC 20306',6106,222,NULL,10,8304,0);
INSERT INTO "django_geo_db_location" VALUES(14744,NULL,'Washington, DC 20307',6106,222,NULL,10,8305,0);
INSERT INTO "django_geo_db_location" VALUES(14745,NULL,'Washington, DC 20310',6106,222,NULL,10,8306,0);
INSERT INTO "django_geo_db_location" VALUES(14746,NULL,'Washington, DC 20314',6106,222,NULL,10,8307,0);
INSERT INTO "django_geo_db_location" VALUES(14747,NULL,'Washington, DC 20315',6106,222,NULL,10,8308,0);
INSERT INTO "django_geo_db_location" VALUES(14748,NULL,'Washington, DC 20317',6106,222,NULL,10,8309,0);
INSERT INTO "django_geo_db_location" VALUES(14749,NULL,'Washington, DC 20318',6106,222,NULL,10,8310,0);
INSERT INTO "django_geo_db_location" VALUES(14750,NULL,'Washington, DC 20319',6106,222,NULL,10,8311,0);
INSERT INTO "django_geo_db_location" VALUES(14751,NULL,'Washington, DC 20330',6106,222,NULL,10,8312,0);
INSERT INTO "django_geo_db_location" VALUES(14752,NULL,'Washington, DC 20332',6106,222,NULL,10,8313,0);
INSERT INTO "django_geo_db_location" VALUES(14753,NULL,'Washington, DC 20336',6106,222,NULL,10,8314,0);
INSERT INTO "django_geo_db_location" VALUES(14754,NULL,'Washington, DC 20337',6106,222,NULL,10,8315,0);
INSERT INTO "django_geo_db_location" VALUES(14755,NULL,'Washington, DC 20338',6106,222,NULL,10,8316,0);
INSERT INTO "django_geo_db_location" VALUES(14756,NULL,'Washington, DC 20340',6106,222,NULL,10,8317,0);
INSERT INTO "django_geo_db_location" VALUES(14757,NULL,'Washington, DC 20350',6106,222,NULL,10,8318,0);
INSERT INTO "django_geo_db_location" VALUES(14758,NULL,'Washington, DC 20370',6106,222,NULL,10,8319,0);
INSERT INTO "django_geo_db_location" VALUES(14759,NULL,'Washington, DC 20372',6106,222,NULL,10,8320,0);
INSERT INTO "django_geo_db_location" VALUES(14760,NULL,'Washington, DC 20373',6106,222,NULL,10,8321,0);
INSERT INTO "django_geo_db_location" VALUES(14761,NULL,'Washington, DC 20374',6106,222,NULL,10,8322,0);
INSERT INTO "django_geo_db_location" VALUES(14762,NULL,'Washington, DC 20375',6106,222,NULL,10,8323,0);
INSERT INTO "django_geo_db_location" VALUES(14763,NULL,'Washington, DC 20380',6106,222,NULL,10,8324,0);
INSERT INTO "django_geo_db_location" VALUES(14764,NULL,'Washington, DC 20388',6106,222,NULL,10,8325,0);
INSERT INTO "django_geo_db_location" VALUES(14765,NULL,'Washington, DC 20389',6106,222,NULL,10,8326,0);
INSERT INTO "django_geo_db_location" VALUES(14766,NULL,'Washington, DC 20390',6106,222,NULL,10,8327,0);
INSERT INTO "django_geo_db_location" VALUES(14767,NULL,'Washington, DC 20391',6106,222,NULL,10,8328,0);
INSERT INTO "django_geo_db_location" VALUES(14768,NULL,'Washington, DC 20392',6106,222,NULL,10,8329,0);
INSERT INTO "django_geo_db_location" VALUES(14769,NULL,'Washington, DC 20393',6106,222,NULL,10,8330,0);
INSERT INTO "django_geo_db_location" VALUES(14770,NULL,'Washington, DC 20394',6106,222,NULL,10,8331,0);
INSERT INTO "django_geo_db_location" VALUES(14771,NULL,'Washington, DC 20395',6106,222,NULL,10,8332,0);
INSERT INTO "django_geo_db_location" VALUES(14772,NULL,'Washington, DC 20398',6106,222,NULL,10,8333,0);
INSERT INTO "django_geo_db_location" VALUES(14773,NULL,'Washington, DC 20401',6106,222,NULL,10,8334,0);
INSERT INTO "django_geo_db_location" VALUES(14774,NULL,'Washington, DC 20402',6106,222,NULL,10,8335,0);
INSERT INTO "django_geo_db_location" VALUES(14775,NULL,'Washington, DC 20403',6106,222,NULL,10,8336,0);
INSERT INTO "django_geo_db_location" VALUES(14776,NULL,'Washington, DC 20404',6106,222,NULL,10,8337,0);
INSERT INTO "django_geo_db_location" VALUES(14777,NULL,'Washington, DC 20405',6106,222,NULL,10,8338,0);
INSERT INTO "django_geo_db_location" VALUES(14778,NULL,'Washington, DC 20406',6106,222,NULL,10,8339,0);
INSERT INTO "django_geo_db_location" VALUES(14779,NULL,'Washington, DC 20407',6106,222,NULL,10,8340,0);
INSERT INTO "django_geo_db_location" VALUES(14780,NULL,'Washington, DC 20408',6106,222,NULL,10,8341,0);
INSERT INTO "django_geo_db_location" VALUES(14781,NULL,'Washington, DC 20409',6106,222,NULL,10,8342,0);
INSERT INTO "django_geo_db_location" VALUES(14782,NULL,'Washington, DC 20410',6106,222,NULL,10,8343,0);
INSERT INTO "django_geo_db_location" VALUES(14783,NULL,'Washington, DC 20411',6106,222,NULL,10,8344,0);
INSERT INTO "django_geo_db_location" VALUES(14784,NULL,'Washington, DC 20412',6106,222,NULL,10,8345,0);
INSERT INTO "django_geo_db_location" VALUES(14785,NULL,'Washington, DC 20413',6106,222,NULL,10,8346,0);
INSERT INTO "django_geo_db_location" VALUES(14786,NULL,'Washington, DC 20414',6106,222,NULL,10,8347,0);
INSERT INTO "django_geo_db_location" VALUES(14787,NULL,'Washington, DC 20415',6106,222,NULL,10,8348,0);
INSERT INTO "django_geo_db_location" VALUES(14788,NULL,'Washington, DC 20416',6106,222,NULL,10,8349,0);
INSERT INTO "django_geo_db_location" VALUES(14789,NULL,'Washington, DC 20418',6106,222,NULL,10,8350,0);
INSERT INTO "django_geo_db_location" VALUES(14790,NULL,'Washington, DC 20419',6106,222,NULL,10,8351,0);
INSERT INTO "django_geo_db_location" VALUES(14791,NULL,'Washington, DC 20420',6106,222,NULL,10,8352,0);
INSERT INTO "django_geo_db_location" VALUES(14792,NULL,'Washington, DC 20421',6106,222,NULL,10,8353,0);
INSERT INTO "django_geo_db_location" VALUES(14793,NULL,'Washington, DC 20422',6106,222,NULL,10,8354,0);
INSERT INTO "django_geo_db_location" VALUES(14794,NULL,'Washington, DC 20423',6106,222,NULL,10,8355,0);
INSERT INTO "django_geo_db_location" VALUES(14795,NULL,'Washington, DC 20424',6106,222,NULL,10,8356,0);
INSERT INTO "django_geo_db_location" VALUES(14796,NULL,'Washington, DC 20425',6106,222,NULL,10,8357,0);
INSERT INTO "django_geo_db_location" VALUES(14797,NULL,'Washington, DC 20426',6106,222,NULL,10,8358,0);
INSERT INTO "django_geo_db_location" VALUES(14798,NULL,'Washington, DC 20427',6106,222,NULL,10,8359,0);
INSERT INTO "django_geo_db_location" VALUES(14799,NULL,'Washington, DC 20428',6106,222,NULL,10,8360,0);
INSERT INTO "django_geo_db_location" VALUES(14800,NULL,'Washington, DC 20429',6106,222,NULL,10,8361,0);
INSERT INTO "django_geo_db_location" VALUES(14801,NULL,'Washington, DC 20431',6106,222,NULL,10,8362,0);
INSERT INTO "django_geo_db_location" VALUES(14802,NULL,'Washington, DC 20433',6106,222,NULL,10,8363,0);
INSERT INTO "django_geo_db_location" VALUES(14803,NULL,'Washington, DC 20434',6106,222,NULL,10,8364,0);
INSERT INTO "django_geo_db_location" VALUES(14804,NULL,'Washington, DC 20435',6106,222,NULL,10,8365,0);
INSERT INTO "django_geo_db_location" VALUES(14805,NULL,'Washington, DC 20436',6106,222,NULL,10,8366,0);
INSERT INTO "django_geo_db_location" VALUES(14806,NULL,'Washington, DC 20437',6106,222,NULL,10,8367,0);
INSERT INTO "django_geo_db_location" VALUES(14807,NULL,'Washington, DC 20439',6106,222,NULL,10,8368,0);
INSERT INTO "django_geo_db_location" VALUES(14808,NULL,'Washington, DC 20440',6106,222,NULL,10,8369,0);
INSERT INTO "django_geo_db_location" VALUES(14809,NULL,'Washington, DC 20441',6106,222,NULL,10,8370,0);
INSERT INTO "django_geo_db_location" VALUES(14810,NULL,'Washington, DC 20442',6106,222,NULL,10,8371,0);
INSERT INTO "django_geo_db_location" VALUES(14811,NULL,'Washington, DC 20444',6106,222,NULL,10,8372,0);
INSERT INTO "django_geo_db_location" VALUES(14812,NULL,'Washington, DC 20447',6106,222,NULL,10,8373,0);
INSERT INTO "django_geo_db_location" VALUES(14813,NULL,'Washington, DC 20451',6106,222,NULL,10,8374,0);
INSERT INTO "django_geo_db_location" VALUES(14814,NULL,'Washington, DC 20453',6106,222,NULL,10,8375,0);
INSERT INTO "django_geo_db_location" VALUES(14815,NULL,'Washington, DC 20456',6106,222,NULL,10,8376,0);
INSERT INTO "django_geo_db_location" VALUES(14816,NULL,'Washington, DC 20460',6106,222,NULL,10,8377,0);
INSERT INTO "django_geo_db_location" VALUES(14817,NULL,'Washington, DC 20463',6106,222,NULL,10,8378,0);
INSERT INTO "django_geo_db_location" VALUES(14818,NULL,'Washington, DC 20468',6106,222,NULL,10,8379,0);
INSERT INTO "django_geo_db_location" VALUES(14819,NULL,'Washington, DC 20469',6106,222,NULL,10,8380,0);
INSERT INTO "django_geo_db_location" VALUES(14820,NULL,'Washington, DC 20470',6106,222,NULL,10,8381,0);
INSERT INTO "django_geo_db_location" VALUES(14821,NULL,'Washington, DC 20472',6106,222,NULL,10,8382,0);
INSERT INTO "django_geo_db_location" VALUES(14822,NULL,'Washington, DC 20500',6106,222,NULL,10,8383,0);
INSERT INTO "django_geo_db_location" VALUES(14823,NULL,'Washington, DC 20501',6106,222,NULL,10,8384,0);
INSERT INTO "django_geo_db_location" VALUES(14824,NULL,'Washington, DC 20502',6106,222,NULL,10,8385,0);
INSERT INTO "django_geo_db_location" VALUES(14825,NULL,'Washington, DC 20503',6106,222,NULL,10,8386,0);
INSERT INTO "django_geo_db_location" VALUES(14826,NULL,'Washington, DC 20504',6106,222,NULL,10,8387,0);
INSERT INTO "django_geo_db_location" VALUES(14827,NULL,'Washington, DC 20505',6106,222,NULL,10,8388,0);
INSERT INTO "django_geo_db_location" VALUES(14828,NULL,'Washington, DC 20506',6106,222,NULL,10,8389,0);
INSERT INTO "django_geo_db_location" VALUES(14829,NULL,'Washington, DC 20507',6106,222,NULL,10,8390,0);
INSERT INTO "django_geo_db_location" VALUES(14830,NULL,'Washington, DC 20508',6106,222,NULL,10,8391,0);
INSERT INTO "django_geo_db_location" VALUES(14831,NULL,'Washington, DC 20510',6106,222,NULL,10,8392,0);
INSERT INTO "django_geo_db_location" VALUES(14832,NULL,'Washington, DC 20515',6106,222,NULL,10,8393,0);
INSERT INTO "django_geo_db_location" VALUES(14833,NULL,'Washington, DC 20520',6106,222,NULL,10,8394,0);
INSERT INTO "django_geo_db_location" VALUES(14834,NULL,'Washington, DC 20521',6106,222,NULL,10,8395,0);
INSERT INTO "django_geo_db_location" VALUES(14835,NULL,'Washington, DC 20522',6106,222,NULL,10,8396,0);
INSERT INTO "django_geo_db_location" VALUES(14836,NULL,'Washington, DC 20523',6106,222,NULL,10,8397,0);
INSERT INTO "django_geo_db_location" VALUES(14837,NULL,'Washington, DC 20524',6106,222,NULL,10,8398,0);
INSERT INTO "django_geo_db_location" VALUES(14838,NULL,'Washington, DC 20525',6106,222,NULL,10,8399,0);
INSERT INTO "django_geo_db_location" VALUES(14839,NULL,'Washington, DC 20526',6106,222,NULL,10,8400,0);
INSERT INTO "django_geo_db_location" VALUES(14840,NULL,'Washington, DC 20527',6106,222,NULL,10,8401,0);
INSERT INTO "django_geo_db_location" VALUES(14841,NULL,'Washington, DC 20530',6106,222,NULL,10,8402,0);
INSERT INTO "django_geo_db_location" VALUES(14842,NULL,'Washington, DC 20531',6106,222,NULL,10,8403,0);
INSERT INTO "django_geo_db_location" VALUES(14843,NULL,'Washington, DC 20532',6106,222,NULL,10,8404,0);
INSERT INTO "django_geo_db_location" VALUES(14844,NULL,'Washington, DC 20533',6106,222,NULL,10,8405,0);
INSERT INTO "django_geo_db_location" VALUES(14845,NULL,'Washington, DC 20534',6106,222,NULL,10,8406,0);
INSERT INTO "django_geo_db_location" VALUES(14846,NULL,'Washington, DC 20535',6106,222,NULL,10,8407,0);
INSERT INTO "django_geo_db_location" VALUES(14847,NULL,'Washington, DC 20536',6106,222,NULL,10,8408,0);
INSERT INTO "django_geo_db_location" VALUES(14848,NULL,'Washington, DC 20537',6106,222,NULL,10,8409,0);
INSERT INTO "django_geo_db_location" VALUES(14849,NULL,'Washington, DC 20538',6106,222,NULL,10,8410,0);
INSERT INTO "django_geo_db_location" VALUES(14850,NULL,'Washington, DC 20539',6106,222,NULL,10,8411,0);
INSERT INTO "django_geo_db_location" VALUES(14851,NULL,'Washington, DC 20540',6106,222,NULL,10,8412,0);
INSERT INTO "django_geo_db_location" VALUES(14852,NULL,'Washington, DC 20541',6106,222,NULL,10,8413,0);
INSERT INTO "django_geo_db_location" VALUES(14853,NULL,'Washington, DC 20542',6106,222,NULL,10,8414,0);
INSERT INTO "django_geo_db_location" VALUES(14854,NULL,'Washington, DC 20543',6106,222,NULL,10,8415,0);
INSERT INTO "django_geo_db_location" VALUES(14855,NULL,'Washington, DC 20544',6106,222,NULL,10,8416,0);
INSERT INTO "django_geo_db_location" VALUES(14856,NULL,'Washington, DC 20546',6106,222,NULL,10,8417,0);
INSERT INTO "django_geo_db_location" VALUES(14857,NULL,'Washington, DC 20547',6106,222,NULL,10,8418,0);
INSERT INTO "django_geo_db_location" VALUES(14858,NULL,'Washington, DC 20548',6106,222,NULL,10,8419,0);
INSERT INTO "django_geo_db_location" VALUES(14859,NULL,'Washington, DC 20549',6106,222,NULL,10,8420,0);
INSERT INTO "django_geo_db_location" VALUES(14860,NULL,'Washington, DC 20550',6106,222,NULL,10,8421,0);
INSERT INTO "django_geo_db_location" VALUES(14861,NULL,'Washington, DC 20551',6106,222,NULL,10,8422,0);
INSERT INTO "django_geo_db_location" VALUES(14862,NULL,'Washington, DC 20552',6106,222,NULL,10,8423,0);
INSERT INTO "django_geo_db_location" VALUES(14863,NULL,'Washington, DC 20553',6106,222,NULL,10,8424,0);
INSERT INTO "django_geo_db_location" VALUES(14864,NULL,'Washington, DC 20554',6106,222,NULL,10,8425,0);
INSERT INTO "django_geo_db_location" VALUES(14865,NULL,'Washington, DC 20555',6106,222,NULL,10,8426,0);
INSERT INTO "django_geo_db_location" VALUES(14866,NULL,'Washington, DC 20557',6106,222,NULL,10,8427,0);
INSERT INTO "django_geo_db_location" VALUES(14867,NULL,'Washington, DC 20558',6106,222,NULL,10,8428,0);
INSERT INTO "django_geo_db_location" VALUES(14868,NULL,'Washington, DC 20559',6106,222,NULL,10,8429,0);
INSERT INTO "django_geo_db_location" VALUES(14869,NULL,'Washington, DC 20560',6106,222,NULL,10,8430,0);
INSERT INTO "django_geo_db_location" VALUES(14870,NULL,'Washington, DC 20565',6106,222,NULL,10,8431,0);
INSERT INTO "django_geo_db_location" VALUES(14871,NULL,'Washington, DC 20566',6106,222,NULL,10,8432,0);
INSERT INTO "django_geo_db_location" VALUES(14872,NULL,'Washington, DC 20570',6106,222,NULL,10,8433,0);
INSERT INTO "django_geo_db_location" VALUES(14873,NULL,'Washington, DC 20571',6106,222,NULL,10,8434,0);
INSERT INTO "django_geo_db_location" VALUES(14874,NULL,'Washington, DC 20572',6106,222,NULL,10,8435,0);
INSERT INTO "django_geo_db_location" VALUES(14875,NULL,'Washington, DC 20573',6106,222,NULL,10,8436,0);
INSERT INTO "django_geo_db_location" VALUES(14876,NULL,'Washington, DC 20575',6106,222,NULL,10,8437,0);
INSERT INTO "django_geo_db_location" VALUES(14877,NULL,'Washington, DC 20576',6106,222,NULL,10,8438,0);
INSERT INTO "django_geo_db_location" VALUES(14878,NULL,'Washington, DC 20577',6106,222,NULL,10,8439,0);
INSERT INTO "django_geo_db_location" VALUES(14879,NULL,'Washington, DC 20578',6106,222,NULL,10,8440,0);
INSERT INTO "django_geo_db_location" VALUES(14880,NULL,'Washington, DC 20579',6106,222,NULL,10,8441,0);
INSERT INTO "django_geo_db_location" VALUES(14881,NULL,'Washington, DC 20580',6106,222,NULL,10,8442,0);
INSERT INTO "django_geo_db_location" VALUES(14882,NULL,'Washington, DC 20581',6106,222,NULL,10,8443,0);
INSERT INTO "django_geo_db_location" VALUES(14883,NULL,'Washington, DC 20585',6106,222,NULL,10,8444,0);
INSERT INTO "django_geo_db_location" VALUES(14884,NULL,'Washington, DC 20586',6106,222,NULL,10,8445,0);
INSERT INTO "django_geo_db_location" VALUES(14885,NULL,'Washington, DC 20590',6106,222,NULL,10,8446,0);
INSERT INTO "django_geo_db_location" VALUES(14886,NULL,'Washington, DC 20591',6106,222,NULL,10,8447,0);
INSERT INTO "django_geo_db_location" VALUES(14887,NULL,'Washington, DC 20593',6106,222,NULL,10,8448,0);
INSERT INTO "django_geo_db_location" VALUES(14888,NULL,'Washington, DC 20594',6106,222,NULL,10,8449,0);
INSERT INTO "django_geo_db_location" VALUES(14889,NULL,'Washington, DC 20597',6106,222,NULL,10,8450,0);
INSERT INTO "django_geo_db_location" VALUES(14890,NULL,'Washington, DC 20599',6106,222,NULL,10,8451,0);
INSERT INTO "django_geo_db_location" VALUES(14891,NULL,'Waldorf, MD',6147,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14892,NULL,'Waldorf, MD 20601',6147,222,NULL,38,8452,0);
INSERT INTO "django_geo_db_location" VALUES(14893,NULL,'Waldorf, MD 20602',6147,222,NULL,38,8453,0);
INSERT INTO "django_geo_db_location" VALUES(14894,NULL,'Waldorf, MD 20603',6147,222,NULL,38,8454,0);
INSERT INTO "django_geo_db_location" VALUES(14895,NULL,'Waldorf, MD 20604',6147,222,NULL,38,8455,0);
INSERT INTO "django_geo_db_location" VALUES(14896,NULL,'Abell, MD',6148,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14897,NULL,'Abell, MD 20606',6148,222,NULL,38,8456,0);
INSERT INTO "django_geo_db_location" VALUES(14898,NULL,'Accokeek, MD',6149,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14899,NULL,'Accokeek, MD 20607',6149,222,NULL,38,8457,0);
INSERT INTO "django_geo_db_location" VALUES(14900,NULL,'Aquasco, MD',6150,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14901,NULL,'Aquasco, MD 20608',6150,222,NULL,38,8458,0);
INSERT INTO "django_geo_db_location" VALUES(14902,NULL,'Avenue, MD',6151,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14903,NULL,'Avenue, MD 20609',6151,222,NULL,38,8459,0);
INSERT INTO "django_geo_db_location" VALUES(14904,NULL,'Barstow, MD',6152,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14905,NULL,'Barstow, MD 20610',6152,222,NULL,38,8460,0);
INSERT INTO "django_geo_db_location" VALUES(14906,NULL,'Bel Alton, MD',6153,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14907,NULL,'Bel Alton, MD 20611',6153,222,NULL,38,8461,0);
INSERT INTO "django_geo_db_location" VALUES(14908,NULL,'Benedict, MD',6154,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14909,NULL,'Benedict, MD 20612',6154,222,NULL,38,8462,0);
INSERT INTO "django_geo_db_location" VALUES(14910,NULL,'Brandywine, MD',6155,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14911,NULL,'Brandywine, MD 20613',6155,222,NULL,38,8463,0);
INSERT INTO "django_geo_db_location" VALUES(14912,NULL,'Broomes Island, MD',6156,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14913,NULL,'Broomes Island, MD 20615',6156,222,NULL,38,8464,0);
INSERT INTO "django_geo_db_location" VALUES(14914,NULL,'Bryans Road, MD',6157,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14915,NULL,'Bryans Road, MD 20616',6157,222,NULL,38,8465,0);
INSERT INTO "django_geo_db_location" VALUES(14916,NULL,'Bryantown, MD',6158,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14917,NULL,'Bryantown, MD 20617',6158,222,NULL,38,8466,0);
INSERT INTO "django_geo_db_location" VALUES(14918,NULL,'Bushwood, MD',6159,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14919,NULL,'Bushwood, MD 20618',6159,222,NULL,38,8467,0);
INSERT INTO "django_geo_db_location" VALUES(14920,NULL,'California, MD',6160,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14921,NULL,'California, MD 20619',6160,222,NULL,38,8468,0);
INSERT INTO "django_geo_db_location" VALUES(14922,NULL,'Callaway, MD',6161,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14923,NULL,'Callaway, MD 20620',6161,222,NULL,38,8469,0);
INSERT INTO "django_geo_db_location" VALUES(14924,NULL,'Chaptico, MD',6162,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14925,NULL,'Chaptico, MD 20621',6162,222,NULL,38,8470,0);
INSERT INTO "django_geo_db_location" VALUES(14926,NULL,'Charlotte Hall, MD',6163,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14927,NULL,'Charlotte Hall, MD 20622',6163,222,NULL,38,8471,0);
INSERT INTO "django_geo_db_location" VALUES(14928,NULL,'Cheltenham, MD',6164,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14929,NULL,'Cheltenham, MD 20623',6164,222,NULL,38,8472,0);
INSERT INTO "django_geo_db_location" VALUES(14930,NULL,'Clements, MD',6165,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14931,NULL,'Clements, MD 20624',6165,222,NULL,38,8473,0);
INSERT INTO "django_geo_db_location" VALUES(14932,NULL,'Cobb Island, MD',6166,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14933,NULL,'Cobb Island, MD 20625',6166,222,NULL,38,8474,0);
INSERT INTO "django_geo_db_location" VALUES(14934,NULL,'Coltons Point, MD',6167,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14935,NULL,'Coltons Point, MD 20626',6167,222,NULL,38,8475,0);
INSERT INTO "django_geo_db_location" VALUES(14936,NULL,'Compton, MD',6168,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14937,NULL,'Compton, MD 20627',6168,222,NULL,38,8476,0);
INSERT INTO "django_geo_db_location" VALUES(14938,NULL,'Dameron, MD',6169,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14939,NULL,'Dameron, MD 20628',6169,222,NULL,38,8477,0);
INSERT INTO "django_geo_db_location" VALUES(14940,NULL,'Dowell, MD',6170,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14941,NULL,'Dowell, MD 20629',6170,222,NULL,38,8478,0);
INSERT INTO "django_geo_db_location" VALUES(14942,NULL,'Drayden, MD',6171,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14943,NULL,'Drayden, MD 20630',6171,222,NULL,38,8479,0);
INSERT INTO "django_geo_db_location" VALUES(14944,NULL,'Faulkner, MD',6172,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14945,NULL,'Faulkner, MD 20632',6172,222,NULL,38,8480,0);
INSERT INTO "django_geo_db_location" VALUES(14946,NULL,'Great Mills, MD',6173,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14947,NULL,'Great Mills, MD 20634',6173,222,NULL,38,8481,0);
INSERT INTO "django_geo_db_location" VALUES(14948,NULL,'Helen, MD',6174,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14949,NULL,'Helen, MD 20635',6174,222,NULL,38,8482,0);
INSERT INTO "django_geo_db_location" VALUES(14950,NULL,'Hollywood, MD',6175,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14951,NULL,'Hollywood, MD 20636',6175,222,NULL,38,8483,0);
INSERT INTO "django_geo_db_location" VALUES(14952,NULL,'Hughesville, MD',6176,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14953,NULL,'Hughesville, MD 20637',6176,222,NULL,38,8484,0);
INSERT INTO "django_geo_db_location" VALUES(14954,NULL,'Huntingtown, MD',6177,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14955,NULL,'Huntingtown, MD 20639',6177,222,NULL,38,8485,0);
INSERT INTO "django_geo_db_location" VALUES(14956,NULL,'Indian Head, MD',6178,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14957,NULL,'Indian Head, MD 20640',6178,222,NULL,38,8486,0);
INSERT INTO "django_geo_db_location" VALUES(14958,NULL,'Ironsides, MD',6179,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14959,NULL,'Ironsides, MD 20643',6179,222,NULL,38,8487,0);
INSERT INTO "django_geo_db_location" VALUES(14960,NULL,'Issue, MD',6180,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14961,NULL,'Issue, MD 20645',6180,222,NULL,38,8488,0);
INSERT INTO "django_geo_db_location" VALUES(14962,NULL,'La Plata, MD',6181,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14963,NULL,'La Plata, MD 20646',6181,222,NULL,38,8489,0);
INSERT INTO "django_geo_db_location" VALUES(14964,NULL,'Leonardtown, MD',6182,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14965,NULL,'Leonardtown, MD 20650',6182,222,NULL,38,8490,0);
INSERT INTO "django_geo_db_location" VALUES(14966,NULL,'Lexington Park, MD',6183,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14967,NULL,'Lexington Park, MD 20653',6183,222,NULL,38,8491,0);
INSERT INTO "django_geo_db_location" VALUES(14968,NULL,'Loveville, MD',6184,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14969,NULL,'Loveville, MD 20656',6184,222,NULL,38,8492,0);
INSERT INTO "django_geo_db_location" VALUES(14970,NULL,'Lusby, MD',6185,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14971,NULL,'Lusby, MD 20657',6185,222,NULL,38,8493,0);
INSERT INTO "django_geo_db_location" VALUES(14972,NULL,'Marbury, MD',6186,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14973,NULL,'Marbury, MD 20658',6186,222,NULL,38,8494,0);
INSERT INTO "django_geo_db_location" VALUES(14974,NULL,'Mechanicsville, MD',6187,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14975,NULL,'Mechanicsville, MD 20659',6187,222,NULL,38,8495,0);
INSERT INTO "django_geo_db_location" VALUES(14976,NULL,'Morganza, MD',6188,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14977,NULL,'Morganza, MD 20660',6188,222,NULL,38,8496,0);
INSERT INTO "django_geo_db_location" VALUES(14978,NULL,'Mount Victoria, MD',6189,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14979,NULL,'Mount Victoria, MD 20661',6189,222,NULL,38,8497,0);
INSERT INTO "django_geo_db_location" VALUES(14980,NULL,'Nanjemoy, MD',6190,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14981,NULL,'Nanjemoy, MD 20662',6190,222,NULL,38,8498,0);
INSERT INTO "django_geo_db_location" VALUES(14982,NULL,'Newburg, MD',6191,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14983,NULL,'Newburg, MD 20664',6191,222,NULL,38,8499,0);
INSERT INTO "django_geo_db_location" VALUES(14984,NULL,'Park Hall, MD',6192,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14985,NULL,'Park Hall, MD 20667',6192,222,NULL,38,8500,0);
INSERT INTO "django_geo_db_location" VALUES(14986,NULL,'Patuxent River, MD',6193,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14987,NULL,'Patuxent River, MD 20670',6193,222,NULL,38,8501,0);
INSERT INTO "django_geo_db_location" VALUES(14988,NULL,'Piney Point, MD',6194,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14989,NULL,'Piney Point, MD 20674',6194,222,NULL,38,8502,0);
INSERT INTO "django_geo_db_location" VALUES(14990,NULL,'Pomfret, MD',6195,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14991,NULL,'Pomfret, MD 20675',6195,222,NULL,38,8503,0);
INSERT INTO "django_geo_db_location" VALUES(14992,NULL,'Port Republic, MD',6196,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14993,NULL,'Port Republic, MD 20676',6196,222,NULL,38,8504,0);
INSERT INTO "django_geo_db_location" VALUES(14994,NULL,'Port Tobacco, MD',6197,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14995,NULL,'Port Tobacco, MD 20677',6197,222,NULL,38,8505,0);
INSERT INTO "django_geo_db_location" VALUES(14996,NULL,'Prince Frederick, MD',6198,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14997,NULL,'Prince Frederick, MD 20678',6198,222,NULL,38,8506,0);
INSERT INTO "django_geo_db_location" VALUES(14998,NULL,'Ridge, MD',6199,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(14999,NULL,'Ridge, MD 20680',6199,222,NULL,38,8507,0);
INSERT INTO "django_geo_db_location" VALUES(15000,NULL,'Rock Point, MD',6200,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15001,NULL,'Rock Point, MD 20682',6200,222,NULL,38,8508,0);
INSERT INTO "django_geo_db_location" VALUES(15002,NULL,'Saint Inigoes, MD',6201,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15003,NULL,'Saint Inigoes, MD 20684',6201,222,NULL,38,8509,0);
INSERT INTO "django_geo_db_location" VALUES(15004,NULL,'Saint Leonard, MD',6202,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15005,NULL,'Saint Leonard, MD 20685',6202,222,NULL,38,8510,0);
INSERT INTO "django_geo_db_location" VALUES(15006,NULL,'Saint Marys City, MD',6203,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15007,NULL,'Saint Marys City, MD 20686',6203,222,NULL,38,8511,0);
INSERT INTO "django_geo_db_location" VALUES(15008,NULL,'Scotland, MD',6204,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15009,NULL,'Scotland, MD 20687',6204,222,NULL,38,8512,0);
INSERT INTO "django_geo_db_location" VALUES(15010,NULL,'Solomons, MD',6205,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15011,NULL,'Solomons, MD 20688',6205,222,NULL,38,8513,0);
INSERT INTO "django_geo_db_location" VALUES(15012,NULL,'Sunderland, MD',6206,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15013,NULL,'Sunderland, MD 20689',6206,222,NULL,38,8514,0);
INSERT INTO "django_geo_db_location" VALUES(15014,NULL,'Tall Timbers, MD',6207,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15015,NULL,'Tall Timbers, MD 20690',6207,222,NULL,38,8515,0);
INSERT INTO "django_geo_db_location" VALUES(15016,NULL,'Valley Lee, MD',6208,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15017,NULL,'Valley Lee, MD 20692',6208,222,NULL,38,8516,0);
INSERT INTO "django_geo_db_location" VALUES(15018,NULL,'Welcome, MD',6209,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15019,NULL,'Welcome, MD 20693',6209,222,NULL,38,8517,0);
INSERT INTO "django_geo_db_location" VALUES(15020,NULL,'White Plains, MD',6210,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15021,NULL,'White Plains, MD 20695',6210,222,NULL,38,8518,0);
INSERT INTO "django_geo_db_location" VALUES(15022,NULL,'Southern Md Facility, MD',6211,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15023,NULL,'Southern Md Facility, MD 20697',6211,222,NULL,38,8519,0);
INSERT INTO "django_geo_db_location" VALUES(15024,NULL,'Annapolis Junction, MD',6212,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15025,NULL,'Annapolis Junction, MD 20701',6212,222,NULL,38,8520,0);
INSERT INTO "django_geo_db_location" VALUES(15026,NULL,'Lanham, MD',6213,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15027,NULL,'Lanham, MD 20703',6213,222,NULL,38,8521,0);
INSERT INTO "django_geo_db_location" VALUES(15028,NULL,'Beltsville, MD',6214,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15029,NULL,'Beltsville, MD 20704',6214,222,NULL,38,8522,0);
INSERT INTO "django_geo_db_location" VALUES(15030,NULL,'Beltsville, MD 20705',6214,222,NULL,38,8523,0);
INSERT INTO "django_geo_db_location" VALUES(15031,NULL,'Lanham, MD 20706',6213,222,NULL,38,8524,0);
INSERT INTO "django_geo_db_location" VALUES(15032,NULL,'Laurel, MD',6215,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15033,NULL,'Laurel, MD 20707',6215,222,NULL,38,8525,0);
INSERT INTO "django_geo_db_location" VALUES(15034,NULL,'Laurel, MD 20708',6215,222,NULL,38,8526,0);
INSERT INTO "django_geo_db_location" VALUES(15035,NULL,'Laurel, MD 20709',6215,222,NULL,38,8527,0);
INSERT INTO "django_geo_db_location" VALUES(15036,NULL,'Bladensburg, MD',6216,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15037,NULL,'Bladensburg, MD 20710',6216,222,NULL,38,8528,0);
INSERT INTO "django_geo_db_location" VALUES(15038,NULL,'Lothian, MD',6217,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15039,NULL,'Lothian, MD 20711',6217,222,NULL,38,8529,0);
INSERT INTO "django_geo_db_location" VALUES(15040,NULL,'Mount Rainier, MD',6218,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15041,NULL,'Mount Rainier, MD 20712',6218,222,NULL,38,8530,0);
INSERT INTO "django_geo_db_location" VALUES(15042,NULL,'North Beach, MD',6219,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15043,NULL,'North Beach, MD 20714',6219,222,NULL,38,8531,0);
INSERT INTO "django_geo_db_location" VALUES(15044,NULL,'Bowie, MD',6220,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15045,NULL,'Bowie, MD 20715',6220,222,NULL,38,8532,0);
INSERT INTO "django_geo_db_location" VALUES(15046,NULL,'Bowie, MD 20716',6220,222,NULL,38,8533,0);
INSERT INTO "django_geo_db_location" VALUES(15047,NULL,'Bowie, MD 20717',6220,222,NULL,38,8534,0);
INSERT INTO "django_geo_db_location" VALUES(15048,NULL,'Bowie, MD 20718',6220,222,NULL,38,8535,0);
INSERT INTO "django_geo_db_location" VALUES(15049,NULL,'Bowie, MD 20719',6220,222,NULL,38,8536,0);
INSERT INTO "django_geo_db_location" VALUES(15050,NULL,'Bowie, MD 20720',6220,222,NULL,38,8537,0);
INSERT INTO "django_geo_db_location" VALUES(15051,NULL,'Bowie, MD 20721',6220,222,NULL,38,8538,0);
INSERT INTO "django_geo_db_location" VALUES(15052,NULL,'Brentwood, MD',6221,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15053,NULL,'Brentwood, MD 20722',6221,222,NULL,38,8539,0);
INSERT INTO "django_geo_db_location" VALUES(15054,NULL,'Laurel, MD 20723',6215,222,NULL,38,8540,0);
INSERT INTO "django_geo_db_location" VALUES(15055,NULL,'Laurel, MD 20724',6215,222,NULL,38,8541,0);
INSERT INTO "django_geo_db_location" VALUES(15056,NULL,'Laurel, MD 20725',6215,222,NULL,38,8542,0);
INSERT INTO "django_geo_db_location" VALUES(15057,NULL,'Laurel, MD 20726',6215,222,NULL,38,8543,0);
INSERT INTO "django_geo_db_location" VALUES(15058,NULL,'Capitol Heights, MD',6222,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15059,NULL,'Capitol Heights, MD 20731',6222,222,NULL,38,8544,0);
INSERT INTO "django_geo_db_location" VALUES(15060,NULL,'Chesapeake Beach, MD',6223,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15061,NULL,'Chesapeake Beach, MD 20732',6223,222,NULL,38,8545,0);
INSERT INTO "django_geo_db_location" VALUES(15062,NULL,'Churchton, MD',6224,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15063,NULL,'Churchton, MD 20733',6224,222,NULL,38,8546,0);
INSERT INTO "django_geo_db_location" VALUES(15064,NULL,'Clinton, MD',6225,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15065,NULL,'Clinton, MD 20735',6225,222,NULL,38,8547,0);
INSERT INTO "django_geo_db_location" VALUES(15066,NULL,'Owings, MD',6226,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15067,NULL,'Owings, MD 20736',6226,222,NULL,38,8548,0);
INSERT INTO "django_geo_db_location" VALUES(15068,NULL,'Riverdale, MD',6227,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15069,NULL,'Riverdale, MD 20737',6227,222,NULL,38,8549,0);
INSERT INTO "django_geo_db_location" VALUES(15070,NULL,'Riverdale, MD 20738',6227,222,NULL,38,8550,0);
INSERT INTO "django_geo_db_location" VALUES(15071,NULL,'College Park, MD',6228,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15072,NULL,'College Park, MD 20740',6228,222,NULL,38,8551,0);
INSERT INTO "django_geo_db_location" VALUES(15073,NULL,'College Park, MD 20741',6228,222,NULL,38,8552,0);
INSERT INTO "django_geo_db_location" VALUES(15074,NULL,'College Park, MD 20742',6228,222,NULL,38,8553,0);
INSERT INTO "django_geo_db_location" VALUES(15075,NULL,'Capitol Heights, MD 20743',6222,222,NULL,38,8554,0);
INSERT INTO "django_geo_db_location" VALUES(15076,NULL,'Fort Washington, MD',6229,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15077,NULL,'Fort Washington, MD 20744',6229,222,NULL,38,8555,0);
INSERT INTO "django_geo_db_location" VALUES(15078,NULL,'Oxon Hill, MD',6230,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15079,NULL,'Oxon Hill, MD 20745',6230,222,NULL,38,8556,0);
INSERT INTO "django_geo_db_location" VALUES(15080,NULL,'Suitland, MD',6231,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15081,NULL,'Suitland, MD 20746',6231,222,NULL,38,8557,0);
INSERT INTO "django_geo_db_location" VALUES(15082,NULL,'District Heights, MD',6232,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15083,NULL,'District Heights, MD 20747',6232,222,NULL,38,8558,0);
INSERT INTO "django_geo_db_location" VALUES(15084,NULL,'Temple Hills, MD',6233,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15085,NULL,'Temple Hills, MD 20748',6233,222,NULL,38,8559,0);
INSERT INTO "django_geo_db_location" VALUES(15086,NULL,'Fort Washington, MD 20749',6229,222,NULL,38,8560,0);
INSERT INTO "django_geo_db_location" VALUES(15087,NULL,'Oxon Hill, MD 20750',6230,222,NULL,38,8561,0);
INSERT INTO "django_geo_db_location" VALUES(15088,NULL,'Deale, MD',6234,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15089,NULL,'Deale, MD 20751',6234,222,NULL,38,8562,0);
INSERT INTO "django_geo_db_location" VALUES(15090,NULL,'Suitland, MD 20752',6231,222,NULL,38,8563,0);
INSERT INTO "django_geo_db_location" VALUES(15091,NULL,'District Heights, MD 20753',6232,222,NULL,38,8564,0);
INSERT INTO "django_geo_db_location" VALUES(15092,NULL,'Dunkirk, MD',6235,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15093,NULL,'Dunkirk, MD 20754',6235,222,NULL,38,8565,0);
INSERT INTO "django_geo_db_location" VALUES(15094,NULL,'Fort George G Meade, MD',6236,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15095,NULL,'Fort George G Meade, MD 20755',6236,222,NULL,38,8566,0);
INSERT INTO "django_geo_db_location" VALUES(15096,NULL,'Temple Hills, MD 20757',6233,222,NULL,38,8567,0);
INSERT INTO "django_geo_db_location" VALUES(15097,NULL,'Friendship, MD',6237,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15098,NULL,'Friendship, MD 20758',6237,222,NULL,38,8568,0);
INSERT INTO "django_geo_db_location" VALUES(15099,NULL,'Fulton, MD',6238,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15100,NULL,'Fulton, MD 20759',6238,222,NULL,38,8569,0);
INSERT INTO "django_geo_db_location" VALUES(15101,NULL,'Andrews Air Force Base, MD',6239,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15102,NULL,'Andrews Air Force Base, MD 20762',6239,222,NULL,38,8570,0);
INSERT INTO "django_geo_db_location" VALUES(15103,NULL,'Savage, MD',6240,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15104,NULL,'Savage, MD 20763',6240,222,NULL,38,8571,0);
INSERT INTO "django_geo_db_location" VALUES(15105,NULL,'Shady Side, MD',6241,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15106,NULL,'Shady Side, MD 20764',6241,222,NULL,38,8572,0);
INSERT INTO "django_geo_db_location" VALUES(15107,NULL,'Galesville, MD',6242,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15108,NULL,'Galesville, MD 20765',6242,222,NULL,38,8573,0);
INSERT INTO "django_geo_db_location" VALUES(15109,NULL,'Greenbelt, MD',6243,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15110,NULL,'Greenbelt, MD 20768',6243,222,NULL,38,8574,0);
INSERT INTO "django_geo_db_location" VALUES(15111,NULL,'Glenn Dale, MD',6244,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15112,NULL,'Glenn Dale, MD 20769',6244,222,NULL,38,8575,0);
INSERT INTO "django_geo_db_location" VALUES(15113,NULL,'Greenbelt, MD 20770',6243,222,NULL,38,8576,0);
INSERT INTO "django_geo_db_location" VALUES(15114,NULL,'Greenbelt, MD 20771',6243,222,NULL,38,8577,0);
INSERT INTO "django_geo_db_location" VALUES(15115,NULL,'Upper Marlboro, MD',6245,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15116,NULL,'Upper Marlboro, MD 20772',6245,222,NULL,38,8578,0);
INSERT INTO "django_geo_db_location" VALUES(15117,NULL,'Upper Marlboro, MD 20773',6245,222,NULL,38,8579,0);
INSERT INTO "django_geo_db_location" VALUES(15118,NULL,'Upper Marlboro, MD 20774',6245,222,NULL,38,8580,0);
INSERT INTO "django_geo_db_location" VALUES(15119,NULL,'Upper Marlboro, MD 20775',6245,222,NULL,38,8581,0);
INSERT INTO "django_geo_db_location" VALUES(15120,NULL,'Harwood, MD',6246,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15121,NULL,'Harwood, MD 20776',6246,222,NULL,38,8582,0);
INSERT INTO "django_geo_db_location" VALUES(15122,NULL,'Highland, MD',6247,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15123,NULL,'Highland, MD 20777',6247,222,NULL,38,8583,0);
INSERT INTO "django_geo_db_location" VALUES(15124,NULL,'West River, MD',6248,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15125,NULL,'West River, MD 20778',6248,222,NULL,38,8584,0);
INSERT INTO "django_geo_db_location" VALUES(15126,NULL,'Tracys Landing, MD',6249,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15127,NULL,'Tracys Landing, MD 20779',6249,222,NULL,38,8585,0);
INSERT INTO "django_geo_db_location" VALUES(15128,NULL,'Hyattsville, MD',6250,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15129,NULL,'Hyattsville, MD 20781',6250,222,NULL,38,8586,0);
INSERT INTO "django_geo_db_location" VALUES(15130,NULL,'Hyattsville, MD 20782',6250,222,NULL,38,8587,0);
INSERT INTO "django_geo_db_location" VALUES(15131,NULL,'Hyattsville, MD 20783',6250,222,NULL,38,8588,0);
INSERT INTO "django_geo_db_location" VALUES(15132,NULL,'Hyattsville, MD 20784',6250,222,NULL,38,8589,0);
INSERT INTO "django_geo_db_location" VALUES(15133,NULL,'Hyattsville, MD 20785',6250,222,NULL,38,8590,0);
INSERT INTO "django_geo_db_location" VALUES(15134,NULL,'Hyattsville, MD 20787',6250,222,NULL,38,8591,0);
INSERT INTO "django_geo_db_location" VALUES(15135,NULL,'Hyattsville, MD 20788',6250,222,NULL,38,8592,0);
INSERT INTO "django_geo_db_location" VALUES(15136,NULL,'Capitol Heights, MD 20790',6222,222,NULL,38,8593,0);
INSERT INTO "django_geo_db_location" VALUES(15137,NULL,'Capitol Heights, MD 20791',6222,222,NULL,38,8594,0);
INSERT INTO "django_geo_db_location" VALUES(15138,NULL,'Jessup, MD',6251,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15139,NULL,'Jessup, MD 20794',6251,222,NULL,38,8595,0);
INSERT INTO "django_geo_db_location" VALUES(15140,NULL,'Southern Md Facility, MD 20797',6211,222,NULL,38,8596,0);
INSERT INTO "django_geo_db_location" VALUES(15141,NULL,'Capitol Heights, MD 20799',6222,222,NULL,38,8597,0);
INSERT INTO "django_geo_db_location" VALUES(15142,NULL,'Glen Echo, MD',6252,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15143,NULL,'Glen Echo, MD 20812',6252,222,NULL,38,8598,0);
INSERT INTO "django_geo_db_location" VALUES(15144,NULL,'Bethesda, MD',6253,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15145,NULL,'Bethesda, MD 20813',6253,222,NULL,38,8599,0);
INSERT INTO "django_geo_db_location" VALUES(15146,NULL,'Bethesda, MD 20814',6253,222,NULL,38,8600,0);
INSERT INTO "django_geo_db_location" VALUES(15147,NULL,'Chevy Chase, MD',6254,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15148,NULL,'Chevy Chase, MD 20815',6254,222,NULL,38,8601,0);
INSERT INTO "django_geo_db_location" VALUES(15149,NULL,'Bethesda, MD 20816',6253,222,NULL,38,8602,0);
INSERT INTO "django_geo_db_location" VALUES(15150,NULL,'Bethesda, MD 20817',6253,222,NULL,38,8603,0);
INSERT INTO "django_geo_db_location" VALUES(15151,NULL,'Cabin John, MD',6255,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15152,NULL,'Cabin John, MD 20818',6255,222,NULL,38,8604,0);
INSERT INTO "django_geo_db_location" VALUES(15153,NULL,'Bethesda, MD 20824',6253,222,NULL,38,8605,0);
INSERT INTO "django_geo_db_location" VALUES(15154,NULL,'Chevy Chase, MD 20825',6254,222,NULL,38,8606,0);
INSERT INTO "django_geo_db_location" VALUES(15155,NULL,'Bethesda, MD 20827',6253,222,NULL,38,8607,0);
INSERT INTO "django_geo_db_location" VALUES(15156,NULL,'Olney, MD',6256,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15157,NULL,'Olney, MD 20830',6256,222,NULL,38,8608,0);
INSERT INTO "django_geo_db_location" VALUES(15158,NULL,'Chesapeake Beach, MD 20831',6223,222,NULL,38,8609,0);
INSERT INTO "django_geo_db_location" VALUES(15159,NULL,'Olney, MD 20832',6256,222,NULL,38,8610,0);
INSERT INTO "django_geo_db_location" VALUES(15160,NULL,'Brookeville, MD',6257,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15161,NULL,'Brookeville, MD 20833',6257,222,NULL,38,8611,0);
INSERT INTO "django_geo_db_location" VALUES(15162,NULL,'Poolesville, MD',6258,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15163,NULL,'Poolesville, MD 20837',6258,222,NULL,38,8612,0);
INSERT INTO "django_geo_db_location" VALUES(15164,NULL,'Barnesville, MD',6259,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15165,NULL,'Barnesville, MD 20838',6259,222,NULL,38,8613,0);
INSERT INTO "django_geo_db_location" VALUES(15166,NULL,'Beallsville, MD',6260,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15167,NULL,'Beallsville, MD 20839',6260,222,NULL,38,8614,0);
INSERT INTO "django_geo_db_location" VALUES(15168,NULL,'Boyds, MD',6261,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15169,NULL,'Boyds, MD 20841',6261,222,NULL,38,8615,0);
INSERT INTO "django_geo_db_location" VALUES(15170,NULL,'Dickerson, MD',6262,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15171,NULL,'Dickerson, MD 20842',6262,222,NULL,38,8616,0);
INSERT INTO "django_geo_db_location" VALUES(15172,NULL,'Rockville, MD',6263,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15173,NULL,'Rockville, MD 20847',6263,222,NULL,38,8617,0);
INSERT INTO "django_geo_db_location" VALUES(15174,NULL,'Rockville, MD 20848',6263,222,NULL,38,8618,0);
INSERT INTO "django_geo_db_location" VALUES(15175,NULL,'Rockville, MD 20849',6263,222,NULL,38,8619,0);
INSERT INTO "django_geo_db_location" VALUES(15176,NULL,'Rockville, MD 20850',6263,222,NULL,38,8620,0);
INSERT INTO "django_geo_db_location" VALUES(15177,NULL,'Rockville, MD 20851',6263,222,NULL,38,8621,0);
INSERT INTO "django_geo_db_location" VALUES(15178,NULL,'Rockville, MD 20852',6263,222,NULL,38,8622,0);
INSERT INTO "django_geo_db_location" VALUES(15179,NULL,'Rockville, MD 20853',6263,222,NULL,38,8623,0);
INSERT INTO "django_geo_db_location" VALUES(15180,NULL,'Potomac, MD',6264,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15181,NULL,'Potomac, MD 20854',6264,222,NULL,38,8624,0);
INSERT INTO "django_geo_db_location" VALUES(15182,NULL,'Derwood, MD',6265,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15183,NULL,'Derwood, MD 20855',6265,222,NULL,38,8625,0);
INSERT INTO "django_geo_db_location" VALUES(15184,NULL,'Rockville, MD 20857',6263,222,NULL,38,8626,0);
INSERT INTO "django_geo_db_location" VALUES(15185,NULL,'Potomac, MD 20859',6264,222,NULL,38,8627,0);
INSERT INTO "django_geo_db_location" VALUES(15186,NULL,'Sandy Spring, MD',6266,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15187,NULL,'Sandy Spring, MD 20860',6266,222,NULL,38,8628,0);
INSERT INTO "django_geo_db_location" VALUES(15188,NULL,'Ashton, MD',6267,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15189,NULL,'Ashton, MD 20861',6267,222,NULL,38,8629,0);
INSERT INTO "django_geo_db_location" VALUES(15190,NULL,'Brinklow, MD',6268,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15191,NULL,'Brinklow, MD 20862',6268,222,NULL,38,8630,0);
INSERT INTO "django_geo_db_location" VALUES(15192,NULL,'Burtonsville, MD',6269,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15193,NULL,'Burtonsville, MD 20866',6269,222,NULL,38,8631,0);
INSERT INTO "django_geo_db_location" VALUES(15194,NULL,'Spencerville, MD',6270,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15195,NULL,'Spencerville, MD 20868',6270,222,NULL,38,8632,0);
INSERT INTO "django_geo_db_location" VALUES(15196,NULL,'Clarksburg, MD',6271,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15197,NULL,'Clarksburg, MD 20871',6271,222,NULL,38,8633,0);
INSERT INTO "django_geo_db_location" VALUES(15198,NULL,'Damascus, MD',6272,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15199,NULL,'Damascus, MD 20872',6272,222,NULL,38,8634,0);
INSERT INTO "django_geo_db_location" VALUES(15200,NULL,'Germantown, MD',6273,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15201,NULL,'Germantown, MD 20874',6273,222,NULL,38,8635,0);
INSERT INTO "django_geo_db_location" VALUES(15202,NULL,'Germantown, MD 20875',6273,222,NULL,38,8636,0);
INSERT INTO "django_geo_db_location" VALUES(15203,NULL,'Germantown, MD 20876',6273,222,NULL,38,8637,0);
INSERT INTO "django_geo_db_location" VALUES(15204,NULL,'Gaithersburg, MD',6274,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15205,NULL,'Gaithersburg, MD 20877',6274,222,NULL,38,8638,0);
INSERT INTO "django_geo_db_location" VALUES(15206,NULL,'Gaithersburg, MD 20878',6274,222,NULL,38,8639,0);
INSERT INTO "django_geo_db_location" VALUES(15207,NULL,'Gaithersburg, MD 20879',6274,222,NULL,38,8640,0);
INSERT INTO "django_geo_db_location" VALUES(15208,NULL,'Washington Grove, MD',6275,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15209,NULL,'Washington Grove, MD 20880',6275,222,NULL,38,8641,0);
INSERT INTO "django_geo_db_location" VALUES(15210,NULL,'Gaithersburg, MD 20882',6274,222,NULL,38,8642,0);
INSERT INTO "django_geo_db_location" VALUES(15211,NULL,'Gaithersburg, MD 20884',6274,222,NULL,38,8643,0);
INSERT INTO "django_geo_db_location" VALUES(15212,NULL,'Gaithersburg, MD 20885',6274,222,NULL,38,8644,0);
INSERT INTO "django_geo_db_location" VALUES(15213,NULL,'Montgomery Village, MD',6276,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15214,NULL,'Montgomery Village, MD 20886',6276,222,NULL,38,8645,0);
INSERT INTO "django_geo_db_location" VALUES(15215,NULL,'Bethesda, MD 20889',6253,222,NULL,38,8646,0);
INSERT INTO "django_geo_db_location" VALUES(15216,NULL,'Kensington, MD',6277,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15217,NULL,'Kensington, MD 20891',6277,222,NULL,38,8647,0);
INSERT INTO "django_geo_db_location" VALUES(15218,NULL,'Bethesda, MD 20892',6253,222,NULL,38,8648,0);
INSERT INTO "django_geo_db_location" VALUES(15219,NULL,'Bethesda, MD 20894',6253,222,NULL,38,8649,0);
INSERT INTO "django_geo_db_location" VALUES(15220,NULL,'Kensington, MD 20895',6277,222,NULL,38,8650,0);
INSERT INTO "django_geo_db_location" VALUES(15221,NULL,'Garrett Park, MD',6278,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15222,NULL,'Garrett Park, MD 20896',6278,222,NULL,38,8651,0);
INSERT INTO "django_geo_db_location" VALUES(15223,NULL,'Suburb Maryland Fac, MD',6279,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15224,NULL,'Suburb Maryland Fac, MD 20897',6279,222,NULL,38,8652,0);
INSERT INTO "django_geo_db_location" VALUES(15225,NULL,'Gaithersburg, MD 20898',6274,222,NULL,38,8653,0);
INSERT INTO "django_geo_db_location" VALUES(15226,NULL,'Gaithersburg, MD 20899',6274,222,NULL,38,8654,0);
INSERT INTO "django_geo_db_location" VALUES(15227,NULL,'Silver Spring, MD',6280,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15228,NULL,'Silver Spring, MD 20901',6280,222,NULL,38,8655,0);
INSERT INTO "django_geo_db_location" VALUES(15229,NULL,'Silver Spring, MD 20902',6280,222,NULL,38,8656,0);
INSERT INTO "django_geo_db_location" VALUES(15230,NULL,'Silver Spring, MD 20903',6280,222,NULL,38,8657,0);
INSERT INTO "django_geo_db_location" VALUES(15231,NULL,'Silver Spring, MD 20904',6280,222,NULL,38,8658,0);
INSERT INTO "django_geo_db_location" VALUES(15232,NULL,'Silver Spring, MD 20905',6280,222,NULL,38,8659,0);
INSERT INTO "django_geo_db_location" VALUES(15233,NULL,'Silver Spring, MD 20906',6280,222,NULL,38,8660,0);
INSERT INTO "django_geo_db_location" VALUES(15234,NULL,'Silver Spring, MD 20907',6280,222,NULL,38,8661,0);
INSERT INTO "django_geo_db_location" VALUES(15235,NULL,'Silver Spring, MD 20908',6280,222,NULL,38,8662,0);
INSERT INTO "django_geo_db_location" VALUES(15236,NULL,'Silver Spring, MD 20910',6280,222,NULL,38,8663,0);
INSERT INTO "django_geo_db_location" VALUES(15237,NULL,'Silver Spring, MD 20911',6280,222,NULL,38,8664,0);
INSERT INTO "django_geo_db_location" VALUES(15238,NULL,'Takoma Park, MD',6281,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15239,NULL,'Takoma Park, MD 20912',6281,222,NULL,38,8665,0);
INSERT INTO "django_geo_db_location" VALUES(15240,NULL,'Takoma Park, MD 20913',6281,222,NULL,38,8666,0);
INSERT INTO "django_geo_db_location" VALUES(15241,NULL,'Silver Spring, MD 20914',6280,222,NULL,38,8667,0);
INSERT INTO "django_geo_db_location" VALUES(15242,NULL,'Silver Spring, MD 20915',6280,222,NULL,38,8668,0);
INSERT INTO "django_geo_db_location" VALUES(15243,NULL,'Silver Spring, MD 20916',6280,222,NULL,38,8669,0);
INSERT INTO "django_geo_db_location" VALUES(15244,NULL,'Silver Spring, MD 20918',6280,222,NULL,38,8670,0);
INSERT INTO "django_geo_db_location" VALUES(15245,NULL,'Silver Spring, MD 20997',6280,222,NULL,38,8671,0);
INSERT INTO "django_geo_db_location" VALUES(15246,NULL,'Aberdeen, MD',6282,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15247,NULL,'Aberdeen, MD 21001',6282,222,NULL,38,8672,0);
INSERT INTO "django_geo_db_location" VALUES(15248,NULL,'Perryman, MD',6283,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15249,NULL,'Perryman, MD 21002',6283,222,NULL,38,8673,0);
INSERT INTO "django_geo_db_location" VALUES(15250,NULL,'Bel Air South, MD',6284,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15251,NULL,'Bel Air South, MD 21004',6284,222,NULL,38,8674,0);
INSERT INTO "django_geo_db_location" VALUES(15252,NULL,'Aberdeen Proving Ground, MD',6285,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15253,NULL,'Aberdeen Proving Ground, MD 21005',6285,222,NULL,38,8675,0);
INSERT INTO "django_geo_db_location" VALUES(15254,NULL,'Abingdon, MD',6286,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15255,NULL,'Abingdon, MD 21009',6286,222,NULL,38,8676,0);
INSERT INTO "django_geo_db_location" VALUES(15256,NULL,'Gunpowder, MD',6287,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15257,NULL,'Gunpowder, MD 21010',6287,222,NULL,38,8677,0);
INSERT INTO "django_geo_db_location" VALUES(15258,NULL,'Arnold, MD',6288,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15259,NULL,'Arnold, MD 21012',6288,222,NULL,38,8678,0);
INSERT INTO "django_geo_db_location" VALUES(15260,NULL,'Baldwin, MD',6289,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15261,NULL,'Baldwin, MD 21013',6289,222,NULL,38,8679,0);
INSERT INTO "django_geo_db_location" VALUES(15262,NULL,'Bel Air, MD',6290,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15263,NULL,'Bel Air, MD 21014',6290,222,NULL,38,8680,0);
INSERT INTO "django_geo_db_location" VALUES(15264,NULL,'Bel Air, MD 21015',6290,222,NULL,38,8681,0);
INSERT INTO "django_geo_db_location" VALUES(15265,NULL,'Belcamp, MD',6291,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15266,NULL,'Belcamp, MD 21017',6291,222,NULL,38,8682,0);
INSERT INTO "django_geo_db_location" VALUES(15267,NULL,'Benson, MD',6292,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15268,NULL,'Benson, MD 21018',6292,222,NULL,38,8683,0);
INSERT INTO "django_geo_db_location" VALUES(15269,NULL,'Boring, MD',6293,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15270,NULL,'Boring, MD 21020',6293,222,NULL,38,8684,0);
INSERT INTO "django_geo_db_location" VALUES(15271,NULL,'Brooklandville, MD',6294,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15272,NULL,'Brooklandville, MD 21022',6294,222,NULL,38,8685,0);
INSERT INTO "django_geo_db_location" VALUES(15273,NULL,'Butler, MD',6295,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15274,NULL,'Butler, MD 21023',6295,222,NULL,38,8686,0);
INSERT INTO "django_geo_db_location" VALUES(15275,NULL,'Chase, MD',6296,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15276,NULL,'Chase, MD 21027',6296,222,NULL,38,8687,0);
INSERT INTO "django_geo_db_location" VALUES(15277,NULL,'Churchville, MD',6297,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15278,NULL,'Churchville, MD 21028',6297,222,NULL,38,8688,0);
INSERT INTO "django_geo_db_location" VALUES(15279,NULL,'Clarksville, MD',6298,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15280,NULL,'Clarksville, MD 21029',6298,222,NULL,38,8689,0);
INSERT INTO "django_geo_db_location" VALUES(15281,NULL,'Cockeysville, MD',6299,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15282,NULL,'Cockeysville, MD 21030',6299,222,NULL,38,8690,0);
INSERT INTO "django_geo_db_location" VALUES(15283,NULL,'Hunt Valley, MD',6300,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15284,NULL,'Hunt Valley, MD 21031',6300,222,NULL,38,8691,0);
INSERT INTO "django_geo_db_location" VALUES(15285,NULL,'Crownsville, MD',6301,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15286,NULL,'Crownsville, MD 21032',6301,222,NULL,38,8692,0);
INSERT INTO "django_geo_db_location" VALUES(15287,NULL,'Darlington, MD',6302,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15288,NULL,'Darlington, MD 21034',6302,222,NULL,38,8693,0);
INSERT INTO "django_geo_db_location" VALUES(15289,NULL,'Davidsonville, MD',6303,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15290,NULL,'Davidsonville, MD 21035',6303,222,NULL,38,8694,0);
INSERT INTO "django_geo_db_location" VALUES(15291,NULL,'Dayton, MD',6304,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15292,NULL,'Dayton, MD 21036',6304,222,NULL,38,8695,0);
INSERT INTO "django_geo_db_location" VALUES(15293,NULL,'Edgewater, MD',6305,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15294,NULL,'Edgewater, MD 21037',6305,222,NULL,38,8696,0);
INSERT INTO "django_geo_db_location" VALUES(15295,NULL,'Edgewood, MD',6306,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15296,NULL,'Edgewood, MD 21040',6306,222,NULL,38,8697,0);
INSERT INTO "django_geo_db_location" VALUES(15297,NULL,'Ellicott City, MD',6307,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15298,NULL,'Ellicott City, MD 21041',6307,222,NULL,38,8698,0);
INSERT INTO "django_geo_db_location" VALUES(15299,NULL,'Ellicott City, MD 21042',6307,222,NULL,38,8699,0);
INSERT INTO "django_geo_db_location" VALUES(15300,NULL,'Ellicott City, MD 21043',6307,222,NULL,38,8700,0);
INSERT INTO "django_geo_db_location" VALUES(15301,NULL,'Columbia, MD',6308,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15302,NULL,'Columbia, MD 21044',6308,222,NULL,38,8701,0);
INSERT INTO "django_geo_db_location" VALUES(15303,NULL,'Columbia, MD 21045',6308,222,NULL,38,8702,0);
INSERT INTO "django_geo_db_location" VALUES(15304,NULL,'Columbia, MD 21046',6308,222,NULL,38,8703,0);
INSERT INTO "django_geo_db_location" VALUES(15305,NULL,'Fallston, MD',6309,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15306,NULL,'Fallston, MD 21047',6309,222,NULL,38,8704,0);
INSERT INTO "django_geo_db_location" VALUES(15307,NULL,'Finksburg, MD',6310,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15308,NULL,'Finksburg, MD 21048',6310,222,NULL,38,8705,0);
INSERT INTO "django_geo_db_location" VALUES(15309,NULL,'Forest Hill, MD',6311,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15310,NULL,'Forest Hill, MD 21050',6311,222,NULL,38,8706,0);
INSERT INTO "django_geo_db_location" VALUES(15311,NULL,'Fork, MD',6312,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15312,NULL,'Fork, MD 21051',6312,222,NULL,38,8707,0);
INSERT INTO "django_geo_db_location" VALUES(15313,NULL,'Fort Howard, MD',6313,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15314,NULL,'Fort Howard, MD 21052',6313,222,NULL,38,8708,0);
INSERT INTO "django_geo_db_location" VALUES(15315,NULL,'Freeland, MD',6314,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15316,NULL,'Freeland, MD 21053',6314,222,NULL,38,8709,0);
INSERT INTO "django_geo_db_location" VALUES(15317,NULL,'Gambrills, MD',6315,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15318,NULL,'Gambrills, MD 21054',6315,222,NULL,38,8710,0);
INSERT INTO "django_geo_db_location" VALUES(15319,NULL,'Garrison, MD',6316,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15320,NULL,'Garrison, MD 21055',6316,222,NULL,38,8711,0);
INSERT INTO "django_geo_db_location" VALUES(15321,NULL,'Gibson Island, MD',6317,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15322,NULL,'Gibson Island, MD 21056',6317,222,NULL,38,8712,0);
INSERT INTO "django_geo_db_location" VALUES(15323,NULL,'Glen Arm, MD',6318,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15324,NULL,'Glen Arm, MD 21057',6318,222,NULL,38,8713,0);
INSERT INTO "django_geo_db_location" VALUES(15325,NULL,'Glen Burnie, MD',6319,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15326,NULL,'Glen Burnie, MD 21060',6319,222,NULL,38,8714,0);
INSERT INTO "django_geo_db_location" VALUES(15327,NULL,'Glen Burnie, MD 21061',6319,222,NULL,38,8715,0);
INSERT INTO "django_geo_db_location" VALUES(15328,NULL,'Glen Burnie, MD 21062',6319,222,NULL,38,8716,0);
INSERT INTO "django_geo_db_location" VALUES(15329,NULL,'Glyndon, MD',6320,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15330,NULL,'Glyndon, MD 21071',6320,222,NULL,38,8717,0);
INSERT INTO "django_geo_db_location" VALUES(15331,NULL,'Hampstead, MD',6321,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15332,NULL,'Hampstead, MD 21074',6321,222,NULL,38,8718,0);
INSERT INTO "django_geo_db_location" VALUES(15333,NULL,'Elkridge, MD',6322,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15334,NULL,'Elkridge, MD 21075',6322,222,NULL,38,8719,0);
INSERT INTO "django_geo_db_location" VALUES(15335,NULL,'Hanover, MD',6323,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15336,NULL,'Hanover, MD 21076',6323,222,NULL,38,8720,0);
INSERT INTO "django_geo_db_location" VALUES(15337,NULL,'Harmans, MD',6324,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15338,NULL,'Harmans, MD 21077',6324,222,NULL,38,8721,0);
INSERT INTO "django_geo_db_location" VALUES(15339,NULL,'Havre De Grace, MD',6325,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15340,NULL,'Havre De Grace, MD 21078',6325,222,NULL,38,8722,0);
INSERT INTO "django_geo_db_location" VALUES(15341,NULL,'Henryton, MD',6326,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15342,NULL,'Henryton, MD 21080',6326,222,NULL,38,8723,0);
INSERT INTO "django_geo_db_location" VALUES(15343,NULL,'Hydes, MD',6327,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15344,NULL,'Hydes, MD 21082',6327,222,NULL,38,8724,0);
INSERT INTO "django_geo_db_location" VALUES(15345,NULL,'Jarrettsville, MD',6328,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15346,NULL,'Jarrettsville, MD 21084',6328,222,NULL,38,8725,0);
INSERT INTO "django_geo_db_location" VALUES(15347,NULL,'Joppa, MD',6329,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15348,NULL,'Joppa, MD 21085',6329,222,NULL,38,8726,0);
INSERT INTO "django_geo_db_location" VALUES(15349,NULL,'Kingsville, MD',6330,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15350,NULL,'Kingsville, MD 21087',6330,222,NULL,38,8727,0);
INSERT INTO "django_geo_db_location" VALUES(15351,NULL,'Lineboro, MD',6331,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15352,NULL,'Lineboro, MD 21088',6331,222,NULL,38,8728,0);
INSERT INTO "django_geo_db_location" VALUES(15353,NULL,'Linthicum Heights, MD',6332,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15354,NULL,'Linthicum Heights, MD 21090',6332,222,NULL,38,8729,0);
INSERT INTO "django_geo_db_location" VALUES(15355,NULL,'Long Green, MD',6333,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15356,NULL,'Long Green, MD 21092',6333,222,NULL,38,8730,0);
INSERT INTO "django_geo_db_location" VALUES(15357,NULL,'Lutherville Timonium, MD',6334,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15358,NULL,'Lutherville Timonium, MD 21093',6334,222,NULL,38,8731,0);
INSERT INTO "django_geo_db_location" VALUES(15359,NULL,'Lutherville Timonium, MD 21094',6334,222,NULL,38,8732,0);
INSERT INTO "django_geo_db_location" VALUES(15360,NULL,'Hanover, MD 21098',6323,222,NULL,38,8733,0);
INSERT INTO "django_geo_db_location" VALUES(15361,NULL,'Manchester, MD',6335,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15362,NULL,'Manchester, MD 21102',6335,222,NULL,38,8734,0);
INSERT INTO "django_geo_db_location" VALUES(15363,NULL,'Marriottsville, MD',6336,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15364,NULL,'Marriottsville, MD 21104',6336,222,NULL,38,8735,0);
INSERT INTO "django_geo_db_location" VALUES(15365,NULL,'Maryland Line, MD',6337,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15366,NULL,'Maryland Line, MD 21105',6337,222,NULL,38,8736,0);
INSERT INTO "django_geo_db_location" VALUES(15367,NULL,'Mayo, MD',6338,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15368,NULL,'Mayo, MD 21106',6338,222,NULL,38,8737,0);
INSERT INTO "django_geo_db_location" VALUES(15369,NULL,'Millersville, MD',6339,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15370,NULL,'Millersville, MD 21108',6339,222,NULL,38,8738,0);
INSERT INTO "django_geo_db_location" VALUES(15371,NULL,'Monkton, MD',6340,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15372,NULL,'Monkton, MD 21111',6340,222,NULL,38,8739,0);
INSERT INTO "django_geo_db_location" VALUES(15373,NULL,'Odenton, MD',6341,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15374,NULL,'Odenton, MD 21113',6341,222,NULL,38,8740,0);
INSERT INTO "django_geo_db_location" VALUES(15375,NULL,'Crofton, MD',6342,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15376,NULL,'Crofton, MD 21114',6342,222,NULL,38,8741,0);
INSERT INTO "django_geo_db_location" VALUES(15377,NULL,'Owings Mills, MD',6343,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15378,NULL,'Owings Mills, MD 21117',6343,222,NULL,38,8742,0);
INSERT INTO "django_geo_db_location" VALUES(15379,NULL,'Parkton, MD',6344,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15380,NULL,'Parkton, MD 21120',6344,222,NULL,38,8743,0);
INSERT INTO "django_geo_db_location" VALUES(15381,NULL,'Pasadena, MD',6345,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15382,NULL,'Pasadena, MD 21122',6345,222,NULL,38,8744,0);
INSERT INTO "django_geo_db_location" VALUES(15383,NULL,'Pasadena, MD 21123',6345,222,NULL,38,8745,0);
INSERT INTO "django_geo_db_location" VALUES(15384,NULL,'Perry Hall, MD',6346,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15385,NULL,'Perry Hall, MD 21128',6346,222,NULL,38,8746,0);
INSERT INTO "django_geo_db_location" VALUES(15386,NULL,'Perryman, MD 21130',6283,222,NULL,38,8747,0);
INSERT INTO "django_geo_db_location" VALUES(15387,NULL,'Phoenix, MD',6347,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15388,NULL,'Phoenix, MD 21131',6347,222,NULL,38,8748,0);
INSERT INTO "django_geo_db_location" VALUES(15389,NULL,'Pylesville, MD',6348,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15390,NULL,'Pylesville, MD 21132',6348,222,NULL,38,8749,0);
INSERT INTO "django_geo_db_location" VALUES(15391,NULL,'Randallstown, MD',6349,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15392,NULL,'Randallstown, MD 21133',6349,222,NULL,38,8750,0);
INSERT INTO "django_geo_db_location" VALUES(15393,NULL,'Reisterstown, MD',6350,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15394,NULL,'Reisterstown, MD 21136',6350,222,NULL,38,8751,0);
INSERT INTO "django_geo_db_location" VALUES(15395,NULL,'Riderwood, MD',6351,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15396,NULL,'Riderwood, MD 21139',6351,222,NULL,38,8752,0);
INSERT INTO "django_geo_db_location" VALUES(15397,NULL,'Riva, MD',6352,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15398,NULL,'Riva, MD 21140',6352,222,NULL,38,8753,0);
INSERT INTO "django_geo_db_location" VALUES(15399,NULL,'Severn, MD',6353,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15400,NULL,'Severn, MD 21144',6353,222,NULL,38,8754,0);
INSERT INTO "django_geo_db_location" VALUES(15401,NULL,'Severna Park, MD',6354,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15402,NULL,'Severna Park, MD 21146',6354,222,NULL,38,8755,0);
INSERT INTO "django_geo_db_location" VALUES(15403,NULL,'Simpsonville, MD',6355,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15404,NULL,'Simpsonville, MD 21150',6355,222,NULL,38,8756,0);
INSERT INTO "django_geo_db_location" VALUES(15405,NULL,'Sparks Glencoe, MD',6356,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15406,NULL,'Sparks Glencoe, MD 21152',6356,222,NULL,38,8757,0);
INSERT INTO "django_geo_db_location" VALUES(15407,NULL,'Stevenson, MD',6357,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15408,NULL,'Stevenson, MD 21153',6357,222,NULL,38,8758,0);
INSERT INTO "django_geo_db_location" VALUES(15409,NULL,'Street, MD',6358,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15410,NULL,'Street, MD 21154',6358,222,NULL,38,8759,0);
INSERT INTO "django_geo_db_location" VALUES(15411,NULL,'Upperco, MD',6359,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15412,NULL,'Upperco, MD 21155',6359,222,NULL,38,8760,0);
INSERT INTO "django_geo_db_location" VALUES(15413,NULL,'Upper Falls, MD',6360,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15414,NULL,'Upper Falls, MD 21156',6360,222,NULL,38,8761,0);
INSERT INTO "django_geo_db_location" VALUES(15415,NULL,'Westminster, MD',6361,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15416,NULL,'Westminster, MD 21157',6361,222,NULL,38,8762,0);
INSERT INTO "django_geo_db_location" VALUES(15417,NULL,'Westminster, MD 21158',6361,222,NULL,38,8763,0);
INSERT INTO "django_geo_db_location" VALUES(15418,NULL,'Whiteford, MD',6362,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15419,NULL,'Whiteford, MD 21160',6362,222,NULL,38,8764,0);
INSERT INTO "django_geo_db_location" VALUES(15420,NULL,'White Hall, MD',6363,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15421,NULL,'White Hall, MD 21161',6363,222,NULL,38,8765,0);
INSERT INTO "django_geo_db_location" VALUES(15422,NULL,'White Marsh, MD',6364,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15423,NULL,'White Marsh, MD 21162',6364,222,NULL,38,8766,0);
INSERT INTO "django_geo_db_location" VALUES(15424,NULL,'Woodstock, MD',6365,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15425,NULL,'Woodstock, MD 21163',6365,222,NULL,38,8767,0);
INSERT INTO "django_geo_db_location" VALUES(15426,NULL,'New Windsor, MD',6366,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15427,NULL,'New Windsor, MD 21176',6366,222,NULL,38,8768,0);
INSERT INTO "django_geo_db_location" VALUES(15428,NULL,'Baltimore, MD',6367,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15429,NULL,'Baltimore, MD 21201',6367,222,NULL,38,8769,0);
INSERT INTO "django_geo_db_location" VALUES(15430,NULL,'Baltimore, MD 21202',6367,222,NULL,38,8770,0);
INSERT INTO "django_geo_db_location" VALUES(15431,NULL,'Baltimore, MD 21203',6367,222,NULL,38,8771,0);
INSERT INTO "django_geo_db_location" VALUES(15432,NULL,'Towson, MD',6368,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15433,NULL,'Towson, MD 21204',6368,222,NULL,38,8772,0);
INSERT INTO "django_geo_db_location" VALUES(15434,NULL,'Baltimore, MD 21205',6367,222,NULL,38,8773,0);
INSERT INTO "django_geo_db_location" VALUES(15435,NULL,'Baltimore, MD 21206',6367,222,NULL,38,8774,0);
INSERT INTO "django_geo_db_location" VALUES(15436,NULL,'Gwynn Oak, MD',6369,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15437,NULL,'Gwynn Oak, MD 21207',6369,222,NULL,38,8775,0);
INSERT INTO "django_geo_db_location" VALUES(15438,NULL,'Pikesville, MD',6370,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15439,NULL,'Pikesville, MD 21208',6370,222,NULL,38,8776,0);
INSERT INTO "django_geo_db_location" VALUES(15440,NULL,'Baltimore, MD 21209',6367,222,NULL,38,8777,0);
INSERT INTO "django_geo_db_location" VALUES(15441,NULL,'Baltimore, MD 21210',6367,222,NULL,38,8778,0);
INSERT INTO "django_geo_db_location" VALUES(15442,NULL,'Baltimore, MD 21211',6367,222,NULL,38,8779,0);
INSERT INTO "django_geo_db_location" VALUES(15443,NULL,'Baltimore, MD 21212',6367,222,NULL,38,8780,0);
INSERT INTO "django_geo_db_location" VALUES(15444,NULL,'Baltimore, MD 21213',6367,222,NULL,38,8781,0);
INSERT INTO "django_geo_db_location" VALUES(15445,NULL,'Baltimore, MD 21214',6367,222,NULL,38,8782,0);
INSERT INTO "django_geo_db_location" VALUES(15446,NULL,'Baltimore, MD 21215',6367,222,NULL,38,8783,0);
INSERT INTO "django_geo_db_location" VALUES(15447,NULL,'Baltimore, MD 21216',6367,222,NULL,38,8784,0);
INSERT INTO "django_geo_db_location" VALUES(15448,NULL,'Baltimore, MD 21217',6367,222,NULL,38,8785,0);
INSERT INTO "django_geo_db_location" VALUES(15449,NULL,'Baltimore, MD 21218',6367,222,NULL,38,8786,0);
INSERT INTO "django_geo_db_location" VALUES(15450,NULL,'Sparrows Point, MD',6371,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15451,NULL,'Sparrows Point, MD 21219',6371,222,NULL,38,8787,0);
INSERT INTO "django_geo_db_location" VALUES(15452,NULL,'Middle River, MD',6372,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15453,NULL,'Middle River, MD 21220',6372,222,NULL,38,8788,0);
INSERT INTO "django_geo_db_location" VALUES(15454,NULL,'Essex, MD',6373,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15455,NULL,'Essex, MD 21221',6373,222,NULL,38,8789,0);
INSERT INTO "django_geo_db_location" VALUES(15456,NULL,'Dundalk, MD',6374,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15457,NULL,'Dundalk, MD 21222',6374,222,NULL,38,8790,0);
INSERT INTO "django_geo_db_location" VALUES(15458,NULL,'Baltimore, MD 21223',6367,222,NULL,38,8791,0);
INSERT INTO "django_geo_db_location" VALUES(15459,NULL,'Baltimore, MD 21224',6367,222,NULL,38,8792,0);
INSERT INTO "django_geo_db_location" VALUES(15460,NULL,'Brooklyn, MD',6375,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15461,NULL,'Brooklyn, MD 21225',6375,222,NULL,38,8793,0);
INSERT INTO "django_geo_db_location" VALUES(15462,NULL,'Curtis Bay, MD',6376,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15463,NULL,'Curtis Bay, MD 21226',6376,222,NULL,38,8794,0);
INSERT INTO "django_geo_db_location" VALUES(15464,NULL,'Halethorpe, MD',6377,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15465,NULL,'Halethorpe, MD 21227',6377,222,NULL,38,8795,0);
INSERT INTO "django_geo_db_location" VALUES(15466,NULL,'Catonsville, MD',6378,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15467,NULL,'Catonsville, MD 21228',6378,222,NULL,38,8796,0);
INSERT INTO "django_geo_db_location" VALUES(15468,NULL,'Baltimore, MD 21229',6367,222,NULL,38,8797,0);
INSERT INTO "django_geo_db_location" VALUES(15469,NULL,'Baltimore, MD 21230',6367,222,NULL,38,8798,0);
INSERT INTO "django_geo_db_location" VALUES(15470,NULL,'Baltimore, MD 21231',6367,222,NULL,38,8799,0);
INSERT INTO "django_geo_db_location" VALUES(15471,NULL,'Baltimore, MD 21233',6367,222,NULL,38,8800,0);
INSERT INTO "django_geo_db_location" VALUES(15472,NULL,'Parkville, MD',6379,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15473,NULL,'Parkville, MD 21234',6379,222,NULL,38,8801,0);
INSERT INTO "django_geo_db_location" VALUES(15474,NULL,'Baltimore, MD 21235',6367,222,NULL,38,8802,0);
INSERT INTO "django_geo_db_location" VALUES(15475,NULL,'Nottingham, MD',6380,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15476,NULL,'Nottingham, MD 21236',6380,222,NULL,38,8803,0);
INSERT INTO "django_geo_db_location" VALUES(15477,NULL,'Rosedale, MD',6381,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15478,NULL,'Rosedale, MD 21237',6381,222,NULL,38,8804,0);
INSERT INTO "django_geo_db_location" VALUES(15479,NULL,'Baltimore, MD 21239',6367,222,NULL,38,8805,0);
INSERT INTO "django_geo_db_location" VALUES(15480,NULL,'Baltimore, MD 21240',6367,222,NULL,38,8806,0);
INSERT INTO "django_geo_db_location" VALUES(15481,NULL,'Baltimore, MD 21241',6367,222,NULL,38,8807,0);
INSERT INTO "django_geo_db_location" VALUES(15482,NULL,'Windsor Mill, MD',6382,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15483,NULL,'Windsor Mill, MD 21244',6382,222,NULL,38,8808,0);
INSERT INTO "django_geo_db_location" VALUES(15484,NULL,'Baltimore, MD 21250',6367,222,NULL,38,8809,0);
INSERT INTO "django_geo_db_location" VALUES(15485,NULL,'Baltimore, MD 21251',6367,222,NULL,38,8810,0);
INSERT INTO "django_geo_db_location" VALUES(15486,NULL,'Baltimore, MD 21252',6367,222,NULL,38,8811,0);
INSERT INTO "django_geo_db_location" VALUES(15487,NULL,'Baltimore, MD 21260',6367,222,NULL,38,8812,0);
INSERT INTO "django_geo_db_location" VALUES(15488,NULL,'Baltimore, MD 21263',6367,222,NULL,38,8813,0);
INSERT INTO "django_geo_db_location" VALUES(15489,NULL,'Baltimore, MD 21264',6367,222,NULL,38,8814,0);
INSERT INTO "django_geo_db_location" VALUES(15490,NULL,'Baltimore, MD 21265',6367,222,NULL,38,8815,0);
INSERT INTO "django_geo_db_location" VALUES(15491,NULL,'Baltimore, MD 21268',6367,222,NULL,38,8816,0);
INSERT INTO "django_geo_db_location" VALUES(15492,NULL,'Baltimore, MD 21270',6367,222,NULL,38,8817,0);
INSERT INTO "django_geo_db_location" VALUES(15493,NULL,'Baltimore, MD 21273',6367,222,NULL,38,8818,0);
INSERT INTO "django_geo_db_location" VALUES(15494,NULL,'Baltimore, MD 21274',6367,222,NULL,38,8819,0);
INSERT INTO "django_geo_db_location" VALUES(15495,NULL,'Baltimore, MD 21275',6367,222,NULL,38,8820,0);
INSERT INTO "django_geo_db_location" VALUES(15496,NULL,'Baltimore, MD 21278',6367,222,NULL,38,8821,0);
INSERT INTO "django_geo_db_location" VALUES(15497,NULL,'Baltimore, MD 21279',6367,222,NULL,38,8822,0);
INSERT INTO "django_geo_db_location" VALUES(15498,NULL,'Baltimore, MD 21280',6367,222,NULL,38,8823,0);
INSERT INTO "django_geo_db_location" VALUES(15499,NULL,'Baltimore, MD 21281',6367,222,NULL,38,8824,0);
INSERT INTO "django_geo_db_location" VALUES(15500,NULL,'Baltimore, MD 21282',6367,222,NULL,38,8825,0);
INSERT INTO "django_geo_db_location" VALUES(15501,NULL,'Baltimore, MD 21283',6367,222,NULL,38,8826,0);
INSERT INTO "django_geo_db_location" VALUES(15502,NULL,'Baltimore, MD 21284',6367,222,NULL,38,8827,0);
INSERT INTO "django_geo_db_location" VALUES(15503,NULL,'Baltimore, MD 21285',6367,222,NULL,38,8828,0);
INSERT INTO "django_geo_db_location" VALUES(15504,NULL,'Towson, MD 21286',6368,222,NULL,38,8829,0);
INSERT INTO "django_geo_db_location" VALUES(15505,NULL,'Baltimore, MD 21287',6367,222,NULL,38,8830,0);
INSERT INTO "django_geo_db_location" VALUES(15506,NULL,'Baltimore, MD 21288',6367,222,NULL,38,8831,0);
INSERT INTO "django_geo_db_location" VALUES(15507,NULL,'Baltimore, MD 21289',6367,222,NULL,38,8832,0);
INSERT INTO "django_geo_db_location" VALUES(15508,NULL,'Baltimore, MD 21290',6367,222,NULL,38,8833,0);
INSERT INTO "django_geo_db_location" VALUES(15509,NULL,'Baltimore, MD 21297',6367,222,NULL,38,8834,0);
INSERT INTO "django_geo_db_location" VALUES(15510,NULL,'Baltimore, MD 21298',6367,222,NULL,38,8835,0);
INSERT INTO "django_geo_db_location" VALUES(15511,NULL,'Annapolis, MD',6383,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15512,NULL,'Annapolis, MD 21401',6383,222,NULL,38,8836,0);
INSERT INTO "django_geo_db_location" VALUES(15513,NULL,'Annapolis, MD 21402',6383,222,NULL,38,8837,0);
INSERT INTO "django_geo_db_location" VALUES(15514,NULL,'Annapolis, MD 21403',6383,222,NULL,38,8838,0);
INSERT INTO "django_geo_db_location" VALUES(15515,NULL,'Annapolis, MD 21404',6383,222,NULL,38,8839,0);
INSERT INTO "django_geo_db_location" VALUES(15516,NULL,'Annapolis, MD 21405',6383,222,NULL,38,8840,0);
INSERT INTO "django_geo_db_location" VALUES(15517,NULL,'Annapolis, MD 21411',6383,222,NULL,38,8841,0);
INSERT INTO "django_geo_db_location" VALUES(15518,NULL,'Annapolis, MD 21412',6383,222,NULL,38,8842,0);
INSERT INTO "django_geo_db_location" VALUES(15519,NULL,'Cumberland, MD',6384,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15520,NULL,'Cumberland, MD 21501',6384,222,NULL,38,8843,0);
INSERT INTO "django_geo_db_location" VALUES(15521,NULL,'Cumberland, MD 21502',6384,222,NULL,38,8844,0);
INSERT INTO "django_geo_db_location" VALUES(15522,NULL,'Cumberland, MD 21503',6384,222,NULL,38,8845,0);
INSERT INTO "django_geo_db_location" VALUES(15523,NULL,'Cumberland, MD 21504',6384,222,NULL,38,8846,0);
INSERT INTO "django_geo_db_location" VALUES(15524,NULL,'Cumberland, MD 21505',6384,222,NULL,38,8847,0);
INSERT INTO "django_geo_db_location" VALUES(15525,NULL,'Accident, MD',6385,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15526,NULL,'Accident, MD 21520',6385,222,NULL,38,8848,0);
INSERT INTO "django_geo_db_location" VALUES(15527,NULL,'Barton, MD',6386,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15528,NULL,'Barton, MD 21521',6386,222,NULL,38,8849,0);
INSERT INTO "django_geo_db_location" VALUES(15529,NULL,'Bittinger, MD',6387,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15530,NULL,'Bittinger, MD 21522',6387,222,NULL,38,8850,0);
INSERT INTO "django_geo_db_location" VALUES(15531,NULL,'Bloomington, MD',6388,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15532,NULL,'Bloomington, MD 21523',6388,222,NULL,38,8851,0);
INSERT INTO "django_geo_db_location" VALUES(15533,NULL,'Corriganville, MD',6389,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15534,NULL,'Corriganville, MD 21524',6389,222,NULL,38,8852,0);
INSERT INTO "django_geo_db_location" VALUES(15535,NULL,'Eckhart Mines, MD',6390,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15536,NULL,'Eckhart Mines, MD 21528',6390,222,NULL,38,8853,0);
INSERT INTO "django_geo_db_location" VALUES(15537,NULL,'Ellerslie, MD',6391,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15538,NULL,'Ellerslie, MD 21529',6391,222,NULL,38,8854,0);
INSERT INTO "django_geo_db_location" VALUES(15539,NULL,'Flintstone, MD',6392,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15540,NULL,'Flintstone, MD 21530',6392,222,NULL,38,8855,0);
INSERT INTO "django_geo_db_location" VALUES(15541,NULL,'Friendsville, MD',6393,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15542,NULL,'Friendsville, MD 21531',6393,222,NULL,38,8856,0);
INSERT INTO "django_geo_db_location" VALUES(15543,NULL,'Frostburg, MD',6394,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15544,NULL,'Frostburg, MD 21532',6394,222,NULL,38,8857,0);
INSERT INTO "django_geo_db_location" VALUES(15545,NULL,'Grantsville, MD',6395,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15546,NULL,'Grantsville, MD 21536',6395,222,NULL,38,8858,0);
INSERT INTO "django_geo_db_location" VALUES(15547,NULL,'Kitzmiller, MD',6396,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15548,NULL,'Kitzmiller, MD 21538',6396,222,NULL,38,8859,0);
INSERT INTO "django_geo_db_location" VALUES(15549,NULL,'Lonaconing, MD',6397,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15550,NULL,'Lonaconing, MD 21539',6397,222,NULL,38,8860,0);
INSERT INTO "django_geo_db_location" VALUES(15551,NULL,'Luke, MD',6398,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15552,NULL,'Luke, MD 21540',6398,222,NULL,38,8861,0);
INSERT INTO "django_geo_db_location" VALUES(15553,NULL,'McHenry, MD',6399,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15554,NULL,'McHenry, MD 21541',6399,222,NULL,38,8862,0);
INSERT INTO "django_geo_db_location" VALUES(15555,NULL,'Midland, MD',6400,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15556,NULL,'Midland, MD 21542',6400,222,NULL,38,8863,0);
INSERT INTO "django_geo_db_location" VALUES(15557,NULL,'Midlothian, MD',6401,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15558,NULL,'Midlothian, MD 21543',6401,222,NULL,38,8864,0);
INSERT INTO "django_geo_db_location" VALUES(15559,NULL,'Mount Savage, MD',6402,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15560,NULL,'Mount Savage, MD 21545',6402,222,NULL,38,8865,0);
INSERT INTO "django_geo_db_location" VALUES(15561,NULL,'Oakland, MD',6403,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15562,NULL,'Oakland, MD 21550',6403,222,NULL,38,8866,0);
INSERT INTO "django_geo_db_location" VALUES(15563,NULL,'Oldtown, MD',6404,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15564,NULL,'Oldtown, MD 21555',6404,222,NULL,38,8867,0);
INSERT INTO "django_geo_db_location" VALUES(15565,NULL,'Pinto, MD',6405,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15566,NULL,'Pinto, MD 21556',6405,222,NULL,38,8868,0);
INSERT INTO "django_geo_db_location" VALUES(15567,NULL,'Rawlings, MD',6406,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15568,NULL,'Rawlings, MD 21557',6406,222,NULL,38,8869,0);
INSERT INTO "django_geo_db_location" VALUES(15569,NULL,'Spring Gap, MD',6407,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15570,NULL,'Spring Gap, MD 21560',6407,222,NULL,38,8870,0);
INSERT INTO "django_geo_db_location" VALUES(15571,NULL,'Swanton, MD',6408,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15572,NULL,'Swanton, MD 21561',6408,222,NULL,38,8871,0);
INSERT INTO "django_geo_db_location" VALUES(15573,NULL,'Westernport, MD',6409,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15574,NULL,'Westernport, MD 21562',6409,222,NULL,38,8872,0);
INSERT INTO "django_geo_db_location" VALUES(15575,NULL,'Easton, MD',6410,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15576,NULL,'Easton, MD 21601',6410,222,NULL,38,8873,0);
INSERT INTO "django_geo_db_location" VALUES(15577,NULL,'Easton, MD 21606',6410,222,NULL,38,8874,0);
INSERT INTO "django_geo_db_location" VALUES(15578,NULL,'Barclay, MD',6411,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15579,NULL,'Barclay, MD 21607',6411,222,NULL,38,8875,0);
INSERT INTO "django_geo_db_location" VALUES(15580,NULL,'Bethlehem, MD',6412,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15581,NULL,'Bethlehem, MD 21609',6412,222,NULL,38,8876,0);
INSERT INTO "django_geo_db_location" VALUES(15582,NULL,'Betterton, MD',6413,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15583,NULL,'Betterton, MD 21610',6413,222,NULL,38,8877,0);
INSERT INTO "django_geo_db_location" VALUES(15584,NULL,'Bozman, MD',6414,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15585,NULL,'Bozman, MD 21612',6414,222,NULL,38,8878,0);
INSERT INTO "django_geo_db_location" VALUES(15586,NULL,'Cambridge, MD',6415,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15587,NULL,'Cambridge, MD 21613',6415,222,NULL,38,8879,0);
INSERT INTO "django_geo_db_location" VALUES(15588,NULL,'Centreville, MD',6416,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15589,NULL,'Centreville, MD 21617',6416,222,NULL,38,8880,0);
INSERT INTO "django_geo_db_location" VALUES(15590,NULL,'Chester, MD',6417,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15591,NULL,'Chester, MD 21619',6417,222,NULL,38,8881,0);
INSERT INTO "django_geo_db_location" VALUES(15592,NULL,'Chestertown, MD',6418,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15593,NULL,'Chestertown, MD 21620',6418,222,NULL,38,8882,0);
INSERT INTO "django_geo_db_location" VALUES(15594,NULL,'Church Creek, MD',6419,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15595,NULL,'Church Creek, MD 21622',6419,222,NULL,38,8883,0);
INSERT INTO "django_geo_db_location" VALUES(15596,NULL,'Church Hill, MD',6420,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15597,NULL,'Church Hill, MD 21623',6420,222,NULL,38,8884,0);
INSERT INTO "django_geo_db_location" VALUES(15598,NULL,'Claiborne, MD',6421,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15599,NULL,'Claiborne, MD 21624',6421,222,NULL,38,8885,0);
INSERT INTO "django_geo_db_location" VALUES(15600,NULL,'Cordova, MD',6422,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15601,NULL,'Cordova, MD 21625',6422,222,NULL,38,8886,0);
INSERT INTO "django_geo_db_location" VALUES(15602,NULL,'Crapo, MD',6423,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15603,NULL,'Crapo, MD 21626',6423,222,NULL,38,8887,0);
INSERT INTO "django_geo_db_location" VALUES(15604,NULL,'Crocheron, MD',6424,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15605,NULL,'Crocheron, MD 21627',6424,222,NULL,38,8888,0);
INSERT INTO "django_geo_db_location" VALUES(15606,NULL,'Crumpton, MD',6425,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15607,NULL,'Crumpton, MD 21628',6425,222,NULL,38,8889,0);
INSERT INTO "django_geo_db_location" VALUES(15608,NULL,'Denton, MD',6426,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15609,NULL,'Denton, MD 21629',6426,222,NULL,38,8890,0);
INSERT INTO "django_geo_db_location" VALUES(15610,NULL,'East New Market, MD',6427,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15611,NULL,'East New Market, MD 21631',6427,222,NULL,38,8891,0);
INSERT INTO "django_geo_db_location" VALUES(15612,NULL,'Federalsburg, MD',6428,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15613,NULL,'Federalsburg, MD 21632',6428,222,NULL,38,8892,0);
INSERT INTO "django_geo_db_location" VALUES(15614,NULL,'Fishing Creek, MD',6429,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15615,NULL,'Fishing Creek, MD 21634',6429,222,NULL,38,8893,0);
INSERT INTO "django_geo_db_location" VALUES(15616,NULL,'Galena, MD',6430,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15617,NULL,'Galena, MD 21635',6430,222,NULL,38,8894,0);
INSERT INTO "django_geo_db_location" VALUES(15618,NULL,'Goldsboro, MD',6431,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15619,NULL,'Goldsboro, MD 21636',6431,222,NULL,38,8895,0);
INSERT INTO "django_geo_db_location" VALUES(15620,NULL,'Grasonville, MD',6432,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15621,NULL,'Grasonville, MD 21638',6432,222,NULL,38,8896,0);
INSERT INTO "django_geo_db_location" VALUES(15622,NULL,'Greensboro, MD',6433,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15623,NULL,'Greensboro, MD 21639',6433,222,NULL,38,8897,0);
INSERT INTO "django_geo_db_location" VALUES(15624,NULL,'Henderson, MD',6434,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15625,NULL,'Henderson, MD 21640',6434,222,NULL,38,8898,0);
INSERT INTO "django_geo_db_location" VALUES(15626,NULL,'Hillsboro, MD',6435,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15627,NULL,'Hillsboro, MD 21641',6435,222,NULL,38,8899,0);
INSERT INTO "django_geo_db_location" VALUES(15628,NULL,'Hurlock, MD',6436,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15629,NULL,'Hurlock, MD 21643',6436,222,NULL,38,8900,0);
INSERT INTO "django_geo_db_location" VALUES(15630,NULL,'Ingleside, MD',6437,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15631,NULL,'Ingleside, MD 21644',6437,222,NULL,38,8901,0);
INSERT INTO "django_geo_db_location" VALUES(15632,NULL,'Kennedyville, MD',6438,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15633,NULL,'Kennedyville, MD 21645',6438,222,NULL,38,8902,0);
INSERT INTO "django_geo_db_location" VALUES(15634,NULL,'Mcdaniel, MD',6439,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15635,NULL,'Mcdaniel, MD 21647',6439,222,NULL,38,8903,0);
INSERT INTO "django_geo_db_location" VALUES(15636,NULL,'Madison, MD',6440,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15637,NULL,'Madison, MD 21648',6440,222,NULL,38,8904,0);
INSERT INTO "django_geo_db_location" VALUES(15638,NULL,'Marydel, MD',6441,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15639,NULL,'Marydel, MD 21649',6441,222,NULL,38,8905,0);
INSERT INTO "django_geo_db_location" VALUES(15640,NULL,'Massey, MD',6442,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15641,NULL,'Massey, MD 21650',6442,222,NULL,38,8906,0);
INSERT INTO "django_geo_db_location" VALUES(15642,NULL,'Millington, MD',6443,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15643,NULL,'Millington, MD 21651',6443,222,NULL,38,8907,0);
INSERT INTO "django_geo_db_location" VALUES(15644,NULL,'Neavitt, MD',6444,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15645,NULL,'Neavitt, MD 21652',6444,222,NULL,38,8908,0);
INSERT INTO "django_geo_db_location" VALUES(15646,NULL,'Newcomb, MD',6445,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15647,NULL,'Newcomb, MD 21653',6445,222,NULL,38,8909,0);
INSERT INTO "django_geo_db_location" VALUES(15648,NULL,'Oxford, MD',6446,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15649,NULL,'Oxford, MD 21654',6446,222,NULL,38,8910,0);
INSERT INTO "django_geo_db_location" VALUES(15650,NULL,'Preston, MD',6447,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15651,NULL,'Preston, MD 21655',6447,222,NULL,38,8911,0);
INSERT INTO "django_geo_db_location" VALUES(15652,NULL,'Price, MD',6448,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15653,NULL,'Price, MD 21656',6448,222,NULL,38,8912,0);
INSERT INTO "django_geo_db_location" VALUES(15654,NULL,'Queen Anne, MD',6449,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15655,NULL,'Queen Anne, MD 21657',6449,222,NULL,38,8913,0);
INSERT INTO "django_geo_db_location" VALUES(15656,NULL,'Queenstown, MD',6450,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15657,NULL,'Queenstown, MD 21658',6450,222,NULL,38,8914,0);
INSERT INTO "django_geo_db_location" VALUES(15658,NULL,'Rhodesdale, MD',6451,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15659,NULL,'Rhodesdale, MD 21659',6451,222,NULL,38,8915,0);
INSERT INTO "django_geo_db_location" VALUES(15660,NULL,'Ridgely, MD',6452,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15661,NULL,'Ridgely, MD 21660',6452,222,NULL,38,8916,0);
INSERT INTO "django_geo_db_location" VALUES(15662,NULL,'Rock Hall, MD',6453,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15663,NULL,'Rock Hall, MD 21661',6453,222,NULL,38,8917,0);
INSERT INTO "django_geo_db_location" VALUES(15664,NULL,'Royal Oak, MD',6454,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15665,NULL,'Royal Oak, MD 21662',6454,222,NULL,38,8918,0);
INSERT INTO "django_geo_db_location" VALUES(15666,NULL,'Saint Michaels, MD',6455,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15667,NULL,'Saint Michaels, MD 21663',6455,222,NULL,38,8919,0);
INSERT INTO "django_geo_db_location" VALUES(15668,NULL,'Secretary, MD',6456,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15669,NULL,'Secretary, MD 21664',6456,222,NULL,38,8920,0);
INSERT INTO "django_geo_db_location" VALUES(15670,NULL,'Sherwood, MD',6457,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15671,NULL,'Sherwood, MD 21665',6457,222,NULL,38,8921,0);
INSERT INTO "django_geo_db_location" VALUES(15672,NULL,'Stevensville, MD',6458,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15673,NULL,'Stevensville, MD 21666',6458,222,NULL,38,8922,0);
INSERT INTO "django_geo_db_location" VALUES(15674,NULL,'Still Pond, MD',6459,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15675,NULL,'Still Pond, MD 21667',6459,222,NULL,38,8923,0);
INSERT INTO "django_geo_db_location" VALUES(15676,NULL,'Sudlersville, MD',6460,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15677,NULL,'Sudlersville, MD 21668',6460,222,NULL,38,8924,0);
INSERT INTO "django_geo_db_location" VALUES(15678,NULL,'Taylors Island, MD',6461,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15679,NULL,'Taylors Island, MD 21669',6461,222,NULL,38,8925,0);
INSERT INTO "django_geo_db_location" VALUES(15680,NULL,'Templeville, MD',6462,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15681,NULL,'Templeville, MD 21670',6462,222,NULL,38,8926,0);
INSERT INTO "django_geo_db_location" VALUES(15682,NULL,'Tilghman, MD',6463,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15683,NULL,'Tilghman, MD 21671',6463,222,NULL,38,8927,0);
INSERT INTO "django_geo_db_location" VALUES(15684,NULL,'Toddville, MD',6464,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15685,NULL,'Toddville, MD 21672',6464,222,NULL,38,8928,0);
INSERT INTO "django_geo_db_location" VALUES(15686,NULL,'Trappe, MD',6465,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15687,NULL,'Trappe, MD 21673',6465,222,NULL,38,8929,0);
INSERT INTO "django_geo_db_location" VALUES(15688,NULL,'Wingate, MD',6466,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15689,NULL,'Wingate, MD 21675',6466,222,NULL,38,8930,0);
INSERT INTO "django_geo_db_location" VALUES(15690,NULL,'Wittman, MD',6467,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15691,NULL,'Wittman, MD 21676',6467,222,NULL,38,8931,0);
INSERT INTO "django_geo_db_location" VALUES(15692,NULL,'Woolford, MD',6468,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15693,NULL,'Woolford, MD 21677',6468,222,NULL,38,8932,0);
INSERT INTO "django_geo_db_location" VALUES(15694,NULL,'Worton, MD',6469,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15695,NULL,'Worton, MD 21678',6469,222,NULL,38,8933,0);
INSERT INTO "django_geo_db_location" VALUES(15696,NULL,'Wye Mills, MD',6470,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15697,NULL,'Wye Mills, MD 21679',6470,222,NULL,38,8934,0);
INSERT INTO "django_geo_db_location" VALUES(15698,NULL,'Ridgely, MD 21681',6452,222,NULL,38,8935,0);
INSERT INTO "django_geo_db_location" VALUES(15699,NULL,'Ridgely, MD 21682',6452,222,NULL,38,8936,0);
INSERT INTO "django_geo_db_location" VALUES(15700,NULL,'Ridgely, MD 21683',6452,222,NULL,38,8937,0);
INSERT INTO "django_geo_db_location" VALUES(15701,NULL,'Ridgely, MD 21684',6452,222,NULL,38,8938,0);
INSERT INTO "django_geo_db_location" VALUES(15702,NULL,'Ridgely, MD 21685',6452,222,NULL,38,8939,0);
INSERT INTO "django_geo_db_location" VALUES(15703,NULL,'Ridgely, MD 21686',6452,222,NULL,38,8940,0);
INSERT INTO "django_geo_db_location" VALUES(15704,NULL,'Ridgely, MD 21687',6452,222,NULL,38,8941,0);
INSERT INTO "django_geo_db_location" VALUES(15705,NULL,'Ridgely, MD 21688',6452,222,NULL,38,8942,0);
INSERT INTO "django_geo_db_location" VALUES(15706,NULL,'Chestertown, MD 21690',6418,222,NULL,38,8943,0);
INSERT INTO "django_geo_db_location" VALUES(15707,NULL,'Frederick, MD',6471,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15708,NULL,'Frederick, MD 21701',6471,222,NULL,38,8944,0);
INSERT INTO "django_geo_db_location" VALUES(15709,NULL,'Frederick, MD 21702',6471,222,NULL,38,8945,0);
INSERT INTO "django_geo_db_location" VALUES(15710,NULL,'Frederick, MD 21703',6471,222,NULL,38,8946,0);
INSERT INTO "django_geo_db_location" VALUES(15711,NULL,'Frederick, MD 21704',6471,222,NULL,38,8947,0);
INSERT INTO "django_geo_db_location" VALUES(15712,NULL,'Frederick, MD 21705',6471,222,NULL,38,8948,0);
INSERT INTO "django_geo_db_location" VALUES(15713,NULL,'Frederick, MD 21709',6471,222,NULL,38,8949,0);
INSERT INTO "django_geo_db_location" VALUES(15714,NULL,'Adamstown, MD',6472,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15715,NULL,'Adamstown, MD 21710',6472,222,NULL,38,8950,0);
INSERT INTO "django_geo_db_location" VALUES(15716,NULL,'Big Pool, MD',6473,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15717,NULL,'Big Pool, MD 21711',6473,222,NULL,38,8951,0);
INSERT INTO "django_geo_db_location" VALUES(15718,NULL,'Boonsboro, MD',6474,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15719,NULL,'Boonsboro, MD 21713',6474,222,NULL,38,8952,0);
INSERT INTO "django_geo_db_location" VALUES(15720,NULL,'Braddock Heights, MD',6475,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15721,NULL,'Braddock Heights, MD 21714',6475,222,NULL,38,8953,0);
INSERT INTO "django_geo_db_location" VALUES(15722,NULL,'Brownsville, MD',6476,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15723,NULL,'Brownsville, MD 21715',6476,222,NULL,38,8954,0);
INSERT INTO "django_geo_db_location" VALUES(15724,NULL,'Brunswick, MD',6477,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15725,NULL,'Brunswick, MD 21716',6477,222,NULL,38,8955,0);
INSERT INTO "django_geo_db_location" VALUES(15726,NULL,'Buckeystown, MD',6478,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15727,NULL,'Buckeystown, MD 21717',6478,222,NULL,38,8956,0);
INSERT INTO "django_geo_db_location" VALUES(15728,NULL,'Burkittsville, MD',6479,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15729,NULL,'Burkittsville, MD 21718',6479,222,NULL,38,8957,0);
INSERT INTO "django_geo_db_location" VALUES(15730,NULL,'Cascade, MD',6480,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15731,NULL,'Cascade, MD 21719',6480,222,NULL,38,8958,0);
INSERT INTO "django_geo_db_location" VALUES(15732,NULL,'Cavetown, MD',6481,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15733,NULL,'Cavetown, MD 21720',6481,222,NULL,38,8959,0);
INSERT INTO "django_geo_db_location" VALUES(15734,NULL,'Chewsville, MD',6482,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15735,NULL,'Chewsville, MD 21721',6482,222,NULL,38,8960,0);
INSERT INTO "django_geo_db_location" VALUES(15736,NULL,'Clear Spring, MD',6483,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15737,NULL,'Clear Spring, MD 21722',6483,222,NULL,38,8961,0);
INSERT INTO "django_geo_db_location" VALUES(15738,NULL,'Cooksville, MD',6484,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15739,NULL,'Cooksville, MD 21723',6484,222,NULL,38,8962,0);
INSERT INTO "django_geo_db_location" VALUES(15740,NULL,'Emmitsburg, MD',6485,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15741,NULL,'Emmitsburg, MD 21727',6485,222,NULL,38,8963,0);
INSERT INTO "django_geo_db_location" VALUES(15742,NULL,'Fairplay, MD',6486,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15743,NULL,'Fairplay, MD 21733',6486,222,NULL,38,8964,0);
INSERT INTO "django_geo_db_location" VALUES(15744,NULL,'Funkstown, MD',6487,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15745,NULL,'Funkstown, MD 21734',6487,222,NULL,38,8965,0);
INSERT INTO "django_geo_db_location" VALUES(15746,NULL,'Gapland, MD',6488,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15747,NULL,'Gapland, MD 21736',6488,222,NULL,38,8966,0);
INSERT INTO "django_geo_db_location" VALUES(15748,NULL,'Glenelg, MD',6489,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15749,NULL,'Glenelg, MD 21737',6489,222,NULL,38,8967,0);
INSERT INTO "django_geo_db_location" VALUES(15750,NULL,'Glenwood, MD',6490,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15751,NULL,'Glenwood, MD 21738',6490,222,NULL,38,8968,0);
INSERT INTO "django_geo_db_location" VALUES(15752,NULL,'Hagerstown, MD',6491,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15753,NULL,'Hagerstown, MD 21740',6491,222,NULL,38,8969,0);
INSERT INTO "django_geo_db_location" VALUES(15754,NULL,'Hagerstown, MD 21741',6491,222,NULL,38,8970,0);
INSERT INTO "django_geo_db_location" VALUES(15755,NULL,'Hagerstown, MD 21742',6491,222,NULL,38,8971,0);
INSERT INTO "django_geo_db_location" VALUES(15756,NULL,'Hagerstown, MD 21746',6491,222,NULL,38,8972,0);
INSERT INTO "django_geo_db_location" VALUES(15757,NULL,'Hagerstown, MD 21747',6491,222,NULL,38,8973,0);
INSERT INTO "django_geo_db_location" VALUES(15758,NULL,'Hagerstown, MD 21748',6491,222,NULL,38,8974,0);
INSERT INTO "django_geo_db_location" VALUES(15759,NULL,'Hagerstown, MD 21749',6491,222,NULL,38,8975,0);
INSERT INTO "django_geo_db_location" VALUES(15760,NULL,'Hancock, MD',6492,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15761,NULL,'Hancock, MD 21750',6492,222,NULL,38,8976,0);
INSERT INTO "django_geo_db_location" VALUES(15762,NULL,'Ijamsville, MD',6493,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15763,NULL,'Ijamsville, MD 21754',6493,222,NULL,38,8977,0);
INSERT INTO "django_geo_db_location" VALUES(15764,NULL,'Jefferson, MD',6494,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15765,NULL,'Jefferson, MD 21755',6494,222,NULL,38,8978,0);
INSERT INTO "django_geo_db_location" VALUES(15766,NULL,'Keedysville, MD',6495,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15767,NULL,'Keedysville, MD 21756',6495,222,NULL,38,8979,0);
INSERT INTO "django_geo_db_location" VALUES(15768,NULL,'Keymar, MD',6496,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15769,NULL,'Keymar, MD 21757',6496,222,NULL,38,8980,0);
INSERT INTO "django_geo_db_location" VALUES(15770,NULL,'Knoxville, MD',6497,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15771,NULL,'Knoxville, MD 21758',6497,222,NULL,38,8981,0);
INSERT INTO "django_geo_db_location" VALUES(15772,NULL,'Ladiesburg, MD',6498,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15773,NULL,'Ladiesburg, MD 21759',6498,222,NULL,38,8982,0);
INSERT INTO "django_geo_db_location" VALUES(15774,NULL,'Libertytown, MD',6499,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15775,NULL,'Libertytown, MD 21762',6499,222,NULL,38,8983,0);
INSERT INTO "django_geo_db_location" VALUES(15776,NULL,'Linwood, MD',6500,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15777,NULL,'Linwood, MD 21764',6500,222,NULL,38,8984,0);
INSERT INTO "django_geo_db_location" VALUES(15778,NULL,'Lisbon, MD',6501,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15779,NULL,'Lisbon, MD 21765',6501,222,NULL,38,8985,0);
INSERT INTO "django_geo_db_location" VALUES(15780,NULL,'Little Orleans, MD',6502,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15781,NULL,'Little Orleans, MD 21766',6502,222,NULL,38,8986,0);
INSERT INTO "django_geo_db_location" VALUES(15782,NULL,'Maugansville, MD',6503,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15783,NULL,'Maugansville, MD 21767',6503,222,NULL,38,8987,0);
INSERT INTO "django_geo_db_location" VALUES(15784,NULL,'Middletown, MD',6504,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15785,NULL,'Middletown, MD 21769',6504,222,NULL,38,8988,0);
INSERT INTO "django_geo_db_location" VALUES(15786,NULL,'Monrovia, MD',6505,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15787,NULL,'Monrovia, MD 21770',6505,222,NULL,38,8989,0);
INSERT INTO "django_geo_db_location" VALUES(15788,NULL,'Mount Airy, MD',6506,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15789,NULL,'Mount Airy, MD 21771',6506,222,NULL,38,8990,0);
INSERT INTO "django_geo_db_location" VALUES(15790,NULL,'Myersville, MD',6507,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15791,NULL,'Myersville, MD 21773',6507,222,NULL,38,8991,0);
INSERT INTO "django_geo_db_location" VALUES(15792,NULL,'New Market, MD',6508,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15793,NULL,'New Market, MD 21774',6508,222,NULL,38,8992,0);
INSERT INTO "django_geo_db_location" VALUES(15794,NULL,'New Midway, MD',6509,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15795,NULL,'New Midway, MD 21775',6509,222,NULL,38,8993,0);
INSERT INTO "django_geo_db_location" VALUES(15796,NULL,'New Windsor, MD 21776',6366,222,NULL,38,8994,0);
INSERT INTO "django_geo_db_location" VALUES(15797,NULL,'Point Of Rocks, MD',6510,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15798,NULL,'Point Of Rocks, MD 21777',6510,222,NULL,38,8995,0);
INSERT INTO "django_geo_db_location" VALUES(15799,NULL,'Rocky Ridge, MD',6511,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15800,NULL,'Rocky Ridge, MD 21778',6511,222,NULL,38,8996,0);
INSERT INTO "django_geo_db_location" VALUES(15801,NULL,'Rohrersville, MD',6512,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15802,NULL,'Rohrersville, MD 21779',6512,222,NULL,38,8997,0);
INSERT INTO "django_geo_db_location" VALUES(15803,NULL,'Sabillasville, MD',6513,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15804,NULL,'Sabillasville, MD 21780',6513,222,NULL,38,8998,0);
INSERT INTO "django_geo_db_location" VALUES(15805,NULL,'Saint James, MD',6514,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15806,NULL,'Saint James, MD 21781',6514,222,NULL,38,8999,0);
INSERT INTO "django_geo_db_location" VALUES(15807,NULL,'Sharpsburg, MD',6515,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15808,NULL,'Sharpsburg, MD 21782',6515,222,NULL,38,9000,0);
INSERT INTO "django_geo_db_location" VALUES(15809,NULL,'Smithsburg, MD',6516,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15810,NULL,'Smithsburg, MD 21783',6516,222,NULL,38,9001,0);
INSERT INTO "django_geo_db_location" VALUES(15811,NULL,'Sykesville, MD',6517,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15812,NULL,'Sykesville, MD 21784',6517,222,NULL,38,9002,0);
INSERT INTO "django_geo_db_location" VALUES(15813,NULL,'Taneytown, MD',6518,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15814,NULL,'Taneytown, MD 21787',6518,222,NULL,38,9003,0);
INSERT INTO "django_geo_db_location" VALUES(15815,NULL,'Thurmont, MD',6519,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15816,NULL,'Thurmont, MD 21788',6519,222,NULL,38,9004,0);
INSERT INTO "django_geo_db_location" VALUES(15817,NULL,'Tuscarora, MD',6520,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15818,NULL,'Tuscarora, MD 21790',6520,222,NULL,38,9005,0);
INSERT INTO "django_geo_db_location" VALUES(15819,NULL,'Union Bridge, MD',6521,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15820,NULL,'Union Bridge, MD 21791',6521,222,NULL,38,9006,0);
INSERT INTO "django_geo_db_location" VALUES(15821,NULL,'Unionville, MD',6522,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15822,NULL,'Unionville, MD 21792',6522,222,NULL,38,9007,0);
INSERT INTO "django_geo_db_location" VALUES(15823,NULL,'Walkersville, MD',6523,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15824,NULL,'Walkersville, MD 21793',6523,222,NULL,38,9008,0);
INSERT INTO "django_geo_db_location" VALUES(15825,NULL,'West Friendship, MD',6524,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15826,NULL,'West Friendship, MD 21794',6524,222,NULL,38,9009,0);
INSERT INTO "django_geo_db_location" VALUES(15827,NULL,'Williamsport, MD',6525,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15828,NULL,'Williamsport, MD 21795',6525,222,NULL,38,9010,0);
INSERT INTO "django_geo_db_location" VALUES(15829,NULL,'Woodbine, MD',6526,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15830,NULL,'Woodbine, MD 21797',6526,222,NULL,38,9011,0);
INSERT INTO "django_geo_db_location" VALUES(15831,NULL,'Woodsboro, MD',6527,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15832,NULL,'Woodsboro, MD 21798',6527,222,NULL,38,9012,0);
INSERT INTO "django_geo_db_location" VALUES(15833,NULL,'Salisbury, MD',6528,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15834,NULL,'Salisbury, MD 21801',6528,222,NULL,38,9013,0);
INSERT INTO "django_geo_db_location" VALUES(15835,NULL,'Salisbury, MD 21802',6528,222,NULL,38,9014,0);
INSERT INTO "django_geo_db_location" VALUES(15836,NULL,'Salisbury, MD 21803',6528,222,NULL,38,9015,0);
INSERT INTO "django_geo_db_location" VALUES(15837,NULL,'Salisbury, MD 21804',6528,222,NULL,38,9016,0);
INSERT INTO "django_geo_db_location" VALUES(15838,NULL,'Allen, MD',6529,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15839,NULL,'Allen, MD 21810',6529,222,NULL,38,9017,0);
INSERT INTO "django_geo_db_location" VALUES(15840,NULL,'Berlin, MD',6530,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15841,NULL,'Berlin, MD 21811',6530,222,NULL,38,9018,0);
INSERT INTO "django_geo_db_location" VALUES(15842,NULL,'Bishopville, MD',6531,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15843,NULL,'Bishopville, MD 21813',6531,222,NULL,38,9019,0);
INSERT INTO "django_geo_db_location" VALUES(15844,NULL,'Bivalve, MD',6532,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15845,NULL,'Bivalve, MD 21814',6532,222,NULL,38,9020,0);
INSERT INTO "django_geo_db_location" VALUES(15846,NULL,'Crisfield, MD',6533,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15847,NULL,'Crisfield, MD 21817',6533,222,NULL,38,9021,0);
INSERT INTO "django_geo_db_location" VALUES(15848,NULL,'Deal Island, MD',6534,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15849,NULL,'Deal Island, MD 21821',6534,222,NULL,38,9022,0);
INSERT INTO "django_geo_db_location" VALUES(15850,NULL,'Eden, MD',6535,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15851,NULL,'Eden, MD 21822',6535,222,NULL,38,9023,0);
INSERT INTO "django_geo_db_location" VALUES(15852,NULL,'Ewell, MD',6536,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15853,NULL,'Ewell, MD 21824',6536,222,NULL,38,9024,0);
INSERT INTO "django_geo_db_location" VALUES(15854,NULL,'Fruitland, MD',6537,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15855,NULL,'Fruitland, MD 21826',6537,222,NULL,38,9025,0);
INSERT INTO "django_geo_db_location" VALUES(15856,NULL,'Girdletree, MD',6538,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15857,NULL,'Girdletree, MD 21829',6538,222,NULL,38,9026,0);
INSERT INTO "django_geo_db_location" VALUES(15858,NULL,'Hebron, MD',6539,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15859,NULL,'Hebron, MD 21830',6539,222,NULL,38,9027,0);
INSERT INTO "django_geo_db_location" VALUES(15860,NULL,'Hebron, MD 21831',6539,222,NULL,38,9028,0);
INSERT INTO "django_geo_db_location" VALUES(15861,NULL,'Linkwood, MD',6540,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15862,NULL,'Linkwood, MD 21835',6540,222,NULL,38,9029,0);
INSERT INTO "django_geo_db_location" VALUES(15863,NULL,'Manokin, MD',6541,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15864,NULL,'Manokin, MD 21836',6541,222,NULL,38,9030,0);
INSERT INTO "django_geo_db_location" VALUES(15865,NULL,'Mardela Springs, MD',6542,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15866,NULL,'Mardela Springs, MD 21837',6542,222,NULL,38,9031,0);
INSERT INTO "django_geo_db_location" VALUES(15867,NULL,'Marion Station, MD',6543,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15868,NULL,'Marion Station, MD 21838',6543,222,NULL,38,9032,0);
INSERT INTO "django_geo_db_location" VALUES(15869,NULL,'Nanticoke, MD',6544,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15870,NULL,'Nanticoke, MD 21840',6544,222,NULL,38,9033,0);
INSERT INTO "django_geo_db_location" VALUES(15871,NULL,'Newark, MD',6545,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15872,NULL,'Newark, MD 21841',6545,222,NULL,38,9034,0);
INSERT INTO "django_geo_db_location" VALUES(15873,NULL,'Ocean City, MD',6546,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15874,NULL,'Ocean City, MD 21842',6546,222,NULL,38,9035,0);
INSERT INTO "django_geo_db_location" VALUES(15875,NULL,'Ocean City, MD 21843',6546,222,NULL,38,9036,0);
INSERT INTO "django_geo_db_location" VALUES(15876,NULL,'Parsonsburg, MD',6547,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15877,NULL,'Parsonsburg, MD 21849',6547,222,NULL,38,9037,0);
INSERT INTO "django_geo_db_location" VALUES(15878,NULL,'Pittsville, MD',6548,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15879,NULL,'Pittsville, MD 21850',6548,222,NULL,38,9038,0);
INSERT INTO "django_geo_db_location" VALUES(15880,NULL,'Pocomoke City, MD',6549,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15881,NULL,'Pocomoke City, MD 21851',6549,222,NULL,38,9039,0);
INSERT INTO "django_geo_db_location" VALUES(15882,NULL,'Powellville, MD',6550,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15883,NULL,'Powellville, MD 21852',6550,222,NULL,38,9040,0);
INSERT INTO "django_geo_db_location" VALUES(15884,NULL,'Princess Anne, MD',6551,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15885,NULL,'Princess Anne, MD 21853',6551,222,NULL,38,9041,0);
INSERT INTO "django_geo_db_location" VALUES(15886,NULL,'Quantico, MD',6552,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15887,NULL,'Quantico, MD 21856',6552,222,NULL,38,9042,0);
INSERT INTO "django_geo_db_location" VALUES(15888,NULL,'Rehobeth, MD',6553,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15889,NULL,'Rehobeth, MD 21857',6553,222,NULL,38,9043,0);
INSERT INTO "django_geo_db_location" VALUES(15890,NULL,'Sharptown, MD',6554,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15891,NULL,'Sharptown, MD 21861',6554,222,NULL,38,9044,0);
INSERT INTO "django_geo_db_location" VALUES(15892,NULL,'Showell, MD',6555,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15893,NULL,'Showell, MD 21862',6555,222,NULL,38,9045,0);
INSERT INTO "django_geo_db_location" VALUES(15894,NULL,'Snow Hill, MD',6556,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15895,NULL,'Snow Hill, MD 21863',6556,222,NULL,38,9046,0);
INSERT INTO "django_geo_db_location" VALUES(15896,NULL,'Stockton, MD',6557,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15897,NULL,'Stockton, MD 21864',6557,222,NULL,38,9047,0);
INSERT INTO "django_geo_db_location" VALUES(15898,NULL,'Tyaskin, MD',6558,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15899,NULL,'Tyaskin, MD 21865',6558,222,NULL,38,9048,0);
INSERT INTO "django_geo_db_location" VALUES(15900,NULL,'Tylerton, MD',6559,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15901,NULL,'Tylerton, MD 21866',6559,222,NULL,38,9049,0);
INSERT INTO "django_geo_db_location" VALUES(15902,NULL,'Upper Fairmount, MD',6560,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15903,NULL,'Upper Fairmount, MD 21867',6560,222,NULL,38,9050,0);
INSERT INTO "django_geo_db_location" VALUES(15904,NULL,'Fairmount, MD',6561,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15905,NULL,'Fairmount, MD 21868',6561,222,NULL,38,9051,0);
INSERT INTO "django_geo_db_location" VALUES(15906,NULL,'Vienna, MD',6562,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15907,NULL,'Vienna, MD 21869',6562,222,NULL,38,9052,0);
INSERT INTO "django_geo_db_location" VALUES(15908,NULL,'Wenona, MD',6563,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15909,NULL,'Wenona, MD 21870',6563,222,NULL,38,9053,0);
INSERT INTO "django_geo_db_location" VALUES(15910,NULL,'Westover, MD',6564,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15911,NULL,'Westover, MD 21871',6564,222,NULL,38,9054,0);
INSERT INTO "django_geo_db_location" VALUES(15912,NULL,'Whaleyville, MD',6565,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15913,NULL,'Whaleyville, MD 21872',6565,222,NULL,38,9055,0);
INSERT INTO "django_geo_db_location" VALUES(15914,NULL,'Willards, MD',6566,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15915,NULL,'Willards, MD 21874',6566,222,NULL,38,9056,0);
INSERT INTO "django_geo_db_location" VALUES(15916,NULL,'Delmar, MD',6567,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15917,NULL,'Delmar, MD 21875',6567,222,NULL,38,9057,0);
INSERT INTO "django_geo_db_location" VALUES(15918,NULL,'Westover, MD 21890',6564,222,NULL,38,9058,0);
INSERT INTO "django_geo_db_location" VALUES(15919,NULL,'North East, MD',6568,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15920,NULL,'North East, MD 21901',6568,222,NULL,38,9059,0);
INSERT INTO "django_geo_db_location" VALUES(15921,NULL,'Perry Point, MD',6569,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15922,NULL,'Perry Point, MD 21902',6569,222,NULL,38,9060,0);
INSERT INTO "django_geo_db_location" VALUES(15923,NULL,'Perryville, MD',6570,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15924,NULL,'Perryville, MD 21903',6570,222,NULL,38,9061,0);
INSERT INTO "django_geo_db_location" VALUES(15925,NULL,'Port Deposit, MD',6571,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15926,NULL,'Port Deposit, MD 21904',6571,222,NULL,38,9062,0);
INSERT INTO "django_geo_db_location" VALUES(15927,NULL,'Rising Sun, MD',6572,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15928,NULL,'Rising Sun, MD 21911',6572,222,NULL,38,9063,0);
INSERT INTO "django_geo_db_location" VALUES(15929,NULL,'Warwick, MD',6573,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15930,NULL,'Warwick, MD 21912',6573,222,NULL,38,9064,0);
INSERT INTO "django_geo_db_location" VALUES(15931,NULL,'Cecilton, MD',6574,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15932,NULL,'Cecilton, MD 21913',6574,222,NULL,38,9065,0);
INSERT INTO "django_geo_db_location" VALUES(15933,NULL,'Charlestown, MD',6575,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15934,NULL,'Charlestown, MD 21914',6575,222,NULL,38,9066,0);
INSERT INTO "django_geo_db_location" VALUES(15935,NULL,'Chesapeake City, MD',6576,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15936,NULL,'Chesapeake City, MD 21915',6576,222,NULL,38,9067,0);
INSERT INTO "django_geo_db_location" VALUES(15937,NULL,'Childs, MD',6577,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15938,NULL,'Childs, MD 21916',6577,222,NULL,38,9068,0);
INSERT INTO "django_geo_db_location" VALUES(15939,NULL,'Colora, MD',6578,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15940,NULL,'Colora, MD 21917',6578,222,NULL,38,9069,0);
INSERT INTO "django_geo_db_location" VALUES(15941,NULL,'Conowingo, MD',6579,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15942,NULL,'Conowingo, MD 21918',6579,222,NULL,38,9070,0);
INSERT INTO "django_geo_db_location" VALUES(15943,NULL,'Earleville, MD',6580,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15944,NULL,'Earleville, MD 21919',6580,222,NULL,38,9071,0);
INSERT INTO "django_geo_db_location" VALUES(15945,NULL,'Elk Mills, MD',6581,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15946,NULL,'Elk Mills, MD 21920',6581,222,NULL,38,9072,0);
INSERT INTO "django_geo_db_location" VALUES(15947,NULL,'Elkton, MD',6582,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15948,NULL,'Elkton, MD 21921',6582,222,NULL,38,9073,0);
INSERT INTO "django_geo_db_location" VALUES(15949,NULL,'Elkton, MD 21922',6582,222,NULL,38,9074,0);
INSERT INTO "django_geo_db_location" VALUES(15950,NULL,'Georgetown, MD',6583,222,NULL,38,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15951,NULL,'Georgetown, MD 21930',6583,222,NULL,38,9075,0);
INSERT INTO "django_geo_db_location" VALUES(15952,NULL,'Amissville, VA 22002',6109,222,NULL,54,9076,0);
INSERT INTO "django_geo_db_location" VALUES(15953,NULL,'Annandale, VA',6584,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15954,NULL,'Annandale, VA 22003',6584,222,NULL,54,9077,0);
INSERT INTO "django_geo_db_location" VALUES(15955,NULL,'Burke, VA',6585,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15956,NULL,'Burke, VA 22009',6585,222,NULL,54,9078,0);
INSERT INTO "django_geo_db_location" VALUES(15957,NULL,'Burke, VA 22015',6585,222,NULL,54,9079,0);
INSERT INTO "django_geo_db_location" VALUES(15958,NULL,'Dumfries, VA',6586,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15959,NULL,'Dumfries, VA 22026',6586,222,NULL,54,9080,0);
INSERT INTO "django_geo_db_location" VALUES(15960,NULL,'Dunn Loring, VA',6587,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15961,NULL,'Dunn Loring, VA 22027',6587,222,NULL,54,9081,0);
INSERT INTO "django_geo_db_location" VALUES(15962,NULL,'Fairfax, VA',6588,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15963,NULL,'Fairfax, VA 22030',6588,222,NULL,54,9082,0);
INSERT INTO "django_geo_db_location" VALUES(15964,NULL,'Fairfax, VA 22031',6588,222,NULL,54,9083,0);
INSERT INTO "django_geo_db_location" VALUES(15965,NULL,'Fairfax, VA 22032',6588,222,NULL,54,9084,0);
INSERT INTO "django_geo_db_location" VALUES(15966,NULL,'Fairfax, VA 22033',6588,222,NULL,54,9085,0);
INSERT INTO "django_geo_db_location" VALUES(15967,NULL,'Fairfax, VA 22034',6588,222,NULL,54,9086,0);
INSERT INTO "django_geo_db_location" VALUES(15968,NULL,'Fairfax, VA 22035',6588,222,NULL,54,9087,0);
INSERT INTO "django_geo_db_location" VALUES(15969,NULL,'Fairfax, VA 22036',6588,222,NULL,54,9088,0);
INSERT INTO "django_geo_db_location" VALUES(15970,NULL,'Fairfax, VA 22037',6588,222,NULL,54,9089,0);
INSERT INTO "django_geo_db_location" VALUES(15971,NULL,'Fairfax, VA 22038',6588,222,NULL,54,9090,0);
INSERT INTO "django_geo_db_location" VALUES(15972,NULL,'Fairfax Station, VA',6589,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15973,NULL,'Fairfax Station, VA 22039',6589,222,NULL,54,9091,0);
INSERT INTO "django_geo_db_location" VALUES(15974,NULL,'Falls Church, VA',6590,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15975,NULL,'Falls Church, VA 22040',6590,222,NULL,54,9092,0);
INSERT INTO "django_geo_db_location" VALUES(15976,NULL,'Falls Church, VA 22041',6590,222,NULL,54,9093,0);
INSERT INTO "django_geo_db_location" VALUES(15977,NULL,'Falls Church, VA 22042',6590,222,NULL,54,9094,0);
INSERT INTO "django_geo_db_location" VALUES(15978,NULL,'Falls Church, VA 22043',6590,222,NULL,54,9095,0);
INSERT INTO "django_geo_db_location" VALUES(15979,NULL,'Falls Church, VA 22044',6590,222,NULL,54,9096,0);
INSERT INTO "django_geo_db_location" VALUES(15980,NULL,'Falls Church, VA 22046',6590,222,NULL,54,9097,0);
INSERT INTO "django_geo_db_location" VALUES(15981,NULL,'Falls Church, VA 22047',6590,222,NULL,54,9098,0);
INSERT INTO "django_geo_db_location" VALUES(15982,NULL,'Fort Belvoir, VA',6591,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15983,NULL,'Fort Belvoir, VA 22060',6591,222,NULL,54,9099,0);
INSERT INTO "django_geo_db_location" VALUES(15984,NULL,'Great Falls, VA',6592,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15985,NULL,'Great Falls, VA 22066',6592,222,NULL,54,9100,0);
INSERT INTO "django_geo_db_location" VALUES(15986,NULL,'Greenway, VA',6593,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15987,NULL,'Greenway, VA 22067',6593,222,NULL,54,9101,0);
INSERT INTO "django_geo_db_location" VALUES(15988,NULL,'Lorton, VA',6594,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15989,NULL,'Lorton, VA 22079',6594,222,NULL,54,9102,0);
INSERT INTO "django_geo_db_location" VALUES(15990,NULL,'Merrifield, VA',6595,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15991,NULL,'Merrifield, VA 22081',6595,222,NULL,54,9103,0);
INSERT INTO "django_geo_db_location" VALUES(15992,NULL,'Merrifield, VA 22082',6595,222,NULL,54,9104,0);
INSERT INTO "django_geo_db_location" VALUES(15993,NULL,'Herndon, VA 22092',6138,222,NULL,54,9105,0);
INSERT INTO "django_geo_db_location" VALUES(15994,NULL,'Ashburn, VA 22093',6131,222,NULL,54,9106,0);
INSERT INTO "django_geo_db_location" VALUES(15995,NULL,'Herndon, VA 22095',6138,222,NULL,54,9107,0);
INSERT INTO "django_geo_db_location" VALUES(15996,NULL,'Reston, VA 22096',6144,222,NULL,54,9108,0);
INSERT INTO "django_geo_db_location" VALUES(15997,NULL,'McLean, VA',6596,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(15998,NULL,'McLean, VA 22101',6596,222,NULL,54,9109,0);
INSERT INTO "django_geo_db_location" VALUES(15999,NULL,'McLean, VA 22102',6596,222,NULL,54,9110,0);
INSERT INTO "django_geo_db_location" VALUES(16000,NULL,'West Mclean, VA',6597,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16001,NULL,'West Mclean, VA 22103',6597,222,NULL,54,9111,0);
INSERT INTO "django_geo_db_location" VALUES(16002,NULL,'McLean, VA 22106',6596,222,NULL,54,9112,0);
INSERT INTO "django_geo_db_location" VALUES(16003,NULL,'McLean, VA 22109',6596,222,NULL,54,9113,0);
INSERT INTO "django_geo_db_location" VALUES(16004,NULL,'Merrifield, VA 22116',6595,222,NULL,54,9114,0);
INSERT INTO "django_geo_db_location" VALUES(16005,NULL,'Merrifield, VA 22118',6595,222,NULL,54,9115,0);
INSERT INTO "django_geo_db_location" VALUES(16006,NULL,'Merrifield, VA 22119',6595,222,NULL,54,9116,0);
INSERT INTO "django_geo_db_location" VALUES(16007,NULL,'Merrifield, VA 22120',6595,222,NULL,54,9117,0);
INSERT INTO "django_geo_db_location" VALUES(16008,NULL,'Mount Vernon, VA',6598,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16009,NULL,'Mount Vernon, VA 22121',6598,222,NULL,54,9118,0);
INSERT INTO "django_geo_db_location" VALUES(16010,NULL,'Newington, VA',6599,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16011,NULL,'Newington, VA 22122',6599,222,NULL,54,9119,0);
INSERT INTO "django_geo_db_location" VALUES(16012,NULL,'Oakton, VA',6600,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16013,NULL,'Oakton, VA 22124',6600,222,NULL,54,9120,0);
INSERT INTO "django_geo_db_location" VALUES(16014,NULL,'Occoquan, VA',6601,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16015,NULL,'Occoquan, VA 22125',6601,222,NULL,54,9121,0);
INSERT INTO "django_geo_db_location" VALUES(16016,NULL,'Quantico, VA',6602,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16017,NULL,'Quantico, VA 22134',6602,222,NULL,54,9122,0);
INSERT INTO "django_geo_db_location" VALUES(16018,NULL,'Quantico, VA 22135',6602,222,NULL,54,9123,0);
INSERT INTO "django_geo_db_location" VALUES(16019,NULL,'Springfield, VA',6603,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16020,NULL,'Springfield, VA 22150',6603,222,NULL,54,9124,0);
INSERT INTO "django_geo_db_location" VALUES(16021,NULL,'Springfield, VA 22151',6603,222,NULL,54,9125,0);
INSERT INTO "django_geo_db_location" VALUES(16022,NULL,'Springfield, VA 22152',6603,222,NULL,54,9126,0);
INSERT INTO "django_geo_db_location" VALUES(16023,NULL,'Springfield, VA 22153',6603,222,NULL,54,9127,0);
INSERT INTO "django_geo_db_location" VALUES(16024,NULL,'Springfield, VA 22156',6603,222,NULL,54,9128,0);
INSERT INTO "django_geo_db_location" VALUES(16025,NULL,'Springfield, VA 22158',6603,222,NULL,54,9129,0);
INSERT INTO "django_geo_db_location" VALUES(16026,NULL,'Springfield, VA 22159',6603,222,NULL,54,9130,0);
INSERT INTO "django_geo_db_location" VALUES(16027,NULL,'Springfield, VA 22160',6603,222,NULL,54,9131,0);
INSERT INTO "django_geo_db_location" VALUES(16028,NULL,'Springfield, VA 22161',6603,222,NULL,54,9132,0);
INSERT INTO "django_geo_db_location" VALUES(16029,NULL,'Triangle, VA',6604,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16030,NULL,'Triangle, VA 22172',6604,222,NULL,54,9133,0);
INSERT INTO "django_geo_db_location" VALUES(16031,NULL,'Vienna, VA',6605,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16032,NULL,'Vienna, VA 22180',6605,222,NULL,54,9134,0);
INSERT INTO "django_geo_db_location" VALUES(16033,NULL,'Vienna, VA 22181',6605,222,NULL,54,9135,0);
INSERT INTO "django_geo_db_location" VALUES(16034,NULL,'Vienna, VA 22182',6605,222,NULL,54,9136,0);
INSERT INTO "django_geo_db_location" VALUES(16035,NULL,'Vienna, VA 22183',6605,222,NULL,54,9137,0);
INSERT INTO "django_geo_db_location" VALUES(16036,NULL,'Vienna, VA 22184',6605,222,NULL,54,9138,0);
INSERT INTO "django_geo_db_location" VALUES(16037,NULL,'Vienna, VA 22185',6605,222,NULL,54,9139,0);
INSERT INTO "django_geo_db_location" VALUES(16038,NULL,'Woodbridge, VA',6606,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16039,NULL,'Woodbridge, VA 22191',6606,222,NULL,54,9140,0);
INSERT INTO "django_geo_db_location" VALUES(16040,NULL,'Woodbridge, VA 22192',6606,222,NULL,54,9141,0);
INSERT INTO "django_geo_db_location" VALUES(16041,NULL,'Woodbridge, VA 22193',6606,222,NULL,54,9142,0);
INSERT INTO "django_geo_db_location" VALUES(16042,NULL,'Woodbridge, VA 22194',6606,222,NULL,54,9143,0);
INSERT INTO "django_geo_db_location" VALUES(16043,NULL,'Woodbridge, VA 22195',6606,222,NULL,54,9144,0);
INSERT INTO "django_geo_db_location" VALUES(16044,NULL,'Lorton, VA 22199',6594,222,NULL,54,9145,0);
INSERT INTO "django_geo_db_location" VALUES(16045,NULL,'Arlington, VA',6607,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16046,NULL,'Arlington, VA 22201',6607,222,NULL,54,9146,0);
INSERT INTO "django_geo_db_location" VALUES(16047,NULL,'Arlington, VA 22202',6607,222,NULL,54,9147,0);
INSERT INTO "django_geo_db_location" VALUES(16048,NULL,'Arlington, VA 22203',6607,222,NULL,54,9148,0);
INSERT INTO "django_geo_db_location" VALUES(16049,NULL,'Arlington, VA 22204',6607,222,NULL,54,9149,0);
INSERT INTO "django_geo_db_location" VALUES(16050,NULL,'Arlington, VA 22205',6607,222,NULL,54,9150,0);
INSERT INTO "django_geo_db_location" VALUES(16051,NULL,'Arlington, VA 22206',6607,222,NULL,54,9151,0);
INSERT INTO "django_geo_db_location" VALUES(16052,NULL,'Arlington, VA 22207',6607,222,NULL,54,9152,0);
INSERT INTO "django_geo_db_location" VALUES(16053,NULL,'Arlington, VA 22209',6607,222,NULL,54,9153,0);
INSERT INTO "django_geo_db_location" VALUES(16054,NULL,'Arlington, VA 22210',6607,222,NULL,54,9154,0);
INSERT INTO "django_geo_db_location" VALUES(16055,NULL,'Ft Myer, VA',6608,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16056,NULL,'Ft Myer, VA 22211',6608,222,NULL,54,9155,0);
INSERT INTO "django_geo_db_location" VALUES(16057,NULL,'Arlington, VA 22212',6607,222,NULL,54,9156,0);
INSERT INTO "django_geo_db_location" VALUES(16058,NULL,'Arlington, VA 22213',6607,222,NULL,54,9157,0);
INSERT INTO "django_geo_db_location" VALUES(16059,NULL,'Arlington, VA 22214',6607,222,NULL,54,9158,0);
INSERT INTO "django_geo_db_location" VALUES(16060,NULL,'Arlington, VA 22215',6607,222,NULL,54,9159,0);
INSERT INTO "django_geo_db_location" VALUES(16061,NULL,'Arlington, VA 22216',6607,222,NULL,54,9160,0);
INSERT INTO "django_geo_db_location" VALUES(16062,NULL,'Arlington, VA 22217',6607,222,NULL,54,9161,0);
INSERT INTO "django_geo_db_location" VALUES(16063,NULL,'Arlington, VA 22218',6607,222,NULL,54,9162,0);
INSERT INTO "django_geo_db_location" VALUES(16064,NULL,'Arlington, VA 22219',6607,222,NULL,54,9163,0);
INSERT INTO "django_geo_db_location" VALUES(16065,NULL,'Arlington, VA 22222',6607,222,NULL,54,9164,0);
INSERT INTO "django_geo_db_location" VALUES(16066,NULL,'Arlington, VA 22223',6607,222,NULL,54,9165,0);
INSERT INTO "django_geo_db_location" VALUES(16067,NULL,'Arlington, VA 22225',6607,222,NULL,54,9166,0);
INSERT INTO "django_geo_db_location" VALUES(16068,NULL,'Arlington, VA 22226',6607,222,NULL,54,9167,0);
INSERT INTO "django_geo_db_location" VALUES(16069,NULL,'Arlington, VA 22227',6607,222,NULL,54,9168,0);
INSERT INTO "django_geo_db_location" VALUES(16070,NULL,'Arlington, VA 22229',6607,222,NULL,54,9169,0);
INSERT INTO "django_geo_db_location" VALUES(16071,NULL,'Arlington, VA 22230',6607,222,NULL,54,9170,0);
INSERT INTO "django_geo_db_location" VALUES(16072,NULL,'Arlington, VA 22234',6607,222,NULL,54,9171,0);
INSERT INTO "django_geo_db_location" VALUES(16073,NULL,'Arlington, VA 22240',6607,222,NULL,54,9172,0);
INSERT INTO "django_geo_db_location" VALUES(16074,NULL,'Arlington, VA 22241',6607,222,NULL,54,9173,0);
INSERT INTO "django_geo_db_location" VALUES(16075,NULL,'Arlington, VA 22242',6607,222,NULL,54,9174,0);
INSERT INTO "django_geo_db_location" VALUES(16076,NULL,'Arlington, VA 22243',6607,222,NULL,54,9175,0);
INSERT INTO "django_geo_db_location" VALUES(16077,NULL,'Arlington, VA 22244',6607,222,NULL,54,9176,0);
INSERT INTO "django_geo_db_location" VALUES(16078,NULL,'Arlington, VA 22245',6607,222,NULL,54,9177,0);
INSERT INTO "django_geo_db_location" VALUES(16079,NULL,'Arlington, VA 22246',6607,222,NULL,54,9178,0);
INSERT INTO "django_geo_db_location" VALUES(16080,NULL,'Alexandria, VA',6609,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16081,NULL,'Alexandria, VA 22301',6609,222,NULL,54,9179,0);
INSERT INTO "django_geo_db_location" VALUES(16082,NULL,'Alexandria, VA 22302',6609,222,NULL,54,9180,0);
INSERT INTO "django_geo_db_location" VALUES(16083,NULL,'Alexandria, VA 22303',6609,222,NULL,54,9181,0);
INSERT INTO "django_geo_db_location" VALUES(16084,NULL,'Alexandria, VA 22304',6609,222,NULL,54,9182,0);
INSERT INTO "django_geo_db_location" VALUES(16085,NULL,'Alexandria, VA 22305',6609,222,NULL,54,9183,0);
INSERT INTO "django_geo_db_location" VALUES(16086,NULL,'Alexandria, VA 22306',6609,222,NULL,54,9184,0);
INSERT INTO "django_geo_db_location" VALUES(16087,NULL,'Alexandria, VA 22307',6609,222,NULL,54,9185,0);
INSERT INTO "django_geo_db_location" VALUES(16088,NULL,'Alexandria, VA 22308',6609,222,NULL,54,9186,0);
INSERT INTO "django_geo_db_location" VALUES(16089,NULL,'Alexandria, VA 22309',6609,222,NULL,54,9187,0);
INSERT INTO "django_geo_db_location" VALUES(16090,NULL,'Alexandria, VA 22310',6609,222,NULL,54,9188,0);
INSERT INTO "django_geo_db_location" VALUES(16091,NULL,'Alexandria, VA 22311',6609,222,NULL,54,9189,0);
INSERT INTO "django_geo_db_location" VALUES(16092,NULL,'Alexandria, VA 22312',6609,222,NULL,54,9190,0);
INSERT INTO "django_geo_db_location" VALUES(16093,NULL,'Alexandria, VA 22313',6609,222,NULL,54,9191,0);
INSERT INTO "django_geo_db_location" VALUES(16094,NULL,'Alexandria, VA 22314',6609,222,NULL,54,9192,0);
INSERT INTO "django_geo_db_location" VALUES(16095,NULL,'Alexandria, VA 22315',6609,222,NULL,54,9193,0);
INSERT INTO "django_geo_db_location" VALUES(16096,NULL,'Alexandria, VA 22320',6609,222,NULL,54,9194,0);
INSERT INTO "django_geo_db_location" VALUES(16097,NULL,'Alexandria, VA 22321',6609,222,NULL,54,9195,0);
INSERT INTO "django_geo_db_location" VALUES(16098,NULL,'Alexandria, VA 22331',6609,222,NULL,54,9196,0);
INSERT INTO "django_geo_db_location" VALUES(16099,NULL,'Alexandria, VA 22332',6609,222,NULL,54,9197,0);
INSERT INTO "django_geo_db_location" VALUES(16100,NULL,'Alexandria, VA 22333',6609,222,NULL,54,9198,0);
INSERT INTO "django_geo_db_location" VALUES(16101,NULL,'Alexandria, VA 22334',6609,222,NULL,54,9199,0);
INSERT INTO "django_geo_db_location" VALUES(16102,NULL,'Alexandria, VA 22336',6609,222,NULL,54,9200,0);
INSERT INTO "django_geo_db_location" VALUES(16103,NULL,'Fishersville, VA',6610,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16104,NULL,'Fishersville, VA 22393',6610,222,NULL,54,9201,0);
INSERT INTO "django_geo_db_location" VALUES(16105,NULL,'Fredericksburg, VA',6611,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16106,NULL,'Fredericksburg, VA 22401',6611,222,NULL,54,9202,0);
INSERT INTO "django_geo_db_location" VALUES(16107,NULL,'Fredericksburg, VA 22402',6611,222,NULL,54,9203,0);
INSERT INTO "django_geo_db_location" VALUES(16108,NULL,'Fredericksburg, VA 22403',6611,222,NULL,54,9204,0);
INSERT INTO "django_geo_db_location" VALUES(16109,NULL,'Fredericksburg, VA 22404',6611,222,NULL,54,9205,0);
INSERT INTO "django_geo_db_location" VALUES(16110,NULL,'Fredericksburg, VA 22405',6611,222,NULL,54,9206,0);
INSERT INTO "django_geo_db_location" VALUES(16111,NULL,'Fredericksburg, VA 22406',6611,222,NULL,54,9207,0);
INSERT INTO "django_geo_db_location" VALUES(16112,NULL,'Fredericksburg, VA 22407',6611,222,NULL,54,9208,0);
INSERT INTO "django_geo_db_location" VALUES(16113,NULL,'Fredericksburg, VA 22408',6611,222,NULL,54,9209,0);
INSERT INTO "django_geo_db_location" VALUES(16114,NULL,'Fredericksburg, VA 22412',6611,222,NULL,54,9210,0);
INSERT INTO "django_geo_db_location" VALUES(16115,NULL,'Bowling Green, VA',6612,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16116,NULL,'Bowling Green, VA 22427',6612,222,NULL,54,9211,0);
INSERT INTO "django_geo_db_location" VALUES(16117,NULL,'Bowling Green, VA 22428',6612,222,NULL,54,9212,0);
INSERT INTO "django_geo_db_location" VALUES(16118,NULL,'Brooke, VA',6613,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16119,NULL,'Brooke, VA 22430',6613,222,NULL,54,9213,0);
INSERT INTO "django_geo_db_location" VALUES(16120,NULL,'Burgess, VA',6614,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16121,NULL,'Burgess, VA 22432',6614,222,NULL,54,9214,0);
INSERT INTO "django_geo_db_location" VALUES(16122,NULL,'Burr Hill, VA',6615,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16123,NULL,'Burr Hill, VA 22433',6615,222,NULL,54,9215,0);
INSERT INTO "django_geo_db_location" VALUES(16124,NULL,'Callao, VA',6616,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16125,NULL,'Callao, VA 22435',6616,222,NULL,54,9216,0);
INSERT INTO "django_geo_db_location" VALUES(16126,NULL,'Caret, VA',6617,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16127,NULL,'Caret, VA 22436',6617,222,NULL,54,9217,0);
INSERT INTO "django_geo_db_location" VALUES(16128,NULL,'Center Cross, VA',6618,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16129,NULL,'Center Cross, VA 22437',6618,222,NULL,54,9218,0);
INSERT INTO "django_geo_db_location" VALUES(16130,NULL,'Champlain, VA',6619,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16131,NULL,'Champlain, VA 22438',6619,222,NULL,54,9219,0);
INSERT INTO "django_geo_db_location" VALUES(16132,NULL,'Coles Point, VA',6620,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16133,NULL,'Coles Point, VA 22442',6620,222,NULL,54,9220,0);
INSERT INTO "django_geo_db_location" VALUES(16134,NULL,'Colonial Beach, VA',6621,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16135,NULL,'Colonial Beach, VA 22443',6621,222,NULL,54,9221,0);
INSERT INTO "django_geo_db_location" VALUES(16136,NULL,'Corbin, VA',6622,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16137,NULL,'Corbin, VA 22446',6622,222,NULL,54,9222,0);
INSERT INTO "django_geo_db_location" VALUES(16138,NULL,'Dahlgren, VA',6623,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16139,NULL,'Dahlgren, VA 22448',6623,222,NULL,54,9223,0);
INSERT INTO "django_geo_db_location" VALUES(16140,NULL,'Dogue, VA',6624,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16141,NULL,'Dogue, VA 22451',6624,222,NULL,54,9224,0);
INSERT INTO "django_geo_db_location" VALUES(16142,NULL,'Dunnsville, VA',6625,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16143,NULL,'Dunnsville, VA 22454',6625,222,NULL,54,9225,0);
INSERT INTO "django_geo_db_location" VALUES(16144,NULL,'Edwardsville, VA',6626,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16145,NULL,'Edwardsville, VA 22456',6626,222,NULL,54,9226,0);
INSERT INTO "django_geo_db_location" VALUES(16146,NULL,'Farnham, VA',6627,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16147,NULL,'Farnham, VA 22460',6627,222,NULL,54,9227,0);
INSERT INTO "django_geo_db_location" VALUES(16148,NULL,'Garrisonville, VA',6628,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16149,NULL,'Garrisonville, VA 22463',6628,222,NULL,54,9228,0);
INSERT INTO "django_geo_db_location" VALUES(16150,NULL,'Hague, VA',6629,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16151,NULL,'Hague, VA 22469',6629,222,NULL,54,9229,0);
INSERT INTO "django_geo_db_location" VALUES(16152,NULL,'Hartwood, VA',6630,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16153,NULL,'Hartwood, VA 22471',6630,222,NULL,54,9230,0);
INSERT INTO "django_geo_db_location" VALUES(16154,NULL,'Haynesville, VA',6631,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16155,NULL,'Haynesville, VA 22472',6631,222,NULL,54,9231,0);
INSERT INTO "django_geo_db_location" VALUES(16156,NULL,'Heathsville, VA',6632,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16157,NULL,'Heathsville, VA 22473',6632,222,NULL,54,9232,0);
INSERT INTO "django_geo_db_location" VALUES(16158,NULL,'Hustle, VA',6633,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16159,NULL,'Hustle, VA 22476',6633,222,NULL,54,9233,0);
INSERT INTO "django_geo_db_location" VALUES(16160,NULL,'Irvington, VA',6634,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16161,NULL,'Irvington, VA 22480',6634,222,NULL,54,9234,0);
INSERT INTO "django_geo_db_location" VALUES(16162,NULL,'Jersey, VA',6635,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16163,NULL,'Jersey, VA 22481',6635,222,NULL,54,9235,0);
INSERT INTO "django_geo_db_location" VALUES(16164,NULL,'Kilmarnock, VA',6636,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16165,NULL,'Kilmarnock, VA 22482',6636,222,NULL,54,9236,0);
INSERT INTO "django_geo_db_location" VALUES(16166,NULL,'King George, VA',6637,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16167,NULL,'King George, VA 22485',6637,222,NULL,54,9237,0);
INSERT INTO "django_geo_db_location" VALUES(16168,NULL,'Irvington, VA 22486',6634,222,NULL,54,9238,0);
INSERT INTO "django_geo_db_location" VALUES(16169,NULL,'Kinsale, VA',6638,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16170,NULL,'Kinsale, VA 22488',6638,222,NULL,54,9239,0);
INSERT INTO "django_geo_db_location" VALUES(16171,NULL,'Ladysmith, VA',6639,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16172,NULL,'Ladysmith, VA 22501',6639,222,NULL,54,9240,0);
INSERT INTO "django_geo_db_location" VALUES(16173,NULL,'Lancaster, VA',6640,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16174,NULL,'Lancaster, VA 22503',6640,222,NULL,54,9241,0);
INSERT INTO "django_geo_db_location" VALUES(16175,NULL,'Laneview, VA',6641,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16176,NULL,'Laneview, VA 22504',6641,222,NULL,54,9242,0);
INSERT INTO "django_geo_db_location" VALUES(16177,NULL,'Lively, VA',6642,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16178,NULL,'Lively, VA 22507',6642,222,NULL,54,9243,0);
INSERT INTO "django_geo_db_location" VALUES(16179,NULL,'Locust Grove, VA',6643,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16180,NULL,'Locust Grove, VA 22508',6643,222,NULL,54,9244,0);
INSERT INTO "django_geo_db_location" VALUES(16181,NULL,'Loretto, VA',6644,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16182,NULL,'Loretto, VA 22509',6644,222,NULL,54,9245,0);
INSERT INTO "django_geo_db_location" VALUES(16183,NULL,'Lottsburg, VA',6645,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16184,NULL,'Lottsburg, VA 22511',6645,222,NULL,54,9246,0);
INSERT INTO "django_geo_db_location" VALUES(16185,NULL,'Merry Point, VA',6646,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16186,NULL,'Merry Point, VA 22513',6646,222,NULL,54,9247,0);
INSERT INTO "django_geo_db_location" VALUES(16187,NULL,'Milford, VA',6647,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16188,NULL,'Milford, VA 22514',6647,222,NULL,54,9248,0);
INSERT INTO "django_geo_db_location" VALUES(16189,NULL,'Mollusk, VA',6648,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16190,NULL,'Mollusk, VA 22517',6648,222,NULL,54,9249,0);
INSERT INTO "django_geo_db_location" VALUES(16191,NULL,'Montross, VA',6649,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16192,NULL,'Montross, VA 22520',6649,222,NULL,54,9250,0);
INSERT INTO "django_geo_db_location" VALUES(16193,NULL,'Morattico, VA',6650,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16194,NULL,'Morattico, VA 22523',6650,222,NULL,54,9251,0);
INSERT INTO "django_geo_db_location" VALUES(16195,NULL,'Mount Holly, VA',6651,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16196,NULL,'Mount Holly, VA 22524',6651,222,NULL,54,9252,0);
INSERT INTO "django_geo_db_location" VALUES(16197,NULL,'Ninde, VA',6652,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16198,NULL,'Ninde, VA 22526',6652,222,NULL,54,9253,0);
INSERT INTO "django_geo_db_location" VALUES(16199,NULL,'Nuttsville, VA',6653,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16200,NULL,'Nuttsville, VA 22528',6653,222,NULL,54,9254,0);
INSERT INTO "django_geo_db_location" VALUES(16201,NULL,'Oldhams, VA',6654,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16202,NULL,'Oldhams, VA 22529',6654,222,NULL,54,9255,0);
INSERT INTO "django_geo_db_location" VALUES(16203,NULL,'Ophelia, VA',6655,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16204,NULL,'Ophelia, VA 22530',6655,222,NULL,54,9256,0);
INSERT INTO "django_geo_db_location" VALUES(16205,NULL,'Partlow, VA',6656,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16206,NULL,'Partlow, VA 22534',6656,222,NULL,54,9257,0);
INSERT INTO "django_geo_db_location" VALUES(16207,NULL,'Port Royal, VA',6657,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16208,NULL,'Port Royal, VA 22535',6657,222,NULL,54,9258,0);
INSERT INTO "django_geo_db_location" VALUES(16209,NULL,'Rappahannock Academy, VA',6658,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16210,NULL,'Rappahannock Academy, VA 22538',6658,222,NULL,54,9259,0);
INSERT INTO "django_geo_db_location" VALUES(16211,NULL,'Reedville, VA',6659,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16212,NULL,'Reedville, VA 22539',6659,222,NULL,54,9260,0);
INSERT INTO "django_geo_db_location" VALUES(16213,NULL,'Rhoadesville, VA',6660,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16214,NULL,'Rhoadesville, VA 22542',6660,222,NULL,54,9261,0);
INSERT INTO "django_geo_db_location" VALUES(16215,NULL,'Rollins Fork, VA',6661,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16216,NULL,'Rollins Fork, VA 22544',6661,222,NULL,54,9262,0);
INSERT INTO "django_geo_db_location" VALUES(16217,NULL,'Ruby, VA',6662,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16218,NULL,'Ruby, VA 22545',6662,222,NULL,54,9263,0);
INSERT INTO "django_geo_db_location" VALUES(16219,NULL,'Ruther Glen, VA',6663,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16220,NULL,'Ruther Glen, VA 22546',6663,222,NULL,54,9264,0);
INSERT INTO "django_geo_db_location" VALUES(16221,NULL,'Sealston, VA',6664,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16222,NULL,'Sealston, VA 22547',6664,222,NULL,54,9265,0);
INSERT INTO "django_geo_db_location" VALUES(16223,NULL,'Sharps, VA',6665,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16224,NULL,'Sharps, VA 22548',6665,222,NULL,54,9266,0);
INSERT INTO "django_geo_db_location" VALUES(16225,NULL,'Sparta, VA',6666,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16226,NULL,'Sparta, VA 22552',6666,222,NULL,54,9267,0);
INSERT INTO "django_geo_db_location" VALUES(16227,NULL,'Spotsylvania, VA',6667,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16228,NULL,'Spotsylvania, VA 22553',6667,222,NULL,54,9268,0);
INSERT INTO "django_geo_db_location" VALUES(16229,NULL,'Stafford, VA',6668,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16230,NULL,'Stafford, VA 22554',6668,222,NULL,54,9269,0);
INSERT INTO "django_geo_db_location" VALUES(16231,NULL,'Stafford, VA 22555',6668,222,NULL,54,9270,0);
INSERT INTO "django_geo_db_location" VALUES(16232,NULL,'Stratford, VA',6669,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16233,NULL,'Stratford, VA 22558',6669,222,NULL,54,9271,0);
INSERT INTO "django_geo_db_location" VALUES(16234,NULL,'Tappahannock, VA',6670,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16235,NULL,'Tappahannock, VA 22560',6670,222,NULL,54,9272,0);
INSERT INTO "django_geo_db_location" VALUES(16236,NULL,'Thornburg, VA',6671,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16237,NULL,'Thornburg, VA 22565',6671,222,NULL,54,9273,0);
INSERT INTO "django_geo_db_location" VALUES(16238,NULL,'Unionville, VA',6672,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16239,NULL,'Unionville, VA 22567',6672,222,NULL,54,9274,0);
INSERT INTO "django_geo_db_location" VALUES(16240,NULL,'Village, VA',6673,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16241,NULL,'Village, VA 22570',6673,222,NULL,54,9275,0);
INSERT INTO "django_geo_db_location" VALUES(16242,NULL,'Warsaw, VA',6674,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16243,NULL,'Warsaw, VA 22572',6674,222,NULL,54,9276,0);
INSERT INTO "django_geo_db_location" VALUES(16244,NULL,'Weems, VA',6675,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16245,NULL,'Weems, VA 22576',6675,222,NULL,54,9277,0);
INSERT INTO "django_geo_db_location" VALUES(16246,NULL,'Sandy Point, VA',6676,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16247,NULL,'Sandy Point, VA 22577',6676,222,NULL,54,9278,0);
INSERT INTO "django_geo_db_location" VALUES(16248,NULL,'White Stone, VA',6677,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16249,NULL,'White Stone, VA 22578',6677,222,NULL,54,9279,0);
INSERT INTO "django_geo_db_location" VALUES(16250,NULL,'Wicomico Church, VA',6678,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16251,NULL,'Wicomico Church, VA 22579',6678,222,NULL,54,9280,0);
INSERT INTO "django_geo_db_location" VALUES(16252,NULL,'Woodford, VA',6679,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16253,NULL,'Woodford, VA 22580',6679,222,NULL,54,9281,0);
INSERT INTO "django_geo_db_location" VALUES(16254,NULL,'Zacata, VA',6680,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16255,NULL,'Zacata, VA 22581',6680,222,NULL,54,9282,0);
INSERT INTO "django_geo_db_location" VALUES(16256,NULL,'Winchester, VA',6681,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16257,NULL,'Winchester, VA 22601',6681,222,NULL,54,9283,0);
INSERT INTO "django_geo_db_location" VALUES(16258,NULL,'Winchester, VA 22602',6681,222,NULL,54,9284,0);
INSERT INTO "django_geo_db_location" VALUES(16259,NULL,'Winchester, VA 22603',6681,222,NULL,54,9285,0);
INSERT INTO "django_geo_db_location" VALUES(16260,NULL,'Winchester, VA 22604',6681,222,NULL,54,9286,0);
INSERT INTO "django_geo_db_location" VALUES(16261,NULL,'Newport News, VA',6682,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16262,NULL,'Newport News, VA 22606',6682,222,NULL,54,9287,0);
INSERT INTO "django_geo_db_location" VALUES(16263,NULL,'Bentonville, VA',6683,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16264,NULL,'Bentonville, VA 22610',6683,222,NULL,54,9288,0);
INSERT INTO "django_geo_db_location" VALUES(16265,NULL,'Berryville, VA',6684,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16266,NULL,'Berryville, VA 22611',6684,222,NULL,54,9289,0);
INSERT INTO "django_geo_db_location" VALUES(16267,NULL,'Boyce, VA',6685,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16268,NULL,'Boyce, VA 22620',6685,222,NULL,54,9290,0);
INSERT INTO "django_geo_db_location" VALUES(16269,NULL,'Brucetown, VA',6686,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16270,NULL,'Brucetown, VA 22622',6686,222,NULL,54,9291,0);
INSERT INTO "django_geo_db_location" VALUES(16271,NULL,'Chester Gap, VA',6687,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16272,NULL,'Chester Gap, VA 22623',6687,222,NULL,54,9292,0);
INSERT INTO "django_geo_db_location" VALUES(16273,NULL,'Clear Brook, VA',6688,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16274,NULL,'Clear Brook, VA 22624',6688,222,NULL,54,9293,0);
INSERT INTO "django_geo_db_location" VALUES(16275,NULL,'Cross Junction, VA',6689,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16276,NULL,'Cross Junction, VA 22625',6689,222,NULL,54,9294,0);
INSERT INTO "django_geo_db_location" VALUES(16277,NULL,'Fishers Hill, VA',6690,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16278,NULL,'Fishers Hill, VA 22626',6690,222,NULL,54,9295,0);
INSERT INTO "django_geo_db_location" VALUES(16279,NULL,'Flint Hill, VA',6691,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16280,NULL,'Flint Hill, VA 22627',6691,222,NULL,54,9296,0);
INSERT INTO "django_geo_db_location" VALUES(16281,NULL,'Front Royal, VA',6692,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16282,NULL,'Front Royal, VA 22630',6692,222,NULL,54,9297,0);
INSERT INTO "django_geo_db_location" VALUES(16283,NULL,'Gore, VA',6693,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16284,NULL,'Gore, VA 22637',6693,222,NULL,54,9298,0);
INSERT INTO "django_geo_db_location" VALUES(16285,NULL,'Winchester, VA 22638',6681,222,NULL,54,9299,0);
INSERT INTO "django_geo_db_location" VALUES(16286,NULL,'Hume, VA',6694,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16287,NULL,'Hume, VA 22639',6694,222,NULL,54,9300,0);
INSERT INTO "django_geo_db_location" VALUES(16288,NULL,'Huntly, VA',6695,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16289,NULL,'Huntly, VA 22640',6695,222,NULL,54,9301,0);
INSERT INTO "django_geo_db_location" VALUES(16290,NULL,'Strasburg, VA',6696,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16291,NULL,'Strasburg, VA 22641',6696,222,NULL,54,9302,0);
INSERT INTO "django_geo_db_location" VALUES(16292,NULL,'Linden, VA',6697,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16293,NULL,'Linden, VA 22642',6697,222,NULL,54,9303,0);
INSERT INTO "django_geo_db_location" VALUES(16294,NULL,'Markham, VA',6698,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16295,NULL,'Markham, VA 22643',6698,222,NULL,54,9304,0);
INSERT INTO "django_geo_db_location" VALUES(16296,NULL,'Maurertown, VA',6699,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16297,NULL,'Maurertown, VA 22644',6699,222,NULL,54,9305,0);
INSERT INTO "django_geo_db_location" VALUES(16298,NULL,'Middletown, VA',6700,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16299,NULL,'Middletown, VA 22645',6700,222,NULL,54,9306,0);
INSERT INTO "django_geo_db_location" VALUES(16300,NULL,'Millwood, VA',6701,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16301,NULL,'Millwood, VA 22646',6701,222,NULL,54,9307,0);
INSERT INTO "django_geo_db_location" VALUES(16302,NULL,'Middletown, VA 22649',6700,222,NULL,54,9308,0);
INSERT INTO "django_geo_db_location" VALUES(16303,NULL,'Rileyville, VA',6702,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16304,NULL,'Rileyville, VA 22650',6702,222,NULL,54,9309,0);
INSERT INTO "django_geo_db_location" VALUES(16305,NULL,'Front Royal, VA 22651',6692,222,NULL,54,9310,0);
INSERT INTO "django_geo_db_location" VALUES(16306,NULL,'Fort Valley, VA',6703,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16307,NULL,'Fort Valley, VA 22652',6703,222,NULL,54,9311,0);
INSERT INTO "django_geo_db_location" VALUES(16308,NULL,'Star Tannery, VA',6704,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16309,NULL,'Star Tannery, VA 22654',6704,222,NULL,54,9312,0);
INSERT INTO "django_geo_db_location" VALUES(16310,NULL,'Stephens City, VA',6705,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16311,NULL,'Stephens City, VA 22655',6705,222,NULL,54,9313,0);
INSERT INTO "django_geo_db_location" VALUES(16312,NULL,'Stephenson, VA',6706,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16313,NULL,'Stephenson, VA 22656',6706,222,NULL,54,9314,0);
INSERT INTO "django_geo_db_location" VALUES(16314,NULL,'Strasburg, VA 22657',6696,222,NULL,54,9315,0);
INSERT INTO "django_geo_db_location" VALUES(16315,NULL,'Toms Brook, VA',6707,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16316,NULL,'Toms Brook, VA 22660',6707,222,NULL,54,9316,0);
INSERT INTO "django_geo_db_location" VALUES(16317,NULL,'White Post, VA',6708,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16318,NULL,'White Post, VA 22663',6708,222,NULL,54,9317,0);
INSERT INTO "django_geo_db_location" VALUES(16319,NULL,'Woodstock, VA',6709,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16320,NULL,'Woodstock, VA 22664',6709,222,NULL,54,9318,0);
INSERT INTO "django_geo_db_location" VALUES(16321,NULL,'Culpeper, VA',6710,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16322,NULL,'Culpeper, VA 22701',6710,222,NULL,54,9319,0);
INSERT INTO "django_geo_db_location" VALUES(16323,NULL,'Aroda, VA',6711,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16324,NULL,'Aroda, VA 22709',6711,222,NULL,54,9320,0);
INSERT INTO "django_geo_db_location" VALUES(16325,NULL,'Banco, VA',6712,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16326,NULL,'Banco, VA 22711',6712,222,NULL,54,9321,0);
INSERT INTO "django_geo_db_location" VALUES(16327,NULL,'Bealeton, VA',6713,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16328,NULL,'Bealeton, VA 22712',6713,222,NULL,54,9322,0);
INSERT INTO "django_geo_db_location" VALUES(16329,NULL,'Boston, VA',6714,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16330,NULL,'Boston, VA 22713',6714,222,NULL,54,9323,0);
INSERT INTO "django_geo_db_location" VALUES(16331,NULL,'Brandy Station, VA',6715,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16332,NULL,'Brandy Station, VA 22714',6715,222,NULL,54,9324,0);
INSERT INTO "django_geo_db_location" VALUES(16333,NULL,'Brightwood, VA',6716,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16334,NULL,'Brightwood, VA 22715',6716,222,NULL,54,9325,0);
INSERT INTO "django_geo_db_location" VALUES(16335,NULL,'Castleton, VA',6717,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16336,NULL,'Castleton, VA 22716',6717,222,NULL,54,9326,0);
INSERT INTO "django_geo_db_location" VALUES(16337,NULL,'Elkwood, VA',6718,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16338,NULL,'Elkwood, VA 22718',6718,222,NULL,54,9327,0);
INSERT INTO "django_geo_db_location" VALUES(16339,NULL,'Etlan, VA',6719,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16340,NULL,'Etlan, VA 22719',6719,222,NULL,54,9328,0);
INSERT INTO "django_geo_db_location" VALUES(16341,NULL,'Goldvein, VA',6720,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16342,NULL,'Goldvein, VA 22720',6720,222,NULL,54,9329,0);
INSERT INTO "django_geo_db_location" VALUES(16343,NULL,'Graves Mill, VA',6721,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16344,NULL,'Graves Mill, VA 22721',6721,222,NULL,54,9330,0);
INSERT INTO "django_geo_db_location" VALUES(16345,NULL,'Haywood, VA',6722,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16346,NULL,'Haywood, VA 22722',6722,222,NULL,54,9331,0);
INSERT INTO "django_geo_db_location" VALUES(16347,NULL,'Hood, VA',6723,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16348,NULL,'Hood, VA 22723',6723,222,NULL,54,9332,0);
INSERT INTO "django_geo_db_location" VALUES(16349,NULL,'Jeffersonton, VA',6724,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16350,NULL,'Jeffersonton, VA 22724',6724,222,NULL,54,9333,0);
INSERT INTO "django_geo_db_location" VALUES(16351,NULL,'Leon, VA',6725,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16352,NULL,'Leon, VA 22725',6725,222,NULL,54,9334,0);
INSERT INTO "django_geo_db_location" VALUES(16353,NULL,'Lignum, VA',6726,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16354,NULL,'Lignum, VA 22726',6726,222,NULL,54,9335,0);
INSERT INTO "django_geo_db_location" VALUES(16355,NULL,'Madison, VA',6727,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16356,NULL,'Madison, VA 22727',6727,222,NULL,54,9336,0);
INSERT INTO "django_geo_db_location" VALUES(16357,NULL,'Midland, VA',6728,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16358,NULL,'Midland, VA 22728',6728,222,NULL,54,9337,0);
INSERT INTO "django_geo_db_location" VALUES(16359,NULL,'Mitchells, VA',6729,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16360,NULL,'Mitchells, VA 22729',6729,222,NULL,54,9338,0);
INSERT INTO "django_geo_db_location" VALUES(16361,NULL,'Oakpark, VA',6730,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16362,NULL,'Oakpark, VA 22730',6730,222,NULL,54,9339,0);
INSERT INTO "django_geo_db_location" VALUES(16363,NULL,'Pratts, VA',6731,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16364,NULL,'Pratts, VA 22731',6731,222,NULL,54,9340,0);
INSERT INTO "django_geo_db_location" VALUES(16365,NULL,'Radiant, VA',6732,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16366,NULL,'Radiant, VA 22732',6732,222,NULL,54,9341,0);
INSERT INTO "django_geo_db_location" VALUES(16367,NULL,'Rapidan, VA',6733,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16368,NULL,'Rapidan, VA 22733',6733,222,NULL,54,9342,0);
INSERT INTO "django_geo_db_location" VALUES(16369,NULL,'Remington, VA',6734,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16370,NULL,'Remington, VA 22734',6734,222,NULL,54,9343,0);
INSERT INTO "django_geo_db_location" VALUES(16371,NULL,'Reva, VA',6735,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16372,NULL,'Reva, VA 22735',6735,222,NULL,54,9344,0);
INSERT INTO "django_geo_db_location" VALUES(16373,NULL,'Richardsville, VA',6736,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16374,NULL,'Richardsville, VA 22736',6736,222,NULL,54,9345,0);
INSERT INTO "django_geo_db_location" VALUES(16375,NULL,'Rixeyville, VA',6737,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16376,NULL,'Rixeyville, VA 22737',6737,222,NULL,54,9346,0);
INSERT INTO "django_geo_db_location" VALUES(16377,NULL,'Rochelle, VA',6738,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16378,NULL,'Rochelle, VA 22738',6738,222,NULL,54,9347,0);
INSERT INTO "django_geo_db_location" VALUES(16379,NULL,'Somerville, VA',6739,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16380,NULL,'Somerville, VA 22739',6739,222,NULL,54,9348,0);
INSERT INTO "django_geo_db_location" VALUES(16381,NULL,'Sperryville, VA',6740,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16382,NULL,'Sperryville, VA 22740',6740,222,NULL,54,9349,0);
INSERT INTO "django_geo_db_location" VALUES(16383,NULL,'Stevensburg, VA',6741,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16384,NULL,'Stevensburg, VA 22741',6741,222,NULL,54,9350,0);
INSERT INTO "django_geo_db_location" VALUES(16385,NULL,'Sumerduck, VA',6742,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16386,NULL,'Sumerduck, VA 22742',6742,222,NULL,54,9351,0);
INSERT INTO "django_geo_db_location" VALUES(16387,NULL,'Syria, VA',6743,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16388,NULL,'Syria, VA 22743',6743,222,NULL,54,9352,0);
INSERT INTO "django_geo_db_location" VALUES(16389,NULL,'Viewtown, VA',6744,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16390,NULL,'Viewtown, VA 22746',6744,222,NULL,54,9353,0);
INSERT INTO "django_geo_db_location" VALUES(16391,NULL,'Washington, VA',6745,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16392,NULL,'Washington, VA 22747',6745,222,NULL,54,9354,0);
INSERT INTO "django_geo_db_location" VALUES(16393,NULL,'Wolftown, VA',6746,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16394,NULL,'Wolftown, VA 22748',6746,222,NULL,54,9355,0);
INSERT INTO "django_geo_db_location" VALUES(16395,NULL,'Woodville, VA',6747,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16396,NULL,'Woodville, VA 22749',6747,222,NULL,54,9356,0);
INSERT INTO "django_geo_db_location" VALUES(16397,NULL,'Harrisonburg, VA',6748,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16398,NULL,'Harrisonburg, VA 22801',6748,222,NULL,54,9357,0);
INSERT INTO "django_geo_db_location" VALUES(16399,NULL,'Harrisonburg, VA 22802',6748,222,NULL,54,9358,0);
INSERT INTO "django_geo_db_location" VALUES(16400,NULL,'Harrisonburg, VA 22807',6748,222,NULL,54,9359,0);
INSERT INTO "django_geo_db_location" VALUES(16401,NULL,'Basye, VA',6749,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16402,NULL,'Basye, VA 22810',6749,222,NULL,54,9360,0);
INSERT INTO "django_geo_db_location" VALUES(16403,NULL,'Bergton, VA',6750,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16404,NULL,'Bergton, VA 22811',6750,222,NULL,54,9361,0);
INSERT INTO "django_geo_db_location" VALUES(16405,NULL,'Bridgewater, VA',6751,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16406,NULL,'Bridgewater, VA 22812',6751,222,NULL,54,9362,0);
INSERT INTO "django_geo_db_location" VALUES(16407,NULL,'Broadway, VA',6752,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16408,NULL,'Broadway, VA 22815',6752,222,NULL,54,9363,0);
INSERT INTO "django_geo_db_location" VALUES(16409,NULL,'Criders, VA',6753,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16410,NULL,'Criders, VA 22820',6753,222,NULL,54,9364,0);
INSERT INTO "django_geo_db_location" VALUES(16411,NULL,'Dayton, VA',6754,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16412,NULL,'Dayton, VA 22821',6754,222,NULL,54,9365,0);
INSERT INTO "django_geo_db_location" VALUES(16413,NULL,'Edinburg, VA',6755,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16414,NULL,'Edinburg, VA 22824',6755,222,NULL,54,9366,0);
INSERT INTO "django_geo_db_location" VALUES(16415,NULL,'Elkton, VA',6756,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16416,NULL,'Elkton, VA 22827',6756,222,NULL,54,9367,0);
INSERT INTO "django_geo_db_location" VALUES(16417,NULL,'Fulks Run, VA',6757,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16418,NULL,'Fulks Run, VA 22830',6757,222,NULL,54,9368,0);
INSERT INTO "django_geo_db_location" VALUES(16419,NULL,'Hinton, VA',6758,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16420,NULL,'Hinton, VA 22831',6758,222,NULL,54,9369,0);
INSERT INTO "django_geo_db_location" VALUES(16421,NULL,'Keezletown, VA',6759,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16422,NULL,'Keezletown, VA 22832',6759,222,NULL,54,9370,0);
INSERT INTO "django_geo_db_location" VALUES(16423,NULL,'Lacey Spring, VA',6760,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16424,NULL,'Lacey Spring, VA 22833',6760,222,NULL,54,9371,0);
INSERT INTO "django_geo_db_location" VALUES(16425,NULL,'Linville, VA',6761,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16426,NULL,'Linville, VA 22834',6761,222,NULL,54,9372,0);
INSERT INTO "django_geo_db_location" VALUES(16427,NULL,'Luray, VA',6762,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16428,NULL,'Luray, VA 22835',6762,222,NULL,54,9373,0);
INSERT INTO "django_geo_db_location" VALUES(16429,NULL,'McGaheysville, VA',6763,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16430,NULL,'McGaheysville, VA 22840',6763,222,NULL,54,9374,0);
INSERT INTO "django_geo_db_location" VALUES(16431,NULL,'Mount Crawford, VA',6764,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16432,NULL,'Mount Crawford, VA 22841',6764,222,NULL,54,9375,0);
INSERT INTO "django_geo_db_location" VALUES(16433,NULL,'Mount Jackson, VA',6765,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16434,NULL,'Mount Jackson, VA 22842',6765,222,NULL,54,9376,0);
INSERT INTO "django_geo_db_location" VALUES(16435,NULL,'Mount Solon, VA',6766,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16436,NULL,'Mount Solon, VA 22843',6766,222,NULL,54,9377,0);
INSERT INTO "django_geo_db_location" VALUES(16437,NULL,'New Market, VA',6767,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16438,NULL,'New Market, VA 22844',6767,222,NULL,54,9378,0);
INSERT INTO "django_geo_db_location" VALUES(16439,NULL,'Orkney Springs, VA',6768,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16440,NULL,'Orkney Springs, VA 22845',6768,222,NULL,54,9379,0);
INSERT INTO "django_geo_db_location" VALUES(16441,NULL,'Penn Laird, VA',6769,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16442,NULL,'Penn Laird, VA 22846',6769,222,NULL,54,9380,0);
INSERT INTO "django_geo_db_location" VALUES(16443,NULL,'Quicksburg, VA',6770,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16444,NULL,'Quicksburg, VA 22847',6770,222,NULL,54,9381,0);
INSERT INTO "django_geo_db_location" VALUES(16445,NULL,'Pleasant Valley, VA',6771,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16446,NULL,'Pleasant Valley, VA 22848',6771,222,NULL,54,9382,0);
INSERT INTO "django_geo_db_location" VALUES(16447,NULL,'Shenandoah, VA',6772,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16448,NULL,'Shenandoah, VA 22849',6772,222,NULL,54,9383,0);
INSERT INTO "django_geo_db_location" VALUES(16449,NULL,'Singers Glen, VA',6773,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16450,NULL,'Singers Glen, VA 22850',6773,222,NULL,54,9384,0);
INSERT INTO "django_geo_db_location" VALUES(16451,NULL,'Stanley, VA',6774,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16452,NULL,'Stanley, VA 22851',6774,222,NULL,54,9385,0);
INSERT INTO "django_geo_db_location" VALUES(16453,NULL,'Timberville, VA',6775,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16454,NULL,'Timberville, VA 22853',6775,222,NULL,54,9386,0);
INSERT INTO "django_geo_db_location" VALUES(16455,NULL,'Luray, VA 22865',6762,222,NULL,54,9387,0);
INSERT INTO "django_geo_db_location" VALUES(16456,NULL,'Luray, VA 22875',6762,222,NULL,54,9388,0);
INSERT INTO "django_geo_db_location" VALUES(16457,NULL,'Waynesboro, VA',6776,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16458,NULL,'Waynesboro, VA 22880',6776,222,NULL,54,9389,0);
INSERT INTO "django_geo_db_location" VALUES(16459,NULL,'Charlottesville, VA',6777,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16460,NULL,'Charlottesville, VA 22901',6777,222,NULL,54,9390,0);
INSERT INTO "django_geo_db_location" VALUES(16461,NULL,'Charlottesville, VA 22902',6777,222,NULL,54,9391,0);
INSERT INTO "django_geo_db_location" VALUES(16462,NULL,'Charlottesville, VA 22903',6777,222,NULL,54,9392,0);
INSERT INTO "django_geo_db_location" VALUES(16463,NULL,'Charlottesville, VA 22904',6777,222,NULL,54,9393,0);
INSERT INTO "django_geo_db_location" VALUES(16464,NULL,'Charlottesville, VA 22905',6777,222,NULL,54,9394,0);
INSERT INTO "django_geo_db_location" VALUES(16465,NULL,'Charlottesville, VA 22906',6777,222,NULL,54,9395,0);
INSERT INTO "django_geo_db_location" VALUES(16466,NULL,'Charlottesville, VA 22907',6777,222,NULL,54,9396,0);
INSERT INTO "django_geo_db_location" VALUES(16467,NULL,'Charlottesville, VA 22908',6777,222,NULL,54,9397,0);
INSERT INTO "django_geo_db_location" VALUES(16468,NULL,'Charlottesville, VA 22909',6777,222,NULL,54,9398,0);
INSERT INTO "django_geo_db_location" VALUES(16469,NULL,'Charlottesville, VA 22910',6777,222,NULL,54,9399,0);
INSERT INTO "django_geo_db_location" VALUES(16470,NULL,'Charlottesville, VA 22911',6777,222,NULL,54,9400,0);
INSERT INTO "django_geo_db_location" VALUES(16471,NULL,'Afton, VA',6778,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16472,NULL,'Afton, VA 22920',6778,222,NULL,54,9401,0);
INSERT INTO "django_geo_db_location" VALUES(16473,NULL,'Arrington, VA',6779,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16474,NULL,'Arrington, VA 22922',6779,222,NULL,54,9402,0);
INSERT INTO "django_geo_db_location" VALUES(16475,NULL,'Barboursville, VA',6780,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16476,NULL,'Barboursville, VA 22923',6780,222,NULL,54,9403,0);
INSERT INTO "django_geo_db_location" VALUES(16477,NULL,'Batesville, VA',6781,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16478,NULL,'Batesville, VA 22924',6781,222,NULL,54,9404,0);
INSERT INTO "django_geo_db_location" VALUES(16479,NULL,'Covesville, VA',6782,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16480,NULL,'Covesville, VA 22931',6782,222,NULL,54,9405,0);
INSERT INTO "django_geo_db_location" VALUES(16481,NULL,'Crozet, VA',6783,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16482,NULL,'Crozet, VA 22932',6783,222,NULL,54,9406,0);
INSERT INTO "django_geo_db_location" VALUES(16483,NULL,'Dyke, VA',6784,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16484,NULL,'Dyke, VA 22935',6784,222,NULL,54,9407,0);
INSERT INTO "django_geo_db_location" VALUES(16485,NULL,'Earlysville, VA',6785,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16486,NULL,'Earlysville, VA 22936',6785,222,NULL,54,9408,0);
INSERT INTO "django_geo_db_location" VALUES(16487,NULL,'Esmont, VA',6786,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16488,NULL,'Esmont, VA 22937',6786,222,NULL,54,9409,0);
INSERT INTO "django_geo_db_location" VALUES(16489,NULL,'Faber, VA',6787,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16490,NULL,'Faber, VA 22938',6787,222,NULL,54,9410,0);
INSERT INTO "django_geo_db_location" VALUES(16491,NULL,'Fishersville, VA 22939',6610,222,NULL,54,9411,0);
INSERT INTO "django_geo_db_location" VALUES(16492,NULL,'Free Union, VA',6788,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16493,NULL,'Free Union, VA 22940',6788,222,NULL,54,9412,0);
INSERT INTO "django_geo_db_location" VALUES(16494,NULL,'Gordonsville, VA',6789,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16495,NULL,'Gordonsville, VA 22942',6789,222,NULL,54,9413,0);
INSERT INTO "django_geo_db_location" VALUES(16496,NULL,'Greenwood, VA',6790,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16497,NULL,'Greenwood, VA 22943',6790,222,NULL,54,9414,0);
INSERT INTO "django_geo_db_location" VALUES(16498,NULL,'Ivy, VA',6791,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16499,NULL,'Ivy, VA 22945',6791,222,NULL,54,9415,0);
INSERT INTO "django_geo_db_location" VALUES(16500,NULL,'Keene, VA',6792,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16501,NULL,'Keene, VA 22946',6792,222,NULL,54,9416,0);
INSERT INTO "django_geo_db_location" VALUES(16502,NULL,'Keswick, VA',6793,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16503,NULL,'Keswick, VA 22947',6793,222,NULL,54,9417,0);
INSERT INTO "django_geo_db_location" VALUES(16504,NULL,'Locust Dale, VA',6794,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16505,NULL,'Locust Dale, VA 22948',6794,222,NULL,54,9418,0);
INSERT INTO "django_geo_db_location" VALUES(16506,NULL,'Lovingston, VA',6795,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16507,NULL,'Lovingston, VA 22949',6795,222,NULL,54,9419,0);
INSERT INTO "django_geo_db_location" VALUES(16508,NULL,'Lyndhurst, VA',6796,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16509,NULL,'Lyndhurst, VA 22952',6796,222,NULL,54,9420,0);
INSERT INTO "django_geo_db_location" VALUES(16510,NULL,'Madison Mills, VA',6797,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16511,NULL,'Madison Mills, VA 22953',6797,222,NULL,54,9421,0);
INSERT INTO "django_geo_db_location" VALUES(16512,NULL,'Massies Mill, VA',6798,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16513,NULL,'Massies Mill, VA 22954',6798,222,NULL,54,9422,0);
INSERT INTO "django_geo_db_location" VALUES(16514,NULL,'Montpelier Station, VA',6799,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16515,NULL,'Montpelier Station, VA 22957',6799,222,NULL,54,9423,0);
INSERT INTO "django_geo_db_location" VALUES(16516,NULL,'Nellysford, VA',6800,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16517,NULL,'Nellysford, VA 22958',6800,222,NULL,54,9424,0);
INSERT INTO "django_geo_db_location" VALUES(16518,NULL,'North Garden, VA',6801,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16519,NULL,'North Garden, VA 22959',6801,222,NULL,54,9425,0);
INSERT INTO "django_geo_db_location" VALUES(16520,NULL,'Orange, VA',6802,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16521,NULL,'Orange, VA 22960',6802,222,NULL,54,9426,0);
INSERT INTO "django_geo_db_location" VALUES(16522,NULL,'Palmyra, VA',6803,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16523,NULL,'Palmyra, VA 22963',6803,222,NULL,54,9427,0);
INSERT INTO "django_geo_db_location" VALUES(16524,NULL,'Piney River, VA',6804,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16525,NULL,'Piney River, VA 22964',6804,222,NULL,54,9428,0);
INSERT INTO "django_geo_db_location" VALUES(16526,NULL,'Quinque, VA',6805,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16527,NULL,'Quinque, VA 22965',6805,222,NULL,54,9429,0);
INSERT INTO "django_geo_db_location" VALUES(16528,NULL,'Roseland, VA',6806,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16529,NULL,'Roseland, VA 22967',6806,222,NULL,54,9430,0);
INSERT INTO "django_geo_db_location" VALUES(16530,NULL,'Ruckersville, VA',6807,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16531,NULL,'Ruckersville, VA 22968',6807,222,NULL,54,9431,0);
INSERT INTO "django_geo_db_location" VALUES(16532,NULL,'Schuyler, VA',6808,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16533,NULL,'Schuyler, VA 22969',6808,222,NULL,54,9432,0);
INSERT INTO "django_geo_db_location" VALUES(16534,NULL,'Shipman, VA',6809,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16535,NULL,'Shipman, VA 22971',6809,222,NULL,54,9433,0);
INSERT INTO "django_geo_db_location" VALUES(16536,NULL,'Somerset, VA',6810,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16537,NULL,'Somerset, VA 22972',6810,222,NULL,54,9434,0);
INSERT INTO "django_geo_db_location" VALUES(16538,NULL,'Stanardsville, VA',6811,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16539,NULL,'Stanardsville, VA 22973',6811,222,NULL,54,9435,0);
INSERT INTO "django_geo_db_location" VALUES(16540,NULL,'Troy, VA',6812,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16541,NULL,'Troy, VA 22974',6812,222,NULL,54,9436,0);
INSERT INTO "django_geo_db_location" VALUES(16542,NULL,'Tyro, VA',6813,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16543,NULL,'Tyro, VA 22976',6813,222,NULL,54,9437,0);
INSERT INTO "django_geo_db_location" VALUES(16544,NULL,'Waynesboro, VA 22980',6776,222,NULL,54,9438,0);
INSERT INTO "django_geo_db_location" VALUES(16545,NULL,'White Hall, VA',6814,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16546,NULL,'White Hall, VA 22987',6814,222,NULL,54,9439,0);
INSERT INTO "django_geo_db_location" VALUES(16547,NULL,'Woodberry Forest, VA',6815,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16548,NULL,'Woodberry Forest, VA 22989',6815,222,NULL,54,9440,0);
INSERT INTO "django_geo_db_location" VALUES(16549,NULL,'Achilles, VA',6816,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16550,NULL,'Achilles, VA 23001',6816,222,NULL,54,9441,0);
INSERT INTO "django_geo_db_location" VALUES(16551,NULL,'Amelia Court House, VA',6817,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16552,NULL,'Amelia Court House, VA 23002',6817,222,NULL,54,9442,0);
INSERT INTO "django_geo_db_location" VALUES(16553,NULL,'Ark, VA',6818,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16554,NULL,'Ark, VA 23003',6818,222,NULL,54,9443,0);
INSERT INTO "django_geo_db_location" VALUES(16555,NULL,'Arvonia, VA',6819,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16556,NULL,'Arvonia, VA 23004',6819,222,NULL,54,9444,0);
INSERT INTO "django_geo_db_location" VALUES(16557,NULL,'Ashland, VA',6820,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16558,NULL,'Ashland, VA 23005',6820,222,NULL,54,9445,0);
INSERT INTO "django_geo_db_location" VALUES(16559,NULL,'Aylett, VA',6821,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16560,NULL,'Aylett, VA 23009',6821,222,NULL,54,9446,0);
INSERT INTO "django_geo_db_location" VALUES(16561,NULL,'Barhamsville, VA',6822,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16562,NULL,'Barhamsville, VA 23011',6822,222,NULL,54,9447,0);
INSERT INTO "django_geo_db_location" VALUES(16563,NULL,'Beaumont, VA',6823,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16564,NULL,'Beaumont, VA 23014',6823,222,NULL,54,9448,0);
INSERT INTO "django_geo_db_location" VALUES(16565,NULL,'Beaverdam, VA',6824,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16566,NULL,'Beaverdam, VA 23015',6824,222,NULL,54,9449,0);
INSERT INTO "django_geo_db_location" VALUES(16567,NULL,'Bellamy, VA',6825,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16568,NULL,'Bellamy, VA 23017',6825,222,NULL,54,9450,0);
INSERT INTO "django_geo_db_location" VALUES(16569,NULL,'Bena, VA',6826,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16570,NULL,'Bena, VA 23018',6826,222,NULL,54,9451,0);
INSERT INTO "django_geo_db_location" VALUES(16571,NULL,'Bohannon, VA',6827,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16572,NULL,'Bohannon, VA 23021',6827,222,NULL,54,9452,0);
INSERT INTO "django_geo_db_location" VALUES(16573,NULL,'Bremo Bluff, VA',6828,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16574,NULL,'Bremo Bluff, VA 23022',6828,222,NULL,54,9453,0);
INSERT INTO "django_geo_db_location" VALUES(16575,NULL,'Bruington, VA',6829,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16576,NULL,'Bruington, VA 23023',6829,222,NULL,54,9454,0);
INSERT INTO "django_geo_db_location" VALUES(16577,NULL,'Bumpass, VA',6830,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16578,NULL,'Bumpass, VA 23024',6830,222,NULL,54,9455,0);
INSERT INTO "django_geo_db_location" VALUES(16579,NULL,'Cardinal, VA',6831,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16580,NULL,'Cardinal, VA 23025',6831,222,NULL,54,9456,0);
INSERT INTO "django_geo_db_location" VALUES(16581,NULL,'Cartersville, VA',6832,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16582,NULL,'Cartersville, VA 23027',6832,222,NULL,54,9457,0);
INSERT INTO "django_geo_db_location" VALUES(16583,NULL,'Charles City, VA',6833,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16584,NULL,'Charles City, VA 23030',6833,222,NULL,54,9458,0);
INSERT INTO "django_geo_db_location" VALUES(16585,NULL,'Christchurch, VA',6834,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16586,NULL,'Christchurch, VA 23031',6834,222,NULL,54,9459,0);
INSERT INTO "django_geo_db_location" VALUES(16587,NULL,'Church View, VA',6835,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16588,NULL,'Church View, VA 23032',6835,222,NULL,54,9460,0);
INSERT INTO "django_geo_db_location" VALUES(16589,NULL,'Cobbs Creek, VA',6836,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16590,NULL,'Cobbs Creek, VA 23035',6836,222,NULL,54,9461,0);
INSERT INTO "django_geo_db_location" VALUES(16591,NULL,'Columbia, VA',6837,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16592,NULL,'Columbia, VA 23038',6837,222,NULL,54,9462,0);
INSERT INTO "django_geo_db_location" VALUES(16593,NULL,'Crozier, VA',6838,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16594,NULL,'Crozier, VA 23039',6838,222,NULL,54,9463,0);
INSERT INTO "django_geo_db_location" VALUES(16595,NULL,'Cumberland, VA',6839,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16596,NULL,'Cumberland, VA 23040',6839,222,NULL,54,9464,0);
INSERT INTO "django_geo_db_location" VALUES(16597,NULL,'Deltaville, VA',6840,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16598,NULL,'Deltaville, VA 23043',6840,222,NULL,54,9465,0);
INSERT INTO "django_geo_db_location" VALUES(16599,NULL,'Diggs, VA',6841,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16600,NULL,'Diggs, VA 23045',6841,222,NULL,54,9466,0);
INSERT INTO "django_geo_db_location" VALUES(16601,NULL,'Doswell, VA',6842,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16602,NULL,'Doswell, VA 23047',6842,222,NULL,54,9467,0);
INSERT INTO "django_geo_db_location" VALUES(16603,NULL,'Dutton, VA',6843,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16604,NULL,'Dutton, VA 23050',6843,222,NULL,54,9468,0);
INSERT INTO "django_geo_db_location" VALUES(16605,NULL,'Fife, VA',6844,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16606,NULL,'Fife, VA 23054',6844,222,NULL,54,9469,0);
INSERT INTO "django_geo_db_location" VALUES(16607,NULL,'Fork Union, VA',6845,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16608,NULL,'Fork Union, VA 23055',6845,222,NULL,54,9470,0);
INSERT INTO "django_geo_db_location" VALUES(16609,NULL,'Foster, VA',6846,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16610,NULL,'Foster, VA 23056',6846,222,NULL,54,9471,0);
INSERT INTO "django_geo_db_location" VALUES(16611,NULL,'Glen Allen, VA',6847,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16612,NULL,'Glen Allen, VA 23058',6847,222,NULL,54,9472,0);
INSERT INTO "django_geo_db_location" VALUES(16613,NULL,'Glen Allen, VA 23059',6847,222,NULL,54,9473,0);
INSERT INTO "django_geo_db_location" VALUES(16614,NULL,'Glen Allen, VA 23060',6847,222,NULL,54,9474,0);
INSERT INTO "django_geo_db_location" VALUES(16615,NULL,'Gloucester, VA',6848,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16616,NULL,'Gloucester, VA 23061',6848,222,NULL,54,9475,0);
INSERT INTO "django_geo_db_location" VALUES(16617,NULL,'Gloucester Point, VA',6849,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16618,NULL,'Gloucester Point, VA 23062',6849,222,NULL,54,9476,0);
INSERT INTO "django_geo_db_location" VALUES(16619,NULL,'Goochland, VA',6850,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16620,NULL,'Goochland, VA 23063',6850,222,NULL,54,9477,0);
INSERT INTO "django_geo_db_location" VALUES(16621,NULL,'Grimstead, VA',6851,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16622,NULL,'Grimstead, VA 23064',6851,222,NULL,54,9478,0);
INSERT INTO "django_geo_db_location" VALUES(16623,NULL,'Gum Spring, VA',6852,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16624,NULL,'Gum Spring, VA 23065',6852,222,NULL,54,9479,0);
INSERT INTO "django_geo_db_location" VALUES(16625,NULL,'Gwynn, VA',6853,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16626,NULL,'Gwynn, VA 23066',6853,222,NULL,54,9480,0);
INSERT INTO "django_geo_db_location" VALUES(16627,NULL,'Hadensville, VA',6854,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16628,NULL,'Hadensville, VA 23067',6854,222,NULL,54,9481,0);
INSERT INTO "django_geo_db_location" VALUES(16629,NULL,'Hallieford, VA',6855,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16630,NULL,'Hallieford, VA 23068',6855,222,NULL,54,9482,0);
INSERT INTO "django_geo_db_location" VALUES(16631,NULL,'Hanover, VA',6856,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16632,NULL,'Hanover, VA 23069',6856,222,NULL,54,9483,0);
INSERT INTO "django_geo_db_location" VALUES(16633,NULL,'Hardyville, VA',6857,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16634,NULL,'Hardyville, VA 23070',6857,222,NULL,54,9484,0);
INSERT INTO "django_geo_db_location" VALUES(16635,NULL,'Hartfield, VA',6858,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16636,NULL,'Hartfield, VA 23071',6858,222,NULL,54,9485,0);
INSERT INTO "django_geo_db_location" VALUES(16637,NULL,'Hayes, VA',6859,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16638,NULL,'Hayes, VA 23072',6859,222,NULL,54,9486,0);
INSERT INTO "django_geo_db_location" VALUES(16639,NULL,'Highland Springs, VA',6860,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16640,NULL,'Highland Springs, VA 23075',6860,222,NULL,54,9487,0);
INSERT INTO "django_geo_db_location" VALUES(16641,NULL,'Hudgins, VA',6861,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16642,NULL,'Hudgins, VA 23076',6861,222,NULL,54,9488,0);
INSERT INTO "django_geo_db_location" VALUES(16643,NULL,'Jamaica, VA',6862,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16644,NULL,'Jamaica, VA 23079',6862,222,NULL,54,9489,0);
INSERT INTO "django_geo_db_location" VALUES(16645,NULL,'Jamestown, VA',6863,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16646,NULL,'Jamestown, VA 23081',6863,222,NULL,54,9490,0);
INSERT INTO "django_geo_db_location" VALUES(16647,NULL,'Jetersville, VA',6864,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16648,NULL,'Jetersville, VA 23083',6864,222,NULL,54,9491,0);
INSERT INTO "django_geo_db_location" VALUES(16649,NULL,'Kents Store, VA',6865,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16650,NULL,'Kents Store, VA 23084',6865,222,NULL,54,9492,0);
INSERT INTO "django_geo_db_location" VALUES(16651,NULL,'King And Queen Court Hous, VA',6866,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16652,NULL,'King And Queen Court Hous, VA 23085',6866,222,NULL,54,9493,0);
INSERT INTO "django_geo_db_location" VALUES(16653,NULL,'King William, VA',6867,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16654,NULL,'King William, VA 23086',6867,222,NULL,54,9494,0);
INSERT INTO "django_geo_db_location" VALUES(16655,NULL,'Lanexa, VA',6868,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16656,NULL,'Lanexa, VA 23089',6868,222,NULL,54,9495,0);
INSERT INTO "django_geo_db_location" VALUES(16657,NULL,'Lightfoot, VA',6869,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16658,NULL,'Lightfoot, VA 23090',6869,222,NULL,54,9496,0);
INSERT INTO "django_geo_db_location" VALUES(16659,NULL,'Little Plymouth, VA',6870,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16660,NULL,'Little Plymouth, VA 23091',6870,222,NULL,54,9497,0);
INSERT INTO "django_geo_db_location" VALUES(16661,NULL,'Locust Hill, VA',6871,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16662,NULL,'Locust Hill, VA 23092',6871,222,NULL,54,9498,0);
INSERT INTO "django_geo_db_location" VALUES(16663,NULL,'Louisa, VA',6872,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16664,NULL,'Louisa, VA 23093',6872,222,NULL,54,9499,0);
INSERT INTO "django_geo_db_location" VALUES(16665,NULL,'Macon, VA',6873,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16666,NULL,'Macon, VA 23101',6873,222,NULL,54,9500,0);
INSERT INTO "django_geo_db_location" VALUES(16667,NULL,'Maidens, VA',6874,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16668,NULL,'Maidens, VA 23102',6874,222,NULL,54,9501,0);
INSERT INTO "django_geo_db_location" VALUES(16669,NULL,'Manakin Sabot, VA',6875,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16670,NULL,'Manakin Sabot, VA 23103',6875,222,NULL,54,9502,0);
INSERT INTO "django_geo_db_location" VALUES(16671,NULL,'Gloucester Point, VA 23104',6849,222,NULL,54,9503,0);
INSERT INTO "django_geo_db_location" VALUES(16672,NULL,'Mannboro, VA',6876,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16673,NULL,'Mannboro, VA 23105',6876,222,NULL,54,9504,0);
INSERT INTO "django_geo_db_location" VALUES(16674,NULL,'Manquin, VA',6877,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16675,NULL,'Manquin, VA 23106',6877,222,NULL,54,9505,0);
INSERT INTO "django_geo_db_location" VALUES(16676,NULL,'Maryus, VA',6878,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16677,NULL,'Maryus, VA 23107',6878,222,NULL,54,9506,0);
INSERT INTO "django_geo_db_location" VALUES(16678,NULL,'Mascot, VA',6879,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16679,NULL,'Mascot, VA 23108',6879,222,NULL,54,9507,0);
INSERT INTO "django_geo_db_location" VALUES(16680,NULL,'Mathews, VA',6880,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16681,NULL,'Mathews, VA 23109',6880,222,NULL,54,9508,0);
INSERT INTO "django_geo_db_location" VALUES(16682,NULL,'Mattaponi, VA',6881,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16683,NULL,'Mattaponi, VA 23110',6881,222,NULL,54,9509,0);
INSERT INTO "django_geo_db_location" VALUES(16684,NULL,'Mechanicsville, VA',6882,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16685,NULL,'Mechanicsville, VA 23111',6882,222,NULL,54,9510,0);
INSERT INTO "django_geo_db_location" VALUES(16686,NULL,'Midlothian, VA',6883,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16687,NULL,'Midlothian, VA 23112',6883,222,NULL,54,9511,0);
INSERT INTO "django_geo_db_location" VALUES(16688,NULL,'Midlothian, VA 23113',6883,222,NULL,54,9512,0);
INSERT INTO "django_geo_db_location" VALUES(16689,NULL,'Millers Tavern, VA',6884,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16690,NULL,'Millers Tavern, VA 23115',6884,222,NULL,54,9513,0);
INSERT INTO "django_geo_db_location" VALUES(16691,NULL,'Mechanicsville, VA 23116',6882,222,NULL,54,9514,0);
INSERT INTO "django_geo_db_location" VALUES(16692,NULL,'Mineral, VA',6885,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16693,NULL,'Mineral, VA 23117',6885,222,NULL,54,9515,0);
INSERT INTO "django_geo_db_location" VALUES(16694,NULL,'Moon, VA',6886,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16695,NULL,'Moon, VA 23119',6886,222,NULL,54,9516,0);
INSERT INTO "django_geo_db_location" VALUES(16696,NULL,'Moseley, VA',6887,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16697,NULL,'Moseley, VA 23120',6887,222,NULL,54,9517,0);
INSERT INTO "django_geo_db_location" VALUES(16698,NULL,'New Canton, VA',6888,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16699,NULL,'New Canton, VA 23123',6888,222,NULL,54,9518,0);
INSERT INTO "django_geo_db_location" VALUES(16700,NULL,'New Kent, VA',6889,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16701,NULL,'New Kent, VA 23124',6889,222,NULL,54,9519,0);
INSERT INTO "django_geo_db_location" VALUES(16702,NULL,'New Point, VA',6890,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16703,NULL,'New Point, VA 23125',6890,222,NULL,54,9520,0);
INSERT INTO "django_geo_db_location" VALUES(16704,NULL,'Newtown, VA',6891,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16705,NULL,'Newtown, VA 23126',6891,222,NULL,54,9521,0);
INSERT INTO "django_geo_db_location" VALUES(16706,NULL,'Norge, VA',6892,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16707,NULL,'Norge, VA 23127',6892,222,NULL,54,9522,0);
INSERT INTO "django_geo_db_location" VALUES(16708,NULL,'North, VA',6893,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16709,NULL,'North, VA 23128',6893,222,NULL,54,9523,0);
INSERT INTO "django_geo_db_location" VALUES(16710,NULL,'Oilville, VA',6894,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16711,NULL,'Oilville, VA 23129',6894,222,NULL,54,9524,0);
INSERT INTO "django_geo_db_location" VALUES(16712,NULL,'Onemo, VA',6895,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16713,NULL,'Onemo, VA 23130',6895,222,NULL,54,9525,0);
INSERT INTO "django_geo_db_location" VALUES(16714,NULL,'Ordinary, VA',6896,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16715,NULL,'Ordinary, VA 23131',6896,222,NULL,54,9526,0);
INSERT INTO "django_geo_db_location" VALUES(16716,NULL,'Port Haywood, VA',6897,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16717,NULL,'Port Haywood, VA 23138',6897,222,NULL,54,9527,0);
INSERT INTO "django_geo_db_location" VALUES(16718,NULL,'Powhatan, VA',6898,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16719,NULL,'Powhatan, VA 23139',6898,222,NULL,54,9528,0);
INSERT INTO "django_geo_db_location" VALUES(16720,NULL,'Providence Forge, VA',6899,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16721,NULL,'Providence Forge, VA 23140',6899,222,NULL,54,9529,0);
INSERT INTO "django_geo_db_location" VALUES(16722,NULL,'Quinton, VA',6900,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16723,NULL,'Quinton, VA 23141',6900,222,NULL,54,9530,0);
INSERT INTO "django_geo_db_location" VALUES(16724,NULL,'Rockville, VA',6901,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16725,NULL,'Rockville, VA 23146',6901,222,NULL,54,9531,0);
INSERT INTO "django_geo_db_location" VALUES(16726,NULL,'Ruthville, VA',6902,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16727,NULL,'Ruthville, VA 23147',6902,222,NULL,54,9532,0);
INSERT INTO "django_geo_db_location" VALUES(16728,NULL,'Saint Stephens Church, VA',6903,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16729,NULL,'Saint Stephens Church, VA 23148',6903,222,NULL,54,9533,0);
INSERT INTO "django_geo_db_location" VALUES(16730,NULL,'Saluda, VA',6904,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16731,NULL,'Saluda, VA 23149',6904,222,NULL,54,9534,0);
INSERT INTO "django_geo_db_location" VALUES(16732,NULL,'Sandston, VA',6905,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16733,NULL,'Sandston, VA 23150',6905,222,NULL,54,9535,0);
INSERT INTO "django_geo_db_location" VALUES(16734,NULL,'Sandy Hook, VA',6906,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16735,NULL,'Sandy Hook, VA 23153',6906,222,NULL,54,9536,0);
INSERT INTO "django_geo_db_location" VALUES(16736,NULL,'Schley, VA',6907,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16737,NULL,'Schley, VA 23154',6907,222,NULL,54,9537,0);
INSERT INTO "django_geo_db_location" VALUES(16738,NULL,'Severn, VA',6908,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16739,NULL,'Severn, VA 23155',6908,222,NULL,54,9538,0);
INSERT INTO "django_geo_db_location" VALUES(16740,NULL,'Shacklefords, VA',6909,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16741,NULL,'Shacklefords, VA 23156',6909,222,NULL,54,9539,0);
INSERT INTO "django_geo_db_location" VALUES(16742,NULL,'State Farm, VA',6910,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16743,NULL,'State Farm, VA 23160',6910,222,NULL,54,9540,0);
INSERT INTO "django_geo_db_location" VALUES(16744,NULL,'Stevensville, VA',6911,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16745,NULL,'Stevensville, VA 23161',6911,222,NULL,54,9541,0);
INSERT INTO "django_geo_db_location" VALUES(16746,NULL,'Studley, VA',6912,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16747,NULL,'Studley, VA 23162',6912,222,NULL,54,9542,0);
INSERT INTO "django_geo_db_location" VALUES(16748,NULL,'Susan, VA',6913,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16749,NULL,'Susan, VA 23163',6913,222,NULL,54,9543,0);
INSERT INTO "django_geo_db_location" VALUES(16750,NULL,'Toano, VA',6914,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16751,NULL,'Toano, VA 23168',6914,222,NULL,54,9544,0);
INSERT INTO "django_geo_db_location" VALUES(16752,NULL,'Topping, VA',6915,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16753,NULL,'Topping, VA 23169',6915,222,NULL,54,9545,0);
INSERT INTO "django_geo_db_location" VALUES(16754,NULL,'Trevilians, VA',6916,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16755,NULL,'Trevilians, VA 23170',6916,222,NULL,54,9546,0);
INSERT INTO "django_geo_db_location" VALUES(16756,NULL,'University Of Richmond, VA',6917,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16757,NULL,'University Of Richmond, VA 23173',6917,222,NULL,54,9547,0);
INSERT INTO "django_geo_db_location" VALUES(16758,NULL,'Urbanna, VA',6918,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16759,NULL,'Urbanna, VA 23175',6918,222,NULL,54,9548,0);
INSERT INTO "django_geo_db_location" VALUES(16760,NULL,'Wake, VA',6919,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16761,NULL,'Wake, VA 23176',6919,222,NULL,54,9549,0);
INSERT INTO "django_geo_db_location" VALUES(16762,NULL,'Walkerton, VA',6920,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16763,NULL,'Walkerton, VA 23177',6920,222,NULL,54,9550,0);
INSERT INTO "django_geo_db_location" VALUES(16764,NULL,'Ware Neck, VA',6921,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16765,NULL,'Ware Neck, VA 23178',6921,222,NULL,54,9551,0);
INSERT INTO "django_geo_db_location" VALUES(16766,NULL,'Water View, VA',6922,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16767,NULL,'Water View, VA 23180',6922,222,NULL,54,9552,0);
INSERT INTO "django_geo_db_location" VALUES(16768,NULL,'West Point, VA',6923,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16769,NULL,'West Point, VA 23181',6923,222,NULL,54,9553,0);
INSERT INTO "django_geo_db_location" VALUES(16770,NULL,'White Marsh, VA',6924,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16771,NULL,'White Marsh, VA 23183',6924,222,NULL,54,9554,0);
INSERT INTO "django_geo_db_location" VALUES(16772,NULL,'Wicomico, VA',6925,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16773,NULL,'Wicomico, VA 23184',6925,222,NULL,54,9555,0);
INSERT INTO "django_geo_db_location" VALUES(16774,NULL,'Williamsburg, VA',6926,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16775,NULL,'Williamsburg, VA 23185',6926,222,NULL,54,9556,0);
INSERT INTO "django_geo_db_location" VALUES(16776,NULL,'Williamsburg, VA 23186',6926,222,NULL,54,9557,0);
INSERT INTO "django_geo_db_location" VALUES(16777,NULL,'Williamsburg, VA 23187',6926,222,NULL,54,9558,0);
INSERT INTO "django_geo_db_location" VALUES(16778,NULL,'Williamsburg, VA 23188',6926,222,NULL,54,9559,0);
INSERT INTO "django_geo_db_location" VALUES(16779,NULL,'Woods Cross Roads, VA',6927,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16780,NULL,'Woods Cross Roads, VA 23190',6927,222,NULL,54,9560,0);
INSERT INTO "django_geo_db_location" VALUES(16781,NULL,'Zanoni, VA',6928,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16782,NULL,'Zanoni, VA 23191',6928,222,NULL,54,9561,0);
INSERT INTO "django_geo_db_location" VALUES(16783,NULL,'Montpelier, VA',6929,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16784,NULL,'Montpelier, VA 23192',6929,222,NULL,54,9562,0);
INSERT INTO "django_geo_db_location" VALUES(16785,NULL,'Richmond, VA',6930,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16786,NULL,'Richmond, VA 23201',6930,222,NULL,54,9563,0);
INSERT INTO "django_geo_db_location" VALUES(16787,NULL,'Richmond, VA 23218',6930,222,NULL,54,9564,0);
INSERT INTO "django_geo_db_location" VALUES(16788,NULL,'Richmond, VA 23219',6930,222,NULL,54,9565,0);
INSERT INTO "django_geo_db_location" VALUES(16789,NULL,'Richmond, VA 23220',6930,222,NULL,54,9566,0);
INSERT INTO "django_geo_db_location" VALUES(16790,NULL,'Richmond, VA 23221',6930,222,NULL,54,9567,0);
INSERT INTO "django_geo_db_location" VALUES(16791,NULL,'Richmond, VA 23222',6930,222,NULL,54,9568,0);
INSERT INTO "django_geo_db_location" VALUES(16792,NULL,'Richmond, VA 23223',6930,222,NULL,54,9569,0);
INSERT INTO "django_geo_db_location" VALUES(16793,NULL,'Richmond, VA 23224',6930,222,NULL,54,9570,0);
INSERT INTO "django_geo_db_location" VALUES(16794,NULL,'Richmond, VA 23225',6930,222,NULL,54,9571,0);
INSERT INTO "django_geo_db_location" VALUES(16795,NULL,'Richmond, VA 23226',6930,222,NULL,54,9572,0);
INSERT INTO "django_geo_db_location" VALUES(16796,NULL,'Richmond, VA 23227',6930,222,NULL,54,9573,0);
INSERT INTO "django_geo_db_location" VALUES(16797,NULL,'Richmond, VA 23228',6930,222,NULL,54,9574,0);
INSERT INTO "django_geo_db_location" VALUES(16798,NULL,'Richmond, VA 23229',6930,222,NULL,54,9575,0);
INSERT INTO "django_geo_db_location" VALUES(16799,NULL,'Richmond, VA 23230',6930,222,NULL,54,9576,0);
INSERT INTO "django_geo_db_location" VALUES(16800,NULL,'Richmond, VA 23231',6930,222,NULL,54,9577,0);
INSERT INTO "django_geo_db_location" VALUES(16801,NULL,'Richmond, VA 23232',6930,222,NULL,54,9578,0);
INSERT INTO "django_geo_db_location" VALUES(16802,NULL,'Richmond, VA 23233',6930,222,NULL,54,9579,0);
INSERT INTO "django_geo_db_location" VALUES(16803,NULL,'Richmond, VA 23234',6930,222,NULL,54,9580,0);
INSERT INTO "django_geo_db_location" VALUES(16804,NULL,'Richmond, VA 23235',6930,222,NULL,54,9581,0);
INSERT INTO "django_geo_db_location" VALUES(16805,NULL,'Richmond, VA 23236',6930,222,NULL,54,9582,0);
INSERT INTO "django_geo_db_location" VALUES(16806,NULL,'Richmond, VA 23237',6930,222,NULL,54,9583,0);
INSERT INTO "django_geo_db_location" VALUES(16807,NULL,'Richmond, VA 23238',6930,222,NULL,54,9584,0);
INSERT INTO "django_geo_db_location" VALUES(16808,NULL,'Richmond, VA 23240',6930,222,NULL,54,9585,0);
INSERT INTO "django_geo_db_location" VALUES(16809,NULL,'Richmond, VA 23241',6930,222,NULL,54,9586,0);
INSERT INTO "django_geo_db_location" VALUES(16810,NULL,'Richmond, VA 23242',6930,222,NULL,54,9587,0);
INSERT INTO "django_geo_db_location" VALUES(16811,NULL,'Richmond, VA 23249',6930,222,NULL,54,9588,0);
INSERT INTO "django_geo_db_location" VALUES(16812,NULL,'Richmond, VA 23250',6930,222,NULL,54,9589,0);
INSERT INTO "django_geo_db_location" VALUES(16813,NULL,'Richmond, VA 23255',6930,222,NULL,54,9590,0);
INSERT INTO "django_geo_db_location" VALUES(16814,NULL,'Richmond, VA 23260',6930,222,NULL,54,9591,0);
INSERT INTO "django_geo_db_location" VALUES(16815,NULL,'Richmond, VA 23261',6930,222,NULL,54,9592,0);
INSERT INTO "django_geo_db_location" VALUES(16816,NULL,'Richmond, VA 23266',6930,222,NULL,54,9593,0);
INSERT INTO "django_geo_db_location" VALUES(16817,NULL,'Richmond, VA 23269',6930,222,NULL,54,9594,0);
INSERT INTO "django_geo_db_location" VALUES(16818,NULL,'Richmond, VA 23270',6930,222,NULL,54,9595,0);
INSERT INTO "django_geo_db_location" VALUES(16819,NULL,'Richmond, VA 23272',6930,222,NULL,54,9596,0);
INSERT INTO "django_geo_db_location" VALUES(16820,NULL,'Richmond, VA 23273',6930,222,NULL,54,9597,0);
INSERT INTO "django_geo_db_location" VALUES(16821,NULL,'Richmond, VA 23274',6930,222,NULL,54,9598,0);
INSERT INTO "django_geo_db_location" VALUES(16822,NULL,'Richmond, VA 23275',6930,222,NULL,54,9599,0);
INSERT INTO "django_geo_db_location" VALUES(16823,NULL,'Richmond, VA 23276',6930,222,NULL,54,9600,0);
INSERT INTO "django_geo_db_location" VALUES(16824,NULL,'Richmond, VA 23278',6930,222,NULL,54,9601,0);
INSERT INTO "django_geo_db_location" VALUES(16825,NULL,'Richmond, VA 23279',6930,222,NULL,54,9602,0);
INSERT INTO "django_geo_db_location" VALUES(16826,NULL,'Richmond, VA 23280',6930,222,NULL,54,9603,0);
INSERT INTO "django_geo_db_location" VALUES(16827,NULL,'Richmond, VA 23282',6930,222,NULL,54,9604,0);
INSERT INTO "django_geo_db_location" VALUES(16828,NULL,'Richmond, VA 23284',6930,222,NULL,54,9605,0);
INSERT INTO "django_geo_db_location" VALUES(16829,NULL,'Richmond, VA 23285',6930,222,NULL,54,9606,0);
INSERT INTO "django_geo_db_location" VALUES(16830,NULL,'Richmond, VA 23286',6930,222,NULL,54,9607,0);
INSERT INTO "django_geo_db_location" VALUES(16831,NULL,'Richmond, VA 23288',6930,222,NULL,54,9608,0);
INSERT INTO "django_geo_db_location" VALUES(16832,NULL,'Richmond, VA 23289',6930,222,NULL,54,9609,0);
INSERT INTO "django_geo_db_location" VALUES(16833,NULL,'Richmond, VA 23290',6930,222,NULL,54,9610,0);
INSERT INTO "django_geo_db_location" VALUES(16834,NULL,'Richmond, VA 23291',6930,222,NULL,54,9611,0);
INSERT INTO "django_geo_db_location" VALUES(16835,NULL,'Richmond, VA 23292',6930,222,NULL,54,9612,0);
INSERT INTO "django_geo_db_location" VALUES(16836,NULL,'Richmond, VA 23293',6930,222,NULL,54,9613,0);
INSERT INTO "django_geo_db_location" VALUES(16837,NULL,'Richmond, VA 23294',6930,222,NULL,54,9614,0);
INSERT INTO "django_geo_db_location" VALUES(16838,NULL,'Richmond, VA 23297',6930,222,NULL,54,9615,0);
INSERT INTO "django_geo_db_location" VALUES(16839,NULL,'Richmond, VA 23298',6930,222,NULL,54,9616,0);
INSERT INTO "django_geo_db_location" VALUES(16840,NULL,'Accomac, VA',6931,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16841,NULL,'Accomac, VA 23301',6931,222,NULL,54,9617,0);
INSERT INTO "django_geo_db_location" VALUES(16842,NULL,'Assawoman, VA',6932,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16843,NULL,'Assawoman, VA 23302',6932,222,NULL,54,9618,0);
INSERT INTO "django_geo_db_location" VALUES(16844,NULL,'Atlantic, VA',6933,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16845,NULL,'Atlantic, VA 23303',6933,222,NULL,54,9619,0);
INSERT INTO "django_geo_db_location" VALUES(16846,NULL,'Battery Park, VA',6934,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16847,NULL,'Battery Park, VA 23304',6934,222,NULL,54,9620,0);
INSERT INTO "django_geo_db_location" VALUES(16848,NULL,'Belle Haven, VA',6935,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16849,NULL,'Belle Haven, VA 23306',6935,222,NULL,54,9621,0);
INSERT INTO "django_geo_db_location" VALUES(16850,NULL,'Birdsnest, VA',6936,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16851,NULL,'Birdsnest, VA 23307',6936,222,NULL,54,9622,0);
INSERT INTO "django_geo_db_location" VALUES(16852,NULL,'Bloxom, VA',6937,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16853,NULL,'Bloxom, VA 23308',6937,222,NULL,54,9623,0);
INSERT INTO "django_geo_db_location" VALUES(16854,NULL,'Cape Charles, VA',6938,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16855,NULL,'Cape Charles, VA 23310',6938,222,NULL,54,9624,0);
INSERT INTO "django_geo_db_location" VALUES(16856,NULL,'Capeville, VA',6939,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16857,NULL,'Capeville, VA 23313',6939,222,NULL,54,9625,0);
INSERT INTO "django_geo_db_location" VALUES(16858,NULL,'Carrollton, VA',6940,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16859,NULL,'Carrollton, VA 23314',6940,222,NULL,54,9626,0);
INSERT INTO "django_geo_db_location" VALUES(16860,NULL,'Carrsville, VA',6941,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16861,NULL,'Carrsville, VA 23315',6941,222,NULL,54,9627,0);
INSERT INTO "django_geo_db_location" VALUES(16862,NULL,'Cheriton, VA',6942,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16863,NULL,'Cheriton, VA 23316',6942,222,NULL,54,9628,0);
INSERT INTO "django_geo_db_location" VALUES(16864,NULL,'Chesapeake, VA',6943,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16865,NULL,'Chesapeake, VA 23320',6943,222,NULL,54,9629,0);
INSERT INTO "django_geo_db_location" VALUES(16866,NULL,'Chesapeake, VA 23321',6943,222,NULL,54,9630,0);
INSERT INTO "django_geo_db_location" VALUES(16867,NULL,'Chesapeake, VA 23322',6943,222,NULL,54,9631,0);
INSERT INTO "django_geo_db_location" VALUES(16868,NULL,'Chesapeake, VA 23323',6943,222,NULL,54,9632,0);
INSERT INTO "django_geo_db_location" VALUES(16869,NULL,'Chesapeake, VA 23324',6943,222,NULL,54,9633,0);
INSERT INTO "django_geo_db_location" VALUES(16870,NULL,'Chesapeake, VA 23325',6943,222,NULL,54,9634,0);
INSERT INTO "django_geo_db_location" VALUES(16871,NULL,'Chesapeake, VA 23326',6943,222,NULL,54,9635,0);
INSERT INTO "django_geo_db_location" VALUES(16872,NULL,'Chesapeake, VA 23327',6943,222,NULL,54,9636,0);
INSERT INTO "django_geo_db_location" VALUES(16873,NULL,'Chesapeake, VA 23328',6943,222,NULL,54,9637,0);
INSERT INTO "django_geo_db_location" VALUES(16874,NULL,'Chincoteague Island, VA',6944,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16875,NULL,'Chincoteague Island, VA 23336',6944,222,NULL,54,9638,0);
INSERT INTO "django_geo_db_location" VALUES(16876,NULL,'Wallops Island, VA',6945,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16877,NULL,'Wallops Island, VA 23337',6945,222,NULL,54,9639,0);
INSERT INTO "django_geo_db_location" VALUES(16878,NULL,'Craddockville, VA',6946,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16879,NULL,'Craddockville, VA 23341',6946,222,NULL,54,9640,0);
INSERT INTO "django_geo_db_location" VALUES(16880,NULL,'Davis Wharf, VA',6947,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16881,NULL,'Davis Wharf, VA 23345',6947,222,NULL,54,9641,0);
INSERT INTO "django_geo_db_location" VALUES(16882,NULL,'Eastville, VA',6948,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16883,NULL,'Eastville, VA 23347',6948,222,NULL,54,9642,0);
INSERT INTO "django_geo_db_location" VALUES(16884,NULL,'Exmore, VA',6949,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16885,NULL,'Exmore, VA 23350',6949,222,NULL,54,9643,0);
INSERT INTO "django_geo_db_location" VALUES(16886,NULL,'Exmore, VA 23351',6949,222,NULL,54,9644,0);
INSERT INTO "django_geo_db_location" VALUES(16887,NULL,'Franktown, VA',6950,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16888,NULL,'Franktown, VA 23354',6950,222,NULL,54,9645,0);
INSERT INTO "django_geo_db_location" VALUES(16889,NULL,'Greenbackville, VA',6951,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16890,NULL,'Greenbackville, VA 23356',6951,222,NULL,54,9646,0);
INSERT INTO "django_geo_db_location" VALUES(16891,NULL,'Greenbush, VA',6952,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16892,NULL,'Greenbush, VA 23357',6952,222,NULL,54,9647,0);
INSERT INTO "django_geo_db_location" VALUES(16893,NULL,'Hacksneck, VA',6953,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16894,NULL,'Hacksneck, VA 23358',6953,222,NULL,54,9648,0);
INSERT INTO "django_geo_db_location" VALUES(16895,NULL,'Hallwood, VA',6954,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16896,NULL,'Hallwood, VA 23359',6954,222,NULL,54,9649,0);
INSERT INTO "django_geo_db_location" VALUES(16897,NULL,'Exmore, VA 23380',6949,222,NULL,54,9650,0);
INSERT INTO "django_geo_db_location" VALUES(16898,NULL,'Harborton, VA',6955,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16899,NULL,'Harborton, VA 23389',6955,222,NULL,54,9651,0);
INSERT INTO "django_geo_db_location" VALUES(16900,NULL,'Horntown, VA',6956,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16901,NULL,'Horntown, VA 23395',6956,222,NULL,54,9652,0);
INSERT INTO "django_geo_db_location" VALUES(16902,NULL,'Oak Hall, VA',6957,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16903,NULL,'Oak Hall, VA 23396',6957,222,NULL,54,9653,0);
INSERT INTO "django_geo_db_location" VALUES(16904,NULL,'Isle Of Wight, VA',6958,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16905,NULL,'Isle Of Wight, VA 23397',6958,222,NULL,54,9654,0);
INSERT INTO "django_geo_db_location" VALUES(16906,NULL,'Jamesville, VA',6959,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16907,NULL,'Jamesville, VA 23398',6959,222,NULL,54,9655,0);
INSERT INTO "django_geo_db_location" VALUES(16908,NULL,'Jenkins Bridge, VA',6960,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16909,NULL,'Jenkins Bridge, VA 23399',6960,222,NULL,54,9656,0);
INSERT INTO "django_geo_db_location" VALUES(16910,NULL,'Keller, VA',6961,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16911,NULL,'Keller, VA 23401',6961,222,NULL,54,9657,0);
INSERT INTO "django_geo_db_location" VALUES(16912,NULL,'Locustville, VA',6962,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16913,NULL,'Locustville, VA 23404',6962,222,NULL,54,9658,0);
INSERT INTO "django_geo_db_location" VALUES(16914,NULL,'Machipongo, VA',6963,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16915,NULL,'Machipongo, VA 23405',6963,222,NULL,54,9659,0);
INSERT INTO "django_geo_db_location" VALUES(16916,NULL,'Mappsville, VA',6964,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16917,NULL,'Mappsville, VA 23407',6964,222,NULL,54,9660,0);
INSERT INTO "django_geo_db_location" VALUES(16918,NULL,'Marionville, VA',6965,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16919,NULL,'Marionville, VA 23408',6965,222,NULL,54,9661,0);
INSERT INTO "django_geo_db_location" VALUES(16920,NULL,'Mears, VA',6966,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16921,NULL,'Mears, VA 23409',6966,222,NULL,54,9662,0);
INSERT INTO "django_geo_db_location" VALUES(16922,NULL,'Melfa, VA',6967,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16923,NULL,'Melfa, VA 23410',6967,222,NULL,54,9663,0);
INSERT INTO "django_geo_db_location" VALUES(16924,NULL,'Modest Town, VA',6968,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16925,NULL,'Modest Town, VA 23412',6968,222,NULL,54,9664,0);
INSERT INTO "django_geo_db_location" VALUES(16926,NULL,'Nassawadox, VA',6969,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16927,NULL,'Nassawadox, VA 23413',6969,222,NULL,54,9665,0);
INSERT INTO "django_geo_db_location" VALUES(16928,NULL,'Nelsonia, VA',6970,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16929,NULL,'Nelsonia, VA 23414',6970,222,NULL,54,9666,0);
INSERT INTO "django_geo_db_location" VALUES(16930,NULL,'New Church, VA',6971,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16931,NULL,'New Church, VA 23415',6971,222,NULL,54,9667,0);
INSERT INTO "django_geo_db_location" VALUES(16932,NULL,'Oak Hall, VA 23416',6957,222,NULL,54,9668,0);
INSERT INTO "django_geo_db_location" VALUES(16933,NULL,'Onancock, VA',6972,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16934,NULL,'Onancock, VA 23417',6972,222,NULL,54,9669,0);
INSERT INTO "django_geo_db_location" VALUES(16935,NULL,'Onley, VA',6973,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16936,NULL,'Onley, VA 23418',6973,222,NULL,54,9670,0);
INSERT INTO "django_geo_db_location" VALUES(16937,NULL,'Oyster, VA',6974,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16938,NULL,'Oyster, VA 23419',6974,222,NULL,54,9671,0);
INSERT INTO "django_geo_db_location" VALUES(16939,NULL,'Painter, VA',6975,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16940,NULL,'Painter, VA 23420',6975,222,NULL,54,9672,0);
INSERT INTO "django_geo_db_location" VALUES(16941,NULL,'Parksley, VA',6976,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16942,NULL,'Parksley, VA 23421',6976,222,NULL,54,9673,0);
INSERT INTO "django_geo_db_location" VALUES(16943,NULL,'Pungoteague, VA',6977,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16944,NULL,'Pungoteague, VA 23422',6977,222,NULL,54,9674,0);
INSERT INTO "django_geo_db_location" VALUES(16945,NULL,'Quinby, VA',6978,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16946,NULL,'Quinby, VA 23423',6978,222,NULL,54,9675,0);
INSERT INTO "django_geo_db_location" VALUES(16947,NULL,'Rescue, VA',6979,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16948,NULL,'Rescue, VA 23424',6979,222,NULL,54,9676,0);
INSERT INTO "django_geo_db_location" VALUES(16949,NULL,'Sanford, VA',6980,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16950,NULL,'Sanford, VA 23426',6980,222,NULL,54,9677,0);
INSERT INTO "django_geo_db_location" VALUES(16951,NULL,'Saxis, VA',6981,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16952,NULL,'Saxis, VA 23427',6981,222,NULL,54,9678,0);
INSERT INTO "django_geo_db_location" VALUES(16953,NULL,'Seaview, VA',6982,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16954,NULL,'Seaview, VA 23429',6982,222,NULL,54,9679,0);
INSERT INTO "django_geo_db_location" VALUES(16955,NULL,'Smithfield, VA',6983,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16956,NULL,'Smithfield, VA 23430',6983,222,NULL,54,9680,0);
INSERT INTO "django_geo_db_location" VALUES(16957,NULL,'Smithfield, VA 23431',6983,222,NULL,54,9681,0);
INSERT INTO "django_geo_db_location" VALUES(16958,NULL,'Suffolk, VA',6984,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16959,NULL,'Suffolk, VA 23432',6984,222,NULL,54,9682,0);
INSERT INTO "django_geo_db_location" VALUES(16960,NULL,'Suffolk, VA 23433',6984,222,NULL,54,9683,0);
INSERT INTO "django_geo_db_location" VALUES(16961,NULL,'Suffolk, VA 23434',6984,222,NULL,54,9684,0);
INSERT INTO "django_geo_db_location" VALUES(16962,NULL,'Suffolk, VA 23435',6984,222,NULL,54,9685,0);
INSERT INTO "django_geo_db_location" VALUES(16963,NULL,'Suffolk, VA 23436',6984,222,NULL,54,9686,0);
INSERT INTO "django_geo_db_location" VALUES(16964,NULL,'Suffolk, VA 23437',6984,222,NULL,54,9687,0);
INSERT INTO "django_geo_db_location" VALUES(16965,NULL,'Suffolk, VA 23438',6984,222,NULL,54,9688,0);
INSERT INTO "django_geo_db_location" VALUES(16966,NULL,'Suffolk, VA 23439',6984,222,NULL,54,9689,0);
INSERT INTO "django_geo_db_location" VALUES(16967,NULL,'Tangier, VA',6985,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16968,NULL,'Tangier, VA 23440',6985,222,NULL,54,9690,0);
INSERT INTO "django_geo_db_location" VALUES(16969,NULL,'Tasley, VA',6986,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16970,NULL,'Tasley, VA 23441',6986,222,NULL,54,9691,0);
INSERT INTO "django_geo_db_location" VALUES(16971,NULL,'Temperanceville, VA',6987,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16972,NULL,'Temperanceville, VA 23442',6987,222,NULL,54,9692,0);
INSERT INTO "django_geo_db_location" VALUES(16973,NULL,'Townsend, VA',6988,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16974,NULL,'Townsend, VA 23443',6988,222,NULL,54,9693,0);
INSERT INTO "django_geo_db_location" VALUES(16975,NULL,'Virginia Beach, VA',6989,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16976,NULL,'Virginia Beach, VA 23450',6989,222,NULL,54,9694,0);
INSERT INTO "django_geo_db_location" VALUES(16977,NULL,'Virginia Beach, VA 23451',6989,222,NULL,54,9695,0);
INSERT INTO "django_geo_db_location" VALUES(16978,NULL,'Virginia Beach, VA 23452',6989,222,NULL,54,9696,0);
INSERT INTO "django_geo_db_location" VALUES(16979,NULL,'Virginia Beach, VA 23453',6989,222,NULL,54,9697,0);
INSERT INTO "django_geo_db_location" VALUES(16980,NULL,'Virginia Beach, VA 23454',6989,222,NULL,54,9698,0);
INSERT INTO "django_geo_db_location" VALUES(16981,NULL,'Virginia Beach, VA 23455',6989,222,NULL,54,9699,0);
INSERT INTO "django_geo_db_location" VALUES(16982,NULL,'Virginia Beach, VA 23456',6989,222,NULL,54,9700,0);
INSERT INTO "django_geo_db_location" VALUES(16983,NULL,'Virginia Beach, VA 23457',6989,222,NULL,54,9701,0);
INSERT INTO "django_geo_db_location" VALUES(16984,NULL,'Virginia Beach, VA 23458',6989,222,NULL,54,9702,0);
INSERT INTO "django_geo_db_location" VALUES(16985,NULL,'Virginia Beach, VA 23459',6989,222,NULL,54,9703,0);
INSERT INTO "django_geo_db_location" VALUES(16986,NULL,'Virginia Beach, VA 23460',6989,222,NULL,54,9704,0);
INSERT INTO "django_geo_db_location" VALUES(16987,NULL,'Virginia Beach, VA 23461',6989,222,NULL,54,9705,0);
INSERT INTO "django_geo_db_location" VALUES(16988,NULL,'Virginia Beach, VA 23462',6989,222,NULL,54,9706,0);
INSERT INTO "django_geo_db_location" VALUES(16989,NULL,'Virginia Beach, VA 23463',6989,222,NULL,54,9707,0);
INSERT INTO "django_geo_db_location" VALUES(16990,NULL,'Virginia Beach, VA 23464',6989,222,NULL,54,9708,0);
INSERT INTO "django_geo_db_location" VALUES(16991,NULL,'Virginia Beach, VA 23465',6989,222,NULL,54,9709,0);
INSERT INTO "django_geo_db_location" VALUES(16992,NULL,'Virginia Beach, VA 23466',6989,222,NULL,54,9710,0);
INSERT INTO "django_geo_db_location" VALUES(16993,NULL,'Virginia Beach, VA 23467',6989,222,NULL,54,9711,0);
INSERT INTO "django_geo_db_location" VALUES(16994,NULL,'Virginia Beach, VA 23468',6989,222,NULL,54,9712,0);
INSERT INTO "django_geo_db_location" VALUES(16995,NULL,'Virginia Beach, VA 23471',6989,222,NULL,54,9713,0);
INSERT INTO "django_geo_db_location" VALUES(16996,NULL,'Gloucester Point, VA 23472',6849,222,NULL,54,9714,0);
INSERT INTO "django_geo_db_location" VALUES(16997,NULL,'Virginia Beach, VA 23479',6989,222,NULL,54,9715,0);
INSERT INTO "django_geo_db_location" VALUES(16998,NULL,'Wachapreague, VA',6990,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(16999,NULL,'Wachapreague, VA 23480',6990,222,NULL,54,9716,0);
INSERT INTO "django_geo_db_location" VALUES(17000,NULL,'Wardtown, VA',6991,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17001,NULL,'Wardtown, VA 23482',6991,222,NULL,54,9717,0);
INSERT INTO "django_geo_db_location" VALUES(17002,NULL,'Wattsville, VA',6992,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17003,NULL,'Wattsville, VA 23483',6992,222,NULL,54,9718,0);
INSERT INTO "django_geo_db_location" VALUES(17004,NULL,'Willis Wharf, VA',6993,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17005,NULL,'Willis Wharf, VA 23486',6993,222,NULL,54,9719,0);
INSERT INTO "django_geo_db_location" VALUES(17006,NULL,'Windsor, VA',6994,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17007,NULL,'Windsor, VA 23487',6994,222,NULL,54,9720,0);
INSERT INTO "django_geo_db_location" VALUES(17008,NULL,'Withams, VA',6995,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17009,NULL,'Withams, VA 23488',6995,222,NULL,54,9721,0);
INSERT INTO "django_geo_db_location" VALUES(17010,NULL,'Norfolk, VA',6996,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17011,NULL,'Norfolk, VA 23501',6996,222,NULL,54,9722,0);
INSERT INTO "django_geo_db_location" VALUES(17012,NULL,'Norfolk, VA 23502',6996,222,NULL,54,9723,0);
INSERT INTO "django_geo_db_location" VALUES(17013,NULL,'Norfolk, VA 23503',6996,222,NULL,54,9724,0);
INSERT INTO "django_geo_db_location" VALUES(17014,NULL,'Norfolk, VA 23504',6996,222,NULL,54,9725,0);
INSERT INTO "django_geo_db_location" VALUES(17015,NULL,'Norfolk, VA 23505',6996,222,NULL,54,9726,0);
INSERT INTO "django_geo_db_location" VALUES(17016,NULL,'Norfolk, VA 23506',6996,222,NULL,54,9727,0);
INSERT INTO "django_geo_db_location" VALUES(17017,NULL,'Norfolk, VA 23507',6996,222,NULL,54,9728,0);
INSERT INTO "django_geo_db_location" VALUES(17018,NULL,'Norfolk, VA 23508',6996,222,NULL,54,9729,0);
INSERT INTO "django_geo_db_location" VALUES(17019,NULL,'Norfolk, VA 23509',6996,222,NULL,54,9730,0);
INSERT INTO "django_geo_db_location" VALUES(17020,NULL,'Norfolk, VA 23510',6996,222,NULL,54,9731,0);
INSERT INTO "django_geo_db_location" VALUES(17021,NULL,'Norfolk, VA 23511',6996,222,NULL,54,9732,0);
INSERT INTO "django_geo_db_location" VALUES(17022,NULL,'Norfolk, VA 23512',6996,222,NULL,54,9733,0);
INSERT INTO "django_geo_db_location" VALUES(17023,NULL,'Norfolk, VA 23513',6996,222,NULL,54,9734,0);
INSERT INTO "django_geo_db_location" VALUES(17024,NULL,'Norfolk, VA 23514',6996,222,NULL,54,9735,0);
INSERT INTO "django_geo_db_location" VALUES(17025,NULL,'Norfolk, VA 23515',6996,222,NULL,54,9736,0);
INSERT INTO "django_geo_db_location" VALUES(17026,NULL,'Norfolk, VA 23517',6996,222,NULL,54,9737,0);
INSERT INTO "django_geo_db_location" VALUES(17027,NULL,'Norfolk, VA 23518',6996,222,NULL,54,9738,0);
INSERT INTO "django_geo_db_location" VALUES(17028,NULL,'Norfolk, VA 23519',6996,222,NULL,54,9739,0);
INSERT INTO "django_geo_db_location" VALUES(17029,NULL,'Norfolk, VA 23520',6996,222,NULL,54,9740,0);
INSERT INTO "django_geo_db_location" VALUES(17030,NULL,'Norfolk, VA 23521',6996,222,NULL,54,9741,0);
INSERT INTO "django_geo_db_location" VALUES(17031,NULL,'Norfolk, VA 23523',6996,222,NULL,54,9742,0);
INSERT INTO "django_geo_db_location" VALUES(17032,NULL,'Norfolk, VA 23529',6996,222,NULL,54,9743,0);
INSERT INTO "django_geo_db_location" VALUES(17033,NULL,'Norfolk, VA 23530',6996,222,NULL,54,9744,0);
INSERT INTO "django_geo_db_location" VALUES(17034,NULL,'Norfolk, VA 23541',6996,222,NULL,54,9745,0);
INSERT INTO "django_geo_db_location" VALUES(17035,NULL,'Norfolk, VA 23551',6996,222,NULL,54,9746,0);
INSERT INTO "django_geo_db_location" VALUES(17036,NULL,'Newport News, VA 23601',6682,222,NULL,54,9747,0);
INSERT INTO "django_geo_db_location" VALUES(17037,NULL,'Newport News, VA 23602',6682,222,NULL,54,9748,0);
INSERT INTO "django_geo_db_location" VALUES(17038,NULL,'Newport News, VA 23603',6682,222,NULL,54,9749,0);
INSERT INTO "django_geo_db_location" VALUES(17039,NULL,'Fort Eustis, VA',6997,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17040,NULL,'Fort Eustis, VA 23604',6997,222,NULL,54,9750,0);
INSERT INTO "django_geo_db_location" VALUES(17041,NULL,'Newport News, VA 23605',6682,222,NULL,54,9751,0);
INSERT INTO "django_geo_db_location" VALUES(17042,NULL,'Newport News, VA 23606',6682,222,NULL,54,9752,0);
INSERT INTO "django_geo_db_location" VALUES(17043,NULL,'Newport News, VA 23607',6682,222,NULL,54,9753,0);
INSERT INTO "django_geo_db_location" VALUES(17044,NULL,'Newport News, VA 23608',6682,222,NULL,54,9754,0);
INSERT INTO "django_geo_db_location" VALUES(17045,NULL,'Newport News, VA 23609',6682,222,NULL,54,9755,0);
INSERT INTO "django_geo_db_location" VALUES(17046,NULL,'Newport News, VA 23612',6682,222,NULL,54,9756,0);
INSERT INTO "django_geo_db_location" VALUES(17047,NULL,'Franklin, VA',6998,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17048,NULL,'Franklin, VA 23620',6998,222,NULL,54,9757,0);
INSERT INTO "django_geo_db_location" VALUES(17049,NULL,'Newport News, VA 23628',6682,222,NULL,54,9758,0);
INSERT INTO "django_geo_db_location" VALUES(17050,NULL,'Hampton, VA',6999,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17051,NULL,'Hampton, VA 23630',6999,222,NULL,54,9759,0);
INSERT INTO "django_geo_db_location" VALUES(17052,NULL,'Hampton, VA 23631',6999,222,NULL,54,9760,0);
INSERT INTO "django_geo_db_location" VALUES(17053,NULL,'Virginia Beach, VA 23642',6989,222,NULL,54,9761,0);
INSERT INTO "django_geo_db_location" VALUES(17054,NULL,'Fort Monroe, VA',7000,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17055,NULL,'Fort Monroe, VA 23651',7000,222,NULL,54,9762,0);
INSERT INTO "django_geo_db_location" VALUES(17056,NULL,'Hampton, VA 23653',6999,222,NULL,54,9763,0);
INSERT INTO "django_geo_db_location" VALUES(17057,NULL,'Hampton, VA 23661',6999,222,NULL,54,9764,0);
INSERT INTO "django_geo_db_location" VALUES(17058,NULL,'Poquoson, VA',7001,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17059,NULL,'Poquoson, VA 23662',7001,222,NULL,54,9765,0);
INSERT INTO "django_geo_db_location" VALUES(17060,NULL,'Hampton, VA 23663',6999,222,NULL,54,9766,0);
INSERT INTO "django_geo_db_location" VALUES(17061,NULL,'Hampton, VA 23664',6999,222,NULL,54,9767,0);
INSERT INTO "django_geo_db_location" VALUES(17062,NULL,'Hampton, VA 23665',6999,222,NULL,54,9768,0);
INSERT INTO "django_geo_db_location" VALUES(17063,NULL,'Hampton, VA 23666',6999,222,NULL,54,9769,0);
INSERT INTO "django_geo_db_location" VALUES(17064,NULL,'Hampton, VA 23667',6999,222,NULL,54,9770,0);
INSERT INTO "django_geo_db_location" VALUES(17065,NULL,'Hampton, VA 23668',6999,222,NULL,54,9771,0);
INSERT INTO "django_geo_db_location" VALUES(17066,NULL,'Hampton, VA 23669',6999,222,NULL,54,9772,0);
INSERT INTO "django_geo_db_location" VALUES(17067,NULL,'Hampton, VA 23670',6999,222,NULL,54,9773,0);
INSERT INTO "django_geo_db_location" VALUES(17068,NULL,'Hampton, VA 23681',6999,222,NULL,54,9774,0);
INSERT INTO "django_geo_db_location" VALUES(17069,NULL,'Yorktown, VA',7002,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17070,NULL,'Yorktown, VA 23690',7002,222,NULL,54,9775,0);
INSERT INTO "django_geo_db_location" VALUES(17071,NULL,'Yorktown, VA 23691',7002,222,NULL,54,9776,0);
INSERT INTO "django_geo_db_location" VALUES(17072,NULL,'Yorktown, VA 23692',7002,222,NULL,54,9777,0);
INSERT INTO "django_geo_db_location" VALUES(17073,NULL,'Yorktown, VA 23693',7002,222,NULL,54,9778,0);
INSERT INTO "django_geo_db_location" VALUES(17074,NULL,'Lackey, VA',7003,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17075,NULL,'Lackey, VA 23694',7003,222,NULL,54,9779,0);
INSERT INTO "django_geo_db_location" VALUES(17076,NULL,'Seaford, VA',7004,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17077,NULL,'Seaford, VA 23696',7004,222,NULL,54,9780,0);
INSERT INTO "django_geo_db_location" VALUES(17078,NULL,'Portsmouth, VA',7005,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17079,NULL,'Portsmouth, VA 23701',7005,222,NULL,54,9781,0);
INSERT INTO "django_geo_db_location" VALUES(17080,NULL,'Portsmouth, VA 23702',7005,222,NULL,54,9782,0);
INSERT INTO "django_geo_db_location" VALUES(17081,NULL,'Portsmouth, VA 23703',7005,222,NULL,54,9783,0);
INSERT INTO "django_geo_db_location" VALUES(17082,NULL,'Portsmouth, VA 23704',7005,222,NULL,54,9784,0);
INSERT INTO "django_geo_db_location" VALUES(17083,NULL,'Portsmouth, VA 23705',7005,222,NULL,54,9785,0);
INSERT INTO "django_geo_db_location" VALUES(17084,NULL,'Portsmouth, VA 23707',7005,222,NULL,54,9786,0);
INSERT INTO "django_geo_db_location" VALUES(17085,NULL,'Portsmouth, VA 23708',7005,222,NULL,54,9787,0);
INSERT INTO "django_geo_db_location" VALUES(17086,NULL,'Portsmouth, VA 23709',7005,222,NULL,54,9788,0);
INSERT INTO "django_geo_db_location" VALUES(17087,NULL,'Fort Lee, VA',7006,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17088,NULL,'Fort Lee, VA 23801',7006,222,NULL,54,9789,0);
INSERT INTO "django_geo_db_location" VALUES(17089,NULL,'Petersburg, VA',7007,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17090,NULL,'Petersburg, VA 23803',7007,222,NULL,54,9790,0);
INSERT INTO "django_geo_db_location" VALUES(17091,NULL,'Petersburg, VA 23804',7007,222,NULL,54,9791,0);
INSERT INTO "django_geo_db_location" VALUES(17092,NULL,'Petersburg, VA 23805',7007,222,NULL,54,9792,0);
INSERT INTO "django_geo_db_location" VALUES(17093,NULL,'Petersburg, VA 23806',7007,222,NULL,54,9793,0);
INSERT INTO "django_geo_db_location" VALUES(17094,NULL,'Cape Charles, VA 23810',6938,222,NULL,54,9794,0);
INSERT INTO "django_geo_db_location" VALUES(17095,NULL,'Gloucester Point, VA 23814',6849,222,NULL,54,9795,0);
INSERT INTO "django_geo_db_location" VALUES(17096,NULL,'Alberta, VA',7008,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17097,NULL,'Alberta, VA 23821',7008,222,NULL,54,9796,0);
INSERT INTO "django_geo_db_location" VALUES(17098,NULL,'Ammon, VA',7009,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17099,NULL,'Ammon, VA 23822',7009,222,NULL,54,9797,0);
INSERT INTO "django_geo_db_location" VALUES(17100,NULL,'Blackstone, VA',7010,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17101,NULL,'Blackstone, VA 23824',7010,222,NULL,54,9798,0);
INSERT INTO "django_geo_db_location" VALUES(17102,NULL,'Boykins, VA',7011,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17103,NULL,'Boykins, VA 23827',7011,222,NULL,54,9799,0);
INSERT INTO "django_geo_db_location" VALUES(17104,NULL,'Branchville, VA',7012,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17105,NULL,'Branchville, VA 23828',7012,222,NULL,54,9800,0);
INSERT INTO "django_geo_db_location" VALUES(17106,NULL,'Capron, VA',7013,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17107,NULL,'Capron, VA 23829',7013,222,NULL,54,9801,0);
INSERT INTO "django_geo_db_location" VALUES(17108,NULL,'Carson, VA',7014,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17109,NULL,'Carson, VA 23830',7014,222,NULL,54,9802,0);
INSERT INTO "django_geo_db_location" VALUES(17110,NULL,'Chester, VA',7015,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17111,NULL,'Chester, VA 23831',7015,222,NULL,54,9803,0);
INSERT INTO "django_geo_db_location" VALUES(17112,NULL,'Chesterfield, VA',7016,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17113,NULL,'Chesterfield, VA 23832',7016,222,NULL,54,9804,0);
INSERT INTO "django_geo_db_location" VALUES(17114,NULL,'Church Road, VA',7017,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17115,NULL,'Church Road, VA 23833',7017,222,NULL,54,9805,0);
INSERT INTO "django_geo_db_location" VALUES(17116,NULL,'Colonial Heights, VA',7018,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17117,NULL,'Colonial Heights, VA 23834',7018,222,NULL,54,9806,0);
INSERT INTO "django_geo_db_location" VALUES(17118,NULL,'Chester, VA 23836',7015,222,NULL,54,9807,0);
INSERT INTO "django_geo_db_location" VALUES(17119,NULL,'Courtland, VA',7019,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17120,NULL,'Courtland, VA 23837',7019,222,NULL,54,9808,0);
INSERT INTO "django_geo_db_location" VALUES(17121,NULL,'Chesterfield, VA 23838',7016,222,NULL,54,9809,0);
INSERT INTO "django_geo_db_location" VALUES(17122,NULL,'Dendron, VA',7020,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17123,NULL,'Dendron, VA 23839',7020,222,NULL,54,9810,0);
INSERT INTO "django_geo_db_location" VALUES(17124,NULL,'Dewitt, VA',7021,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17125,NULL,'Dewitt, VA 23840',7021,222,NULL,54,9811,0);
INSERT INTO "django_geo_db_location" VALUES(17126,NULL,'Dinwiddie, VA',7022,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17127,NULL,'Dinwiddie, VA 23841',7022,222,NULL,54,9812,0);
INSERT INTO "django_geo_db_location" VALUES(17128,NULL,'Disputanta, VA',7023,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17129,NULL,'Disputanta, VA 23842',7023,222,NULL,54,9813,0);
INSERT INTO "django_geo_db_location" VALUES(17130,NULL,'Dolphin, VA',7024,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17131,NULL,'Dolphin, VA 23843',7024,222,NULL,54,9814,0);
INSERT INTO "django_geo_db_location" VALUES(17132,NULL,'Drewryville, VA',7025,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17133,NULL,'Drewryville, VA 23844',7025,222,NULL,54,9815,0);
INSERT INTO "django_geo_db_location" VALUES(17134,NULL,'Ebony, VA',7026,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17135,NULL,'Ebony, VA 23845',7026,222,NULL,54,9816,0);
INSERT INTO "django_geo_db_location" VALUES(17136,NULL,'Elberon, VA',7027,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17137,NULL,'Elberon, VA 23846',7027,222,NULL,54,9817,0);
INSERT INTO "django_geo_db_location" VALUES(17138,NULL,'Emporia, VA',7028,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17139,NULL,'Emporia, VA 23847',7028,222,NULL,54,9818,0);
INSERT INTO "django_geo_db_location" VALUES(17140,NULL,'Ford, VA',7029,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17141,NULL,'Ford, VA 23850',7029,222,NULL,54,9819,0);
INSERT INTO "django_geo_db_location" VALUES(17142,NULL,'Franklin, VA 23851',6998,222,NULL,54,9820,0);
INSERT INTO "django_geo_db_location" VALUES(17143,NULL,'Freeman, VA',7030,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17144,NULL,'Freeman, VA 23856',7030,222,NULL,54,9821,0);
INSERT INTO "django_geo_db_location" VALUES(17145,NULL,'Gasburg, VA',7031,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17146,NULL,'Gasburg, VA 23857',7031,222,NULL,54,9822,0);
INSERT INTO "django_geo_db_location" VALUES(17147,NULL,'Hopewell, VA',7032,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17148,NULL,'Hopewell, VA 23860',7032,222,NULL,54,9823,0);
INSERT INTO "django_geo_db_location" VALUES(17149,NULL,'Ivor, VA',7033,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17150,NULL,'Ivor, VA 23866',7033,222,NULL,54,9824,0);
INSERT INTO "django_geo_db_location" VALUES(17151,NULL,'Jarratt, VA',7034,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17152,NULL,'Jarratt, VA 23867',7034,222,NULL,54,9825,0);
INSERT INTO "django_geo_db_location" VALUES(17153,NULL,'Lawrenceville, VA',7035,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17154,NULL,'Lawrenceville, VA 23868',7035,222,NULL,54,9826,0);
INSERT INTO "django_geo_db_location" VALUES(17155,NULL,'Jarratt, VA 23870',7034,222,NULL,54,9827,0);
INSERT INTO "django_geo_db_location" VALUES(17156,NULL,'McKenney, VA',7036,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17157,NULL,'McKenney, VA 23872',7036,222,NULL,54,9828,0);
INSERT INTO "django_geo_db_location" VALUES(17158,NULL,'Meredithville, VA',7037,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17159,NULL,'Meredithville, VA 23873',7037,222,NULL,54,9829,0);
INSERT INTO "django_geo_db_location" VALUES(17160,NULL,'Newsoms, VA',7038,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17161,NULL,'Newsoms, VA 23874',7038,222,NULL,54,9830,0);
INSERT INTO "django_geo_db_location" VALUES(17162,NULL,'Prince George, VA',7039,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17163,NULL,'Prince George, VA 23875',7039,222,NULL,54,9831,0);
INSERT INTO "django_geo_db_location" VALUES(17164,NULL,'Rawlings, VA',7040,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17165,NULL,'Rawlings, VA 23876',7040,222,NULL,54,9832,0);
INSERT INTO "django_geo_db_location" VALUES(17166,NULL,'Sedley, VA',7041,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17167,NULL,'Sedley, VA 23878',7041,222,NULL,54,9833,0);
INSERT INTO "django_geo_db_location" VALUES(17168,NULL,'Skippers, VA',7042,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17169,NULL,'Skippers, VA 23879',7042,222,NULL,54,9834,0);
INSERT INTO "django_geo_db_location" VALUES(17170,NULL,'Spring Grove, VA',7043,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17171,NULL,'Spring Grove, VA 23881',7043,222,NULL,54,9835,0);
INSERT INTO "django_geo_db_location" VALUES(17172,NULL,'Stony Creek, VA',7044,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17173,NULL,'Stony Creek, VA 23882',7044,222,NULL,54,9836,0);
INSERT INTO "django_geo_db_location" VALUES(17174,NULL,'Surry, VA',7045,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17175,NULL,'Surry, VA 23883',7045,222,NULL,54,9837,0);
INSERT INTO "django_geo_db_location" VALUES(17176,NULL,'Sussex, VA',7046,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17177,NULL,'Sussex, VA 23884',7046,222,NULL,54,9838,0);
INSERT INTO "django_geo_db_location" VALUES(17178,NULL,'Sutherland, VA',7047,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17179,NULL,'Sutherland, VA 23885',7047,222,NULL,54,9839,0);
INSERT INTO "django_geo_db_location" VALUES(17180,NULL,'Valentines, VA',7048,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17181,NULL,'Valentines, VA 23887',7048,222,NULL,54,9840,0);
INSERT INTO "django_geo_db_location" VALUES(17182,NULL,'Wakefield, VA',7049,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17183,NULL,'Wakefield, VA 23888',7049,222,NULL,54,9841,0);
INSERT INTO "django_geo_db_location" VALUES(17184,NULL,'Warfield, VA',7050,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17185,NULL,'Warfield, VA 23889',7050,222,NULL,54,9842,0);
INSERT INTO "django_geo_db_location" VALUES(17186,NULL,'Waverly, VA',7051,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17187,NULL,'Waverly, VA 23890',7051,222,NULL,54,9843,0);
INSERT INTO "django_geo_db_location" VALUES(17188,NULL,'Waverly, VA 23891',7051,222,NULL,54,9844,0);
INSERT INTO "django_geo_db_location" VALUES(17189,NULL,'White Plains, VA',7052,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17190,NULL,'White Plains, VA 23893',7052,222,NULL,54,9845,0);
INSERT INTO "django_geo_db_location" VALUES(17191,NULL,'Wilsons, VA',7053,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17192,NULL,'Wilsons, VA 23894',7053,222,NULL,54,9846,0);
INSERT INTO "django_geo_db_location" VALUES(17193,NULL,'Yale, VA',7054,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17194,NULL,'Yale, VA 23897',7054,222,NULL,54,9847,0);
INSERT INTO "django_geo_db_location" VALUES(17195,NULL,'Zuni, VA',7055,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17196,NULL,'Zuni, VA 23898',7055,222,NULL,54,9848,0);
INSERT INTO "django_geo_db_location" VALUES(17197,NULL,'Claremont, VA',7056,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17198,NULL,'Claremont, VA 23899',7056,222,NULL,54,9849,0);
INSERT INTO "django_geo_db_location" VALUES(17199,NULL,'Farmville, VA',7057,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17200,NULL,'Farmville, VA 23901',7057,222,NULL,54,9850,0);
INSERT INTO "django_geo_db_location" VALUES(17201,NULL,'Farmville, VA 23909',7057,222,NULL,54,9851,0);
INSERT INTO "django_geo_db_location" VALUES(17202,NULL,'Baskerville, VA',7058,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17203,NULL,'Baskerville, VA 23915',7058,222,NULL,54,9852,0);
INSERT INTO "django_geo_db_location" VALUES(17204,NULL,'Boydton, VA',7059,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17205,NULL,'Boydton, VA 23917',7059,222,NULL,54,9853,0);
INSERT INTO "django_geo_db_location" VALUES(17206,NULL,'Bracey, VA',7060,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17207,NULL,'Bracey, VA 23919',7060,222,NULL,54,9854,0);
INSERT INTO "django_geo_db_location" VALUES(17208,NULL,'Brodnax, VA',7061,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17209,NULL,'Brodnax, VA 23920',7061,222,NULL,54,9855,0);
INSERT INTO "django_geo_db_location" VALUES(17210,NULL,'Buckingham, VA',7062,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17211,NULL,'Buckingham, VA 23921',7062,222,NULL,54,9856,0);
INSERT INTO "django_geo_db_location" VALUES(17212,NULL,'Burkeville, VA',7063,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17213,NULL,'Burkeville, VA 23922',7063,222,NULL,54,9857,0);
INSERT INTO "django_geo_db_location" VALUES(17214,NULL,'Charlotte Court House, VA',7064,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17215,NULL,'Charlotte Court House, VA 23923',7064,222,NULL,54,9858,0);
INSERT INTO "django_geo_db_location" VALUES(17216,NULL,'Chase City, VA',7065,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17217,NULL,'Chase City, VA 23924',7065,222,NULL,54,9859,0);
INSERT INTO "django_geo_db_location" VALUES(17218,NULL,'Clarksville, VA',7066,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17219,NULL,'Clarksville, VA 23927',7066,222,NULL,54,9860,0);
INSERT INTO "django_geo_db_location" VALUES(17220,NULL,'Crewe, VA',7067,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17221,NULL,'Crewe, VA 23930',7067,222,NULL,54,9861,0);
INSERT INTO "django_geo_db_location" VALUES(17222,NULL,'Cullen, VA',7068,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17223,NULL,'Cullen, VA 23934',7068,222,NULL,54,9862,0);
INSERT INTO "django_geo_db_location" VALUES(17224,NULL,'Dillwyn, VA',7069,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17225,NULL,'Dillwyn, VA 23936',7069,222,NULL,54,9863,0);
INSERT INTO "django_geo_db_location" VALUES(17226,NULL,'Drakes Branch, VA',7070,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17227,NULL,'Drakes Branch, VA 23937',7070,222,NULL,54,9864,0);
INSERT INTO "django_geo_db_location" VALUES(17228,NULL,'Dundas, VA',7071,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17229,NULL,'Dundas, VA 23938',7071,222,NULL,54,9865,0);
INSERT INTO "django_geo_db_location" VALUES(17230,NULL,'Evergreen, VA',7072,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17231,NULL,'Evergreen, VA 23939',7072,222,NULL,54,9866,0);
INSERT INTO "django_geo_db_location" VALUES(17232,NULL,'Fort Mitchell, VA',7073,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17233,NULL,'Fort Mitchell, VA 23941',7073,222,NULL,54,9867,0);
INSERT INTO "django_geo_db_location" VALUES(17234,NULL,'Green Bay, VA',7074,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17235,NULL,'Green Bay, VA 23942',7074,222,NULL,54,9868,0);
INSERT INTO "django_geo_db_location" VALUES(17236,NULL,'Hampden Sydney, VA',7075,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17237,NULL,'Hampden Sydney, VA 23943',7075,222,NULL,54,9869,0);
INSERT INTO "django_geo_db_location" VALUES(17238,NULL,'Kenbridge, VA',7076,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17239,NULL,'Kenbridge, VA 23944',7076,222,NULL,54,9870,0);
INSERT INTO "django_geo_db_location" VALUES(17240,NULL,'Keysville, VA',7077,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17241,NULL,'Keysville, VA 23947',7077,222,NULL,54,9871,0);
INSERT INTO "django_geo_db_location" VALUES(17242,NULL,'La Crosse, VA',7078,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17243,NULL,'La Crosse, VA 23950',7078,222,NULL,54,9872,0);
INSERT INTO "django_geo_db_location" VALUES(17244,NULL,'Lunenburg, VA',7079,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17245,NULL,'Lunenburg, VA 23952',7079,222,NULL,54,9873,0);
INSERT INTO "django_geo_db_location" VALUES(17246,NULL,'Meherrin, VA',7080,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17247,NULL,'Meherrin, VA 23954',7080,222,NULL,54,9874,0);
INSERT INTO "django_geo_db_location" VALUES(17248,NULL,'Nottoway, VA',7081,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17249,NULL,'Nottoway, VA 23955',7081,222,NULL,54,9875,0);
INSERT INTO "django_geo_db_location" VALUES(17250,NULL,'Pamplin, VA',7082,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17251,NULL,'Pamplin, VA 23958',7082,222,NULL,54,9876,0);
INSERT INTO "django_geo_db_location" VALUES(17252,NULL,'Phenix, VA',7083,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17253,NULL,'Phenix, VA 23959',7083,222,NULL,54,9877,0);
INSERT INTO "django_geo_db_location" VALUES(17254,NULL,'Prospect, VA',7084,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17255,NULL,'Prospect, VA 23960',7084,222,NULL,54,9878,0);
INSERT INTO "django_geo_db_location" VALUES(17256,NULL,'Randolph, VA',7085,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17257,NULL,'Randolph, VA 23962',7085,222,NULL,54,9879,0);
INSERT INTO "django_geo_db_location" VALUES(17258,NULL,'Red House, VA',7086,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17259,NULL,'Red House, VA 23963',7086,222,NULL,54,9880,0);
INSERT INTO "django_geo_db_location" VALUES(17260,NULL,'Red Oak, VA',7087,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17261,NULL,'Red Oak, VA 23964',7087,222,NULL,54,9881,0);
INSERT INTO "django_geo_db_location" VALUES(17262,NULL,'Rice, VA',7088,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17263,NULL,'Rice, VA 23966',7088,222,NULL,54,9882,0);
INSERT INTO "django_geo_db_location" VALUES(17264,NULL,'Saxe, VA',7089,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17265,NULL,'Saxe, VA 23967',7089,222,NULL,54,9883,0);
INSERT INTO "django_geo_db_location" VALUES(17266,NULL,'Skipwith, VA',7090,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17267,NULL,'Skipwith, VA 23968',7090,222,NULL,54,9884,0);
INSERT INTO "django_geo_db_location" VALUES(17268,NULL,'South Hill, VA',7091,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17269,NULL,'South Hill, VA 23970',7091,222,NULL,54,9885,0);
INSERT INTO "django_geo_db_location" VALUES(17270,NULL,'Victoria, VA',7092,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17271,NULL,'Victoria, VA 23974',7092,222,NULL,54,9886,0);
INSERT INTO "django_geo_db_location" VALUES(17272,NULL,'Wylliesburg, VA',7093,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17273,NULL,'Wylliesburg, VA 23976',7093,222,NULL,54,9887,0);
INSERT INTO "django_geo_db_location" VALUES(17274,NULL,'Richmond, VA 23999',6930,222,NULL,54,9888,0);
INSERT INTO "django_geo_db_location" VALUES(17275,NULL,'Roanoke, VA',7094,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17276,NULL,'Roanoke, VA 24001',7094,222,NULL,54,9889,0);
INSERT INTO "django_geo_db_location" VALUES(17277,NULL,'Roanoke, VA 24002',7094,222,NULL,54,9890,0);
INSERT INTO "django_geo_db_location" VALUES(17278,NULL,'Roanoke, VA 24003',7094,222,NULL,54,9891,0);
INSERT INTO "django_geo_db_location" VALUES(17279,NULL,'Roanoke, VA 24004',7094,222,NULL,54,9892,0);
INSERT INTO "django_geo_db_location" VALUES(17280,NULL,'Roanoke, VA 24005',7094,222,NULL,54,9893,0);
INSERT INTO "django_geo_db_location" VALUES(17281,NULL,'Roanoke, VA 24006',7094,222,NULL,54,9894,0);
INSERT INTO "django_geo_db_location" VALUES(17282,NULL,'Roanoke, VA 24007',7094,222,NULL,54,9895,0);
INSERT INTO "django_geo_db_location" VALUES(17283,NULL,'Roanoke, VA 24008',7094,222,NULL,54,9896,0);
INSERT INTO "django_geo_db_location" VALUES(17284,NULL,'Roanoke, VA 24009',7094,222,NULL,54,9897,0);
INSERT INTO "django_geo_db_location" VALUES(17285,NULL,'Roanoke, VA 24010',7094,222,NULL,54,9898,0);
INSERT INTO "django_geo_db_location" VALUES(17286,NULL,'Roanoke, VA 24011',7094,222,NULL,54,9899,0);
INSERT INTO "django_geo_db_location" VALUES(17287,NULL,'Roanoke, VA 24012',7094,222,NULL,54,9900,0);
INSERT INTO "django_geo_db_location" VALUES(17288,NULL,'Roanoke, VA 24013',7094,222,NULL,54,9901,0);
INSERT INTO "django_geo_db_location" VALUES(17289,NULL,'Roanoke, VA 24014',7094,222,NULL,54,9902,0);
INSERT INTO "django_geo_db_location" VALUES(17290,NULL,'Roanoke, VA 24015',7094,222,NULL,54,9903,0);
INSERT INTO "django_geo_db_location" VALUES(17291,NULL,'Roanoke, VA 24016',7094,222,NULL,54,9904,0);
INSERT INTO "django_geo_db_location" VALUES(17292,NULL,'Roanoke, VA 24017',7094,222,NULL,54,9905,0);
INSERT INTO "django_geo_db_location" VALUES(17293,NULL,'Roanoke, VA 24018',7094,222,NULL,54,9906,0);
INSERT INTO "django_geo_db_location" VALUES(17294,NULL,'Roanoke, VA 24019',7094,222,NULL,54,9907,0);
INSERT INTO "django_geo_db_location" VALUES(17295,NULL,'Roanoke, VA 24020',7094,222,NULL,54,9908,0);
INSERT INTO "django_geo_db_location" VALUES(17296,NULL,'Roanoke, VA 24022',7094,222,NULL,54,9909,0);
INSERT INTO "django_geo_db_location" VALUES(17297,NULL,'Roanoke, VA 24023',7094,222,NULL,54,9910,0);
INSERT INTO "django_geo_db_location" VALUES(17298,NULL,'Roanoke, VA 24024',7094,222,NULL,54,9911,0);
INSERT INTO "django_geo_db_location" VALUES(17299,NULL,'Roanoke, VA 24025',7094,222,NULL,54,9912,0);
INSERT INTO "django_geo_db_location" VALUES(17300,NULL,'Roanoke, VA 24026',7094,222,NULL,54,9913,0);
INSERT INTO "django_geo_db_location" VALUES(17301,NULL,'Roanoke, VA 24027',7094,222,NULL,54,9914,0);
INSERT INTO "django_geo_db_location" VALUES(17302,NULL,'Roanoke, VA 24028',7094,222,NULL,54,9915,0);
INSERT INTO "django_geo_db_location" VALUES(17303,NULL,'Roanoke, VA 24029',7094,222,NULL,54,9916,0);
INSERT INTO "django_geo_db_location" VALUES(17304,NULL,'Roanoke, VA 24030',7094,222,NULL,54,9917,0);
INSERT INTO "django_geo_db_location" VALUES(17305,NULL,'Roanoke, VA 24031',7094,222,NULL,54,9918,0);
INSERT INTO "django_geo_db_location" VALUES(17306,NULL,'Roanoke, VA 24032',7094,222,NULL,54,9919,0);
INSERT INTO "django_geo_db_location" VALUES(17307,NULL,'Roanoke, VA 24033',7094,222,NULL,54,9920,0);
INSERT INTO "django_geo_db_location" VALUES(17308,NULL,'Roanoke, VA 24034',7094,222,NULL,54,9921,0);
INSERT INTO "django_geo_db_location" VALUES(17309,NULL,'Roanoke, VA 24035',7094,222,NULL,54,9922,0);
INSERT INTO "django_geo_db_location" VALUES(17310,NULL,'Roanoke, VA 24036',7094,222,NULL,54,9923,0);
INSERT INTO "django_geo_db_location" VALUES(17311,NULL,'Roanoke, VA 24037',7094,222,NULL,54,9924,0);
INSERT INTO "django_geo_db_location" VALUES(17312,NULL,'Roanoke, VA 24038',7094,222,NULL,54,9925,0);
INSERT INTO "django_geo_db_location" VALUES(17313,NULL,'Roanoke, VA 24040',7094,222,NULL,54,9926,0);
INSERT INTO "django_geo_db_location" VALUES(17314,NULL,'Roanoke, VA 24042',7094,222,NULL,54,9927,0);
INSERT INTO "django_geo_db_location" VALUES(17315,NULL,'Roanoke, VA 24043',7094,222,NULL,54,9928,0);
INSERT INTO "django_geo_db_location" VALUES(17316,NULL,'Roanoke, VA 24044',7094,222,NULL,54,9929,0);
INSERT INTO "django_geo_db_location" VALUES(17317,NULL,'Roanoke, VA 24045',7094,222,NULL,54,9930,0);
INSERT INTO "django_geo_db_location" VALUES(17318,NULL,'Roanoke, VA 24048',7094,222,NULL,54,9931,0);
INSERT INTO "django_geo_db_location" VALUES(17319,NULL,'Roanoke, VA 24050',7094,222,NULL,54,9932,0);
INSERT INTO "django_geo_db_location" VALUES(17320,NULL,'Ararat, VA',7095,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17321,NULL,'Ararat, VA 24053',7095,222,NULL,54,9933,0);
INSERT INTO "django_geo_db_location" VALUES(17322,NULL,'Axton, VA',7096,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17323,NULL,'Axton, VA 24054',7096,222,NULL,54,9934,0);
INSERT INTO "django_geo_db_location" VALUES(17324,NULL,'Bassett, VA',7097,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17325,NULL,'Bassett, VA 24055',7097,222,NULL,54,9935,0);
INSERT INTO "django_geo_db_location" VALUES(17326,NULL,'Belspring, VA',7098,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17327,NULL,'Belspring, VA 24058',7098,222,NULL,54,9936,0);
INSERT INTO "django_geo_db_location" VALUES(17328,NULL,'Bent Mountain, VA',7099,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17329,NULL,'Bent Mountain, VA 24059',7099,222,NULL,54,9937,0);
INSERT INTO "django_geo_db_location" VALUES(17330,NULL,'Blacksburg, VA',7100,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17331,NULL,'Blacksburg, VA 24060',7100,222,NULL,54,9938,0);
INSERT INTO "django_geo_db_location" VALUES(17332,NULL,'Blacksburg, VA 24061',7100,222,NULL,54,9939,0);
INSERT INTO "django_geo_db_location" VALUES(17333,NULL,'Blacksburg, VA 24062',7100,222,NULL,54,9940,0);
INSERT INTO "django_geo_db_location" VALUES(17334,NULL,'Blacksburg, VA 24063',7100,222,NULL,54,9941,0);
INSERT INTO "django_geo_db_location" VALUES(17335,NULL,'Blue Ridge, VA',7101,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17336,NULL,'Blue Ridge, VA 24064',7101,222,NULL,54,9942,0);
INSERT INTO "django_geo_db_location" VALUES(17337,NULL,'Boones Mill, VA',7102,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17338,NULL,'Boones Mill, VA 24065',7102,222,NULL,54,9943,0);
INSERT INTO "django_geo_db_location" VALUES(17339,NULL,'Buchanan, VA',7103,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17340,NULL,'Buchanan, VA 24066',7103,222,NULL,54,9944,0);
INSERT INTO "django_geo_db_location" VALUES(17341,NULL,'Callaway, VA',7104,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17342,NULL,'Callaway, VA 24067',7104,222,NULL,54,9945,0);
INSERT INTO "django_geo_db_location" VALUES(17343,NULL,'Christiansburg, VA',7105,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17344,NULL,'Christiansburg, VA 24068',7105,222,NULL,54,9946,0);
INSERT INTO "django_geo_db_location" VALUES(17345,NULL,'Cascade, VA',7106,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17346,NULL,'Cascade, VA 24069',7106,222,NULL,54,9947,0);
INSERT INTO "django_geo_db_location" VALUES(17347,NULL,'Catawba, VA',7107,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17348,NULL,'Catawba, VA 24070',7107,222,NULL,54,9948,0);
INSERT INTO "django_geo_db_location" VALUES(17349,NULL,'Check, VA',7108,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17350,NULL,'Check, VA 24072',7108,222,NULL,54,9949,0);
INSERT INTO "django_geo_db_location" VALUES(17351,NULL,'Christiansburg, VA 24073',7105,222,NULL,54,9950,0);
INSERT INTO "django_geo_db_location" VALUES(17352,NULL,'Claudville, VA',7109,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17353,NULL,'Claudville, VA 24076',7109,222,NULL,54,9951,0);
INSERT INTO "django_geo_db_location" VALUES(17354,NULL,'Cloverdale, VA',7110,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17355,NULL,'Cloverdale, VA 24077',7110,222,NULL,54,9952,0);
INSERT INTO "django_geo_db_location" VALUES(17356,NULL,'Collinsville, VA',7111,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17357,NULL,'Collinsville, VA 24078',7111,222,NULL,54,9953,0);
INSERT INTO "django_geo_db_location" VALUES(17358,NULL,'Copper Hill, VA',7112,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17359,NULL,'Copper Hill, VA 24079',7112,222,NULL,54,9954,0);
INSERT INTO "django_geo_db_location" VALUES(17360,NULL,'Critz, VA',7113,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17361,NULL,'Critz, VA 24082',7113,222,NULL,54,9955,0);
INSERT INTO "django_geo_db_location" VALUES(17362,NULL,'Daleville, VA',7114,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17363,NULL,'Daleville, VA 24083',7114,222,NULL,54,9956,0);
INSERT INTO "django_geo_db_location" VALUES(17364,NULL,'Dublin, VA',7115,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17365,NULL,'Dublin, VA 24084',7115,222,NULL,54,9957,0);
INSERT INTO "django_geo_db_location" VALUES(17366,NULL,'Eagle Rock, VA',7116,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17367,NULL,'Eagle Rock, VA 24085',7116,222,NULL,54,9958,0);
INSERT INTO "django_geo_db_location" VALUES(17368,NULL,'Eggleston, VA',7117,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17369,NULL,'Eggleston, VA 24086',7117,222,NULL,54,9959,0);
INSERT INTO "django_geo_db_location" VALUES(17370,NULL,'Elliston, VA',7118,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17371,NULL,'Elliston, VA 24087',7118,222,NULL,54,9960,0);
INSERT INTO "django_geo_db_location" VALUES(17372,NULL,'Ferrum, VA',7119,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17373,NULL,'Ferrum, VA 24088',7119,222,NULL,54,9961,0);
INSERT INTO "django_geo_db_location" VALUES(17374,NULL,'Fieldale, VA',7120,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17375,NULL,'Fieldale, VA 24089',7120,222,NULL,54,9962,0);
INSERT INTO "django_geo_db_location" VALUES(17376,NULL,'Fincastle, VA',7121,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17377,NULL,'Fincastle, VA 24090',7121,222,NULL,54,9963,0);
INSERT INTO "django_geo_db_location" VALUES(17378,NULL,'Floyd, VA',7122,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17379,NULL,'Floyd, VA 24091',7122,222,NULL,54,9964,0);
INSERT INTO "django_geo_db_location" VALUES(17380,NULL,'Glade Hill, VA',7123,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17381,NULL,'Glade Hill, VA 24092',7123,222,NULL,54,9965,0);
INSERT INTO "django_geo_db_location" VALUES(17382,NULL,'Glen Lyn, VA',7124,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17383,NULL,'Glen Lyn, VA 24093',7124,222,NULL,54,9966,0);
INSERT INTO "django_geo_db_location" VALUES(17384,NULL,'Goldbond, VA',7125,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17385,NULL,'Goldbond, VA 24094',7125,222,NULL,54,9967,0);
INSERT INTO "django_geo_db_location" VALUES(17386,NULL,'Goodview, VA',7126,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17387,NULL,'Goodview, VA 24095',7126,222,NULL,54,9968,0);
INSERT INTO "django_geo_db_location" VALUES(17388,NULL,'Hardy, VA',7127,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17389,NULL,'Hardy, VA 24101',7127,222,NULL,54,9969,0);
INSERT INTO "django_geo_db_location" VALUES(17390,NULL,'Henry, VA',7128,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17391,NULL,'Henry, VA 24102',7128,222,NULL,54,9970,0);
INSERT INTO "django_geo_db_location" VALUES(17392,NULL,'Huddleston, VA',7129,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17393,NULL,'Huddleston, VA 24104',7129,222,NULL,54,9971,0);
INSERT INTO "django_geo_db_location" VALUES(17394,NULL,'Indian Valley, VA',7130,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17395,NULL,'Indian Valley, VA 24105',7130,222,NULL,54,9972,0);
INSERT INTO "django_geo_db_location" VALUES(17396,NULL,'McCoy, VA',7131,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17397,NULL,'McCoy, VA 24111',7131,222,NULL,54,9973,0);
INSERT INTO "django_geo_db_location" VALUES(17398,NULL,'Martinsville, VA',7132,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17399,NULL,'Martinsville, VA 24112',7132,222,NULL,54,9974,0);
INSERT INTO "django_geo_db_location" VALUES(17400,NULL,'Martinsville, VA 24113',7132,222,NULL,54,9975,0);
INSERT INTO "django_geo_db_location" VALUES(17401,NULL,'Martinsville, VA 24114',7132,222,NULL,54,9976,0);
INSERT INTO "django_geo_db_location" VALUES(17402,NULL,'Martinsville, VA 24115',7132,222,NULL,54,9977,0);
INSERT INTO "django_geo_db_location" VALUES(17403,NULL,'Meadows Of Dan, VA',7133,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17404,NULL,'Meadows Of Dan, VA 24120',7133,222,NULL,54,9978,0);
INSERT INTO "django_geo_db_location" VALUES(17405,NULL,'Moneta, VA',7134,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17406,NULL,'Moneta, VA 24121',7134,222,NULL,54,9979,0);
INSERT INTO "django_geo_db_location" VALUES(17407,NULL,'Montvale, VA',7135,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17408,NULL,'Montvale, VA 24122',7135,222,NULL,54,9980,0);
INSERT INTO "django_geo_db_location" VALUES(17409,NULL,'Narrows, VA',7136,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17410,NULL,'Narrows, VA 24124',7136,222,NULL,54,9981,0);
INSERT INTO "django_geo_db_location" VALUES(17411,NULL,'Newbern, VA',7137,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17412,NULL,'Newbern, VA 24126',7137,222,NULL,54,9982,0);
INSERT INTO "django_geo_db_location" VALUES(17413,NULL,'New Castle, VA',7138,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17414,NULL,'New Castle, VA 24127',7138,222,NULL,54,9983,0);
INSERT INTO "django_geo_db_location" VALUES(17415,NULL,'Newport, VA',7139,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17416,NULL,'Newport, VA 24128',7139,222,NULL,54,9984,0);
INSERT INTO "django_geo_db_location" VALUES(17417,NULL,'New River, VA',7140,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17418,NULL,'New River, VA 24129',7140,222,NULL,54,9985,0);
INSERT INTO "django_geo_db_location" VALUES(17419,NULL,'Oriskany, VA',7141,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17420,NULL,'Oriskany, VA 24130',7141,222,NULL,54,9986,0);
INSERT INTO "django_geo_db_location" VALUES(17421,NULL,'Paint Bank, VA',7142,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17422,NULL,'Paint Bank, VA 24131',7142,222,NULL,54,9987,0);
INSERT INTO "django_geo_db_location" VALUES(17423,NULL,'Parrott, VA',7143,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17424,NULL,'Parrott, VA 24132',7143,222,NULL,54,9988,0);
INSERT INTO "django_geo_db_location" VALUES(17425,NULL,'Patrick Springs, VA',7144,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17426,NULL,'Patrick Springs, VA 24133',7144,222,NULL,54,9989,0);
INSERT INTO "django_geo_db_location" VALUES(17427,NULL,'Pearisburg, VA',7145,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17428,NULL,'Pearisburg, VA 24134',7145,222,NULL,54,9990,0);
INSERT INTO "django_geo_db_location" VALUES(17429,NULL,'Pembroke, VA',7146,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17430,NULL,'Pembroke, VA 24136',7146,222,NULL,54,9991,0);
INSERT INTO "django_geo_db_location" VALUES(17431,NULL,'Penhook, VA',7147,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17432,NULL,'Penhook, VA 24137',7147,222,NULL,54,9992,0);
INSERT INTO "django_geo_db_location" VALUES(17433,NULL,'Pilot, VA',7148,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17434,NULL,'Pilot, VA 24138',7148,222,NULL,54,9993,0);
INSERT INTO "django_geo_db_location" VALUES(17435,NULL,'Pittsville, VA',7149,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17436,NULL,'Pittsville, VA 24139',7149,222,NULL,54,9994,0);
INSERT INTO "django_geo_db_location" VALUES(17437,NULL,'Radford, VA',7150,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17438,NULL,'Radford, VA 24141',7150,222,NULL,54,9995,0);
INSERT INTO "django_geo_db_location" VALUES(17439,NULL,'Radford, VA 24142',7150,222,NULL,54,9996,0);
INSERT INTO "django_geo_db_location" VALUES(17440,NULL,'Radford, VA 24143',7150,222,NULL,54,9997,0);
INSERT INTO "django_geo_db_location" VALUES(17441,NULL,'Redwood, VA',7151,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17442,NULL,'Redwood, VA 24146',7151,222,NULL,54,9998,0);
INSERT INTO "django_geo_db_location" VALUES(17443,NULL,'Rich Creek, VA',7152,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17444,NULL,'Rich Creek, VA 24147',7152,222,NULL,54,9999,0);
INSERT INTO "django_geo_db_location" VALUES(17445,NULL,'Ridgeway, VA',7153,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17446,NULL,'Ridgeway, VA 24148',7153,222,NULL,54,10000,0);
INSERT INTO "django_geo_db_location" VALUES(17447,NULL,'Riner, VA',7154,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17448,NULL,'Riner, VA 24149',7154,222,NULL,54,10001,0);
INSERT INTO "django_geo_db_location" VALUES(17449,NULL,'Ripplemead, VA',7155,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17450,NULL,'Ripplemead, VA 24150',7155,222,NULL,54,10002,0);
INSERT INTO "django_geo_db_location" VALUES(17451,NULL,'Rocky Mount, VA',7156,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17452,NULL,'Rocky Mount, VA 24151',7156,222,NULL,54,10003,0);
INSERT INTO "django_geo_db_location" VALUES(17453,NULL,'Salem, VA',7157,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17454,NULL,'Salem, VA 24153',7157,222,NULL,54,10004,0);
INSERT INTO "django_geo_db_location" VALUES(17455,NULL,'Salem, VA 24155',7157,222,NULL,54,10005,0);
INSERT INTO "django_geo_db_location" VALUES(17456,NULL,'Salem, VA 24156',7157,222,NULL,54,10006,0);
INSERT INTO "django_geo_db_location" VALUES(17457,NULL,'Salem, VA 24157',7157,222,NULL,54,10007,0);
INSERT INTO "django_geo_db_location" VALUES(17458,NULL,'Sandy Level, VA',7158,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17459,NULL,'Sandy Level, VA 24161',7158,222,NULL,54,10008,0);
INSERT INTO "django_geo_db_location" VALUES(17460,NULL,'Shawsville, VA',7159,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17461,NULL,'Shawsville, VA 24162',7159,222,NULL,54,10009,0);
INSERT INTO "django_geo_db_location" VALUES(17462,NULL,'Spencer, VA',7160,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17463,NULL,'Spencer, VA 24165',7160,222,NULL,54,10010,0);
INSERT INTO "django_geo_db_location" VALUES(17464,NULL,'Staffordsville, VA',7161,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17465,NULL,'Staffordsville, VA 24167',7161,222,NULL,54,10011,0);
INSERT INTO "django_geo_db_location" VALUES(17466,NULL,'Stanleytown, VA',7162,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17467,NULL,'Stanleytown, VA 24168',7162,222,NULL,54,10012,0);
INSERT INTO "django_geo_db_location" VALUES(17468,NULL,'Stuart, VA',7163,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17469,NULL,'Stuart, VA 24171',7163,222,NULL,54,10013,0);
INSERT INTO "django_geo_db_location" VALUES(17470,NULL,'Thaxton, VA',7164,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17471,NULL,'Thaxton, VA 24174',7164,222,NULL,54,10014,0);
INSERT INTO "django_geo_db_location" VALUES(17472,NULL,'Troutville, VA',7165,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17473,NULL,'Troutville, VA 24175',7165,222,NULL,54,10015,0);
INSERT INTO "django_geo_db_location" VALUES(17474,NULL,'Union Hall, VA',7166,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17475,NULL,'Union Hall, VA 24176',7166,222,NULL,54,10016,0);
INSERT INTO "django_geo_db_location" VALUES(17476,NULL,'Vesta, VA',7167,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17477,NULL,'Vesta, VA 24177',7167,222,NULL,54,10017,0);
INSERT INTO "django_geo_db_location" VALUES(17478,NULL,'Villamont, VA',7168,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17479,NULL,'Villamont, VA 24178',7168,222,NULL,54,10018,0);
INSERT INTO "django_geo_db_location" VALUES(17480,NULL,'Vinton, VA',7169,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17481,NULL,'Vinton, VA 24179',7169,222,NULL,54,10019,0);
INSERT INTO "django_geo_db_location" VALUES(17482,NULL,'Wirtz, VA',7170,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17483,NULL,'Wirtz, VA 24184',7170,222,NULL,54,10020,0);
INSERT INTO "django_geo_db_location" VALUES(17484,NULL,'Woolwine, VA',7171,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17485,NULL,'Woolwine, VA 24185',7171,222,NULL,54,10021,0);
INSERT INTO "django_geo_db_location" VALUES(17486,NULL,'Bristol, VA',7172,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17487,NULL,'Bristol, VA 24201',7172,222,NULL,54,10022,0);
INSERT INTO "django_geo_db_location" VALUES(17488,NULL,'Bristol, VA 24202',7172,222,NULL,54,10023,0);
INSERT INTO "django_geo_db_location" VALUES(17489,NULL,'Bristol, VA 24203',7172,222,NULL,54,10024,0);
INSERT INTO "django_geo_db_location" VALUES(17490,NULL,'Bristol, VA 24209',7172,222,NULL,54,10025,0);
INSERT INTO "django_geo_db_location" VALUES(17491,NULL,'Abingdon, VA',7173,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17492,NULL,'Abingdon, VA 24210',7173,222,NULL,54,10026,0);
INSERT INTO "django_geo_db_location" VALUES(17493,NULL,'Abingdon, VA 24211',7173,222,NULL,54,10027,0);
INSERT INTO "django_geo_db_location" VALUES(17494,NULL,'Abingdon, VA 24212',7173,222,NULL,54,10028,0);
INSERT INTO "django_geo_db_location" VALUES(17495,NULL,'Andover, VA',7174,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17496,NULL,'Andover, VA 24215',7174,222,NULL,54,10029,0);
INSERT INTO "django_geo_db_location" VALUES(17497,NULL,'Appalachia, VA',7175,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17498,NULL,'Appalachia, VA 24216',7175,222,NULL,54,10030,0);
INSERT INTO "django_geo_db_location" VALUES(17499,NULL,'Bee, VA',7176,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17500,NULL,'Bee, VA 24217',7176,222,NULL,54,10031,0);
INSERT INTO "django_geo_db_location" VALUES(17501,NULL,'Ben Hur, VA',7177,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17502,NULL,'Ben Hur, VA 24218',7177,222,NULL,54,10032,0);
INSERT INTO "django_geo_db_location" VALUES(17503,NULL,'Big Stone Gap, VA',7178,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17504,NULL,'Big Stone Gap, VA 24219',7178,222,NULL,54,10033,0);
INSERT INTO "django_geo_db_location" VALUES(17505,NULL,'Birchleaf, VA',7179,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17506,NULL,'Birchleaf, VA 24220',7179,222,NULL,54,10034,0);
INSERT INTO "django_geo_db_location" VALUES(17507,NULL,'Blackwater, VA',7180,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17508,NULL,'Blackwater, VA 24221',7180,222,NULL,54,10035,0);
INSERT INTO "django_geo_db_location" VALUES(17509,NULL,'Castlewood, VA',7181,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17510,NULL,'Castlewood, VA 24224',7181,222,NULL,54,10036,0);
INSERT INTO "django_geo_db_location" VALUES(17511,NULL,'Cleveland, VA',7182,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17512,NULL,'Cleveland, VA 24225',7182,222,NULL,54,10037,0);
INSERT INTO "django_geo_db_location" VALUES(17513,NULL,'Clinchco, VA',7183,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17514,NULL,'Clinchco, VA 24226',7183,222,NULL,54,10038,0);
INSERT INTO "django_geo_db_location" VALUES(17515,NULL,'Clintwood, VA',7184,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17516,NULL,'Clintwood, VA 24228',7184,222,NULL,54,10039,0);
INSERT INTO "django_geo_db_location" VALUES(17517,NULL,'Coeburn, VA',7185,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17518,NULL,'Coeburn, VA 24230',7185,222,NULL,54,10040,0);
INSERT INTO "django_geo_db_location" VALUES(17519,NULL,'Damascus, VA',7186,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17520,NULL,'Damascus, VA 24236',7186,222,NULL,54,10041,0);
INSERT INTO "django_geo_db_location" VALUES(17521,NULL,'Dante, VA',7187,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17522,NULL,'Dante, VA 24237',7187,222,NULL,54,10042,0);
INSERT INTO "django_geo_db_location" VALUES(17523,NULL,'Davenport, VA',7188,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17524,NULL,'Davenport, VA 24239',7188,222,NULL,54,10043,0);
INSERT INTO "django_geo_db_location" VALUES(17525,NULL,'Dryden, VA',7189,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17526,NULL,'Dryden, VA 24243',7189,222,NULL,54,10044,0);
INSERT INTO "django_geo_db_location" VALUES(17527,NULL,'Duffield, VA',7190,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17528,NULL,'Duffield, VA 24244',7190,222,NULL,54,10045,0);
INSERT INTO "django_geo_db_location" VALUES(17529,NULL,'Dungannon, VA',7191,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17530,NULL,'Dungannon, VA 24245',7191,222,NULL,54,10046,0);
INSERT INTO "django_geo_db_location" VALUES(17531,NULL,'East Stone Gap, VA',7192,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17532,NULL,'East Stone Gap, VA 24246',7192,222,NULL,54,10047,0);
INSERT INTO "django_geo_db_location" VALUES(17533,NULL,'Ewing, VA',7193,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17534,NULL,'Ewing, VA 24248',7193,222,NULL,54,10048,0);
INSERT INTO "django_geo_db_location" VALUES(17535,NULL,'Fort Blackmore, VA',7194,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17536,NULL,'Fort Blackmore, VA 24250',7194,222,NULL,54,10049,0);
INSERT INTO "django_geo_db_location" VALUES(17537,NULL,'Gate City, VA',7195,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17538,NULL,'Gate City, VA 24251',7195,222,NULL,54,10050,0);
INSERT INTO "django_geo_db_location" VALUES(17539,NULL,'Haysi, VA',7196,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17540,NULL,'Haysi, VA 24256',7196,222,NULL,54,10051,0);
INSERT INTO "django_geo_db_location" VALUES(17541,NULL,'Hiltons, VA',7197,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17542,NULL,'Hiltons, VA 24258',7197,222,NULL,54,10052,0);
INSERT INTO "django_geo_db_location" VALUES(17543,NULL,'Honaker, VA',7198,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17544,NULL,'Honaker, VA 24260',7198,222,NULL,54,10053,0);
INSERT INTO "django_geo_db_location" VALUES(17545,NULL,'Jonesville, VA',7199,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17546,NULL,'Jonesville, VA 24263',7199,222,NULL,54,10054,0);
INSERT INTO "django_geo_db_location" VALUES(17547,NULL,'Keokee, VA',7200,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17548,NULL,'Keokee, VA 24265',7200,222,NULL,54,10055,0);
INSERT INTO "django_geo_db_location" VALUES(17549,NULL,'Lebanon, VA',7201,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17550,NULL,'Lebanon, VA 24266',7201,222,NULL,54,10056,0);
INSERT INTO "django_geo_db_location" VALUES(17551,NULL,'McClure, VA',7202,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17552,NULL,'McClure, VA 24269',7202,222,NULL,54,10057,0);
INSERT INTO "django_geo_db_location" VALUES(17553,NULL,'Mendota, VA',7203,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17554,NULL,'Mendota, VA 24270',7203,222,NULL,54,10058,0);
INSERT INTO "django_geo_db_location" VALUES(17555,NULL,'Nickelsville, VA',7204,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17556,NULL,'Nickelsville, VA 24271',7204,222,NULL,54,10059,0);
INSERT INTO "django_geo_db_location" VALUES(17557,NULL,'Nora, VA',7205,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17558,NULL,'Nora, VA 24272',7205,222,NULL,54,10060,0);
INSERT INTO "django_geo_db_location" VALUES(17559,NULL,'Norton, VA',7206,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17560,NULL,'Norton, VA 24273',7206,222,NULL,54,10061,0);
INSERT INTO "django_geo_db_location" VALUES(17561,NULL,'Pound, VA',7207,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17562,NULL,'Pound, VA 24274',7207,222,NULL,54,10062,0);
INSERT INTO "django_geo_db_location" VALUES(17563,NULL,'Pennington Gap, VA',7208,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17564,NULL,'Pennington Gap, VA 24277',7208,222,NULL,54,10063,0);
INSERT INTO "django_geo_db_location" VALUES(17565,NULL,'Pound, VA 24279',7207,222,NULL,54,10064,0);
INSERT INTO "django_geo_db_location" VALUES(17566,NULL,'Rosedale, VA',7209,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17567,NULL,'Rosedale, VA 24280',7209,222,NULL,54,10065,0);
INSERT INTO "django_geo_db_location" VALUES(17568,NULL,'Rose Hill, VA',7210,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17569,NULL,'Rose Hill, VA 24281',7210,222,NULL,54,10066,0);
INSERT INTO "django_geo_db_location" VALUES(17570,NULL,'Saint Charles, VA',7211,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17571,NULL,'Saint Charles, VA 24282',7211,222,NULL,54,10067,0);
INSERT INTO "django_geo_db_location" VALUES(17572,NULL,'Saint Paul, VA',7212,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17573,NULL,'Saint Paul, VA 24283',7212,222,NULL,54,10068,0);
INSERT INTO "django_geo_db_location" VALUES(17574,NULL,'Stonega, VA',7213,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17575,NULL,'Stonega, VA 24285',7213,222,NULL,54,10069,0);
INSERT INTO "django_geo_db_location" VALUES(17576,NULL,'Trammel, VA',7214,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17577,NULL,'Trammel, VA 24289',7214,222,NULL,54,10070,0);
INSERT INTO "django_geo_db_location" VALUES(17578,NULL,'Weber City, VA',7215,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17579,NULL,'Weber City, VA 24290',7215,222,NULL,54,10071,0);
INSERT INTO "django_geo_db_location" VALUES(17580,NULL,'Whitetop, VA',7216,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17581,NULL,'Whitetop, VA 24292',7216,222,NULL,54,10072,0);
INSERT INTO "django_geo_db_location" VALUES(17582,NULL,'Wise, VA',7217,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17583,NULL,'Wise, VA 24293',7217,222,NULL,54,10073,0);
INSERT INTO "django_geo_db_location" VALUES(17584,NULL,'Pulaski, VA',7218,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17585,NULL,'Pulaski, VA 24301',7218,222,NULL,54,10074,0);
INSERT INTO "django_geo_db_location" VALUES(17586,NULL,'Atkins, VA',7219,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17587,NULL,'Atkins, VA 24311',7219,222,NULL,54,10075,0);
INSERT INTO "django_geo_db_location" VALUES(17588,NULL,'Austinville, VA',7220,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17589,NULL,'Austinville, VA 24312',7220,222,NULL,54,10076,0);
INSERT INTO "django_geo_db_location" VALUES(17590,NULL,'Barren Springs, VA',7221,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17591,NULL,'Barren Springs, VA 24313',7221,222,NULL,54,10077,0);
INSERT INTO "django_geo_db_location" VALUES(17592,NULL,'Bastian, VA',7222,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17593,NULL,'Bastian, VA 24314',7222,222,NULL,54,10078,0);
INSERT INTO "django_geo_db_location" VALUES(17594,NULL,'Bland, VA',7223,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17595,NULL,'Bland, VA 24315',7223,222,NULL,54,10079,0);
INSERT INTO "django_geo_db_location" VALUES(17596,NULL,'Broadford, VA',7224,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17597,NULL,'Broadford, VA 24316',7224,222,NULL,54,10080,0);
INSERT INTO "django_geo_db_location" VALUES(17598,NULL,'Cana, VA',7225,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17599,NULL,'Cana, VA 24317',7225,222,NULL,54,10081,0);
INSERT INTO "django_geo_db_location" VALUES(17600,NULL,'Ceres, VA',7226,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17601,NULL,'Ceres, VA 24318',7226,222,NULL,54,10082,0);
INSERT INTO "django_geo_db_location" VALUES(17602,NULL,'Chilhowie, VA',7227,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17603,NULL,'Chilhowie, VA 24319',7227,222,NULL,54,10083,0);
INSERT INTO "django_geo_db_location" VALUES(17604,NULL,'Cripple Creek, VA',7228,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17605,NULL,'Cripple Creek, VA 24322',7228,222,NULL,54,10084,0);
INSERT INTO "django_geo_db_location" VALUES(17606,NULL,'Crockett, VA',7229,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17607,NULL,'Crockett, VA 24323',7229,222,NULL,54,10085,0);
INSERT INTO "django_geo_db_location" VALUES(17608,NULL,'Draper, VA',7230,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17609,NULL,'Draper, VA 24324',7230,222,NULL,54,10086,0);
INSERT INTO "django_geo_db_location" VALUES(17610,NULL,'Dugspur, VA',7231,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17611,NULL,'Dugspur, VA 24325',7231,222,NULL,54,10087,0);
INSERT INTO "django_geo_db_location" VALUES(17612,NULL,'Elk Creek, VA',7232,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17613,NULL,'Elk Creek, VA 24326',7232,222,NULL,54,10088,0);
INSERT INTO "django_geo_db_location" VALUES(17614,NULL,'Emory, VA',7233,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17615,NULL,'Emory, VA 24327',7233,222,NULL,54,10089,0);
INSERT INTO "django_geo_db_location" VALUES(17616,NULL,'Fancy Gap, VA',7234,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17617,NULL,'Fancy Gap, VA 24328',7234,222,NULL,54,10090,0);
INSERT INTO "django_geo_db_location" VALUES(17618,NULL,'Fries, VA',7235,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17619,NULL,'Fries, VA 24330',7235,222,NULL,54,10091,0);
INSERT INTO "django_geo_db_location" VALUES(17620,NULL,'Galax, VA',7236,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17621,NULL,'Galax, VA 24333',7236,222,NULL,54,10092,0);
INSERT INTO "django_geo_db_location" VALUES(17622,NULL,'Fries, VA 24338',7235,222,NULL,54,10093,0);
INSERT INTO "django_geo_db_location" VALUES(17623,NULL,'Glade Spring, VA',7237,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17624,NULL,'Glade Spring, VA 24340',7237,222,NULL,54,10094,0);
INSERT INTO "django_geo_db_location" VALUES(17625,NULL,'Hillsville, VA',7238,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17626,NULL,'Hillsville, VA 24343',7238,222,NULL,54,10095,0);
INSERT INTO "django_geo_db_location" VALUES(17627,NULL,'Hiwassee, VA',7239,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17628,NULL,'Hiwassee, VA 24347',7239,222,NULL,54,10096,0);
INSERT INTO "django_geo_db_location" VALUES(17629,NULL,'Independence, VA',7240,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17630,NULL,'Independence, VA 24348',7240,222,NULL,54,10097,0);
INSERT INTO "django_geo_db_location" VALUES(17631,NULL,'Ivanhoe, VA',7241,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17632,NULL,'Ivanhoe, VA 24350',7241,222,NULL,54,10098,0);
INSERT INTO "django_geo_db_location" VALUES(17633,NULL,'Lambsburg, VA',7242,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17634,NULL,'Lambsburg, VA 24351',7242,222,NULL,54,10099,0);
INSERT INTO "django_geo_db_location" VALUES(17635,NULL,'Laurel Fork, VA',7243,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17636,NULL,'Laurel Fork, VA 24352',7243,222,NULL,54,10100,0);
INSERT INTO "django_geo_db_location" VALUES(17637,NULL,'Marion, VA',7244,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17638,NULL,'Marion, VA 24354',7244,222,NULL,54,10101,0);
INSERT INTO "django_geo_db_location" VALUES(17639,NULL,'Max Meadows, VA',7245,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17640,NULL,'Max Meadows, VA 24360',7245,222,NULL,54,10102,0);
INSERT INTO "django_geo_db_location" VALUES(17641,NULL,'Meadowview, VA',7246,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17642,NULL,'Meadowview, VA 24361',7246,222,NULL,54,10103,0);
INSERT INTO "django_geo_db_location" VALUES(17643,NULL,'Mouth Of Wilson, VA',7247,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17644,NULL,'Mouth Of Wilson, VA 24363',7247,222,NULL,54,10104,0);
INSERT INTO "django_geo_db_location" VALUES(17645,NULL,'Rocky Gap, VA',7248,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17646,NULL,'Rocky Gap, VA 24366',7248,222,NULL,54,10105,0);
INSERT INTO "django_geo_db_location" VALUES(17647,NULL,'Rural Retreat, VA',7249,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17648,NULL,'Rural Retreat, VA 24368',7249,222,NULL,54,10106,0);
INSERT INTO "django_geo_db_location" VALUES(17649,NULL,'Saltville, VA',7250,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17650,NULL,'Saltville, VA 24370',7250,222,NULL,54,10107,0);
INSERT INTO "django_geo_db_location" VALUES(17651,NULL,'Seven Mile Ford, VA',7251,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17652,NULL,'Seven Mile Ford, VA 24373',7251,222,NULL,54,10108,0);
INSERT INTO "django_geo_db_location" VALUES(17653,NULL,'Speedwell, VA',7252,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17654,NULL,'Speedwell, VA 24374',7252,222,NULL,54,10109,0);
INSERT INTO "django_geo_db_location" VALUES(17655,NULL,'Sugar Grove, VA',7253,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17656,NULL,'Sugar Grove, VA 24375',7253,222,NULL,54,10110,0);
INSERT INTO "django_geo_db_location" VALUES(17657,NULL,'Tannersville, VA',7254,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17658,NULL,'Tannersville, VA 24377',7254,222,NULL,54,10111,0);
INSERT INTO "django_geo_db_location" VALUES(17659,NULL,'Trout Dale, VA',7255,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17660,NULL,'Trout Dale, VA 24378',7255,222,NULL,54,10112,0);
INSERT INTO "django_geo_db_location" VALUES(17661,NULL,'Volney, VA',7256,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17662,NULL,'Volney, VA 24379',7256,222,NULL,54,10113,0);
INSERT INTO "django_geo_db_location" VALUES(17663,NULL,'Willis, VA',7257,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17664,NULL,'Willis, VA 24380',7257,222,NULL,54,10114,0);
INSERT INTO "django_geo_db_location" VALUES(17665,NULL,'Woodlawn, VA',7258,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17666,NULL,'Woodlawn, VA 24381',7258,222,NULL,54,10115,0);
INSERT INTO "django_geo_db_location" VALUES(17667,NULL,'Wytheville, VA',7259,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17668,NULL,'Wytheville, VA 24382',7259,222,NULL,54,10116,0);
INSERT INTO "django_geo_db_location" VALUES(17669,NULL,'Staunton, VA',7260,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17670,NULL,'Staunton, VA 24401',7260,222,NULL,54,10117,0);
INSERT INTO "django_geo_db_location" VALUES(17671,NULL,'Staunton, VA 24402',7260,222,NULL,54,10118,0);
INSERT INTO "django_geo_db_location" VALUES(17672,NULL,'Staunton, VA 24407',7260,222,NULL,54,10119,0);
INSERT INTO "django_geo_db_location" VALUES(17673,NULL,'Augusta Springs, VA',7261,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17674,NULL,'Augusta Springs, VA 24411',7261,222,NULL,54,10120,0);
INSERT INTO "django_geo_db_location" VALUES(17675,NULL,'Bacova, VA',7262,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17676,NULL,'Bacova, VA 24412',7262,222,NULL,54,10121,0);
INSERT INTO "django_geo_db_location" VALUES(17677,NULL,'Blue Grass, VA',7263,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17678,NULL,'Blue Grass, VA 24413',7263,222,NULL,54,10122,0);
INSERT INTO "django_geo_db_location" VALUES(17679,NULL,'Brownsburg, VA',7264,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17680,NULL,'Brownsburg, VA 24415',7264,222,NULL,54,10123,0);
INSERT INTO "django_geo_db_location" VALUES(17681,NULL,'Buena Vista, VA',7265,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17682,NULL,'Buena Vista, VA 24416',7265,222,NULL,54,10124,0);
INSERT INTO "django_geo_db_location" VALUES(17683,NULL,'Churchville, VA',7266,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17684,NULL,'Churchville, VA 24421',7266,222,NULL,54,10125,0);
INSERT INTO "django_geo_db_location" VALUES(17685,NULL,'Clifton Forge, VA',7267,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17686,NULL,'Clifton Forge, VA 24422',7267,222,NULL,54,10126,0);
INSERT INTO "django_geo_db_location" VALUES(17687,NULL,'Covington, VA',7268,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17688,NULL,'Covington, VA 24426',7268,222,NULL,54,10127,0);
INSERT INTO "django_geo_db_location" VALUES(17689,NULL,'Craigsville, VA',7269,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17690,NULL,'Craigsville, VA 24430',7269,222,NULL,54,10128,0);
INSERT INTO "django_geo_db_location" VALUES(17691,NULL,'Crimora, VA',7270,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17692,NULL,'Crimora, VA 24431',7270,222,NULL,54,10129,0);
INSERT INTO "django_geo_db_location" VALUES(17693,NULL,'Deerfield, VA',7271,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17694,NULL,'Deerfield, VA 24432',7271,222,NULL,54,10130,0);
INSERT INTO "django_geo_db_location" VALUES(17695,NULL,'Doe Hill, VA',7272,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17696,NULL,'Doe Hill, VA 24433',7272,222,NULL,54,10131,0);
INSERT INTO "django_geo_db_location" VALUES(17697,NULL,'Fairfield, VA',7273,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17698,NULL,'Fairfield, VA 24435',7273,222,NULL,54,10132,0);
INSERT INTO "django_geo_db_location" VALUES(17699,NULL,'Fort Defiance, VA',7274,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17700,NULL,'Fort Defiance, VA 24437',7274,222,NULL,54,10133,0);
INSERT INTO "django_geo_db_location" VALUES(17701,NULL,'Glen Wilton, VA',7275,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17702,NULL,'Glen Wilton, VA 24438',7275,222,NULL,54,10134,0);
INSERT INTO "django_geo_db_location" VALUES(17703,NULL,'Goshen, VA',7276,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17704,NULL,'Goshen, VA 24439',7276,222,NULL,54,10135,0);
INSERT INTO "django_geo_db_location" VALUES(17705,NULL,'Greenville, VA',7277,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17706,NULL,'Greenville, VA 24440',7277,222,NULL,54,10136,0);
INSERT INTO "django_geo_db_location" VALUES(17707,NULL,'Grottoes, VA',7278,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17708,NULL,'Grottoes, VA 24441',7278,222,NULL,54,10137,0);
INSERT INTO "django_geo_db_location" VALUES(17709,NULL,'Head Waters, VA',7279,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17710,NULL,'Head Waters, VA 24442',7279,222,NULL,54,10138,0);
INSERT INTO "django_geo_db_location" VALUES(17711,NULL,'Iron Gate, VA',7280,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17712,NULL,'Iron Gate, VA 24444',7280,222,NULL,54,10139,0);
INSERT INTO "django_geo_db_location" VALUES(17713,NULL,'Hot Springs, VA',7281,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17714,NULL,'Hot Springs, VA 24445',7281,222,NULL,54,10140,0);
INSERT INTO "django_geo_db_location" VALUES(17715,NULL,'Iron Gate, VA 24448',7280,222,NULL,54,10141,0);
INSERT INTO "django_geo_db_location" VALUES(17716,NULL,'Lexington, VA',7282,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17717,NULL,'Lexington, VA 24450',7282,222,NULL,54,10142,0);
INSERT INTO "django_geo_db_location" VALUES(17718,NULL,'Low Moor, VA',7283,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17719,NULL,'Low Moor, VA 24457',7283,222,NULL,54,10143,0);
INSERT INTO "django_geo_db_location" VALUES(17720,NULL,'McDowell, VA',7284,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17721,NULL,'McDowell, VA 24458',7284,222,NULL,54,10144,0);
INSERT INTO "django_geo_db_location" VALUES(17722,NULL,'Middlebrook, VA',7285,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17723,NULL,'Middlebrook, VA 24459',7285,222,NULL,54,10145,0);
INSERT INTO "django_geo_db_location" VALUES(17724,NULL,'Millboro, VA',7286,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17725,NULL,'Millboro, VA 24460',7286,222,NULL,54,10146,0);
INSERT INTO "django_geo_db_location" VALUES(17726,NULL,'Mint Spring, VA',7287,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17727,NULL,'Mint Spring, VA 24463',7287,222,NULL,54,10147,0);
INSERT INTO "django_geo_db_location" VALUES(17728,NULL,'Montebello, VA',7288,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17729,NULL,'Montebello, VA 24464',7288,222,NULL,54,10148,0);
INSERT INTO "django_geo_db_location" VALUES(17730,NULL,'Monterey, VA',7289,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17731,NULL,'Monterey, VA 24465',7289,222,NULL,54,10149,0);
INSERT INTO "django_geo_db_location" VALUES(17732,NULL,'Mount Sidney, VA',7290,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17733,NULL,'Mount Sidney, VA 24467',7290,222,NULL,54,10150,0);
INSERT INTO "django_geo_db_location" VALUES(17734,NULL,'Mustoe, VA',7291,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17735,NULL,'Mustoe, VA 24468',7291,222,NULL,54,10151,0);
INSERT INTO "django_geo_db_location" VALUES(17736,NULL,'New Hope, VA',7292,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17737,NULL,'New Hope, VA 24469',7292,222,NULL,54,10152,0);
INSERT INTO "django_geo_db_location" VALUES(17738,NULL,'Port Republic, VA',7293,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17739,NULL,'Port Republic, VA 24471',7293,222,NULL,54,10153,0);
INSERT INTO "django_geo_db_location" VALUES(17740,NULL,'Raphine, VA',7294,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17741,NULL,'Raphine, VA 24472',7294,222,NULL,54,10154,0);
INSERT INTO "django_geo_db_location" VALUES(17742,NULL,'Rockbridge Baths, VA',7295,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17743,NULL,'Rockbridge Baths, VA 24473',7295,222,NULL,54,10155,0);
INSERT INTO "django_geo_db_location" VALUES(17744,NULL,'Selma, VA',7296,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17745,NULL,'Selma, VA 24474',7296,222,NULL,54,10156,0);
INSERT INTO "django_geo_db_location" VALUES(17746,NULL,'Spottswood, VA',7297,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17747,NULL,'Spottswood, VA 24475',7297,222,NULL,54,10157,0);
INSERT INTO "django_geo_db_location" VALUES(17748,NULL,'Steeles Tavern, VA',7298,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17749,NULL,'Steeles Tavern, VA 24476',7298,222,NULL,54,10158,0);
INSERT INTO "django_geo_db_location" VALUES(17750,NULL,'Stuarts Draft, VA',7299,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17751,NULL,'Stuarts Draft, VA 24477',7299,222,NULL,54,10159,0);
INSERT INTO "django_geo_db_location" VALUES(17752,NULL,'Swoope, VA',7300,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17753,NULL,'Swoope, VA 24479',7300,222,NULL,54,10160,0);
INSERT INTO "django_geo_db_location" VALUES(17754,NULL,'Verona, VA',7301,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17755,NULL,'Verona, VA 24482',7301,222,NULL,54,10161,0);
INSERT INTO "django_geo_db_location" VALUES(17756,NULL,'Vesuvius, VA',7302,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17757,NULL,'Vesuvius, VA 24483',7302,222,NULL,54,10162,0);
INSERT INTO "django_geo_db_location" VALUES(17758,NULL,'Warm Springs, VA',7303,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17759,NULL,'Warm Springs, VA 24484',7303,222,NULL,54,10163,0);
INSERT INTO "django_geo_db_location" VALUES(17760,NULL,'West Augusta, VA',7304,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17761,NULL,'West Augusta, VA 24485',7304,222,NULL,54,10164,0);
INSERT INTO "django_geo_db_location" VALUES(17762,NULL,'Weyers Cave, VA',7305,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17763,NULL,'Weyers Cave, VA 24486',7305,222,NULL,54,10165,0);
INSERT INTO "django_geo_db_location" VALUES(17764,NULL,'Williamsville, VA',7306,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17765,NULL,'Williamsville, VA 24487',7306,222,NULL,54,10166,0);
INSERT INTO "django_geo_db_location" VALUES(17766,NULL,'Lynchburg, VA',7307,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17767,NULL,'Lynchburg, VA 24501',7307,222,NULL,54,10167,0);
INSERT INTO "django_geo_db_location" VALUES(17768,NULL,'Lynchburg, VA 24502',7307,222,NULL,54,10168,0);
INSERT INTO "django_geo_db_location" VALUES(17769,NULL,'Lynchburg, VA 24503',7307,222,NULL,54,10169,0);
INSERT INTO "django_geo_db_location" VALUES(17770,NULL,'Lynchburg, VA 24504',7307,222,NULL,54,10170,0);
INSERT INTO "django_geo_db_location" VALUES(17771,NULL,'Lynchburg, VA 24505',7307,222,NULL,54,10171,0);
INSERT INTO "django_geo_db_location" VALUES(17772,NULL,'Lynchburg, VA 24506',7307,222,NULL,54,10172,0);
INSERT INTO "django_geo_db_location" VALUES(17773,NULL,'Lynchburg, VA 24512',7307,222,NULL,54,10173,0);
INSERT INTO "django_geo_db_location" VALUES(17774,NULL,'Lynchburg, VA 24513',7307,222,NULL,54,10174,0);
INSERT INTO "django_geo_db_location" VALUES(17775,NULL,'Lynchburg, VA 24514',7307,222,NULL,54,10175,0);
INSERT INTO "django_geo_db_location" VALUES(17776,NULL,'Lynchburg, VA 24515',7307,222,NULL,54,10176,0);
INSERT INTO "django_geo_db_location" VALUES(17777,NULL,'Altavista, VA',7308,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17778,NULL,'Altavista, VA 24517',7308,222,NULL,54,10177,0);
INSERT INTO "django_geo_db_location" VALUES(17779,NULL,'Alton, VA',7309,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17780,NULL,'Alton, VA 24520',7309,222,NULL,54,10178,0);
INSERT INTO "django_geo_db_location" VALUES(17781,NULL,'Amherst, VA',7310,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17782,NULL,'Amherst, VA 24521',7310,222,NULL,54,10179,0);
INSERT INTO "django_geo_db_location" VALUES(17783,NULL,'Appomattox, VA',7311,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17784,NULL,'Appomattox, VA 24522',7311,222,NULL,54,10180,0);
INSERT INTO "django_geo_db_location" VALUES(17785,NULL,'Bedford, VA',7312,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17786,NULL,'Bedford, VA 24523',7312,222,NULL,54,10181,0);
INSERT INTO "django_geo_db_location" VALUES(17787,NULL,'Big Island, VA',7313,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17788,NULL,'Big Island, VA 24526',7313,222,NULL,54,10182,0);
INSERT INTO "django_geo_db_location" VALUES(17789,NULL,'Blairs, VA',7314,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17790,NULL,'Blairs, VA 24527',7314,222,NULL,54,10183,0);
INSERT INTO "django_geo_db_location" VALUES(17791,NULL,'Brookneal, VA',7315,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17792,NULL,'Brookneal, VA 24528',7315,222,NULL,54,10184,0);
INSERT INTO "django_geo_db_location" VALUES(17793,NULL,'Buffalo Junction, VA',7316,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17794,NULL,'Buffalo Junction, VA 24529',7316,222,NULL,54,10185,0);
INSERT INTO "django_geo_db_location" VALUES(17795,NULL,'Callands, VA',7317,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17796,NULL,'Callands, VA 24530',7317,222,NULL,54,10186,0);
INSERT INTO "django_geo_db_location" VALUES(17797,NULL,'Chatham, VA',7318,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17798,NULL,'Chatham, VA 24531',7318,222,NULL,54,10187,0);
INSERT INTO "django_geo_db_location" VALUES(17799,NULL,'Clifford, VA',7319,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17800,NULL,'Clifford, VA 24533',7319,222,NULL,54,10188,0);
INSERT INTO "django_geo_db_location" VALUES(17801,NULL,'Clover, VA',7320,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17802,NULL,'Clover, VA 24534',7320,222,NULL,54,10189,0);
INSERT INTO "django_geo_db_location" VALUES(17803,NULL,'Cluster Springs, VA',7321,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17804,NULL,'Cluster Springs, VA 24535',7321,222,NULL,54,10190,0);
INSERT INTO "django_geo_db_location" VALUES(17805,NULL,'Coleman Falls, VA',7322,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17806,NULL,'Coleman Falls, VA 24536',7322,222,NULL,54,10191,0);
INSERT INTO "django_geo_db_location" VALUES(17807,NULL,'Concord, VA',7323,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17808,NULL,'Concord, VA 24538',7323,222,NULL,54,10192,0);
INSERT INTO "django_geo_db_location" VALUES(17809,NULL,'Crystal Hill, VA',7324,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17810,NULL,'Crystal Hill, VA 24539',7324,222,NULL,54,10193,0);
INSERT INTO "django_geo_db_location" VALUES(17811,NULL,'Danville, VA',7325,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17812,NULL,'Danville, VA 24540',7325,222,NULL,54,10194,0);
INSERT INTO "django_geo_db_location" VALUES(17813,NULL,'Danville, VA 24541',7325,222,NULL,54,10195,0);
INSERT INTO "django_geo_db_location" VALUES(17814,NULL,'Danville, VA 24542',7325,222,NULL,54,10196,0);
INSERT INTO "django_geo_db_location" VALUES(17815,NULL,'Danville, VA 24543',7325,222,NULL,54,10197,0);
INSERT INTO "django_geo_db_location" VALUES(17816,NULL,'Danville, VA 24544',7325,222,NULL,54,10198,0);
INSERT INTO "django_geo_db_location" VALUES(17817,NULL,'Dry Fork, VA',7326,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17818,NULL,'Dry Fork, VA 24549',7326,222,NULL,54,10199,0);
INSERT INTO "django_geo_db_location" VALUES(17819,NULL,'Evington, VA',7327,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17820,NULL,'Evington, VA 24550',7327,222,NULL,54,10200,0);
INSERT INTO "django_geo_db_location" VALUES(17821,NULL,'Forest, VA',7328,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17822,NULL,'Forest, VA 24551',7328,222,NULL,54,10201,0);
INSERT INTO "django_geo_db_location" VALUES(17823,NULL,'Gladstone, VA',7329,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17824,NULL,'Gladstone, VA 24553',7329,222,NULL,54,10202,0);
INSERT INTO "django_geo_db_location" VALUES(17825,NULL,'Gladys, VA',7330,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17826,NULL,'Gladys, VA 24554',7330,222,NULL,54,10203,0);
INSERT INTO "django_geo_db_location" VALUES(17827,NULL,'Glasgow, VA',7331,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17828,NULL,'Glasgow, VA 24555',7331,222,NULL,54,10204,0);
INSERT INTO "django_geo_db_location" VALUES(17829,NULL,'Goode, VA',7332,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17830,NULL,'Goode, VA 24556',7332,222,NULL,54,10205,0);
INSERT INTO "django_geo_db_location" VALUES(17831,NULL,'Gretna, VA',7333,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17832,NULL,'Gretna, VA 24557',7333,222,NULL,54,10206,0);
INSERT INTO "django_geo_db_location" VALUES(17833,NULL,'Halifax, VA',7334,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17834,NULL,'Halifax, VA 24558',7334,222,NULL,54,10207,0);
INSERT INTO "django_geo_db_location" VALUES(17835,NULL,'Howardsville, VA',7335,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17836,NULL,'Howardsville, VA 24562',7335,222,NULL,54,10208,0);
INSERT INTO "django_geo_db_location" VALUES(17837,NULL,'Hurt, VA',7336,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17838,NULL,'Hurt, VA 24563',7336,222,NULL,54,10209,0);
INSERT INTO "django_geo_db_location" VALUES(17839,NULL,'Java, VA',7337,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17840,NULL,'Java, VA 24565',7337,222,NULL,54,10210,0);
INSERT INTO "django_geo_db_location" VALUES(17841,NULL,'Keeling, VA',7338,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17842,NULL,'Keeling, VA 24566',7338,222,NULL,54,10211,0);
INSERT INTO "django_geo_db_location" VALUES(17843,NULL,'Long Island, VA',7339,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17844,NULL,'Long Island, VA 24569',7339,222,NULL,54,10212,0);
INSERT INTO "django_geo_db_location" VALUES(17845,NULL,'Lowry, VA',7340,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17846,NULL,'Lowry, VA 24570',7340,222,NULL,54,10213,0);
INSERT INTO "django_geo_db_location" VALUES(17847,NULL,'Lynch Station, VA',7341,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17848,NULL,'Lynch Station, VA 24571',7341,222,NULL,54,10214,0);
INSERT INTO "django_geo_db_location" VALUES(17849,NULL,'Madison Heights, VA',7342,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17850,NULL,'Madison Heights, VA 24572',7342,222,NULL,54,10215,0);
INSERT INTO "django_geo_db_location" VALUES(17851,NULL,'Monroe, VA',7343,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17852,NULL,'Monroe, VA 24574',7343,222,NULL,54,10216,0);
INSERT INTO "django_geo_db_location" VALUES(17853,NULL,'Naruna, VA',7344,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17854,NULL,'Naruna, VA 24576',7344,222,NULL,54,10217,0);
INSERT INTO "django_geo_db_location" VALUES(17855,NULL,'Nathalie, VA',7345,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17856,NULL,'Nathalie, VA 24577',7345,222,NULL,54,10218,0);
INSERT INTO "django_geo_db_location" VALUES(17857,NULL,'Natural Bridge, VA',7346,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17858,NULL,'Natural Bridge, VA 24578',7346,222,NULL,54,10219,0);
INSERT INTO "django_geo_db_location" VALUES(17859,NULL,'Natural Bridge Station, VA',7347,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17860,NULL,'Natural Bridge Station, VA 24579',7347,222,NULL,54,10220,0);
INSERT INTO "django_geo_db_location" VALUES(17861,NULL,'Nelson, VA',7348,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17862,NULL,'Nelson, VA 24580',7348,222,NULL,54,10221,0);
INSERT INTO "django_geo_db_location" VALUES(17863,NULL,'Norwood, VA',7349,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17864,NULL,'Norwood, VA 24581',7349,222,NULL,54,10222,0);
INSERT INTO "django_geo_db_location" VALUES(17865,NULL,'Republican Grove, VA',7350,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17866,NULL,'Republican Grove, VA 24585',7350,222,NULL,54,10223,0);
INSERT INTO "django_geo_db_location" VALUES(17867,NULL,'Ringgold, VA',7351,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17868,NULL,'Ringgold, VA 24586',7351,222,NULL,54,10224,0);
INSERT INTO "django_geo_db_location" VALUES(17869,NULL,'Rustburg, VA',7352,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17870,NULL,'Rustburg, VA 24588',7352,222,NULL,54,10225,0);
INSERT INTO "django_geo_db_location" VALUES(17871,NULL,'Scottsburg, VA',7353,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17872,NULL,'Scottsburg, VA 24589',7353,222,NULL,54,10226,0);
INSERT INTO "django_geo_db_location" VALUES(17873,NULL,'Scottsville, VA',7354,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17874,NULL,'Scottsville, VA 24590',7354,222,NULL,54,10227,0);
INSERT INTO "django_geo_db_location" VALUES(17875,NULL,'South Boston, VA',7355,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17876,NULL,'South Boston, VA 24592',7355,222,NULL,54,10228,0);
INSERT INTO "django_geo_db_location" VALUES(17877,NULL,'Spout Spring, VA',7356,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17878,NULL,'Spout Spring, VA 24593',7356,222,NULL,54,10229,0);
INSERT INTO "django_geo_db_location" VALUES(17879,NULL,'Sutherlin, VA',7357,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17880,NULL,'Sutherlin, VA 24594',7357,222,NULL,54,10230,0);
INSERT INTO "django_geo_db_location" VALUES(17881,NULL,'Sweet Briar, VA',7358,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17882,NULL,'Sweet Briar, VA 24595',7358,222,NULL,54,10231,0);
INSERT INTO "django_geo_db_location" VALUES(17883,NULL,'Vernon Hill, VA',7359,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17884,NULL,'Vernon Hill, VA 24597',7359,222,NULL,54,10232,0);
INSERT INTO "django_geo_db_location" VALUES(17885,NULL,'Virgilina, VA',7360,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17886,NULL,'Virgilina, VA 24598',7360,222,NULL,54,10233,0);
INSERT INTO "django_geo_db_location" VALUES(17887,NULL,'Wingina, VA',7361,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17888,NULL,'Wingina, VA 24599',7361,222,NULL,54,10234,0);
INSERT INTO "django_geo_db_location" VALUES(17889,NULL,'Amonate, VA',7362,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17890,NULL,'Amonate, VA 24601',7362,222,NULL,54,10235,0);
INSERT INTO "django_geo_db_location" VALUES(17891,NULL,'Bandy, VA',7363,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17892,NULL,'Bandy, VA 24602',7363,222,NULL,54,10236,0);
INSERT INTO "django_geo_db_location" VALUES(17893,NULL,'Big Rock, VA',7364,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17894,NULL,'Big Rock, VA 24603',7364,222,NULL,54,10237,0);
INSERT INTO "django_geo_db_location" VALUES(17895,NULL,'Bishop, VA',7365,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17896,NULL,'Bishop, VA 24604',7365,222,NULL,54,10238,0);
INSERT INTO "django_geo_db_location" VALUES(17897,NULL,'Bluefield, VA',7366,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17898,NULL,'Bluefield, VA 24605',7366,222,NULL,54,10239,0);
INSERT INTO "django_geo_db_location" VALUES(17899,NULL,'Boissevain, VA',7367,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17900,NULL,'Boissevain, VA 24606',7367,222,NULL,54,10240,0);
INSERT INTO "django_geo_db_location" VALUES(17901,NULL,'Breaks, VA',7368,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17902,NULL,'Breaks, VA 24607',7368,222,NULL,54,10241,0);
INSERT INTO "django_geo_db_location" VALUES(17903,NULL,'Burkes Garden, VA',7369,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17904,NULL,'Burkes Garden, VA 24608',7369,222,NULL,54,10242,0);
INSERT INTO "django_geo_db_location" VALUES(17905,NULL,'Cedar Bluff, VA',7370,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17906,NULL,'Cedar Bluff, VA 24609',7370,222,NULL,54,10243,0);
INSERT INTO "django_geo_db_location" VALUES(17907,NULL,'Doran, VA',7371,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17908,NULL,'Doran, VA 24612',7371,222,NULL,54,10244,0);
INSERT INTO "django_geo_db_location" VALUES(17909,NULL,'Falls Mills, VA',7372,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17910,NULL,'Falls Mills, VA 24613',7372,222,NULL,54,10245,0);
INSERT INTO "django_geo_db_location" VALUES(17911,NULL,'Grundy, VA',7373,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17912,NULL,'Grundy, VA 24614',7373,222,NULL,54,10246,0);
INSERT INTO "django_geo_db_location" VALUES(17913,NULL,'Harman, VA',7374,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17914,NULL,'Harman, VA 24618',7374,222,NULL,54,10247,0);
INSERT INTO "django_geo_db_location" VALUES(17915,NULL,'Horsepen, VA',7375,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17916,NULL,'Horsepen, VA 24619',7375,222,NULL,54,10248,0);
INSERT INTO "django_geo_db_location" VALUES(17917,NULL,'Hurley, VA',7376,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17918,NULL,'Hurley, VA 24620',7376,222,NULL,54,10249,0);
INSERT INTO "django_geo_db_location" VALUES(17919,NULL,'Jewell Ridge, VA',7377,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17920,NULL,'Jewell Ridge, VA 24622',7377,222,NULL,54,10250,0);
INSERT INTO "django_geo_db_location" VALUES(17921,NULL,'Keen Mountain, VA',7378,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17922,NULL,'Keen Mountain, VA 24624',7378,222,NULL,54,10251,0);
INSERT INTO "django_geo_db_location" VALUES(17923,NULL,'Mavisdale, VA',7379,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17924,NULL,'Mavisdale, VA 24627',7379,222,NULL,54,10252,0);
INSERT INTO "django_geo_db_location" VALUES(17925,NULL,'Maxie, VA',7380,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17926,NULL,'Maxie, VA 24628',7380,222,NULL,54,10253,0);
INSERT INTO "django_geo_db_location" VALUES(17927,NULL,'North Tazewell, VA',7381,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17928,NULL,'North Tazewell, VA 24630',7381,222,NULL,54,10254,0);
INSERT INTO "django_geo_db_location" VALUES(17929,NULL,'Oakwood, VA',7382,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17930,NULL,'Oakwood, VA 24631',7382,222,NULL,54,10255,0);
INSERT INTO "django_geo_db_location" VALUES(17931,NULL,'Pilgrims Knob, VA',7383,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17932,NULL,'Pilgrims Knob, VA 24634',7383,222,NULL,54,10256,0);
INSERT INTO "django_geo_db_location" VALUES(17933,NULL,'Pocahontas, VA',7384,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17934,NULL,'Pocahontas, VA 24635',7384,222,NULL,54,10257,0);
INSERT INTO "django_geo_db_location" VALUES(17935,NULL,'Pounding Mill, VA',7385,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17936,NULL,'Pounding Mill, VA 24637',7385,222,NULL,54,10258,0);
INSERT INTO "django_geo_db_location" VALUES(17937,NULL,'Raven, VA',7386,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17938,NULL,'Raven, VA 24639',7386,222,NULL,54,10259,0);
INSERT INTO "django_geo_db_location" VALUES(17939,NULL,'Red Ash, VA',7387,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17940,NULL,'Red Ash, VA 24640',7387,222,NULL,54,10260,0);
INSERT INTO "django_geo_db_location" VALUES(17941,NULL,'Richlands, VA',7388,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17942,NULL,'Richlands, VA 24641',7388,222,NULL,54,10261,0);
INSERT INTO "django_geo_db_location" VALUES(17943,NULL,'Rowe, VA',7389,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17944,NULL,'Rowe, VA 24646',7389,222,NULL,54,10262,0);
INSERT INTO "django_geo_db_location" VALUES(17945,NULL,'Shortt Gap, VA',7390,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17946,NULL,'Shortt Gap, VA 24647',7390,222,NULL,54,10263,0);
INSERT INTO "django_geo_db_location" VALUES(17947,NULL,'Swords Creek, VA',7391,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17948,NULL,'Swords Creek, VA 24649',7391,222,NULL,54,10264,0);
INSERT INTO "django_geo_db_location" VALUES(17949,NULL,'Tazewell, VA',7392,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17950,NULL,'Tazewell, VA 24651',7392,222,NULL,54,10265,0);
INSERT INTO "django_geo_db_location" VALUES(17951,NULL,'Vansant, VA',7393,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17952,NULL,'Vansant, VA 24656',7393,222,NULL,54,10266,0);
INSERT INTO "django_geo_db_location" VALUES(17953,NULL,'Whitewood, VA',7394,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17954,NULL,'Whitewood, VA 24657',7394,222,NULL,54,10267,0);
INSERT INTO "django_geo_db_location" VALUES(17955,NULL,'Wolford, VA',7395,222,NULL,54,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17956,NULL,'Wolford, VA 24658',7395,222,NULL,54,10268,0);
INSERT INTO "django_geo_db_location" VALUES(17957,NULL,'Bluefield, WV',7396,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17958,NULL,'Bluefield, WV 24701',7396,222,NULL,57,10269,0);
INSERT INTO "django_geo_db_location" VALUES(17959,NULL,'Bluefield, WV 24704',7396,222,NULL,57,10270,0);
INSERT INTO "django_geo_db_location" VALUES(17960,NULL,'Athens, WV',7397,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17961,NULL,'Athens, WV 24712',7397,222,NULL,57,10271,0);
INSERT INTO "django_geo_db_location" VALUES(17962,NULL,'Beeson, WV',7398,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17963,NULL,'Beeson, WV 24714',7398,222,NULL,57,10272,0);
INSERT INTO "django_geo_db_location" VALUES(17964,NULL,'Bramwell, WV',7399,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17965,NULL,'Bramwell, WV 24715',7399,222,NULL,57,10273,0);
INSERT INTO "django_geo_db_location" VALUES(17966,NULL,'Bud, WV',7400,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17967,NULL,'Bud, WV 24716',7400,222,NULL,57,10274,0);
INSERT INTO "django_geo_db_location" VALUES(17968,NULL,'Covel, WV',7401,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17969,NULL,'Covel, WV 24719',7401,222,NULL,57,10275,0);
INSERT INTO "django_geo_db_location" VALUES(17970,NULL,'Freeman, WV',7402,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17971,NULL,'Freeman, WV 24724',7402,222,NULL,57,10276,0);
INSERT INTO "django_geo_db_location" VALUES(17972,NULL,'Herndon, WV',7403,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17973,NULL,'Herndon, WV 24726',7403,222,NULL,57,10277,0);
INSERT INTO "django_geo_db_location" VALUES(17974,NULL,'Hiawatha, WV',7404,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17975,NULL,'Hiawatha, WV 24729',7404,222,NULL,57,10278,0);
INSERT INTO "django_geo_db_location" VALUES(17976,NULL,'Kegley, WV',7405,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17977,NULL,'Kegley, WV 24731',7405,222,NULL,57,10279,0);
INSERT INTO "django_geo_db_location" VALUES(17978,NULL,'Kellysville, WV',7406,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17979,NULL,'Kellysville, WV 24732',7406,222,NULL,57,10280,0);
INSERT INTO "django_geo_db_location" VALUES(17980,NULL,'Lashmeet, WV',7407,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17981,NULL,'Lashmeet, WV 24733',7407,222,NULL,57,10281,0);
INSERT INTO "django_geo_db_location" VALUES(17982,NULL,'Matoaka, WV',7408,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17983,NULL,'Matoaka, WV 24736',7408,222,NULL,57,10282,0);
INSERT INTO "django_geo_db_location" VALUES(17984,NULL,'Montcalm, WV',7409,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17985,NULL,'Montcalm, WV 24737',7409,222,NULL,57,10283,0);
INSERT INTO "django_geo_db_location" VALUES(17986,NULL,'Nemours, WV',7410,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17987,NULL,'Nemours, WV 24738',7410,222,NULL,57,10284,0);
INSERT INTO "django_geo_db_location" VALUES(17988,NULL,'Oakvale, WV',7411,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17989,NULL,'Oakvale, WV 24739',7411,222,NULL,57,10285,0);
INSERT INTO "django_geo_db_location" VALUES(17990,NULL,'Princeton, WV',7412,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17991,NULL,'Princeton, WV 24740',7412,222,NULL,57,10286,0);
INSERT INTO "django_geo_db_location" VALUES(17992,NULL,'Rock, WV',7413,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17993,NULL,'Rock, WV 24747',7413,222,NULL,57,10287,0);
INSERT INTO "django_geo_db_location" VALUES(17994,NULL,'Wolfe, WV',7414,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17995,NULL,'Wolfe, WV 24751',7414,222,NULL,57,10288,0);
INSERT INTO "django_geo_db_location" VALUES(17996,NULL,'Welch, WV',7415,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17997,NULL,'Welch, WV 24801',7415,222,NULL,57,10289,0);
INSERT INTO "django_geo_db_location" VALUES(17998,NULL,'Anawalt, WV',7416,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(17999,NULL,'Anawalt, WV 24808',7416,222,NULL,57,10290,0);
INSERT INTO "django_geo_db_location" VALUES(18000,NULL,'Avondale, WV',7417,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18001,NULL,'Avondale, WV 24811',7417,222,NULL,57,10291,0);
INSERT INTO "django_geo_db_location" VALUES(18002,NULL,'Bartley, WV',7418,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18003,NULL,'Bartley, WV 24813',7418,222,NULL,57,10292,0);
INSERT INTO "django_geo_db_location" VALUES(18004,NULL,'Berwind, WV',7419,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18005,NULL,'Berwind, WV 24815',7419,222,NULL,57,10293,0);
INSERT INTO "django_geo_db_location" VALUES(18006,NULL,'Big Sandy, WV',7420,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18007,NULL,'Big Sandy, WV 24816',7420,222,NULL,57,10294,0);
INSERT INTO "django_geo_db_location" VALUES(18008,NULL,'Bradshaw, WV',7421,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18009,NULL,'Bradshaw, WV 24817',7421,222,NULL,57,10295,0);
INSERT INTO "django_geo_db_location" VALUES(18010,NULL,'Brenton, WV',7422,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18011,NULL,'Brenton, WV 24818',7422,222,NULL,57,10296,0);
INSERT INTO "django_geo_db_location" VALUES(18012,NULL,'Capels, WV',7423,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18013,NULL,'Capels, WV 24820',7423,222,NULL,57,10297,0);
INSERT INTO "django_geo_db_location" VALUES(18014,NULL,'Caretta, WV',7424,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18015,NULL,'Caretta, WV 24821',7424,222,NULL,57,10298,0);
INSERT INTO "django_geo_db_location" VALUES(18016,NULL,'Clear Fork, WV',7425,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18017,NULL,'Clear Fork, WV 24822',7425,222,NULL,57,10299,0);
INSERT INTO "django_geo_db_location" VALUES(18018,NULL,'Coal Mountain, WV',7426,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18019,NULL,'Coal Mountain, WV 24823',7426,222,NULL,57,10300,0);
INSERT INTO "django_geo_db_location" VALUES(18020,NULL,'Coalwood, WV',7427,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18021,NULL,'Coalwood, WV 24824',7427,222,NULL,57,10301,0);
INSERT INTO "django_geo_db_location" VALUES(18022,NULL,'Crumpler, WV',7428,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18023,NULL,'Crumpler, WV 24825',7428,222,NULL,57,10302,0);
INSERT INTO "django_geo_db_location" VALUES(18024,NULL,'Cucumber, WV',7429,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18025,NULL,'Cucumber, WV 24826',7429,222,NULL,57,10303,0);
INSERT INTO "django_geo_db_location" VALUES(18026,NULL,'Cyclone, WV',7430,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18027,NULL,'Cyclone, WV 24827',7430,222,NULL,57,10304,0);
INSERT INTO "django_geo_db_location" VALUES(18028,NULL,'Davy, WV',7431,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18029,NULL,'Davy, WV 24828',7431,222,NULL,57,10305,0);
INSERT INTO "django_geo_db_location" VALUES(18030,NULL,'Eckman, WV',7432,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18031,NULL,'Eckman, WV 24829',7432,222,NULL,57,10306,0);
INSERT INTO "django_geo_db_location" VALUES(18032,NULL,'Elbert, WV',7433,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18033,NULL,'Elbert, WV 24830',7433,222,NULL,57,10307,0);
INSERT INTO "django_geo_db_location" VALUES(18034,NULL,'Elkhorn, WV',7434,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18035,NULL,'Elkhorn, WV 24831',7434,222,NULL,57,10308,0);
INSERT INTO "django_geo_db_location" VALUES(18036,NULL,'English, WV',7435,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18037,NULL,'English, WV 24832',7435,222,NULL,57,10309,0);
INSERT INTO "django_geo_db_location" VALUES(18038,NULL,'Fanrock, WV',7436,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18039,NULL,'Fanrock, WV 24834',7436,222,NULL,57,10310,0);
INSERT INTO "django_geo_db_location" VALUES(18040,NULL,'Gary, WV',7437,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18041,NULL,'Gary, WV 24836',7437,222,NULL,57,10311,0);
INSERT INTO "django_geo_db_location" VALUES(18042,NULL,'Hanover, WV',7438,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18043,NULL,'Hanover, WV 24839',7438,222,NULL,57,10312,0);
INSERT INTO "django_geo_db_location" VALUES(18044,NULL,'Havaco, WV',7439,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18045,NULL,'Havaco, WV 24841',7439,222,NULL,57,10313,0);
INSERT INTO "django_geo_db_location" VALUES(18046,NULL,'Hemphill, WV',7440,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18047,NULL,'Hemphill, WV 24842',7440,222,NULL,57,10314,0);
INSERT INTO "django_geo_db_location" VALUES(18048,NULL,'Hensley, WV',7441,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18049,NULL,'Hensley, WV 24843',7441,222,NULL,57,10315,0);
INSERT INTO "django_geo_db_location" VALUES(18050,NULL,'Iaeger, WV',7442,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18051,NULL,'Iaeger, WV 24844',7442,222,NULL,57,10316,0);
INSERT INTO "django_geo_db_location" VALUES(18052,NULL,'Ikes Fork, WV',7443,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18053,NULL,'Ikes Fork, WV 24845',7443,222,NULL,57,10317,0);
INSERT INTO "django_geo_db_location" VALUES(18054,NULL,'Isaban, WV',7444,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18055,NULL,'Isaban, WV 24846',7444,222,NULL,57,10318,0);
INSERT INTO "django_geo_db_location" VALUES(18056,NULL,'Itmann, WV',7445,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18057,NULL,'Itmann, WV 24847',7445,222,NULL,57,10319,0);
INSERT INTO "django_geo_db_location" VALUES(18058,NULL,'Jenkinjones, WV',7446,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18059,NULL,'Jenkinjones, WV 24848',7446,222,NULL,57,10320,0);
INSERT INTO "django_geo_db_location" VALUES(18060,NULL,'Jesse, WV',7447,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18061,NULL,'Jesse, WV 24849',7447,222,NULL,57,10321,0);
INSERT INTO "django_geo_db_location" VALUES(18062,NULL,'Jolo, WV',7448,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18063,NULL,'Jolo, WV 24850',7448,222,NULL,57,10322,0);
INSERT INTO "django_geo_db_location" VALUES(18064,NULL,'Justice, WV',7449,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18065,NULL,'Justice, WV 24851',7449,222,NULL,57,10323,0);
INSERT INTO "django_geo_db_location" VALUES(18066,NULL,'Keystone, WV',7450,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18067,NULL,'Keystone, WV 24852',7450,222,NULL,57,10324,0);
INSERT INTO "django_geo_db_location" VALUES(18068,NULL,'Kimball, WV',7451,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18069,NULL,'Kimball, WV 24853',7451,222,NULL,57,10325,0);
INSERT INTO "django_geo_db_location" VALUES(18070,NULL,'Kopperston, WV',7452,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18071,NULL,'Kopperston, WV 24854',7452,222,NULL,57,10326,0);
INSERT INTO "django_geo_db_location" VALUES(18072,NULL,'Kyle, WV',7453,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18073,NULL,'Kyle, WV 24855',7453,222,NULL,57,10327,0);
INSERT INTO "django_geo_db_location" VALUES(18074,NULL,'Leckie, WV',7454,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18075,NULL,'Leckie, WV 24856',7454,222,NULL,57,10328,0);
INSERT INTO "django_geo_db_location" VALUES(18076,NULL,'Lynco, WV',7455,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18077,NULL,'Lynco, WV 24857',7455,222,NULL,57,10329,0);
INSERT INTO "django_geo_db_location" VALUES(18078,NULL,'Marianna, WV',7456,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18079,NULL,'Marianna, WV 24859',7456,222,NULL,57,10330,0);
INSERT INTO "django_geo_db_location" VALUES(18080,NULL,'Matheny, WV',7457,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18081,NULL,'Matheny, WV 24860',7457,222,NULL,57,10331,0);
INSERT INTO "django_geo_db_location" VALUES(18082,NULL,'Maybeury, WV',7458,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18083,NULL,'Maybeury, WV 24861',7458,222,NULL,57,10332,0);
INSERT INTO "django_geo_db_location" VALUES(18084,NULL,'Mohawk, WV',7459,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18085,NULL,'Mohawk, WV 24862',7459,222,NULL,57,10333,0);
INSERT INTO "django_geo_db_location" VALUES(18086,NULL,'Newhall, WV',7460,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18087,NULL,'Newhall, WV 24866',7460,222,NULL,57,10334,0);
INSERT INTO "django_geo_db_location" VALUES(18088,NULL,'New Richmond, WV',7461,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18089,NULL,'New Richmond, WV 24867',7461,222,NULL,57,10335,0);
INSERT INTO "django_geo_db_location" VALUES(18090,NULL,'Northfork, WV',7462,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18091,NULL,'Northfork, WV 24868',7462,222,NULL,57,10336,0);
INSERT INTO "django_geo_db_location" VALUES(18092,NULL,'North Spring, WV',7463,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18093,NULL,'North Spring, WV 24869',7463,222,NULL,57,10337,0);
INSERT INTO "django_geo_db_location" VALUES(18094,NULL,'Oceana, WV',7464,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18095,NULL,'Oceana, WV 24870',7464,222,NULL,57,10338,0);
INSERT INTO "django_geo_db_location" VALUES(18096,NULL,'Pageton, WV',7465,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18097,NULL,'Pageton, WV 24871',7465,222,NULL,57,10339,0);
INSERT INTO "django_geo_db_location" VALUES(18098,NULL,'Panther, WV',7466,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18099,NULL,'Panther, WV 24872',7466,222,NULL,57,10340,0);
INSERT INTO "django_geo_db_location" VALUES(18100,NULL,'Paynesville, WV',7467,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18101,NULL,'Paynesville, WV 24873',7467,222,NULL,57,10341,0);
INSERT INTO "django_geo_db_location" VALUES(18102,NULL,'Pineville, WV',7468,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18103,NULL,'Pineville, WV 24874',7468,222,NULL,57,10342,0);
INSERT INTO "django_geo_db_location" VALUES(18104,NULL,'Powhatan, WV',7469,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18105,NULL,'Powhatan, WV 24877',7469,222,NULL,57,10343,0);
INSERT INTO "django_geo_db_location" VALUES(18106,NULL,'Premier, WV',7470,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18107,NULL,'Premier, WV 24878',7470,222,NULL,57,10344,0);
INSERT INTO "django_geo_db_location" VALUES(18108,NULL,'Raysal, WV',7471,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18109,NULL,'Raysal, WV 24879',7471,222,NULL,57,10345,0);
INSERT INTO "django_geo_db_location" VALUES(18110,NULL,'Rock View, WV',7472,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18111,NULL,'Rock View, WV 24880',7472,222,NULL,57,10346,0);
INSERT INTO "django_geo_db_location" VALUES(18112,NULL,'Roderfield, WV',7473,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18113,NULL,'Roderfield, WV 24881',7473,222,NULL,57,10347,0);
INSERT INTO "django_geo_db_location" VALUES(18114,NULL,'Simon, WV',7474,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18115,NULL,'Simon, WV 24882',7474,222,NULL,57,10348,0);
INSERT INTO "django_geo_db_location" VALUES(18116,NULL,'Skygusty, WV',7475,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18117,NULL,'Skygusty, WV 24883',7475,222,NULL,57,10349,0);
INSERT INTO "django_geo_db_location" VALUES(18118,NULL,'Squire, WV',7476,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18119,NULL,'Squire, WV 24884',7476,222,NULL,57,10350,0);
INSERT INTO "django_geo_db_location" VALUES(18120,NULL,'Switchback, WV',7477,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18121,NULL,'Switchback, WV 24887',7477,222,NULL,57,10351,0);
INSERT INTO "django_geo_db_location" VALUES(18122,NULL,'Thorpe, WV',7478,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18123,NULL,'Thorpe, WV 24888',7478,222,NULL,57,10352,0);
INSERT INTO "django_geo_db_location" VALUES(18124,NULL,'Twin Branch, WV',7479,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18125,NULL,'Twin Branch, WV 24889',7479,222,NULL,57,10353,0);
INSERT INTO "django_geo_db_location" VALUES(18126,NULL,'War, WV',7480,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18127,NULL,'War, WV 24892',7480,222,NULL,57,10354,0);
INSERT INTO "django_geo_db_location" VALUES(18128,NULL,'Warriormine, WV',7481,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18129,NULL,'Warriormine, WV 24894',7481,222,NULL,57,10355,0);
INSERT INTO "django_geo_db_location" VALUES(18130,NULL,'Wilcoe, WV',7482,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18131,NULL,'Wilcoe, WV 24895',7482,222,NULL,57,10356,0);
INSERT INTO "django_geo_db_location" VALUES(18132,NULL,'Wolf Pen, WV',7483,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18133,NULL,'Wolf Pen, WV 24896',7483,222,NULL,57,10357,0);
INSERT INTO "django_geo_db_location" VALUES(18134,NULL,'Worth, WV',7484,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18135,NULL,'Worth, WV 24897',7484,222,NULL,57,10358,0);
INSERT INTO "django_geo_db_location" VALUES(18136,NULL,'Wyoming, WV',7485,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18137,NULL,'Wyoming, WV 24898',7485,222,NULL,57,10359,0);
INSERT INTO "django_geo_db_location" VALUES(18138,NULL,'Yukon, WV',7486,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18139,NULL,'Yukon, WV 24899',7486,222,NULL,57,10360,0);
INSERT INTO "django_geo_db_location" VALUES(18140,NULL,'Lewisburg, WV',7487,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18141,NULL,'Lewisburg, WV 24901',7487,222,NULL,57,10361,0);
INSERT INTO "django_geo_db_location" VALUES(18142,NULL,'Fairlea, WV',7488,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18143,NULL,'Fairlea, WV 24902',7488,222,NULL,57,10362,0);
INSERT INTO "django_geo_db_location" VALUES(18144,NULL,'Alderson, WV',7489,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18145,NULL,'Alderson, WV 24910',7489,222,NULL,57,10363,0);
INSERT INTO "django_geo_db_location" VALUES(18146,NULL,'Arbovale, WV',7490,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18147,NULL,'Arbovale, WV 24915',7490,222,NULL,57,10364,0);
INSERT INTO "django_geo_db_location" VALUES(18148,NULL,'Asbury, WV',7491,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18149,NULL,'Asbury, WV 24916',7491,222,NULL,57,10365,0);
INSERT INTO "django_geo_db_location" VALUES(18150,NULL,'Auto, WV',7492,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18151,NULL,'Auto, WV 24917',7492,222,NULL,57,10366,0);
INSERT INTO "django_geo_db_location" VALUES(18152,NULL,'Ballard, WV',7493,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18153,NULL,'Ballard, WV 24918',7493,222,NULL,57,10367,0);
INSERT INTO "django_geo_db_location" VALUES(18154,NULL,'Ballengee, WV',7494,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18155,NULL,'Ballengee, WV 24919',7494,222,NULL,57,10368,0);
INSERT INTO "django_geo_db_location" VALUES(18156,NULL,'Bartow, WV',7495,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18157,NULL,'Bartow, WV 24920',7495,222,NULL,57,10369,0);
INSERT INTO "django_geo_db_location" VALUES(18158,NULL,'Buckeye, WV',7496,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18159,NULL,'Buckeye, WV 24924',7496,222,NULL,57,10370,0);
INSERT INTO "django_geo_db_location" VALUES(18160,NULL,'Caldwell, WV',7497,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18161,NULL,'Caldwell, WV 24925',7497,222,NULL,57,10371,0);
INSERT INTO "django_geo_db_location" VALUES(18162,NULL,'Cass, WV',7498,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18163,NULL,'Cass, WV 24927',7498,222,NULL,57,10372,0);
INSERT INTO "django_geo_db_location" VALUES(18164,NULL,'Crawley, WV',7499,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18165,NULL,'Crawley, WV 24931',7499,222,NULL,57,10373,0);
INSERT INTO "django_geo_db_location" VALUES(18166,NULL,'Dunmore, WV',7500,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18167,NULL,'Dunmore, WV 24934',7500,222,NULL,57,10374,0);
INSERT INTO "django_geo_db_location" VALUES(18168,NULL,'Forest Hill, WV',7501,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18169,NULL,'Forest Hill, WV 24935',7501,222,NULL,57,10375,0);
INSERT INTO "django_geo_db_location" VALUES(18170,NULL,'Fort Spring, WV',7502,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18171,NULL,'Fort Spring, WV 24936',7502,222,NULL,57,10376,0);
INSERT INTO "django_geo_db_location" VALUES(18172,NULL,'Frankford, WV',7503,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18173,NULL,'Frankford, WV 24938',7503,222,NULL,57,10377,0);
INSERT INTO "django_geo_db_location" VALUES(18174,NULL,'Gap Mills, WV',7504,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18175,NULL,'Gap Mills, WV 24941',7504,222,NULL,57,10378,0);
INSERT INTO "django_geo_db_location" VALUES(18176,NULL,'Glace, WV',7505,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18177,NULL,'Glace, WV 24942',7505,222,NULL,57,10379,0);
INSERT INTO "django_geo_db_location" VALUES(18178,NULL,'Grassy Meadows, WV',7506,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18179,NULL,'Grassy Meadows, WV 24943',7506,222,NULL,57,10380,0);
INSERT INTO "django_geo_db_location" VALUES(18180,NULL,'Green Bank, WV',7507,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18181,NULL,'Green Bank, WV 24944',7507,222,NULL,57,10381,0);
INSERT INTO "django_geo_db_location" VALUES(18182,NULL,'Greenville, WV',7508,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18183,NULL,'Greenville, WV 24945',7508,222,NULL,57,10382,0);
INSERT INTO "django_geo_db_location" VALUES(18184,NULL,'Hillsboro, WV',7509,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18185,NULL,'Hillsboro, WV 24946',7509,222,NULL,57,10383,0);
INSERT INTO "django_geo_db_location" VALUES(18186,NULL,'Kieffer, WV',7510,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18187,NULL,'Kieffer, WV 24950',7510,222,NULL,57,10384,0);
INSERT INTO "django_geo_db_location" VALUES(18188,NULL,'Lindside, WV',7511,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18189,NULL,'Lindside, WV 24951',7511,222,NULL,57,10385,0);
INSERT INTO "django_geo_db_location" VALUES(18190,NULL,'Marlinton, WV',7512,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18191,NULL,'Marlinton, WV 24954',7512,222,NULL,57,10386,0);
INSERT INTO "django_geo_db_location" VALUES(18192,NULL,'Maxwelton, WV',7513,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18193,NULL,'Maxwelton, WV 24957',7513,222,NULL,57,10387,0);
INSERT INTO "django_geo_db_location" VALUES(18194,NULL,'Meadow Bluff, WV',7514,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18195,NULL,'Meadow Bluff, WV 24958',7514,222,NULL,57,10388,0);
INSERT INTO "django_geo_db_location" VALUES(18196,NULL,'Neola, WV',7515,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18197,NULL,'Neola, WV 24961',7515,222,NULL,57,10389,0);
INSERT INTO "django_geo_db_location" VALUES(18198,NULL,'Pence Springs, WV',7516,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18199,NULL,'Pence Springs, WV 24962',7516,222,NULL,57,10390,0);
INSERT INTO "django_geo_db_location" VALUES(18200,NULL,'Peterstown, WV',7517,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18201,NULL,'Peterstown, WV 24963',7517,222,NULL,57,10391,0);
INSERT INTO "django_geo_db_location" VALUES(18202,NULL,'Renick, WV',7518,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18203,NULL,'Renick, WV 24966',7518,222,NULL,57,10392,0);
INSERT INTO "django_geo_db_location" VALUES(18204,NULL,'Ronceverte, WV',7519,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18205,NULL,'Ronceverte, WV 24970',7519,222,NULL,57,10393,0);
INSERT INTO "django_geo_db_location" VALUES(18206,NULL,'Lewisburg, WV 24971',7487,222,NULL,57,10394,0);
INSERT INTO "django_geo_db_location" VALUES(18207,NULL,'Secondcreek, WV',7520,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18208,NULL,'Secondcreek, WV 24974',7520,222,NULL,57,10395,0);
INSERT INTO "django_geo_db_location" VALUES(18209,NULL,'Sinks Grove, WV',7521,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18210,NULL,'Sinks Grove, WV 24976',7521,222,NULL,57,10396,0);
INSERT INTO "django_geo_db_location" VALUES(18211,NULL,'Smoot, WV',7522,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18212,NULL,'Smoot, WV 24977',7522,222,NULL,57,10397,0);
INSERT INTO "django_geo_db_location" VALUES(18213,NULL,'Talcott, WV',7523,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18214,NULL,'Talcott, WV 24981',7523,222,NULL,57,10398,0);
INSERT INTO "django_geo_db_location" VALUES(18215,NULL,'Union, WV',7524,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18216,NULL,'Union, WV 24983',7524,222,NULL,57,10399,0);
INSERT INTO "django_geo_db_location" VALUES(18217,NULL,'Waiteville, WV',7525,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18218,NULL,'Waiteville, WV 24984',7525,222,NULL,57,10400,0);
INSERT INTO "django_geo_db_location" VALUES(18219,NULL,'Wayside, WV',7526,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18220,NULL,'Wayside, WV 24985',7526,222,NULL,57,10401,0);
INSERT INTO "django_geo_db_location" VALUES(18221,NULL,'White Sulphur Springs, WV',7527,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18222,NULL,'White Sulphur Springs, WV 24986',7527,222,NULL,57,10402,0);
INSERT INTO "django_geo_db_location" VALUES(18223,NULL,'Williamsburg, WV',7528,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18224,NULL,'Williamsburg, WV 24991',7528,222,NULL,57,10403,0);
INSERT INTO "django_geo_db_location" VALUES(18225,NULL,'Wolfcreek, WV',7529,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18226,NULL,'Wolfcreek, WV 24993',7529,222,NULL,57,10404,0);
INSERT INTO "django_geo_db_location" VALUES(18227,NULL,'Alloy, WV',7530,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18228,NULL,'Alloy, WV 25002',7530,222,NULL,57,10405,0);
INSERT INTO "django_geo_db_location" VALUES(18229,NULL,'Alum Creek, WV',7531,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18230,NULL,'Alum Creek, WV 25003',7531,222,NULL,57,10406,0);
INSERT INTO "django_geo_db_location" VALUES(18231,NULL,'Ameagle, WV',7532,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18232,NULL,'Ameagle, WV 25004',7532,222,NULL,57,10407,0);
INSERT INTO "django_geo_db_location" VALUES(18233,NULL,'Amma, WV',7533,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18234,NULL,'Amma, WV 25005',7533,222,NULL,57,10408,0);
INSERT INTO "django_geo_db_location" VALUES(18235,NULL,'Arnett, WV',7534,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18236,NULL,'Arnett, WV 25007',7534,222,NULL,57,10409,0);
INSERT INTO "django_geo_db_location" VALUES(18237,NULL,'Artie, WV',7535,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18238,NULL,'Artie, WV 25008',7535,222,NULL,57,10410,0);
INSERT INTO "django_geo_db_location" VALUES(18239,NULL,'Ashford, WV',7536,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18240,NULL,'Ashford, WV 25009',7536,222,NULL,57,10411,0);
INSERT INTO "django_geo_db_location" VALUES(18241,NULL,'Bald Knob, WV',7537,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18242,NULL,'Bald Knob, WV 25010',7537,222,NULL,57,10412,0);
INSERT INTO "django_geo_db_location" VALUES(18243,NULL,'Bancroft, WV',7538,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18244,NULL,'Bancroft, WV 25011',7538,222,NULL,57,10413,0);
INSERT INTO "django_geo_db_location" VALUES(18245,NULL,'Belle, WV',7539,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18246,NULL,'Belle, WV 25015',7539,222,NULL,57,10414,0);
INSERT INTO "django_geo_db_location" VALUES(18247,NULL,'Bentree, WV',7540,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18248,NULL,'Bentree, WV 25018',7540,222,NULL,57,10415,0);
INSERT INTO "django_geo_db_location" VALUES(18249,NULL,'Bickmore, WV',7541,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18250,NULL,'Bickmore, WV 25019',7541,222,NULL,57,10416,0);
INSERT INTO "django_geo_db_location" VALUES(18251,NULL,'Bim, WV',7542,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18252,NULL,'Bim, WV 25021',7542,222,NULL,57,10417,0);
INSERT INTO "django_geo_db_location" VALUES(18253,NULL,'Blair, WV',7543,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18254,NULL,'Blair, WV 25022',7543,222,NULL,57,10418,0);
INSERT INTO "django_geo_db_location" VALUES(18255,NULL,'Bloomingrose, WV',7544,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18256,NULL,'Bloomingrose, WV 25024',7544,222,NULL,57,10419,0);
INSERT INTO "django_geo_db_location" VALUES(18257,NULL,'Blount, WV',7545,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18258,NULL,'Blount, WV 25025',7545,222,NULL,57,10420,0);
INSERT INTO "django_geo_db_location" VALUES(18259,NULL,'Blue Creek, WV',7546,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18260,NULL,'Blue Creek, WV 25026',7546,222,NULL,57,10421,0);
INSERT INTO "django_geo_db_location" VALUES(18261,NULL,'Bob White, WV',7547,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18262,NULL,'Bob White, WV 25028',7547,222,NULL,57,10422,0);
INSERT INTO "django_geo_db_location" VALUES(18263,NULL,'Bomont, WV',7548,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18264,NULL,'Bomont, WV 25030',7548,222,NULL,57,10423,0);
INSERT INTO "django_geo_db_location" VALUES(18265,NULL,'Boomer, WV',7549,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18266,NULL,'Boomer, WV 25031',7549,222,NULL,57,10424,0);
INSERT INTO "django_geo_db_location" VALUES(18267,NULL,'Buffalo, WV',7550,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18268,NULL,'Buffalo, WV 25033',7550,222,NULL,57,10425,0);
INSERT INTO "django_geo_db_location" VALUES(18269,NULL,'Cabin Creek, WV',7551,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18270,NULL,'Cabin Creek, WV 25035',7551,222,NULL,57,10426,0);
INSERT INTO "django_geo_db_location" VALUES(18271,NULL,'Cannelton, WV',7552,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18272,NULL,'Cannelton, WV 25036',7552,222,NULL,57,10427,0);
INSERT INTO "django_geo_db_location" VALUES(18273,NULL,'Cedar Grove, WV',7553,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18274,NULL,'Cedar Grove, WV 25039',7553,222,NULL,57,10428,0);
INSERT INTO "django_geo_db_location" VALUES(18275,NULL,'Charlton Heights, WV',7554,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18276,NULL,'Charlton Heights, WV 25040',7554,222,NULL,57,10429,0);
INSERT INTO "django_geo_db_location" VALUES(18277,NULL,'Clay, WV',7555,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18278,NULL,'Clay, WV 25043',7555,222,NULL,57,10430,0);
INSERT INTO "django_geo_db_location" VALUES(18279,NULL,'Clear Creek, WV',7556,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18280,NULL,'Clear Creek, WV 25044',7556,222,NULL,57,10431,0);
INSERT INTO "django_geo_db_location" VALUES(18281,NULL,'Clendenin, WV',7557,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18282,NULL,'Clendenin, WV 25045',7557,222,NULL,57,10432,0);
INSERT INTO "django_geo_db_location" VALUES(18283,NULL,'Clio, WV',7558,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18284,NULL,'Clio, WV 25046',7558,222,NULL,57,10433,0);
INSERT INTO "django_geo_db_location" VALUES(18285,NULL,'Clothier, WV',7559,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18286,NULL,'Clothier, WV 25047',7559,222,NULL,57,10434,0);
INSERT INTO "django_geo_db_location" VALUES(18287,NULL,'Colcord, WV',7560,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18288,NULL,'Colcord, WV 25048',7560,222,NULL,57,10435,0);
INSERT INTO "django_geo_db_location" VALUES(18289,NULL,'Comfort, WV',7561,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18290,NULL,'Comfort, WV 25049',7561,222,NULL,57,10436,0);
INSERT INTO "django_geo_db_location" VALUES(18291,NULL,'Costa, WV',7562,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18292,NULL,'Costa, WV 25051',7562,222,NULL,57,10437,0);
INSERT INTO "django_geo_db_location" VALUES(18293,NULL,'Danville, WV',7563,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18294,NULL,'Danville, WV 25053',7563,222,NULL,57,10438,0);
INSERT INTO "django_geo_db_location" VALUES(18295,NULL,'Dawes, WV',7564,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18296,NULL,'Dawes, WV 25054',7564,222,NULL,57,10439,0);
INSERT INTO "django_geo_db_location" VALUES(18297,NULL,'Deep Water, WV',7565,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18298,NULL,'Deep Water, WV 25057',7565,222,NULL,57,10440,0);
INSERT INTO "django_geo_db_location" VALUES(18299,NULL,'Dixie, WV',7566,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18300,NULL,'Dixie, WV 25059',7566,222,NULL,57,10441,0);
INSERT INTO "django_geo_db_location" VALUES(18301,NULL,'Dorothy, WV',7567,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18302,NULL,'Dorothy, WV 25060',7567,222,NULL,57,10442,0);
INSERT INTO "django_geo_db_location" VALUES(18303,NULL,'Drybranch, WV',7568,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18304,NULL,'Drybranch, WV 25061',7568,222,NULL,57,10443,0);
INSERT INTO "django_geo_db_location" VALUES(18305,NULL,'Dry Creek, WV',7569,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18306,NULL,'Dry Creek, WV 25062',7569,222,NULL,57,10444,0);
INSERT INTO "django_geo_db_location" VALUES(18307,NULL,'Duck, WV',7570,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18308,NULL,'Duck, WV 25063',7570,222,NULL,57,10445,0);
INSERT INTO "django_geo_db_location" VALUES(18309,NULL,'Dunbar, WV',7571,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18310,NULL,'Dunbar, WV 25064',7571,222,NULL,57,10446,0);
INSERT INTO "django_geo_db_location" VALUES(18311,NULL,'East Bank, WV',7572,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18312,NULL,'East Bank, WV 25067',7572,222,NULL,57,10447,0);
INSERT INTO "django_geo_db_location" VALUES(18313,NULL,'Eleanor, WV',7573,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18314,NULL,'Eleanor, WV 25070',7573,222,NULL,57,10448,0);
INSERT INTO "django_geo_db_location" VALUES(18315,NULL,'Elkview, WV',7574,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18316,NULL,'Elkview, WV 25071',7574,222,NULL,57,10449,0);
INSERT INTO "django_geo_db_location" VALUES(18317,NULL,'Eskdale, WV',7575,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18318,NULL,'Eskdale, WV 25075',7575,222,NULL,57,10450,0);
INSERT INTO "django_geo_db_location" VALUES(18319,NULL,'Ethel, WV',7576,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18320,NULL,'Ethel, WV 25076',7576,222,NULL,57,10451,0);
INSERT INTO "django_geo_db_location" VALUES(18321,NULL,'Falling Rock, WV',7577,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18322,NULL,'Falling Rock, WV 25079',7577,222,NULL,57,10452,0);
INSERT INTO "django_geo_db_location" VALUES(18323,NULL,'Foster, WV',7578,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18324,NULL,'Foster, WV 25081',7578,222,NULL,57,10453,0);
INSERT INTO "django_geo_db_location" VALUES(18325,NULL,'Fraziers Bottom, WV',7579,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18326,NULL,'Fraziers Bottom, WV 25082',7579,222,NULL,57,10454,0);
INSERT INTO "django_geo_db_location" VALUES(18327,NULL,'Gallagher, WV',7580,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18328,NULL,'Gallagher, WV 25083',7580,222,NULL,57,10455,0);
INSERT INTO "django_geo_db_location" VALUES(18329,NULL,'Gauley Bridge, WV',7581,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18330,NULL,'Gauley Bridge, WV 25085',7581,222,NULL,57,10456,0);
INSERT INTO "django_geo_db_location" VALUES(18331,NULL,'Glasgow, WV',7582,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18332,NULL,'Glasgow, WV 25086',7582,222,NULL,57,10457,0);
INSERT INTO "django_geo_db_location" VALUES(18333,NULL,'Glen, WV',7583,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18334,NULL,'Glen, WV 25088',7583,222,NULL,57,10458,0);
INSERT INTO "django_geo_db_location" VALUES(18335,NULL,'Glen Ferris, WV',7584,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18336,NULL,'Glen Ferris, WV 25090',7584,222,NULL,57,10459,0);
INSERT INTO "django_geo_db_location" VALUES(18337,NULL,'Gordon, WV',7585,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18338,NULL,'Gordon, WV 25093',7585,222,NULL,57,10460,0);
INSERT INTO "django_geo_db_location" VALUES(18339,NULL,'Grimms Landing, WV',7586,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18340,NULL,'Grimms Landing, WV 25095',7586,222,NULL,57,10461,0);
INSERT INTO "django_geo_db_location" VALUES(18341,NULL,'Handley, WV',7587,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18342,NULL,'Handley, WV 25102',7587,222,NULL,57,10462,0);
INSERT INTO "django_geo_db_location" VALUES(18343,NULL,'Hansford, WV',7588,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18344,NULL,'Hansford, WV 25103',7588,222,NULL,57,10463,0);
INSERT INTO "django_geo_db_location" VALUES(18345,NULL,'Henderson, WV',7589,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18346,NULL,'Henderson, WV 25106',7589,222,NULL,57,10464,0);
INSERT INTO "django_geo_db_location" VALUES(18347,NULL,'Hernshaw, WV',7590,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18348,NULL,'Hernshaw, WV 25107',7590,222,NULL,57,10465,0);
INSERT INTO "django_geo_db_location" VALUES(18349,NULL,'Hewett, WV',7591,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18350,NULL,'Hewett, WV 25108',7591,222,NULL,57,10466,0);
INSERT INTO "django_geo_db_location" VALUES(18351,NULL,'Hometown, WV',7592,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18352,NULL,'Hometown, WV 25109',7592,222,NULL,57,10467,0);
INSERT INTO "django_geo_db_location" VALUES(18353,NULL,'Hugheston, WV',7593,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18354,NULL,'Hugheston, WV 25110',7593,222,NULL,57,10468,0);
INSERT INTO "django_geo_db_location" VALUES(18355,NULL,'Indore, WV',7594,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18356,NULL,'Indore, WV 25111',7594,222,NULL,57,10469,0);
INSERT INTO "django_geo_db_location" VALUES(18357,NULL,'Institute, WV',7595,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18358,NULL,'Institute, WV 25112',7595,222,NULL,57,10470,0);
INSERT INTO "django_geo_db_location" VALUES(18359,NULL,'Ivydale, WV',7596,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18360,NULL,'Ivydale, WV 25113',7596,222,NULL,57,10471,0);
INSERT INTO "django_geo_db_location" VALUES(18361,NULL,'Jeffrey, WV',7597,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18362,NULL,'Jeffrey, WV 25114',7597,222,NULL,57,10472,0);
INSERT INTO "django_geo_db_location" VALUES(18363,NULL,'Kanawha Falls, WV',7598,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18364,NULL,'Kanawha Falls, WV 25115',7598,222,NULL,57,10473,0);
INSERT INTO "django_geo_db_location" VALUES(18365,NULL,'Kimberly, WV',7599,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18366,NULL,'Kimberly, WV 25118',7599,222,NULL,57,10474,0);
INSERT INTO "django_geo_db_location" VALUES(18367,NULL,'Kincaid, WV',7600,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18368,NULL,'Kincaid, WV 25119',7600,222,NULL,57,10475,0);
INSERT INTO "django_geo_db_location" VALUES(18369,NULL,'Lake, WV',7601,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18370,NULL,'Lake, WV 25121',7601,222,NULL,57,10476,0);
INSERT INTO "django_geo_db_location" VALUES(18371,NULL,'Leewood, WV',7602,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18372,NULL,'Leewood, WV 25122',7602,222,NULL,57,10477,0);
INSERT INTO "django_geo_db_location" VALUES(18373,NULL,'Leon, WV',7603,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18374,NULL,'Leon, WV 25123',7603,222,NULL,57,10478,0);
INSERT INTO "django_geo_db_location" VALUES(18375,NULL,'Liberty, WV',7604,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18376,NULL,'Liberty, WV 25124',7604,222,NULL,57,10479,0);
INSERT INTO "django_geo_db_location" VALUES(18377,NULL,'Lizemores, WV',7605,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18378,NULL,'Lizemores, WV 25125',7605,222,NULL,57,10480,0);
INSERT INTO "django_geo_db_location" VALUES(18379,NULL,'London, WV',7606,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18380,NULL,'London, WV 25126',7606,222,NULL,57,10481,0);
INSERT INTO "django_geo_db_location" VALUES(18381,NULL,'Madison, WV',7607,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18382,NULL,'Madison, WV 25130',7607,222,NULL,57,10482,0);
INSERT INTO "django_geo_db_location" VALUES(18383,NULL,'Mammoth, WV',7608,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18384,NULL,'Mammoth, WV 25132',7608,222,NULL,57,10483,0);
INSERT INTO "django_geo_db_location" VALUES(18385,NULL,'Maysel, WV',7609,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18386,NULL,'Maysel, WV 25133',7609,222,NULL,57,10484,0);
INSERT INTO "django_geo_db_location" VALUES(18387,NULL,'Miami, WV',7610,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18388,NULL,'Miami, WV 25134',7610,222,NULL,57,10485,0);
INSERT INTO "django_geo_db_location" VALUES(18389,NULL,'Montgomery, WV',7611,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18390,NULL,'Montgomery, WV 25136',7611,222,NULL,57,10486,0);
INSERT INTO "django_geo_db_location" VALUES(18391,NULL,'Mount Carbon, WV',7612,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18392,NULL,'Mount Carbon, WV 25139',7612,222,NULL,57,10487,0);
INSERT INTO "django_geo_db_location" VALUES(18393,NULL,'Naoma, WV',7613,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18394,NULL,'Naoma, WV 25140',7613,222,NULL,57,10488,0);
INSERT INTO "django_geo_db_location" VALUES(18395,NULL,'Nebo, WV',7614,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18396,NULL,'Nebo, WV 25141',7614,222,NULL,57,10489,0);
INSERT INTO "django_geo_db_location" VALUES(18397,NULL,'Nellis, WV',7615,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18398,NULL,'Nellis, WV 25142',7615,222,NULL,57,10490,0);
INSERT INTO "django_geo_db_location" VALUES(18399,NULL,'Nitro, WV',7616,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18400,NULL,'Nitro, WV 25143',7616,222,NULL,57,10491,0);
INSERT INTO "django_geo_db_location" VALUES(18401,NULL,'Ohley, WV',7617,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18402,NULL,'Ohley, WV 25147',7617,222,NULL,57,10492,0);
INSERT INTO "django_geo_db_location" VALUES(18403,NULL,'Orgas, WV',7618,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18404,NULL,'Orgas, WV 25148',7618,222,NULL,57,10493,0);
INSERT INTO "django_geo_db_location" VALUES(18405,NULL,'Ottawa, WV',7619,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18406,NULL,'Ottawa, WV 25149',7619,222,NULL,57,10494,0);
INSERT INTO "django_geo_db_location" VALUES(18407,NULL,'Ovapa, WV',7620,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18408,NULL,'Ovapa, WV 25150',7620,222,NULL,57,10495,0);
INSERT INTO "django_geo_db_location" VALUES(18409,NULL,'Page, WV',7621,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18410,NULL,'Page, WV 25152',7621,222,NULL,57,10496,0);
INSERT INTO "django_geo_db_location" VALUES(18411,NULL,'Peytona, WV',7622,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18412,NULL,'Peytona, WV 25154',7622,222,NULL,57,10497,0);
INSERT INTO "django_geo_db_location" VALUES(18413,NULL,'Pinch, WV',7623,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18414,NULL,'Pinch, WV 25156',7623,222,NULL,57,10498,0);
INSERT INTO "django_geo_db_location" VALUES(18415,NULL,'Poca, WV',7624,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18416,NULL,'Poca, WV 25159',7624,222,NULL,57,10499,0);
INSERT INTO "django_geo_db_location" VALUES(18417,NULL,'Pond Gap, WV',7625,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18418,NULL,'Pond Gap, WV 25160',7625,222,NULL,57,10500,0);
INSERT INTO "django_geo_db_location" VALUES(18419,NULL,'Powellton, WV',7626,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18420,NULL,'Powellton, WV 25161',7626,222,NULL,57,10501,0);
INSERT INTO "django_geo_db_location" VALUES(18421,NULL,'Pratt, WV',7627,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18422,NULL,'Pratt, WV 25162',7627,222,NULL,57,10502,0);
INSERT INTO "django_geo_db_location" VALUES(18423,NULL,'Procious, WV',7628,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18424,NULL,'Procious, WV 25164',7628,222,NULL,57,10503,0);
INSERT INTO "django_geo_db_location" VALUES(18425,NULL,'Racine, WV',7629,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18426,NULL,'Racine, WV 25165',7629,222,NULL,57,10504,0);
INSERT INTO "django_geo_db_location" VALUES(18427,NULL,'Red House, WV',7630,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18428,NULL,'Red House, WV 25168',7630,222,NULL,57,10505,0);
INSERT INTO "django_geo_db_location" VALUES(18429,NULL,'Ridgeview, WV',7631,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18430,NULL,'Ridgeview, WV 25169',7631,222,NULL,57,10506,0);
INSERT INTO "django_geo_db_location" VALUES(18431,NULL,'Robson, WV',7632,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18432,NULL,'Robson, WV 25173',7632,222,NULL,57,10507,0);
INSERT INTO "django_geo_db_location" VALUES(18433,NULL,'Rock Creek, WV',7633,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18434,NULL,'Rock Creek, WV 25174',7633,222,NULL,57,10508,0);
INSERT INTO "django_geo_db_location" VALUES(18435,NULL,'Saint Albans, WV',7634,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18436,NULL,'Saint Albans, WV 25177',7634,222,NULL,57,10509,0);
INSERT INTO "django_geo_db_location" VALUES(18437,NULL,'Saxon, WV',7635,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18438,NULL,'Saxon, WV 25180',7635,222,NULL,57,10510,0);
INSERT INTO "django_geo_db_location" VALUES(18439,NULL,'Seth, WV',7636,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18440,NULL,'Seth, WV 25181',7636,222,NULL,57,10511,0);
INSERT INTO "django_geo_db_location" VALUES(18441,NULL,'Sharon, WV',7637,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18442,NULL,'Sharon, WV 25182',7637,222,NULL,57,10512,0);
INSERT INTO "django_geo_db_location" VALUES(18443,NULL,'Sharples, WV',7638,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18444,NULL,'Sharples, WV 25183',7638,222,NULL,57,10513,0);
INSERT INTO "django_geo_db_location" VALUES(18445,NULL,'Mount Olive, WV',7639,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18446,NULL,'Mount Olive, WV 25185',7639,222,NULL,57,10514,0);
INSERT INTO "django_geo_db_location" VALUES(18447,NULL,'Smithers, WV',7640,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18448,NULL,'Smithers, WV 25186',7640,222,NULL,57,10515,0);
INSERT INTO "django_geo_db_location" VALUES(18449,NULL,'Southside, WV',7641,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18450,NULL,'Southside, WV 25187',7641,222,NULL,57,10516,0);
INSERT INTO "django_geo_db_location" VALUES(18451,NULL,'Sylvester, WV',7642,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18452,NULL,'Sylvester, WV 25193',7642,222,NULL,57,10517,0);
INSERT INTO "django_geo_db_location" VALUES(18453,NULL,'Tad, WV',7643,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18454,NULL,'Tad, WV 25201',7643,222,NULL,57,10518,0);
INSERT INTO "django_geo_db_location" VALUES(18455,NULL,'Tornado, WV',7644,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18456,NULL,'Tornado, WV 25202',7644,222,NULL,57,10519,0);
INSERT INTO "django_geo_db_location" VALUES(18457,NULL,'Turtle Creek, WV',7645,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18458,NULL,'Turtle Creek, WV 25203',7645,222,NULL,57,10520,0);
INSERT INTO "django_geo_db_location" VALUES(18459,NULL,'Twilight, WV',7646,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18460,NULL,'Twilight, WV 25204',7646,222,NULL,57,10521,0);
INSERT INTO "django_geo_db_location" VALUES(18461,NULL,'Uneeda, WV',7647,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18462,NULL,'Uneeda, WV 25205',7647,222,NULL,57,10522,0);
INSERT INTO "django_geo_db_location" VALUES(18463,NULL,'Van, WV',7648,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18464,NULL,'Van, WV 25206',7648,222,NULL,57,10523,0);
INSERT INTO "django_geo_db_location" VALUES(18465,NULL,'Wharton, WV',7649,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18466,NULL,'Wharton, WV 25208',7649,222,NULL,57,10524,0);
INSERT INTO "django_geo_db_location" VALUES(18467,NULL,'Whitesville, WV',7650,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18468,NULL,'Whitesville, WV 25209',7650,222,NULL,57,10525,0);
INSERT INTO "django_geo_db_location" VALUES(18469,NULL,'Widen, WV',7651,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18470,NULL,'Widen, WV 25211',7651,222,NULL,57,10526,0);
INSERT INTO "django_geo_db_location" VALUES(18471,NULL,'Winfield, WV',7652,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18472,NULL,'Winfield, WV 25213',7652,222,NULL,57,10527,0);
INSERT INTO "django_geo_db_location" VALUES(18473,NULL,'Winifrede, WV',7653,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18474,NULL,'Winifrede, WV 25214',7653,222,NULL,57,10528,0);
INSERT INTO "django_geo_db_location" VALUES(18475,NULL,'Advent, WV',7654,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18476,NULL,'Advent, WV 25231',7654,222,NULL,57,10529,0);
INSERT INTO "django_geo_db_location" VALUES(18477,NULL,'Arnoldsburg, WV',7655,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18478,NULL,'Arnoldsburg, WV 25234',7655,222,NULL,57,10530,0);
INSERT INTO "django_geo_db_location" VALUES(18479,NULL,'Chloe, WV',7656,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18480,NULL,'Chloe, WV 25235',7656,222,NULL,57,10531,0);
INSERT INTO "django_geo_db_location" VALUES(18481,NULL,'Cottageville, WV',7657,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18482,NULL,'Cottageville, WV 25239',7657,222,NULL,57,10532,0);
INSERT INTO "django_geo_db_location" VALUES(18483,NULL,'Evans, WV',7658,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18484,NULL,'Evans, WV 25241',7658,222,NULL,57,10533,0);
INSERT INTO "django_geo_db_location" VALUES(18485,NULL,'Gandeeville, WV',7659,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18486,NULL,'Gandeeville, WV 25243',7659,222,NULL,57,10534,0);
INSERT INTO "django_geo_db_location" VALUES(18487,NULL,'Gay, WV',7660,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18488,NULL,'Gay, WV 25244',7660,222,NULL,57,10535,0);
INSERT INTO "django_geo_db_location" VALUES(18489,NULL,'Given, WV',7661,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18490,NULL,'Given, WV 25245',7661,222,NULL,57,10536,0);
INSERT INTO "django_geo_db_location" VALUES(18491,NULL,'Hartford, WV',7662,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18492,NULL,'Hartford, WV 25247',7662,222,NULL,57,10537,0);
INSERT INTO "django_geo_db_location" VALUES(18493,NULL,'Kenna, WV',7663,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18494,NULL,'Kenna, WV 25248',7663,222,NULL,57,10538,0);
INSERT INTO "django_geo_db_location" VALUES(18495,NULL,'Lakin, WV',7664,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18496,NULL,'Lakin, WV 25250',7664,222,NULL,57,10539,0);
INSERT INTO "django_geo_db_location" VALUES(18497,NULL,'Left Hand, WV',7665,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18498,NULL,'Left Hand, WV 25251',7665,222,NULL,57,10540,0);
INSERT INTO "django_geo_db_location" VALUES(18499,NULL,'Le Roy, WV',7666,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18500,NULL,'Le Roy, WV 25252',7666,222,NULL,57,10541,0);
INSERT INTO "django_geo_db_location" VALUES(18501,NULL,'Letart, WV',7667,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18502,NULL,'Letart, WV 25253',7667,222,NULL,57,10542,0);
INSERT INTO "django_geo_db_location" VALUES(18503,NULL,'Linden, WV',7668,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18504,NULL,'Linden, WV 25256',7668,222,NULL,57,10543,0);
INSERT INTO "django_geo_db_location" VALUES(18505,NULL,'Lockney, WV',7669,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18506,NULL,'Lockney, WV 25258',7669,222,NULL,57,10544,0);
INSERT INTO "django_geo_db_location" VALUES(18507,NULL,'Looneyville, WV',7670,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18508,NULL,'Looneyville, WV 25259',7670,222,NULL,57,10545,0);
INSERT INTO "django_geo_db_location" VALUES(18509,NULL,'Mason, WV',7671,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18510,NULL,'Mason, WV 25260',7671,222,NULL,57,10546,0);
INSERT INTO "django_geo_db_location" VALUES(18511,NULL,'Millstone, WV',7672,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18512,NULL,'Millstone, WV 25261',7672,222,NULL,57,10547,0);
INSERT INTO "django_geo_db_location" VALUES(18513,NULL,'Millwood, WV',7673,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18514,NULL,'Millwood, WV 25262',7673,222,NULL,57,10548,0);
INSERT INTO "django_geo_db_location" VALUES(18515,NULL,'Mount Alto, WV',7674,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18516,NULL,'Mount Alto, WV 25264',7674,222,NULL,57,10549,0);
INSERT INTO "django_geo_db_location" VALUES(18517,NULL,'New Haven, WV',7675,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18518,NULL,'New Haven, WV 25265',7675,222,NULL,57,10550,0);
INSERT INTO "django_geo_db_location" VALUES(18519,NULL,'Newton, WV',7676,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18520,NULL,'Newton, WV 25266',7676,222,NULL,57,10551,0);
INSERT INTO "django_geo_db_location" VALUES(18521,NULL,'Normantown, WV',7677,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18522,NULL,'Normantown, WV 25267',7677,222,NULL,57,10552,0);
INSERT INTO "django_geo_db_location" VALUES(18523,NULL,'Orma, WV',7678,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18524,NULL,'Orma, WV 25268',7678,222,NULL,57,10553,0);
INSERT INTO "django_geo_db_location" VALUES(18525,NULL,'Reedy, WV',7679,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18526,NULL,'Reedy, WV 25270',7679,222,NULL,57,10554,0);
INSERT INTO "django_geo_db_location" VALUES(18527,NULL,'Ripley, WV',7680,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18528,NULL,'Ripley, WV 25271',7680,222,NULL,57,10555,0);
INSERT INTO "django_geo_db_location" VALUES(18529,NULL,'Sandyville, WV',7681,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18530,NULL,'Sandyville, WV 25275',7681,222,NULL,57,10556,0);
INSERT INTO "django_geo_db_location" VALUES(18531,NULL,'Spencer, WV',7682,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18532,NULL,'Spencer, WV 25276',7682,222,NULL,57,10557,0);
INSERT INTO "django_geo_db_location" VALUES(18533,NULL,'Statts Mills, WV',7683,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18534,NULL,'Statts Mills, WV 25279',7683,222,NULL,57,10558,0);
INSERT INTO "django_geo_db_location" VALUES(18535,NULL,'Tariff, WV',7684,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18536,NULL,'Tariff, WV 25281',7684,222,NULL,57,10559,0);
INSERT INTO "django_geo_db_location" VALUES(18537,NULL,'Valley Fork, WV',7685,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18538,NULL,'Valley Fork, WV 25283',7685,222,NULL,57,10560,0);
INSERT INTO "django_geo_db_location" VALUES(18539,NULL,'Wallback, WV',7686,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18540,NULL,'Wallback, WV 25285',7686,222,NULL,57,10561,0);
INSERT INTO "django_geo_db_location" VALUES(18541,NULL,'Walton, WV',7687,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18542,NULL,'Walton, WV 25286',7687,222,NULL,57,10562,0);
INSERT INTO "django_geo_db_location" VALUES(18543,NULL,'West Columbia, WV',7688,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18544,NULL,'West Columbia, WV 25287',7688,222,NULL,57,10563,0);
INSERT INTO "django_geo_db_location" VALUES(18545,NULL,'Charleston, WV',7689,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18546,NULL,'Charleston, WV 25301',7689,222,NULL,57,10564,0);
INSERT INTO "django_geo_db_location" VALUES(18547,NULL,'Charleston, WV 25302',7689,222,NULL,57,10565,0);
INSERT INTO "django_geo_db_location" VALUES(18548,NULL,'Charleston, WV 25303',7689,222,NULL,57,10566,0);
INSERT INTO "django_geo_db_location" VALUES(18549,NULL,'Charleston, WV 25304',7689,222,NULL,57,10567,0);
INSERT INTO "django_geo_db_location" VALUES(18550,NULL,'Charleston, WV 25305',7689,222,NULL,57,10568,0);
INSERT INTO "django_geo_db_location" VALUES(18551,NULL,'Charleston, WV 25306',7689,222,NULL,57,10569,0);
INSERT INTO "django_geo_db_location" VALUES(18552,NULL,'Charleston, WV 25309',7689,222,NULL,57,10570,0);
INSERT INTO "django_geo_db_location" VALUES(18553,NULL,'Charleston, WV 25311',7689,222,NULL,57,10571,0);
INSERT INTO "django_geo_db_location" VALUES(18554,NULL,'Charleston, WV 25312',7689,222,NULL,57,10572,0);
INSERT INTO "django_geo_db_location" VALUES(18555,NULL,'Charleston, WV 25313',7689,222,NULL,57,10573,0);
INSERT INTO "django_geo_db_location" VALUES(18556,NULL,'Charleston, WV 25314',7689,222,NULL,57,10574,0);
INSERT INTO "django_geo_db_location" VALUES(18557,NULL,'Charleston, WV 25315',7689,222,NULL,57,10575,0);
INSERT INTO "django_geo_db_location" VALUES(18558,NULL,'Charleston, WV 25317',7689,222,NULL,57,10576,0);
INSERT INTO "django_geo_db_location" VALUES(18559,NULL,'Charleston, WV 25320',7689,222,NULL,57,10577,0);
INSERT INTO "django_geo_db_location" VALUES(18560,NULL,'Charleston, WV 25321',7689,222,NULL,57,10578,0);
INSERT INTO "django_geo_db_location" VALUES(18561,NULL,'Charleston, WV 25322',7689,222,NULL,57,10579,0);
INSERT INTO "django_geo_db_location" VALUES(18562,NULL,'Charleston, WV 25323',7689,222,NULL,57,10580,0);
INSERT INTO "django_geo_db_location" VALUES(18563,NULL,'Charleston, WV 25324',7689,222,NULL,57,10581,0);
INSERT INTO "django_geo_db_location" VALUES(18564,NULL,'Charleston, WV 25325',7689,222,NULL,57,10582,0);
INSERT INTO "django_geo_db_location" VALUES(18565,NULL,'Charleston, WV 25326',7689,222,NULL,57,10583,0);
INSERT INTO "django_geo_db_location" VALUES(18566,NULL,'Charleston, WV 25327',7689,222,NULL,57,10584,0);
INSERT INTO "django_geo_db_location" VALUES(18567,NULL,'Charleston, WV 25328',7689,222,NULL,57,10585,0);
INSERT INTO "django_geo_db_location" VALUES(18568,NULL,'Charleston, WV 25329',7689,222,NULL,57,10586,0);
INSERT INTO "django_geo_db_location" VALUES(18569,NULL,'Charleston, WV 25330',7689,222,NULL,57,10587,0);
INSERT INTO "django_geo_db_location" VALUES(18570,NULL,'Charleston, WV 25331',7689,222,NULL,57,10588,0);
INSERT INTO "django_geo_db_location" VALUES(18571,NULL,'Charleston, WV 25332',7689,222,NULL,57,10589,0);
INSERT INTO "django_geo_db_location" VALUES(18572,NULL,'Charleston, WV 25333',7689,222,NULL,57,10590,0);
INSERT INTO "django_geo_db_location" VALUES(18573,NULL,'Charleston, WV 25334',7689,222,NULL,57,10591,0);
INSERT INTO "django_geo_db_location" VALUES(18574,NULL,'Charleston, WV 25335',7689,222,NULL,57,10592,0);
INSERT INTO "django_geo_db_location" VALUES(18575,NULL,'Charleston, WV 25336',7689,222,NULL,57,10593,0);
INSERT INTO "django_geo_db_location" VALUES(18576,NULL,'Charleston, WV 25337',7689,222,NULL,57,10594,0);
INSERT INTO "django_geo_db_location" VALUES(18577,NULL,'Charleston, WV 25338',7689,222,NULL,57,10595,0);
INSERT INTO "django_geo_db_location" VALUES(18578,NULL,'Charleston, WV 25339',7689,222,NULL,57,10596,0);
INSERT INTO "django_geo_db_location" VALUES(18579,NULL,'Charleston, WV 25350',7689,222,NULL,57,10597,0);
INSERT INTO "django_geo_db_location" VALUES(18580,NULL,'Charleston, WV 25356',7689,222,NULL,57,10598,0);
INSERT INTO "django_geo_db_location" VALUES(18581,NULL,'Charleston, WV 25357',7689,222,NULL,57,10599,0);
INSERT INTO "django_geo_db_location" VALUES(18582,NULL,'Charleston, WV 25358',7689,222,NULL,57,10600,0);
INSERT INTO "django_geo_db_location" VALUES(18583,NULL,'Charleston, WV 25360',7689,222,NULL,57,10601,0);
INSERT INTO "django_geo_db_location" VALUES(18584,NULL,'Charleston, WV 25361',7689,222,NULL,57,10602,0);
INSERT INTO "django_geo_db_location" VALUES(18585,NULL,'Charleston, WV 25362',7689,222,NULL,57,10603,0);
INSERT INTO "django_geo_db_location" VALUES(18586,NULL,'Charleston, WV 25364',7689,222,NULL,57,10604,0);
INSERT INTO "django_geo_db_location" VALUES(18587,NULL,'Charleston, WV 25365',7689,222,NULL,57,10605,0);
INSERT INTO "django_geo_db_location" VALUES(18588,NULL,'Charleston, WV 25375',7689,222,NULL,57,10606,0);
INSERT INTO "django_geo_db_location" VALUES(18589,NULL,'Charleston, WV 25387',7689,222,NULL,57,10607,0);
INSERT INTO "django_geo_db_location" VALUES(18590,NULL,'Charleston, WV 25389',7689,222,NULL,57,10608,0);
INSERT INTO "django_geo_db_location" VALUES(18591,NULL,'Charleston, WV 25392',7689,222,NULL,57,10609,0);
INSERT INTO "django_geo_db_location" VALUES(18592,NULL,'Charleston, WV 25396',7689,222,NULL,57,10610,0);
INSERT INTO "django_geo_db_location" VALUES(18593,NULL,'Martinsburg, WV',7690,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18594,NULL,'Martinsburg, WV 25401',7690,222,NULL,57,10611,0);
INSERT INTO "django_geo_db_location" VALUES(18595,NULL,'Martinsburg, WV 25402',7690,222,NULL,57,10612,0);
INSERT INTO "django_geo_db_location" VALUES(18596,NULL,'Bakerton, WV',7691,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18597,NULL,'Bakerton, WV 25410',7691,222,NULL,57,10613,0);
INSERT INTO "django_geo_db_location" VALUES(18598,NULL,'Berkeley Springs, WV',7692,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18599,NULL,'Berkeley Springs, WV 25411',7692,222,NULL,57,10614,0);
INSERT INTO "django_geo_db_location" VALUES(18600,NULL,'Bunker Hill, WV',7693,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18601,NULL,'Bunker Hill, WV 25413',7693,222,NULL,57,10615,0);
INSERT INTO "django_geo_db_location" VALUES(18602,NULL,'Charles Town, WV',7694,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18603,NULL,'Charles Town, WV 25414',7694,222,NULL,57,10616,0);
INSERT INTO "django_geo_db_location" VALUES(18604,NULL,'Falling Waters, WV',7695,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18605,NULL,'Falling Waters, WV 25419',7695,222,NULL,57,10617,0);
INSERT INTO "django_geo_db_location" VALUES(18606,NULL,'Gerrardstown, WV',7696,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18607,NULL,'Gerrardstown, WV 25420',7696,222,NULL,57,10618,0);
INSERT INTO "django_geo_db_location" VALUES(18608,NULL,'Glengary, WV',7697,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18609,NULL,'Glengary, WV 25421',7697,222,NULL,57,10619,0);
INSERT INTO "django_geo_db_location" VALUES(18610,NULL,'Great Cacapon, WV',7698,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18611,NULL,'Great Cacapon, WV 25422',7698,222,NULL,57,10620,0);
INSERT INTO "django_geo_db_location" VALUES(18612,NULL,'Halltown, WV',7699,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18613,NULL,'Halltown, WV 25423',7699,222,NULL,57,10621,0);
INSERT INTO "django_geo_db_location" VALUES(18614,NULL,'Harpers Ferry, WV',7700,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18615,NULL,'Harpers Ferry, WV 25425',7700,222,NULL,57,10622,0);
INSERT INTO "django_geo_db_location" VALUES(18616,NULL,'Hedgesville, WV',7701,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18617,NULL,'Hedgesville, WV 25427',7701,222,NULL,57,10623,0);
INSERT INTO "django_geo_db_location" VALUES(18618,NULL,'Inwood, WV',7702,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18619,NULL,'Inwood, WV 25428',7702,222,NULL,57,10624,0);
INSERT INTO "django_geo_db_location" VALUES(18620,NULL,'Kearneysville, WV',7703,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18621,NULL,'Kearneysville, WV 25429',7703,222,NULL,57,10625,0);
INSERT INTO "django_geo_db_location" VALUES(18622,NULL,'Kearneysville, WV 25430',7703,222,NULL,57,10626,0);
INSERT INTO "django_geo_db_location" VALUES(18623,NULL,'Levels, WV',7704,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18624,NULL,'Levels, WV 25431',7704,222,NULL,57,10627,0);
INSERT INTO "django_geo_db_location" VALUES(18625,NULL,'Millville, WV',7705,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18626,NULL,'Millville, WV 25432',7705,222,NULL,57,10628,0);
INSERT INTO "django_geo_db_location" VALUES(18627,NULL,'Paw Paw, WV',7706,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18628,NULL,'Paw Paw, WV 25434',7706,222,NULL,57,10629,0);
INSERT INTO "django_geo_db_location" VALUES(18629,NULL,'Points, WV',7707,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18630,NULL,'Points, WV 25437',7707,222,NULL,57,10630,0);
INSERT INTO "django_geo_db_location" VALUES(18631,NULL,'Ranson, WV',7708,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18632,NULL,'Ranson, WV 25438',7708,222,NULL,57,10631,0);
INSERT INTO "django_geo_db_location" VALUES(18633,NULL,'Ridgeway, WV',7709,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18634,NULL,'Ridgeway, WV 25440',7709,222,NULL,57,10632,0);
INSERT INTO "django_geo_db_location" VALUES(18635,NULL,'Rippon, WV',7710,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18636,NULL,'Rippon, WV 25441',7710,222,NULL,57,10633,0);
INSERT INTO "django_geo_db_location" VALUES(18637,NULL,'Shenandoah Junction, WV',7711,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18638,NULL,'Shenandoah Junction, WV 25442',7711,222,NULL,57,10634,0);
INSERT INTO "django_geo_db_location" VALUES(18639,NULL,'Shepherdstown, WV',7712,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18640,NULL,'Shepherdstown, WV 25443',7712,222,NULL,57,10635,0);
INSERT INTO "django_geo_db_location" VALUES(18641,NULL,'Slanesville, WV',7713,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18642,NULL,'Slanesville, WV 25444',7713,222,NULL,57,10636,0);
INSERT INTO "django_geo_db_location" VALUES(18643,NULL,'Summit Point, WV',7714,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18644,NULL,'Summit Point, WV 25446',7714,222,NULL,57,10637,0);
INSERT INTO "django_geo_db_location" VALUES(18645,NULL,'Alkol, WV',7715,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18646,NULL,'Alkol, WV 25501',7715,222,NULL,57,10638,0);
INSERT INTO "django_geo_db_location" VALUES(18647,NULL,'Apple Grove, WV',7716,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18648,NULL,'Apple Grove, WV 25502',7716,222,NULL,57,10639,0);
INSERT INTO "django_geo_db_location" VALUES(18649,NULL,'Ashton, WV',7717,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18650,NULL,'Ashton, WV 25503',7717,222,NULL,57,10640,0);
INSERT INTO "django_geo_db_location" VALUES(18651,NULL,'Barboursville, WV',7718,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18652,NULL,'Barboursville, WV 25504',7718,222,NULL,57,10641,0);
INSERT INTO "django_geo_db_location" VALUES(18653,NULL,'Big Creek, WV',7719,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18654,NULL,'Big Creek, WV 25505',7719,222,NULL,57,10642,0);
INSERT INTO "django_geo_db_location" VALUES(18655,NULL,'Branchland, WV',7720,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18656,NULL,'Branchland, WV 25506',7720,222,NULL,57,10643,0);
INSERT INTO "django_geo_db_location" VALUES(18657,NULL,'Ceredo, WV',7721,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18658,NULL,'Ceredo, WV 25507',7721,222,NULL,57,10644,0);
INSERT INTO "django_geo_db_location" VALUES(18659,NULL,'Chapmanville, WV',7722,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18660,NULL,'Chapmanville, WV 25508',7722,222,NULL,57,10645,0);
INSERT INTO "django_geo_db_location" VALUES(18661,NULL,'Culloden, WV',7723,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18662,NULL,'Culloden, WV 25510',7723,222,NULL,57,10646,0);
INSERT INTO "django_geo_db_location" VALUES(18663,NULL,'Dunlow, WV',7724,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18664,NULL,'Dunlow, WV 25511',7724,222,NULL,57,10647,0);
INSERT INTO "django_geo_db_location" VALUES(18665,NULL,'East Lynn, WV',7725,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18666,NULL,'East Lynn, WV 25512',7725,222,NULL,57,10648,0);
INSERT INTO "django_geo_db_location" VALUES(18667,NULL,'Fort Gay, WV',7726,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18668,NULL,'Fort Gay, WV 25514',7726,222,NULL,57,10649,0);
INSERT INTO "django_geo_db_location" VALUES(18669,NULL,'Gallipolis Ferry, WV',7727,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18670,NULL,'Gallipolis Ferry, WV 25515',7727,222,NULL,57,10650,0);
INSERT INTO "django_geo_db_location" VALUES(18671,NULL,'Genoa, WV',7728,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18672,NULL,'Genoa, WV 25517',7728,222,NULL,57,10651,0);
INSERT INTO "django_geo_db_location" VALUES(18673,NULL,'Glenhayes, WV',7729,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18674,NULL,'Glenhayes, WV 25519',7729,222,NULL,57,10652,0);
INSERT INTO "django_geo_db_location" VALUES(18675,NULL,'Glenwood, WV',7730,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18676,NULL,'Glenwood, WV 25520',7730,222,NULL,57,10653,0);
INSERT INTO "django_geo_db_location" VALUES(18677,NULL,'Griffithsville, WV',7731,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18678,NULL,'Griffithsville, WV 25521',7731,222,NULL,57,10654,0);
INSERT INTO "django_geo_db_location" VALUES(18679,NULL,'Hamlin, WV',7732,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18680,NULL,'Hamlin, WV 25523',7732,222,NULL,57,10655,0);
INSERT INTO "django_geo_db_location" VALUES(18681,NULL,'Harts, WV',7733,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18682,NULL,'Harts, WV 25524',7733,222,NULL,57,10656,0);
INSERT INTO "django_geo_db_location" VALUES(18683,NULL,'Hurricane, WV',7734,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18684,NULL,'Hurricane, WV 25526',7734,222,NULL,57,10657,0);
INSERT INTO "django_geo_db_location" VALUES(18685,NULL,'Julian, WV',7735,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18686,NULL,'Julian, WV 25529',7735,222,NULL,57,10658,0);
INSERT INTO "django_geo_db_location" VALUES(18687,NULL,'Kenova, WV',7736,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18688,NULL,'Kenova, WV 25530',7736,222,NULL,57,10659,0);
INSERT INTO "django_geo_db_location" VALUES(18689,NULL,'Kiahsville, WV',7737,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18690,NULL,'Kiahsville, WV 25534',7737,222,NULL,57,10660,0);
INSERT INTO "django_geo_db_location" VALUES(18691,NULL,'Lavalette, WV',7738,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18692,NULL,'Lavalette, WV 25535',7738,222,NULL,57,10661,0);
INSERT INTO "django_geo_db_location" VALUES(18693,NULL,'Lesage, WV',7739,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18694,NULL,'Lesage, WV 25537',7739,222,NULL,57,10662,0);
INSERT INTO "django_geo_db_location" VALUES(18695,NULL,'Midkiff, WV',7740,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18696,NULL,'Midkiff, WV 25540',7740,222,NULL,57,10663,0);
INSERT INTO "django_geo_db_location" VALUES(18697,NULL,'Milton, WV',7741,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18698,NULL,'Milton, WV 25541',7741,222,NULL,57,10664,0);
INSERT INTO "django_geo_db_location" VALUES(18699,NULL,'Shepherdstown, WV 25543',7712,222,NULL,57,10665,0);
INSERT INTO "django_geo_db_location" VALUES(18700,NULL,'Myra, WV',7742,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18701,NULL,'Myra, WV 25544',7742,222,NULL,57,10666,0);
INSERT INTO "django_geo_db_location" VALUES(18702,NULL,'Ona, WV',7743,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18703,NULL,'Ona, WV 25545',7743,222,NULL,57,10667,0);
INSERT INTO "django_geo_db_location" VALUES(18704,NULL,'Pecks Mill, WV',7744,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18705,NULL,'Pecks Mill, WV 25547',7744,222,NULL,57,10668,0);
INSERT INTO "django_geo_db_location" VALUES(18706,NULL,'Point Pleasant, WV',7745,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18707,NULL,'Point Pleasant, WV 25550',7745,222,NULL,57,10669,0);
INSERT INTO "django_geo_db_location" VALUES(18708,NULL,'Prichard, WV',7746,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18709,NULL,'Prichard, WV 25555',7746,222,NULL,57,10670,0);
INSERT INTO "django_geo_db_location" VALUES(18710,NULL,'Ranger, WV',7747,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18711,NULL,'Ranger, WV 25557',7747,222,NULL,57,10671,0);
INSERT INTO "django_geo_db_location" VALUES(18712,NULL,'Salt Rock, WV',7748,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18713,NULL,'Salt Rock, WV 25559',7748,222,NULL,57,10672,0);
INSERT INTO "django_geo_db_location" VALUES(18714,NULL,'Scott Depot, WV',7749,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18715,NULL,'Scott Depot, WV 25560',7749,222,NULL,57,10673,0);
INSERT INTO "django_geo_db_location" VALUES(18716,NULL,'Shoals, WV',7750,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18717,NULL,'Shoals, WV 25562',7750,222,NULL,57,10674,0);
INSERT INTO "django_geo_db_location" VALUES(18718,NULL,'Sod, WV',7751,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18719,NULL,'Sod, WV 25564',7751,222,NULL,57,10675,0);
INSERT INTO "django_geo_db_location" VALUES(18720,NULL,'Spurlockville, WV',7752,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18721,NULL,'Spurlockville, WV 25565',7752,222,NULL,57,10676,0);
INSERT INTO "django_geo_db_location" VALUES(18722,NULL,'Sumerco, WV',7753,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18723,NULL,'Sumerco, WV 25567',7753,222,NULL,57,10677,0);
INSERT INTO "django_geo_db_location" VALUES(18724,NULL,'Teays, WV',7754,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18725,NULL,'Teays, WV 25569',7754,222,NULL,57,10678,0);
INSERT INTO "django_geo_db_location" VALUES(18726,NULL,'Wayne, WV',7755,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18727,NULL,'Wayne, WV 25570',7755,222,NULL,57,10679,0);
INSERT INTO "django_geo_db_location" VALUES(18728,NULL,'West Hamlin, WV',7756,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18729,NULL,'West Hamlin, WV 25571',7756,222,NULL,57,10680,0);
INSERT INTO "django_geo_db_location" VALUES(18730,NULL,'Woodville, WV',7757,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18731,NULL,'Woodville, WV 25572',7757,222,NULL,57,10681,0);
INSERT INTO "django_geo_db_location" VALUES(18732,NULL,'Yawkey, WV',7758,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18733,NULL,'Yawkey, WV 25573',7758,222,NULL,57,10682,0);
INSERT INTO "django_geo_db_location" VALUES(18734,NULL,'Logan, WV',7759,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18735,NULL,'Logan, WV 25601',7759,222,NULL,57,10683,0);
INSERT INTO "django_geo_db_location" VALUES(18736,NULL,'Accoville, WV',7760,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18737,NULL,'Accoville, WV 25606',7760,222,NULL,57,10684,0);
INSERT INTO "django_geo_db_location" VALUES(18738,NULL,'Amherstdale, WV',7761,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18739,NULL,'Amherstdale, WV 25607',7761,222,NULL,57,10685,0);
INSERT INTO "django_geo_db_location" VALUES(18740,NULL,'Baisden, WV',7762,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18741,NULL,'Baisden, WV 25608',7762,222,NULL,57,10686,0);
INSERT INTO "django_geo_db_location" VALUES(18742,NULL,'Bruno, WV',7763,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18743,NULL,'Bruno, WV 25611',7763,222,NULL,57,10687,0);
INSERT INTO "django_geo_db_location" VALUES(18744,NULL,'Chauncey, WV',7764,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18745,NULL,'Chauncey, WV 25612',7764,222,NULL,57,10688,0);
INSERT INTO "django_geo_db_location" VALUES(18746,NULL,'Cora, WV',7765,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18747,NULL,'Cora, WV 25614',7765,222,NULL,57,10689,0);
INSERT INTO "django_geo_db_location" VALUES(18748,NULL,'Davin, WV',7766,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18749,NULL,'Davin, WV 25617',7766,222,NULL,57,10690,0);
INSERT INTO "django_geo_db_location" VALUES(18750,NULL,'Gilbert, WV',7767,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18751,NULL,'Gilbert, WV 25621',7767,222,NULL,57,10691,0);
INSERT INTO "django_geo_db_location" VALUES(18752,NULL,'Hampden, WV',7768,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18753,NULL,'Hampden, WV 25623',7768,222,NULL,57,10692,0);
INSERT INTO "django_geo_db_location" VALUES(18754,NULL,'Henlawson, WV',7769,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18755,NULL,'Henlawson, WV 25624',7769,222,NULL,57,10693,0);
INSERT INTO "django_geo_db_location" VALUES(18756,NULL,'Holden, WV',7770,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18757,NULL,'Holden, WV 25625',7770,222,NULL,57,10694,0);
INSERT INTO "django_geo_db_location" VALUES(18758,NULL,'Kistler, WV',7771,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18759,NULL,'Kistler, WV 25628',7771,222,NULL,57,10695,0);
INSERT INTO "django_geo_db_location" VALUES(18760,NULL,'Lorado, WV',7772,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18761,NULL,'Lorado, WV 25630',7772,222,NULL,57,10696,0);
INSERT INTO "django_geo_db_location" VALUES(18762,NULL,'Amherstdale-Robinette, WV',7773,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18763,NULL,'Amherstdale-Robinette, WV 25631',7773,222,NULL,57,10697,0);
INSERT INTO "django_geo_db_location" VALUES(18764,NULL,'Lyburn, WV',7774,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18765,NULL,'Lyburn, WV 25632',7774,222,NULL,57,10698,0);
INSERT INTO "django_geo_db_location" VALUES(18766,NULL,'Mallory, WV',7775,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18767,NULL,'Mallory, WV 25634',7775,222,NULL,57,10699,0);
INSERT INTO "django_geo_db_location" VALUES(18768,NULL,'Man, WV',7776,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18769,NULL,'Man, WV 25635',7776,222,NULL,57,10700,0);
INSERT INTO "django_geo_db_location" VALUES(18770,NULL,'Monaville, WV',7777,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18771,NULL,'Monaville, WV 25636',7777,222,NULL,57,10701,0);
INSERT INTO "django_geo_db_location" VALUES(18772,NULL,'Mount Gay, WV',7778,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18773,NULL,'Mount Gay, WV 25637',7778,222,NULL,57,10702,0);
INSERT INTO "django_geo_db_location" VALUES(18774,NULL,'Omar, WV',7779,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18775,NULL,'Omar, WV 25638',7779,222,NULL,57,10703,0);
INSERT INTO "django_geo_db_location" VALUES(18776,NULL,'Peach Creek, WV',7780,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18777,NULL,'Peach Creek, WV 25639',7780,222,NULL,57,10704,0);
INSERT INTO "django_geo_db_location" VALUES(18778,NULL,'Sarah Ann, WV',7781,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18779,NULL,'Sarah Ann, WV 25644',7781,222,NULL,57,10705,0);
INSERT INTO "django_geo_db_location" VALUES(18780,NULL,'Stirrat, WV',7782,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18781,NULL,'Stirrat, WV 25645',7782,222,NULL,57,10706,0);
INSERT INTO "django_geo_db_location" VALUES(18782,NULL,'Stollings, WV',7783,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18783,NULL,'Stollings, WV 25646',7783,222,NULL,57,10707,0);
INSERT INTO "django_geo_db_location" VALUES(18784,NULL,'Switzer, WV',7784,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18785,NULL,'Switzer, WV 25647',7784,222,NULL,57,10708,0);
INSERT INTO "django_geo_db_location" VALUES(18786,NULL,'Verdunville, WV',7785,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18787,NULL,'Verdunville, WV 25649',7785,222,NULL,57,10709,0);
INSERT INTO "django_geo_db_location" VALUES(18788,NULL,'Verner, WV',7786,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18789,NULL,'Verner, WV 25650',7786,222,NULL,57,10710,0);
INSERT INTO "django_geo_db_location" VALUES(18790,NULL,'Wharncliffe, WV',7787,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18791,NULL,'Wharncliffe, WV 25651',7787,222,NULL,57,10711,0);
INSERT INTO "django_geo_db_location" VALUES(18792,NULL,'Whitman, WV',7788,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18793,NULL,'Whitman, WV 25652',7788,222,NULL,57,10712,0);
INSERT INTO "django_geo_db_location" VALUES(18794,NULL,'Wilkinson, WV',7789,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18795,NULL,'Wilkinson, WV 25653',7789,222,NULL,57,10713,0);
INSERT INTO "django_geo_db_location" VALUES(18796,NULL,'Yolyn, WV',7790,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18797,NULL,'Yolyn, WV 25654',7790,222,NULL,57,10714,0);
INSERT INTO "django_geo_db_location" VALUES(18798,NULL,'Williamson, WV',7791,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18799,NULL,'Williamson, WV 25661',7791,222,NULL,57,10715,0);
INSERT INTO "django_geo_db_location" VALUES(18800,NULL,'Borderland, WV',7792,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18801,NULL,'Borderland, WV 25665',7792,222,NULL,57,10716,0);
INSERT INTO "django_geo_db_location" VALUES(18802,NULL,'Breeden, WV',7793,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18803,NULL,'Breeden, WV 25666',7793,222,NULL,57,10717,0);
INSERT INTO "django_geo_db_location" VALUES(18804,NULL,'Chattaroy, WV',7794,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18805,NULL,'Chattaroy, WV 25667',7794,222,NULL,57,10718,0);
INSERT INTO "django_geo_db_location" VALUES(18806,NULL,'Crum, WV',7795,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18807,NULL,'Crum, WV 25669',7795,222,NULL,57,10719,0);
INSERT INTO "django_geo_db_location" VALUES(18808,NULL,'Delbarton, WV',7796,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18809,NULL,'Delbarton, WV 25670',7796,222,NULL,57,10720,0);
INSERT INTO "django_geo_db_location" VALUES(18810,NULL,'Dingess, WV',7797,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18811,NULL,'Dingess, WV 25671',7797,222,NULL,57,10721,0);
INSERT INTO "django_geo_db_location" VALUES(18812,NULL,'Edgarton, WV',7798,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18813,NULL,'Edgarton, WV 25672',7798,222,NULL,57,10722,0);
INSERT INTO "django_geo_db_location" VALUES(18814,NULL,'Kermit, WV',7799,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18815,NULL,'Kermit, WV 25674',7799,222,NULL,57,10723,0);
INSERT INTO "django_geo_db_location" VALUES(18816,NULL,'Lenore, WV',7800,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18817,NULL,'Lenore, WV 25676',7800,222,NULL,57,10724,0);
INSERT INTO "django_geo_db_location" VALUES(18818,NULL,'Matewan, WV',7801,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18819,NULL,'Matewan, WV 25678',7801,222,NULL,57,10725,0);
INSERT INTO "django_geo_db_location" VALUES(18820,NULL,'Meador, WV',7802,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18821,NULL,'Meador, WV 25682',7802,222,NULL,57,10726,0);
INSERT INTO "django_geo_db_location" VALUES(18822,NULL,'Naugatuck, WV',7803,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18823,NULL,'Naugatuck, WV 25685',7803,222,NULL,57,10727,0);
INSERT INTO "django_geo_db_location" VALUES(18824,NULL,'Newtown, WV',7804,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18825,NULL,'Newtown, WV 25686',7804,222,NULL,57,10728,0);
INSERT INTO "django_geo_db_location" VALUES(18826,NULL,'Nolan, WV',7805,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18827,NULL,'Nolan, WV 25687',7805,222,NULL,57,10729,0);
INSERT INTO "django_geo_db_location" VALUES(18828,NULL,'North Matewan, WV',7806,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18829,NULL,'North Matewan, WV 25688',7806,222,NULL,57,10730,0);
INSERT INTO "django_geo_db_location" VALUES(18830,NULL,'Ragland, WV',7807,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18831,NULL,'Ragland, WV 25690',7807,222,NULL,57,10731,0);
INSERT INTO "django_geo_db_location" VALUES(18832,NULL,'Rawl, WV',7808,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18833,NULL,'Rawl, WV 25691',7808,222,NULL,57,10732,0);
INSERT INTO "django_geo_db_location" VALUES(18834,NULL,'Red Jacket, WV',7809,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18835,NULL,'Red Jacket, WV 25692',7809,222,NULL,57,10733,0);
INSERT INTO "django_geo_db_location" VALUES(18836,NULL,'Thacker, WV',7810,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18837,NULL,'Thacker, WV 25694',7810,222,NULL,57,10734,0);
INSERT INTO "django_geo_db_location" VALUES(18838,NULL,'Varney, WV',7811,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18839,NULL,'Varney, WV 25696',7811,222,NULL,57,10735,0);
INSERT INTO "django_geo_db_location" VALUES(18840,NULL,'Vulcan, WV',7812,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18841,NULL,'Vulcan, WV 25697',7812,222,NULL,57,10736,0);
INSERT INTO "django_geo_db_location" VALUES(18842,NULL,'Wilsondale, WV',7813,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18843,NULL,'Wilsondale, WV 25699',7813,222,NULL,57,10737,0);
INSERT INTO "django_geo_db_location" VALUES(18844,NULL,'Huntington, WV',7814,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18845,NULL,'Huntington, WV 25701',7814,222,NULL,57,10738,0);
INSERT INTO "django_geo_db_location" VALUES(18846,NULL,'Huntington, WV 25702',7814,222,NULL,57,10739,0);
INSERT INTO "django_geo_db_location" VALUES(18847,NULL,'Huntington, WV 25703',7814,222,NULL,57,10740,0);
INSERT INTO "django_geo_db_location" VALUES(18848,NULL,'Huntington, WV 25704',7814,222,NULL,57,10741,0);
INSERT INTO "django_geo_db_location" VALUES(18849,NULL,'Huntington, WV 25705',7814,222,NULL,57,10742,0);
INSERT INTO "django_geo_db_location" VALUES(18850,NULL,'Huntington, WV 25706',7814,222,NULL,57,10743,0);
INSERT INTO "django_geo_db_location" VALUES(18851,NULL,'Huntington, WV 25707',7814,222,NULL,57,10744,0);
INSERT INTO "django_geo_db_location" VALUES(18852,NULL,'Huntington, WV 25708',7814,222,NULL,57,10745,0);
INSERT INTO "django_geo_db_location" VALUES(18853,NULL,'Huntington, WV 25709',7814,222,NULL,57,10746,0);
INSERT INTO "django_geo_db_location" VALUES(18854,NULL,'Huntington, WV 25710',7814,222,NULL,57,10747,0);
INSERT INTO "django_geo_db_location" VALUES(18855,NULL,'Huntington, WV 25711',7814,222,NULL,57,10748,0);
INSERT INTO "django_geo_db_location" VALUES(18856,NULL,'Huntington, WV 25712',7814,222,NULL,57,10749,0);
INSERT INTO "django_geo_db_location" VALUES(18857,NULL,'Huntington, WV 25713',7814,222,NULL,57,10750,0);
INSERT INTO "django_geo_db_location" VALUES(18858,NULL,'Huntington, WV 25714',7814,222,NULL,57,10751,0);
INSERT INTO "django_geo_db_location" VALUES(18859,NULL,'Huntington, WV 25715',7814,222,NULL,57,10752,0);
INSERT INTO "django_geo_db_location" VALUES(18860,NULL,'Huntington, WV 25716',7814,222,NULL,57,10753,0);
INSERT INTO "django_geo_db_location" VALUES(18861,NULL,'Huntington, WV 25717',7814,222,NULL,57,10754,0);
INSERT INTO "django_geo_db_location" VALUES(18862,NULL,'Huntington, WV 25718',7814,222,NULL,57,10755,0);
INSERT INTO "django_geo_db_location" VALUES(18863,NULL,'Huntington, WV 25719',7814,222,NULL,57,10756,0);
INSERT INTO "django_geo_db_location" VALUES(18864,NULL,'Huntington, WV 25720',7814,222,NULL,57,10757,0);
INSERT INTO "django_geo_db_location" VALUES(18865,NULL,'Huntington, WV 25721',7814,222,NULL,57,10758,0);
INSERT INTO "django_geo_db_location" VALUES(18866,NULL,'Huntington, WV 25722',7814,222,NULL,57,10759,0);
INSERT INTO "django_geo_db_location" VALUES(18867,NULL,'Huntington, WV 25723',7814,222,NULL,57,10760,0);
INSERT INTO "django_geo_db_location" VALUES(18868,NULL,'Huntington, WV 25724',7814,222,NULL,57,10761,0);
INSERT INTO "django_geo_db_location" VALUES(18869,NULL,'Huntington, WV 25725',7814,222,NULL,57,10762,0);
INSERT INTO "django_geo_db_location" VALUES(18870,NULL,'Huntington, WV 25726',7814,222,NULL,57,10763,0);
INSERT INTO "django_geo_db_location" VALUES(18871,NULL,'Huntington, WV 25727',7814,222,NULL,57,10764,0);
INSERT INTO "django_geo_db_location" VALUES(18872,NULL,'Huntington, WV 25728',7814,222,NULL,57,10765,0);
INSERT INTO "django_geo_db_location" VALUES(18873,NULL,'Huntington, WV 25729',7814,222,NULL,57,10766,0);
INSERT INTO "django_geo_db_location" VALUES(18874,NULL,'Huntington, WV 25755',7814,222,NULL,57,10767,0);
INSERT INTO "django_geo_db_location" VALUES(18875,NULL,'Huntington, WV 25770',7814,222,NULL,57,10768,0);
INSERT INTO "django_geo_db_location" VALUES(18876,NULL,'Huntington, WV 25771',7814,222,NULL,57,10769,0);
INSERT INTO "django_geo_db_location" VALUES(18877,NULL,'Huntington, WV 25772',7814,222,NULL,57,10770,0);
INSERT INTO "django_geo_db_location" VALUES(18878,NULL,'Huntington, WV 25773',7814,222,NULL,57,10771,0);
INSERT INTO "django_geo_db_location" VALUES(18879,NULL,'Huntington, WV 25774',7814,222,NULL,57,10772,0);
INSERT INTO "django_geo_db_location" VALUES(18880,NULL,'Huntington, WV 25775',7814,222,NULL,57,10773,0);
INSERT INTO "django_geo_db_location" VALUES(18881,NULL,'Huntington, WV 25776',7814,222,NULL,57,10774,0);
INSERT INTO "django_geo_db_location" VALUES(18882,NULL,'Huntington, WV 25777',7814,222,NULL,57,10775,0);
INSERT INTO "django_geo_db_location" VALUES(18883,NULL,'Huntington, WV 25778',7814,222,NULL,57,10776,0);
INSERT INTO "django_geo_db_location" VALUES(18884,NULL,'Huntington, WV 25779',7814,222,NULL,57,10777,0);
INSERT INTO "django_geo_db_location" VALUES(18885,NULL,'Beckley, WV',7815,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18886,NULL,'Beckley, WV 25801',7815,222,NULL,57,10778,0);
INSERT INTO "django_geo_db_location" VALUES(18887,NULL,'Beckley, WV 25802',7815,222,NULL,57,10779,0);
INSERT INTO "django_geo_db_location" VALUES(18888,NULL,'Allen Junction, WV',7816,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18889,NULL,'Allen Junction, WV 25810',7816,222,NULL,57,10780,0);
INSERT INTO "django_geo_db_location" VALUES(18890,NULL,'Amigo, WV',7817,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18891,NULL,'Amigo, WV 25811',7817,222,NULL,57,10781,0);
INSERT INTO "django_geo_db_location" VALUES(18892,NULL,'Ansted, WV',7818,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18893,NULL,'Ansted, WV 25812',7818,222,NULL,57,10782,0);
INSERT INTO "django_geo_db_location" VALUES(18894,NULL,'Beaver, WV',7819,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18895,NULL,'Beaver, WV 25813',7819,222,NULL,57,10783,0);
INSERT INTO "django_geo_db_location" VALUES(18896,NULL,'Blue Jay, WV',7820,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18897,NULL,'Blue Jay, WV 25816',7820,222,NULL,57,10784,0);
INSERT INTO "django_geo_db_location" VALUES(18898,NULL,'Bolt, WV',7821,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18899,NULL,'Bolt, WV 25817',7821,222,NULL,57,10785,0);
INSERT INTO "django_geo_db_location" VALUES(18900,NULL,'Bradley, WV',7822,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18901,NULL,'Bradley, WV 25818',7822,222,NULL,57,10786,0);
INSERT INTO "django_geo_db_location" VALUES(18902,NULL,'Camp Creek, WV',7823,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18903,NULL,'Camp Creek, WV 25820',7823,222,NULL,57,10787,0);
INSERT INTO "django_geo_db_location" VALUES(18904,NULL,'Coal City, WV',7824,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18905,NULL,'Coal City, WV 25823',7824,222,NULL,57,10788,0);
INSERT INTO "django_geo_db_location" VALUES(18906,NULL,'Cool Ridge, WV',7825,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18907,NULL,'Cool Ridge, WV 25825',7825,222,NULL,57,10789,0);
INSERT INTO "django_geo_db_location" VALUES(18908,NULL,'Corinne, WV',7826,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18909,NULL,'Corinne, WV 25826',7826,222,NULL,57,10790,0);
INSERT INTO "django_geo_db_location" VALUES(18910,NULL,'Crab Orchard, WV',7827,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18911,NULL,'Crab Orchard, WV 25827',7827,222,NULL,57,10791,0);
INSERT INTO "django_geo_db_location" VALUES(18912,NULL,'Danese, WV',7828,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18913,NULL,'Danese, WV 25831',7828,222,NULL,57,10792,0);
INSERT INTO "django_geo_db_location" VALUES(18914,NULL,'Daniels, WV',7829,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18915,NULL,'Daniels, WV 25832',7829,222,NULL,57,10793,0);
INSERT INTO "django_geo_db_location" VALUES(18916,NULL,'Dothan, WV',7830,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18917,NULL,'Dothan, WV 25833',7830,222,NULL,57,10794,0);
INSERT INTO "django_geo_db_location" VALUES(18918,NULL,'Eccles, WV',7831,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18919,NULL,'Eccles, WV 25836',7831,222,NULL,57,10795,0);
INSERT INTO "django_geo_db_location" VALUES(18920,NULL,'Edmond, WV',7832,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18921,NULL,'Edmond, WV 25837',7832,222,NULL,57,10796,0);
INSERT INTO "django_geo_db_location" VALUES(18922,NULL,'Fairdale, WV',7833,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18923,NULL,'Fairdale, WV 25839',7833,222,NULL,57,10797,0);
INSERT INTO "django_geo_db_location" VALUES(18924,NULL,'Fayetteville, WV',7834,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18925,NULL,'Fayetteville, WV 25840',7834,222,NULL,57,10798,0);
INSERT INTO "django_geo_db_location" VALUES(18926,NULL,'Flat Top, WV',7835,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18927,NULL,'Flat Top, WV 25841',7835,222,NULL,57,10799,0);
INSERT INTO "django_geo_db_location" VALUES(18928,NULL,'Ghent, WV',7836,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18929,NULL,'Ghent, WV 25843',7836,222,NULL,57,10800,0);
INSERT INTO "django_geo_db_location" VALUES(18930,NULL,'Glen Daniel, WV',7837,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18931,NULL,'Glen Daniel, WV 25844',7837,222,NULL,57,10801,0);
INSERT INTO "django_geo_db_location" VALUES(18932,NULL,'Glen Fork, WV',7838,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18933,NULL,'Glen Fork, WV 25845',7838,222,NULL,57,10802,0);
INSERT INTO "django_geo_db_location" VALUES(18934,NULL,'Glen Jean, WV',7839,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18935,NULL,'Glen Jean, WV 25846',7839,222,NULL,57,10803,0);
INSERT INTO "django_geo_db_location" VALUES(18936,NULL,'Glen Morgan, WV',7840,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18937,NULL,'Glen Morgan, WV 25847',7840,222,NULL,57,10804,0);
INSERT INTO "django_geo_db_location" VALUES(18938,NULL,'Glen Rogers, WV',7841,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18939,NULL,'Glen Rogers, WV 25848',7841,222,NULL,57,10805,0);
INSERT INTO "django_geo_db_location" VALUES(18940,NULL,'Glen White, WV',7842,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18941,NULL,'Glen White, WV 25849',7842,222,NULL,57,10806,0);
INSERT INTO "django_geo_db_location" VALUES(18942,NULL,'Harper, WV',7843,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18943,NULL,'Harper, WV 25851',7843,222,NULL,57,10807,0);
INSERT INTO "django_geo_db_location" VALUES(18944,NULL,'Helen, WV',7844,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18945,NULL,'Helen, WV 25853',7844,222,NULL,57,10808,0);
INSERT INTO "django_geo_db_location" VALUES(18946,NULL,'Hico, WV',7845,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18947,NULL,'Hico, WV 25854',7845,222,NULL,57,10809,0);
INSERT INTO "django_geo_db_location" VALUES(18948,NULL,'Hilltop, WV',7846,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18949,NULL,'Hilltop, WV 25855',7846,222,NULL,57,10810,0);
INSERT INTO "django_geo_db_location" VALUES(18950,NULL,'Jonben, WV',7847,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18951,NULL,'Jonben, WV 25856',7847,222,NULL,57,10811,0);
INSERT INTO "django_geo_db_location" VALUES(18952,NULL,'Josephine, WV',7848,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18953,NULL,'Josephine, WV 25857',7848,222,NULL,57,10812,0);
INSERT INTO "django_geo_db_location" VALUES(18954,NULL,'Kilsyth, WV',7849,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18955,NULL,'Kilsyth, WV 25859',7849,222,NULL,57,10813,0);
INSERT INTO "django_geo_db_location" VALUES(18956,NULL,'Lanark, WV',7850,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18957,NULL,'Lanark, WV 25860',7850,222,NULL,57,10814,0);
INSERT INTO "django_geo_db_location" VALUES(18958,NULL,'Lansing, WV',7851,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18959,NULL,'Lansing, WV 25862',7851,222,NULL,57,10815,0);
INSERT INTO "django_geo_db_location" VALUES(18960,NULL,'Layland, WV',7852,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18961,NULL,'Layland, WV 25864',7852,222,NULL,57,10816,0);
INSERT INTO "django_geo_db_location" VALUES(18962,NULL,'Lester, WV',7853,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18963,NULL,'Lester, WV 25865',7853,222,NULL,57,10817,0);
INSERT INTO "django_geo_db_location" VALUES(18964,NULL,'Lochgelly, WV',7854,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18965,NULL,'Lochgelly, WV 25866',7854,222,NULL,57,10818,0);
INSERT INTO "django_geo_db_location" VALUES(18966,NULL,'Lookout, WV',7855,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18967,NULL,'Lookout, WV 25868',7855,222,NULL,57,10819,0);
INSERT INTO "django_geo_db_location" VALUES(18968,NULL,'Maben, WV',7856,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18969,NULL,'Maben, WV 25870',7856,222,NULL,57,10820,0);
INSERT INTO "django_geo_db_location" VALUES(18970,NULL,'Mabscott, WV',7857,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18971,NULL,'Mabscott, WV 25871',7857,222,NULL,57,10821,0);
INSERT INTO "django_geo_db_location" VALUES(18972,NULL,'Mac Arthur, WV',7858,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18973,NULL,'Mac Arthur, WV 25873',7858,222,NULL,57,10822,0);
INSERT INTO "django_geo_db_location" VALUES(18974,NULL,'McGraws, WV',7859,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18975,NULL,'McGraws, WV 25875',7859,222,NULL,57,10823,0);
INSERT INTO "django_geo_db_location" VALUES(18976,NULL,'Saulsville, WV',7860,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18977,NULL,'Saulsville, WV 25876',7860,222,NULL,57,10824,0);
INSERT INTO "django_geo_db_location" VALUES(18978,NULL,'Midway, WV',7861,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18979,NULL,'Midway, WV 25878',7861,222,NULL,57,10825,0);
INSERT INTO "django_geo_db_location" VALUES(18980,NULL,'Minden, WV',7862,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18981,NULL,'Minden, WV 25879',7862,222,NULL,57,10826,0);
INSERT INTO "django_geo_db_location" VALUES(18982,NULL,'Mount Hope, WV',7863,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18983,NULL,'Mount Hope, WV 25880',7863,222,NULL,57,10827,0);
INSERT INTO "django_geo_db_location" VALUES(18984,NULL,'Mullens, WV',7864,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18985,NULL,'Mullens, WV 25882',7864,222,NULL,57,10828,0);
INSERT INTO "django_geo_db_location" VALUES(18986,NULL,'Shady Spring, WV',7865,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18987,NULL,'Shady Spring, WV 25898',7865,222,NULL,57,10829,0);
INSERT INTO "django_geo_db_location" VALUES(18988,NULL,'Oak Hill, WV',7866,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18989,NULL,'Oak Hill, WV 25901',7866,222,NULL,57,10830,0);
INSERT INTO "django_geo_db_location" VALUES(18990,NULL,'Odd, WV',7867,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18991,NULL,'Odd, WV 25902',7867,222,NULL,57,10831,0);
INSERT INTO "django_geo_db_location" VALUES(18992,NULL,'Pax, WV',7868,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18993,NULL,'Pax, WV 25904',7868,222,NULL,57,10832,0);
INSERT INTO "django_geo_db_location" VALUES(18994,NULL,'Piney View, WV',7869,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18995,NULL,'Piney View, WV 25906',7869,222,NULL,57,10833,0);
INSERT INTO "django_geo_db_location" VALUES(18996,NULL,'Prince, WV',7870,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18997,NULL,'Prince, WV 25907',7870,222,NULL,57,10834,0);
INSERT INTO "django_geo_db_location" VALUES(18998,NULL,'Princewick, WV',7871,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(18999,NULL,'Princewick, WV 25908',7871,222,NULL,57,10835,0);
INSERT INTO "django_geo_db_location" VALUES(19000,NULL,'Prosperity, WV',7872,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19001,NULL,'Prosperity, WV 25909',7872,222,NULL,57,10836,0);
INSERT INTO "django_geo_db_location" VALUES(19002,NULL,'Raleigh, WV',7873,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19003,NULL,'Raleigh, WV 25911',7873,222,NULL,57,10837,0);
INSERT INTO "django_geo_db_location" VALUES(19004,NULL,'Ramsey, WV',7874,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19005,NULL,'Ramsey, WV 25912',7874,222,NULL,57,10838,0);
INSERT INTO "django_geo_db_location" VALUES(19006,NULL,'Ravencliff, WV',7875,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19007,NULL,'Ravencliff, WV 25913',7875,222,NULL,57,10839,0);
INSERT INTO "django_geo_db_location" VALUES(19008,NULL,'Redstar, WV',7876,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19009,NULL,'Redstar, WV 25914',7876,222,NULL,57,10840,0);
INSERT INTO "django_geo_db_location" VALUES(19010,NULL,'Rhodell, WV',7877,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19011,NULL,'Rhodell, WV 25915',7877,222,NULL,57,10841,0);
INSERT INTO "django_geo_db_location" VALUES(19012,NULL,'Sabine, WV',7878,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19013,NULL,'Sabine, WV 25916',7878,222,NULL,57,10842,0);
INSERT INTO "django_geo_db_location" VALUES(19014,NULL,'Scarbro, WV',7879,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19015,NULL,'Scarbro, WV 25917',7879,222,NULL,57,10843,0);
INSERT INTO "django_geo_db_location" VALUES(19016,NULL,'Shady Spring, WV 25918',7865,222,NULL,57,10844,0);
INSERT INTO "django_geo_db_location" VALUES(19017,NULL,'Skelton, WV',7880,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19018,NULL,'Skelton, WV 25919',7880,222,NULL,57,10845,0);
INSERT INTO "django_geo_db_location" VALUES(19019,NULL,'Slab Fork, WV',7881,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19020,NULL,'Slab Fork, WV 25920',7881,222,NULL,57,10846,0);
INSERT INTO "django_geo_db_location" VALUES(19021,NULL,'Sophia, WV',7882,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19022,NULL,'Sophia, WV 25921',7882,222,NULL,57,10847,0);
INSERT INTO "django_geo_db_location" VALUES(19023,NULL,'Spanishburg, WV',7883,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19024,NULL,'Spanishburg, WV 25922',7883,222,NULL,57,10848,0);
INSERT INTO "django_geo_db_location" VALUES(19025,NULL,'Sprague, WV',7884,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19026,NULL,'Sprague, WV 25926',7884,222,NULL,57,10849,0);
INSERT INTO "django_geo_db_location" VALUES(19027,NULL,'Stanaford, WV',7885,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19028,NULL,'Stanaford, WV 25927',7885,222,NULL,57,10850,0);
INSERT INTO "django_geo_db_location" VALUES(19029,NULL,'Stephenson, WV',7886,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19030,NULL,'Stephenson, WV 25928',7886,222,NULL,57,10851,0);
INSERT INTO "django_geo_db_location" VALUES(19031,NULL,'Summerlee, WV',7887,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19032,NULL,'Summerlee, WV 25931',7887,222,NULL,57,10852,0);
INSERT INTO "django_geo_db_location" VALUES(19033,NULL,'Surveyor, WV',7888,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19034,NULL,'Surveyor, WV 25932',7888,222,NULL,57,10853,0);
INSERT INTO "django_geo_db_location" VALUES(19035,NULL,'Terry, WV',7889,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19036,NULL,'Terry, WV 25934',7889,222,NULL,57,10854,0);
INSERT INTO "django_geo_db_location" VALUES(19037,NULL,'Thurmond, WV',7890,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19038,NULL,'Thurmond, WV 25936',7890,222,NULL,57,10855,0);
INSERT INTO "django_geo_db_location" VALUES(19039,NULL,'Victor, WV',7891,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19040,NULL,'Victor, WV 25938',7891,222,NULL,57,10856,0);
INSERT INTO "django_geo_db_location" VALUES(19041,NULL,'Winona, WV',7892,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19042,NULL,'Winona, WV 25942',7892,222,NULL,57,10857,0);
INSERT INTO "django_geo_db_location" VALUES(19043,NULL,'Wyco, WV',7893,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19044,NULL,'Wyco, WV 25943',7893,222,NULL,57,10858,0);
INSERT INTO "django_geo_db_location" VALUES(19045,NULL,'Hinton, WV',7894,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19046,NULL,'Hinton, WV 25951',7894,222,NULL,57,10859,0);
INSERT INTO "django_geo_db_location" VALUES(19047,NULL,'Charmco, WV',7895,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19048,NULL,'Charmco, WV 25958',7895,222,NULL,57,10860,0);
INSERT INTO "django_geo_db_location" VALUES(19049,NULL,'Crichton, WV',7896,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19050,NULL,'Crichton, WV 25961',7896,222,NULL,57,10861,0);
INSERT INTO "django_geo_db_location" VALUES(19051,NULL,'Rainelle, WV',7897,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19052,NULL,'Rainelle, WV 25962',7897,222,NULL,57,10862,0);
INSERT INTO "django_geo_db_location" VALUES(19053,NULL,'Elton, WV',7898,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19054,NULL,'Elton, WV 25965',7898,222,NULL,57,10863,0);
INSERT INTO "django_geo_db_location" VALUES(19055,NULL,'Green Sulphur Springs, WV',7899,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19056,NULL,'Green Sulphur Springs, WV 25966',7899,222,NULL,57,10864,0);
INSERT INTO "django_geo_db_location" VALUES(19057,NULL,'Hines, WV',7900,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19058,NULL,'Hines, WV 25967',7900,222,NULL,57,10865,0);
INSERT INTO "django_geo_db_location" VALUES(19059,NULL,'Jumping Branch, WV',7901,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19060,NULL,'Jumping Branch, WV 25969',7901,222,NULL,57,10866,0);
INSERT INTO "django_geo_db_location" VALUES(19061,NULL,'Lerona, WV',7902,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19062,NULL,'Lerona, WV 25971',7902,222,NULL,57,10867,0);
INSERT INTO "django_geo_db_location" VALUES(19063,NULL,'Leslie, WV',7903,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19064,NULL,'Leslie, WV 25972',7903,222,NULL,57,10868,0);
INSERT INTO "django_geo_db_location" VALUES(19065,NULL,'Meadow Bridge, WV',7904,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19066,NULL,'Meadow Bridge, WV 25976',7904,222,NULL,57,10869,0);
INSERT INTO "django_geo_db_location" VALUES(19067,NULL,'Meadow Creek, WV',7905,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19068,NULL,'Meadow Creek, WV 25977',7905,222,NULL,57,10870,0);
INSERT INTO "django_geo_db_location" VALUES(19069,NULL,'Nimitz, WV',7906,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19070,NULL,'Nimitz, WV 25978',7906,222,NULL,57,10871,0);
INSERT INTO "django_geo_db_location" VALUES(19071,NULL,'Pipestem, WV',7907,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19072,NULL,'Pipestem, WV 25979',7907,222,NULL,57,10872,0);
INSERT INTO "django_geo_db_location" VALUES(19073,NULL,'Quinwood, WV',7908,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19074,NULL,'Quinwood, WV 25981',7908,222,NULL,57,10873,0);
INSERT INTO "django_geo_db_location" VALUES(19075,NULL,'Rupert, WV',7909,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19076,NULL,'Rupert, WV 25984',7909,222,NULL,57,10874,0);
INSERT INTO "django_geo_db_location" VALUES(19077,NULL,'Sandstone, WV',7910,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19078,NULL,'Sandstone, WV 25985',7910,222,NULL,57,10875,0);
INSERT INTO "django_geo_db_location" VALUES(19079,NULL,'Spring Dale, WV',7911,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19080,NULL,'Spring Dale, WV 25986',7911,222,NULL,57,10876,0);
INSERT INTO "django_geo_db_location" VALUES(19081,NULL,'True, WV',7912,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19082,NULL,'True, WV 25988',7912,222,NULL,57,10877,0);
INSERT INTO "django_geo_db_location" VALUES(19083,NULL,'White Oak, WV',7913,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19084,NULL,'White Oak, WV 25989',7913,222,NULL,57,10878,0);
INSERT INTO "django_geo_db_location" VALUES(19085,NULL,'Wheeling, WV',7914,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19086,NULL,'Wheeling, WV 26003',7914,222,NULL,57,10879,0);
INSERT INTO "django_geo_db_location" VALUES(19087,NULL,'Beech Bottom, WV',7915,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19088,NULL,'Beech Bottom, WV 26030',7915,222,NULL,57,10880,0);
INSERT INTO "django_geo_db_location" VALUES(19089,NULL,'Benwood, WV',7916,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19090,NULL,'Benwood, WV 26031',7916,222,NULL,57,10881,0);
INSERT INTO "django_geo_db_location" VALUES(19091,NULL,'Bethany, WV',7917,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19092,NULL,'Bethany, WV 26032',7917,222,NULL,57,10882,0);
INSERT INTO "django_geo_db_location" VALUES(19093,NULL,'Cameron, WV',7918,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19094,NULL,'Cameron, WV 26033',7918,222,NULL,57,10883,0);
INSERT INTO "django_geo_db_location" VALUES(19095,NULL,'Chester, WV',7919,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19096,NULL,'Chester, WV 26034',7919,222,NULL,57,10884,0);
INSERT INTO "django_geo_db_location" VALUES(19097,NULL,'Colliers, WV',7920,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19098,NULL,'Colliers, WV 26035',7920,222,NULL,57,10885,0);
INSERT INTO "django_geo_db_location" VALUES(19099,NULL,'Dallas, WV',7921,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19100,NULL,'Dallas, WV 26036',7921,222,NULL,57,10886,0);
INSERT INTO "django_geo_db_location" VALUES(19101,NULL,'Follansbee, WV',7922,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19102,NULL,'Follansbee, WV 26037',7922,222,NULL,57,10887,0);
INSERT INTO "django_geo_db_location" VALUES(19103,NULL,'Glen Dale, WV',7923,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19104,NULL,'Glen Dale, WV 26038',7923,222,NULL,57,10888,0);
INSERT INTO "django_geo_db_location" VALUES(19105,NULL,'Glen Easton, WV',7924,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19106,NULL,'Glen Easton, WV 26039',7924,222,NULL,57,10889,0);
INSERT INTO "django_geo_db_location" VALUES(19107,NULL,'McMechen, WV',7925,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19108,NULL,'McMechen, WV 26040',7925,222,NULL,57,10890,0);
INSERT INTO "django_geo_db_location" VALUES(19109,NULL,'Moundsville, WV',7926,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19110,NULL,'Moundsville, WV 26041',7926,222,NULL,57,10891,0);
INSERT INTO "django_geo_db_location" VALUES(19111,NULL,'New Cumberland, WV',7927,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19112,NULL,'New Cumberland, WV 26047',7927,222,NULL,57,10892,0);
INSERT INTO "django_geo_db_location" VALUES(19113,NULL,'Newell, WV',7928,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19114,NULL,'Newell, WV 26050',7928,222,NULL,57,10893,0);
INSERT INTO "django_geo_db_location" VALUES(19115,NULL,'Proctor, WV',7929,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19116,NULL,'Proctor, WV 26055',7929,222,NULL,57,10894,0);
INSERT INTO "django_geo_db_location" VALUES(19117,NULL,'New Manchester, WV',7930,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19118,NULL,'New Manchester, WV 26056',7930,222,NULL,57,10895,0);
INSERT INTO "django_geo_db_location" VALUES(19119,NULL,'Short Creek, WV',7931,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19120,NULL,'Short Creek, WV 26058',7931,222,NULL,57,10896,0);
INSERT INTO "django_geo_db_location" VALUES(19121,NULL,'Triadelphia, WV',7932,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19122,NULL,'Triadelphia, WV 26059',7932,222,NULL,57,10897,0);
INSERT INTO "django_geo_db_location" VALUES(19123,NULL,'Valley Grove, WV',7933,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19124,NULL,'Valley Grove, WV 26060',7933,222,NULL,57,10898,0);
INSERT INTO "django_geo_db_location" VALUES(19125,NULL,'Weirton, WV',7934,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19126,NULL,'Weirton, WV 26062',7934,222,NULL,57,10899,0);
INSERT INTO "django_geo_db_location" VALUES(19127,NULL,'Wellsburg, WV',7935,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19128,NULL,'Wellsburg, WV 26070',7935,222,NULL,57,10900,0);
INSERT INTO "django_geo_db_location" VALUES(19129,NULL,'West Liberty, WV',7936,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19130,NULL,'West Liberty, WV 26074',7936,222,NULL,57,10901,0);
INSERT INTO "django_geo_db_location" VALUES(19131,NULL,'Windsor Heights, WV',7937,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19132,NULL,'Windsor Heights, WV 26075',7937,222,NULL,57,10902,0);
INSERT INTO "django_geo_db_location" VALUES(19133,NULL,'Parkersburg, WV',7938,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19134,NULL,'Parkersburg, WV 26101',7938,222,NULL,57,10903,0);
INSERT INTO "django_geo_db_location" VALUES(19135,NULL,'Parkersburg, WV 26102',7938,222,NULL,57,10904,0);
INSERT INTO "django_geo_db_location" VALUES(19136,NULL,'Parkersburg, WV 26103',7938,222,NULL,57,10905,0);
INSERT INTO "django_geo_db_location" VALUES(19137,NULL,'Parkersburg, WV 26104',7938,222,NULL,57,10906,0);
INSERT INTO "django_geo_db_location" VALUES(19138,NULL,'Vienna, WV',7939,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19139,NULL,'Vienna, WV 26105',7939,222,NULL,57,10907,0);
INSERT INTO "django_geo_db_location" VALUES(19140,NULL,'Parkersburg, WV 26106',7938,222,NULL,57,10908,0);
INSERT INTO "django_geo_db_location" VALUES(19141,NULL,'Mineral Wells, WV',7940,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19142,NULL,'Mineral Wells, WV 26120',7940,222,NULL,57,10909,0);
INSERT INTO "django_geo_db_location" VALUES(19143,NULL,'Mineral Wells, WV 26121',7940,222,NULL,57,10910,0);
INSERT INTO "django_geo_db_location" VALUES(19144,NULL,'Belleville, WV',7941,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19145,NULL,'Belleville, WV 26133',7941,222,NULL,57,10911,0);
INSERT INTO "django_geo_db_location" VALUES(19146,NULL,'Belmont, WV',7942,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19147,NULL,'Belmont, WV 26134',7942,222,NULL,57,10912,0);
INSERT INTO "django_geo_db_location" VALUES(19148,NULL,'Bens Run, WV',7943,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19149,NULL,'Bens Run, WV 26135',7943,222,NULL,57,10913,0);
INSERT INTO "django_geo_db_location" VALUES(19150,NULL,'Big Bend, WV',7944,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19151,NULL,'Big Bend, WV 26136',7944,222,NULL,57,10914,0);
INSERT INTO "django_geo_db_location" VALUES(19152,NULL,'Big Springs, WV',7945,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19153,NULL,'Big Springs, WV 26137',7945,222,NULL,57,10915,0);
INSERT INTO "django_geo_db_location" VALUES(19154,NULL,'Brohard, WV',7946,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19155,NULL,'Brohard, WV 26138',7946,222,NULL,57,10916,0);
INSERT INTO "django_geo_db_location" VALUES(19156,NULL,'Creston, WV',7947,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19157,NULL,'Creston, WV 26141',7947,222,NULL,57,10917,0);
INSERT INTO "django_geo_db_location" VALUES(19158,NULL,'Davisville, WV',7948,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19159,NULL,'Davisville, WV 26142',7948,222,NULL,57,10918,0);
INSERT INTO "django_geo_db_location" VALUES(19160,NULL,'Elizabeth, WV',7949,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19161,NULL,'Elizabeth, WV 26143',7949,222,NULL,57,10919,0);
INSERT INTO "django_geo_db_location" VALUES(19162,NULL,'Pennsboro, WV',7950,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19163,NULL,'Pennsboro, WV 26145',7950,222,NULL,57,10920,0);
INSERT INTO "django_geo_db_location" VALUES(19164,NULL,'Friendly, WV',7951,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19165,NULL,'Friendly, WV 26146',7951,222,NULL,57,10921,0);
INSERT INTO "django_geo_db_location" VALUES(19166,NULL,'Grantsville, WV',7952,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19167,NULL,'Grantsville, WV 26147',7952,222,NULL,57,10922,0);
INSERT INTO "django_geo_db_location" VALUES(19168,NULL,'Macfarlan, WV',7953,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19169,NULL,'Macfarlan, WV 26148',7953,222,NULL,57,10923,0);
INSERT INTO "django_geo_db_location" VALUES(19170,NULL,'Middlebourne, WV',7954,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19171,NULL,'Middlebourne, WV 26149',7954,222,NULL,57,10924,0);
INSERT INTO "django_geo_db_location" VALUES(19172,NULL,'Mineral Wells, WV 26150',7940,222,NULL,57,10925,0);
INSERT INTO "django_geo_db_location" VALUES(19173,NULL,'Mount Zion, WV',7955,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19174,NULL,'Mount Zion, WV 26151',7955,222,NULL,57,10926,0);
INSERT INTO "django_geo_db_location" VALUES(19175,NULL,'Munday, WV',7956,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19176,NULL,'Munday, WV 26152',7956,222,NULL,57,10927,0);
INSERT INTO "django_geo_db_location" VALUES(19177,NULL,'New Martinsville, WV',7957,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19178,NULL,'New Martinsville, WV 26155',7957,222,NULL,57,10928,0);
INSERT INTO "django_geo_db_location" VALUES(19179,NULL,'Paden City, WV',7958,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19180,NULL,'Paden City, WV 26159',7958,222,NULL,57,10929,0);
INSERT INTO "django_geo_db_location" VALUES(19181,NULL,'Palestine, WV',7959,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19182,NULL,'Palestine, WV 26160',7959,222,NULL,57,10930,0);
INSERT INTO "django_geo_db_location" VALUES(19183,NULL,'Petroleum, WV',7960,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19184,NULL,'Petroleum, WV 26161',7960,222,NULL,57,10931,0);
INSERT INTO "django_geo_db_location" VALUES(19185,NULL,'Porters Falls, WV',7961,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19186,NULL,'Porters Falls, WV 26162',7961,222,NULL,57,10932,0);
INSERT INTO "django_geo_db_location" VALUES(19187,NULL,'Ravenswood, WV',7962,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19188,NULL,'Ravenswood, WV 26164',7962,222,NULL,57,10933,0);
INSERT INTO "django_geo_db_location" VALUES(19189,NULL,'Reader, WV',7963,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19190,NULL,'Reader, WV 26167',7963,222,NULL,57,10934,0);
INSERT INTO "django_geo_db_location" VALUES(19191,NULL,'Rockport, WV',7964,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19192,NULL,'Rockport, WV 26169',7964,222,NULL,57,10935,0);
INSERT INTO "django_geo_db_location" VALUES(19193,NULL,'Saint Marys, WV',7965,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19194,NULL,'Saint Marys, WV 26170',7965,222,NULL,57,10936,0);
INSERT INTO "django_geo_db_location" VALUES(19195,NULL,'Sherman, WV',7966,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19196,NULL,'Sherman, WV 26173',7966,222,NULL,57,10937,0);
INSERT INTO "django_geo_db_location" VALUES(19197,NULL,'Sistersville, WV',7967,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19198,NULL,'Sistersville, WV 26175',7967,222,NULL,57,10938,0);
INSERT INTO "django_geo_db_location" VALUES(19199,NULL,'Smithville, WV',7968,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19200,NULL,'Smithville, WV 26178',7968,222,NULL,57,10939,0);
INSERT INTO "django_geo_db_location" VALUES(19201,NULL,'Walker, WV',7969,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19202,NULL,'Walker, WV 26180',7969,222,NULL,57,10940,0);
INSERT INTO "django_geo_db_location" VALUES(19203,NULL,'Washington, WV',7970,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19204,NULL,'Washington, WV 26181',7970,222,NULL,57,10941,0);
INSERT INTO "django_geo_db_location" VALUES(19205,NULL,'Waverly, WV',7971,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19206,NULL,'Waverly, WV 26184',7971,222,NULL,57,10942,0);
INSERT INTO "django_geo_db_location" VALUES(19207,NULL,'Wileyville, WV',7972,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19208,NULL,'Wileyville, WV 26186',7972,222,NULL,57,10943,0);
INSERT INTO "django_geo_db_location" VALUES(19209,NULL,'Williamstown, WV',7973,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19210,NULL,'Williamstown, WV 26187',7973,222,NULL,57,10944,0);
INSERT INTO "django_geo_db_location" VALUES(19211,NULL,'Buckhannon, WV',7974,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19212,NULL,'Buckhannon, WV 26201',7974,222,NULL,57,10945,0);
INSERT INTO "django_geo_db_location" VALUES(19213,NULL,'Fenwick, WV',7975,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19214,NULL,'Fenwick, WV 26202',7975,222,NULL,57,10946,0);
INSERT INTO "django_geo_db_location" VALUES(19215,NULL,'Erbacon, WV',7976,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19216,NULL,'Erbacon, WV 26203',7976,222,NULL,57,10947,0);
INSERT INTO "django_geo_db_location" VALUES(19217,NULL,'Craigsville, WV',7977,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19218,NULL,'Craigsville, WV 26205',7977,222,NULL,57,10948,0);
INSERT INTO "django_geo_db_location" VALUES(19219,NULL,'Cowen, WV',7978,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19220,NULL,'Cowen, WV 26206',7978,222,NULL,57,10949,0);
INSERT INTO "django_geo_db_location" VALUES(19221,NULL,'Camden On Gauley, WV',7979,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19222,NULL,'Camden On Gauley, WV 26208',7979,222,NULL,57,10950,0);
INSERT INTO "django_geo_db_location" VALUES(19223,NULL,'Snowshoe, WV',7980,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19224,NULL,'Snowshoe, WV 26209',7980,222,NULL,57,10951,0);
INSERT INTO "django_geo_db_location" VALUES(19225,NULL,'Adrian, WV',7981,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19226,NULL,'Adrian, WV 26210',7981,222,NULL,57,10952,0);
INSERT INTO "django_geo_db_location" VALUES(19227,NULL,'Cleveland, WV',7982,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19228,NULL,'Cleveland, WV 26215',7982,222,NULL,57,10953,0);
INSERT INTO "django_geo_db_location" VALUES(19229,NULL,'Diana, WV',7983,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19230,NULL,'Diana, WV 26217',7983,222,NULL,57,10954,0);
INSERT INTO "django_geo_db_location" VALUES(19231,NULL,'French Creek, WV',7984,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19232,NULL,'French Creek, WV 26218',7984,222,NULL,57,10955,0);
INSERT INTO "django_geo_db_location" VALUES(19233,NULL,'Frenchton, WV',7985,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19234,NULL,'Frenchton, WV 26219',7985,222,NULL,57,10956,0);
INSERT INTO "django_geo_db_location" VALUES(19235,NULL,'Hacker Valley, WV',7986,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19236,NULL,'Hacker Valley, WV 26222',7986,222,NULL,57,10957,0);
INSERT INTO "django_geo_db_location" VALUES(19237,NULL,'Helvetia, WV',7987,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19238,NULL,'Helvetia, WV 26224',7987,222,NULL,57,10958,0);
INSERT INTO "django_geo_db_location" VALUES(19239,NULL,'Kanawha Head, WV',7988,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19240,NULL,'Kanawha Head, WV 26228',7988,222,NULL,57,10959,0);
INSERT INTO "django_geo_db_location" VALUES(19241,NULL,'Lorentz, WV',7989,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19242,NULL,'Lorentz, WV 26229',7989,222,NULL,57,10960,0);
INSERT INTO "django_geo_db_location" VALUES(19243,NULL,'Pickens, WV',7990,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19244,NULL,'Pickens, WV 26230',7990,222,NULL,57,10961,0);
INSERT INTO "django_geo_db_location" VALUES(19245,NULL,'Rock Cave, WV',7991,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19246,NULL,'Rock Cave, WV 26234',7991,222,NULL,57,10962,0);
INSERT INTO "django_geo_db_location" VALUES(19247,NULL,'Selbyville, WV',7992,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19248,NULL,'Selbyville, WV 26236',7992,222,NULL,57,10963,0);
INSERT INTO "django_geo_db_location" VALUES(19249,NULL,'Tallmansville, WV',7993,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19250,NULL,'Tallmansville, WV 26237',7993,222,NULL,57,10964,0);
INSERT INTO "django_geo_db_location" VALUES(19251,NULL,'Volga, WV',7994,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19252,NULL,'Volga, WV 26238',7994,222,NULL,57,10965,0);
INSERT INTO "django_geo_db_location" VALUES(19253,NULL,'Elkins, WV',7995,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19254,NULL,'Elkins, WV 26241',7995,222,NULL,57,10966,0);
INSERT INTO "django_geo_db_location" VALUES(19255,NULL,'Belington, WV',7996,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19256,NULL,'Belington, WV 26250',7996,222,NULL,57,10967,0);
INSERT INTO "django_geo_db_location" VALUES(19257,NULL,'Beverly, WV',7997,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19258,NULL,'Beverly, WV 26253',7997,222,NULL,57,10968,0);
INSERT INTO "django_geo_db_location" VALUES(19259,NULL,'Bowden, WV',7998,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19260,NULL,'Bowden, WV 26254',7998,222,NULL,57,10969,0);
INSERT INTO "django_geo_db_location" VALUES(19261,NULL,'Coalton, WV',7999,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19262,NULL,'Coalton, WV 26257',7999,222,NULL,57,10970,0);
INSERT INTO "django_geo_db_location" VALUES(19263,NULL,'Dailey, WV',8000,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19264,NULL,'Dailey, WV 26259',8000,222,NULL,57,10971,0);
INSERT INTO "django_geo_db_location" VALUES(19265,NULL,'Davis, WV',8001,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19266,NULL,'Davis, WV 26260',8001,222,NULL,57,10972,0);
INSERT INTO "django_geo_db_location" VALUES(19267,NULL,'Richwood, WV',8002,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19268,NULL,'Richwood, WV 26261',8002,222,NULL,57,10973,0);
INSERT INTO "django_geo_db_location" VALUES(19269,NULL,'Dryfork, WV',8003,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19270,NULL,'Dryfork, WV 26263',8003,222,NULL,57,10974,0);
INSERT INTO "django_geo_db_location" VALUES(19271,NULL,'Durbin, WV',8004,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19272,NULL,'Durbin, WV 26264',8004,222,NULL,57,10975,0);
INSERT INTO "django_geo_db_location" VALUES(19273,NULL,'Upperglade, WV',8005,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19274,NULL,'Upperglade, WV 26266',8005,222,NULL,57,10976,0);
INSERT INTO "django_geo_db_location" VALUES(19275,NULL,'Ellamore, WV',8006,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19276,NULL,'Ellamore, WV 26267',8006,222,NULL,57,10977,0);
INSERT INTO "django_geo_db_location" VALUES(19277,NULL,'Glady, WV',8007,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19278,NULL,'Glady, WV 26268',8007,222,NULL,57,10978,0);
INSERT INTO "django_geo_db_location" VALUES(19279,NULL,'Hambleton, WV',8008,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19280,NULL,'Hambleton, WV 26269',8008,222,NULL,57,10979,0);
INSERT INTO "django_geo_db_location" VALUES(19281,NULL,'Harman, WV',8009,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19282,NULL,'Harman, WV 26270',8009,222,NULL,57,10980,0);
INSERT INTO "django_geo_db_location" VALUES(19283,NULL,'Hendricks, WV',8010,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19284,NULL,'Hendricks, WV 26271',8010,222,NULL,57,10981,0);
INSERT INTO "django_geo_db_location" VALUES(19285,NULL,'Huttonsville, WV',8011,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19286,NULL,'Huttonsville, WV 26273',8011,222,NULL,57,10982,0);
INSERT INTO "django_geo_db_location" VALUES(19287,NULL,'Junior, WV',8012,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19288,NULL,'Junior, WV 26275',8012,222,NULL,57,10983,0);
INSERT INTO "django_geo_db_location" VALUES(19289,NULL,'Kerens, WV',8013,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19290,NULL,'Kerens, WV 26276',8013,222,NULL,57,10984,0);
INSERT INTO "django_geo_db_location" VALUES(19291,NULL,'Mabie, WV',8014,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19292,NULL,'Mabie, WV 26278',8014,222,NULL,57,10985,0);
INSERT INTO "django_geo_db_location" VALUES(19293,NULL,'Mill Creek, WV',8015,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19294,NULL,'Mill Creek, WV 26280',8015,222,NULL,57,10986,0);
INSERT INTO "django_geo_db_location" VALUES(19295,NULL,'Monterville, WV',8016,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19296,NULL,'Monterville, WV 26282',8016,222,NULL,57,10987,0);
INSERT INTO "django_geo_db_location" VALUES(19297,NULL,'Montrose, WV',8017,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19298,NULL,'Montrose, WV 26283',8017,222,NULL,57,10988,0);
INSERT INTO "django_geo_db_location" VALUES(19299,NULL,'Norton, WV',8018,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19300,NULL,'Norton, WV 26285',8018,222,NULL,57,10989,0);
INSERT INTO "django_geo_db_location" VALUES(19301,NULL,'Parsons, WV',8019,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19302,NULL,'Parsons, WV 26287',8019,222,NULL,57,10990,0);
INSERT INTO "django_geo_db_location" VALUES(19303,NULL,'Webster Springs, WV',8020,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19304,NULL,'Webster Springs, WV 26288',8020,222,NULL,57,10991,0);
INSERT INTO "django_geo_db_location" VALUES(19305,NULL,'Red Creek, WV',8021,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19306,NULL,'Red Creek, WV 26289',8021,222,NULL,57,10992,0);
INSERT INTO "django_geo_db_location" VALUES(19307,NULL,'Slatyfork, WV',8022,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19308,NULL,'Slatyfork, WV 26291',8022,222,NULL,57,10993,0);
INSERT INTO "django_geo_db_location" VALUES(19309,NULL,'Thomas, WV',8023,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19310,NULL,'Thomas, WV 26292',8023,222,NULL,57,10994,0);
INSERT INTO "django_geo_db_location" VALUES(19311,NULL,'Valley Bend, WV',8024,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19312,NULL,'Valley Bend, WV 26293',8024,222,NULL,57,10995,0);
INSERT INTO "django_geo_db_location" VALUES(19313,NULL,'Valley Head, WV',8025,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19314,NULL,'Valley Head, WV 26294',8025,222,NULL,57,10996,0);
INSERT INTO "django_geo_db_location" VALUES(19315,NULL,'Whitmer, WV',8026,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19316,NULL,'Whitmer, WV 26296',8026,222,NULL,57,10997,0);
INSERT INTO "django_geo_db_location" VALUES(19317,NULL,'Bergoo, WV',8027,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19318,NULL,'Bergoo, WV 26298',8027,222,NULL,57,10998,0);
INSERT INTO "django_geo_db_location" VALUES(19319,NULL,'Clarksburg, WV',8028,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19320,NULL,'Clarksburg, WV 26301',8028,222,NULL,57,10999,0);
INSERT INTO "django_geo_db_location" VALUES(19321,NULL,'Clarksburg, WV 26302',8028,222,NULL,57,11000,0);
INSERT INTO "django_geo_db_location" VALUES(19322,NULL,'Clarksburg, WV 26306',8028,222,NULL,57,11001,0);
INSERT INTO "django_geo_db_location" VALUES(19323,NULL,'Alma, WV',8029,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19324,NULL,'Alma, WV 26320',8029,222,NULL,57,11002,0);
INSERT INTO "django_geo_db_location" VALUES(19325,NULL,'Alum Bridge, WV',8030,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19326,NULL,'Alum Bridge, WV 26321',8030,222,NULL,57,11003,0);
INSERT INTO "django_geo_db_location" VALUES(19327,NULL,'Anmoore, WV',8031,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19328,NULL,'Anmoore, WV 26323',8031,222,NULL,57,11004,0);
INSERT INTO "django_geo_db_location" VALUES(19329,NULL,'Auburn, WV',8032,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19330,NULL,'Auburn, WV 26325',8032,222,NULL,57,11005,0);
INSERT INTO "django_geo_db_location" VALUES(19331,NULL,'Berea, WV',8033,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19332,NULL,'Berea, WV 26327',8033,222,NULL,57,11006,0);
INSERT INTO "django_geo_db_location" VALUES(19333,NULL,'Blandville, WV',8034,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19334,NULL,'Blandville, WV 26328',8034,222,NULL,57,11007,0);
INSERT INTO "django_geo_db_location" VALUES(19335,NULL,'Bridgeport, WV',8035,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19336,NULL,'Bridgeport, WV 26330',8035,222,NULL,57,11008,0);
INSERT INTO "django_geo_db_location" VALUES(19337,NULL,'Bristol, WV',8036,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19338,NULL,'Bristol, WV 26332',8036,222,NULL,57,11009,0);
INSERT INTO "django_geo_db_location" VALUES(19339,NULL,'Burnsville, WV',8037,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19340,NULL,'Burnsville, WV 26333',8037,222,NULL,57,11010,0);
INSERT INTO "django_geo_db_location" VALUES(19341,NULL,'Brownton, WV',8038,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19342,NULL,'Brownton, WV 26334',8038,222,NULL,57,11011,0);
INSERT INTO "django_geo_db_location" VALUES(19343,NULL,'Burnsville, WV 26335',8037,222,NULL,57,11012,0);
INSERT INTO "django_geo_db_location" VALUES(19344,NULL,'Cairo, WV',8039,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19345,NULL,'Cairo, WV 26337',8039,222,NULL,57,11013,0);
INSERT INTO "django_geo_db_location" VALUES(19346,NULL,'Camden, WV',8040,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19347,NULL,'Camden, WV 26338',8040,222,NULL,57,11014,0);
INSERT INTO "django_geo_db_location" VALUES(19348,NULL,'Center Point, WV',8041,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19349,NULL,'Center Point, WV 26339',8041,222,NULL,57,11015,0);
INSERT INTO "django_geo_db_location" VALUES(19350,NULL,'Coxs Mills, WV',8042,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19351,NULL,'Coxs Mills, WV 26342',8042,222,NULL,57,11016,0);
INSERT INTO "django_geo_db_location" VALUES(19352,NULL,'Crawford, WV',8043,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19353,NULL,'Crawford, WV 26343',8043,222,NULL,57,11017,0);
INSERT INTO "django_geo_db_location" VALUES(19354,NULL,'Ellenboro, WV',8044,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19355,NULL,'Ellenboro, WV 26346',8044,222,NULL,57,11018,0);
INSERT INTO "django_geo_db_location" VALUES(19356,NULL,'Flemington, WV',8045,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19357,NULL,'Flemington, WV 26347',8045,222,NULL,57,11019,0);
INSERT INTO "django_geo_db_location" VALUES(19358,NULL,'Folsom, WV',8046,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19359,NULL,'Folsom, WV 26348',8046,222,NULL,57,11020,0);
INSERT INTO "django_geo_db_location" VALUES(19360,NULL,'Galloway, WV',8047,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19361,NULL,'Galloway, WV 26349',8047,222,NULL,57,11021,0);
INSERT INTO "django_geo_db_location" VALUES(19362,NULL,'Gilmer, WV',8048,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19363,NULL,'Gilmer, WV 26350',8048,222,NULL,57,11022,0);
INSERT INTO "django_geo_db_location" VALUES(19364,NULL,'Glenville, WV',8049,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19365,NULL,'Glenville, WV 26351',8049,222,NULL,57,11023,0);
INSERT INTO "django_geo_db_location" VALUES(19366,NULL,'Grafton, WV',8050,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19367,NULL,'Grafton, WV 26354',8050,222,NULL,57,11024,0);
INSERT INTO "django_geo_db_location" VALUES(19368,NULL,'Gypsy, WV',8051,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19369,NULL,'Gypsy, WV 26361',8051,222,NULL,57,11025,0);
INSERT INTO "django_geo_db_location" VALUES(19370,NULL,'Harrisville, WV',8052,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19371,NULL,'Harrisville, WV 26362',8052,222,NULL,57,11026,0);
INSERT INTO "django_geo_db_location" VALUES(19372,NULL,'Haywood, WV',8053,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19373,NULL,'Haywood, WV 26366',8053,222,NULL,57,11027,0);
INSERT INTO "django_geo_db_location" VALUES(19374,NULL,'Hepzibah, WV',8054,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19375,NULL,'Hepzibah, WV 26369',8054,222,NULL,57,11028,0);
INSERT INTO "django_geo_db_location" VALUES(19376,NULL,'Horner, WV',8055,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19377,NULL,'Horner, WV 26372',8055,222,NULL,57,11029,0);
INSERT INTO "django_geo_db_location" VALUES(19378,NULL,'Independence, WV',8056,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19379,NULL,'Independence, WV 26374',8056,222,NULL,57,11030,0);
INSERT INTO "django_geo_db_location" VALUES(19380,NULL,'Industrial, WV',8057,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19381,NULL,'Industrial, WV 26375',8057,222,NULL,57,11031,0);
INSERT INTO "django_geo_db_location" VALUES(19382,NULL,'Ireland, WV',8058,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19383,NULL,'Ireland, WV 26376',8058,222,NULL,57,11032,0);
INSERT INTO "django_geo_db_location" VALUES(19384,NULL,'Jacksonburg, WV',8059,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19385,NULL,'Jacksonburg, WV 26377',8059,222,NULL,57,11033,0);
INSERT INTO "django_geo_db_location" VALUES(19386,NULL,'Jane Lew, WV',8060,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19387,NULL,'Jane Lew, WV 26378',8060,222,NULL,57,11034,0);
INSERT INTO "django_geo_db_location" VALUES(19388,NULL,'Linn, WV',8061,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19389,NULL,'Linn, WV 26384',8061,222,NULL,57,11035,0);
INSERT INTO "django_geo_db_location" VALUES(19390,NULL,'Lost Creek, WV',8062,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19391,NULL,'Lost Creek, WV 26385',8062,222,NULL,57,11036,0);
INSERT INTO "django_geo_db_location" VALUES(19392,NULL,'Lumberport, WV',8063,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19393,NULL,'Lumberport, WV 26386',8063,222,NULL,57,11037,0);
INSERT INTO "django_geo_db_location" VALUES(19394,NULL,'Meadowbrook, WV',8064,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19395,NULL,'Meadowbrook, WV 26404',8064,222,NULL,57,11038,0);
INSERT INTO "django_geo_db_location" VALUES(19396,NULL,'Moatsville, WV',8065,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19397,NULL,'Moatsville, WV 26405',8065,222,NULL,57,11039,0);
INSERT INTO "django_geo_db_location" VALUES(19398,NULL,'Mountain, WV',8066,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19399,NULL,'Mountain, WV 26407',8066,222,NULL,57,11040,0);
INSERT INTO "django_geo_db_location" VALUES(19400,NULL,'Mount Clare, WV',8067,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19401,NULL,'Mount Clare, WV 26408',8067,222,NULL,57,11041,0);
INSERT INTO "django_geo_db_location" VALUES(19402,NULL,'Newburg, WV',8068,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19403,NULL,'Newburg, WV 26410',8068,222,NULL,57,11042,0);
INSERT INTO "django_geo_db_location" VALUES(19404,NULL,'New Milton, WV',8069,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19405,NULL,'New Milton, WV 26411',8069,222,NULL,57,11043,0);
INSERT INTO "django_geo_db_location" VALUES(19406,NULL,'Orlando, WV',8070,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19407,NULL,'Orlando, WV 26412',8070,222,NULL,57,11044,0);
INSERT INTO "django_geo_db_location" VALUES(19408,NULL,'Pennsboro, WV 26415',7950,222,NULL,57,11045,0);
INSERT INTO "django_geo_db_location" VALUES(19409,NULL,'Philippi, WV',8071,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19410,NULL,'Philippi, WV 26416',8071,222,NULL,57,11046,0);
INSERT INTO "django_geo_db_location" VALUES(19411,NULL,'Pine Grove, WV',8072,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19412,NULL,'Pine Grove, WV 26419',8072,222,NULL,57,11047,0);
INSERT INTO "django_geo_db_location" VALUES(19413,NULL,'Pullman, WV',8073,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19414,NULL,'Pullman, WV 26421',8073,222,NULL,57,11048,0);
INSERT INTO "django_geo_db_location" VALUES(19415,NULL,'Reynoldsville, WV',8074,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19416,NULL,'Reynoldsville, WV 26422',8074,222,NULL,57,11049,0);
INSERT INTO "django_geo_db_location" VALUES(19417,NULL,'Rosemont, WV',8075,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19418,NULL,'Rosemont, WV 26424',8075,222,NULL,57,11050,0);
INSERT INTO "django_geo_db_location" VALUES(19419,NULL,'Rowlesburg, WV',8076,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19420,NULL,'Rowlesburg, WV 26425',8076,222,NULL,57,11051,0);
INSERT INTO "django_geo_db_location" VALUES(19421,NULL,'Salem, WV',8077,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19422,NULL,'Salem, WV 26426',8077,222,NULL,57,11052,0);
INSERT INTO "django_geo_db_location" VALUES(19423,NULL,'Sand Fork, WV',8078,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19424,NULL,'Sand Fork, WV 26430',8078,222,NULL,57,11053,0);
INSERT INTO "django_geo_db_location" VALUES(19425,NULL,'Shinnston, WV',8079,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19426,NULL,'Shinnston, WV 26431',8079,222,NULL,57,11054,0);
INSERT INTO "django_geo_db_location" VALUES(19427,NULL,'Shirley, WV',8080,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19428,NULL,'Shirley, WV 26434',8080,222,NULL,57,11055,0);
INSERT INTO "django_geo_db_location" VALUES(19429,NULL,'Simpson, WV',8081,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19430,NULL,'Simpson, WV 26435',8081,222,NULL,57,11056,0);
INSERT INTO "django_geo_db_location" VALUES(19431,NULL,'Smithburg, WV',8082,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19432,NULL,'Smithburg, WV 26436',8082,222,NULL,57,11057,0);
INSERT INTO "django_geo_db_location" VALUES(19433,NULL,'Smithfield, WV',8083,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19434,NULL,'Smithfield, WV 26437',8083,222,NULL,57,11058,0);
INSERT INTO "django_geo_db_location" VALUES(19435,NULL,'Spelter, WV',8084,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19436,NULL,'Spelter, WV 26438',8084,222,NULL,57,11059,0);
INSERT INTO "django_geo_db_location" VALUES(19437,NULL,'Thornton, WV',8085,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19438,NULL,'Thornton, WV 26440',8085,222,NULL,57,11060,0);
INSERT INTO "django_geo_db_location" VALUES(19439,NULL,'Troy, WV',8086,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19440,NULL,'Troy, WV 26443',8086,222,NULL,57,11061,0);
INSERT INTO "django_geo_db_location" VALUES(19441,NULL,'Tunnelton, WV',8087,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19442,NULL,'Tunnelton, WV 26444',8087,222,NULL,57,11062,0);
INSERT INTO "django_geo_db_location" VALUES(19443,NULL,'Walkersville, WV',8088,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19444,NULL,'Walkersville, WV 26447',8088,222,NULL,57,11063,0);
INSERT INTO "django_geo_db_location" VALUES(19445,NULL,'Wallace, WV',8089,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19446,NULL,'Wallace, WV 26448',8089,222,NULL,57,11064,0);
INSERT INTO "django_geo_db_location" VALUES(19447,NULL,'West Milford, WV',8090,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19448,NULL,'West Milford, WV 26451',8090,222,NULL,57,11065,0);
INSERT INTO "django_geo_db_location" VALUES(19449,NULL,'Weston, WV',8091,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19450,NULL,'Weston, WV 26452',8091,222,NULL,57,11066,0);
INSERT INTO "django_geo_db_location" VALUES(19451,NULL,'West Union, WV',8092,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19452,NULL,'West Union, WV 26456',8092,222,NULL,57,11067,0);
INSERT INTO "django_geo_db_location" VALUES(19453,NULL,'Wilsonburg, WV',8093,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19454,NULL,'Wilsonburg, WV 26461',8093,222,NULL,57,11068,0);
INSERT INTO "django_geo_db_location" VALUES(19455,NULL,'Weston, WV 26462',8091,222,NULL,57,11069,0);
INSERT INTO "django_geo_db_location" VALUES(19456,NULL,'Wyatt, WV',8094,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19457,NULL,'Wyatt, WV 26463',8094,222,NULL,57,11070,0);
INSERT INTO "django_geo_db_location" VALUES(19458,NULL,'Morgantown, WV',8095,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19459,NULL,'Morgantown, WV 26501',8095,222,NULL,57,11071,0);
INSERT INTO "django_geo_db_location" VALUES(19460,NULL,'Morgantown, WV 26502',8095,222,NULL,57,11072,0);
INSERT INTO "django_geo_db_location" VALUES(19461,NULL,'Morgantown, WV 26503',8095,222,NULL,57,11073,0);
INSERT INTO "django_geo_db_location" VALUES(19462,NULL,'Morgantown, WV 26504',8095,222,NULL,57,11074,0);
INSERT INTO "django_geo_db_location" VALUES(19463,NULL,'Morgantown, WV 26505',8095,222,NULL,57,11075,0);
INSERT INTO "django_geo_db_location" VALUES(19464,NULL,'Morgantown, WV 26506',8095,222,NULL,57,11076,0);
INSERT INTO "django_geo_db_location" VALUES(19465,NULL,'Morgantown, WV 26507',8095,222,NULL,57,11077,0);
INSERT INTO "django_geo_db_location" VALUES(19466,NULL,'Morgantown, WV 26508',8095,222,NULL,57,11078,0);
INSERT INTO "django_geo_db_location" VALUES(19467,NULL,'Albright, WV',8096,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19468,NULL,'Albright, WV 26519',8096,222,NULL,57,11079,0);
INSERT INTO "django_geo_db_location" VALUES(19469,NULL,'Arthurdale, WV',8097,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19470,NULL,'Arthurdale, WV 26520',8097,222,NULL,57,11080,0);
INSERT INTO "django_geo_db_location" VALUES(19471,NULL,'Blacksville, WV',8098,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19472,NULL,'Blacksville, WV 26521',8098,222,NULL,57,11081,0);
INSERT INTO "django_geo_db_location" VALUES(19473,NULL,'Booth, WV',8099,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19474,NULL,'Booth, WV 26522',8099,222,NULL,57,11082,0);
INSERT INTO "django_geo_db_location" VALUES(19475,NULL,'Bretz, WV',8100,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19476,NULL,'Bretz, WV 26524',8100,222,NULL,57,11083,0);
INSERT INTO "django_geo_db_location" VALUES(19477,NULL,'Bruceton Mills, WV',8101,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19478,NULL,'Bruceton Mills, WV 26525',8101,222,NULL,57,11084,0);
INSERT INTO "django_geo_db_location" VALUES(19479,NULL,'Cassville, WV',8102,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19480,NULL,'Cassville, WV 26527',8102,222,NULL,57,11085,0);
INSERT INTO "django_geo_db_location" VALUES(19481,NULL,'Core, WV',8103,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19482,NULL,'Core, WV 26529',8103,222,NULL,57,11086,0);
INSERT INTO "django_geo_db_location" VALUES(19483,NULL,'Dellslow, WV',8104,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19484,NULL,'Dellslow, WV 26531',8104,222,NULL,57,11087,0);
INSERT INTO "django_geo_db_location" VALUES(19485,NULL,'Everettville, WV',8105,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19486,NULL,'Everettville, WV 26533',8105,222,NULL,57,11088,0);
INSERT INTO "django_geo_db_location" VALUES(19487,NULL,'Granville, WV',8106,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19488,NULL,'Granville, WV 26534',8106,222,NULL,57,11089,0);
INSERT INTO "django_geo_db_location" VALUES(19489,NULL,'Hazelton, WV',8107,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19490,NULL,'Hazelton, WV 26535',8107,222,NULL,57,11090,0);
INSERT INTO "django_geo_db_location" VALUES(19491,NULL,'Kingwood, WV',8108,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19492,NULL,'Kingwood, WV 26537',8108,222,NULL,57,11091,0);
INSERT INTO "django_geo_db_location" VALUES(19493,NULL,'Maidsville, WV',8109,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19494,NULL,'Maidsville, WV 26541',8109,222,NULL,57,11092,0);
INSERT INTO "django_geo_db_location" VALUES(19495,NULL,'Masontown, WV',8110,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19496,NULL,'Masontown, WV 26542',8110,222,NULL,57,11093,0);
INSERT INTO "django_geo_db_location" VALUES(19497,NULL,'Osage, WV',8111,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19498,NULL,'Osage, WV 26543',8111,222,NULL,57,11094,0);
INSERT INTO "django_geo_db_location" VALUES(19499,NULL,'Pentress, WV',8112,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19500,NULL,'Pentress, WV 26544',8112,222,NULL,57,11095,0);
INSERT INTO "django_geo_db_location" VALUES(19501,NULL,'Pursglove, WV',8113,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19502,NULL,'Pursglove, WV 26546',8113,222,NULL,57,11096,0);
INSERT INTO "django_geo_db_location" VALUES(19503,NULL,'Reedsville, WV',8114,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19504,NULL,'Reedsville, WV 26547',8114,222,NULL,57,11097,0);
INSERT INTO "django_geo_db_location" VALUES(19505,NULL,'Fairmont, WV',8115,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19506,NULL,'Fairmont, WV 26554',8115,222,NULL,57,11098,0);
INSERT INTO "django_geo_db_location" VALUES(19507,NULL,'Fairmont, WV 26555',8115,222,NULL,57,11099,0);
INSERT INTO "django_geo_db_location" VALUES(19508,NULL,'Barrackville, WV',8116,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19509,NULL,'Barrackville, WV 26559',8116,222,NULL,57,11100,0);
INSERT INTO "django_geo_db_location" VALUES(19510,NULL,'Baxter, WV',8117,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19511,NULL,'Baxter, WV 26560',8117,222,NULL,57,11101,0);
INSERT INTO "django_geo_db_location" VALUES(19512,NULL,'Big Run, WV',8118,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19513,NULL,'Big Run, WV 26561',8118,222,NULL,57,11102,0);
INSERT INTO "django_geo_db_location" VALUES(19514,NULL,'Burton, WV',8119,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19515,NULL,'Burton, WV 26562',8119,222,NULL,57,11103,0);
INSERT INTO "django_geo_db_location" VALUES(19516,NULL,'Carolina, WV',8120,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19517,NULL,'Carolina, WV 26563',8120,222,NULL,57,11104,0);
INSERT INTO "django_geo_db_location" VALUES(19518,NULL,'Colfax, WV',8121,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19519,NULL,'Colfax, WV 26566',8121,222,NULL,57,11105,0);
INSERT INTO "django_geo_db_location" VALUES(19520,NULL,'Enterprise, WV',8122,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19521,NULL,'Enterprise, WV 26568',8122,222,NULL,57,11106,0);
INSERT INTO "django_geo_db_location" VALUES(19522,NULL,'Fairview, WV',8123,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19523,NULL,'Fairview, WV 26570',8123,222,NULL,57,11107,0);
INSERT INTO "django_geo_db_location" VALUES(19524,NULL,'Farmington, WV',8124,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19525,NULL,'Farmington, WV 26571',8124,222,NULL,57,11108,0);
INSERT INTO "django_geo_db_location" VALUES(19526,NULL,'Four States, WV',8125,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19527,NULL,'Four States, WV 26572',8125,222,NULL,57,11109,0);
INSERT INTO "django_geo_db_location" VALUES(19528,NULL,'Grant Town, WV',8126,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19529,NULL,'Grant Town, WV 26574',8126,222,NULL,57,11110,0);
INSERT INTO "django_geo_db_location" VALUES(19530,NULL,'Hundred, WV',8127,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19531,NULL,'Hundred, WV 26575',8127,222,NULL,57,11111,0);
INSERT INTO "django_geo_db_location" VALUES(19532,NULL,'Idamay, WV',8128,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19533,NULL,'Idamay, WV 26576',8128,222,NULL,57,11112,0);
INSERT INTO "django_geo_db_location" VALUES(19534,NULL,'Kingmont, WV',8129,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19535,NULL,'Kingmont, WV 26578',8129,222,NULL,57,11113,0);
INSERT INTO "django_geo_db_location" VALUES(19536,NULL,'Littleton, WV',8130,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19537,NULL,'Littleton, WV 26581',8130,222,NULL,57,11114,0);
INSERT INTO "django_geo_db_location" VALUES(19538,NULL,'Mannington, WV',8131,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19539,NULL,'Mannington, WV 26582',8131,222,NULL,57,11115,0);
INSERT INTO "django_geo_db_location" VALUES(19540,NULL,'Metz, WV',8132,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19541,NULL,'Metz, WV 26585',8132,222,NULL,57,11116,0);
INSERT INTO "django_geo_db_location" VALUES(19542,NULL,'Montana Mines, WV',8133,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19543,NULL,'Montana Mines, WV 26586',8133,222,NULL,57,11117,0);
INSERT INTO "django_geo_db_location" VALUES(19544,NULL,'Rachel, WV',8134,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19545,NULL,'Rachel, WV 26587',8134,222,NULL,57,11118,0);
INSERT INTO "django_geo_db_location" VALUES(19546,NULL,'Rivesville, WV',8135,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19547,NULL,'Rivesville, WV 26588',8135,222,NULL,57,11119,0);
INSERT INTO "django_geo_db_location" VALUES(19548,NULL,'Wadestown, WV',8136,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19549,NULL,'Wadestown, WV 26589',8136,222,NULL,57,11120,0);
INSERT INTO "django_geo_db_location" VALUES(19550,NULL,'Wana, WV',8137,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19551,NULL,'Wana, WV 26590',8137,222,NULL,57,11121,0);
INSERT INTO "django_geo_db_location" VALUES(19552,NULL,'Worthington, WV',8138,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19553,NULL,'Worthington, WV 26591',8138,222,NULL,57,11122,0);
INSERT INTO "django_geo_db_location" VALUES(19554,NULL,'Sutton, WV',8139,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19555,NULL,'Sutton, WV 26601',8139,222,NULL,57,11123,0);
INSERT INTO "django_geo_db_location" VALUES(19556,NULL,'Birch River, WV',8140,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19557,NULL,'Birch River, WV 26610',8140,222,NULL,57,11124,0);
INSERT INTO "django_geo_db_location" VALUES(19558,NULL,'Cedarville, WV',8141,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19559,NULL,'Cedarville, WV 26611',8141,222,NULL,57,11125,0);
INSERT INTO "django_geo_db_location" VALUES(19560,NULL,'Centralia, WV',8142,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19561,NULL,'Centralia, WV 26612',8142,222,NULL,57,11126,0);
INSERT INTO "django_geo_db_location" VALUES(19562,NULL,'Copen, WV',8143,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19563,NULL,'Copen, WV 26615',8143,222,NULL,57,11127,0);
INSERT INTO "django_geo_db_location" VALUES(19564,NULL,'Dille, WV',8144,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19565,NULL,'Dille, WV 26617',8144,222,NULL,57,11128,0);
INSERT INTO "django_geo_db_location" VALUES(19566,NULL,'Elmira, WV',8145,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19567,NULL,'Elmira, WV 26618',8145,222,NULL,57,11129,0);
INSERT INTO "django_geo_db_location" VALUES(19568,NULL,'Exchange, WV',8146,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19569,NULL,'Exchange, WV 26619',8146,222,NULL,57,11130,0);
INSERT INTO "django_geo_db_location" VALUES(19570,NULL,'Flatwoods, WV',8147,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19571,NULL,'Flatwoods, WV 26621',8147,222,NULL,57,11131,0);
INSERT INTO "django_geo_db_location" VALUES(19572,NULL,'Frametown, WV',8148,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19573,NULL,'Frametown, WV 26623',8148,222,NULL,57,11132,0);
INSERT INTO "django_geo_db_location" VALUES(19574,NULL,'Gassaway, WV',8149,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19575,NULL,'Gassaway, WV 26624',8149,222,NULL,57,11133,0);
INSERT INTO "django_geo_db_location" VALUES(19576,NULL,'Heaters, WV',8150,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19577,NULL,'Heaters, WV 26627',8150,222,NULL,57,11134,0);
INSERT INTO "django_geo_db_location" VALUES(19578,NULL,'Little Birch, WV',8151,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19579,NULL,'Little Birch, WV 26629',8151,222,NULL,57,11135,0);
INSERT INTO "django_geo_db_location" VALUES(19580,NULL,'Bridgeport, WV 26630',8035,222,NULL,57,11136,0);
INSERT INTO "django_geo_db_location" VALUES(19581,NULL,'Napier, WV',8152,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19582,NULL,'Napier, WV 26631',8152,222,NULL,57,11137,0);
INSERT INTO "django_geo_db_location" VALUES(19583,NULL,'Perkins, WV',8153,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19584,NULL,'Perkins, WV 26634',8153,222,NULL,57,11138,0);
INSERT INTO "django_geo_db_location" VALUES(19585,NULL,'Rosedale, WV',8154,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19586,NULL,'Rosedale, WV 26636',8154,222,NULL,57,11139,0);
INSERT INTO "django_geo_db_location" VALUES(19587,NULL,'Shock, WV',8155,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19588,NULL,'Shock, WV 26638',8155,222,NULL,57,11140,0);
INSERT INTO "django_geo_db_location" VALUES(19589,NULL,'Strange Creek, WV',8156,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19590,NULL,'Strange Creek, WV 26639',8156,222,NULL,57,11141,0);
INSERT INTO "django_geo_db_location" VALUES(19591,NULL,'Wilsie, WV',8157,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19592,NULL,'Wilsie, WV 26641',8157,222,NULL,57,11142,0);
INSERT INTO "django_geo_db_location" VALUES(19593,NULL,'Summersville, WV',8158,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19594,NULL,'Summersville, WV 26651',8158,222,NULL,57,11143,0);
INSERT INTO "django_geo_db_location" VALUES(19595,NULL,'Belva, WV',8159,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19596,NULL,'Belva, WV 26656',8159,222,NULL,57,11144,0);
INSERT INTO "django_geo_db_location" VALUES(19597,NULL,'Calvin, WV',8160,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19598,NULL,'Calvin, WV 26660',8160,222,NULL,57,11145,0);
INSERT INTO "django_geo_db_location" VALUES(19599,NULL,'Canvas, WV',8161,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19600,NULL,'Canvas, WV 26662',8161,222,NULL,57,11146,0);
INSERT INTO "django_geo_db_location" VALUES(19601,NULL,'Drennen, WV',8162,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19602,NULL,'Drennen, WV 26667',8162,222,NULL,57,11147,0);
INSERT INTO "django_geo_db_location" VALUES(19603,NULL,'Gilboa, WV',8163,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19604,NULL,'Gilboa, WV 26671',8163,222,NULL,57,11148,0);
INSERT INTO "django_geo_db_location" VALUES(19605,NULL,'Jodie, WV',8164,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19606,NULL,'Jodie, WV 26674',8164,222,NULL,57,11149,0);
INSERT INTO "django_geo_db_location" VALUES(19607,NULL,'Keslers Cross Lanes, WV',8165,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19608,NULL,'Keslers Cross Lanes, WV 26675',8165,222,NULL,57,11150,0);
INSERT INTO "django_geo_db_location" VALUES(19609,NULL,'Leivasy, WV',8166,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19610,NULL,'Leivasy, WV 26676',8166,222,NULL,57,11151,0);
INSERT INTO "django_geo_db_location" VALUES(19611,NULL,'Mount Lookout, WV',8167,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19612,NULL,'Mount Lookout, WV 26678',8167,222,NULL,57,11152,0);
INSERT INTO "django_geo_db_location" VALUES(19613,NULL,'Mount Nebo, WV',8168,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19614,NULL,'Mount Nebo, WV 26679',8168,222,NULL,57,11153,0);
INSERT INTO "django_geo_db_location" VALUES(19615,NULL,'Nallen, WV',8169,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19616,NULL,'Nallen, WV 26680',8169,222,NULL,57,11154,0);
INSERT INTO "django_geo_db_location" VALUES(19617,NULL,'Nettie, WV',8170,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19618,NULL,'Nettie, WV 26681',8170,222,NULL,57,11155,0);
INSERT INTO "django_geo_db_location" VALUES(19619,NULL,'Pool, WV',8171,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19620,NULL,'Pool, WV 26684',8171,222,NULL,57,11156,0);
INSERT INTO "django_geo_db_location" VALUES(19621,NULL,'Swiss, WV',8172,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19622,NULL,'Swiss, WV 26690',8172,222,NULL,57,11157,0);
INSERT INTO "django_geo_db_location" VALUES(19623,NULL,'Tioga, WV',8173,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19624,NULL,'Tioga, WV 26691',8173,222,NULL,57,11158,0);
INSERT INTO "django_geo_db_location" VALUES(19625,NULL,'Augusta, WV',8174,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19626,NULL,'Augusta, WV 26704',8174,222,NULL,57,11159,0);
INSERT INTO "django_geo_db_location" VALUES(19627,NULL,'Aurora, WV',8175,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19628,NULL,'Aurora, WV 26705',8175,222,NULL,57,11160,0);
INSERT INTO "django_geo_db_location" VALUES(19629,NULL,'Bayard, WV',8176,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19630,NULL,'Bayard, WV 26707',8176,222,NULL,57,11161,0);
INSERT INTO "django_geo_db_location" VALUES(19631,NULL,'Burlington, WV',8177,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19632,NULL,'Burlington, WV 26710',8177,222,NULL,57,11162,0);
INSERT INTO "django_geo_db_location" VALUES(19633,NULL,'Capon Bridge, WV',8178,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19634,NULL,'Capon Bridge, WV 26711',8178,222,NULL,57,11163,0);
INSERT INTO "django_geo_db_location" VALUES(19635,NULL,'Delray, WV',8179,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19636,NULL,'Delray, WV 26714',8179,222,NULL,57,11164,0);
INSERT INTO "django_geo_db_location" VALUES(19637,NULL,'Eglon, WV',8180,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19638,NULL,'Eglon, WV 26716',8180,222,NULL,57,11165,0);
INSERT INTO "django_geo_db_location" VALUES(19639,NULL,'Elk Garden, WV',8181,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19640,NULL,'Elk Garden, WV 26717',8181,222,NULL,57,11166,0);
INSERT INTO "django_geo_db_location" VALUES(19641,NULL,'Fort Ashby, WV',8182,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19642,NULL,'Fort Ashby, WV 26719',8182,222,NULL,57,11167,0);
INSERT INTO "django_geo_db_location" VALUES(19643,NULL,'Gormania, WV',8183,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19644,NULL,'Gormania, WV 26720',8183,222,NULL,57,11168,0);
INSERT INTO "django_geo_db_location" VALUES(19645,NULL,'Green Spring, WV',8184,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19646,NULL,'Green Spring, WV 26722',8184,222,NULL,57,11169,0);
INSERT INTO "django_geo_db_location" VALUES(19647,NULL,'Keyser, WV',8185,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19648,NULL,'Keyser, WV 26726',8185,222,NULL,57,11170,0);
INSERT INTO "django_geo_db_location" VALUES(19649,NULL,'Lahmansville, WV',8186,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19650,NULL,'Lahmansville, WV 26731',8186,222,NULL,57,11171,0);
INSERT INTO "django_geo_db_location" VALUES(19651,NULL,'Medley, WV',8187,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19652,NULL,'Medley, WV 26734',8187,222,NULL,57,11172,0);
INSERT INTO "django_geo_db_location" VALUES(19653,NULL,'Mount Storm, WV',8188,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19654,NULL,'Mount Storm, WV 26739',8188,222,NULL,57,11173,0);
INSERT INTO "django_geo_db_location" VALUES(19655,NULL,'New Creek, WV',8189,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19656,NULL,'New Creek, WV 26743',8189,222,NULL,57,11174,0);
INSERT INTO "django_geo_db_location" VALUES(19657,NULL,'Piedmont, WV',8190,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19658,NULL,'Piedmont, WV 26750',8190,222,NULL,57,11175,0);
INSERT INTO "django_geo_db_location" VALUES(19659,NULL,'Ridgeley, WV',8191,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19660,NULL,'Ridgeley, WV 26753',8191,222,NULL,57,11176,0);
INSERT INTO "django_geo_db_location" VALUES(19661,NULL,'Rio, WV',8192,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19662,NULL,'Rio, WV 26755',8192,222,NULL,57,11177,0);
INSERT INTO "django_geo_db_location" VALUES(19663,NULL,'Romney, WV',8193,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19664,NULL,'Romney, WV 26757',8193,222,NULL,57,11178,0);
INSERT INTO "django_geo_db_location" VALUES(19665,NULL,'Shanks, WV',8194,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19666,NULL,'Shanks, WV 26761',8194,222,NULL,57,11179,0);
INSERT INTO "django_geo_db_location" VALUES(19667,NULL,'Springfield, WV',8195,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19668,NULL,'Springfield, WV 26763',8195,222,NULL,57,11180,0);
INSERT INTO "django_geo_db_location" VALUES(19669,NULL,'Terra Alta, WV',8196,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19670,NULL,'Terra Alta, WV 26764',8196,222,NULL,57,11181,0);
INSERT INTO "django_geo_db_location" VALUES(19671,NULL,'Wiley Ford, WV',8197,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19672,NULL,'Wiley Ford, WV 26767',8197,222,NULL,57,11182,0);
INSERT INTO "django_geo_db_location" VALUES(19673,NULL,'Baker, WV',8198,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19674,NULL,'Baker, WV 26801',8198,222,NULL,57,11183,0);
INSERT INTO "django_geo_db_location" VALUES(19675,NULL,'Brandywine, WV',8199,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19676,NULL,'Brandywine, WV 26802',8199,222,NULL,57,11184,0);
INSERT INTO "django_geo_db_location" VALUES(19677,NULL,'Circleville, WV',8200,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19678,NULL,'Circleville, WV 26804',8200,222,NULL,57,11185,0);
INSERT INTO "django_geo_db_location" VALUES(19679,NULL,'Franklin, WV',8201,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19680,NULL,'Franklin, WV 26807',8201,222,NULL,57,11186,0);
INSERT INTO "django_geo_db_location" VALUES(19681,NULL,'High View, WV',8202,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19682,NULL,'High View, WV 26808',8202,222,NULL,57,11187,0);
INSERT INTO "django_geo_db_location" VALUES(19683,NULL,'Lost City, WV',8203,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19684,NULL,'Lost City, WV 26810',8203,222,NULL,57,11188,0);
INSERT INTO "django_geo_db_location" VALUES(19685,NULL,'Mathias, WV',8204,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19686,NULL,'Mathias, WV 26812',8204,222,NULL,57,11189,0);
INSERT INTO "django_geo_db_location" VALUES(19687,NULL,'Riverton, WV',8205,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19688,NULL,'Riverton, WV 26814',8205,222,NULL,57,11190,0);
INSERT INTO "django_geo_db_location" VALUES(19689,NULL,'Sugar Grove, WV',8206,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19690,NULL,'Sugar Grove, WV 26815',8206,222,NULL,57,11191,0);
INSERT INTO "django_geo_db_location" VALUES(19691,NULL,'Bloomery, WV',8207,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19692,NULL,'Bloomery, WV 26817',8207,222,NULL,57,11192,0);
INSERT INTO "django_geo_db_location" VALUES(19693,NULL,'Fisher, WV',8208,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19694,NULL,'Fisher, WV 26818',8208,222,NULL,57,11193,0);
INSERT INTO "django_geo_db_location" VALUES(19695,NULL,'Capon Springs, WV',8209,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19696,NULL,'Capon Springs, WV 26823',8209,222,NULL,57,11194,0);
INSERT INTO "django_geo_db_location" VALUES(19697,NULL,'Junction, WV',8210,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19698,NULL,'Junction, WV 26824',8210,222,NULL,57,11195,0);
INSERT INTO "django_geo_db_location" VALUES(19699,NULL,'Maysville, WV',8211,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19700,NULL,'Maysville, WV 26833',8211,222,NULL,57,11196,0);
INSERT INTO "django_geo_db_location" VALUES(19701,NULL,'Moorefield, WV',8212,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19702,NULL,'Moorefield, WV 26836',8212,222,NULL,57,11197,0);
INSERT INTO "django_geo_db_location" VALUES(19703,NULL,'Milam, WV',8213,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19704,NULL,'Milam, WV 26838',8213,222,NULL,57,11198,0);
INSERT INTO "django_geo_db_location" VALUES(19705,NULL,'Old Fields, WV',8214,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19706,NULL,'Old Fields, WV 26845',8214,222,NULL,57,11199,0);
INSERT INTO "django_geo_db_location" VALUES(19707,NULL,'Petersburg, WV',8215,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19708,NULL,'Petersburg, WV 26847',8215,222,NULL,57,11200,0);
INSERT INTO "django_geo_db_location" VALUES(19709,NULL,'Wardensville, WV',8216,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19710,NULL,'Wardensville, WV 26851',8216,222,NULL,57,11201,0);
INSERT INTO "django_geo_db_location" VALUES(19711,NULL,'Purgitsville, WV',8217,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19712,NULL,'Purgitsville, WV 26852',8217,222,NULL,57,11202,0);
INSERT INTO "django_geo_db_location" VALUES(19713,NULL,'Cabins, WV',8218,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19714,NULL,'Cabins, WV 26855',8218,222,NULL,57,11203,0);
INSERT INTO "django_geo_db_location" VALUES(19715,NULL,'Yellow Spring, WV',8219,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19716,NULL,'Yellow Spring, WV 26865',8219,222,NULL,57,11204,0);
INSERT INTO "django_geo_db_location" VALUES(19717,NULL,'Upper Tract, WV',8220,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19718,NULL,'Upper Tract, WV 26866',8220,222,NULL,57,11205,0);
INSERT INTO "django_geo_db_location" VALUES(19719,NULL,'Seneca Rocks, WV',8221,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19720,NULL,'Seneca Rocks, WV 26884',8221,222,NULL,57,11206,0);
INSERT INTO "django_geo_db_location" VALUES(19721,NULL,'Onego, WV',8222,222,NULL,57,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19722,NULL,'Onego, WV 26886',8222,222,NULL,57,11207,0);
INSERT INTO "django_geo_db_location" VALUES(19723,NULL,'Morgantown, WV 26905',8095,222,NULL,57,11208,0);
INSERT INTO "django_geo_db_location" VALUES(19724,NULL,'Advance, NC',8223,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19725,NULL,'Advance, NC 27006',8223,222,NULL,33,11209,0);
INSERT INTO "django_geo_db_location" VALUES(19726,NULL,'Ararat, NC',8224,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19727,NULL,'Ararat, NC 27007',8224,222,NULL,33,11210,0);
INSERT INTO "django_geo_db_location" VALUES(19728,NULL,'Belews Creek, NC',8225,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19729,NULL,'Belews Creek, NC 27009',8225,222,NULL,33,11211,0);
INSERT INTO "django_geo_db_location" VALUES(19730,NULL,'Bethania, NC',8226,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19731,NULL,'Bethania, NC 27010',8226,222,NULL,33,11212,0);
INSERT INTO "django_geo_db_location" VALUES(19732,NULL,'Boonville, NC',8227,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19733,NULL,'Boonville, NC 27011',8227,222,NULL,33,11213,0);
INSERT INTO "django_geo_db_location" VALUES(19734,NULL,'Clemmons, NC',8228,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19735,NULL,'Clemmons, NC 27012',8228,222,NULL,33,11214,0);
INSERT INTO "django_geo_db_location" VALUES(19736,NULL,'Cleveland, NC',8229,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19737,NULL,'Cleveland, NC 27013',8229,222,NULL,33,11215,0);
INSERT INTO "django_geo_db_location" VALUES(19738,NULL,'Cooleemee, NC',8230,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19739,NULL,'Cooleemee, NC 27014',8230,222,NULL,33,11216,0);
INSERT INTO "django_geo_db_location" VALUES(19740,NULL,'Danbury, NC',8231,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19741,NULL,'Danbury, NC 27016',8231,222,NULL,33,11217,0);
INSERT INTO "django_geo_db_location" VALUES(19742,NULL,'Dobson, NC',8232,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19743,NULL,'Dobson, NC 27017',8232,222,NULL,33,11218,0);
INSERT INTO "django_geo_db_location" VALUES(19744,NULL,'East Bend, NC',8233,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19745,NULL,'East Bend, NC 27018',8233,222,NULL,33,11219,0);
INSERT INTO "django_geo_db_location" VALUES(19746,NULL,'Germanton, NC',8234,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19747,NULL,'Germanton, NC 27019',8234,222,NULL,33,11220,0);
INSERT INTO "django_geo_db_location" VALUES(19748,NULL,'Hamptonville, NC',8235,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19749,NULL,'Hamptonville, NC 27020',8235,222,NULL,33,11221,0);
INSERT INTO "django_geo_db_location" VALUES(19750,NULL,'King, NC',8236,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19751,NULL,'King, NC 27021',8236,222,NULL,33,11222,0);
INSERT INTO "django_geo_db_location" VALUES(19752,NULL,'Lawsonville, NC',8237,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19753,NULL,'Lawsonville, NC 27022',8237,222,NULL,33,11223,0);
INSERT INTO "django_geo_db_location" VALUES(19754,NULL,'Lewisville, NC',8238,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19755,NULL,'Lewisville, NC 27023',8238,222,NULL,33,11224,0);
INSERT INTO "django_geo_db_location" VALUES(19756,NULL,'Lowgap, NC',8239,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19757,NULL,'Lowgap, NC 27024',8239,222,NULL,33,11225,0);
INSERT INTO "django_geo_db_location" VALUES(19758,NULL,'Madison, NC',8240,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19759,NULL,'Madison, NC 27025',8240,222,NULL,33,11226,0);
INSERT INTO "django_geo_db_location" VALUES(19760,NULL,'Mayodan, NC',8241,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19761,NULL,'Mayodan, NC 27027',8241,222,NULL,33,11227,0);
INSERT INTO "django_geo_db_location" VALUES(19762,NULL,'Mocksville, NC',8242,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19763,NULL,'Mocksville, NC 27028',8242,222,NULL,33,11228,0);
INSERT INTO "django_geo_db_location" VALUES(19764,NULL,'Mount Airy, NC',8243,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19765,NULL,'Mount Airy, NC 27030',8243,222,NULL,33,11229,0);
INSERT INTO "django_geo_db_location" VALUES(19766,NULL,'White Plains, NC',8244,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19767,NULL,'White Plains, NC 27031',8244,222,NULL,33,11230,0);
INSERT INTO "django_geo_db_location" VALUES(19768,NULL,'Pfafftown, NC',8245,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19769,NULL,'Pfafftown, NC 27040',8245,222,NULL,33,11231,0);
INSERT INTO "django_geo_db_location" VALUES(19770,NULL,'Pilot Mountain, NC',8246,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19771,NULL,'Pilot Mountain, NC 27041',8246,222,NULL,33,11232,0);
INSERT INTO "django_geo_db_location" VALUES(19772,NULL,'Pine Hall, NC',8247,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19773,NULL,'Pine Hall, NC 27042',8247,222,NULL,33,11233,0);
INSERT INTO "django_geo_db_location" VALUES(19774,NULL,'Pinnacle, NC',8248,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19775,NULL,'Pinnacle, NC 27043',8248,222,NULL,33,11234,0);
INSERT INTO "django_geo_db_location" VALUES(19776,NULL,'Rural Hall, NC',8249,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19777,NULL,'Rural Hall, NC 27045',8249,222,NULL,33,11235,0);
INSERT INTO "django_geo_db_location" VALUES(19778,NULL,'Sandy Ridge, NC',8250,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19779,NULL,'Sandy Ridge, NC 27046',8250,222,NULL,33,11236,0);
INSERT INTO "django_geo_db_location" VALUES(19780,NULL,'Siloam, NC',8251,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19781,NULL,'Siloam, NC 27047',8251,222,NULL,33,11237,0);
INSERT INTO "django_geo_db_location" VALUES(19782,NULL,'Stoneville, NC',8252,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19783,NULL,'Stoneville, NC 27048',8252,222,NULL,33,11238,0);
INSERT INTO "django_geo_db_location" VALUES(19784,NULL,'Toast, NC',8253,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19785,NULL,'Toast, NC 27049',8253,222,NULL,33,11239,0);
INSERT INTO "django_geo_db_location" VALUES(19786,NULL,'Tobaccoville, NC',8254,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19787,NULL,'Tobaccoville, NC 27050',8254,222,NULL,33,11240,0);
INSERT INTO "django_geo_db_location" VALUES(19788,NULL,'Walkertown, NC',8255,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19789,NULL,'Walkertown, NC 27051',8255,222,NULL,33,11241,0);
INSERT INTO "django_geo_db_location" VALUES(19790,NULL,'Walnut Cove, NC',8256,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19791,NULL,'Walnut Cove, NC 27052',8256,222,NULL,33,11242,0);
INSERT INTO "django_geo_db_location" VALUES(19792,NULL,'Westfield, NC',8257,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19793,NULL,'Westfield, NC 27053',8257,222,NULL,33,11243,0);
INSERT INTO "django_geo_db_location" VALUES(19794,NULL,'Woodleaf, NC',8258,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19795,NULL,'Woodleaf, NC 27054',8258,222,NULL,33,11244,0);
INSERT INTO "django_geo_db_location" VALUES(19796,NULL,'Yadkinville, NC',8259,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19797,NULL,'Yadkinville, NC 27055',8259,222,NULL,33,11245,0);
INSERT INTO "django_geo_db_location" VALUES(19798,NULL,'Rural Hall, NC 27094',8249,222,NULL,33,11246,0);
INSERT INTO "django_geo_db_location" VALUES(19799,NULL,'Rural Hall, NC 27098',8249,222,NULL,33,11247,0);
INSERT INTO "django_geo_db_location" VALUES(19800,NULL,'Rural Hall, NC 27099',8249,222,NULL,33,11248,0);
INSERT INTO "django_geo_db_location" VALUES(19801,NULL,'Winston Salem, NC',8260,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19802,NULL,'Winston Salem, NC 27101',8260,222,NULL,33,11249,0);
INSERT INTO "django_geo_db_location" VALUES(19803,NULL,'Winston Salem, NC 27102',8260,222,NULL,33,11250,0);
INSERT INTO "django_geo_db_location" VALUES(19804,NULL,'Winston Salem, NC 27103',8260,222,NULL,33,11251,0);
INSERT INTO "django_geo_db_location" VALUES(19805,NULL,'Winston Salem, NC 27104',8260,222,NULL,33,11252,0);
INSERT INTO "django_geo_db_location" VALUES(19806,NULL,'Winston Salem, NC 27105',8260,222,NULL,33,11253,0);
INSERT INTO "django_geo_db_location" VALUES(19807,NULL,'Winston Salem, NC 27106',8260,222,NULL,33,11254,0);
INSERT INTO "django_geo_db_location" VALUES(19808,NULL,'Winston Salem, NC 27107',8260,222,NULL,33,11255,0);
INSERT INTO "django_geo_db_location" VALUES(19809,NULL,'Winston Salem, NC 27108',8260,222,NULL,33,11256,0);
INSERT INTO "django_geo_db_location" VALUES(19810,NULL,'Winston Salem, NC 27109',8260,222,NULL,33,11257,0);
INSERT INTO "django_geo_db_location" VALUES(19811,NULL,'Winston Salem, NC 27110',8260,222,NULL,33,11258,0);
INSERT INTO "django_geo_db_location" VALUES(19812,NULL,'Winston Salem, NC 27111',8260,222,NULL,33,11259,0);
INSERT INTO "django_geo_db_location" VALUES(19813,NULL,'Winston Salem, NC 27113',8260,222,NULL,33,11260,0);
INSERT INTO "django_geo_db_location" VALUES(19814,NULL,'Winston Salem, NC 27114',8260,222,NULL,33,11261,0);
INSERT INTO "django_geo_db_location" VALUES(19815,NULL,'Winston Salem, NC 27115',8260,222,NULL,33,11262,0);
INSERT INTO "django_geo_db_location" VALUES(19816,NULL,'Winston Salem, NC 27116',8260,222,NULL,33,11263,0);
INSERT INTO "django_geo_db_location" VALUES(19817,NULL,'Winston Salem, NC 27117',8260,222,NULL,33,11264,0);
INSERT INTO "django_geo_db_location" VALUES(19818,NULL,'Winston Salem, NC 27120',8260,222,NULL,33,11265,0);
INSERT INTO "django_geo_db_location" VALUES(19819,NULL,'Winston Salem, NC 27127',8260,222,NULL,33,11266,0);
INSERT INTO "django_geo_db_location" VALUES(19820,NULL,'Winston Salem, NC 27130',8260,222,NULL,33,11267,0);
INSERT INTO "django_geo_db_location" VALUES(19821,NULL,'Salisbury, NC',8261,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19822,NULL,'Salisbury, NC 27144',8261,222,NULL,33,11268,0);
INSERT INTO "django_geo_db_location" VALUES(19823,NULL,'Winston Salem, NC 27150',8260,222,NULL,33,11269,0);
INSERT INTO "django_geo_db_location" VALUES(19824,NULL,'Winston Salem, NC 27151',8260,222,NULL,33,11270,0);
INSERT INTO "django_geo_db_location" VALUES(19825,NULL,'Winston Salem, NC 27152',8260,222,NULL,33,11271,0);
INSERT INTO "django_geo_db_location" VALUES(19826,NULL,'Winston Salem, NC 27155',8260,222,NULL,33,11272,0);
INSERT INTO "django_geo_db_location" VALUES(19827,NULL,'Winston Salem, NC 27156',8260,222,NULL,33,11273,0);
INSERT INTO "django_geo_db_location" VALUES(19828,NULL,'Winston Salem, NC 27157',8260,222,NULL,33,11274,0);
INSERT INTO "django_geo_db_location" VALUES(19829,NULL,'Winston Salem, NC 27198',8260,222,NULL,33,11275,0);
INSERT INTO "django_geo_db_location" VALUES(19830,NULL,'Winston Salem, NC 27199',8260,222,NULL,33,11276,0);
INSERT INTO "django_geo_db_location" VALUES(19831,NULL,'Alamance, NC',8262,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19832,NULL,'Alamance, NC 27201',8262,222,NULL,33,11277,0);
INSERT INTO "django_geo_db_location" VALUES(19833,NULL,'Altamahaw, NC',8263,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19834,NULL,'Altamahaw, NC 27202',8263,222,NULL,33,11278,0);
INSERT INTO "django_geo_db_location" VALUES(19835,NULL,'Asheboro, NC',8264,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19836,NULL,'Asheboro, NC 27203',8264,222,NULL,33,11279,0);
INSERT INTO "django_geo_db_location" VALUES(19837,NULL,'Asheboro, NC 27204',8264,222,NULL,33,11280,0);
INSERT INTO "django_geo_db_location" VALUES(19838,NULL,'Asheboro, NC 27205',8264,222,NULL,33,11281,0);
INSERT INTO "django_geo_db_location" VALUES(19839,NULL,'Bear Creek, NC',8265,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19840,NULL,'Bear Creek, NC 27207',8265,222,NULL,33,11282,0);
INSERT INTO "django_geo_db_location" VALUES(19841,NULL,'Bennett, NC',8266,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19842,NULL,'Bennett, NC 27208',8266,222,NULL,33,11283,0);
INSERT INTO "django_geo_db_location" VALUES(19843,NULL,'Biscoe, NC',8267,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19844,NULL,'Biscoe, NC 27209',8267,222,NULL,33,11284,0);
INSERT INTO "django_geo_db_location" VALUES(19845,NULL,'Blanch, NC',8268,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19846,NULL,'Blanch, NC 27212',8268,222,NULL,33,11285,0);
INSERT INTO "django_geo_db_location" VALUES(19847,NULL,'Bonlee, NC',8269,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19848,NULL,'Bonlee, NC 27213',8269,222,NULL,33,11286,0);
INSERT INTO "django_geo_db_location" VALUES(19849,NULL,'Browns Summit, NC',8270,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19850,NULL,'Browns Summit, NC 27214',8270,222,NULL,33,11287,0);
INSERT INTO "django_geo_db_location" VALUES(19851,NULL,'Burlington, NC',8271,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19852,NULL,'Burlington, NC 27215',8271,222,NULL,33,11288,0);
INSERT INTO "django_geo_db_location" VALUES(19853,NULL,'Burlington, NC 27216',8271,222,NULL,33,11289,0);
INSERT INTO "django_geo_db_location" VALUES(19854,NULL,'Burlington, NC 27217',8271,222,NULL,33,11290,0);
INSERT INTO "django_geo_db_location" VALUES(19855,NULL,'Burlington, NC 27220',8271,222,NULL,33,11291,0);
INSERT INTO "django_geo_db_location" VALUES(19856,NULL,'Bynum, NC',8272,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19857,NULL,'Bynum, NC 27228',8272,222,NULL,33,11292,0);
INSERT INTO "django_geo_db_location" VALUES(19858,NULL,'Candor, NC',8273,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19859,NULL,'Candor, NC 27229',8273,222,NULL,33,11293,0);
INSERT INTO "django_geo_db_location" VALUES(19860,NULL,'Cedar Falls, NC',8274,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19861,NULL,'Cedar Falls, NC 27230',8274,222,NULL,33,11294,0);
INSERT INTO "django_geo_db_location" VALUES(19862,NULL,'Cedar Grove, NC',8275,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19863,NULL,'Cedar Grove, NC 27231',8275,222,NULL,33,11295,0);
INSERT INTO "django_geo_db_location" VALUES(19864,NULL,'Climax, NC',8276,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19865,NULL,'Climax, NC 27233',8276,222,NULL,33,11296,0);
INSERT INTO "django_geo_db_location" VALUES(19866,NULL,'Colfax, NC',8277,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19867,NULL,'Colfax, NC 27235',8277,222,NULL,33,11297,0);
INSERT INTO "django_geo_db_location" VALUES(19868,NULL,'Cumnock, NC',8278,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19869,NULL,'Cumnock, NC 27237',8278,222,NULL,33,11298,0);
INSERT INTO "django_geo_db_location" VALUES(19870,NULL,'Denton, NC',8279,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19871,NULL,'Denton, NC 27239',8279,222,NULL,33,11299,0);
INSERT INTO "django_geo_db_location" VALUES(19872,NULL,'Eagle Springs, NC',8280,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19873,NULL,'Eagle Springs, NC 27242',8280,222,NULL,33,11300,0);
INSERT INTO "django_geo_db_location" VALUES(19874,NULL,'Efland, NC',8281,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19875,NULL,'Efland, NC 27243',8281,222,NULL,33,11301,0);
INSERT INTO "django_geo_db_location" VALUES(19876,NULL,'Elon College, NC',8282,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19877,NULL,'Elon College, NC 27244',8282,222,NULL,33,11302,0);
INSERT INTO "django_geo_db_location" VALUES(19878,NULL,'Ether, NC',8283,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19879,NULL,'Ether, NC 27247',8283,222,NULL,33,11303,0);
INSERT INTO "django_geo_db_location" VALUES(19880,NULL,'Franklinville, NC',8284,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19881,NULL,'Franklinville, NC 27248',8284,222,NULL,33,11304,0);
INSERT INTO "django_geo_db_location" VALUES(19882,NULL,'Gibsonville, NC',8285,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19883,NULL,'Gibsonville, NC 27249',8285,222,NULL,33,11305,0);
INSERT INTO "django_geo_db_location" VALUES(19884,NULL,'Goldston, NC',8286,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19885,NULL,'Goldston, NC 27252',8286,222,NULL,33,11306,0);
INSERT INTO "django_geo_db_location" VALUES(19886,NULL,'Graham, NC',8287,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19887,NULL,'Graham, NC 27253',8287,222,NULL,33,11307,0);
INSERT INTO "django_geo_db_location" VALUES(19888,NULL,'Gulf, NC',8288,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19889,NULL,'Gulf, NC 27256',8288,222,NULL,33,11308,0);
INSERT INTO "django_geo_db_location" VALUES(19890,NULL,'Haw River, NC',8289,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19891,NULL,'Haw River, NC 27258',8289,222,NULL,33,11309,0);
INSERT INTO "django_geo_db_location" VALUES(19892,NULL,'Highfalls, NC',8290,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19893,NULL,'Highfalls, NC 27259',8290,222,NULL,33,11310,0);
INSERT INTO "django_geo_db_location" VALUES(19894,NULL,'High Point, NC',8291,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19895,NULL,'High Point, NC 27260',8291,222,NULL,33,11311,0);
INSERT INTO "django_geo_db_location" VALUES(19896,NULL,'High Point, NC 27261',8291,222,NULL,33,11312,0);
INSERT INTO "django_geo_db_location" VALUES(19897,NULL,'High Point, NC 27262',8291,222,NULL,33,11313,0);
INSERT INTO "django_geo_db_location" VALUES(19898,NULL,'High Point, NC 27263',8291,222,NULL,33,11314,0);
INSERT INTO "django_geo_db_location" VALUES(19899,NULL,'High Point, NC 27264',8291,222,NULL,33,11315,0);
INSERT INTO "django_geo_db_location" VALUES(19900,NULL,'High Point, NC 27265',8291,222,NULL,33,11316,0);
INSERT INTO "django_geo_db_location" VALUES(19901,NULL,'Hillsborough, NC',8292,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19902,NULL,'Hillsborough, NC 27278',8292,222,NULL,33,11317,0);
INSERT INTO "django_geo_db_location" VALUES(19903,NULL,'Jackson Springs, NC',8293,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19904,NULL,'Jackson Springs, NC 27281',8293,222,NULL,33,11318,0);
INSERT INTO "django_geo_db_location" VALUES(19905,NULL,'Jamestown, NC',8294,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19906,NULL,'Jamestown, NC 27282',8294,222,NULL,33,11319,0);
INSERT INTO "django_geo_db_location" VALUES(19907,NULL,'Julian, NC',8295,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19908,NULL,'Julian, NC 27283',8295,222,NULL,33,11320,0);
INSERT INTO "django_geo_db_location" VALUES(19909,NULL,'Kernersville, NC',8296,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19910,NULL,'Kernersville, NC 27284',8296,222,NULL,33,11321,0);
INSERT INTO "django_geo_db_location" VALUES(19911,NULL,'Kernersville, NC 27285',8296,222,NULL,33,11322,0);
INSERT INTO "django_geo_db_location" VALUES(19912,NULL,'Eden, NC',8297,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19913,NULL,'Eden, NC 27288',8297,222,NULL,33,11323,0);
INSERT INTO "django_geo_db_location" VALUES(19914,NULL,'Eden, NC 27289',8297,222,NULL,33,11324,0);
INSERT INTO "django_geo_db_location" VALUES(19915,NULL,'Leasburg, NC',8298,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19916,NULL,'Leasburg, NC 27291',8298,222,NULL,33,11325,0);
INSERT INTO "django_geo_db_location" VALUES(19917,NULL,'Lexington, NC',8299,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19918,NULL,'Lexington, NC 27292',8299,222,NULL,33,11326,0);
INSERT INTO "django_geo_db_location" VALUES(19919,NULL,'Lexington, NC 27293',8299,222,NULL,33,11327,0);
INSERT INTO "django_geo_db_location" VALUES(19920,NULL,'Lexington, NC 27294',8299,222,NULL,33,11328,0);
INSERT INTO "django_geo_db_location" VALUES(19921,NULL,'Lexington, NC 27295',8299,222,NULL,33,11329,0);
INSERT INTO "django_geo_db_location" VALUES(19922,NULL,'Liberty, NC',8300,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19923,NULL,'Liberty, NC 27298',8300,222,NULL,33,11330,0);
INSERT INTO "django_geo_db_location" VALUES(19924,NULL,'Linwood, NC',8301,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19925,NULL,'Linwood, NC 27299',8301,222,NULL,33,11331,0);
INSERT INTO "django_geo_db_location" VALUES(19926,NULL,'McLeansville, NC',8302,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19927,NULL,'McLeansville, NC 27301',8302,222,NULL,33,11332,0);
INSERT INTO "django_geo_db_location" VALUES(19928,NULL,'Mebane, NC',8303,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19929,NULL,'Mebane, NC 27302',8303,222,NULL,33,11333,0);
INSERT INTO "django_geo_db_location" VALUES(19930,NULL,'Milton, NC',8304,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19931,NULL,'Milton, NC 27305',8304,222,NULL,33,11334,0);
INSERT INTO "django_geo_db_location" VALUES(19932,NULL,'Mount Gilead, NC',8305,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19933,NULL,'Mount Gilead, NC 27306',8305,222,NULL,33,11335,0);
INSERT INTO "django_geo_db_location" VALUES(19934,NULL,'Oak Ridge, NC',8306,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19935,NULL,'Oak Ridge, NC 27310',8306,222,NULL,33,11336,0);
INSERT INTO "django_geo_db_location" VALUES(19936,NULL,'Pelham, NC',8307,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19937,NULL,'Pelham, NC 27311',8307,222,NULL,33,11337,0);
INSERT INTO "django_geo_db_location" VALUES(19938,NULL,'Pittsboro, NC',8308,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19939,NULL,'Pittsboro, NC 27312',8308,222,NULL,33,11338,0);
INSERT INTO "django_geo_db_location" VALUES(19940,NULL,'Pleasant Garden, NC',8309,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19941,NULL,'Pleasant Garden, NC 27313',8309,222,NULL,33,11339,0);
INSERT INTO "django_geo_db_location" VALUES(19942,NULL,'Prospect Hill, NC',8310,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19943,NULL,'Prospect Hill, NC 27314',8310,222,NULL,33,11340,0);
INSERT INTO "django_geo_db_location" VALUES(19944,NULL,'Providence, NC',8311,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19945,NULL,'Providence, NC 27315',8311,222,NULL,33,11341,0);
INSERT INTO "django_geo_db_location" VALUES(19946,NULL,'Ramseur, NC',8312,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19947,NULL,'Ramseur, NC 27316',8312,222,NULL,33,11342,0);
INSERT INTO "django_geo_db_location" VALUES(19948,NULL,'Randleman, NC',8313,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19949,NULL,'Randleman, NC 27317',8313,222,NULL,33,11343,0);
INSERT INTO "django_geo_db_location" VALUES(19950,NULL,'Reidsville, NC',8314,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19951,NULL,'Reidsville, NC 27320',8314,222,NULL,33,11344,0);
INSERT INTO "django_geo_db_location" VALUES(19952,NULL,'Reidsville, NC 27321',8314,222,NULL,33,11345,0);
INSERT INTO "django_geo_db_location" VALUES(19953,NULL,'Reidsville, NC 27322',8314,222,NULL,33,11346,0);
INSERT INTO "django_geo_db_location" VALUES(19954,NULL,'Reidsville, NC 27323',8314,222,NULL,33,11347,0);
INSERT INTO "django_geo_db_location" VALUES(19955,NULL,'Robbins, NC',8315,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19956,NULL,'Robbins, NC 27325',8315,222,NULL,33,11348,0);
INSERT INTO "django_geo_db_location" VALUES(19957,NULL,'Ruffin, NC',8316,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19958,NULL,'Ruffin, NC 27326',8316,222,NULL,33,11349,0);
INSERT INTO "django_geo_db_location" VALUES(19959,NULL,'Sanford, NC',8317,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19960,NULL,'Sanford, NC 27330',8317,222,NULL,33,11350,0);
INSERT INTO "django_geo_db_location" VALUES(19961,NULL,'Sanford, NC 27331',8317,222,NULL,33,11351,0);
INSERT INTO "django_geo_db_location" VALUES(19962,NULL,'Sanford, NC 27332',8317,222,NULL,33,11352,0);
INSERT INTO "django_geo_db_location" VALUES(19963,NULL,'Saxapahaw, NC',8318,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19964,NULL,'Saxapahaw, NC 27340',8318,222,NULL,33,11353,0);
INSERT INTO "django_geo_db_location" VALUES(19965,NULL,'Seagrove, NC',8319,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19966,NULL,'Seagrove, NC 27341',8319,222,NULL,33,11354,0);
INSERT INTO "django_geo_db_location" VALUES(19967,NULL,'Sedalia, NC',8320,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19968,NULL,'Sedalia, NC 27342',8320,222,NULL,33,11355,0);
INSERT INTO "django_geo_db_location" VALUES(19969,NULL,'Semora, NC',8321,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19970,NULL,'Semora, NC 27343',8321,222,NULL,33,11356,0);
INSERT INTO "django_geo_db_location" VALUES(19971,NULL,'Siler City, NC',8322,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19972,NULL,'Siler City, NC 27344',8322,222,NULL,33,11357,0);
INSERT INTO "django_geo_db_location" VALUES(19973,NULL,'Snow Camp, NC',8323,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19974,NULL,'Snow Camp, NC 27349',8323,222,NULL,33,11358,0);
INSERT INTO "django_geo_db_location" VALUES(19975,NULL,'Sophia, NC',8324,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19976,NULL,'Sophia, NC 27350',8324,222,NULL,33,11359,0);
INSERT INTO "django_geo_db_location" VALUES(19977,NULL,'Southmont, NC',8325,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19978,NULL,'Southmont, NC 27351',8325,222,NULL,33,11360,0);
INSERT INTO "django_geo_db_location" VALUES(19979,NULL,'Staley, NC',8326,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19980,NULL,'Staley, NC 27355',8326,222,NULL,33,11361,0);
INSERT INTO "django_geo_db_location" VALUES(19981,NULL,'Star, NC',8327,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19982,NULL,'Star, NC 27356',8327,222,NULL,33,11362,0);
INSERT INTO "django_geo_db_location" VALUES(19983,NULL,'Stokesdale, NC',8328,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19984,NULL,'Stokesdale, NC 27357',8328,222,NULL,33,11363,0);
INSERT INTO "django_geo_db_location" VALUES(19985,NULL,'Summerfield, NC',8329,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19986,NULL,'Summerfield, NC 27358',8329,222,NULL,33,11364,0);
INSERT INTO "django_geo_db_location" VALUES(19987,NULL,'Swepsonville, NC',8330,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19988,NULL,'Swepsonville, NC 27359',8330,222,NULL,33,11365,0);
INSERT INTO "django_geo_db_location" VALUES(19989,NULL,'Thomasville, NC',8331,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19990,NULL,'Thomasville, NC 27360',8331,222,NULL,33,11366,0);
INSERT INTO "django_geo_db_location" VALUES(19991,NULL,'Thomasville, NC 27361',8331,222,NULL,33,11367,0);
INSERT INTO "django_geo_db_location" VALUES(19992,NULL,'Trinity, NC',8332,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19993,NULL,'Trinity, NC 27370',8332,222,NULL,33,11368,0);
INSERT INTO "django_geo_db_location" VALUES(19994,NULL,'Troy, NC',8333,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19995,NULL,'Troy, NC 27371',8333,222,NULL,33,11369,0);
INSERT INTO "django_geo_db_location" VALUES(19996,NULL,'Wallburg, NC',8334,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19997,NULL,'Wallburg, NC 27373',8334,222,NULL,33,11370,0);
INSERT INTO "django_geo_db_location" VALUES(19998,NULL,'Welcome, NC',8335,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(19999,NULL,'Welcome, NC 27374',8335,222,NULL,33,11371,0);
INSERT INTO "django_geo_db_location" VALUES(20000,NULL,'Wentworth, NC',8336,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20001,NULL,'Wentworth, NC 27375',8336,222,NULL,33,11372,0);
INSERT INTO "django_geo_db_location" VALUES(20002,NULL,'West End, NC',8337,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20003,NULL,'West End, NC 27376',8337,222,NULL,33,11373,0);
INSERT INTO "django_geo_db_location" VALUES(20004,NULL,'Whitsett, NC',8338,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20005,NULL,'Whitsett, NC 27377',8338,222,NULL,33,11374,0);
INSERT INTO "django_geo_db_location" VALUES(20006,NULL,'Yanceyville, NC',8339,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20007,NULL,'Yanceyville, NC 27379',8339,222,NULL,33,11375,0);
INSERT INTO "django_geo_db_location" VALUES(20008,NULL,'Troy, NC 27391',8333,222,NULL,33,11376,0);
INSERT INTO "django_geo_db_location" VALUES(20009,NULL,'Yanceyville, NC 27397',8339,222,NULL,33,11377,0);
INSERT INTO "django_geo_db_location" VALUES(20010,NULL,'Greensboro, NC',8340,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20011,NULL,'Greensboro, NC 27401',8340,222,NULL,33,11378,0);
INSERT INTO "django_geo_db_location" VALUES(20012,NULL,'Greensboro, NC 27402',8340,222,NULL,33,11379,0);
INSERT INTO "django_geo_db_location" VALUES(20013,NULL,'Greensboro, NC 27403',8340,222,NULL,33,11380,0);
INSERT INTO "django_geo_db_location" VALUES(20014,NULL,'Greensboro, NC 27404',8340,222,NULL,33,11381,0);
INSERT INTO "django_geo_db_location" VALUES(20015,NULL,'Greensboro, NC 27405',8340,222,NULL,33,11382,0);
INSERT INTO "django_geo_db_location" VALUES(20016,NULL,'Greensboro, NC 27406',8340,222,NULL,33,11383,0);
INSERT INTO "django_geo_db_location" VALUES(20017,NULL,'Greensboro, NC 27407',8340,222,NULL,33,11384,0);
INSERT INTO "django_geo_db_location" VALUES(20018,NULL,'Greensboro, NC 27408',8340,222,NULL,33,11385,0);
INSERT INTO "django_geo_db_location" VALUES(20019,NULL,'Greensboro, NC 27409',8340,222,NULL,33,11386,0);
INSERT INTO "django_geo_db_location" VALUES(20020,NULL,'Greensboro, NC 27410',8340,222,NULL,33,11387,0);
INSERT INTO "django_geo_db_location" VALUES(20021,NULL,'Greensboro, NC 27411',8340,222,NULL,33,11388,0);
INSERT INTO "django_geo_db_location" VALUES(20022,NULL,'Greensboro, NC 27412',8340,222,NULL,33,11389,0);
INSERT INTO "django_geo_db_location" VALUES(20023,NULL,'Greensboro, NC 27413',8340,222,NULL,33,11390,0);
INSERT INTO "django_geo_db_location" VALUES(20024,NULL,'Greensboro, NC 27415',8340,222,NULL,33,11391,0);
INSERT INTO "django_geo_db_location" VALUES(20025,NULL,'Greensboro, NC 27416',8340,222,NULL,33,11392,0);
INSERT INTO "django_geo_db_location" VALUES(20026,NULL,'Greensboro, NC 27417',8340,222,NULL,33,11393,0);
INSERT INTO "django_geo_db_location" VALUES(20027,NULL,'Greensboro, NC 27419',8340,222,NULL,33,11394,0);
INSERT INTO "django_geo_db_location" VALUES(20028,NULL,'Greensboro, NC 27420',8340,222,NULL,33,11395,0);
INSERT INTO "django_geo_db_location" VALUES(20029,NULL,'Greensboro, NC 27425',8340,222,NULL,33,11396,0);
INSERT INTO "django_geo_db_location" VALUES(20030,NULL,'Greensboro, NC 27427',8340,222,NULL,33,11397,0);
INSERT INTO "django_geo_db_location" VALUES(20031,NULL,'Greensboro, NC 27429',8340,222,NULL,33,11398,0);
INSERT INTO "django_geo_db_location" VALUES(20032,NULL,'Greensboro, NC 27435',8340,222,NULL,33,11399,0);
INSERT INTO "django_geo_db_location" VALUES(20033,NULL,'Greensboro, NC 27438',8340,222,NULL,33,11400,0);
INSERT INTO "django_geo_db_location" VALUES(20034,NULL,'Greensboro, NC 27455',8340,222,NULL,33,11401,0);
INSERT INTO "django_geo_db_location" VALUES(20035,NULL,'Greensboro, NC 27480',8340,222,NULL,33,11402,0);
INSERT INTO "django_geo_db_location" VALUES(20036,NULL,'Greensboro, NC 27495',8340,222,NULL,33,11403,0);
INSERT INTO "django_geo_db_location" VALUES(20037,NULL,'Greensboro, NC 27498',8340,222,NULL,33,11404,0);
INSERT INTO "django_geo_db_location" VALUES(20038,NULL,'Greensboro, NC 27499',8340,222,NULL,33,11405,0);
INSERT INTO "django_geo_db_location" VALUES(20039,NULL,'Angier, NC',8341,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20040,NULL,'Angier, NC 27501',8341,222,NULL,33,11406,0);
INSERT INTO "django_geo_db_location" VALUES(20041,NULL,'Apex, NC',8342,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20042,NULL,'Apex, NC 27502',8342,222,NULL,33,11407,0);
INSERT INTO "django_geo_db_location" VALUES(20043,NULL,'Bahama, NC',8343,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20044,NULL,'Bahama, NC 27503',8343,222,NULL,33,11408,0);
INSERT INTO "django_geo_db_location" VALUES(20045,NULL,'Benson, NC',8344,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20046,NULL,'Benson, NC 27504',8344,222,NULL,33,11409,0);
INSERT INTO "django_geo_db_location" VALUES(20047,NULL,'Broadway, NC',8345,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20048,NULL,'Broadway, NC 27505',8345,222,NULL,33,11410,0);
INSERT INTO "django_geo_db_location" VALUES(20049,NULL,'Buies Creek, NC',8346,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20050,NULL,'Buies Creek, NC 27506',8346,222,NULL,33,11411,0);
INSERT INTO "django_geo_db_location" VALUES(20051,NULL,'Bullock, NC',8347,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20052,NULL,'Bullock, NC 27507',8347,222,NULL,33,11412,0);
INSERT INTO "django_geo_db_location" VALUES(20053,NULL,'Bunn, NC',8348,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20054,NULL,'Bunn, NC 27508',8348,222,NULL,33,11413,0);
INSERT INTO "django_geo_db_location" VALUES(20055,NULL,'Butner, NC',8349,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20056,NULL,'Butner, NC 27509',8349,222,NULL,33,11414,0);
INSERT INTO "django_geo_db_location" VALUES(20057,NULL,'Carrboro, NC',8350,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20058,NULL,'Carrboro, NC 27510',8350,222,NULL,33,11415,0);
INSERT INTO "django_geo_db_location" VALUES(20059,NULL,'Cary, NC',8351,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20060,NULL,'Cary, NC 27511',8351,222,NULL,33,11416,0);
INSERT INTO "django_geo_db_location" VALUES(20061,NULL,'Cary, NC 27512',8351,222,NULL,33,11417,0);
INSERT INTO "django_geo_db_location" VALUES(20062,NULL,'Cary, NC 27513',8351,222,NULL,33,11418,0);
INSERT INTO "django_geo_db_location" VALUES(20063,NULL,'Chapel Hill, NC',8352,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20064,NULL,'Chapel Hill, NC 27514',8352,222,NULL,33,11419,0);
INSERT INTO "django_geo_db_location" VALUES(20065,NULL,'Chapel Hill, NC 27515',8352,222,NULL,33,11420,0);
INSERT INTO "django_geo_db_location" VALUES(20066,NULL,'Chapel Hill, NC 27516',8352,222,NULL,33,11421,0);
INSERT INTO "django_geo_db_location" VALUES(20067,NULL,'Chapel Hill, NC 27517',8352,222,NULL,33,11422,0);
INSERT INTO "django_geo_db_location" VALUES(20068,NULL,'Cary, NC 27518',8351,222,NULL,33,11423,0);
INSERT INTO "django_geo_db_location" VALUES(20069,NULL,'Cary, NC 27519',8351,222,NULL,33,11424,0);
INSERT INTO "django_geo_db_location" VALUES(20070,NULL,'Clayton, NC',8353,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20071,NULL,'Clayton, NC 27520',8353,222,NULL,33,11425,0);
INSERT INTO "django_geo_db_location" VALUES(20072,NULL,'Coats, NC',8354,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20073,NULL,'Coats, NC 27521',8354,222,NULL,33,11426,0);
INSERT INTO "django_geo_db_location" VALUES(20074,NULL,'Creedmoor, NC',8355,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20075,NULL,'Creedmoor, NC 27522',8355,222,NULL,33,11427,0);
INSERT INTO "django_geo_db_location" VALUES(20076,NULL,'Eagle Rock, NC',8356,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20077,NULL,'Eagle Rock, NC 27523',8356,222,NULL,33,11428,0);
INSERT INTO "django_geo_db_location" VALUES(20078,NULL,'Four Oaks, NC',8357,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20079,NULL,'Four Oaks, NC 27524',8357,222,NULL,33,11429,0);
INSERT INTO "django_geo_db_location" VALUES(20080,NULL,'Franklinton, NC',8358,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20081,NULL,'Franklinton, NC 27525',8358,222,NULL,33,11430,0);
INSERT INTO "django_geo_db_location" VALUES(20082,NULL,'Fuquay Varina, NC',8359,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20083,NULL,'Fuquay Varina, NC 27526',8359,222,NULL,33,11431,0);
INSERT INTO "django_geo_db_location" VALUES(20084,NULL,'Garner, NC',8360,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20085,NULL,'Garner, NC 27529',8360,222,NULL,33,11432,0);
INSERT INTO "django_geo_db_location" VALUES(20086,NULL,'Goldsboro, NC',8361,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20087,NULL,'Goldsboro, NC 27530',8361,222,NULL,33,11433,0);
INSERT INTO "django_geo_db_location" VALUES(20088,NULL,'Goldsboro, NC 27531',8361,222,NULL,33,11434,0);
INSERT INTO "django_geo_db_location" VALUES(20089,NULL,'Goldsboro, NC 27532',8361,222,NULL,33,11435,0);
INSERT INTO "django_geo_db_location" VALUES(20090,NULL,'Goldsboro, NC 27533',8361,222,NULL,33,11436,0);
INSERT INTO "django_geo_db_location" VALUES(20091,NULL,'Goldsboro, NC 27534',8361,222,NULL,33,11437,0);
INSERT INTO "django_geo_db_location" VALUES(20092,NULL,'Henderson, NC',8362,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20093,NULL,'Henderson, NC 27536',8362,222,NULL,33,11438,0);
INSERT INTO "django_geo_db_location" VALUES(20094,NULL,'Henderson, NC 27537',8362,222,NULL,33,11439,0);
INSERT INTO "django_geo_db_location" VALUES(20095,NULL,'Apex, NC 27539',8342,222,NULL,33,11440,0);
INSERT INTO "django_geo_db_location" VALUES(20096,NULL,'Holly Springs, NC',8363,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20097,NULL,'Holly Springs, NC 27540',8363,222,NULL,33,11441,0);
INSERT INTO "django_geo_db_location" VALUES(20098,NULL,'Hurdle Mills, NC',8364,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20099,NULL,'Hurdle Mills, NC 27541',8364,222,NULL,33,11442,0);
INSERT INTO "django_geo_db_location" VALUES(20100,NULL,'Kenly, NC',8365,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20101,NULL,'Kenly, NC 27542',8365,222,NULL,33,11443,0);
INSERT INTO "django_geo_db_location" VALUES(20102,NULL,'Kipling, NC',8366,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20103,NULL,'Kipling, NC 27543',8366,222,NULL,33,11444,0);
INSERT INTO "django_geo_db_location" VALUES(20104,NULL,'Kittrell, NC',8367,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20105,NULL,'Kittrell, NC 27544',8367,222,NULL,33,11445,0);
INSERT INTO "django_geo_db_location" VALUES(20106,NULL,'Knightdale, NC',8368,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20107,NULL,'Knightdale, NC 27545',8368,222,NULL,33,11446,0);
INSERT INTO "django_geo_db_location" VALUES(20108,NULL,'Lillington, NC',8369,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20109,NULL,'Lillington, NC 27546',8369,222,NULL,33,11447,0);
INSERT INTO "django_geo_db_location" VALUES(20110,NULL,'Louisburg, NC',8370,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20111,NULL,'Louisburg, NC 27549',8370,222,NULL,33,11448,0);
INSERT INTO "django_geo_db_location" VALUES(20112,NULL,'Macon, NC',8371,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20113,NULL,'Macon, NC 27551',8371,222,NULL,33,11449,0);
INSERT INTO "django_geo_db_location" VALUES(20114,NULL,'Mamers, NC',8372,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20115,NULL,'Mamers, NC 27552',8372,222,NULL,33,11450,0);
INSERT INTO "django_geo_db_location" VALUES(20116,NULL,'Manson, NC',8373,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20117,NULL,'Manson, NC 27553',8373,222,NULL,33,11451,0);
INSERT INTO "django_geo_db_location" VALUES(20118,NULL,'Micro, NC',8374,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20119,NULL,'Micro, NC 27555',8374,222,NULL,33,11452,0);
INSERT INTO "django_geo_db_location" VALUES(20120,NULL,'Middleburg, NC',8375,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20121,NULL,'Middleburg, NC 27556',8375,222,NULL,33,11453,0);
INSERT INTO "django_geo_db_location" VALUES(20122,NULL,'Middlesex, NC',8376,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20123,NULL,'Middlesex, NC 27557',8376,222,NULL,33,11454,0);
INSERT INTO "django_geo_db_location" VALUES(20124,NULL,'Moncure, NC',8377,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20125,NULL,'Moncure, NC 27559',8377,222,NULL,33,11455,0);
INSERT INTO "django_geo_db_location" VALUES(20126,NULL,'Morrisville, NC',8378,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20127,NULL,'Morrisville, NC 27560',8378,222,NULL,33,11456,0);
INSERT INTO "django_geo_db_location" VALUES(20128,NULL,'Raleigh, NC',8379,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20129,NULL,'Raleigh, NC 27561',8379,222,NULL,33,11457,0);
INSERT INTO "django_geo_db_location" VALUES(20130,NULL,'New Hill, NC',8380,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20131,NULL,'New Hill, NC 27562',8380,222,NULL,33,11458,0);
INSERT INTO "django_geo_db_location" VALUES(20132,NULL,'Norlina, NC',8381,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20133,NULL,'Norlina, NC 27563',8381,222,NULL,33,11459,0);
INSERT INTO "django_geo_db_location" VALUES(20134,NULL,'Creedmoor, NC 27564',8355,222,NULL,33,11460,0);
INSERT INTO "django_geo_db_location" VALUES(20135,NULL,'Oxford, NC',8382,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20136,NULL,'Oxford, NC 27565',8382,222,NULL,33,11461,0);
INSERT INTO "django_geo_db_location" VALUES(20137,NULL,'Pine Level, NC',8383,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20138,NULL,'Pine Level, NC 27568',8383,222,NULL,33,11462,0);
INSERT INTO "django_geo_db_location" VALUES(20139,NULL,'Princeton, NC',8384,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20140,NULL,'Princeton, NC 27569',8384,222,NULL,33,11463,0);
INSERT INTO "django_geo_db_location" VALUES(20141,NULL,'Ridgeway, NC',8385,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20142,NULL,'Ridgeway, NC 27570',8385,222,NULL,33,11464,0);
INSERT INTO "django_geo_db_location" VALUES(20143,NULL,'Rolesville, NC',8386,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20144,NULL,'Rolesville, NC 27571',8386,222,NULL,33,11465,0);
INSERT INTO "django_geo_db_location" VALUES(20145,NULL,'Rougemont, NC',8387,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20146,NULL,'Rougemont, NC 27572',8387,222,NULL,33,11466,0);
INSERT INTO "django_geo_db_location" VALUES(20147,NULL,'Roxboro, NC',8388,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20148,NULL,'Roxboro, NC 27573',8388,222,NULL,33,11467,0);
INSERT INTO "django_geo_db_location" VALUES(20149,NULL,'Roxboro, NC 27574',8388,222,NULL,33,11468,0);
INSERT INTO "django_geo_db_location" VALUES(20150,NULL,'Selma, NC',8389,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20151,NULL,'Selma, NC 27576',8389,222,NULL,33,11469,0);
INSERT INTO "django_geo_db_location" VALUES(20152,NULL,'Smithfield, NC',8390,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20153,NULL,'Smithfield, NC 27577',8390,222,NULL,33,11470,0);
INSERT INTO "django_geo_db_location" VALUES(20154,NULL,'Stem, NC',8391,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20155,NULL,'Stem, NC 27581',8391,222,NULL,33,11471,0);
INSERT INTO "django_geo_db_location" VALUES(20156,NULL,'Stovall, NC',8392,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20157,NULL,'Stovall, NC 27582',8392,222,NULL,33,11472,0);
INSERT INTO "django_geo_db_location" VALUES(20158,NULL,'Timberlake, NC',8393,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20159,NULL,'Timberlake, NC 27583',8393,222,NULL,33,11473,0);
INSERT INTO "django_geo_db_location" VALUES(20160,NULL,'Townsville, NC',8394,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20161,NULL,'Townsville, NC 27584',8394,222,NULL,33,11474,0);
INSERT INTO "django_geo_db_location" VALUES(20162,NULL,'Vaughan, NC',8395,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20163,NULL,'Vaughan, NC 27586',8395,222,NULL,33,11475,0);
INSERT INTO "django_geo_db_location" VALUES(20164,NULL,'Wake Forest, NC',8396,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20165,NULL,'Wake Forest, NC 27587',8396,222,NULL,33,11476,0);
INSERT INTO "django_geo_db_location" VALUES(20166,NULL,'Wake Forest, NC 27588',8396,222,NULL,33,11477,0);
INSERT INTO "django_geo_db_location" VALUES(20167,NULL,'Warrenton, NC',8397,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20168,NULL,'Warrenton, NC 27589',8397,222,NULL,33,11478,0);
INSERT INTO "django_geo_db_location" VALUES(20169,NULL,'Wendell, NC',8398,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20170,NULL,'Wendell, NC 27591',8398,222,NULL,33,11479,0);
INSERT INTO "django_geo_db_location" VALUES(20171,NULL,'Willow Spring, NC',8399,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20172,NULL,'Willow Spring, NC 27592',8399,222,NULL,33,11480,0);
INSERT INTO "django_geo_db_location" VALUES(20173,NULL,'Wilsons Mills, NC',8400,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20174,NULL,'Wilsons Mills, NC 27593',8400,222,NULL,33,11481,0);
INSERT INTO "django_geo_db_location" VALUES(20175,NULL,'Wise, NC',8401,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20176,NULL,'Wise, NC 27594',8401,222,NULL,33,11482,0);
INSERT INTO "django_geo_db_location" VALUES(20177,NULL,'Youngsville, NC',8402,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20178,NULL,'Youngsville, NC 27596',8402,222,NULL,33,11483,0);
INSERT INTO "django_geo_db_location" VALUES(20179,NULL,'Zebulon, NC',8403,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20180,NULL,'Zebulon, NC 27597',8403,222,NULL,33,11484,0);
INSERT INTO "django_geo_db_location" VALUES(20181,NULL,'Chapel Hill, NC 27599',8352,222,NULL,33,11485,0);
INSERT INTO "django_geo_db_location" VALUES(20182,NULL,'Raleigh, NC 27601',8379,222,NULL,33,11486,0);
INSERT INTO "django_geo_db_location" VALUES(20183,NULL,'Raleigh, NC 27602',8379,222,NULL,33,11487,0);
INSERT INTO "django_geo_db_location" VALUES(20184,NULL,'Raleigh, NC 27603',8379,222,NULL,33,11488,0);
INSERT INTO "django_geo_db_location" VALUES(20185,NULL,'Raleigh, NC 27604',8379,222,NULL,33,11489,0);
INSERT INTO "django_geo_db_location" VALUES(20186,NULL,'Raleigh, NC 27605',8379,222,NULL,33,11490,0);
INSERT INTO "django_geo_db_location" VALUES(20187,NULL,'Raleigh, NC 27606',8379,222,NULL,33,11491,0);
INSERT INTO "django_geo_db_location" VALUES(20188,NULL,'Raleigh, NC 27607',8379,222,NULL,33,11492,0);
INSERT INTO "django_geo_db_location" VALUES(20189,NULL,'Raleigh, NC 27608',8379,222,NULL,33,11493,0);
INSERT INTO "django_geo_db_location" VALUES(20190,NULL,'Raleigh, NC 27609',8379,222,NULL,33,11494,0);
INSERT INTO "django_geo_db_location" VALUES(20191,NULL,'Raleigh, NC 27610',8379,222,NULL,33,11495,0);
INSERT INTO "django_geo_db_location" VALUES(20192,NULL,'Raleigh, NC 27611',8379,222,NULL,33,11496,0);
INSERT INTO "django_geo_db_location" VALUES(20193,NULL,'Raleigh, NC 27612',8379,222,NULL,33,11497,0);
INSERT INTO "django_geo_db_location" VALUES(20194,NULL,'Raleigh, NC 27613',8379,222,NULL,33,11498,0);
INSERT INTO "django_geo_db_location" VALUES(20195,NULL,'Raleigh, NC 27614',8379,222,NULL,33,11499,0);
INSERT INTO "django_geo_db_location" VALUES(20196,NULL,'Raleigh, NC 27615',8379,222,NULL,33,11500,0);
INSERT INTO "django_geo_db_location" VALUES(20197,NULL,'Raleigh, NC 27616',8379,222,NULL,33,11501,0);
INSERT INTO "django_geo_db_location" VALUES(20198,NULL,'Raleigh, NC 27617',8379,222,NULL,33,11502,0);
INSERT INTO "django_geo_db_location" VALUES(20199,NULL,'Raleigh, NC 27619',8379,222,NULL,33,11503,0);
INSERT INTO "django_geo_db_location" VALUES(20200,NULL,'Raleigh, NC 27620',8379,222,NULL,33,11504,0);
INSERT INTO "django_geo_db_location" VALUES(20201,NULL,'Raleigh, NC 27621',8379,222,NULL,33,11505,0);
INSERT INTO "django_geo_db_location" VALUES(20202,NULL,'Raleigh, NC 27622',8379,222,NULL,33,11506,0);
INSERT INTO "django_geo_db_location" VALUES(20203,NULL,'Raleigh, NC 27623',8379,222,NULL,33,11507,0);
INSERT INTO "django_geo_db_location" VALUES(20204,NULL,'Raleigh, NC 27624',8379,222,NULL,33,11508,0);
INSERT INTO "django_geo_db_location" VALUES(20205,NULL,'Raleigh, NC 27625',8379,222,NULL,33,11509,0);
INSERT INTO "django_geo_db_location" VALUES(20206,NULL,'Raleigh, NC 27626',8379,222,NULL,33,11510,0);
INSERT INTO "django_geo_db_location" VALUES(20207,NULL,'Raleigh, NC 27627',8379,222,NULL,33,11511,0);
INSERT INTO "django_geo_db_location" VALUES(20208,NULL,'Raleigh, NC 27628',8379,222,NULL,33,11512,0);
INSERT INTO "django_geo_db_location" VALUES(20209,NULL,'Raleigh, NC 27629',8379,222,NULL,33,11513,0);
INSERT INTO "django_geo_db_location" VALUES(20210,NULL,'Thomasville, NC 27630',8331,222,NULL,33,11514,0);
INSERT INTO "django_geo_db_location" VALUES(20211,NULL,'Raleigh, NC 27634',8379,222,NULL,33,11515,0);
INSERT INTO "django_geo_db_location" VALUES(20212,NULL,'Raleigh, NC 27635',8379,222,NULL,33,11516,0);
INSERT INTO "django_geo_db_location" VALUES(20213,NULL,'Raleigh, NC 27636',8379,222,NULL,33,11517,0);
INSERT INTO "django_geo_db_location" VALUES(20214,NULL,'Raleigh, NC 27640',8379,222,NULL,33,11518,0);
INSERT INTO "django_geo_db_location" VALUES(20215,NULL,'Raleigh, NC 27650',8379,222,NULL,33,11519,0);
INSERT INTO "django_geo_db_location" VALUES(20216,NULL,'Raleigh, NC 27656',8379,222,NULL,33,11520,0);
INSERT INTO "django_geo_db_location" VALUES(20217,NULL,'Raleigh, NC 27658',8379,222,NULL,33,11521,0);
INSERT INTO "django_geo_db_location" VALUES(20218,NULL,'Raleigh, NC 27661',8379,222,NULL,33,11522,0);
INSERT INTO "django_geo_db_location" VALUES(20219,NULL,'Raleigh, NC 27668',8379,222,NULL,33,11523,0);
INSERT INTO "django_geo_db_location" VALUES(20220,NULL,'Raleigh, NC 27675',8379,222,NULL,33,11524,0);
INSERT INTO "django_geo_db_location" VALUES(20221,NULL,'Raleigh, NC 27676',8379,222,NULL,33,11525,0);
INSERT INTO "django_geo_db_location" VALUES(20222,NULL,'Raleigh, NC 27690',8379,222,NULL,33,11526,0);
INSERT INTO "django_geo_db_location" VALUES(20223,NULL,'Raleigh, NC 27695',8379,222,NULL,33,11527,0);
INSERT INTO "django_geo_db_location" VALUES(20224,NULL,'Raleigh, NC 27697',8379,222,NULL,33,11528,0);
INSERT INTO "django_geo_db_location" VALUES(20225,NULL,'Raleigh, NC 27698',8379,222,NULL,33,11529,0);
INSERT INTO "django_geo_db_location" VALUES(20226,NULL,'Raleigh, NC 27699',8379,222,NULL,33,11530,0);
INSERT INTO "django_geo_db_location" VALUES(20227,NULL,'Durham, NC',8404,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20228,NULL,'Durham, NC 27701',8404,222,NULL,33,11531,0);
INSERT INTO "django_geo_db_location" VALUES(20229,NULL,'Durham, NC 27702',8404,222,NULL,33,11532,0);
INSERT INTO "django_geo_db_location" VALUES(20230,NULL,'Durham, NC 27703',8404,222,NULL,33,11533,0);
INSERT INTO "django_geo_db_location" VALUES(20231,NULL,'Durham, NC 27704',8404,222,NULL,33,11534,0);
INSERT INTO "django_geo_db_location" VALUES(20232,NULL,'Durham, NC 27705',8404,222,NULL,33,11535,0);
INSERT INTO "django_geo_db_location" VALUES(20233,NULL,'Durham, NC 27706',8404,222,NULL,33,11536,0);
INSERT INTO "django_geo_db_location" VALUES(20234,NULL,'Durham, NC 27707',8404,222,NULL,33,11537,0);
INSERT INTO "django_geo_db_location" VALUES(20235,NULL,'Durham, NC 27708',8404,222,NULL,33,11538,0);
INSERT INTO "django_geo_db_location" VALUES(20236,NULL,'Durham, NC 27709',8404,222,NULL,33,11539,0);
INSERT INTO "django_geo_db_location" VALUES(20237,NULL,'Durham, NC 27710',8404,222,NULL,33,11540,0);
INSERT INTO "django_geo_db_location" VALUES(20238,NULL,'Durham, NC 27711',8404,222,NULL,33,11541,0);
INSERT INTO "django_geo_db_location" VALUES(20239,NULL,'Durham, NC 27712',8404,222,NULL,33,11542,0);
INSERT INTO "django_geo_db_location" VALUES(20240,NULL,'Durham, NC 27713',8404,222,NULL,33,11543,0);
INSERT INTO "django_geo_db_location" VALUES(20241,NULL,'Durham, NC 27715',8404,222,NULL,33,11544,0);
INSERT INTO "django_geo_db_location" VALUES(20242,NULL,'Durham, NC 27717',8404,222,NULL,33,11545,0);
INSERT INTO "django_geo_db_location" VALUES(20243,NULL,'Durham, NC 27722',8404,222,NULL,33,11546,0);
INSERT INTO "django_geo_db_location" VALUES(20244,NULL,'Rocky Mount, NC',8405,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20245,NULL,'Rocky Mount, NC 27801',8405,222,NULL,33,11547,0);
INSERT INTO "django_geo_db_location" VALUES(20246,NULL,'Rocky Mount, NC 27802',8405,222,NULL,33,11548,0);
INSERT INTO "django_geo_db_location" VALUES(20247,NULL,'Rocky Mount, NC 27803',8405,222,NULL,33,11549,0);
INSERT INTO "django_geo_db_location" VALUES(20248,NULL,'Rocky Mount, NC 27804',8405,222,NULL,33,11550,0);
INSERT INTO "django_geo_db_location" VALUES(20249,NULL,'Aulander, NC',8406,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20250,NULL,'Aulander, NC 27805',8406,222,NULL,33,11551,0);
INSERT INTO "django_geo_db_location" VALUES(20251,NULL,'Aurora, NC',8407,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20252,NULL,'Aurora, NC 27806',8407,222,NULL,33,11552,0);
INSERT INTO "django_geo_db_location" VALUES(20253,NULL,'Bailey, NC',8408,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20254,NULL,'Bailey, NC 27807',8408,222,NULL,33,11553,0);
INSERT INTO "django_geo_db_location" VALUES(20255,NULL,'Bath, NC',8409,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20256,NULL,'Bath, NC 27808',8409,222,NULL,33,11554,0);
INSERT INTO "django_geo_db_location" VALUES(20257,NULL,'Battleboro, NC',8410,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20258,NULL,'Battleboro, NC 27809',8410,222,NULL,33,11555,0);
INSERT INTO "django_geo_db_location" VALUES(20259,NULL,'Belhaven, NC',8411,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20260,NULL,'Belhaven, NC 27810',8411,222,NULL,33,11556,0);
INSERT INTO "django_geo_db_location" VALUES(20261,NULL,'Bellarthur, NC',8412,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20262,NULL,'Bellarthur, NC 27811',8412,222,NULL,33,11557,0);
INSERT INTO "django_geo_db_location" VALUES(20263,NULL,'Bethel, NC',8413,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20264,NULL,'Bethel, NC 27812',8413,222,NULL,33,11558,0);
INSERT INTO "django_geo_db_location" VALUES(20265,NULL,'Black Creek, NC',8414,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20266,NULL,'Black Creek, NC 27813',8414,222,NULL,33,11559,0);
INSERT INTO "django_geo_db_location" VALUES(20267,NULL,'Blounts Creek, NC',8415,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20268,NULL,'Blounts Creek, NC 27814',8415,222,NULL,33,11560,0);
INSERT INTO "django_geo_db_location" VALUES(20269,NULL,'Castalia, NC',8416,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20270,NULL,'Castalia, NC 27816',8416,222,NULL,33,11561,0);
INSERT INTO "django_geo_db_location" VALUES(20271,NULL,'Chocowinity, NC',8417,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20272,NULL,'Chocowinity, NC 27817',8417,222,NULL,33,11562,0);
INSERT INTO "django_geo_db_location" VALUES(20273,NULL,'Como, NC',8418,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20274,NULL,'Como, NC 27818',8418,222,NULL,33,11563,0);
INSERT INTO "django_geo_db_location" VALUES(20275,NULL,'Conetoe, NC',8419,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20276,NULL,'Conetoe, NC 27819',8419,222,NULL,33,11564,0);
INSERT INTO "django_geo_db_location" VALUES(20277,NULL,'Conway, NC',8420,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20278,NULL,'Conway, NC 27820',8420,222,NULL,33,11565,0);
INSERT INTO "django_geo_db_location" VALUES(20279,NULL,'Edward, NC',8421,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20280,NULL,'Edward, NC 27821',8421,222,NULL,33,11566,0);
INSERT INTO "django_geo_db_location" VALUES(20281,NULL,'Elm City, NC',8422,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20282,NULL,'Elm City, NC 27822',8422,222,NULL,33,11567,0);
INSERT INTO "django_geo_db_location" VALUES(20283,NULL,'Enfield, NC',8423,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20284,NULL,'Enfield, NC 27823',8423,222,NULL,33,11568,0);
INSERT INTO "django_geo_db_location" VALUES(20285,NULL,'Engelhard, NC',8424,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20286,NULL,'Engelhard, NC 27824',8424,222,NULL,33,11569,0);
INSERT INTO "django_geo_db_location" VALUES(20287,NULL,'Everetts, NC',8425,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20288,NULL,'Everetts, NC 27825',8425,222,NULL,33,11570,0);
INSERT INTO "django_geo_db_location" VALUES(20289,NULL,'Fairfield, NC',8426,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20290,NULL,'Fairfield, NC 27826',8426,222,NULL,33,11571,0);
INSERT INTO "django_geo_db_location" VALUES(20291,NULL,'Falkland, NC',8427,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20292,NULL,'Falkland, NC 27827',8427,222,NULL,33,11572,0);
INSERT INTO "django_geo_db_location" VALUES(20293,NULL,'Farmville, NC',8428,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20294,NULL,'Farmville, NC 27828',8428,222,NULL,33,11573,0);
INSERT INTO "django_geo_db_location" VALUES(20295,NULL,'Fountain, NC',8429,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20296,NULL,'Fountain, NC 27829',8429,222,NULL,33,11574,0);
INSERT INTO "django_geo_db_location" VALUES(20297,NULL,'Fremont, NC',8430,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20298,NULL,'Fremont, NC 27830',8430,222,NULL,33,11575,0);
INSERT INTO "django_geo_db_location" VALUES(20299,NULL,'Garysburg, NC',8431,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20300,NULL,'Garysburg, NC 27831',8431,222,NULL,33,11576,0);
INSERT INTO "django_geo_db_location" VALUES(20301,NULL,'Gaston, NC',8432,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20302,NULL,'Gaston, NC 27832',8432,222,NULL,33,11577,0);
INSERT INTO "django_geo_db_location" VALUES(20303,NULL,'Greenville, NC',8433,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20304,NULL,'Greenville, NC 27833',8433,222,NULL,33,11578,0);
INSERT INTO "django_geo_db_location" VALUES(20305,NULL,'Greenville, NC 27834',8433,222,NULL,33,11579,0);
INSERT INTO "django_geo_db_location" VALUES(20306,NULL,'Greenville, NC 27835',8433,222,NULL,33,11580,0);
INSERT INTO "django_geo_db_location" VALUES(20307,NULL,'Greenville, NC 27836',8433,222,NULL,33,11581,0);
INSERT INTO "django_geo_db_location" VALUES(20308,NULL,'Grimesland, NC',8434,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20309,NULL,'Grimesland, NC 27837',8434,222,NULL,33,11582,0);
INSERT INTO "django_geo_db_location" VALUES(20310,NULL,'Gumberry, NC',8435,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20311,NULL,'Gumberry, NC 27838',8435,222,NULL,33,11583,0);
INSERT INTO "django_geo_db_location" VALUES(20312,NULL,'Halifax, NC',8436,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20313,NULL,'Halifax, NC 27839',8436,222,NULL,33,11584,0);
INSERT INTO "django_geo_db_location" VALUES(20314,NULL,'Hamilton, NC',8437,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20315,NULL,'Hamilton, NC 27840',8437,222,NULL,33,11585,0);
INSERT INTO "django_geo_db_location" VALUES(20316,NULL,'Hassell, NC',8438,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20317,NULL,'Hassell, NC 27841',8438,222,NULL,33,11586,0);
INSERT INTO "django_geo_db_location" VALUES(20318,NULL,'Henrico, NC',8439,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20319,NULL,'Henrico, NC 27842',8439,222,NULL,33,11587,0);
INSERT INTO "django_geo_db_location" VALUES(20320,NULL,'Hobgood, NC',8440,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20321,NULL,'Hobgood, NC 27843',8440,222,NULL,33,11588,0);
INSERT INTO "django_geo_db_location" VALUES(20322,NULL,'Hollister, NC',8441,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20323,NULL,'Hollister, NC 27844',8441,222,NULL,33,11589,0);
INSERT INTO "django_geo_db_location" VALUES(20324,NULL,'Jackson, NC',8442,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20325,NULL,'Jackson, NC 27845',8442,222,NULL,33,11590,0);
INSERT INTO "django_geo_db_location" VALUES(20326,NULL,'Jamesville, NC',8443,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20327,NULL,'Jamesville, NC 27846',8443,222,NULL,33,11591,0);
INSERT INTO "django_geo_db_location" VALUES(20328,NULL,'Kelford, NC',8444,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20329,NULL,'Kelford, NC 27847',8444,222,NULL,33,11592,0);
INSERT INTO "django_geo_db_location" VALUES(20330,NULL,'Lewiston Woodville, NC',8445,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20331,NULL,'Lewiston Woodville, NC 27849',8445,222,NULL,33,11593,0);
INSERT INTO "django_geo_db_location" VALUES(20332,NULL,'Littleton, NC',8446,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20333,NULL,'Littleton, NC 27850',8446,222,NULL,33,11594,0);
INSERT INTO "django_geo_db_location" VALUES(20334,NULL,'Lucama, NC',8447,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20335,NULL,'Lucama, NC 27851',8447,222,NULL,33,11595,0);
INSERT INTO "django_geo_db_location" VALUES(20336,NULL,'Macclesfield, NC',8448,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20337,NULL,'Macclesfield, NC 27852',8448,222,NULL,33,11596,0);
INSERT INTO "django_geo_db_location" VALUES(20338,NULL,'Margarettsville, NC',8449,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20339,NULL,'Margarettsville, NC 27853',8449,222,NULL,33,11597,0);
INSERT INTO "django_geo_db_location" VALUES(20340,NULL,'Milwaukee, NC',8450,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20341,NULL,'Milwaukee, NC 27854',8450,222,NULL,33,11598,0);
INSERT INTO "django_geo_db_location" VALUES(20342,NULL,'Murfreesboro, NC',8451,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20343,NULL,'Murfreesboro, NC 27855',8451,222,NULL,33,11599,0);
INSERT INTO "django_geo_db_location" VALUES(20344,NULL,'Nashville, NC',8452,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20345,NULL,'Nashville, NC 27856',8452,222,NULL,33,11600,0);
INSERT INTO "django_geo_db_location" VALUES(20346,NULL,'Oak City, NC',8453,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20347,NULL,'Oak City, NC 27857',8453,222,NULL,33,11601,0);
INSERT INTO "django_geo_db_location" VALUES(20348,NULL,'Greenville, NC 27858',8433,222,NULL,33,11602,0);
INSERT INTO "django_geo_db_location" VALUES(20349,NULL,'Palmyra, NC',8454,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20350,NULL,'Palmyra, NC 27859',8454,222,NULL,33,11603,0);
INSERT INTO "django_geo_db_location" VALUES(20351,NULL,'Pantego, NC',8455,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20352,NULL,'Pantego, NC 27860',8455,222,NULL,33,11604,0);
INSERT INTO "django_geo_db_location" VALUES(20353,NULL,'Parmele, NC',8456,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20354,NULL,'Parmele, NC 27861',8456,222,NULL,33,11605,0);
INSERT INTO "django_geo_db_location" VALUES(20355,NULL,'Pendleton, NC',8457,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20356,NULL,'Pendleton, NC 27862',8457,222,NULL,33,11606,0);
INSERT INTO "django_geo_db_location" VALUES(20357,NULL,'Pikeville, NC',8458,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20358,NULL,'Pikeville, NC 27863',8458,222,NULL,33,11607,0);
INSERT INTO "django_geo_db_location" VALUES(20359,NULL,'Pinetops, NC',8459,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20360,NULL,'Pinetops, NC 27864',8459,222,NULL,33,11608,0);
INSERT INTO "django_geo_db_location" VALUES(20361,NULL,'Pinetown, NC',8460,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20362,NULL,'Pinetown, NC 27865',8460,222,NULL,33,11609,0);
INSERT INTO "django_geo_db_location" VALUES(20363,NULL,'Pleasant Hill, NC',8461,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20364,NULL,'Pleasant Hill, NC 27866',8461,222,NULL,33,11610,0);
INSERT INTO "django_geo_db_location" VALUES(20365,NULL,'Potecasi, NC',8462,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20366,NULL,'Potecasi, NC 27867',8462,222,NULL,33,11611,0);
INSERT INTO "django_geo_db_location" VALUES(20367,NULL,'Red Oak, NC',8463,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20368,NULL,'Red Oak, NC 27868',8463,222,NULL,33,11612,0);
INSERT INTO "django_geo_db_location" VALUES(20369,NULL,'Rich Square, NC',8464,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20370,NULL,'Rich Square, NC 27869',8464,222,NULL,33,11613,0);
INSERT INTO "django_geo_db_location" VALUES(20371,NULL,'Roanoke Rapids, NC',8465,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20372,NULL,'Roanoke Rapids, NC 27870',8465,222,NULL,33,11614,0);
INSERT INTO "django_geo_db_location" VALUES(20373,NULL,'Robersonville, NC',8466,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20374,NULL,'Robersonville, NC 27871',8466,222,NULL,33,11615,0);
INSERT INTO "django_geo_db_location" VALUES(20375,NULL,'Roxobel, NC',8467,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20376,NULL,'Roxobel, NC 27872',8467,222,NULL,33,11616,0);
INSERT INTO "django_geo_db_location" VALUES(20377,NULL,'Saratoga, NC',8468,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20378,NULL,'Saratoga, NC 27873',8468,222,NULL,33,11617,0);
INSERT INTO "django_geo_db_location" VALUES(20379,NULL,'Scotland Neck, NC',8469,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20380,NULL,'Scotland Neck, NC 27874',8469,222,NULL,33,11618,0);
INSERT INTO "django_geo_db_location" VALUES(20381,NULL,'Scranton, NC',8470,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20382,NULL,'Scranton, NC 27875',8470,222,NULL,33,11619,0);
INSERT INTO "django_geo_db_location" VALUES(20383,NULL,'Seaboard, NC',8471,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20384,NULL,'Seaboard, NC 27876',8471,222,NULL,33,11620,0);
INSERT INTO "django_geo_db_location" VALUES(20385,NULL,'Severn, NC',8472,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20386,NULL,'Severn, NC 27877',8472,222,NULL,33,11621,0);
INSERT INTO "django_geo_db_location" VALUES(20387,NULL,'Sharpsburg, NC',8473,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20388,NULL,'Sharpsburg, NC 27878',8473,222,NULL,33,11622,0);
INSERT INTO "django_geo_db_location" VALUES(20389,NULL,'Simpson, NC',8474,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20390,NULL,'Simpson, NC 27879',8474,222,NULL,33,11623,0);
INSERT INTO "django_geo_db_location" VALUES(20391,NULL,'Sims, NC',8475,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20392,NULL,'Sims, NC 27880',8475,222,NULL,33,11624,0);
INSERT INTO "django_geo_db_location" VALUES(20393,NULL,'Speed, NC',8476,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20394,NULL,'Speed, NC 27881',8476,222,NULL,33,11625,0);
INSERT INTO "django_geo_db_location" VALUES(20395,NULL,'Spring Hope, NC',8477,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20396,NULL,'Spring Hope, NC 27882',8477,222,NULL,33,11626,0);
INSERT INTO "django_geo_db_location" VALUES(20397,NULL,'Stantonsburg, NC',8478,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20398,NULL,'Stantonsburg, NC 27883',8478,222,NULL,33,11627,0);
INSERT INTO "django_geo_db_location" VALUES(20399,NULL,'Stokes, NC',8479,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20400,NULL,'Stokes, NC 27884',8479,222,NULL,33,11628,0);
INSERT INTO "django_geo_db_location" VALUES(20401,NULL,'Swanquarter, NC',8480,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20402,NULL,'Swanquarter, NC 27885',8480,222,NULL,33,11629,0);
INSERT INTO "django_geo_db_location" VALUES(20403,NULL,'Tarboro, NC',8481,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20404,NULL,'Tarboro, NC 27886',8481,222,NULL,33,11630,0);
INSERT INTO "django_geo_db_location" VALUES(20405,NULL,'Tillery, NC',8482,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20406,NULL,'Tillery, NC 27887',8482,222,NULL,33,11631,0);
INSERT INTO "django_geo_db_location" VALUES(20407,NULL,'Walstonburg, NC',8483,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20408,NULL,'Walstonburg, NC 27888',8483,222,NULL,33,11632,0);
INSERT INTO "django_geo_db_location" VALUES(20409,NULL,'Washington, NC',8484,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20410,NULL,'Washington, NC 27889',8484,222,NULL,33,11633,0);
INSERT INTO "django_geo_db_location" VALUES(20411,NULL,'Weldon, NC',8485,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20412,NULL,'Weldon, NC 27890',8485,222,NULL,33,11634,0);
INSERT INTO "django_geo_db_location" VALUES(20413,NULL,'Whitakers, NC',8486,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20414,NULL,'Whitakers, NC 27891',8486,222,NULL,33,11635,0);
INSERT INTO "django_geo_db_location" VALUES(20415,NULL,'Williamston, NC',8487,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20416,NULL,'Williamston, NC 27892',8487,222,NULL,33,11636,0);
INSERT INTO "django_geo_db_location" VALUES(20417,NULL,'Wilson, NC',8488,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20418,NULL,'Wilson, NC 27893',8488,222,NULL,33,11637,0);
INSERT INTO "django_geo_db_location" VALUES(20419,NULL,'Wilson, NC 27894',8488,222,NULL,33,11638,0);
INSERT INTO "django_geo_db_location" VALUES(20420,NULL,'Wilson, NC 27895',8488,222,NULL,33,11639,0);
INSERT INTO "django_geo_db_location" VALUES(20421,NULL,'Wilson, NC 27896',8488,222,NULL,33,11640,0);
INSERT INTO "django_geo_db_location" VALUES(20422,NULL,'Woodland, NC',8489,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20423,NULL,'Woodland, NC 27897',8489,222,NULL,33,11641,0);
INSERT INTO "django_geo_db_location" VALUES(20424,NULL,'Elizabeth City, NC',8490,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20425,NULL,'Elizabeth City, NC 27906',8490,222,NULL,33,11642,0);
INSERT INTO "django_geo_db_location" VALUES(20426,NULL,'Elizabeth City, NC 27907',8490,222,NULL,33,11643,0);
INSERT INTO "django_geo_db_location" VALUES(20427,NULL,'Elizabeth City, NC 27909',8490,222,NULL,33,11644,0);
INSERT INTO "django_geo_db_location" VALUES(20428,NULL,'Ahoskie, NC',8491,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20429,NULL,'Ahoskie, NC 27910',8491,222,NULL,33,11645,0);
INSERT INTO "django_geo_db_location" VALUES(20430,NULL,'Avon, NC',8492,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20431,NULL,'Avon, NC 27915',8492,222,NULL,33,11646,0);
INSERT INTO "django_geo_db_location" VALUES(20432,NULL,'Aydlett, NC',8493,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20433,NULL,'Aydlett, NC 27916',8493,222,NULL,33,11647,0);
INSERT INTO "django_geo_db_location" VALUES(20434,NULL,'Barco, NC',8494,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20435,NULL,'Barco, NC 27917',8494,222,NULL,33,11648,0);
INSERT INTO "django_geo_db_location" VALUES(20436,NULL,'Belvidere, NC',8495,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20437,NULL,'Belvidere, NC 27919',8495,222,NULL,33,11649,0);
INSERT INTO "django_geo_db_location" VALUES(20438,NULL,'Buxton, NC',8496,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20439,NULL,'Buxton, NC 27920',8496,222,NULL,33,11650,0);
INSERT INTO "django_geo_db_location" VALUES(20440,NULL,'Camden, NC',8497,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20441,NULL,'Camden, NC 27921',8497,222,NULL,33,11651,0);
INSERT INTO "django_geo_db_location" VALUES(20442,NULL,'Cofield, NC',8498,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20443,NULL,'Cofield, NC 27922',8498,222,NULL,33,11652,0);
INSERT INTO "django_geo_db_location" VALUES(20444,NULL,'Coinjock, NC',8499,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20445,NULL,'Coinjock, NC 27923',8499,222,NULL,33,11653,0);
INSERT INTO "django_geo_db_location" VALUES(20446,NULL,'Colerain, NC',8500,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20447,NULL,'Colerain, NC 27924',8500,222,NULL,33,11654,0);
INSERT INTO "django_geo_db_location" VALUES(20448,NULL,'Columbia, NC',8501,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20449,NULL,'Columbia, NC 27925',8501,222,NULL,33,11655,0);
INSERT INTO "django_geo_db_location" VALUES(20450,NULL,'Corapeake, NC',8502,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20451,NULL,'Corapeake, NC 27926',8502,222,NULL,33,11656,0);
INSERT INTO "django_geo_db_location" VALUES(20452,NULL,'Corolla, NC',8503,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20453,NULL,'Corolla, NC 27927',8503,222,NULL,33,11657,0);
INSERT INTO "django_geo_db_location" VALUES(20454,NULL,'Creswell, NC',8504,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20455,NULL,'Creswell, NC 27928',8504,222,NULL,33,11658,0);
INSERT INTO "django_geo_db_location" VALUES(20456,NULL,'Currituck, NC',8505,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20457,NULL,'Currituck, NC 27929',8505,222,NULL,33,11659,0);
INSERT INTO "django_geo_db_location" VALUES(20458,NULL,'Durants Neck, NC',8506,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20459,NULL,'Durants Neck, NC 27930',8506,222,NULL,33,11660,0);
INSERT INTO "django_geo_db_location" VALUES(20460,NULL,'Edenton, NC',8507,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20461,NULL,'Edenton, NC 27932',8507,222,NULL,33,11661,0);
INSERT INTO "django_geo_db_location" VALUES(20462,NULL,'Eure, NC',8508,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20463,NULL,'Eure, NC 27935',8508,222,NULL,33,11662,0);
INSERT INTO "django_geo_db_location" VALUES(20464,NULL,'Frisco, NC',8509,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20465,NULL,'Frisco, NC 27936',8509,222,NULL,33,11663,0);
INSERT INTO "django_geo_db_location" VALUES(20466,NULL,'Gates, NC',8510,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20467,NULL,'Gates, NC 27937',8510,222,NULL,33,11664,0);
INSERT INTO "django_geo_db_location" VALUES(20468,NULL,'Gatesville, NC',8511,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20469,NULL,'Gatesville, NC 27938',8511,222,NULL,33,11665,0);
INSERT INTO "django_geo_db_location" VALUES(20470,NULL,'Grandy, NC',8512,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20471,NULL,'Grandy, NC 27939',8512,222,NULL,33,11666,0);
INSERT INTO "django_geo_db_location" VALUES(20472,NULL,'Harbinger, NC',8513,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20473,NULL,'Harbinger, NC 27941',8513,222,NULL,33,11667,0);
INSERT INTO "django_geo_db_location" VALUES(20474,NULL,'Harrellsville, NC',8514,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20475,NULL,'Harrellsville, NC 27942',8514,222,NULL,33,11668,0);
INSERT INTO "django_geo_db_location" VALUES(20476,NULL,'Hatteras, NC',8515,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20477,NULL,'Hatteras, NC 27943',8515,222,NULL,33,11669,0);
INSERT INTO "django_geo_db_location" VALUES(20478,NULL,'Hertford, NC',8516,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20479,NULL,'Hertford, NC 27944',8516,222,NULL,33,11670,0);
INSERT INTO "django_geo_db_location" VALUES(20480,NULL,'Hobbsville, NC',8517,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20481,NULL,'Hobbsville, NC 27946',8517,222,NULL,33,11671,0);
INSERT INTO "django_geo_db_location" VALUES(20482,NULL,'Jarvisburg, NC',8518,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20483,NULL,'Jarvisburg, NC 27947',8518,222,NULL,33,11672,0);
INSERT INTO "django_geo_db_location" VALUES(20484,NULL,'Kill Devil Hills, NC',8519,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20485,NULL,'Kill Devil Hills, NC 27948',8519,222,NULL,33,11673,0);
INSERT INTO "django_geo_db_location" VALUES(20486,NULL,'Kitty Hawk, NC',8520,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20487,NULL,'Kitty Hawk, NC 27949',8520,222,NULL,33,11674,0);
INSERT INTO "django_geo_db_location" VALUES(20488,NULL,'Knotts Island, NC',8521,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20489,NULL,'Knotts Island, NC 27950',8521,222,NULL,33,11675,0);
INSERT INTO "django_geo_db_location" VALUES(20490,NULL,'Manns Harbor, NC',8522,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20491,NULL,'Manns Harbor, NC 27953',8522,222,NULL,33,11676,0);
INSERT INTO "django_geo_db_location" VALUES(20492,NULL,'Manteo, NC',8523,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20493,NULL,'Manteo, NC 27954',8523,222,NULL,33,11677,0);
INSERT INTO "django_geo_db_location" VALUES(20494,NULL,'Maple, NC',8524,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20495,NULL,'Maple, NC 27956',8524,222,NULL,33,11678,0);
INSERT INTO "django_geo_db_location" VALUES(20496,NULL,'Merry Hill, NC',8525,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20497,NULL,'Merry Hill, NC 27957',8525,222,NULL,33,11679,0);
INSERT INTO "django_geo_db_location" VALUES(20498,NULL,'Moyock, NC',8526,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20499,NULL,'Moyock, NC 27958',8526,222,NULL,33,11680,0);
INSERT INTO "django_geo_db_location" VALUES(20500,NULL,'Nags Head, NC',8527,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20501,NULL,'Nags Head, NC 27959',8527,222,NULL,33,11681,0);
INSERT INTO "django_geo_db_location" VALUES(20502,NULL,'Ocracoke, NC',8528,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20503,NULL,'Ocracoke, NC 27960',8528,222,NULL,33,11682,0);
INSERT INTO "django_geo_db_location" VALUES(20504,NULL,'Plymouth, NC',8529,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20505,NULL,'Plymouth, NC 27962',8529,222,NULL,33,11683,0);
INSERT INTO "django_geo_db_location" VALUES(20506,NULL,'Point Harbor, NC',8530,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20507,NULL,'Point Harbor, NC 27964',8530,222,NULL,33,11684,0);
INSERT INTO "django_geo_db_location" VALUES(20508,NULL,'Poplar Branch, NC',8531,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20509,NULL,'Poplar Branch, NC 27965',8531,222,NULL,33,11685,0);
INSERT INTO "django_geo_db_location" VALUES(20510,NULL,'Powells Point, NC',8532,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20511,NULL,'Powells Point, NC 27966',8532,222,NULL,33,11686,0);
INSERT INTO "django_geo_db_location" VALUES(20512,NULL,'Powellsville, NC',8533,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20513,NULL,'Powellsville, NC 27967',8533,222,NULL,33,11687,0);
INSERT INTO "django_geo_db_location" VALUES(20514,NULL,'Rodanthe, NC',8534,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20515,NULL,'Rodanthe, NC 27968',8534,222,NULL,33,11688,0);
INSERT INTO "django_geo_db_location" VALUES(20516,NULL,'Roduco, NC',8535,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20517,NULL,'Roduco, NC 27969',8535,222,NULL,33,11689,0);
INSERT INTO "django_geo_db_location" VALUES(20518,NULL,'Roper, NC',8536,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20519,NULL,'Roper, NC 27970',8536,222,NULL,33,11690,0);
INSERT INTO "django_geo_db_location" VALUES(20520,NULL,'Salvo, NC',8537,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20521,NULL,'Salvo, NC 27972',8537,222,NULL,33,11691,0);
INSERT INTO "django_geo_db_location" VALUES(20522,NULL,'Shawboro, NC',8538,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20523,NULL,'Shawboro, NC 27973',8538,222,NULL,33,11692,0);
INSERT INTO "django_geo_db_location" VALUES(20524,NULL,'Shiloh, NC',8539,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20525,NULL,'Shiloh, NC 27974',8539,222,NULL,33,11693,0);
INSERT INTO "django_geo_db_location" VALUES(20526,NULL,'South Mills, NC',8540,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20527,NULL,'South Mills, NC 27976',8540,222,NULL,33,11694,0);
INSERT INTO "django_geo_db_location" VALUES(20528,NULL,'Stumpy Point, NC',8541,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20529,NULL,'Stumpy Point, NC 27978',8541,222,NULL,33,11695,0);
INSERT INTO "django_geo_db_location" VALUES(20530,NULL,'Sunbury, NC',8542,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20531,NULL,'Sunbury, NC 27979',8542,222,NULL,33,11696,0);
INSERT INTO "django_geo_db_location" VALUES(20532,NULL,'Tyner, NC',8543,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20533,NULL,'Tyner, NC 27980',8543,222,NULL,33,11697,0);
INSERT INTO "django_geo_db_location" VALUES(20534,NULL,'Wanchese, NC',8544,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20535,NULL,'Wanchese, NC 27981',8544,222,NULL,33,11698,0);
INSERT INTO "django_geo_db_location" VALUES(20536,NULL,'Waves, NC',8545,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20537,NULL,'Waves, NC 27982',8545,222,NULL,33,11699,0);
INSERT INTO "django_geo_db_location" VALUES(20538,NULL,'Windsor, NC',8546,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20539,NULL,'Windsor, NC 27983',8546,222,NULL,33,11700,0);
INSERT INTO "django_geo_db_location" VALUES(20540,NULL,'Winfall, NC',8547,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20541,NULL,'Winfall, NC 27985',8547,222,NULL,33,11701,0);
INSERT INTO "django_geo_db_location" VALUES(20542,NULL,'Winton, NC',8548,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20543,NULL,'Winton, NC 27986',8548,222,NULL,33,11702,0);
INSERT INTO "django_geo_db_location" VALUES(20544,NULL,'Albemarle, NC',8549,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20545,NULL,'Albemarle, NC 28001',8549,222,NULL,33,11703,0);
INSERT INTO "django_geo_db_location" VALUES(20546,NULL,'Albemarle, NC 28002',8549,222,NULL,33,11704,0);
INSERT INTO "django_geo_db_location" VALUES(20547,NULL,'Marshville, NC',8550,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20548,NULL,'Marshville, NC 28003',8550,222,NULL,33,11705,0);
INSERT INTO "django_geo_db_location" VALUES(20549,NULL,'Alexis, NC',8551,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20550,NULL,'Alexis, NC 28006',8551,222,NULL,33,11706,0);
INSERT INTO "django_geo_db_location" VALUES(20551,NULL,'Ansonville, NC',8552,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20552,NULL,'Ansonville, NC 28007',8552,222,NULL,33,11707,0);
INSERT INTO "django_geo_db_location" VALUES(20553,NULL,'Badin, NC',8553,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20554,NULL,'Badin, NC 28009',8553,222,NULL,33,11708,0);
INSERT INTO "django_geo_db_location" VALUES(20555,NULL,'Barium Springs, NC',8554,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20556,NULL,'Barium Springs, NC 28010',8554,222,NULL,33,11709,0);
INSERT INTO "django_geo_db_location" VALUES(20557,NULL,'Belmont, NC',8555,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20558,NULL,'Belmont, NC 28012',8555,222,NULL,33,11710,0);
INSERT INTO "django_geo_db_location" VALUES(20559,NULL,'Bessemer City, NC',8556,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20560,NULL,'Bessemer City, NC 28016',8556,222,NULL,33,11711,0);
INSERT INTO "django_geo_db_location" VALUES(20561,NULL,'Boiling Springs, NC',8557,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20562,NULL,'Boiling Springs, NC 28017',8557,222,NULL,33,11712,0);
INSERT INTO "django_geo_db_location" VALUES(20563,NULL,'Bostic, NC',8558,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20564,NULL,'Bostic, NC 28018',8558,222,NULL,33,11713,0);
INSERT INTO "django_geo_db_location" VALUES(20565,NULL,'Caroleen, NC',8559,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20566,NULL,'Caroleen, NC 28019',8559,222,NULL,33,11714,0);
INSERT INTO "django_geo_db_location" VALUES(20567,NULL,'Casar, NC',8560,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20568,NULL,'Casar, NC 28020',8560,222,NULL,33,11715,0);
INSERT INTO "django_geo_db_location" VALUES(20569,NULL,'Cherryville, NC',8561,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20570,NULL,'Cherryville, NC 28021',8561,222,NULL,33,11716,0);
INSERT INTO "django_geo_db_location" VALUES(20571,NULL,'China Grove, NC',8562,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20572,NULL,'China Grove, NC 28023',8562,222,NULL,33,11717,0);
INSERT INTO "django_geo_db_location" VALUES(20573,NULL,'Cliffside, NC',8563,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20574,NULL,'Cliffside, NC 28024',8563,222,NULL,33,11718,0);
INSERT INTO "django_geo_db_location" VALUES(20575,NULL,'Concord, NC',8564,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20576,NULL,'Concord, NC 28025',8564,222,NULL,33,11719,0);
INSERT INTO "django_geo_db_location" VALUES(20577,NULL,'Concord, NC 28026',8564,222,NULL,33,11720,0);
INSERT INTO "django_geo_db_location" VALUES(20578,NULL,'Concord, NC 28027',8564,222,NULL,33,11721,0);
INSERT INTO "django_geo_db_location" VALUES(20579,NULL,'Cornelius, NC',8565,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20580,NULL,'Cornelius, NC 28031',8565,222,NULL,33,11722,0);
INSERT INTO "django_geo_db_location" VALUES(20581,NULL,'Cramerton, NC',8566,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20582,NULL,'Cramerton, NC 28032',8566,222,NULL,33,11723,0);
INSERT INTO "django_geo_db_location" VALUES(20583,NULL,'Crouse, NC',8567,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20584,NULL,'Crouse, NC 28033',8567,222,NULL,33,11724,0);
INSERT INTO "django_geo_db_location" VALUES(20585,NULL,'Dallas, NC',8568,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20586,NULL,'Dallas, NC 28034',8568,222,NULL,33,11725,0);
INSERT INTO "django_geo_db_location" VALUES(20587,NULL,'Davidson, NC',8569,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20588,NULL,'Davidson, NC 28036',8569,222,NULL,33,11726,0);
INSERT INTO "django_geo_db_location" VALUES(20589,NULL,'Denver, NC',8570,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20590,NULL,'Denver, NC 28037',8570,222,NULL,33,11727,0);
INSERT INTO "django_geo_db_location" VALUES(20591,NULL,'Earl, NC',8571,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20592,NULL,'Earl, NC 28038',8571,222,NULL,33,11728,0);
INSERT INTO "django_geo_db_location" VALUES(20593,NULL,'East Spencer, NC',8572,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20594,NULL,'East Spencer, NC 28039',8572,222,NULL,33,11729,0);
INSERT INTO "django_geo_db_location" VALUES(20595,NULL,'Ellenboro, NC',8573,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20596,NULL,'Ellenboro, NC 28040',8573,222,NULL,33,11730,0);
INSERT INTO "django_geo_db_location" VALUES(20597,NULL,'Faith, NC',8574,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20598,NULL,'Faith, NC 28041',8574,222,NULL,33,11731,0);
INSERT INTO "django_geo_db_location" VALUES(20599,NULL,'Fallston, NC',8575,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20600,NULL,'Fallston, NC 28042',8575,222,NULL,33,11732,0);
INSERT INTO "django_geo_db_location" VALUES(20601,NULL,'Forest City, NC',8576,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20602,NULL,'Forest City, NC 28043',8576,222,NULL,33,11733,0);
INSERT INTO "django_geo_db_location" VALUES(20603,NULL,'Gastonia, NC',8577,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20604,NULL,'Gastonia, NC 28051',8577,222,NULL,33,11734,0);
INSERT INTO "django_geo_db_location" VALUES(20605,NULL,'Gastonia, NC 28052',8577,222,NULL,33,11735,0);
INSERT INTO "django_geo_db_location" VALUES(20606,NULL,'Gastonia, NC 28053',8577,222,NULL,33,11736,0);
INSERT INTO "django_geo_db_location" VALUES(20607,NULL,'Gastonia, NC 28054',8577,222,NULL,33,11737,0);
INSERT INTO "django_geo_db_location" VALUES(20608,NULL,'Gastonia, NC 28055',8577,222,NULL,33,11738,0);
INSERT INTO "django_geo_db_location" VALUES(20609,NULL,'Gastonia, NC 28056',8577,222,NULL,33,11739,0);
INSERT INTO "django_geo_db_location" VALUES(20610,NULL,'Huntersville, NC',8578,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20611,NULL,'Huntersville, NC 28070',8578,222,NULL,33,11740,0);
INSERT INTO "django_geo_db_location" VALUES(20612,NULL,'Gold Hill, NC',8579,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20613,NULL,'Gold Hill, NC 28071',8579,222,NULL,33,11741,0);
INSERT INTO "django_geo_db_location" VALUES(20614,NULL,'Granite Quarry, NC',8580,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20615,NULL,'Granite Quarry, NC 28072',8580,222,NULL,33,11742,0);
INSERT INTO "django_geo_db_location" VALUES(20616,NULL,'Grover, NC',8581,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20617,NULL,'Grover, NC 28073',8581,222,NULL,33,11743,0);
INSERT INTO "django_geo_db_location" VALUES(20618,NULL,'Harris, NC',8582,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20619,NULL,'Harris, NC 28074',8582,222,NULL,33,11744,0);
INSERT INTO "django_geo_db_location" VALUES(20620,NULL,'Harrisburg, NC',8583,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20621,NULL,'Harrisburg, NC 28075',8583,222,NULL,33,11745,0);
INSERT INTO "django_geo_db_location" VALUES(20622,NULL,'Henrietta, NC',8584,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20623,NULL,'Henrietta, NC 28076',8584,222,NULL,33,11746,0);
INSERT INTO "django_geo_db_location" VALUES(20624,NULL,'High Shoals, NC',8585,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20625,NULL,'High Shoals, NC 28077',8585,222,NULL,33,11747,0);
INSERT INTO "django_geo_db_location" VALUES(20626,NULL,'Huntersville, NC 28078',8578,222,NULL,33,11748,0);
INSERT INTO "django_geo_db_location" VALUES(20627,NULL,'Indian Trail, NC',8586,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20628,NULL,'Indian Trail, NC 28079',8586,222,NULL,33,11749,0);
INSERT INTO "django_geo_db_location" VALUES(20629,NULL,'Iron Station, NC',8587,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20630,NULL,'Iron Station, NC 28080',8587,222,NULL,33,11750,0);
INSERT INTO "django_geo_db_location" VALUES(20631,NULL,'Kannapolis, NC',8588,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20632,NULL,'Kannapolis, NC 28081',8588,222,NULL,33,11751,0);
INSERT INTO "django_geo_db_location" VALUES(20633,NULL,'Kannapolis, NC 28082',8588,222,NULL,33,11752,0);
INSERT INTO "django_geo_db_location" VALUES(20634,NULL,'Kannapolis, NC 28083',8588,222,NULL,33,11753,0);
INSERT INTO "django_geo_db_location" VALUES(20635,NULL,'Kings Mountain, NC',8589,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20636,NULL,'Kings Mountain, NC 28086',8589,222,NULL,33,11754,0);
INSERT INTO "django_geo_db_location" VALUES(20637,NULL,'Landis, NC',8590,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20638,NULL,'Landis, NC 28088',8590,222,NULL,33,11755,0);
INSERT INTO "django_geo_db_location" VALUES(20639,NULL,'Lattimore, NC',8591,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20640,NULL,'Lattimore, NC 28089',8591,222,NULL,33,11756,0);
INSERT INTO "django_geo_db_location" VALUES(20641,NULL,'Lawndale, NC',8592,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20642,NULL,'Lawndale, NC 28090',8592,222,NULL,33,11757,0);
INSERT INTO "django_geo_db_location" VALUES(20643,NULL,'Lilesville, NC',8593,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20644,NULL,'Lilesville, NC 28091',8593,222,NULL,33,11758,0);
INSERT INTO "django_geo_db_location" VALUES(20645,NULL,'Lincolnton, NC',8594,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20646,NULL,'Lincolnton, NC 28092',8594,222,NULL,33,11759,0);
INSERT INTO "django_geo_db_location" VALUES(20647,NULL,'Lincolnton, NC 28093',8594,222,NULL,33,11760,0);
INSERT INTO "django_geo_db_location" VALUES(20648,NULL,'Locust, NC',8595,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20649,NULL,'Locust, NC 28097',8595,222,NULL,33,11761,0);
INSERT INTO "django_geo_db_location" VALUES(20650,NULL,'Lowell, NC',8596,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20651,NULL,'Lowell, NC 28098',8596,222,NULL,33,11762,0);
INSERT INTO "django_geo_db_location" VALUES(20652,NULL,'McAdenville, NC',8597,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20653,NULL,'McAdenville, NC 28101',8597,222,NULL,33,11763,0);
INSERT INTO "django_geo_db_location" VALUES(20654,NULL,'McFarlan, NC',8598,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20655,NULL,'McFarlan, NC 28102',8598,222,NULL,33,11764,0);
INSERT INTO "django_geo_db_location" VALUES(20656,NULL,'Marshville, NC 28103',8550,222,NULL,33,11765,0);
INSERT INTO "django_geo_db_location" VALUES(20657,NULL,'Matthews, NC',8599,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20658,NULL,'Matthews, NC 28104',8599,222,NULL,33,11766,0);
INSERT INTO "django_geo_db_location" VALUES(20659,NULL,'Matthews, NC 28105',8599,222,NULL,33,11767,0);
INSERT INTO "django_geo_db_location" VALUES(20660,NULL,'Matthews, NC 28106',8599,222,NULL,33,11768,0);
INSERT INTO "django_geo_db_location" VALUES(20661,NULL,'Midland, NC',8600,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20662,NULL,'Midland, NC 28107',8600,222,NULL,33,11769,0);
INSERT INTO "django_geo_db_location" VALUES(20663,NULL,'Mineral Springs, NC',8601,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20664,NULL,'Mineral Springs, NC 28108',8601,222,NULL,33,11770,0);
INSERT INTO "django_geo_db_location" VALUES(20665,NULL,'Misenheimer, NC',8602,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20666,NULL,'Misenheimer, NC 28109',8602,222,NULL,33,11771,0);
INSERT INTO "django_geo_db_location" VALUES(20667,NULL,'Monroe, NC',8603,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20668,NULL,'Monroe, NC 28110',8603,222,NULL,33,11772,0);
INSERT INTO "django_geo_db_location" VALUES(20669,NULL,'Monroe, NC 28111',8603,222,NULL,33,11773,0);
INSERT INTO "django_geo_db_location" VALUES(20670,NULL,'Monroe, NC 28112',8603,222,NULL,33,11774,0);
INSERT INTO "django_geo_db_location" VALUES(20671,NULL,'Mooresboro, NC',8604,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20672,NULL,'Mooresboro, NC 28114',8604,222,NULL,33,11775,0);
INSERT INTO "django_geo_db_location" VALUES(20673,NULL,'Mooresville, NC',8605,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20674,NULL,'Mooresville, NC 28115',8605,222,NULL,33,11776,0);
INSERT INTO "django_geo_db_location" VALUES(20675,NULL,'Mooresville, NC 28117',8605,222,NULL,33,11777,0);
INSERT INTO "django_geo_db_location" VALUES(20676,NULL,'Morven, NC',8606,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20677,NULL,'Morven, NC 28119',8606,222,NULL,33,11778,0);
INSERT INTO "django_geo_db_location" VALUES(20678,NULL,'Mount Holly, NC',8607,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20679,NULL,'Mount Holly, NC 28120',8607,222,NULL,33,11779,0);
INSERT INTO "django_geo_db_location" VALUES(20680,NULL,'Mount Mourne, NC',8608,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20681,NULL,'Mount Mourne, NC 28123',8608,222,NULL,33,11780,0);
INSERT INTO "django_geo_db_location" VALUES(20682,NULL,'Mount Pleasant, NC',8609,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20683,NULL,'Mount Pleasant, NC 28124',8609,222,NULL,33,11781,0);
INSERT INTO "django_geo_db_location" VALUES(20684,NULL,'Mount Ulla, NC',8610,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20685,NULL,'Mount Ulla, NC 28125',8610,222,NULL,33,11782,0);
INSERT INTO "django_geo_db_location" VALUES(20686,NULL,'Newell, NC',8611,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20687,NULL,'Newell, NC 28126',8611,222,NULL,33,11783,0);
INSERT INTO "django_geo_db_location" VALUES(20688,NULL,'New London, NC',8612,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20689,NULL,'New London, NC 28127',8612,222,NULL,33,11784,0);
INSERT INTO "django_geo_db_location" VALUES(20690,NULL,'Norwood, NC',8613,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20691,NULL,'Norwood, NC 28128',8613,222,NULL,33,11785,0);
INSERT INTO "django_geo_db_location" VALUES(20692,NULL,'Oakboro, NC',8614,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20693,NULL,'Oakboro, NC 28129',8614,222,NULL,33,11786,0);
INSERT INTO "django_geo_db_location" VALUES(20694,NULL,'Paw Creek, NC',8615,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20695,NULL,'Paw Creek, NC 28130',8615,222,NULL,33,11787,0);
INSERT INTO "django_geo_db_location" VALUES(20696,NULL,'Peachland, NC',8616,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20697,NULL,'Peachland, NC 28133',8616,222,NULL,33,11788,0);
INSERT INTO "django_geo_db_location" VALUES(20698,NULL,'Pineville, NC',8617,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20699,NULL,'Pineville, NC 28134',8617,222,NULL,33,11789,0);
INSERT INTO "django_geo_db_location" VALUES(20700,NULL,'Polkton, NC',8618,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20701,NULL,'Polkton, NC 28135',8618,222,NULL,33,11790,0);
INSERT INTO "django_geo_db_location" VALUES(20702,NULL,'Polkville, NC',8619,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20703,NULL,'Polkville, NC 28136',8619,222,NULL,33,11791,0);
INSERT INTO "django_geo_db_location" VALUES(20704,NULL,'Richfield, NC',8620,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20705,NULL,'Richfield, NC 28137',8620,222,NULL,33,11792,0);
INSERT INTO "django_geo_db_location" VALUES(20706,NULL,'Rockwell, NC',8621,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20707,NULL,'Rockwell, NC 28138',8621,222,NULL,33,11793,0);
INSERT INTO "django_geo_db_location" VALUES(20708,NULL,'Rutherfordton, NC',8622,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20709,NULL,'Rutherfordton, NC 28139',8622,222,NULL,33,11794,0);
INSERT INTO "django_geo_db_location" VALUES(20710,NULL,'Salisbury, NC 28144',8261,222,NULL,33,11795,0);
INSERT INTO "django_geo_db_location" VALUES(20711,NULL,'Salisbury, NC 28145',8261,222,NULL,33,11796,0);
INSERT INTO "django_geo_db_location" VALUES(20712,NULL,'Salisbury, NC 28146',8261,222,NULL,33,11797,0);
INSERT INTO "django_geo_db_location" VALUES(20713,NULL,'Salisbury, NC 28147',8261,222,NULL,33,11798,0);
INSERT INTO "django_geo_db_location" VALUES(20714,NULL,'Shelby, NC',8623,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20715,NULL,'Shelby, NC 28150',8623,222,NULL,33,11799,0);
INSERT INTO "django_geo_db_location" VALUES(20716,NULL,'Shelby, NC 28151',8623,222,NULL,33,11800,0);
INSERT INTO "django_geo_db_location" VALUES(20717,NULL,'Shelby, NC 28152',8623,222,NULL,33,11801,0);
INSERT INTO "django_geo_db_location" VALUES(20718,NULL,'Spencer, NC',8624,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20719,NULL,'Spencer, NC 28159',8624,222,NULL,33,11802,0);
INSERT INTO "django_geo_db_location" VALUES(20720,NULL,'Spindale, NC',8625,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20721,NULL,'Spindale, NC 28160',8625,222,NULL,33,11803,0);
INSERT INTO "django_geo_db_location" VALUES(20722,NULL,'Stanfield, NC',8626,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20723,NULL,'Stanfield, NC 28163',8626,222,NULL,33,11804,0);
INSERT INTO "django_geo_db_location" VALUES(20724,NULL,'Stanley, NC',8627,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20725,NULL,'Stanley, NC 28164',8627,222,NULL,33,11805,0);
INSERT INTO "django_geo_db_location" VALUES(20726,NULL,'Troutman, NC',8628,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20727,NULL,'Troutman, NC 28166',8628,222,NULL,33,11806,0);
INSERT INTO "django_geo_db_location" VALUES(20728,NULL,'Union Mills, NC',8629,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20729,NULL,'Union Mills, NC 28167',8629,222,NULL,33,11807,0);
INSERT INTO "django_geo_db_location" VALUES(20730,NULL,'Vale, NC',8630,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20731,NULL,'Vale, NC 28168',8630,222,NULL,33,11808,0);
INSERT INTO "django_geo_db_location" VALUES(20732,NULL,'Waco, NC',8631,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20733,NULL,'Waco, NC 28169',8631,222,NULL,33,11809,0);
INSERT INTO "django_geo_db_location" VALUES(20734,NULL,'Wadesboro, NC',8632,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20735,NULL,'Wadesboro, NC 28170',8632,222,NULL,33,11810,0);
INSERT INTO "django_geo_db_location" VALUES(20736,NULL,'Waxhaw, NC',8633,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20737,NULL,'Waxhaw, NC 28173',8633,222,NULL,33,11811,0);
INSERT INTO "django_geo_db_location" VALUES(20738,NULL,'Wingate, NC',8634,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20739,NULL,'Wingate, NC 28174',8634,222,NULL,33,11812,0);
INSERT INTO "django_geo_db_location" VALUES(20740,NULL,'Charlotte, NC',8635,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20741,NULL,'Charlotte, NC 28201',8635,222,NULL,33,11813,0);
INSERT INTO "django_geo_db_location" VALUES(20742,NULL,'Charlotte, NC 28202',8635,222,NULL,33,11814,0);
INSERT INTO "django_geo_db_location" VALUES(20743,NULL,'Charlotte, NC 28203',8635,222,NULL,33,11815,0);
INSERT INTO "django_geo_db_location" VALUES(20744,NULL,'Charlotte, NC 28204',8635,222,NULL,33,11816,0);
INSERT INTO "django_geo_db_location" VALUES(20745,NULL,'Charlotte, NC 28205',8635,222,NULL,33,11817,0);
INSERT INTO "django_geo_db_location" VALUES(20746,NULL,'Charlotte, NC 28206',8635,222,NULL,33,11818,0);
INSERT INTO "django_geo_db_location" VALUES(20747,NULL,'Charlotte, NC 28207',8635,222,NULL,33,11819,0);
INSERT INTO "django_geo_db_location" VALUES(20748,NULL,'Charlotte, NC 28208',8635,222,NULL,33,11820,0);
INSERT INTO "django_geo_db_location" VALUES(20749,NULL,'Charlotte, NC 28209',8635,222,NULL,33,11821,0);
INSERT INTO "django_geo_db_location" VALUES(20750,NULL,'Charlotte, NC 28210',8635,222,NULL,33,11822,0);
INSERT INTO "django_geo_db_location" VALUES(20751,NULL,'Charlotte, NC 28211',8635,222,NULL,33,11823,0);
INSERT INTO "django_geo_db_location" VALUES(20752,NULL,'Charlotte, NC 28212',8635,222,NULL,33,11824,0);
INSERT INTO "django_geo_db_location" VALUES(20753,NULL,'Charlotte, NC 28213',8635,222,NULL,33,11825,0);
INSERT INTO "django_geo_db_location" VALUES(20754,NULL,'Charlotte, NC 28214',8635,222,NULL,33,11826,0);
INSERT INTO "django_geo_db_location" VALUES(20755,NULL,'Charlotte, NC 28215',8635,222,NULL,33,11827,0);
INSERT INTO "django_geo_db_location" VALUES(20756,NULL,'Charlotte, NC 28216',8635,222,NULL,33,11828,0);
INSERT INTO "django_geo_db_location" VALUES(20757,NULL,'Charlotte, NC 28217',8635,222,NULL,33,11829,0);
INSERT INTO "django_geo_db_location" VALUES(20758,NULL,'Charlotte, NC 28218',8635,222,NULL,33,11830,0);
INSERT INTO "django_geo_db_location" VALUES(20759,NULL,'Charlotte, NC 28219',8635,222,NULL,33,11831,0);
INSERT INTO "django_geo_db_location" VALUES(20760,NULL,'Charlotte, NC 28220',8635,222,NULL,33,11832,0);
INSERT INTO "django_geo_db_location" VALUES(20761,NULL,'Charlotte, NC 28221',8635,222,NULL,33,11833,0);
INSERT INTO "django_geo_db_location" VALUES(20762,NULL,'Charlotte, NC 28222',8635,222,NULL,33,11834,0);
INSERT INTO "django_geo_db_location" VALUES(20763,NULL,'Charlotte, NC 28223',8635,222,NULL,33,11835,0);
INSERT INTO "django_geo_db_location" VALUES(20764,NULL,'Charlotte, NC 28224',8635,222,NULL,33,11836,0);
INSERT INTO "django_geo_db_location" VALUES(20765,NULL,'Charlotte, NC 28225',8635,222,NULL,33,11837,0);
INSERT INTO "django_geo_db_location" VALUES(20766,NULL,'Charlotte, NC 28226',8635,222,NULL,33,11838,0);
INSERT INTO "django_geo_db_location" VALUES(20767,NULL,'Charlotte, NC 28227',8635,222,NULL,33,11839,0);
INSERT INTO "django_geo_db_location" VALUES(20768,NULL,'Charlotte, NC 28228',8635,222,NULL,33,11840,0);
INSERT INTO "django_geo_db_location" VALUES(20769,NULL,'Charlotte, NC 28229',8635,222,NULL,33,11841,0);
INSERT INTO "django_geo_db_location" VALUES(20770,NULL,'Charlotte, NC 28230',8635,222,NULL,33,11842,0);
INSERT INTO "django_geo_db_location" VALUES(20771,NULL,'Charlotte, NC 28231',8635,222,NULL,33,11843,0);
INSERT INTO "django_geo_db_location" VALUES(20772,NULL,'Charlotte, NC 28232',8635,222,NULL,33,11844,0);
INSERT INTO "django_geo_db_location" VALUES(20773,NULL,'Charlotte, NC 28233',8635,222,NULL,33,11845,0);
INSERT INTO "django_geo_db_location" VALUES(20774,NULL,'Charlotte, NC 28234',8635,222,NULL,33,11846,0);
INSERT INTO "django_geo_db_location" VALUES(20775,NULL,'Charlotte, NC 28235',8635,222,NULL,33,11847,0);
INSERT INTO "django_geo_db_location" VALUES(20776,NULL,'Charlotte, NC 28236',8635,222,NULL,33,11848,0);
INSERT INTO "django_geo_db_location" VALUES(20777,NULL,'Charlotte, NC 28237',8635,222,NULL,33,11849,0);
INSERT INTO "django_geo_db_location" VALUES(20778,NULL,'Charlotte, NC 28240',8635,222,NULL,33,11850,0);
INSERT INTO "django_geo_db_location" VALUES(20779,NULL,'Charlotte, NC 28241',8635,222,NULL,33,11851,0);
INSERT INTO "django_geo_db_location" VALUES(20780,NULL,'Charlotte, NC 28242',8635,222,NULL,33,11852,0);
INSERT INTO "django_geo_db_location" VALUES(20781,NULL,'Charlotte, NC 28243',8635,222,NULL,33,11853,0);
INSERT INTO "django_geo_db_location" VALUES(20782,NULL,'Charlotte, NC 28244',8635,222,NULL,33,11854,0);
INSERT INTO "django_geo_db_location" VALUES(20783,NULL,'Charlotte, NC 28246',8635,222,NULL,33,11855,0);
INSERT INTO "django_geo_db_location" VALUES(20784,NULL,'Charlotte, NC 28247',8635,222,NULL,33,11856,0);
INSERT INTO "django_geo_db_location" VALUES(20785,NULL,'Charlotte, NC 28250',8635,222,NULL,33,11857,0);
INSERT INTO "django_geo_db_location" VALUES(20786,NULL,'Charlotte, NC 28253',8635,222,NULL,33,11858,0);
INSERT INTO "django_geo_db_location" VALUES(20787,NULL,'Charlotte, NC 28254',8635,222,NULL,33,11859,0);
INSERT INTO "django_geo_db_location" VALUES(20788,NULL,'Charlotte, NC 28255',8635,222,NULL,33,11860,0);
INSERT INTO "django_geo_db_location" VALUES(20789,NULL,'Charlotte, NC 28256',8635,222,NULL,33,11861,0);
INSERT INTO "django_geo_db_location" VALUES(20790,NULL,'Charlotte, NC 28258',8635,222,NULL,33,11862,0);
INSERT INTO "django_geo_db_location" VALUES(20791,NULL,'Charlotte, NC 28260',8635,222,NULL,33,11863,0);
INSERT INTO "django_geo_db_location" VALUES(20792,NULL,'Charlotte, NC 28261',8635,222,NULL,33,11864,0);
INSERT INTO "django_geo_db_location" VALUES(20793,NULL,'Charlotte, NC 28262',8635,222,NULL,33,11865,0);
INSERT INTO "django_geo_db_location" VALUES(20794,NULL,'Charlotte, NC 28265',8635,222,NULL,33,11866,0);
INSERT INTO "django_geo_db_location" VALUES(20795,NULL,'Charlotte, NC 28266',8635,222,NULL,33,11867,0);
INSERT INTO "django_geo_db_location" VALUES(20796,NULL,'Charlotte, NC 28269',8635,222,NULL,33,11868,0);
INSERT INTO "django_geo_db_location" VALUES(20797,NULL,'Charlotte, NC 28270',8635,222,NULL,33,11869,0);
INSERT INTO "django_geo_db_location" VALUES(20798,NULL,'Charlotte, NC 28272',8635,222,NULL,33,11870,0);
INSERT INTO "django_geo_db_location" VALUES(20799,NULL,'Charlotte, NC 28273',8635,222,NULL,33,11871,0);
INSERT INTO "django_geo_db_location" VALUES(20800,NULL,'Charlotte, NC 28274',8635,222,NULL,33,11872,0);
INSERT INTO "django_geo_db_location" VALUES(20801,NULL,'Charlotte, NC 28275',8635,222,NULL,33,11873,0);
INSERT INTO "django_geo_db_location" VALUES(20802,NULL,'Charlotte, NC 28277',8635,222,NULL,33,11874,0);
INSERT INTO "django_geo_db_location" VALUES(20803,NULL,'Charlotte, NC 28278',8635,222,NULL,33,11875,0);
INSERT INTO "django_geo_db_location" VALUES(20804,NULL,'Charlotte, NC 28280',8635,222,NULL,33,11876,0);
INSERT INTO "django_geo_db_location" VALUES(20805,NULL,'Charlotte, NC 28281',8635,222,NULL,33,11877,0);
INSERT INTO "django_geo_db_location" VALUES(20806,NULL,'Charlotte, NC 28282',8635,222,NULL,33,11878,0);
INSERT INTO "django_geo_db_location" VALUES(20807,NULL,'Charlotte, NC 28283',8635,222,NULL,33,11879,0);
INSERT INTO "django_geo_db_location" VALUES(20808,NULL,'Charlotte, NC 28284',8635,222,NULL,33,11880,0);
INSERT INTO "django_geo_db_location" VALUES(20809,NULL,'Charlotte, NC 28285',8635,222,NULL,33,11881,0);
INSERT INTO "django_geo_db_location" VALUES(20810,NULL,'Charlotte, NC 28286',8635,222,NULL,33,11882,0);
INSERT INTO "django_geo_db_location" VALUES(20811,NULL,'Charlotte, NC 28287',8635,222,NULL,33,11883,0);
INSERT INTO "django_geo_db_location" VALUES(20812,NULL,'Charlotte, NC 28288',8635,222,NULL,33,11884,0);
INSERT INTO "django_geo_db_location" VALUES(20813,NULL,'Charlotte, NC 28289',8635,222,NULL,33,11885,0);
INSERT INTO "django_geo_db_location" VALUES(20814,NULL,'Charlotte, NC 28290',8635,222,NULL,33,11886,0);
INSERT INTO "django_geo_db_location" VALUES(20815,NULL,'Charlotte, NC 28296',8635,222,NULL,33,11887,0);
INSERT INTO "django_geo_db_location" VALUES(20816,NULL,'Charlotte, NC 28297',8635,222,NULL,33,11888,0);
INSERT INTO "django_geo_db_location" VALUES(20817,NULL,'Charlotte, NC 28299',8635,222,NULL,33,11889,0);
INSERT INTO "django_geo_db_location" VALUES(20818,NULL,'Fayetteville, NC',8636,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20819,NULL,'Fayetteville, NC 28301',8636,222,NULL,33,11890,0);
INSERT INTO "django_geo_db_location" VALUES(20820,NULL,'Fayetteville, NC 28302',8636,222,NULL,33,11891,0);
INSERT INTO "django_geo_db_location" VALUES(20821,NULL,'Fayetteville, NC 28303',8636,222,NULL,33,11892,0);
INSERT INTO "django_geo_db_location" VALUES(20822,NULL,'Fayetteville, NC 28304',8636,222,NULL,33,11893,0);
INSERT INTO "django_geo_db_location" VALUES(20823,NULL,'Fayetteville, NC 28305',8636,222,NULL,33,11894,0);
INSERT INTO "django_geo_db_location" VALUES(20824,NULL,'Fayetteville, NC 28306',8636,222,NULL,33,11895,0);
INSERT INTO "django_geo_db_location" VALUES(20825,NULL,'Fort Bragg, NC',8637,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20826,NULL,'Fort Bragg, NC 28307',8637,222,NULL,33,11896,0);
INSERT INTO "django_geo_db_location" VALUES(20827,NULL,'Pope A F B, NC',8638,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20828,NULL,'Pope A F B, NC 28308',8638,222,NULL,33,11897,0);
INSERT INTO "django_geo_db_location" VALUES(20829,NULL,'Fayetteville, NC 28309',8636,222,NULL,33,11898,0);
INSERT INTO "django_geo_db_location" VALUES(20830,NULL,'Fort Bragg, NC 28310',8637,222,NULL,33,11899,0);
INSERT INTO "django_geo_db_location" VALUES(20831,NULL,'Fayetteville, NC 28311',8636,222,NULL,33,11900,0);
INSERT INTO "django_geo_db_location" VALUES(20832,NULL,'Fayetteville, NC 28314',8636,222,NULL,33,11901,0);
INSERT INTO "django_geo_db_location" VALUES(20833,NULL,'Aberdeen, NC',8639,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20834,NULL,'Aberdeen, NC 28315',8639,222,NULL,33,11902,0);
INSERT INTO "django_geo_db_location" VALUES(20835,NULL,'Autryville, NC',8640,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20836,NULL,'Autryville, NC 28318',8640,222,NULL,33,11903,0);
INSERT INTO "django_geo_db_location" VALUES(20837,NULL,'Barnesville, NC',8641,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20838,NULL,'Barnesville, NC 28319',8641,222,NULL,33,11904,0);
INSERT INTO "django_geo_db_location" VALUES(20839,NULL,'Bladenboro, NC',8642,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20840,NULL,'Bladenboro, NC 28320',8642,222,NULL,33,11905,0);
INSERT INTO "django_geo_db_location" VALUES(20841,NULL,'Bunnlevel, NC',8643,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20842,NULL,'Bunnlevel, NC 28323',8643,222,NULL,33,11906,0);
INSERT INTO "django_geo_db_location" VALUES(20843,NULL,'Calypso, NC',8644,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20844,NULL,'Calypso, NC 28325',8644,222,NULL,33,11907,0);
INSERT INTO "django_geo_db_location" VALUES(20845,NULL,'Cameron, NC',8645,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20846,NULL,'Cameron, NC 28326',8645,222,NULL,33,11908,0);
INSERT INTO "django_geo_db_location" VALUES(20847,NULL,'Carthage, NC',8646,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20848,NULL,'Carthage, NC 28327',8646,222,NULL,33,11909,0);
INSERT INTO "django_geo_db_location" VALUES(20849,NULL,'Clinton, NC',8647,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20850,NULL,'Clinton, NC 28328',8647,222,NULL,33,11910,0);
INSERT INTO "django_geo_db_location" VALUES(20851,NULL,'Clinton, NC 28329',8647,222,NULL,33,11911,0);
INSERT INTO "django_geo_db_location" VALUES(20852,NULL,'Cordova, NC',8648,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20853,NULL,'Cordova, NC 28330',8648,222,NULL,33,11912,0);
INSERT INTO "django_geo_db_location" VALUES(20854,NULL,'Cumberland, NC',8649,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20855,NULL,'Cumberland, NC 28331',8649,222,NULL,33,11913,0);
INSERT INTO "django_geo_db_location" VALUES(20856,NULL,'Dublin, NC',8650,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20857,NULL,'Dublin, NC 28332',8650,222,NULL,33,11914,0);
INSERT INTO "django_geo_db_location" VALUES(20858,NULL,'Dudley, NC',8651,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20859,NULL,'Dudley, NC 28333',8651,222,NULL,33,11915,0);
INSERT INTO "django_geo_db_location" VALUES(20860,NULL,'Dunn, NC',8652,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20861,NULL,'Dunn, NC 28334',8652,222,NULL,33,11916,0);
INSERT INTO "django_geo_db_location" VALUES(20862,NULL,'Dunn, NC 28335',8652,222,NULL,33,11917,0);
INSERT INTO "django_geo_db_location" VALUES(20863,NULL,'Elizabethtown, NC',8653,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20864,NULL,'Elizabethtown, NC 28337',8653,222,NULL,33,11918,0);
INSERT INTO "django_geo_db_location" VALUES(20865,NULL,'Ellerbe, NC',8654,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20866,NULL,'Ellerbe, NC 28338',8654,222,NULL,33,11919,0);
INSERT INTO "django_geo_db_location" VALUES(20867,NULL,'Erwin, NC',8655,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20868,NULL,'Erwin, NC 28339',8655,222,NULL,33,11920,0);
INSERT INTO "django_geo_db_location" VALUES(20869,NULL,'Fairmont, NC',8656,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20870,NULL,'Fairmont, NC 28340',8656,222,NULL,33,11921,0);
INSERT INTO "django_geo_db_location" VALUES(20871,NULL,'Faison, NC',8657,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20872,NULL,'Faison, NC 28341',8657,222,NULL,33,11922,0);
INSERT INTO "django_geo_db_location" VALUES(20873,NULL,'Falcon, NC',8658,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20874,NULL,'Falcon, NC 28342',8658,222,NULL,33,11923,0);
INSERT INTO "django_geo_db_location" VALUES(20875,NULL,'Gibson, NC',8659,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20876,NULL,'Gibson, NC 28343',8659,222,NULL,33,11924,0);
INSERT INTO "django_geo_db_location" VALUES(20877,NULL,'Godwin, NC',8660,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20878,NULL,'Godwin, NC 28344',8660,222,NULL,33,11925,0);
INSERT INTO "django_geo_db_location" VALUES(20879,NULL,'Hamlet, NC',8661,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20880,NULL,'Hamlet, NC 28345',8661,222,NULL,33,11926,0);
INSERT INTO "django_geo_db_location" VALUES(20881,NULL,'Hoffman, NC',8662,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20882,NULL,'Hoffman, NC 28347',8662,222,NULL,33,11927,0);
INSERT INTO "django_geo_db_location" VALUES(20883,NULL,'Hope Mills, NC',8663,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20884,NULL,'Hope Mills, NC 28348',8663,222,NULL,33,11928,0);
INSERT INTO "django_geo_db_location" VALUES(20885,NULL,'Kenansville, NC',8664,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20886,NULL,'Kenansville, NC 28349',8664,222,NULL,33,11929,0);
INSERT INTO "django_geo_db_location" VALUES(20887,NULL,'Lakeview, NC',8665,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20888,NULL,'Lakeview, NC 28350',8665,222,NULL,33,11930,0);
INSERT INTO "django_geo_db_location" VALUES(20889,NULL,'Laurel Hill, NC',8666,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20890,NULL,'Laurel Hill, NC 28351',8666,222,NULL,33,11931,0);
INSERT INTO "django_geo_db_location" VALUES(20891,NULL,'Laurinburg, NC',8667,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20892,NULL,'Laurinburg, NC 28352',8667,222,NULL,33,11932,0);
INSERT INTO "django_geo_db_location" VALUES(20893,NULL,'Laurinburg, NC 28353',8667,222,NULL,33,11933,0);
INSERT INTO "django_geo_db_location" VALUES(20894,NULL,'Lemon Springs, NC',8668,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20895,NULL,'Lemon Springs, NC 28355',8668,222,NULL,33,11934,0);
INSERT INTO "django_geo_db_location" VALUES(20896,NULL,'Linden, NC',8669,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20897,NULL,'Linden, NC 28356',8669,222,NULL,33,11935,0);
INSERT INTO "django_geo_db_location" VALUES(20898,NULL,'Lumber Bridge, NC',8670,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20899,NULL,'Lumber Bridge, NC 28357',8670,222,NULL,33,11936,0);
INSERT INTO "django_geo_db_location" VALUES(20900,NULL,'Lumberton, NC',8671,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20901,NULL,'Lumberton, NC 28358',8671,222,NULL,33,11937,0);
INSERT INTO "django_geo_db_location" VALUES(20902,NULL,'Lumberton, NC 28359',8671,222,NULL,33,11938,0);
INSERT INTO "django_geo_db_location" VALUES(20903,NULL,'Lumberton, NC 28360',8671,222,NULL,33,11939,0);
INSERT INTO "django_geo_db_location" VALUES(20904,NULL,'Mccain, NC',8672,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20905,NULL,'Mccain, NC 28361',8672,222,NULL,33,11940,0);
INSERT INTO "django_geo_db_location" VALUES(20906,NULL,'Marietta, NC',8673,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20907,NULL,'Marietta, NC 28362',8673,222,NULL,33,11941,0);
INSERT INTO "django_geo_db_location" VALUES(20908,NULL,'Marston, NC',8674,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20909,NULL,'Marston, NC 28363',8674,222,NULL,33,11942,0);
INSERT INTO "django_geo_db_location" VALUES(20910,NULL,'Maxton, NC',8675,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20911,NULL,'Maxton, NC 28364',8675,222,NULL,33,11943,0);
INSERT INTO "django_geo_db_location" VALUES(20912,NULL,'Mount Olive, NC',8676,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20913,NULL,'Mount Olive, NC 28365',8676,222,NULL,33,11944,0);
INSERT INTO "django_geo_db_location" VALUES(20914,NULL,'Newton Grove, NC',8677,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20915,NULL,'Newton Grove, NC 28366',8677,222,NULL,33,11945,0);
INSERT INTO "django_geo_db_location" VALUES(20916,NULL,'Norman, NC',8678,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20917,NULL,'Norman, NC 28367',8678,222,NULL,33,11946,0);
INSERT INTO "django_geo_db_location" VALUES(20918,NULL,'Olivia, NC',8679,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20919,NULL,'Olivia, NC 28368',8679,222,NULL,33,11947,0);
INSERT INTO "django_geo_db_location" VALUES(20920,NULL,'Orrum, NC',8680,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20921,NULL,'Orrum, NC 28369',8680,222,NULL,33,11948,0);
INSERT INTO "django_geo_db_location" VALUES(20922,NULL,'Pinehurst, NC',8681,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20923,NULL,'Pinehurst, NC 28370',8681,222,NULL,33,11949,0);
INSERT INTO "django_geo_db_location" VALUES(20924,NULL,'Parkton, NC',8682,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20925,NULL,'Parkton, NC 28371',8682,222,NULL,33,11950,0);
INSERT INTO "django_geo_db_location" VALUES(20926,NULL,'Pembroke, NC',8683,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20927,NULL,'Pembroke, NC 28372',8683,222,NULL,33,11951,0);
INSERT INTO "django_geo_db_location" VALUES(20928,NULL,'Pinebluff, NC',8684,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20929,NULL,'Pinebluff, NC 28373',8684,222,NULL,33,11952,0);
INSERT INTO "django_geo_db_location" VALUES(20930,NULL,'Pinehurst, NC 28374',8681,222,NULL,33,11953,0);
INSERT INTO "django_geo_db_location" VALUES(20931,NULL,'Proctorville, NC',8685,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20932,NULL,'Proctorville, NC 28375',8685,222,NULL,33,11954,0);
INSERT INTO "django_geo_db_location" VALUES(20933,NULL,'Raeford, NC',8686,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20934,NULL,'Raeford, NC 28376',8686,222,NULL,33,11955,0);
INSERT INTO "django_geo_db_location" VALUES(20935,NULL,'Red Springs, NC',8687,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20936,NULL,'Red Springs, NC 28377',8687,222,NULL,33,11956,0);
INSERT INTO "django_geo_db_location" VALUES(20937,NULL,'Rex, NC',8688,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20938,NULL,'Rex, NC 28378',8688,222,NULL,33,11957,0);
INSERT INTO "django_geo_db_location" VALUES(20939,NULL,'Rockingham, NC',8689,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20940,NULL,'Rockingham, NC 28379',8689,222,NULL,33,11958,0);
INSERT INTO "django_geo_db_location" VALUES(20941,NULL,'Rockingham, NC 28380',8689,222,NULL,33,11959,0);
INSERT INTO "django_geo_db_location" VALUES(20942,NULL,'Roseboro, NC',8690,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20943,NULL,'Roseboro, NC 28382',8690,222,NULL,33,11960,0);
INSERT INTO "django_geo_db_location" VALUES(20944,NULL,'Rowland, NC',8691,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20945,NULL,'Rowland, NC 28383',8691,222,NULL,33,11961,0);
INSERT INTO "django_geo_db_location" VALUES(20946,NULL,'Saint Pauls, NC',8692,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20947,NULL,'Saint Pauls, NC 28384',8692,222,NULL,33,11962,0);
INSERT INTO "django_geo_db_location" VALUES(20948,NULL,'Salemburg, NC',8693,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20949,NULL,'Salemburg, NC 28385',8693,222,NULL,33,11963,0);
INSERT INTO "django_geo_db_location" VALUES(20950,NULL,'Shannon, NC',8694,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20951,NULL,'Shannon, NC 28386',8694,222,NULL,33,11964,0);
INSERT INTO "django_geo_db_location" VALUES(20952,NULL,'Southern Pines, NC',8695,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20953,NULL,'Southern Pines, NC 28387',8695,222,NULL,33,11965,0);
INSERT INTO "django_geo_db_location" VALUES(20954,NULL,'Southern Pines, NC 28388',8695,222,NULL,33,11966,0);
INSERT INTO "django_geo_db_location" VALUES(20955,NULL,'Spring Lake, NC',8696,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20956,NULL,'Spring Lake, NC 28390',8696,222,NULL,33,11967,0);
INSERT INTO "django_geo_db_location" VALUES(20957,NULL,'Stedman, NC',8697,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20958,NULL,'Stedman, NC 28391',8697,222,NULL,33,11968,0);
INSERT INTO "django_geo_db_location" VALUES(20959,NULL,'Tar Heel, NC',8698,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20960,NULL,'Tar Heel, NC 28392',8698,222,NULL,33,11969,0);
INSERT INTO "django_geo_db_location" VALUES(20961,NULL,'Turkey, NC',8699,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20962,NULL,'Turkey, NC 28393',8699,222,NULL,33,11970,0);
INSERT INTO "django_geo_db_location" VALUES(20963,NULL,'Vass, NC',8700,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20964,NULL,'Vass, NC 28394',8700,222,NULL,33,11971,0);
INSERT INTO "django_geo_db_location" VALUES(20965,NULL,'Wade, NC',8701,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20966,NULL,'Wade, NC 28395',8701,222,NULL,33,11972,0);
INSERT INTO "django_geo_db_location" VALUES(20967,NULL,'Wagram, NC',8702,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20968,NULL,'Wagram, NC 28396',8702,222,NULL,33,11973,0);
INSERT INTO "django_geo_db_location" VALUES(20969,NULL,'Stedman, NC 28397',8697,222,NULL,33,11974,0);
INSERT INTO "django_geo_db_location" VALUES(20970,NULL,'Warsaw, NC',8703,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20971,NULL,'Warsaw, NC 28398',8703,222,NULL,33,11975,0);
INSERT INTO "django_geo_db_location" VALUES(20972,NULL,'White Oak, NC',8704,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20973,NULL,'White Oak, NC 28399',8704,222,NULL,33,11976,0);
INSERT INTO "django_geo_db_location" VALUES(20974,NULL,'Wilmington, NC',8705,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20975,NULL,'Wilmington, NC 28401',8705,222,NULL,33,11977,0);
INSERT INTO "django_geo_db_location" VALUES(20976,NULL,'Wilmington, NC 28402',8705,222,NULL,33,11978,0);
INSERT INTO "django_geo_db_location" VALUES(20977,NULL,'Wilmington, NC 28403',8705,222,NULL,33,11979,0);
INSERT INTO "django_geo_db_location" VALUES(20978,NULL,'Wilmington, NC 28404',8705,222,NULL,33,11980,0);
INSERT INTO "django_geo_db_location" VALUES(20979,NULL,'Wilmington, NC 28405',8705,222,NULL,33,11981,0);
INSERT INTO "django_geo_db_location" VALUES(20980,NULL,'Wilmington, NC 28406',8705,222,NULL,33,11982,0);
INSERT INTO "django_geo_db_location" VALUES(20981,NULL,'Wilmington, NC 28407',8705,222,NULL,33,11983,0);
INSERT INTO "django_geo_db_location" VALUES(20982,NULL,'Wilmington, NC 28408',8705,222,NULL,33,11984,0);
INSERT INTO "django_geo_db_location" VALUES(20983,NULL,'Wilmington, NC 28409',8705,222,NULL,33,11985,0);
INSERT INTO "django_geo_db_location" VALUES(20984,NULL,'Wilmington, NC 28410',8705,222,NULL,33,11986,0);
INSERT INTO "django_geo_db_location" VALUES(20985,NULL,'Wilmington, NC 28411',8705,222,NULL,33,11987,0);
INSERT INTO "django_geo_db_location" VALUES(20986,NULL,'Wilmington, NC 28412',8705,222,NULL,33,11988,0);
INSERT INTO "django_geo_db_location" VALUES(20987,NULL,'Ash, NC',8706,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20988,NULL,'Ash, NC 28420',8706,222,NULL,33,11989,0);
INSERT INTO "django_geo_db_location" VALUES(20989,NULL,'Atkinson, NC',8707,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20990,NULL,'Atkinson, NC 28421',8707,222,NULL,33,11990,0);
INSERT INTO "django_geo_db_location" VALUES(20991,NULL,'Bolivia, NC',8708,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20992,NULL,'Bolivia, NC 28422',8708,222,NULL,33,11991,0);
INSERT INTO "django_geo_db_location" VALUES(20993,NULL,'Bolton, NC',8709,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20994,NULL,'Bolton, NC 28423',8709,222,NULL,33,11992,0);
INSERT INTO "django_geo_db_location" VALUES(20995,NULL,'Brunswick, NC',8710,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20996,NULL,'Brunswick, NC 28424',8710,222,NULL,33,11993,0);
INSERT INTO "django_geo_db_location" VALUES(20997,NULL,'Burgaw, NC',8711,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(20998,NULL,'Burgaw, NC 28425',8711,222,NULL,33,11994,0);
INSERT INTO "django_geo_db_location" VALUES(20999,NULL,'Carolina Beach, NC',8712,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21000,NULL,'Carolina Beach, NC 28428',8712,222,NULL,33,11995,0);
INSERT INTO "django_geo_db_location" VALUES(21001,NULL,'Castle Hayne, NC',8713,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21002,NULL,'Castle Hayne, NC 28429',8713,222,NULL,33,11996,0);
INSERT INTO "django_geo_db_location" VALUES(21003,NULL,'Cerro Gordo, NC',8714,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21004,NULL,'Cerro Gordo, NC 28430',8714,222,NULL,33,11997,0);
INSERT INTO "django_geo_db_location" VALUES(21005,NULL,'Chadbourn, NC',8715,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21006,NULL,'Chadbourn, NC 28431',8715,222,NULL,33,11998,0);
INSERT INTO "django_geo_db_location" VALUES(21007,NULL,'Clarendon, NC',8716,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21008,NULL,'Clarendon, NC 28432',8716,222,NULL,33,11999,0);
INSERT INTO "django_geo_db_location" VALUES(21009,NULL,'Clarkton, NC',8717,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21010,NULL,'Clarkton, NC 28433',8717,222,NULL,33,12000,0);
INSERT INTO "django_geo_db_location" VALUES(21011,NULL,'Council, NC',8718,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21012,NULL,'Council, NC 28434',8718,222,NULL,33,12001,0);
INSERT INTO "django_geo_db_location" VALUES(21013,NULL,'Currie, NC',8719,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21014,NULL,'Currie, NC 28435',8719,222,NULL,33,12002,0);
INSERT INTO "django_geo_db_location" VALUES(21015,NULL,'Delco, NC',8720,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21016,NULL,'Delco, NC 28436',8720,222,NULL,33,12003,0);
INSERT INTO "django_geo_db_location" VALUES(21017,NULL,'Evergreen, NC',8721,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21018,NULL,'Evergreen, NC 28438',8721,222,NULL,33,12004,0);
INSERT INTO "django_geo_db_location" VALUES(21019,NULL,'Fair Bluff, NC',8722,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21020,NULL,'Fair Bluff, NC 28439',8722,222,NULL,33,12005,0);
INSERT INTO "django_geo_db_location" VALUES(21021,NULL,'Garland, NC',8723,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21022,NULL,'Garland, NC 28441',8723,222,NULL,33,12006,0);
INSERT INTO "django_geo_db_location" VALUES(21023,NULL,'Hallsboro, NC',8724,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21024,NULL,'Hallsboro, NC 28442',8724,222,NULL,33,12007,0);
INSERT INTO "django_geo_db_location" VALUES(21025,NULL,'Hampstead, NC',8725,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21026,NULL,'Hampstead, NC 28443',8725,222,NULL,33,12008,0);
INSERT INTO "django_geo_db_location" VALUES(21027,NULL,'Harrells, NC',8726,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21028,NULL,'Harrells, NC 28444',8726,222,NULL,33,12009,0);
INSERT INTO "django_geo_db_location" VALUES(21029,NULL,'Holly Ridge, NC',8727,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21030,NULL,'Holly Ridge, NC 28445',8727,222,NULL,33,12010,0);
INSERT INTO "django_geo_db_location" VALUES(21031,NULL,'Ingold, NC',8728,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21032,NULL,'Ingold, NC 28446',8728,222,NULL,33,12011,0);
INSERT INTO "django_geo_db_location" VALUES(21033,NULL,'Ivanhoe, NC',8729,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21034,NULL,'Ivanhoe, NC 28447',8729,222,NULL,33,12012,0);
INSERT INTO "django_geo_db_location" VALUES(21035,NULL,'Kelly, NC',8730,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21036,NULL,'Kelly, NC 28448',8730,222,NULL,33,12013,0);
INSERT INTO "django_geo_db_location" VALUES(21037,NULL,'Kure Beach, NC',8731,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21038,NULL,'Kure Beach, NC 28449',8731,222,NULL,33,12014,0);
INSERT INTO "django_geo_db_location" VALUES(21039,NULL,'Lake Waccamaw, NC',8732,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21040,NULL,'Lake Waccamaw, NC 28450',8732,222,NULL,33,12015,0);
INSERT INTO "django_geo_db_location" VALUES(21041,NULL,'Leland, NC',8733,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21042,NULL,'Leland, NC 28451',8733,222,NULL,33,12016,0);
INSERT INTO "django_geo_db_location" VALUES(21043,NULL,'Longwood, NC',8734,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21044,NULL,'Longwood, NC 28452',8734,222,NULL,33,12017,0);
INSERT INTO "django_geo_db_location" VALUES(21045,NULL,'Magnolia, NC',8735,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21046,NULL,'Magnolia, NC 28453',8735,222,NULL,33,12018,0);
INSERT INTO "django_geo_db_location" VALUES(21047,NULL,'Maple Hill, NC',8736,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21048,NULL,'Maple Hill, NC 28454',8736,222,NULL,33,12019,0);
INSERT INTO "django_geo_db_location" VALUES(21049,NULL,'Nakina, NC',8737,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21050,NULL,'Nakina, NC 28455',8737,222,NULL,33,12020,0);
INSERT INTO "django_geo_db_location" VALUES(21051,NULL,'Riegelwood, NC',8738,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21052,NULL,'Riegelwood, NC 28456',8738,222,NULL,33,12021,0);
INSERT INTO "django_geo_db_location" VALUES(21053,NULL,'Rocky Point, NC',8739,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21054,NULL,'Rocky Point, NC 28457',8739,222,NULL,33,12022,0);
INSERT INTO "django_geo_db_location" VALUES(21055,NULL,'Rose Hill, NC',8740,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21056,NULL,'Rose Hill, NC 28458',8740,222,NULL,33,12023,0);
INSERT INTO "django_geo_db_location" VALUES(21057,NULL,'Shallotte, NC',8741,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21058,NULL,'Shallotte, NC 28459',8741,222,NULL,33,12024,0);
INSERT INTO "django_geo_db_location" VALUES(21059,NULL,'Sneads Ferry, NC',8742,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21060,NULL,'Sneads Ferry, NC 28460',8742,222,NULL,33,12025,0);
INSERT INTO "django_geo_db_location" VALUES(21061,NULL,'Southport, NC',8743,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21062,NULL,'Southport, NC 28461',8743,222,NULL,33,12026,0);
INSERT INTO "django_geo_db_location" VALUES(21063,NULL,'Supply, NC',8744,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21064,NULL,'Supply, NC 28462',8744,222,NULL,33,12027,0);
INSERT INTO "django_geo_db_location" VALUES(21065,NULL,'Tabor City, NC',8745,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21066,NULL,'Tabor City, NC 28463',8745,222,NULL,33,12028,0);
INSERT INTO "django_geo_db_location" VALUES(21067,NULL,'Teachey, NC',8746,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21068,NULL,'Teachey, NC 28464',8746,222,NULL,33,12029,0);
INSERT INTO "django_geo_db_location" VALUES(21069,NULL,'Oak Island, NC',8747,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21070,NULL,'Oak Island, NC 28465',8747,222,NULL,33,12030,0);
INSERT INTO "django_geo_db_location" VALUES(21071,NULL,'Wallace, NC',8748,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21072,NULL,'Wallace, NC 28466',8748,222,NULL,33,12031,0);
INSERT INTO "django_geo_db_location" VALUES(21073,NULL,'Calabash, NC',8749,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21074,NULL,'Calabash, NC 28467',8749,222,NULL,33,12032,0);
INSERT INTO "django_geo_db_location" VALUES(21075,NULL,'Sunset Beach, NC',8750,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21076,NULL,'Sunset Beach, NC 28468',8750,222,NULL,33,12033,0);
INSERT INTO "django_geo_db_location" VALUES(21077,NULL,'Ocean Isle Beach, NC',8751,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21078,NULL,'Ocean Isle Beach, NC 28469',8751,222,NULL,33,12034,0);
INSERT INTO "django_geo_db_location" VALUES(21079,NULL,'South Brunswick, NC',8752,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21080,NULL,'South Brunswick, NC 28470',8752,222,NULL,33,12035,0);
INSERT INTO "django_geo_db_location" VALUES(21081,NULL,'Watha, NC',8753,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21082,NULL,'Watha, NC 28471',8753,222,NULL,33,12036,0);
INSERT INTO "django_geo_db_location" VALUES(21083,NULL,'Whiteville, NC',8754,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21084,NULL,'Whiteville, NC 28472',8754,222,NULL,33,12037,0);
INSERT INTO "django_geo_db_location" VALUES(21085,NULL,'Willard, NC',8755,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21086,NULL,'Willard, NC 28478',8755,222,NULL,33,12038,0);
INSERT INTO "django_geo_db_location" VALUES(21087,NULL,'Winnabow, NC',8756,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21088,NULL,'Winnabow, NC 28479',8756,222,NULL,33,12039,0);
INSERT INTO "django_geo_db_location" VALUES(21089,NULL,'Wrightsville Beach, NC',8757,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21090,NULL,'Wrightsville Beach, NC 28480',8757,222,NULL,33,12040,0);
INSERT INTO "django_geo_db_location" VALUES(21091,NULL,'Kinston, NC',8758,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21092,NULL,'Kinston, NC 28501',8758,222,NULL,33,12041,0);
INSERT INTO "django_geo_db_location" VALUES(21093,NULL,'Kinston, NC 28502',8758,222,NULL,33,12042,0);
INSERT INTO "django_geo_db_location" VALUES(21094,NULL,'Kinston, NC 28503',8758,222,NULL,33,12043,0);
INSERT INTO "django_geo_db_location" VALUES(21095,NULL,'Kinston, NC 28504',8758,222,NULL,33,12044,0);
INSERT INTO "django_geo_db_location" VALUES(21096,NULL,'Albertson, NC',8759,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21097,NULL,'Albertson, NC 28508',8759,222,NULL,33,12045,0);
INSERT INTO "django_geo_db_location" VALUES(21098,NULL,'Alliance, NC',8760,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21099,NULL,'Alliance, NC 28509',8760,222,NULL,33,12046,0);
INSERT INTO "django_geo_db_location" VALUES(21100,NULL,'Arapahoe, NC',8761,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21101,NULL,'Arapahoe, NC 28510',8761,222,NULL,33,12047,0);
INSERT INTO "django_geo_db_location" VALUES(21102,NULL,'Atlantic, NC',8762,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21103,NULL,'Atlantic, NC 28511',8762,222,NULL,33,12048,0);
INSERT INTO "django_geo_db_location" VALUES(21104,NULL,'Atlantic Beach, NC',8763,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21105,NULL,'Atlantic Beach, NC 28512',8763,222,NULL,33,12049,0);
INSERT INTO "django_geo_db_location" VALUES(21106,NULL,'Ayden, NC',8764,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21107,NULL,'Ayden, NC 28513',8764,222,NULL,33,12050,0);
INSERT INTO "django_geo_db_location" VALUES(21108,NULL,'Bayboro, NC',8765,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21109,NULL,'Bayboro, NC 28515',8765,222,NULL,33,12051,0);
INSERT INTO "django_geo_db_location" VALUES(21110,NULL,'Beaufort, NC',8766,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21111,NULL,'Beaufort, NC 28516',8766,222,NULL,33,12052,0);
INSERT INTO "django_geo_db_location" VALUES(21112,NULL,'Beulaville, NC',8767,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21113,NULL,'Beulaville, NC 28518',8767,222,NULL,33,12053,0);
INSERT INTO "django_geo_db_location" VALUES(21114,NULL,'Bridgeton, NC',8768,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21115,NULL,'Bridgeton, NC 28519',8768,222,NULL,33,12054,0);
INSERT INTO "django_geo_db_location" VALUES(21116,NULL,'Cedar Island, NC',8769,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21117,NULL,'Cedar Island, NC 28520',8769,222,NULL,33,12055,0);
INSERT INTO "django_geo_db_location" VALUES(21118,NULL,'Chinquapin, NC',8770,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21119,NULL,'Chinquapin, NC 28521',8770,222,NULL,33,12056,0);
INSERT INTO "django_geo_db_location" VALUES(21120,NULL,'Comfort, NC',8771,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21121,NULL,'Comfort, NC 28522',8771,222,NULL,33,12057,0);
INSERT INTO "django_geo_db_location" VALUES(21122,NULL,'Cove City, NC',8772,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21123,NULL,'Cove City, NC 28523',8772,222,NULL,33,12058,0);
INSERT INTO "django_geo_db_location" VALUES(21124,NULL,'Davis, NC',8773,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21125,NULL,'Davis, NC 28524',8773,222,NULL,33,12059,0);
INSERT INTO "django_geo_db_location" VALUES(21126,NULL,'Deep Run, NC',8774,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21127,NULL,'Deep Run, NC 28525',8774,222,NULL,33,12060,0);
INSERT INTO "django_geo_db_location" VALUES(21128,NULL,'Dover, NC',8775,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21129,NULL,'Dover, NC 28526',8775,222,NULL,33,12061,0);
INSERT INTO "django_geo_db_location" VALUES(21130,NULL,'Ernul, NC',8776,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21131,NULL,'Ernul, NC 28527',8776,222,NULL,33,12062,0);
INSERT INTO "django_geo_db_location" VALUES(21132,NULL,'Gloucester, NC',8777,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21133,NULL,'Gloucester, NC 28528',8777,222,NULL,33,12063,0);
INSERT INTO "django_geo_db_location" VALUES(21134,NULL,'Grantsboro, NC',8778,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21135,NULL,'Grantsboro, NC 28529',8778,222,NULL,33,12064,0);
INSERT INTO "django_geo_db_location" VALUES(21136,NULL,'Grifton, NC',8779,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21137,NULL,'Grifton, NC 28530',8779,222,NULL,33,12065,0);
INSERT INTO "django_geo_db_location" VALUES(21138,NULL,'Harkers Island, NC',8780,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21139,NULL,'Harkers Island, NC 28531',8780,222,NULL,33,12066,0);
INSERT INTO "django_geo_db_location" VALUES(21140,NULL,'Havelock, NC',8781,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21141,NULL,'Havelock, NC 28532',8781,222,NULL,33,12067,0);
INSERT INTO "django_geo_db_location" VALUES(21142,NULL,'Cherry Point, NC',8782,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21143,NULL,'Cherry Point, NC 28533',8782,222,NULL,33,12068,0);
INSERT INTO "django_geo_db_location" VALUES(21144,NULL,'Hobucken, NC',8783,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21145,NULL,'Hobucken, NC 28537',8783,222,NULL,33,12069,0);
INSERT INTO "django_geo_db_location" VALUES(21146,NULL,'Hookerton, NC',8784,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21147,NULL,'Hookerton, NC 28538',8784,222,NULL,33,12070,0);
INSERT INTO "django_geo_db_location" VALUES(21148,NULL,'Hubert, NC',8785,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21149,NULL,'Hubert, NC 28539',8785,222,NULL,33,12071,0);
INSERT INTO "django_geo_db_location" VALUES(21150,NULL,'Jacksonville, NC',8786,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21151,NULL,'Jacksonville, NC 28540',8786,222,NULL,33,12072,0);
INSERT INTO "django_geo_db_location" VALUES(21152,NULL,'Jacksonville, NC 28541',8786,222,NULL,33,12073,0);
INSERT INTO "django_geo_db_location" VALUES(21153,NULL,'Camp Lejeune, NC',8787,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21154,NULL,'Camp Lejeune, NC 28542',8787,222,NULL,33,12074,0);
INSERT INTO "django_geo_db_location" VALUES(21155,NULL,'Tarawa Terrace, NC',8788,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21156,NULL,'Tarawa Terrace, NC 28543',8788,222,NULL,33,12075,0);
INSERT INTO "django_geo_db_location" VALUES(21157,NULL,'Midway Park, NC',8789,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21158,NULL,'Midway Park, NC 28544',8789,222,NULL,33,12076,0);
INSERT INTO "django_geo_db_location" VALUES(21159,NULL,'Mccutcheon Field, NC',8790,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21160,NULL,'Mccutcheon Field, NC 28545',8790,222,NULL,33,12077,0);
INSERT INTO "django_geo_db_location" VALUES(21161,NULL,'Jacksonville, NC 28546',8786,222,NULL,33,12078,0);
INSERT INTO "django_geo_db_location" VALUES(21162,NULL,'Camp Lejeune, NC 28547',8787,222,NULL,33,12079,0);
INSERT INTO "django_geo_db_location" VALUES(21163,NULL,'La Grange, NC',8791,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21164,NULL,'La Grange, NC 28551',8791,222,NULL,33,12080,0);
INSERT INTO "django_geo_db_location" VALUES(21165,NULL,'Lowland, NC',8792,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21166,NULL,'Lowland, NC 28552',8792,222,NULL,33,12081,0);
INSERT INTO "django_geo_db_location" VALUES(21167,NULL,'Marshallberg, NC',8793,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21168,NULL,'Marshallberg, NC 28553',8793,222,NULL,33,12082,0);
INSERT INTO "django_geo_db_location" VALUES(21169,NULL,'Maury, NC',8794,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21170,NULL,'Maury, NC 28554',8794,222,NULL,33,12083,0);
INSERT INTO "django_geo_db_location" VALUES(21171,NULL,'Maysville, NC',8795,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21172,NULL,'Maysville, NC 28555',8795,222,NULL,33,12084,0);
INSERT INTO "django_geo_db_location" VALUES(21173,NULL,'Merritt, NC',8796,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21174,NULL,'Merritt, NC 28556',8796,222,NULL,33,12085,0);
INSERT INTO "django_geo_db_location" VALUES(21175,NULL,'Morehead City, NC',8797,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21176,NULL,'Morehead City, NC 28557',8797,222,NULL,33,12086,0);
INSERT INTO "django_geo_db_location" VALUES(21177,NULL,'Fairplains, NC',8798,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21178,NULL,'Fairplains, NC 28559',8798,222,NULL,33,12087,0);
INSERT INTO "django_geo_db_location" VALUES(21179,NULL,'New Bern, NC',8799,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21180,NULL,'New Bern, NC 28560',8799,222,NULL,33,12088,0);
INSERT INTO "django_geo_db_location" VALUES(21181,NULL,'New Bern, NC 28561',8799,222,NULL,33,12089,0);
INSERT INTO "django_geo_db_location" VALUES(21182,NULL,'New Bern, NC 28562',8799,222,NULL,33,12090,0);
INSERT INTO "django_geo_db_location" VALUES(21183,NULL,'New Bern, NC 28563',8799,222,NULL,33,12091,0);
INSERT INTO "django_geo_db_location" VALUES(21184,NULL,'New Bern, NC 28564',8799,222,NULL,33,12092,0);
INSERT INTO "django_geo_db_location" VALUES(21185,NULL,'Newport, NC',8800,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21186,NULL,'Newport, NC 28570',8800,222,NULL,33,12093,0);
INSERT INTO "django_geo_db_location" VALUES(21187,NULL,'Oriental, NC',8801,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21188,NULL,'Oriental, NC 28571',8801,222,NULL,33,12094,0);
INSERT INTO "django_geo_db_location" VALUES(21189,NULL,'Pink Hill, NC',8802,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21190,NULL,'Pink Hill, NC 28572',8802,222,NULL,33,12095,0);
INSERT INTO "django_geo_db_location" VALUES(21191,NULL,'Pollocksville, NC',8803,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21192,NULL,'Pollocksville, NC 28573',8803,222,NULL,33,12096,0);
INSERT INTO "django_geo_db_location" VALUES(21193,NULL,'Richlands, NC',8804,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21194,NULL,'Richlands, NC 28574',8804,222,NULL,33,12097,0);
INSERT INTO "django_geo_db_location" VALUES(21195,NULL,'Salter Path, NC',8805,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21196,NULL,'Salter Path, NC 28575',8805,222,NULL,33,12098,0);
INSERT INTO "django_geo_db_location" VALUES(21197,NULL,'Sealevel, NC',8806,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21198,NULL,'Sealevel, NC 28577',8806,222,NULL,33,12099,0);
INSERT INTO "django_geo_db_location" VALUES(21199,NULL,'Seven Springs, NC',8807,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21200,NULL,'Seven Springs, NC 28578',8807,222,NULL,33,12100,0);
INSERT INTO "django_geo_db_location" VALUES(21201,NULL,'Smyrna, NC',8808,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21202,NULL,'Smyrna, NC 28579',8808,222,NULL,33,12101,0);
INSERT INTO "django_geo_db_location" VALUES(21203,NULL,'Snow Hill, NC',8809,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21204,NULL,'Snow Hill, NC 28580',8809,222,NULL,33,12102,0);
INSERT INTO "django_geo_db_location" VALUES(21205,NULL,'Stacy, NC',8810,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21206,NULL,'Stacy, NC 28581',8810,222,NULL,33,12103,0);
INSERT INTO "django_geo_db_location" VALUES(21207,NULL,'Stella, NC',8811,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21208,NULL,'Stella, NC 28582',8811,222,NULL,33,12104,0);
INSERT INTO "django_geo_db_location" VALUES(21209,NULL,'Stonewall, NC',8812,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21210,NULL,'Stonewall, NC 28583',8812,222,NULL,33,12105,0);
INSERT INTO "django_geo_db_location" VALUES(21211,NULL,'Swansboro, NC',8813,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21212,NULL,'Swansboro, NC 28584',8813,222,NULL,33,12106,0);
INSERT INTO "django_geo_db_location" VALUES(21213,NULL,'Trenton, NC',8814,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21214,NULL,'Trenton, NC 28585',8814,222,NULL,33,12107,0);
INSERT INTO "django_geo_db_location" VALUES(21215,NULL,'Vanceboro, NC',8815,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21216,NULL,'Vanceboro, NC 28586',8815,222,NULL,33,12108,0);
INSERT INTO "django_geo_db_location" VALUES(21217,NULL,'Vandemere, NC',8816,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21218,NULL,'Vandemere, NC 28587',8816,222,NULL,33,12109,0);
INSERT INTO "django_geo_db_location" VALUES(21219,NULL,'Williston, NC',8817,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21220,NULL,'Williston, NC 28589',8817,222,NULL,33,12110,0);
INSERT INTO "django_geo_db_location" VALUES(21221,NULL,'Winterville, NC',8818,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21222,NULL,'Winterville, NC 28590',8818,222,NULL,33,12111,0);
INSERT INTO "django_geo_db_location" VALUES(21223,NULL,'Emerald Isle, NC',8819,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21224,NULL,'Emerald Isle, NC 28594',8819,222,NULL,33,12112,0);
INSERT INTO "django_geo_db_location" VALUES(21225,NULL,'Emerald Isle, NC 28599',8819,222,NULL,33,12113,0);
INSERT INTO "django_geo_db_location" VALUES(21226,NULL,'Hickory, NC',8820,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21227,NULL,'Hickory, NC 28601',8820,222,NULL,33,12114,0);
INSERT INTO "django_geo_db_location" VALUES(21228,NULL,'Hickory, NC 28602',8820,222,NULL,33,12115,0);
INSERT INTO "django_geo_db_location" VALUES(21229,NULL,'Hickory, NC 28603',8820,222,NULL,33,12116,0);
INSERT INTO "django_geo_db_location" VALUES(21230,NULL,'Banner Elk, NC',8821,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21231,NULL,'Banner Elk, NC 28604',8821,222,NULL,33,12117,0);
INSERT INTO "django_geo_db_location" VALUES(21232,NULL,'Blowing Rock, NC',8822,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21233,NULL,'Blowing Rock, NC 28605',8822,222,NULL,33,12118,0);
INSERT INTO "django_geo_db_location" VALUES(21234,NULL,'Boomer, NC',8823,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21235,NULL,'Boomer, NC 28606',8823,222,NULL,33,12119,0);
INSERT INTO "django_geo_db_location" VALUES(21236,NULL,'Boone, NC',8824,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21237,NULL,'Boone, NC 28607',8824,222,NULL,33,12120,0);
INSERT INTO "django_geo_db_location" VALUES(21238,NULL,'Boone, NC 28608',8824,222,NULL,33,12121,0);
INSERT INTO "django_geo_db_location" VALUES(21239,NULL,'Catawba, NC',8825,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21240,NULL,'Catawba, NC 28609',8825,222,NULL,33,12122,0);
INSERT INTO "django_geo_db_location" VALUES(21241,NULL,'Claremont, NC',8826,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21242,NULL,'Claremont, NC 28610',8826,222,NULL,33,12123,0);
INSERT INTO "django_geo_db_location" VALUES(21243,NULL,'Collettsville, NC',8827,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21244,NULL,'Collettsville, NC 28611',8827,222,NULL,33,12124,0);
INSERT INTO "django_geo_db_location" VALUES(21245,NULL,'Connellys Springs, NC',8828,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21246,NULL,'Connellys Springs, NC 28612',8828,222,NULL,33,12125,0);
INSERT INTO "django_geo_db_location" VALUES(21247,NULL,'Conover, NC',8829,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21248,NULL,'Conover, NC 28613',8829,222,NULL,33,12126,0);
INSERT INTO "django_geo_db_location" VALUES(21249,NULL,'Creston, NC',8830,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21250,NULL,'Creston, NC 28615',8830,222,NULL,33,12127,0);
INSERT INTO "django_geo_db_location" VALUES(21251,NULL,'Crossnore, NC',8831,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21252,NULL,'Crossnore, NC 28616',8831,222,NULL,33,12128,0);
INSERT INTO "django_geo_db_location" VALUES(21253,NULL,'Crumpler, NC',8832,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21254,NULL,'Crumpler, NC 28617',8832,222,NULL,33,12129,0);
INSERT INTO "django_geo_db_location" VALUES(21255,NULL,'Deep Gap, NC',8833,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21256,NULL,'Deep Gap, NC 28618',8833,222,NULL,33,12130,0);
INSERT INTO "django_geo_db_location" VALUES(21257,NULL,'Drexel, NC',8834,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21258,NULL,'Drexel, NC 28619',8834,222,NULL,33,12131,0);
INSERT INTO "django_geo_db_location" VALUES(21259,NULL,'Pleasant Hill, NC 28620',8461,222,NULL,33,12132,0);
INSERT INTO "django_geo_db_location" VALUES(21260,NULL,'Elkin, NC',8835,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21261,NULL,'Elkin, NC 28621',8835,222,NULL,33,12133,0);
INSERT INTO "django_geo_db_location" VALUES(21262,NULL,'Elk Park, NC',8836,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21263,NULL,'Elk Park, NC 28622',8836,222,NULL,33,12134,0);
INSERT INTO "django_geo_db_location" VALUES(21264,NULL,'Ennice, NC',8837,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21265,NULL,'Ennice, NC 28623',8837,222,NULL,33,12135,0);
INSERT INTO "django_geo_db_location" VALUES(21266,NULL,'Ferguson, NC',8838,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21267,NULL,'Ferguson, NC 28624',8838,222,NULL,33,12136,0);
INSERT INTO "django_geo_db_location" VALUES(21268,NULL,'Statesville, NC',8839,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21269,NULL,'Statesville, NC 28625',8839,222,NULL,33,12137,0);
INSERT INTO "django_geo_db_location" VALUES(21270,NULL,'Fleetwood, NC',8840,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21271,NULL,'Fleetwood, NC 28626',8840,222,NULL,33,12138,0);
INSERT INTO "django_geo_db_location" VALUES(21272,NULL,'Glade Valley, NC',8841,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21273,NULL,'Glade Valley, NC 28627',8841,222,NULL,33,12139,0);
INSERT INTO "django_geo_db_location" VALUES(21274,NULL,'Glen Alpine, NC',8842,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21275,NULL,'Glen Alpine, NC 28628',8842,222,NULL,33,12140,0);
INSERT INTO "django_geo_db_location" VALUES(21276,NULL,'Glendale Springs, NC',8843,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21277,NULL,'Glendale Springs, NC 28629',8843,222,NULL,33,12141,0);
INSERT INTO "django_geo_db_location" VALUES(21278,NULL,'Granite Falls, NC',8844,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21279,NULL,'Granite Falls, NC 28630',8844,222,NULL,33,12142,0);
INSERT INTO "django_geo_db_location" VALUES(21280,NULL,'Grassy Creek, NC',8845,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21281,NULL,'Grassy Creek, NC 28631',8845,222,NULL,33,12143,0);
INSERT INTO "django_geo_db_location" VALUES(21282,NULL,'Lenoir, NC',8846,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21283,NULL,'Lenoir, NC 28633',8846,222,NULL,33,12144,0);
INSERT INTO "django_geo_db_location" VALUES(21284,NULL,'Harmony, NC',8847,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21285,NULL,'Harmony, NC 28634',8847,222,NULL,33,12145,0);
INSERT INTO "django_geo_db_location" VALUES(21286,NULL,'Hays, NC',8848,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21287,NULL,'Hays, NC 28635',8848,222,NULL,33,12146,0);
INSERT INTO "django_geo_db_location" VALUES(21288,NULL,'Hiddenite, NC',8849,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21289,NULL,'Hiddenite, NC 28636',8849,222,NULL,33,12147,0);
INSERT INTO "django_geo_db_location" VALUES(21290,NULL,'Hildebran, NC',8850,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21291,NULL,'Hildebran, NC 28637',8850,222,NULL,33,12148,0);
INSERT INTO "django_geo_db_location" VALUES(21292,NULL,'Hudson, NC',8851,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21293,NULL,'Hudson, NC 28638',8851,222,NULL,33,12149,0);
INSERT INTO "django_geo_db_location" VALUES(21294,NULL,'Jefferson, NC',8852,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21295,NULL,'Jefferson, NC 28640',8852,222,NULL,33,12150,0);
INSERT INTO "django_geo_db_location" VALUES(21296,NULL,'Jonas Ridge, NC',8853,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21297,NULL,'Jonas Ridge, NC 28641',8853,222,NULL,33,12151,0);
INSERT INTO "django_geo_db_location" VALUES(21298,NULL,'Jonesville, NC',8854,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21299,NULL,'Jonesville, NC 28642',8854,222,NULL,33,12152,0);
INSERT INTO "django_geo_db_location" VALUES(21300,NULL,'Lansing, NC',8855,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21301,NULL,'Lansing, NC 28643',8855,222,NULL,33,12153,0);
INSERT INTO "django_geo_db_location" VALUES(21302,NULL,'Laurel Springs, NC',8856,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21303,NULL,'Laurel Springs, NC 28644',8856,222,NULL,33,12154,0);
INSERT INTO "django_geo_db_location" VALUES(21304,NULL,'Lenoir, NC 28645',8846,222,NULL,33,12155,0);
INSERT INTO "django_geo_db_location" VALUES(21305,NULL,'Linville, NC',8857,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21306,NULL,'Linville, NC 28646',8857,222,NULL,33,12156,0);
INSERT INTO "django_geo_db_location" VALUES(21307,NULL,'Linville Falls, NC',8858,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21308,NULL,'Linville Falls, NC 28647',8858,222,NULL,33,12157,0);
INSERT INTO "django_geo_db_location" VALUES(21309,NULL,'McGrady, NC',8859,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21310,NULL,'McGrady, NC 28649',8859,222,NULL,33,12158,0);
INSERT INTO "django_geo_db_location" VALUES(21311,NULL,'Maiden, NC',8860,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21312,NULL,'Maiden, NC 28650',8860,222,NULL,33,12159,0);
INSERT INTO "django_geo_db_location" VALUES(21313,NULL,'Millers Creek, NC',8861,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21314,NULL,'Millers Creek, NC 28651',8861,222,NULL,33,12160,0);
INSERT INTO "django_geo_db_location" VALUES(21315,NULL,'Minneapolis, NC',8862,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21316,NULL,'Minneapolis, NC 28652',8862,222,NULL,33,12161,0);
INSERT INTO "django_geo_db_location" VALUES(21317,NULL,'Montezuma, NC',8863,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21318,NULL,'Montezuma, NC 28653',8863,222,NULL,33,12162,0);
INSERT INTO "django_geo_db_location" VALUES(21319,NULL,'Moravian Falls, NC',8864,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21320,NULL,'Moravian Falls, NC 28654',8864,222,NULL,33,12163,0);
INSERT INTO "django_geo_db_location" VALUES(21321,NULL,'Morganton, NC',8865,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21322,NULL,'Morganton, NC 28655',8865,222,NULL,33,12164,0);
INSERT INTO "django_geo_db_location" VALUES(21323,NULL,'North Wilkesboro, NC',8866,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21324,NULL,'North Wilkesboro, NC 28656',8866,222,NULL,33,12165,0);
INSERT INTO "django_geo_db_location" VALUES(21325,NULL,'Newland, NC',8867,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21326,NULL,'Newland, NC 28657',8867,222,NULL,33,12166,0);
INSERT INTO "django_geo_db_location" VALUES(21327,NULL,'Newton, NC',8868,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21328,NULL,'Newton, NC 28658',8868,222,NULL,33,12167,0);
INSERT INTO "django_geo_db_location" VALUES(21329,NULL,'North Wilkesboro, NC 28659',8866,222,NULL,33,12168,0);
INSERT INTO "django_geo_db_location" VALUES(21330,NULL,'Olin, NC',8869,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21331,NULL,'Olin, NC 28660',8869,222,NULL,33,12169,0);
INSERT INTO "django_geo_db_location" VALUES(21332,NULL,'Patterson, NC',8870,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21333,NULL,'Patterson, NC 28661',8870,222,NULL,33,12170,0);
INSERT INTO "django_geo_db_location" VALUES(21334,NULL,'Pineola, NC',8871,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21335,NULL,'Pineola, NC 28662',8871,222,NULL,33,12171,0);
INSERT INTO "django_geo_db_location" VALUES(21336,NULL,'Piney Creek, NC',8872,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21337,NULL,'Piney Creek, NC 28663',8872,222,NULL,33,12172,0);
INSERT INTO "django_geo_db_location" VALUES(21338,NULL,'Plumtree, NC',8873,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21339,NULL,'Plumtree, NC 28664',8873,222,NULL,33,12173,0);
INSERT INTO "django_geo_db_location" VALUES(21340,NULL,'Purlear, NC',8874,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21341,NULL,'Purlear, NC 28665',8874,222,NULL,33,12174,0);
INSERT INTO "django_geo_db_location" VALUES(21342,NULL,'Icard, NC',8875,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21343,NULL,'Icard, NC 28666',8875,222,NULL,33,12175,0);
INSERT INTO "django_geo_db_location" VALUES(21344,NULL,'Rhodhiss, NC',8876,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21345,NULL,'Rhodhiss, NC 28667',8876,222,NULL,33,12176,0);
INSERT INTO "django_geo_db_location" VALUES(21346,NULL,'Roaring Gap, NC',8877,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21347,NULL,'Roaring Gap, NC 28668',8877,222,NULL,33,12177,0);
INSERT INTO "django_geo_db_location" VALUES(21348,NULL,'Roaring River, NC',8878,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21349,NULL,'Roaring River, NC 28669',8878,222,NULL,33,12178,0);
INSERT INTO "django_geo_db_location" VALUES(21350,NULL,'Ronda, NC',8879,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21351,NULL,'Ronda, NC 28670',8879,222,NULL,33,12179,0);
INSERT INTO "django_geo_db_location" VALUES(21352,NULL,'Rutherford College, NC',8880,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21353,NULL,'Rutherford College, NC 28671',8880,222,NULL,33,12180,0);
INSERT INTO "django_geo_db_location" VALUES(21354,NULL,'Scottville, NC',8881,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21355,NULL,'Scottville, NC 28672',8881,222,NULL,33,12181,0);
INSERT INTO "django_geo_db_location" VALUES(21356,NULL,'Sherrills Ford, NC',8882,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21357,NULL,'Sherrills Ford, NC 28673',8882,222,NULL,33,12182,0);
INSERT INTO "django_geo_db_location" VALUES(21358,NULL,'North Wilkesboro, NC 28674',8866,222,NULL,33,12183,0);
INSERT INTO "django_geo_db_location" VALUES(21359,NULL,'Sparta, NC',8883,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21360,NULL,'Sparta, NC 28675',8883,222,NULL,33,12184,0);
INSERT INTO "django_geo_db_location" VALUES(21361,NULL,'State Road, NC',8884,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21362,NULL,'State Road, NC 28676',8884,222,NULL,33,12185,0);
INSERT INTO "django_geo_db_location" VALUES(21363,NULL,'Statesville, NC 28677',8839,222,NULL,33,12186,0);
INSERT INTO "django_geo_db_location" VALUES(21364,NULL,'Stony Point, NC',8885,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21365,NULL,'Stony Point, NC 28678',8885,222,NULL,33,12187,0);
INSERT INTO "django_geo_db_location" VALUES(21366,NULL,'Sugar Grove, NC',8886,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21367,NULL,'Sugar Grove, NC 28679',8886,222,NULL,33,12188,0);
INSERT INTO "django_geo_db_location" VALUES(21368,NULL,'Morganton, NC 28680',8865,222,NULL,33,12189,0);
INSERT INTO "django_geo_db_location" VALUES(21369,NULL,'Taylorsville, NC',8887,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21370,NULL,'Taylorsville, NC 28681',8887,222,NULL,33,12190,0);
INSERT INTO "django_geo_db_location" VALUES(21371,NULL,'Terrell, NC',8888,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21372,NULL,'Terrell, NC 28682',8888,222,NULL,33,12191,0);
INSERT INTO "django_geo_db_location" VALUES(21373,NULL,'Thurmond, NC',8889,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21374,NULL,'Thurmond, NC 28683',8889,222,NULL,33,12192,0);
INSERT INTO "django_geo_db_location" VALUES(21375,NULL,'Todd, NC',8890,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21376,NULL,'Todd, NC 28684',8890,222,NULL,33,12193,0);
INSERT INTO "django_geo_db_location" VALUES(21377,NULL,'Traphill, NC',8891,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21378,NULL,'Traphill, NC 28685',8891,222,NULL,33,12194,0);
INSERT INTO "django_geo_db_location" VALUES(21379,NULL,'Statesville, NC 28687',8839,222,NULL,33,12195,0);
INSERT INTO "django_geo_db_location" VALUES(21380,NULL,'Turnersburg, NC',8892,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21381,NULL,'Turnersburg, NC 28688',8892,222,NULL,33,12196,0);
INSERT INTO "django_geo_db_location" VALUES(21382,NULL,'Union Grove, NC',8893,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21383,NULL,'Union Grove, NC 28689',8893,222,NULL,33,12197,0);
INSERT INTO "django_geo_db_location" VALUES(21384,NULL,'Valdese, NC',8894,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21385,NULL,'Valdese, NC 28690',8894,222,NULL,33,12198,0);
INSERT INTO "django_geo_db_location" VALUES(21386,NULL,'Valle Crucis, NC',8895,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21387,NULL,'Valle Crucis, NC 28691',8895,222,NULL,33,12199,0);
INSERT INTO "django_geo_db_location" VALUES(21388,NULL,'Vilas, NC',8896,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21389,NULL,'Vilas, NC 28692',8896,222,NULL,33,12200,0);
INSERT INTO "django_geo_db_location" VALUES(21390,NULL,'Warrensville, NC',8897,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21391,NULL,'Warrensville, NC 28693',8897,222,NULL,33,12201,0);
INSERT INTO "django_geo_db_location" VALUES(21392,NULL,'West Jefferson, NC',8898,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21393,NULL,'West Jefferson, NC 28694',8898,222,NULL,33,12202,0);
INSERT INTO "django_geo_db_location" VALUES(21394,NULL,'Wilkesboro, NC',8899,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21395,NULL,'Wilkesboro, NC 28697',8899,222,NULL,33,12203,0);
INSERT INTO "django_geo_db_location" VALUES(21396,NULL,'Zionville, NC',8900,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21397,NULL,'Zionville, NC 28698',8900,222,NULL,33,12204,0);
INSERT INTO "django_geo_db_location" VALUES(21398,NULL,'Scotts, NC',8901,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21399,NULL,'Scotts, NC 28699',8901,222,NULL,33,12205,0);
INSERT INTO "django_geo_db_location" VALUES(21400,NULL,'Alexander, NC',8902,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21401,NULL,'Alexander, NC 28701',8902,222,NULL,33,12206,0);
INSERT INTO "django_geo_db_location" VALUES(21402,NULL,'Almond, NC',8903,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21403,NULL,'Almond, NC 28702',8903,222,NULL,33,12207,0);
INSERT INTO "django_geo_db_location" VALUES(21404,NULL,'Arden, NC',8904,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21405,NULL,'Arden, NC 28704',8904,222,NULL,33,12208,0);
INSERT INTO "django_geo_db_location" VALUES(21406,NULL,'Bakersville, NC',8905,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21407,NULL,'Bakersville, NC 28705',8905,222,NULL,33,12209,0);
INSERT INTO "django_geo_db_location" VALUES(21408,NULL,'Balsam, NC',8906,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21409,NULL,'Balsam, NC 28707',8906,222,NULL,33,12210,0);
INSERT INTO "django_geo_db_location" VALUES(21410,NULL,'Balsam Grove, NC',8907,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21411,NULL,'Balsam Grove, NC 28708',8907,222,NULL,33,12211,0);
INSERT INTO "django_geo_db_location" VALUES(21412,NULL,'Barnardsville, NC',8908,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21413,NULL,'Barnardsville, NC 28709',8908,222,NULL,33,12212,0);
INSERT INTO "django_geo_db_location" VALUES(21414,NULL,'Bat Cave, NC',8909,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21415,NULL,'Bat Cave, NC 28710',8909,222,NULL,33,12213,0);
INSERT INTO "django_geo_db_location" VALUES(21416,NULL,'Black Mountain, NC',8910,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21417,NULL,'Black Mountain, NC 28711',8910,222,NULL,33,12214,0);
INSERT INTO "django_geo_db_location" VALUES(21418,NULL,'Brevard, NC',8911,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21419,NULL,'Brevard, NC 28712',8911,222,NULL,33,12215,0);
INSERT INTO "django_geo_db_location" VALUES(21420,NULL,'Bryson City, NC',8912,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21421,NULL,'Bryson City, NC 28713',8912,222,NULL,33,12216,0);
INSERT INTO "django_geo_db_location" VALUES(21422,NULL,'Burnsville, NC',8913,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21423,NULL,'Burnsville, NC 28714',8913,222,NULL,33,12217,0);
INSERT INTO "django_geo_db_location" VALUES(21424,NULL,'Candler, NC',8914,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21425,NULL,'Candler, NC 28715',8914,222,NULL,33,12218,0);
INSERT INTO "django_geo_db_location" VALUES(21426,NULL,'Canton, NC',8915,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21427,NULL,'Canton, NC 28716',8915,222,NULL,33,12219,0);
INSERT INTO "django_geo_db_location" VALUES(21428,NULL,'Cashiers, NC',8916,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21429,NULL,'Cashiers, NC 28717',8916,222,NULL,33,12220,0);
INSERT INTO "django_geo_db_location" VALUES(21430,NULL,'Cedar Mountain, NC',8917,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21431,NULL,'Cedar Mountain, NC 28718',8917,222,NULL,33,12221,0);
INSERT INTO "django_geo_db_location" VALUES(21432,NULL,'Cherokee, NC',8918,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21433,NULL,'Cherokee, NC 28719',8918,222,NULL,33,12222,0);
INSERT INTO "django_geo_db_location" VALUES(21434,NULL,'Chimney Rock, NC',8919,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21435,NULL,'Chimney Rock, NC 28720',8919,222,NULL,33,12223,0);
INSERT INTO "django_geo_db_location" VALUES(21436,NULL,'Clyde, NC',8920,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21437,NULL,'Clyde, NC 28721',8920,222,NULL,33,12224,0);
INSERT INTO "django_geo_db_location" VALUES(21438,NULL,'Columbus, NC',8921,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21439,NULL,'Columbus, NC 28722',8921,222,NULL,33,12225,0);
INSERT INTO "django_geo_db_location" VALUES(21440,NULL,'Cullowhee, NC',8922,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21441,NULL,'Cullowhee, NC 28723',8922,222,NULL,33,12226,0);
INSERT INTO "django_geo_db_location" VALUES(21442,NULL,'Dana, NC',8923,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21443,NULL,'Dana, NC 28724',8923,222,NULL,33,12227,0);
INSERT INTO "django_geo_db_location" VALUES(21444,NULL,'Dillsboro, NC',8924,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21445,NULL,'Dillsboro, NC 28725',8924,222,NULL,33,12228,0);
INSERT INTO "django_geo_db_location" VALUES(21446,NULL,'East Flat Rock, NC',8925,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21447,NULL,'East Flat Rock, NC 28726',8925,222,NULL,33,12229,0);
INSERT INTO "django_geo_db_location" VALUES(21448,NULL,'Edneyville, NC',8926,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21449,NULL,'Edneyville, NC 28727',8926,222,NULL,33,12230,0);
INSERT INTO "django_geo_db_location" VALUES(21450,NULL,'Enka, NC',8927,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21451,NULL,'Enka, NC 28728',8927,222,NULL,33,12231,0);
INSERT INTO "django_geo_db_location" VALUES(21452,NULL,'Etowah, NC',8928,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21453,NULL,'Etowah, NC 28729',8928,222,NULL,33,12232,0);
INSERT INTO "django_geo_db_location" VALUES(21454,NULL,'Fairview, NC',8929,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21455,NULL,'Fairview, NC 28730',8929,222,NULL,33,12233,0);
INSERT INTO "django_geo_db_location" VALUES(21456,NULL,'Flat Rock, NC',8930,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21457,NULL,'Flat Rock, NC 28731',8930,222,NULL,33,12234,0);
INSERT INTO "django_geo_db_location" VALUES(21458,NULL,'Fletcher, NC',8931,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21459,NULL,'Fletcher, NC 28732',8931,222,NULL,33,12235,0);
INSERT INTO "django_geo_db_location" VALUES(21460,NULL,'Fontana Dam, NC',8932,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21461,NULL,'Fontana Dam, NC 28733',8932,222,NULL,33,12236,0);
INSERT INTO "django_geo_db_location" VALUES(21462,NULL,'Franklin, NC',8933,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21463,NULL,'Franklin, NC 28734',8933,222,NULL,33,12237,0);
INSERT INTO "django_geo_db_location" VALUES(21464,NULL,'Gerton, NC',8934,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21465,NULL,'Gerton, NC 28735',8934,222,NULL,33,12238,0);
INSERT INTO "django_geo_db_location" VALUES(21466,NULL,'Glenville, NC',8935,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21467,NULL,'Glenville, NC 28736',8935,222,NULL,33,12239,0);
INSERT INTO "django_geo_db_location" VALUES(21468,NULL,'Glenwood, NC',8936,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21469,NULL,'Glenwood, NC 28737',8936,222,NULL,33,12240,0);
INSERT INTO "django_geo_db_location" VALUES(21470,NULL,'Hazelwood, NC',8937,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21471,NULL,'Hazelwood, NC 28738',8937,222,NULL,33,12241,0);
INSERT INTO "django_geo_db_location" VALUES(21472,NULL,'Hendersonville, NC',8938,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21473,NULL,'Hendersonville, NC 28739',8938,222,NULL,33,12242,0);
INSERT INTO "django_geo_db_location" VALUES(21474,NULL,'Greenmountain, NC',8939,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21475,NULL,'Greenmountain, NC 28740',8939,222,NULL,33,12243,0);
INSERT INTO "django_geo_db_location" VALUES(21476,NULL,'Highlands, NC',8940,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21477,NULL,'Highlands, NC 28741',8940,222,NULL,33,12244,0);
INSERT INTO "django_geo_db_location" VALUES(21478,NULL,'Horse Shoe, NC',8941,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21479,NULL,'Horse Shoe, NC 28742',8941,222,NULL,33,12245,0);
INSERT INTO "django_geo_db_location" VALUES(21480,NULL,'Hot Springs, NC',8942,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21481,NULL,'Hot Springs, NC 28743',8942,222,NULL,33,12246,0);
INSERT INTO "django_geo_db_location" VALUES(21482,NULL,'Franklin, NC 28744',8933,222,NULL,33,12247,0);
INSERT INTO "django_geo_db_location" VALUES(21483,NULL,'Lake Junaluska, NC',8943,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21484,NULL,'Lake Junaluska, NC 28745',8943,222,NULL,33,12248,0);
INSERT INTO "django_geo_db_location" VALUES(21485,NULL,'Lake Lure, NC',8944,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21486,NULL,'Lake Lure, NC 28746',8944,222,NULL,33,12249,0);
INSERT INTO "django_geo_db_location" VALUES(21487,NULL,'Lake Toxaway, NC',8945,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21488,NULL,'Lake Toxaway, NC 28747',8945,222,NULL,33,12250,0);
INSERT INTO "django_geo_db_location" VALUES(21489,NULL,'Leicester, NC',8946,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21490,NULL,'Leicester, NC 28748',8946,222,NULL,33,12251,0);
INSERT INTO "django_geo_db_location" VALUES(21491,NULL,'Little Switzerland, NC',8947,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21492,NULL,'Little Switzerland, NC 28749',8947,222,NULL,33,12252,0);
INSERT INTO "django_geo_db_location" VALUES(21493,NULL,'Lynn, NC',8948,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21494,NULL,'Lynn, NC 28750',8948,222,NULL,33,12253,0);
INSERT INTO "django_geo_db_location" VALUES(21495,NULL,'Maggie Valley, NC',8949,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21496,NULL,'Maggie Valley, NC 28751',8949,222,NULL,33,12254,0);
INSERT INTO "django_geo_db_location" VALUES(21497,NULL,'Marion, NC',8950,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21498,NULL,'Marion, NC 28752',8950,222,NULL,33,12255,0);
INSERT INTO "django_geo_db_location" VALUES(21499,NULL,'Marshall, NC',8951,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21500,NULL,'Marshall, NC 28753',8951,222,NULL,33,12256,0);
INSERT INTO "django_geo_db_location" VALUES(21501,NULL,'Mars Hill, NC',8952,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21502,NULL,'Mars Hill, NC 28754',8952,222,NULL,33,12257,0);
INSERT INTO "django_geo_db_location" VALUES(21503,NULL,'Micaville, NC',8953,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21504,NULL,'Micaville, NC 28755',8953,222,NULL,33,12258,0);
INSERT INTO "django_geo_db_location" VALUES(21505,NULL,'Mill Spring, NC',8954,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21506,NULL,'Mill Spring, NC 28756',8954,222,NULL,33,12259,0);
INSERT INTO "django_geo_db_location" VALUES(21507,NULL,'Montreat, NC',8955,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21508,NULL,'Montreat, NC 28757',8955,222,NULL,33,12260,0);
INSERT INTO "django_geo_db_location" VALUES(21509,NULL,'Mountain Home, NC',8956,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21510,NULL,'Mountain Home, NC 28758',8956,222,NULL,33,12261,0);
INSERT INTO "django_geo_db_location" VALUES(21511,NULL,'Naples, NC',8957,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21512,NULL,'Naples, NC 28760',8957,222,NULL,33,12262,0);
INSERT INTO "django_geo_db_location" VALUES(21513,NULL,'Nebo, NC',8958,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21514,NULL,'Nebo, NC 28761',8958,222,NULL,33,12263,0);
INSERT INTO "django_geo_db_location" VALUES(21515,NULL,'Old Fort, NC',8959,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21516,NULL,'Old Fort, NC 28762',8959,222,NULL,33,12264,0);
INSERT INTO "django_geo_db_location" VALUES(21517,NULL,'Otto, NC',8960,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21518,NULL,'Otto, NC 28763',8960,222,NULL,33,12265,0);
INSERT INTO "django_geo_db_location" VALUES(21519,NULL,'Penland, NC',8961,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21520,NULL,'Penland, NC 28765',8961,222,NULL,33,12266,0);
INSERT INTO "django_geo_db_location" VALUES(21521,NULL,'Penrose, NC',8962,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21522,NULL,'Penrose, NC 28766',8962,222,NULL,33,12267,0);
INSERT INTO "django_geo_db_location" VALUES(21523,NULL,'Old Fort, NC 28767',8959,222,NULL,33,12268,0);
INSERT INTO "django_geo_db_location" VALUES(21524,NULL,'Pisgah Forest, NC',8963,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21525,NULL,'Pisgah Forest, NC 28768',8963,222,NULL,33,12269,0);
INSERT INTO "django_geo_db_location" VALUES(21526,NULL,'Ridgecrest, NC',8964,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21527,NULL,'Ridgecrest, NC 28770',8964,222,NULL,33,12270,0);
INSERT INTO "django_geo_db_location" VALUES(21528,NULL,'Robbinsville, NC',8965,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21529,NULL,'Robbinsville, NC 28771',8965,222,NULL,33,12271,0);
INSERT INTO "django_geo_db_location" VALUES(21530,NULL,'Rosman, NC',8966,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21531,NULL,'Rosman, NC 28772',8966,222,NULL,33,12272,0);
INSERT INTO "django_geo_db_location" VALUES(21532,NULL,'Saluda, NC',8967,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21533,NULL,'Saluda, NC 28773',8967,222,NULL,33,12273,0);
INSERT INTO "django_geo_db_location" VALUES(21534,NULL,'Sapphire, NC',8968,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21535,NULL,'Sapphire, NC 28774',8968,222,NULL,33,12274,0);
INSERT INTO "django_geo_db_location" VALUES(21536,NULL,'Scaly Mountain, NC',8969,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21537,NULL,'Scaly Mountain, NC 28775',8969,222,NULL,33,12275,0);
INSERT INTO "django_geo_db_location" VALUES(21538,NULL,'Skyland, NC',8970,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21539,NULL,'Skyland, NC 28776',8970,222,NULL,33,12276,0);
INSERT INTO "django_geo_db_location" VALUES(21540,NULL,'Spruce Pine, NC',8971,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21541,NULL,'Spruce Pine, NC 28777',8971,222,NULL,33,12277,0);
INSERT INTO "django_geo_db_location" VALUES(21542,NULL,'Swannanoa, NC',8972,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21543,NULL,'Swannanoa, NC 28778',8972,222,NULL,33,12278,0);
INSERT INTO "django_geo_db_location" VALUES(21544,NULL,'Sylva, NC',8973,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21545,NULL,'Sylva, NC 28779',8973,222,NULL,33,12279,0);
INSERT INTO "django_geo_db_location" VALUES(21546,NULL,'Topton, NC',8974,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21547,NULL,'Topton, NC 28781',8974,222,NULL,33,12280,0);
INSERT INTO "django_geo_db_location" VALUES(21548,NULL,'Tryon, NC',8975,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21549,NULL,'Tryon, NC 28782',8975,222,NULL,33,12281,0);
INSERT INTO "django_geo_db_location" VALUES(21550,NULL,'Tuckasegee, NC',8976,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21551,NULL,'Tuckasegee, NC 28783',8976,222,NULL,33,12282,0);
INSERT INTO "django_geo_db_location" VALUES(21552,NULL,'Tuxedo, NC',8977,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21553,NULL,'Tuxedo, NC 28784',8977,222,NULL,33,12283,0);
INSERT INTO "django_geo_db_location" VALUES(21554,NULL,'Maggie Valley, NC 28785',8949,222,NULL,33,12284,0);
INSERT INTO "django_geo_db_location" VALUES(21555,NULL,'Waynesville, NC',8978,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21556,NULL,'Waynesville, NC 28786',8978,222,NULL,33,12285,0);
INSERT INTO "django_geo_db_location" VALUES(21557,NULL,'Weaverville, NC',8979,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21558,NULL,'Weaverville, NC 28787',8979,222,NULL,33,12286,0);
INSERT INTO "django_geo_db_location" VALUES(21559,NULL,'Webster, NC',8980,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21560,NULL,'Webster, NC 28788',8980,222,NULL,33,12287,0);
INSERT INTO "django_geo_db_location" VALUES(21561,NULL,'Whittier, NC',8981,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21562,NULL,'Whittier, NC 28789',8981,222,NULL,33,12288,0);
INSERT INTO "django_geo_db_location" VALUES(21563,NULL,'Zirconia, NC',8982,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21564,NULL,'Zirconia, NC 28790',8982,222,NULL,33,12289,0);
INSERT INTO "django_geo_db_location" VALUES(21565,NULL,'Hendersonville, NC 28791',8938,222,NULL,33,12290,0);
INSERT INTO "django_geo_db_location" VALUES(21566,NULL,'Hendersonville, NC 28792',8938,222,NULL,33,12291,0);
INSERT INTO "django_geo_db_location" VALUES(21567,NULL,'Hendersonville, NC 28793',8938,222,NULL,33,12292,0);
INSERT INTO "django_geo_db_location" VALUES(21568,NULL,'East Flat Rock, NC 28796',8925,222,NULL,33,12293,0);
INSERT INTO "django_geo_db_location" VALUES(21569,NULL,'Asheville, NC',8983,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21570,NULL,'Asheville, NC 28800',8983,222,NULL,33,12294,0);
INSERT INTO "django_geo_db_location" VALUES(21571,NULL,'Asheville, NC 28801',8983,222,NULL,33,12295,0);
INSERT INTO "django_geo_db_location" VALUES(21572,NULL,'Asheville, NC 28802',8983,222,NULL,33,12296,0);
INSERT INTO "django_geo_db_location" VALUES(21573,NULL,'Asheville, NC 28803',8983,222,NULL,33,12297,0);
INSERT INTO "django_geo_db_location" VALUES(21574,NULL,'Asheville, NC 28804',8983,222,NULL,33,12298,0);
INSERT INTO "django_geo_db_location" VALUES(21575,NULL,'Asheville, NC 28805',8983,222,NULL,33,12299,0);
INSERT INTO "django_geo_db_location" VALUES(21576,NULL,'Asheville, NC 28806',8983,222,NULL,33,12300,0);
INSERT INTO "django_geo_db_location" VALUES(21577,NULL,'Asheville, NC 28808',8983,222,NULL,33,12301,0);
INSERT INTO "django_geo_db_location" VALUES(21578,NULL,'Asheville, NC 28810',8983,222,NULL,33,12302,0);
INSERT INTO "django_geo_db_location" VALUES(21579,NULL,'Asheville, NC 28813',8983,222,NULL,33,12303,0);
INSERT INTO "django_geo_db_location" VALUES(21580,NULL,'Asheville, NC 28814',8983,222,NULL,33,12304,0);
INSERT INTO "django_geo_db_location" VALUES(21581,NULL,'Asheville, NC 28815',8983,222,NULL,33,12305,0);
INSERT INTO "django_geo_db_location" VALUES(21582,NULL,'Asheville, NC 28816',8983,222,NULL,33,12306,0);
INSERT INTO "django_geo_db_location" VALUES(21583,NULL,'Beulaville, NC 28818',8767,222,NULL,33,12307,0);
INSERT INTO "django_geo_db_location" VALUES(21584,NULL,'Wrightsboro, NC',8984,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21585,NULL,'Wrightsboro, NC 28849',8984,222,NULL,33,12308,0);
INSERT INTO "django_geo_db_location" VALUES(21586,NULL,'Vass, NC 28894',8700,222,NULL,33,12309,0);
INSERT INTO "django_geo_db_location" VALUES(21587,NULL,'Andrews, NC',8985,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21588,NULL,'Andrews, NC 28901',8985,222,NULL,33,12310,0);
INSERT INTO "django_geo_db_location" VALUES(21589,NULL,'Brasstown, NC',8986,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21590,NULL,'Brasstown, NC 28902',8986,222,NULL,33,12311,0);
INSERT INTO "django_geo_db_location" VALUES(21591,NULL,'Culberson, NC',8987,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21592,NULL,'Culberson, NC 28903',8987,222,NULL,33,12312,0);
INSERT INTO "django_geo_db_location" VALUES(21593,NULL,'Hayesville, NC',8988,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21594,NULL,'Hayesville, NC 28904',8988,222,NULL,33,12313,0);
INSERT INTO "django_geo_db_location" VALUES(21595,NULL,'Marble, NC',8989,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21596,NULL,'Marble, NC 28905',8989,222,NULL,33,12314,0);
INSERT INTO "django_geo_db_location" VALUES(21597,NULL,'Murphy, NC',8990,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21598,NULL,'Murphy, NC 28906',8990,222,NULL,33,12315,0);
INSERT INTO "django_geo_db_location" VALUES(21599,NULL,'Warne, NC',8991,222,NULL,33,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21600,NULL,'Warne, NC 28909',8991,222,NULL,33,12316,0);
INSERT INTO "django_geo_db_location" VALUES(21601,NULL,'Winterville, NC 28950',8818,222,NULL,33,12317,0);
INSERT INTO "django_geo_db_location" VALUES(21602,NULL,'Emerald Isle, NC 28954',8819,222,NULL,33,12318,0);
INSERT INTO "django_geo_db_location" VALUES(21603,NULL,'Hendersonville, NC 28971',8938,222,NULL,33,12319,0);
INSERT INTO "django_geo_db_location" VALUES(21604,NULL,'Hendersonville, NC 28972',8938,222,NULL,33,12320,0);
INSERT INTO "django_geo_db_location" VALUES(21605,NULL,'Alcolu, SC',8992,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21606,NULL,'Alcolu, SC 29001',8992,222,NULL,48,12321,0);
INSERT INTO "django_geo_db_location" VALUES(21607,NULL,'Ballentine, SC',8993,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21608,NULL,'Ballentine, SC 29002',8993,222,NULL,48,12322,0);
INSERT INTO "django_geo_db_location" VALUES(21609,NULL,'Bamberg, SC',8994,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21610,NULL,'Bamberg, SC 29003',8994,222,NULL,48,12323,0);
INSERT INTO "django_geo_db_location" VALUES(21611,NULL,'Batesburg, SC',8995,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21612,NULL,'Batesburg, SC 29006',8995,222,NULL,48,12324,0);
INSERT INTO "django_geo_db_location" VALUES(21613,NULL,'Bethune, SC',8996,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21614,NULL,'Bethune, SC 29009',8996,222,NULL,48,12325,0);
INSERT INTO "django_geo_db_location" VALUES(21615,NULL,'Bishopville, SC',8997,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21616,NULL,'Bishopville, SC 29010',8997,222,NULL,48,12326,0);
INSERT INTO "django_geo_db_location" VALUES(21617,NULL,'Blackstock, SC',8998,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21618,NULL,'Blackstock, SC 29014',8998,222,NULL,48,12327,0);
INSERT INTO "django_geo_db_location" VALUES(21619,NULL,'Blair, SC',8999,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21620,NULL,'Blair, SC 29015',8999,222,NULL,48,12328,0);
INSERT INTO "django_geo_db_location" VALUES(21621,NULL,'Blythewood, SC',9000,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21622,NULL,'Blythewood, SC 29016',9000,222,NULL,48,12329,0);
INSERT INTO "django_geo_db_location" VALUES(21623,NULL,'Bowman, SC',9001,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21624,NULL,'Bowman, SC 29018',9001,222,NULL,48,12330,0);
INSERT INTO "django_geo_db_location" VALUES(21625,NULL,'Camden, SC',9002,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21626,NULL,'Camden, SC 29020',9002,222,NULL,48,12331,0);
INSERT INTO "django_geo_db_location" VALUES(21627,NULL,'Cameron, SC',9003,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21628,NULL,'Cameron, SC 29030',9003,222,NULL,48,12332,0);
INSERT INTO "django_geo_db_location" VALUES(21629,NULL,'Carlisle, SC',9004,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21630,NULL,'Carlisle, SC 29031',9004,222,NULL,48,12333,0);
INSERT INTO "django_geo_db_location" VALUES(21631,NULL,'Cassatt, SC',9005,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21632,NULL,'Cassatt, SC 29032',9005,222,NULL,48,12334,0);
INSERT INTO "django_geo_db_location" VALUES(21633,NULL,'Cayce, SC',9006,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21634,NULL,'Cayce, SC 29033',9006,222,NULL,48,12335,0);
INSERT INTO "django_geo_db_location" VALUES(21635,NULL,'Chapin, SC',9007,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21636,NULL,'Chapin, SC 29036',9007,222,NULL,48,12336,0);
INSERT INTO "django_geo_db_location" VALUES(21637,NULL,'Chappells, SC',9008,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21638,NULL,'Chappells, SC 29037',9008,222,NULL,48,12337,0);
INSERT INTO "django_geo_db_location" VALUES(21639,NULL,'Cope, SC',9009,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21640,NULL,'Cope, SC 29038',9009,222,NULL,48,12338,0);
INSERT INTO "django_geo_db_location" VALUES(21641,NULL,'Cordova, SC',9010,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21642,NULL,'Cordova, SC 29039',9010,222,NULL,48,12339,0);
INSERT INTO "django_geo_db_location" VALUES(21643,NULL,'Dalzell, SC',9011,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21644,NULL,'Dalzell, SC 29040',9011,222,NULL,48,12340,0);
INSERT INTO "django_geo_db_location" VALUES(21645,NULL,'Davis Station, SC',9012,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21646,NULL,'Davis Station, SC 29041',9012,222,NULL,48,12341,0);
INSERT INTO "django_geo_db_location" VALUES(21647,NULL,'Denmark, SC',9013,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21648,NULL,'Denmark, SC 29042',9013,222,NULL,48,12342,0);
INSERT INTO "django_geo_db_location" VALUES(21649,NULL,'Eastover, SC',9014,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21650,NULL,'Eastover, SC 29044',9014,222,NULL,48,12343,0);
INSERT INTO "django_geo_db_location" VALUES(21651,NULL,'Elgin, SC',9015,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21652,NULL,'Elgin, SC 29045',9015,222,NULL,48,12344,0);
INSERT INTO "django_geo_db_location" VALUES(21653,NULL,'Elliott, SC',9016,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21654,NULL,'Elliott, SC 29046',9016,222,NULL,48,12345,0);
INSERT INTO "django_geo_db_location" VALUES(21655,NULL,'Elloree, SC',9017,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21656,NULL,'Elloree, SC 29047',9017,222,NULL,48,12346,0);
INSERT INTO "django_geo_db_location" VALUES(21657,NULL,'Eutawville, SC',9018,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21658,NULL,'Eutawville, SC 29048',9018,222,NULL,48,12347,0);
INSERT INTO "django_geo_db_location" VALUES(21659,NULL,'Gable, SC',9019,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21660,NULL,'Gable, SC 29051',9019,222,NULL,48,12348,0);
INSERT INTO "django_geo_db_location" VALUES(21661,NULL,'Gadsden, SC',9020,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21662,NULL,'Gadsden, SC 29052',9020,222,NULL,48,12349,0);
INSERT INTO "django_geo_db_location" VALUES(21663,NULL,'Gaston, SC',9021,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21664,NULL,'Gaston, SC 29053',9021,222,NULL,48,12350,0);
INSERT INTO "django_geo_db_location" VALUES(21665,NULL,'Gilbert, SC',9022,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21666,NULL,'Gilbert, SC 29054',9022,222,NULL,48,12351,0);
INSERT INTO "django_geo_db_location" VALUES(21667,NULL,'Great Falls, SC',9023,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21668,NULL,'Great Falls, SC 29055',9023,222,NULL,48,12352,0);
INSERT INTO "django_geo_db_location" VALUES(21669,NULL,'Greeleyville, SC',9024,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21670,NULL,'Greeleyville, SC 29056',9024,222,NULL,48,12353,0);
INSERT INTO "django_geo_db_location" VALUES(21671,NULL,'Heath Springs, SC',9025,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21672,NULL,'Heath Springs, SC 29058',9025,222,NULL,48,12354,0);
INSERT INTO "django_geo_db_location" VALUES(21673,NULL,'Holly Hill, SC',9026,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21674,NULL,'Holly Hill, SC 29059',9026,222,NULL,48,12355,0);
INSERT INTO "django_geo_db_location" VALUES(21675,NULL,'Hopkins, SC',9027,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21676,NULL,'Hopkins, SC 29061',9027,222,NULL,48,12356,0);
INSERT INTO "django_geo_db_location" VALUES(21677,NULL,'Horatio, SC',9028,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21678,NULL,'Horatio, SC 29062',9028,222,NULL,48,12357,0);
INSERT INTO "django_geo_db_location" VALUES(21679,NULL,'Irmo, SC',9029,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21680,NULL,'Irmo, SC 29063',9029,222,NULL,48,12358,0);
INSERT INTO "django_geo_db_location" VALUES(21681,NULL,'Jenkinsville, SC',9030,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21682,NULL,'Jenkinsville, SC 29065',9030,222,NULL,48,12359,0);
INSERT INTO "django_geo_db_location" VALUES(21683,NULL,'Batesburg-Leesville, SC',9031,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21684,NULL,'Batesburg-Leesville, SC 29066',9031,222,NULL,48,12360,0);
INSERT INTO "django_geo_db_location" VALUES(21685,NULL,'Kershaw, SC',9032,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21686,NULL,'Kershaw, SC 29067',9032,222,NULL,48,12361,0);
INSERT INTO "django_geo_db_location" VALUES(21687,NULL,'Lamar, SC',9033,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21688,NULL,'Lamar, SC 29069',9033,222,NULL,48,12362,0);
INSERT INTO "django_geo_db_location" VALUES(21689,NULL,'Leesville, SC',9034,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21690,NULL,'Leesville, SC 29070',9034,222,NULL,48,12363,0);
INSERT INTO "django_geo_db_location" VALUES(21691,NULL,'Lexington, SC',9035,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21692,NULL,'Lexington, SC 29071',9035,222,NULL,48,12364,0);
INSERT INTO "django_geo_db_location" VALUES(21693,NULL,'Lexington, SC 29072',9035,222,NULL,48,12365,0);
INSERT INTO "django_geo_db_location" VALUES(21694,NULL,'Lexington, SC 29073',9035,222,NULL,48,12366,0);
INSERT INTO "django_geo_db_location" VALUES(21695,NULL,'Liberty Hill, SC',9036,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21696,NULL,'Liberty Hill, SC 29074',9036,222,NULL,48,12367,0);
INSERT INTO "django_geo_db_location" VALUES(21697,NULL,'Little Mountain, SC',9037,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21698,NULL,'Little Mountain, SC 29075',9037,222,NULL,48,12368,0);
INSERT INTO "django_geo_db_location" VALUES(21699,NULL,'Lugoff, SC',9038,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21700,NULL,'Lugoff, SC 29078',9038,222,NULL,48,12369,0);
INSERT INTO "django_geo_db_location" VALUES(21701,NULL,'Lydia, SC',9039,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21702,NULL,'Lydia, SC 29079',9039,222,NULL,48,12370,0);
INSERT INTO "django_geo_db_location" VALUES(21703,NULL,'Lynchburg, SC',9040,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21704,NULL,'Lynchburg, SC 29080',9040,222,NULL,48,12371,0);
INSERT INTO "django_geo_db_location" VALUES(21705,NULL,'Ehrhardt, SC',9041,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21706,NULL,'Ehrhardt, SC 29081',9041,222,NULL,48,12372,0);
INSERT INTO "django_geo_db_location" VALUES(21707,NULL,'Lodge, SC',9042,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21708,NULL,'Lodge, SC 29082',9042,222,NULL,48,12373,0);
INSERT INTO "django_geo_db_location" VALUES(21709,NULL,'McBee, SC',9043,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21710,NULL,'McBee, SC 29101',9043,222,NULL,48,12374,0);
INSERT INTO "django_geo_db_location" VALUES(21711,NULL,'Manning, SC',9044,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21712,NULL,'Manning, SC 29102',9044,222,NULL,48,12375,0);
INSERT INTO "django_geo_db_location" VALUES(21713,NULL,'Mayesville, SC',9045,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21714,NULL,'Mayesville, SC 29103',9045,222,NULL,48,12376,0);
INSERT INTO "django_geo_db_location" VALUES(21715,NULL,'Mayesville, SC 29104',9045,222,NULL,48,12377,0);
INSERT INTO "django_geo_db_location" VALUES(21716,NULL,'Monetta, SC',9046,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21717,NULL,'Monetta, SC 29105',9046,222,NULL,48,12378,0);
INSERT INTO "django_geo_db_location" VALUES(21718,NULL,'Monticello, SC',9047,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21719,NULL,'Monticello, SC 29106',9047,222,NULL,48,12379,0);
INSERT INTO "django_geo_db_location" VALUES(21720,NULL,'Neeses, SC',9048,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21721,NULL,'Neeses, SC 29107',9048,222,NULL,48,12380,0);
INSERT INTO "django_geo_db_location" VALUES(21722,NULL,'Newberry, SC',9049,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21723,NULL,'Newberry, SC 29108',9049,222,NULL,48,12381,0);
INSERT INTO "django_geo_db_location" VALUES(21724,NULL,'New Zion, SC',9050,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21725,NULL,'New Zion, SC 29111',9050,222,NULL,48,12382,0);
INSERT INTO "django_geo_db_location" VALUES(21726,NULL,'North, SC',9051,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21727,NULL,'North, SC 29112',9051,222,NULL,48,12383,0);
INSERT INTO "django_geo_db_location" VALUES(21728,NULL,'Norway, SC',9052,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21729,NULL,'Norway, SC 29113',9052,222,NULL,48,12384,0);
INSERT INTO "django_geo_db_location" VALUES(21730,NULL,'Olanta, SC',9053,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21731,NULL,'Olanta, SC 29114',9053,222,NULL,48,12385,0);
INSERT INTO "django_geo_db_location" VALUES(21732,NULL,'Orangeburg, SC',9054,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21733,NULL,'Orangeburg, SC 29115',9054,222,NULL,48,12386,0);
INSERT INTO "django_geo_db_location" VALUES(21734,NULL,'Orangeburg, SC 29116',9054,222,NULL,48,12387,0);
INSERT INTO "django_geo_db_location" VALUES(21735,NULL,'Orangeburg, SC 29117',9054,222,NULL,48,12388,0);
INSERT INTO "django_geo_db_location" VALUES(21736,NULL,'Orangeburg, SC 29118',9054,222,NULL,48,12389,0);
INSERT INTO "django_geo_db_location" VALUES(21737,NULL,'Peak, SC',9055,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21738,NULL,'Peak, SC 29122',9055,222,NULL,48,12390,0);
INSERT INTO "django_geo_db_location" VALUES(21739,NULL,'Pelion, SC',9056,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21740,NULL,'Pelion, SC 29123',9056,222,NULL,48,12391,0);
INSERT INTO "django_geo_db_location" VALUES(21741,NULL,'Perry, SC',9057,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21742,NULL,'Perry, SC 29124',9057,222,NULL,48,12392,0);
INSERT INTO "django_geo_db_location" VALUES(21743,NULL,'Pinewood, SC',9058,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21744,NULL,'Pinewood, SC 29125',9058,222,NULL,48,12393,0);
INSERT INTO "django_geo_db_location" VALUES(21745,NULL,'Pomaria, SC',9059,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21746,NULL,'Pomaria, SC 29126',9059,222,NULL,48,12394,0);
INSERT INTO "django_geo_db_location" VALUES(21747,NULL,'Prosperity, SC',9060,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21748,NULL,'Prosperity, SC 29127',9060,222,NULL,48,12395,0);
INSERT INTO "django_geo_db_location" VALUES(21749,NULL,'Rembert, SC',9061,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21750,NULL,'Rembert, SC 29128',9061,222,NULL,48,12396,0);
INSERT INTO "django_geo_db_location" VALUES(21751,NULL,'Ridge Spring, SC',9062,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21752,NULL,'Ridge Spring, SC 29129',9062,222,NULL,48,12397,0);
INSERT INTO "django_geo_db_location" VALUES(21753,NULL,'Ridgeway, SC',9063,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21754,NULL,'Ridgeway, SC 29130',9063,222,NULL,48,12398,0);
INSERT INTO "django_geo_db_location" VALUES(21755,NULL,'Rion, SC',9064,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21756,NULL,'Rion, SC 29132',9064,222,NULL,48,12399,0);
INSERT INTO "django_geo_db_location" VALUES(21757,NULL,'Rowesville, SC',9065,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21758,NULL,'Rowesville, SC 29133',9065,222,NULL,48,12400,0);
INSERT INTO "django_geo_db_location" VALUES(21759,NULL,'Saint Matthews, SC',9066,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21760,NULL,'Saint Matthews, SC 29135',9066,222,NULL,48,12401,0);
INSERT INTO "django_geo_db_location" VALUES(21761,NULL,'Salley, SC',9067,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21762,NULL,'Salley, SC 29137',9067,222,NULL,48,12402,0);
INSERT INTO "django_geo_db_location" VALUES(21763,NULL,'Saluda, SC',9068,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21764,NULL,'Saluda, SC 29138',9068,222,NULL,48,12403,0);
INSERT INTO "django_geo_db_location" VALUES(21765,NULL,'Santee, SC',9069,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21766,NULL,'Santee, SC 29142',9069,222,NULL,48,12404,0);
INSERT INTO "django_geo_db_location" VALUES(21767,NULL,'Sardinia, SC',9070,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21768,NULL,'Sardinia, SC 29143',9070,222,NULL,48,12405,0);
INSERT INTO "django_geo_db_location" VALUES(21769,NULL,'Silverstreet, SC',9071,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21770,NULL,'Silverstreet, SC 29145',9071,222,NULL,48,12406,0);
INSERT INTO "django_geo_db_location" VALUES(21771,NULL,'Springfield, SC',9072,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21772,NULL,'Springfield, SC 29146',9072,222,NULL,48,12407,0);
INSERT INTO "django_geo_db_location" VALUES(21773,NULL,'State Park, SC',9073,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21774,NULL,'State Park, SC 29147',9073,222,NULL,48,12408,0);
INSERT INTO "django_geo_db_location" VALUES(21775,NULL,'Summerton, SC',9074,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21776,NULL,'Summerton, SC 29148',9074,222,NULL,48,12409,0);
INSERT INTO "django_geo_db_location" VALUES(21777,NULL,'Sumter, SC',9075,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21778,NULL,'Sumter, SC 29150',9075,222,NULL,48,12410,0);
INSERT INTO "django_geo_db_location" VALUES(21779,NULL,'Sumter, SC 29151',9075,222,NULL,48,12411,0);
INSERT INTO "django_geo_db_location" VALUES(21780,NULL,'Shaw A F B, SC',9076,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21781,NULL,'Shaw A F B, SC 29152',9076,222,NULL,48,12412,0);
INSERT INTO "django_geo_db_location" VALUES(21782,NULL,'Sumter, SC 29153',9075,222,NULL,48,12413,0);
INSERT INTO "django_geo_db_location" VALUES(21783,NULL,'Sumter, SC 29154',9075,222,NULL,48,12414,0);
INSERT INTO "django_geo_db_location" VALUES(21784,NULL,'Swansea, SC',9077,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21785,NULL,'Swansea, SC 29160',9077,222,NULL,48,12415,0);
INSERT INTO "django_geo_db_location" VALUES(21786,NULL,'Timmonsville, SC',9078,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21787,NULL,'Timmonsville, SC 29161',9078,222,NULL,48,12416,0);
INSERT INTO "django_geo_db_location" VALUES(21788,NULL,'Turbeville, SC',9079,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21789,NULL,'Turbeville, SC 29162',9079,222,NULL,48,12417,0);
INSERT INTO "django_geo_db_location" VALUES(21790,NULL,'Vance, SC',9080,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21791,NULL,'Vance, SC 29163',9080,222,NULL,48,12418,0);
INSERT INTO "django_geo_db_location" VALUES(21792,NULL,'Wagener, SC',9081,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21793,NULL,'Wagener, SC 29164',9081,222,NULL,48,12419,0);
INSERT INTO "django_geo_db_location" VALUES(21794,NULL,'Ward, SC',9082,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21795,NULL,'Ward, SC 29166',9082,222,NULL,48,12420,0);
INSERT INTO "django_geo_db_location" VALUES(21796,NULL,'Wedgefield, SC',9083,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21797,NULL,'Wedgefield, SC 29168',9083,222,NULL,48,12421,0);
INSERT INTO "django_geo_db_location" VALUES(21798,NULL,'West Columbia, SC',9084,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21799,NULL,'West Columbia, SC 29169',9084,222,NULL,48,12422,0);
INSERT INTO "django_geo_db_location" VALUES(21800,NULL,'West Columbia, SC 29170',9084,222,NULL,48,12423,0);
INSERT INTO "django_geo_db_location" VALUES(21801,NULL,'West Columbia, SC 29171',9084,222,NULL,48,12424,0);
INSERT INTO "django_geo_db_location" VALUES(21802,NULL,'West Columbia, SC 29172',9084,222,NULL,48,12425,0);
INSERT INTO "django_geo_db_location" VALUES(21803,NULL,'Westville, SC',9085,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21804,NULL,'Westville, SC 29175',9085,222,NULL,48,12426,0);
INSERT INTO "django_geo_db_location" VALUES(21805,NULL,'White Oak, SC',9086,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21806,NULL,'White Oak, SC 29176',9086,222,NULL,48,12427,0);
INSERT INTO "django_geo_db_location" VALUES(21807,NULL,'White Rock, SC',9087,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21808,NULL,'White Rock, SC 29177',9087,222,NULL,48,12428,0);
INSERT INTO "django_geo_db_location" VALUES(21809,NULL,'Whitmire, SC',9088,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21810,NULL,'Whitmire, SC 29178',9088,222,NULL,48,12429,0);
INSERT INTO "django_geo_db_location" VALUES(21811,NULL,'Winnsboro, SC',9089,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21812,NULL,'Winnsboro, SC 29180',9089,222,NULL,48,12430,0);
INSERT INTO "django_geo_db_location" VALUES(21813,NULL,'Columbia, SC',9090,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21814,NULL,'Columbia, SC 29201',9090,222,NULL,48,12431,0);
INSERT INTO "django_geo_db_location" VALUES(21815,NULL,'Columbia, SC 29202',9090,222,NULL,48,12432,0);
INSERT INTO "django_geo_db_location" VALUES(21816,NULL,'Columbia, SC 29203',9090,222,NULL,48,12433,0);
INSERT INTO "django_geo_db_location" VALUES(21817,NULL,'Columbia, SC 29204',9090,222,NULL,48,12434,0);
INSERT INTO "django_geo_db_location" VALUES(21818,NULL,'Columbia, SC 29205',9090,222,NULL,48,12435,0);
INSERT INTO "django_geo_db_location" VALUES(21819,NULL,'Columbia, SC 29206',9090,222,NULL,48,12436,0);
INSERT INTO "django_geo_db_location" VALUES(21820,NULL,'Columbia, SC 29207',9090,222,NULL,48,12437,0);
INSERT INTO "django_geo_db_location" VALUES(21821,NULL,'Columbia, SC 29208',9090,222,NULL,48,12438,0);
INSERT INTO "django_geo_db_location" VALUES(21822,NULL,'Columbia, SC 29209',9090,222,NULL,48,12439,0);
INSERT INTO "django_geo_db_location" VALUES(21823,NULL,'Columbia, SC 29210',9090,222,NULL,48,12440,0);
INSERT INTO "django_geo_db_location" VALUES(21824,NULL,'Columbia, SC 29211',9090,222,NULL,48,12441,0);
INSERT INTO "django_geo_db_location" VALUES(21825,NULL,'Columbia, SC 29212',9090,222,NULL,48,12442,0);
INSERT INTO "django_geo_db_location" VALUES(21826,NULL,'Columbia, SC 29214',9090,222,NULL,48,12443,0);
INSERT INTO "django_geo_db_location" VALUES(21827,NULL,'Columbia, SC 29215',9090,222,NULL,48,12444,0);
INSERT INTO "django_geo_db_location" VALUES(21828,NULL,'Columbia, SC 29216',9090,222,NULL,48,12445,0);
INSERT INTO "django_geo_db_location" VALUES(21829,NULL,'Columbia, SC 29217',9090,222,NULL,48,12446,0);
INSERT INTO "django_geo_db_location" VALUES(21830,NULL,'Columbia, SC 29218',9090,222,NULL,48,12447,0);
INSERT INTO "django_geo_db_location" VALUES(21831,NULL,'Columbia, SC 29219',9090,222,NULL,48,12448,0);
INSERT INTO "django_geo_db_location" VALUES(21832,NULL,'Columbia, SC 29220',9090,222,NULL,48,12449,0);
INSERT INTO "django_geo_db_location" VALUES(21833,NULL,'Columbia, SC 29221',9090,222,NULL,48,12450,0);
INSERT INTO "django_geo_db_location" VALUES(21834,NULL,'Columbia, SC 29222',9090,222,NULL,48,12451,0);
INSERT INTO "django_geo_db_location" VALUES(21835,NULL,'Columbia, SC 29223',9090,222,NULL,48,12452,0);
INSERT INTO "django_geo_db_location" VALUES(21836,NULL,'Columbia, SC 29224',9090,222,NULL,48,12453,0);
INSERT INTO "django_geo_db_location" VALUES(21837,NULL,'Columbia, SC 29225',9090,222,NULL,48,12454,0);
INSERT INTO "django_geo_db_location" VALUES(21838,NULL,'Columbia, SC 29226',9090,222,NULL,48,12455,0);
INSERT INTO "django_geo_db_location" VALUES(21839,NULL,'Columbia, SC 29227',9090,222,NULL,48,12456,0);
INSERT INTO "django_geo_db_location" VALUES(21840,NULL,'Columbia, SC 29228',9090,222,NULL,48,12457,0);
INSERT INTO "django_geo_db_location" VALUES(21841,NULL,'Columbia, SC 29229',9090,222,NULL,48,12458,0);
INSERT INTO "django_geo_db_location" VALUES(21842,NULL,'Columbia, SC 29230',9090,222,NULL,48,12459,0);
INSERT INTO "django_geo_db_location" VALUES(21843,NULL,'Columbia, SC 29233',9090,222,NULL,48,12460,0);
INSERT INTO "django_geo_db_location" VALUES(21844,NULL,'Clinton, SC',9091,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21845,NULL,'Clinton, SC 29235',9091,222,NULL,48,12461,0);
INSERT INTO "django_geo_db_location" VALUES(21846,NULL,'Columbia, SC 29240',9090,222,NULL,48,12462,0);
INSERT INTO "django_geo_db_location" VALUES(21847,NULL,'Columbia, SC 29250',9090,222,NULL,48,12463,0);
INSERT INTO "django_geo_db_location" VALUES(21848,NULL,'Columbia, SC 29260',9090,222,NULL,48,12464,0);
INSERT INTO "django_geo_db_location" VALUES(21849,NULL,'Columbia, SC 29290',9090,222,NULL,48,12465,0);
INSERT INTO "django_geo_db_location" VALUES(21850,NULL,'Columbia, SC 29292',9090,222,NULL,48,12466,0);
INSERT INTO "django_geo_db_location" VALUES(21851,NULL,'Spartanburg, SC',9092,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21852,NULL,'Spartanburg, SC 29301',9092,222,NULL,48,12467,0);
INSERT INTO "django_geo_db_location" VALUES(21853,NULL,'Spartanburg, SC 29302',9092,222,NULL,48,12468,0);
INSERT INTO "django_geo_db_location" VALUES(21854,NULL,'Spartanburg, SC 29303',9092,222,NULL,48,12469,0);
INSERT INTO "django_geo_db_location" VALUES(21855,NULL,'Spartanburg, SC 29304',9092,222,NULL,48,12470,0);
INSERT INTO "django_geo_db_location" VALUES(21856,NULL,'Spartanburg, SC 29305',9092,222,NULL,48,12471,0);
INSERT INTO "django_geo_db_location" VALUES(21857,NULL,'Spartanburg, SC 29306',9092,222,NULL,48,12472,0);
INSERT INTO "django_geo_db_location" VALUES(21858,NULL,'Spartanburg, SC 29307',9092,222,NULL,48,12473,0);
INSERT INTO "django_geo_db_location" VALUES(21859,NULL,'Spartanburg, SC 29316',9092,222,NULL,48,12474,0);
INSERT INTO "django_geo_db_location" VALUES(21860,NULL,'Spartanburg, SC 29318',9092,222,NULL,48,12475,0);
INSERT INTO "django_geo_db_location" VALUES(21861,NULL,'Spartanburg, SC 29319',9092,222,NULL,48,12476,0);
INSERT INTO "django_geo_db_location" VALUES(21862,NULL,'Arcadia, SC',9093,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21863,NULL,'Arcadia, SC 29320',9093,222,NULL,48,12477,0);
INSERT INTO "django_geo_db_location" VALUES(21864,NULL,'Buffalo, SC',9094,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21865,NULL,'Buffalo, SC 29321',9094,222,NULL,48,12478,0);
INSERT INTO "django_geo_db_location" VALUES(21866,NULL,'Campobello, SC',9095,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21867,NULL,'Campobello, SC 29322',9095,222,NULL,48,12479,0);
INSERT INTO "django_geo_db_location" VALUES(21868,NULL,'Chesnee, SC',9096,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21869,NULL,'Chesnee, SC 29323',9096,222,NULL,48,12480,0);
INSERT INTO "django_geo_db_location" VALUES(21870,NULL,'Clifton, SC',9097,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21871,NULL,'Clifton, SC 29324',9097,222,NULL,48,12481,0);
INSERT INTO "django_geo_db_location" VALUES(21872,NULL,'Clinton, SC 29325',9091,222,NULL,48,12482,0);
INSERT INTO "django_geo_db_location" VALUES(21873,NULL,'Converse, SC',9098,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21874,NULL,'Converse, SC 29329',9098,222,NULL,48,12483,0);
INSERT INTO "django_geo_db_location" VALUES(21875,NULL,'Cowpens, SC',9099,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21876,NULL,'Cowpens, SC 29330',9099,222,NULL,48,12484,0);
INSERT INTO "django_geo_db_location" VALUES(21877,NULL,'Cross Anchor, SC',9100,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21878,NULL,'Cross Anchor, SC 29331',9100,222,NULL,48,12485,0);
INSERT INTO "django_geo_db_location" VALUES(21879,NULL,'Cross Hill, SC',9101,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21880,NULL,'Cross Hill, SC 29332',9101,222,NULL,48,12486,0);
INSERT INTO "django_geo_db_location" VALUES(21881,NULL,'Drayton, SC',9102,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21882,NULL,'Drayton, SC 29333',9102,222,NULL,48,12487,0);
INSERT INTO "django_geo_db_location" VALUES(21883,NULL,'Duncan, SC',9103,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21884,NULL,'Duncan, SC 29334',9103,222,NULL,48,12488,0);
INSERT INTO "django_geo_db_location" VALUES(21885,NULL,'Enoree, SC',9104,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21886,NULL,'Enoree, SC 29335',9104,222,NULL,48,12489,0);
INSERT INTO "django_geo_db_location" VALUES(21887,NULL,'Fairforest, SC',9105,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21888,NULL,'Fairforest, SC 29336',9105,222,NULL,48,12490,0);
INSERT INTO "django_geo_db_location" VALUES(21889,NULL,'Fingerville, SC',9106,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21890,NULL,'Fingerville, SC 29338',9106,222,NULL,48,12491,0);
INSERT INTO "django_geo_db_location" VALUES(21891,NULL,'Gaffney, SC',9107,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21892,NULL,'Gaffney, SC 29340',9107,222,NULL,48,12492,0);
INSERT INTO "django_geo_db_location" VALUES(21893,NULL,'Gaffney, SC 29341',9107,222,NULL,48,12493,0);
INSERT INTO "django_geo_db_location" VALUES(21894,NULL,'Gaffney, SC 29342',9107,222,NULL,48,12494,0);
INSERT INTO "django_geo_db_location" VALUES(21895,NULL,'Glendale, SC',9108,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21896,NULL,'Glendale, SC 29346',9108,222,NULL,48,12495,0);
INSERT INTO "django_geo_db_location" VALUES(21897,NULL,'Gramling, SC',9109,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21898,NULL,'Gramling, SC 29348',9109,222,NULL,48,12496,0);
INSERT INTO "django_geo_db_location" VALUES(21899,NULL,'Inman, SC',9110,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21900,NULL,'Inman, SC 29349',9110,222,NULL,48,12497,0);
INSERT INTO "django_geo_db_location" VALUES(21901,NULL,'Joanna, SC',9111,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21902,NULL,'Joanna, SC 29351',9111,222,NULL,48,12498,0);
INSERT INTO "django_geo_db_location" VALUES(21903,NULL,'Jonesville, SC',9112,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21904,NULL,'Jonesville, SC 29353',9112,222,NULL,48,12499,0);
INSERT INTO "django_geo_db_location" VALUES(21905,NULL,'Kinards, SC',9113,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21906,NULL,'Kinards, SC 29355',9113,222,NULL,48,12500,0);
INSERT INTO "django_geo_db_location" VALUES(21907,NULL,'Landrum, SC',9114,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21908,NULL,'Landrum, SC 29356',9114,222,NULL,48,12501,0);
INSERT INTO "django_geo_db_location" VALUES(21909,NULL,'Laurens, SC',9115,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21910,NULL,'Laurens, SC 29360',9115,222,NULL,48,12502,0);
INSERT INTO "django_geo_db_location" VALUES(21911,NULL,'Lake View, SC',9116,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21912,NULL,'Lake View, SC 29363',9116,222,NULL,48,12503,0);
INSERT INTO "django_geo_db_location" VALUES(21913,NULL,'Lockhart, SC',9117,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21914,NULL,'Lockhart, SC 29364',9117,222,NULL,48,12504,0);
INSERT INTO "django_geo_db_location" VALUES(21915,NULL,'Lyman, SC',9118,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21916,NULL,'Lyman, SC 29365',9118,222,NULL,48,12505,0);
INSERT INTO "django_geo_db_location" VALUES(21917,NULL,'Mayo, SC',9119,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21918,NULL,'Mayo, SC 29368',9119,222,NULL,48,12506,0);
INSERT INTO "django_geo_db_location" VALUES(21919,NULL,'Moore, SC',9120,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21920,NULL,'Moore, SC 29369',9120,222,NULL,48,12507,0);
INSERT INTO "django_geo_db_location" VALUES(21921,NULL,'Mountville, SC',9121,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21922,NULL,'Mountville, SC 29370',9121,222,NULL,48,12508,0);
INSERT INTO "django_geo_db_location" VALUES(21923,NULL,'Pacolet, SC',9122,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21924,NULL,'Pacolet, SC 29372',9122,222,NULL,48,12509,0);
INSERT INTO "django_geo_db_location" VALUES(21925,NULL,'Pacolet Mills, SC',9123,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21926,NULL,'Pacolet Mills, SC 29373',9123,222,NULL,48,12510,0);
INSERT INTO "django_geo_db_location" VALUES(21927,NULL,'Pauline, SC',9124,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21928,NULL,'Pauline, SC 29374',9124,222,NULL,48,12511,0);
INSERT INTO "django_geo_db_location" VALUES(21929,NULL,'Reidville, SC',9125,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21930,NULL,'Reidville, SC 29375',9125,222,NULL,48,12512,0);
INSERT INTO "django_geo_db_location" VALUES(21931,NULL,'Roebuck, SC',9126,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21932,NULL,'Roebuck, SC 29376',9126,222,NULL,48,12513,0);
INSERT INTO "django_geo_db_location" VALUES(21933,NULL,'Startex, SC',9127,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21934,NULL,'Startex, SC 29377',9127,222,NULL,48,12514,0);
INSERT INTO "django_geo_db_location" VALUES(21935,NULL,'Una, SC',9128,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21936,NULL,'Una, SC 29378',9128,222,NULL,48,12515,0);
INSERT INTO "django_geo_db_location" VALUES(21937,NULL,'Union, SC',9129,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21938,NULL,'Union, SC 29379',9129,222,NULL,48,12516,0);
INSERT INTO "django_geo_db_location" VALUES(21939,NULL,'Waterloo, SC',9130,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21940,NULL,'Waterloo, SC 29384',9130,222,NULL,48,12517,0);
INSERT INTO "django_geo_db_location" VALUES(21941,NULL,'Wellford, SC',9131,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21942,NULL,'Wellford, SC 29385',9131,222,NULL,48,12518,0);
INSERT INTO "django_geo_db_location" VALUES(21943,NULL,'White Stone, SC',9132,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21944,NULL,'White Stone, SC 29386',9132,222,NULL,48,12519,0);
INSERT INTO "django_geo_db_location" VALUES(21945,NULL,'Woodruff, SC',9133,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21946,NULL,'Woodruff, SC 29388',9133,222,NULL,48,12520,0);
INSERT INTO "django_geo_db_location" VALUES(21947,NULL,'Duncan, SC 29390',9103,222,NULL,48,12521,0);
INSERT INTO "django_geo_db_location" VALUES(21948,NULL,'Duncan, SC 29391',9103,222,NULL,48,12522,0);
INSERT INTO "django_geo_db_location" VALUES(21949,NULL,'Charleston, SC',9134,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21950,NULL,'Charleston, SC 29401',9134,222,NULL,48,12523,0);
INSERT INTO "django_geo_db_location" VALUES(21951,NULL,'Charleston, SC 29402',9134,222,NULL,48,12524,0);
INSERT INTO "django_geo_db_location" VALUES(21952,NULL,'Charleston, SC 29403',9134,222,NULL,48,12525,0);
INSERT INTO "django_geo_db_location" VALUES(21953,NULL,'Charleston AFB, SC',9135,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21954,NULL,'Charleston AFB, SC 29404',9135,222,NULL,48,12526,0);
INSERT INTO "django_geo_db_location" VALUES(21955,NULL,'North Charleston, SC',9136,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21956,NULL,'North Charleston, SC 29405',9136,222,NULL,48,12527,0);
INSERT INTO "django_geo_db_location" VALUES(21957,NULL,'Charleston, SC 29406',9134,222,NULL,48,12528,0);
INSERT INTO "django_geo_db_location" VALUES(21958,NULL,'Charleston, SC 29407',9134,222,NULL,48,12529,0);
INSERT INTO "django_geo_db_location" VALUES(21959,NULL,'Charleston, SC 29409',9134,222,NULL,48,12530,0);
INSERT INTO "django_geo_db_location" VALUES(21960,NULL,'Charleston, SC 29410',9134,222,NULL,48,12531,0);
INSERT INTO "django_geo_db_location" VALUES(21961,NULL,'Charleston, SC 29412',9134,222,NULL,48,12532,0);
INSERT INTO "django_geo_db_location" VALUES(21962,NULL,'Charleston, SC 29413',9134,222,NULL,48,12533,0);
INSERT INTO "django_geo_db_location" VALUES(21963,NULL,'Charleston, SC 29414',9134,222,NULL,48,12534,0);
INSERT INTO "django_geo_db_location" VALUES(21964,NULL,'Charleston, SC 29415',9134,222,NULL,48,12535,0);
INSERT INTO "django_geo_db_location" VALUES(21965,NULL,'Charleston, SC 29416',9134,222,NULL,48,12536,0);
INSERT INTO "django_geo_db_location" VALUES(21966,NULL,'Charleston, SC 29417',9134,222,NULL,48,12537,0);
INSERT INTO "django_geo_db_location" VALUES(21967,NULL,'North Charleston, SC 29418',9136,222,NULL,48,12538,0);
INSERT INTO "django_geo_db_location" VALUES(21968,NULL,'Charleston, SC 29419',9134,222,NULL,48,12539,0);
INSERT INTO "django_geo_db_location" VALUES(21969,NULL,'North Charleston, SC 29420',9136,222,NULL,48,12540,0);
INSERT INTO "django_geo_db_location" VALUES(21970,NULL,'Charleston, SC 29422',9134,222,NULL,48,12541,0);
INSERT INTO "django_geo_db_location" VALUES(21971,NULL,'Charleston, SC 29423',9134,222,NULL,48,12542,0);
INSERT INTO "django_geo_db_location" VALUES(21972,NULL,'Charleston, SC 29424',9134,222,NULL,48,12543,0);
INSERT INTO "django_geo_db_location" VALUES(21973,NULL,'Charleston, SC 29425',9134,222,NULL,48,12544,0);
INSERT INTO "django_geo_db_location" VALUES(21974,NULL,'Adams Run, SC',9137,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21975,NULL,'Adams Run, SC 29426',9137,222,NULL,48,12545,0);
INSERT INTO "django_geo_db_location" VALUES(21976,NULL,'Awendaw, SC',9138,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21977,NULL,'Awendaw, SC 29429',9138,222,NULL,48,12546,0);
INSERT INTO "django_geo_db_location" VALUES(21978,NULL,'Bethera, SC',9139,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21979,NULL,'Bethera, SC 29430',9139,222,NULL,48,12547,0);
INSERT INTO "django_geo_db_location" VALUES(21980,NULL,'Bonneau, SC',9140,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21981,NULL,'Bonneau, SC 29431',9140,222,NULL,48,12548,0);
INSERT INTO "django_geo_db_location" VALUES(21982,NULL,'Branchville, SC',9141,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21983,NULL,'Branchville, SC 29432',9141,222,NULL,48,12549,0);
INSERT INTO "django_geo_db_location" VALUES(21984,NULL,'Canadys, SC',9142,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21985,NULL,'Canadys, SC 29433',9142,222,NULL,48,12550,0);
INSERT INTO "django_geo_db_location" VALUES(21986,NULL,'Cordesville, SC',9143,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21987,NULL,'Cordesville, SC 29434',9143,222,NULL,48,12551,0);
INSERT INTO "django_geo_db_location" VALUES(21988,NULL,'Cottageville, SC',9144,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21989,NULL,'Cottageville, SC 29435',9144,222,NULL,48,12552,0);
INSERT INTO "django_geo_db_location" VALUES(21990,NULL,'Cross, SC',9145,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21991,NULL,'Cross, SC 29436',9145,222,NULL,48,12553,0);
INSERT INTO "django_geo_db_location" VALUES(21992,NULL,'Dorchester, SC',9146,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21993,NULL,'Dorchester, SC 29437',9146,222,NULL,48,12554,0);
INSERT INTO "django_geo_db_location" VALUES(21994,NULL,'Edisto Island, SC',9147,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21995,NULL,'Edisto Island, SC 29438',9147,222,NULL,48,12555,0);
INSERT INTO "django_geo_db_location" VALUES(21996,NULL,'Folly Beach, SC',9148,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21997,NULL,'Folly Beach, SC 29439',9148,222,NULL,48,12556,0);
INSERT INTO "django_geo_db_location" VALUES(21998,NULL,'Georgetown, SC',9149,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(21999,NULL,'Georgetown, SC 29440',9149,222,NULL,48,12557,0);
INSERT INTO "django_geo_db_location" VALUES(22000,NULL,'Georgetown, SC 29442',9149,222,NULL,48,12558,0);
INSERT INTO "django_geo_db_location" VALUES(22001,NULL,'Goose Creek, SC',9150,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22002,NULL,'Goose Creek, SC 29445',9150,222,NULL,48,12559,0);
INSERT INTO "django_geo_db_location" VALUES(22003,NULL,'Green Pond, SC',9151,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22004,NULL,'Green Pond, SC 29446',9151,222,NULL,48,12560,0);
INSERT INTO "django_geo_db_location" VALUES(22005,NULL,'Grover, SC',9152,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22006,NULL,'Grover, SC 29447',9152,222,NULL,48,12561,0);
INSERT INTO "django_geo_db_location" VALUES(22007,NULL,'Harleyville, SC',9153,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22008,NULL,'Harleyville, SC 29448',9153,222,NULL,48,12562,0);
INSERT INTO "django_geo_db_location" VALUES(22009,NULL,'Hollywood, SC',9154,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22010,NULL,'Hollywood, SC 29449',9154,222,NULL,48,12563,0);
INSERT INTO "django_geo_db_location" VALUES(22011,NULL,'Huger, SC',9155,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22012,NULL,'Huger, SC 29450',9155,222,NULL,48,12564,0);
INSERT INTO "django_geo_db_location" VALUES(22013,NULL,'Isle Of Palms, SC',9156,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22014,NULL,'Isle Of Palms, SC 29451',9156,222,NULL,48,12565,0);
INSERT INTO "django_geo_db_location" VALUES(22015,NULL,'Jacksonboro, SC',9157,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22016,NULL,'Jacksonboro, SC 29452',9157,222,NULL,48,12566,0);
INSERT INTO "django_geo_db_location" VALUES(22017,NULL,'Jamestown, SC',9158,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22018,NULL,'Jamestown, SC 29453',9158,222,NULL,48,12567,0);
INSERT INTO "django_geo_db_location" VALUES(22019,NULL,'Johns Island, SC',9159,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22020,NULL,'Johns Island, SC 29455',9159,222,NULL,48,12568,0);
INSERT INTO "django_geo_db_location" VALUES(22021,NULL,'Ladson, SC',9160,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22022,NULL,'Ladson, SC 29456',9160,222,NULL,48,12569,0);
INSERT INTO "django_geo_db_location" VALUES(22023,NULL,'Johns Island, SC 29457',9159,222,NULL,48,12570,0);
INSERT INTO "django_geo_db_location" VALUES(22024,NULL,'McClellanville, SC',9161,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22025,NULL,'McClellanville, SC 29458',9161,222,NULL,48,12571,0);
INSERT INTO "django_geo_db_location" VALUES(22026,NULL,'Moncks Corner, SC',9162,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22027,NULL,'Moncks Corner, SC 29461',9162,222,NULL,48,12572,0);
INSERT INTO "django_geo_db_location" VALUES(22028,NULL,'Mount Pleasant, SC',9163,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22029,NULL,'Mount Pleasant, SC 29464',9163,222,NULL,48,12573,0);
INSERT INTO "django_geo_db_location" VALUES(22030,NULL,'Mount Pleasant, SC 29465',9163,222,NULL,48,12574,0);
INSERT INTO "django_geo_db_location" VALUES(22031,NULL,'Mount Pleasant, SC 29466',9163,222,NULL,48,12575,0);
INSERT INTO "django_geo_db_location" VALUES(22032,NULL,'Pineville, SC',9164,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22033,NULL,'Pineville, SC 29468',9164,222,NULL,48,12576,0);
INSERT INTO "django_geo_db_location" VALUES(22034,NULL,'Pinopolis, SC',9165,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22035,NULL,'Pinopolis, SC 29469',9165,222,NULL,48,12577,0);
INSERT INTO "django_geo_db_location" VALUES(22036,NULL,'Ravenel, SC',9166,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22037,NULL,'Ravenel, SC 29470',9166,222,NULL,48,12578,0);
INSERT INTO "django_geo_db_location" VALUES(22038,NULL,'Reevesville, SC',9167,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22039,NULL,'Reevesville, SC 29471',9167,222,NULL,48,12579,0);
INSERT INTO "django_geo_db_location" VALUES(22040,NULL,'Ridgeville, SC',9168,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22041,NULL,'Ridgeville, SC 29472',9168,222,NULL,48,12580,0);
INSERT INTO "django_geo_db_location" VALUES(22042,NULL,'Round O, SC',9169,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22043,NULL,'Round O, SC 29474',9169,222,NULL,48,12581,0);
INSERT INTO "django_geo_db_location" VALUES(22044,NULL,'Ruffin, SC',9170,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22045,NULL,'Ruffin, SC 29475',9170,222,NULL,48,12582,0);
INSERT INTO "django_geo_db_location" VALUES(22046,NULL,'Russellville, SC',9171,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22047,NULL,'Russellville, SC 29476',9171,222,NULL,48,12583,0);
INSERT INTO "django_geo_db_location" VALUES(22048,NULL,'Saint George, SC',9172,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22049,NULL,'Saint George, SC 29477',9172,222,NULL,48,12584,0);
INSERT INTO "django_geo_db_location" VALUES(22050,NULL,'Saint Stephen, SC',9173,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22051,NULL,'Saint Stephen, SC 29479',9173,222,NULL,48,12585,0);
INSERT INTO "django_geo_db_location" VALUES(22052,NULL,'Smoaks, SC',9174,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22053,NULL,'Smoaks, SC 29481',9174,222,NULL,48,12586,0);
INSERT INTO "django_geo_db_location" VALUES(22054,NULL,'Sullivans Island, SC',9175,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22055,NULL,'Sullivans Island, SC 29482',9175,222,NULL,48,12587,0);
INSERT INTO "django_geo_db_location" VALUES(22056,NULL,'Summerville, SC',9176,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22057,NULL,'Summerville, SC 29483',9176,222,NULL,48,12588,0);
INSERT INTO "django_geo_db_location" VALUES(22058,NULL,'Summerville, SC 29484',9176,222,NULL,48,12589,0);
INSERT INTO "django_geo_db_location" VALUES(22059,NULL,'Summerville, SC 29485',9176,222,NULL,48,12590,0);
INSERT INTO "django_geo_db_location" VALUES(22060,NULL,'Wadmalaw Island, SC',9177,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22061,NULL,'Wadmalaw Island, SC 29487',9177,222,NULL,48,12591,0);
INSERT INTO "django_geo_db_location" VALUES(22062,NULL,'Walterboro, SC',9178,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22063,NULL,'Walterboro, SC 29488',9178,222,NULL,48,12592,0);
INSERT INTO "django_geo_db_location" VALUES(22064,NULL,'Charleston, SC 29492',9134,222,NULL,48,12593,0);
INSERT INTO "django_geo_db_location" VALUES(22065,NULL,'Williams, SC',9179,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22066,NULL,'Williams, SC 29493',9179,222,NULL,48,12594,0);
INSERT INTO "django_geo_db_location" VALUES(22067,NULL,'Hollywood, SC 29494',9154,222,NULL,48,12595,0);
INSERT INTO "django_geo_db_location" VALUES(22068,NULL,'Florence, SC',9180,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22069,NULL,'Florence, SC 29501',9180,222,NULL,48,12596,0);
INSERT INTO "django_geo_db_location" VALUES(22070,NULL,'Florence, SC 29502',9180,222,NULL,48,12597,0);
INSERT INTO "django_geo_db_location" VALUES(22071,NULL,'Florence, SC 29503',9180,222,NULL,48,12598,0);
INSERT INTO "django_geo_db_location" VALUES(22072,NULL,'Florence, SC 29504',9180,222,NULL,48,12599,0);
INSERT INTO "django_geo_db_location" VALUES(22073,NULL,'Florence, SC 29505',9180,222,NULL,48,12600,0);
INSERT INTO "django_geo_db_location" VALUES(22074,NULL,'Florence, SC 29506',9180,222,NULL,48,12601,0);
INSERT INTO "django_geo_db_location" VALUES(22075,NULL,'Andrews, SC',9181,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22076,NULL,'Andrews, SC 29510',9181,222,NULL,48,12602,0);
INSERT INTO "django_geo_db_location" VALUES(22077,NULL,'Aynor, SC',9182,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22078,NULL,'Aynor, SC 29511',9182,222,NULL,48,12603,0);
INSERT INTO "django_geo_db_location" VALUES(22079,NULL,'Bennettsville, SC',9183,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22080,NULL,'Bennettsville, SC 29512',9183,222,NULL,48,12604,0);
INSERT INTO "django_geo_db_location" VALUES(22081,NULL,'Blenheim, SC',9184,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22082,NULL,'Blenheim, SC 29516',9184,222,NULL,48,12605,0);
INSERT INTO "django_geo_db_location" VALUES(22083,NULL,'Cades, SC',9185,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22084,NULL,'Cades, SC 29518',9185,222,NULL,48,12606,0);
INSERT INTO "django_geo_db_location" VALUES(22085,NULL,'Centenary, SC',9186,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22086,NULL,'Centenary, SC 29519',9186,222,NULL,48,12607,0);
INSERT INTO "django_geo_db_location" VALUES(22087,NULL,'Cheraw, SC',9187,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22088,NULL,'Cheraw, SC 29520',9187,222,NULL,48,12608,0);
INSERT INTO "django_geo_db_location" VALUES(22089,NULL,'Clio, SC',9188,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22090,NULL,'Clio, SC 29525',9188,222,NULL,48,12609,0);
INSERT INTO "django_geo_db_location" VALUES(22091,NULL,'Conway, SC',9189,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22092,NULL,'Conway, SC 29526',9189,222,NULL,48,12610,0);
INSERT INTO "django_geo_db_location" VALUES(22093,NULL,'Conway, SC 29527',9189,222,NULL,48,12611,0);
INSERT INTO "django_geo_db_location" VALUES(22094,NULL,'Conway, SC 29528',9189,222,NULL,48,12612,0);
INSERT INTO "django_geo_db_location" VALUES(22095,NULL,'Coward, SC',9190,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22096,NULL,'Coward, SC 29530',9190,222,NULL,48,12613,0);
INSERT INTO "django_geo_db_location" VALUES(22097,NULL,'Darlington, SC',9191,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22098,NULL,'Darlington, SC 29532',9191,222,NULL,48,12614,0);
INSERT INTO "django_geo_db_location" VALUES(22099,NULL,'McCormick, SC',9192,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22100,NULL,'McCormick, SC 29535',9192,222,NULL,48,12615,0);
INSERT INTO "django_geo_db_location" VALUES(22101,NULL,'Dillon, SC',9193,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22102,NULL,'Dillon, SC 29536',9193,222,NULL,48,12616,0);
INSERT INTO "django_geo_db_location" VALUES(22103,NULL,'Darlington, SC 29540',9191,222,NULL,48,12617,0);
INSERT INTO "django_geo_db_location" VALUES(22104,NULL,'Effingham, SC',9194,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22105,NULL,'Effingham, SC 29541',9194,222,NULL,48,12618,0);
INSERT INTO "django_geo_db_location" VALUES(22106,NULL,'Floyd Dale, SC',9195,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22107,NULL,'Floyd Dale, SC 29542',9195,222,NULL,48,12619,0);
INSERT INTO "django_geo_db_location" VALUES(22108,NULL,'Fork, SC',9196,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22109,NULL,'Fork, SC 29543',9196,222,NULL,48,12620,0);
INSERT INTO "django_geo_db_location" VALUES(22110,NULL,'Galivants Ferry, SC',9197,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22111,NULL,'Galivants Ferry, SC 29544',9197,222,NULL,48,12621,0);
INSERT INTO "django_geo_db_location" VALUES(22112,NULL,'Green Sea, SC',9198,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22113,NULL,'Green Sea, SC 29545',9198,222,NULL,48,12622,0);
INSERT INTO "django_geo_db_location" VALUES(22114,NULL,'Gresham, SC',9199,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22115,NULL,'Gresham, SC 29546',9199,222,NULL,48,12623,0);
INSERT INTO "django_geo_db_location" VALUES(22116,NULL,'Hamer, SC',9200,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22117,NULL,'Hamer, SC 29547',9200,222,NULL,48,12624,0);
INSERT INTO "django_geo_db_location" VALUES(22118,NULL,'Myrtle Beach, SC',9201,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22119,NULL,'Myrtle Beach, SC 29549',9201,222,NULL,48,12625,0);
INSERT INTO "django_geo_db_location" VALUES(22120,NULL,'Hartsville, SC',9202,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22121,NULL,'Hartsville, SC 29550',9202,222,NULL,48,12626,0);
INSERT INTO "django_geo_db_location" VALUES(22122,NULL,'Hartsville, SC 29551',9202,222,NULL,48,12627,0);
INSERT INTO "django_geo_db_location" VALUES(22123,NULL,'Hemingway, SC',9203,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22124,NULL,'Hemingway, SC 29554',9203,222,NULL,48,12628,0);
INSERT INTO "django_geo_db_location" VALUES(22125,NULL,'Johnsonville, SC',9204,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22126,NULL,'Johnsonville, SC 29555',9204,222,NULL,48,12629,0);
INSERT INTO "django_geo_db_location" VALUES(22127,NULL,'Kingstree, SC',9205,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22128,NULL,'Kingstree, SC 29556',9205,222,NULL,48,12630,0);
INSERT INTO "django_geo_db_location" VALUES(22129,NULL,'Lake City, SC',9206,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22130,NULL,'Lake City, SC 29560',9206,222,NULL,48,12631,0);
INSERT INTO "django_geo_db_location" VALUES(22131,NULL,'Latta, SC',9207,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22132,NULL,'Latta, SC 29561',9207,222,NULL,48,12632,0);
INSERT INTO "django_geo_db_location" VALUES(22133,NULL,'Lake View, SC 29563',9116,222,NULL,48,12633,0);
INSERT INTO "django_geo_db_location" VALUES(22134,NULL,'Lane, SC',9208,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22135,NULL,'Lane, SC 29564',9208,222,NULL,48,12634,0);
INSERT INTO "django_geo_db_location" VALUES(22136,NULL,'Latta, SC 29565',9207,222,NULL,48,12635,0);
INSERT INTO "django_geo_db_location" VALUES(22137,NULL,'Little River, SC',9209,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22138,NULL,'Little River, SC 29566',9209,222,NULL,48,12636,0);
INSERT INTO "django_geo_db_location" VALUES(22139,NULL,'Little Rock, SC',9210,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22140,NULL,'Little Rock, SC 29567',9210,222,NULL,48,12637,0);
INSERT INTO "django_geo_db_location" VALUES(22141,NULL,'Longs, SC',9211,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22142,NULL,'Longs, SC 29568',9211,222,NULL,48,12638,0);
INSERT INTO "django_geo_db_location" VALUES(22143,NULL,'Loris, SC',9212,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22144,NULL,'Loris, SC 29569',9212,222,NULL,48,12639,0);
INSERT INTO "django_geo_db_location" VALUES(22145,NULL,'McColl, SC',9213,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22146,NULL,'McColl, SC 29570',9213,222,NULL,48,12640,0);
INSERT INTO "django_geo_db_location" VALUES(22147,NULL,'Marion, SC',9214,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22148,NULL,'Marion, SC 29571',9214,222,NULL,48,12641,0);
INSERT INTO "django_geo_db_location" VALUES(22149,NULL,'Myrtle Beach, SC 29572',9201,222,NULL,48,12642,0);
INSERT INTO "django_geo_db_location" VALUES(22150,NULL,'Minturn, SC',9215,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22151,NULL,'Minturn, SC 29573',9215,222,NULL,48,12643,0);
INSERT INTO "django_geo_db_location" VALUES(22152,NULL,'Mullins, SC',9216,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22153,NULL,'Mullins, SC 29574',9216,222,NULL,48,12644,0);
INSERT INTO "django_geo_db_location" VALUES(22154,NULL,'Myrtle Beach, SC 29575',9201,222,NULL,48,12645,0);
INSERT INTO "django_geo_db_location" VALUES(22155,NULL,'Murrells Inlet, SC',9217,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22156,NULL,'Murrells Inlet, SC 29576',9217,222,NULL,48,12646,0);
INSERT INTO "django_geo_db_location" VALUES(22157,NULL,'Myrtle Beach, SC 29577',9201,222,NULL,48,12647,0);
INSERT INTO "django_geo_db_location" VALUES(22158,NULL,'Myrtle Beach, SC 29578',9201,222,NULL,48,12648,0);
INSERT INTO "django_geo_db_location" VALUES(22159,NULL,'Myrtle Beach, SC 29579',9201,222,NULL,48,12649,0);
INSERT INTO "django_geo_db_location" VALUES(22160,NULL,'Nesmith, SC',9218,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22161,NULL,'Nesmith, SC 29580',9218,222,NULL,48,12650,0);
INSERT INTO "django_geo_db_location" VALUES(22162,NULL,'Nichols, SC',9219,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22163,NULL,'Nichols, SC 29581',9219,222,NULL,48,12651,0);
INSERT INTO "django_geo_db_location" VALUES(22164,NULL,'North Myrtle Beach, SC',9220,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22165,NULL,'North Myrtle Beach, SC 29582',9220,222,NULL,48,12652,0);
INSERT INTO "django_geo_db_location" VALUES(22166,NULL,'Pamplico, SC',9221,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22167,NULL,'Pamplico, SC 29583',9221,222,NULL,48,12653,0);
INSERT INTO "django_geo_db_location" VALUES(22168,NULL,'Patrick, SC',9222,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22169,NULL,'Patrick, SC 29584',9222,222,NULL,48,12654,0);
INSERT INTO "django_geo_db_location" VALUES(22170,NULL,'Pawleys Island, SC',9223,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22171,NULL,'Pawleys Island, SC 29585',9223,222,NULL,48,12655,0);
INSERT INTO "django_geo_db_location" VALUES(22172,NULL,'Myrtle Beach, SC 29587',9201,222,NULL,48,12656,0);
INSERT INTO "django_geo_db_location" VALUES(22173,NULL,'Myrtle Beach, SC 29588',9201,222,NULL,48,12657,0);
INSERT INTO "django_geo_db_location" VALUES(22174,NULL,'Rains, SC',9224,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22175,NULL,'Rains, SC 29589',9224,222,NULL,48,12658,0);
INSERT INTO "django_geo_db_location" VALUES(22176,NULL,'Salters, SC',9225,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22177,NULL,'Salters, SC 29590',9225,222,NULL,48,12659,0);
INSERT INTO "django_geo_db_location" VALUES(22178,NULL,'Scranton, SC',9226,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22179,NULL,'Scranton, SC 29591',9226,222,NULL,48,12660,0);
INSERT INTO "django_geo_db_location" VALUES(22180,NULL,'Sellers, SC',9227,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22181,NULL,'Sellers, SC 29592',9227,222,NULL,48,12661,0);
INSERT INTO "django_geo_db_location" VALUES(22182,NULL,'Society Hill, SC',9228,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22183,NULL,'Society Hill, SC 29593',9228,222,NULL,48,12662,0);
INSERT INTO "django_geo_db_location" VALUES(22184,NULL,'Tatum, SC',9229,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22185,NULL,'Tatum, SC 29594',9229,222,NULL,48,12663,0);
INSERT INTO "django_geo_db_location" VALUES(22186,NULL,'Wallace, SC',9230,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22187,NULL,'Wallace, SC 29596',9230,222,NULL,48,12664,0);
INSERT INTO "django_geo_db_location" VALUES(22188,NULL,'North Myrtle Beach, SC 29597',9220,222,NULL,48,12665,0);
INSERT INTO "django_geo_db_location" VALUES(22189,NULL,'North Myrtle Beach, SC 29598',9220,222,NULL,48,12666,0);
INSERT INTO "django_geo_db_location" VALUES(22190,NULL,'Socastee, SC',9231,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22191,NULL,'Socastee, SC 29599',9231,222,NULL,48,12667,0);
INSERT INTO "django_geo_db_location" VALUES(22192,NULL,'Greenville, SC',9232,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22193,NULL,'Greenville, SC 29601',9232,222,NULL,48,12668,0);
INSERT INTO "django_geo_db_location" VALUES(22194,NULL,'Greenville, SC 29602',9232,222,NULL,48,12669,0);
INSERT INTO "django_geo_db_location" VALUES(22195,NULL,'Greenville, SC 29603',9232,222,NULL,48,12670,0);
INSERT INTO "django_geo_db_location" VALUES(22196,NULL,'Greenville, SC 29604',9232,222,NULL,48,12671,0);
INSERT INTO "django_geo_db_location" VALUES(22197,NULL,'Greenville, SC 29605',9232,222,NULL,48,12672,0);
INSERT INTO "django_geo_db_location" VALUES(22198,NULL,'Greenville, SC 29606',9232,222,NULL,48,12673,0);
INSERT INTO "django_geo_db_location" VALUES(22199,NULL,'Greenville, SC 29607',9232,222,NULL,48,12674,0);
INSERT INTO "django_geo_db_location" VALUES(22200,NULL,'Greenville, SC 29608',9232,222,NULL,48,12675,0);
INSERT INTO "django_geo_db_location" VALUES(22201,NULL,'Greenville, SC 29609',9232,222,NULL,48,12676,0);
INSERT INTO "django_geo_db_location" VALUES(22202,NULL,'Greenville, SC 29610',9232,222,NULL,48,12677,0);
INSERT INTO "django_geo_db_location" VALUES(22203,NULL,'Greenville, SC 29611',9232,222,NULL,48,12678,0);
INSERT INTO "django_geo_db_location" VALUES(22204,NULL,'Greenville, SC 29612',9232,222,NULL,48,12679,0);
INSERT INTO "django_geo_db_location" VALUES(22205,NULL,'Greenville, SC 29613',9232,222,NULL,48,12680,0);
INSERT INTO "django_geo_db_location" VALUES(22206,NULL,'Greenville, SC 29614',9232,222,NULL,48,12681,0);
INSERT INTO "django_geo_db_location" VALUES(22207,NULL,'Greenville, SC 29615',9232,222,NULL,48,12682,0);
INSERT INTO "django_geo_db_location" VALUES(22208,NULL,'Greenville, SC 29616',9232,222,NULL,48,12683,0);
INSERT INTO "django_geo_db_location" VALUES(22209,NULL,'Greenville, SC 29617',9232,222,NULL,48,12684,0);
INSERT INTO "django_geo_db_location" VALUES(22210,NULL,'Abbeville, SC',9233,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22211,NULL,'Abbeville, SC 29620',9233,222,NULL,48,12685,0);
INSERT INTO "django_geo_db_location" VALUES(22212,NULL,'Anderson, SC',9234,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22213,NULL,'Anderson, SC 29621',9234,222,NULL,48,12686,0);
INSERT INTO "django_geo_db_location" VALUES(22214,NULL,'Anderson, SC 29622',9234,222,NULL,48,12687,0);
INSERT INTO "django_geo_db_location" VALUES(22215,NULL,'Anderson, SC 29623',9234,222,NULL,48,12688,0);
INSERT INTO "django_geo_db_location" VALUES(22216,NULL,'Anderson, SC 29624',9234,222,NULL,48,12689,0);
INSERT INTO "django_geo_db_location" VALUES(22217,NULL,'Anderson, SC 29625',9234,222,NULL,48,12690,0);
INSERT INTO "django_geo_db_location" VALUES(22218,NULL,'Anderson, SC 29626',9234,222,NULL,48,12691,0);
INSERT INTO "django_geo_db_location" VALUES(22219,NULL,'Belton, SC',9235,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22220,NULL,'Belton, SC 29627',9235,222,NULL,48,12692,0);
INSERT INTO "django_geo_db_location" VALUES(22221,NULL,'Calhoun Falls, SC',9236,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22222,NULL,'Calhoun Falls, SC 29628',9236,222,NULL,48,12693,0);
INSERT INTO "django_geo_db_location" VALUES(22223,NULL,'Central, SC',9237,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22224,NULL,'Central, SC 29630',9237,222,NULL,48,12694,0);
INSERT INTO "django_geo_db_location" VALUES(22225,NULL,'Clemson, SC',9238,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22226,NULL,'Clemson, SC 29631',9238,222,NULL,48,12695,0);
INSERT INTO "django_geo_db_location" VALUES(22227,NULL,'Clemson, SC 29632',9238,222,NULL,48,12696,0);
INSERT INTO "django_geo_db_location" VALUES(22228,NULL,'Clemson, SC 29633',9238,222,NULL,48,12697,0);
INSERT INTO "django_geo_db_location" VALUES(22229,NULL,'Clemson, SC 29634',9238,222,NULL,48,12698,0);
INSERT INTO "django_geo_db_location" VALUES(22230,NULL,'Cleveland, SC',9239,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22231,NULL,'Cleveland, SC 29635',9239,222,NULL,48,12699,0);
INSERT INTO "django_geo_db_location" VALUES(22232,NULL,'Conestee, SC',9240,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22233,NULL,'Conestee, SC 29636',9240,222,NULL,48,12700,0);
INSERT INTO "django_geo_db_location" VALUES(22234,NULL,'Donalds, SC',9241,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22235,NULL,'Donalds, SC 29638',9241,222,NULL,48,12701,0);
INSERT INTO "django_geo_db_location" VALUES(22236,NULL,'Due West, SC',9242,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22237,NULL,'Due West, SC 29639',9242,222,NULL,48,12702,0);
INSERT INTO "django_geo_db_location" VALUES(22238,NULL,'Easley, SC',9243,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22239,NULL,'Easley, SC 29640',9243,222,NULL,48,12703,0);
INSERT INTO "django_geo_db_location" VALUES(22240,NULL,'Easley, SC 29641',9243,222,NULL,48,12704,0);
INSERT INTO "django_geo_db_location" VALUES(22241,NULL,'Easley, SC 29642',9243,222,NULL,48,12705,0);
INSERT INTO "django_geo_db_location" VALUES(22242,NULL,'Fair Play, SC',9244,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22243,NULL,'Fair Play, SC 29643',9244,222,NULL,48,12706,0);
INSERT INTO "django_geo_db_location" VALUES(22244,NULL,'Fountain Inn, SC',9245,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22245,NULL,'Fountain Inn, SC 29644',9245,222,NULL,48,12707,0);
INSERT INTO "django_geo_db_location" VALUES(22246,NULL,'Gray Court, SC',9246,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22247,NULL,'Gray Court, SC 29645',9246,222,NULL,48,12708,0);
INSERT INTO "django_geo_db_location" VALUES(22248,NULL,'Greenwood, SC',9247,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22249,NULL,'Greenwood, SC 29646',9247,222,NULL,48,12709,0);
INSERT INTO "django_geo_db_location" VALUES(22250,NULL,'Greenwood, SC 29647',9247,222,NULL,48,12710,0);
INSERT INTO "django_geo_db_location" VALUES(22251,NULL,'Greenwood, SC 29648',9247,222,NULL,48,12711,0);
INSERT INTO "django_geo_db_location" VALUES(22252,NULL,'Greenwood, SC 29649',9247,222,NULL,48,12712,0);
INSERT INTO "django_geo_db_location" VALUES(22253,NULL,'Greer, SC',9248,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22254,NULL,'Greer, SC 29650',9248,222,NULL,48,12713,0);
INSERT INTO "django_geo_db_location" VALUES(22255,NULL,'Greer, SC 29651',9248,222,NULL,48,12714,0);
INSERT INTO "django_geo_db_location" VALUES(22256,NULL,'Greer, SC 29652',9248,222,NULL,48,12715,0);
INSERT INTO "django_geo_db_location" VALUES(22257,NULL,'Hodges, SC',9249,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22258,NULL,'Hodges, SC 29653',9249,222,NULL,48,12716,0);
INSERT INTO "django_geo_db_location" VALUES(22259,NULL,'Honea Path, SC',9250,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22260,NULL,'Honea Path, SC 29654',9250,222,NULL,48,12717,0);
INSERT INTO "django_geo_db_location" VALUES(22261,NULL,'Iva, SC',9251,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22262,NULL,'Iva, SC 29655',9251,222,NULL,48,12718,0);
INSERT INTO "django_geo_db_location" VALUES(22263,NULL,'La France, SC',9252,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22264,NULL,'La France, SC 29656',9252,222,NULL,48,12719,0);
INSERT INTO "django_geo_db_location" VALUES(22265,NULL,'Liberty, SC',9253,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22266,NULL,'Liberty, SC 29657',9253,222,NULL,48,12720,0);
INSERT INTO "django_geo_db_location" VALUES(22267,NULL,'Long Creek, SC',9254,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22268,NULL,'Long Creek, SC 29658',9254,222,NULL,48,12721,0);
INSERT INTO "django_geo_db_location" VALUES(22269,NULL,'Lowndesville, SC',9255,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22270,NULL,'Lowndesville, SC 29659',9255,222,NULL,48,12722,0);
INSERT INTO "django_geo_db_location" VALUES(22271,NULL,'Marietta, SC',9256,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22272,NULL,'Marietta, SC 29661',9256,222,NULL,48,12723,0);
INSERT INTO "django_geo_db_location" VALUES(22273,NULL,'Mauldin, SC',9257,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22274,NULL,'Mauldin, SC 29662',9257,222,NULL,48,12724,0);
INSERT INTO "django_geo_db_location" VALUES(22275,NULL,'Mountain Rest, SC',9258,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22276,NULL,'Mountain Rest, SC 29664',9258,222,NULL,48,12725,0);
INSERT INTO "django_geo_db_location" VALUES(22277,NULL,'Newry, SC',9259,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22278,NULL,'Newry, SC 29665',9259,222,NULL,48,12726,0);
INSERT INTO "django_geo_db_location" VALUES(22279,NULL,'Ninety Six, SC',9260,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22280,NULL,'Ninety Six, SC 29666',9260,222,NULL,48,12727,0);
INSERT INTO "django_geo_db_location" VALUES(22281,NULL,'Norris, SC',9261,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22282,NULL,'Norris, SC 29667',9261,222,NULL,48,12728,0);
INSERT INTO "django_geo_db_location" VALUES(22283,NULL,'Pelzer, SC',9262,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22284,NULL,'Pelzer, SC 29669',9262,222,NULL,48,12729,0);
INSERT INTO "django_geo_db_location" VALUES(22285,NULL,'Pendleton, SC',9263,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22286,NULL,'Pendleton, SC 29670',9263,222,NULL,48,12730,0);
INSERT INTO "django_geo_db_location" VALUES(22287,NULL,'Pickens, SC',9264,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22288,NULL,'Pickens, SC 29671',9264,222,NULL,48,12731,0);
INSERT INTO "django_geo_db_location" VALUES(22289,NULL,'Seneca, SC',9265,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22290,NULL,'Seneca, SC 29672',9265,222,NULL,48,12732,0);
INSERT INTO "django_geo_db_location" VALUES(22291,NULL,'Piedmont, SC',9266,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22292,NULL,'Piedmont, SC 29673',9266,222,NULL,48,12733,0);
INSERT INTO "django_geo_db_location" VALUES(22293,NULL,'Richland, SC',9267,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22294,NULL,'Richland, SC 29675',9267,222,NULL,48,12734,0);
INSERT INTO "django_geo_db_location" VALUES(22295,NULL,'Salem, SC',9268,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22296,NULL,'Salem, SC 29676',9268,222,NULL,48,12735,0);
INSERT INTO "django_geo_db_location" VALUES(22297,NULL,'Sandy Springs, SC',9269,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22298,NULL,'Sandy Springs, SC 29677',9269,222,NULL,48,12736,0);
INSERT INTO "django_geo_db_location" VALUES(22299,NULL,'Seneca, SC 29678',9265,222,NULL,48,12737,0);
INSERT INTO "django_geo_db_location" VALUES(22300,NULL,'Seneca, SC 29679',9265,222,NULL,48,12738,0);
INSERT INTO "django_geo_db_location" VALUES(22301,NULL,'Simpsonville, SC',9270,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22302,NULL,'Simpsonville, SC 29680',9270,222,NULL,48,12739,0);
INSERT INTO "django_geo_db_location" VALUES(22303,NULL,'Simpsonville, SC 29681',9270,222,NULL,48,12740,0);
INSERT INTO "django_geo_db_location" VALUES(22304,NULL,'Six Mile, SC',9271,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22305,NULL,'Six Mile, SC 29682',9271,222,NULL,48,12741,0);
INSERT INTO "django_geo_db_location" VALUES(22306,NULL,'Slater, SC',9272,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22307,NULL,'Slater, SC 29683',9272,222,NULL,48,12742,0);
INSERT INTO "django_geo_db_location" VALUES(22308,NULL,'Starr, SC',9273,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22309,NULL,'Starr, SC 29684',9273,222,NULL,48,12743,0);
INSERT INTO "django_geo_db_location" VALUES(22310,NULL,'Sunset, SC',9274,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22311,NULL,'Sunset, SC 29685',9274,222,NULL,48,12744,0);
INSERT INTO "django_geo_db_location" VALUES(22312,NULL,'Tamassee, SC',9275,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22313,NULL,'Tamassee, SC 29686',9275,222,NULL,48,12745,0);
INSERT INTO "django_geo_db_location" VALUES(22314,NULL,'Taylors, SC',9276,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22315,NULL,'Taylors, SC 29687',9276,222,NULL,48,12746,0);
INSERT INTO "django_geo_db_location" VALUES(22316,NULL,'Tigerville, SC',9277,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22317,NULL,'Tigerville, SC 29688',9277,222,NULL,48,12747,0);
INSERT INTO "django_geo_db_location" VALUES(22318,NULL,'Townville, SC',9278,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22319,NULL,'Townville, SC 29689',9278,222,NULL,48,12748,0);
INSERT INTO "django_geo_db_location" VALUES(22320,NULL,'Travelers Rest, SC',9279,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22321,NULL,'Travelers Rest, SC 29690',9279,222,NULL,48,12749,0);
INSERT INTO "django_geo_db_location" VALUES(22322,NULL,'Walhalla, SC',9280,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22323,NULL,'Walhalla, SC 29691',9280,222,NULL,48,12750,0);
INSERT INTO "django_geo_db_location" VALUES(22324,NULL,'Ware Shoals, SC',9281,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22325,NULL,'Ware Shoals, SC 29692',9281,222,NULL,48,12751,0);
INSERT INTO "django_geo_db_location" VALUES(22326,NULL,'Westminster, SC',9282,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22327,NULL,'Westminster, SC 29693',9282,222,NULL,48,12752,0);
INSERT INTO "django_geo_db_location" VALUES(22328,NULL,'Hodges, SC 29695',9249,222,NULL,48,12753,0);
INSERT INTO "django_geo_db_location" VALUES(22329,NULL,'West Union, SC',9283,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22330,NULL,'West Union, SC 29696',9283,222,NULL,48,12754,0);
INSERT INTO "django_geo_db_location" VALUES(22331,NULL,'Williamston, SC',9284,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22332,NULL,'Williamston, SC 29697',9284,222,NULL,48,12755,0);
INSERT INTO "django_geo_db_location" VALUES(22333,NULL,'Greenville, SC 29698',9232,222,NULL,48,12756,0);
INSERT INTO "django_geo_db_location" VALUES(22334,NULL,'Blacksburg, SC',9285,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22335,NULL,'Blacksburg, SC 29702',9285,222,NULL,48,12757,0);
INSERT INTO "django_geo_db_location" VALUES(22336,NULL,'Bowling Green, SC',9286,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22337,NULL,'Bowling Green, SC 29703',9286,222,NULL,48,12758,0);
INSERT INTO "django_geo_db_location" VALUES(22338,NULL,'Catawba, SC',9287,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22339,NULL,'Catawba, SC 29704',9287,222,NULL,48,12759,0);
INSERT INTO "django_geo_db_location" VALUES(22340,NULL,'Chester, SC',9288,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22341,NULL,'Chester, SC 29706',9288,222,NULL,48,12760,0);
INSERT INTO "django_geo_db_location" VALUES(22342,NULL,'Fort Mill, SC',9289,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22343,NULL,'Fort Mill, SC 29708',9289,222,NULL,48,12761,0);
INSERT INTO "django_geo_db_location" VALUES(22344,NULL,'Chesterfield, SC',9290,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22345,NULL,'Chesterfield, SC 29709',9290,222,NULL,48,12762,0);
INSERT INTO "django_geo_db_location" VALUES(22346,NULL,'Clover, SC',9291,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22347,NULL,'Clover, SC 29710',9291,222,NULL,48,12763,0);
INSERT INTO "django_geo_db_location" VALUES(22348,NULL,'Edgemoor, SC',9292,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22349,NULL,'Edgemoor, SC 29712',9292,222,NULL,48,12764,0);
INSERT INTO "django_geo_db_location" VALUES(22350,NULL,'Fort Lawn, SC',9293,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22351,NULL,'Fort Lawn, SC 29714',9293,222,NULL,48,12765,0);
INSERT INTO "django_geo_db_location" VALUES(22352,NULL,'Fort Mill, SC 29715',9289,222,NULL,48,12766,0);
INSERT INTO "django_geo_db_location" VALUES(22353,NULL,'Fort Mill, SC 29716',9289,222,NULL,48,12767,0);
INSERT INTO "django_geo_db_location" VALUES(22354,NULL,'Hickory Grove, SC',9294,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22355,NULL,'Hickory Grove, SC 29717',9294,222,NULL,48,12768,0);
INSERT INTO "django_geo_db_location" VALUES(22356,NULL,'Jefferson, SC',9295,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22357,NULL,'Jefferson, SC 29718',9295,222,NULL,48,12769,0);
INSERT INTO "django_geo_db_location" VALUES(22358,NULL,'Lancaster, SC',9296,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22359,NULL,'Lancaster, SC 29720',9296,222,NULL,48,12770,0);
INSERT INTO "django_geo_db_location" VALUES(22360,NULL,'Lancaster, SC 29721',9296,222,NULL,48,12771,0);
INSERT INTO "django_geo_db_location" VALUES(22361,NULL,'Lancaster, SC 29722',9296,222,NULL,48,12772,0);
INSERT INTO "django_geo_db_location" VALUES(22362,NULL,'Lando, SC',9297,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22363,NULL,'Lando, SC 29724',9297,222,NULL,48,12773,0);
INSERT INTO "django_geo_db_location" VALUES(22364,NULL,'McConnells, SC',9298,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22365,NULL,'McConnells, SC 29726',9298,222,NULL,48,12774,0);
INSERT INTO "django_geo_db_location" VALUES(22366,NULL,'Mount Croghan, SC',9299,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22367,NULL,'Mount Croghan, SC 29727',9299,222,NULL,48,12775,0);
INSERT INTO "django_geo_db_location" VALUES(22368,NULL,'Pageland, SC',9300,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22369,NULL,'Pageland, SC 29728',9300,222,NULL,48,12776,0);
INSERT INTO "django_geo_db_location" VALUES(22370,NULL,'Richburg, SC',9301,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22371,NULL,'Richburg, SC 29729',9301,222,NULL,48,12777,0);
INSERT INTO "django_geo_db_location" VALUES(22372,NULL,'Rock Hill, SC',9302,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22373,NULL,'Rock Hill, SC 29730',9302,222,NULL,48,12778,0);
INSERT INTO "django_geo_db_location" VALUES(22374,NULL,'Rock Hill, SC 29731',9302,222,NULL,48,12779,0);
INSERT INTO "django_geo_db_location" VALUES(22375,NULL,'Rock Hill, SC 29732',9302,222,NULL,48,12780,0);
INSERT INTO "django_geo_db_location" VALUES(22376,NULL,'Rock Hill, SC 29733',9302,222,NULL,48,12781,0);
INSERT INTO "django_geo_db_location" VALUES(22377,NULL,'Rock Hill, SC 29734',9302,222,NULL,48,12782,0);
INSERT INTO "django_geo_db_location" VALUES(22378,NULL,'Ruby, SC',9303,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22379,NULL,'Ruby, SC 29741',9303,222,NULL,48,12783,0);
INSERT INTO "django_geo_db_location" VALUES(22380,NULL,'Sharon, SC',9304,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22381,NULL,'Sharon, SC 29742',9304,222,NULL,48,12784,0);
INSERT INTO "django_geo_db_location" VALUES(22382,NULL,'Smyrna, SC',9305,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22383,NULL,'Smyrna, SC 29743',9305,222,NULL,48,12785,0);
INSERT INTO "django_geo_db_location" VALUES(22384,NULL,'Van Wyck, SC',9306,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22385,NULL,'Van Wyck, SC 29744',9306,222,NULL,48,12786,0);
INSERT INTO "django_geo_db_location" VALUES(22386,NULL,'York, SC',9307,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22387,NULL,'York, SC 29745',9307,222,NULL,48,12787,0);
INSERT INTO "django_geo_db_location" VALUES(22388,NULL,'Garden City, SC',9308,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22389,NULL,'Garden City, SC 29756',9308,222,NULL,48,12788,0);
INSERT INTO "django_geo_db_location" VALUES(22390,NULL,'Aiken, SC',9309,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22391,NULL,'Aiken, SC 29801',9309,222,NULL,48,12789,0);
INSERT INTO "django_geo_db_location" VALUES(22392,NULL,'Aiken, SC 29802',9309,222,NULL,48,12790,0);
INSERT INTO "django_geo_db_location" VALUES(22393,NULL,'Aiken, SC 29803',9309,222,NULL,48,12791,0);
INSERT INTO "django_geo_db_location" VALUES(22394,NULL,'Aiken, SC 29804',9309,222,NULL,48,12792,0);
INSERT INTO "django_geo_db_location" VALUES(22395,NULL,'Aiken, SC 29805',9309,222,NULL,48,12793,0);
INSERT INTO "django_geo_db_location" VALUES(22396,NULL,'Aiken, SC 29808',9309,222,NULL,48,12794,0);
INSERT INTO "django_geo_db_location" VALUES(22397,NULL,'New Ellenton, SC',9310,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22398,NULL,'New Ellenton, SC 29809',9310,222,NULL,48,12795,0);
INSERT INTO "django_geo_db_location" VALUES(22399,NULL,'Allendale, SC',9311,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22400,NULL,'Allendale, SC 29810',9311,222,NULL,48,12796,0);
INSERT INTO "django_geo_db_location" VALUES(22401,NULL,'Barnwell, SC',9312,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22402,NULL,'Barnwell, SC 29812',9312,222,NULL,48,12797,0);
INSERT INTO "django_geo_db_location" VALUES(22403,NULL,'Hilda, SC',9313,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22404,NULL,'Hilda, SC 29813',9313,222,NULL,48,12798,0);
INSERT INTO "django_geo_db_location" VALUES(22405,NULL,'Bath, SC',9314,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22406,NULL,'Bath, SC 29816',9314,222,NULL,48,12799,0);
INSERT INTO "django_geo_db_location" VALUES(22407,NULL,'Blackville, SC',9315,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22408,NULL,'Blackville, SC 29817',9315,222,NULL,48,12800,0);
INSERT INTO "django_geo_db_location" VALUES(22409,NULL,'Bradley, SC',9316,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22410,NULL,'Bradley, SC 29819',9316,222,NULL,48,12801,0);
INSERT INTO "django_geo_db_location" VALUES(22411,NULL,'Clarks Hill, SC',9317,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22412,NULL,'Clarks Hill, SC 29821',9317,222,NULL,48,12802,0);
INSERT INTO "django_geo_db_location" VALUES(22413,NULL,'Clearwater, SC',9318,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22414,NULL,'Clearwater, SC 29822',9318,222,NULL,48,12803,0);
INSERT INTO "django_geo_db_location" VALUES(22415,NULL,'Edgefield, SC',9319,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22416,NULL,'Edgefield, SC 29824',9319,222,NULL,48,12804,0);
INSERT INTO "django_geo_db_location" VALUES(22417,NULL,'Elko, SC',9320,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22418,NULL,'Elko, SC 29826',9320,222,NULL,48,12805,0);
INSERT INTO "django_geo_db_location" VALUES(22419,NULL,'Fairfax, SC',9321,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22420,NULL,'Fairfax, SC 29827',9321,222,NULL,48,12806,0);
INSERT INTO "django_geo_db_location" VALUES(22421,NULL,'Gloverville, SC',9322,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22422,NULL,'Gloverville, SC 29828',9322,222,NULL,48,12807,0);
INSERT INTO "django_geo_db_location" VALUES(22423,NULL,'Graniteville, SC',9323,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22424,NULL,'Graniteville, SC 29829',9323,222,NULL,48,12808,0);
INSERT INTO "django_geo_db_location" VALUES(22425,NULL,'Jackson, SC',9324,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22426,NULL,'Jackson, SC 29831',9324,222,NULL,48,12809,0);
INSERT INTO "django_geo_db_location" VALUES(22427,NULL,'Johnston, SC',9325,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22428,NULL,'Johnston, SC 29832',9325,222,NULL,48,12810,0);
INSERT INTO "django_geo_db_location" VALUES(22429,NULL,'Langley, SC',9326,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22430,NULL,'Langley, SC 29834',9326,222,NULL,48,12811,0);
INSERT INTO "django_geo_db_location" VALUES(22431,NULL,'McCormick, SC 29835',9192,222,NULL,48,12812,0);
INSERT INTO "django_geo_db_location" VALUES(22432,NULL,'Martin, SC',9327,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22433,NULL,'Martin, SC 29836',9327,222,NULL,48,12813,0);
INSERT INTO "django_geo_db_location" VALUES(22434,NULL,'Modoc, SC',9328,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22435,NULL,'Modoc, SC 29838',9328,222,NULL,48,12814,0);
INSERT INTO "django_geo_db_location" VALUES(22436,NULL,'Montmorenci, SC',9329,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22437,NULL,'Montmorenci, SC 29839',9329,222,NULL,48,12815,0);
INSERT INTO "django_geo_db_location" VALUES(22438,NULL,'Mount Carmel, SC',9330,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22439,NULL,'Mount Carmel, SC 29840',9330,222,NULL,48,12816,0);
INSERT INTO "django_geo_db_location" VALUES(22440,NULL,'North Augusta, SC',9331,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22441,NULL,'North Augusta, SC 29841',9331,222,NULL,48,12817,0);
INSERT INTO "django_geo_db_location" VALUES(22442,NULL,'Beech Island, SC',9332,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22443,NULL,'Beech Island, SC 29842',9332,222,NULL,48,12818,0);
INSERT INTO "django_geo_db_location" VALUES(22444,NULL,'Olar, SC',9333,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22445,NULL,'Olar, SC 29843',9333,222,NULL,48,12819,0);
INSERT INTO "django_geo_db_location" VALUES(22446,NULL,'Parksville, SC',9334,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22447,NULL,'Parksville, SC 29844',9334,222,NULL,48,12820,0);
INSERT INTO "django_geo_db_location" VALUES(22448,NULL,'Plum Branch, SC',9335,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22449,NULL,'Plum Branch, SC 29845',9335,222,NULL,48,12821,0);
INSERT INTO "django_geo_db_location" VALUES(22450,NULL,'Sycamore, SC',9336,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22451,NULL,'Sycamore, SC 29846',9336,222,NULL,48,12822,0);
INSERT INTO "django_geo_db_location" VALUES(22452,NULL,'Trenton, SC',9337,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22453,NULL,'Trenton, SC 29847',9337,222,NULL,48,12823,0);
INSERT INTO "django_geo_db_location" VALUES(22454,NULL,'Troy, SC',9338,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22455,NULL,'Troy, SC 29848',9338,222,NULL,48,12824,0);
INSERT INTO "django_geo_db_location" VALUES(22456,NULL,'Ulmer, SC',9339,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22457,NULL,'Ulmer, SC 29849',9339,222,NULL,48,12825,0);
INSERT INTO "django_geo_db_location" VALUES(22458,NULL,'Vaucluse, SC',9340,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22459,NULL,'Vaucluse, SC 29850',9340,222,NULL,48,12826,0);
INSERT INTO "django_geo_db_location" VALUES(22460,NULL,'Warrenville, SC',9341,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22461,NULL,'Warrenville, SC 29851',9341,222,NULL,48,12827,0);
INSERT INTO "django_geo_db_location" VALUES(22462,NULL,'Williston, SC',9342,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22463,NULL,'Williston, SC 29853',9342,222,NULL,48,12828,0);
INSERT INTO "django_geo_db_location" VALUES(22464,NULL,'Windsor, SC',9343,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22465,NULL,'Windsor, SC 29856',9343,222,NULL,48,12829,0);
INSERT INTO "django_geo_db_location" VALUES(22466,NULL,'North Augusta, SC 29860',9331,222,NULL,48,12830,0);
INSERT INTO "django_geo_db_location" VALUES(22467,NULL,'North Augusta, SC 29861',9331,222,NULL,48,12831,0);
INSERT INTO "django_geo_db_location" VALUES(22468,NULL,'Murrells Inlet, SC 29875',9217,222,NULL,48,12832,0);
INSERT INTO "django_geo_db_location" VALUES(22469,NULL,'McCormick, SC 29899',9192,222,NULL,48,12833,0);
INSERT INTO "django_geo_db_location" VALUES(22470,NULL,'Beaufort, SC',9344,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22471,NULL,'Beaufort, SC 29901',9344,222,NULL,48,12834,0);
INSERT INTO "django_geo_db_location" VALUES(22472,NULL,'Beaufort, SC 29902',9344,222,NULL,48,12835,0);
INSERT INTO "django_geo_db_location" VALUES(22473,NULL,'Beaufort, SC 29903',9344,222,NULL,48,12836,0);
INSERT INTO "django_geo_db_location" VALUES(22474,NULL,'Beaufort, SC 29904',9344,222,NULL,48,12837,0);
INSERT INTO "django_geo_db_location" VALUES(22475,NULL,'Beaufort, SC 29905',9344,222,NULL,48,12838,0);
INSERT INTO "django_geo_db_location" VALUES(22476,NULL,'Beaufort, SC 29906',9344,222,NULL,48,12839,0);
INSERT INTO "django_geo_db_location" VALUES(22477,NULL,'Beaufort, SC 29907',9344,222,NULL,48,12840,0);
INSERT INTO "django_geo_db_location" VALUES(22478,NULL,'Hilton Head Island, SC',9345,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22479,NULL,'Hilton Head Island, SC 29909',9345,222,NULL,48,12841,0);
INSERT INTO "django_geo_db_location" VALUES(22480,NULL,'Bluffton, SC',9346,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22481,NULL,'Bluffton, SC 29910',9346,222,NULL,48,12842,0);
INSERT INTO "django_geo_db_location" VALUES(22482,NULL,'Brunson, SC',9347,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22483,NULL,'Brunson, SC 29911',9347,222,NULL,48,12843,0);
INSERT INTO "django_geo_db_location" VALUES(22484,NULL,'Coosawatchie, SC',9348,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22485,NULL,'Coosawatchie, SC 29912',9348,222,NULL,48,12844,0);
INSERT INTO "django_geo_db_location" VALUES(22486,NULL,'Crocketville, SC',9349,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22487,NULL,'Crocketville, SC 29913',9349,222,NULL,48,12845,0);
INSERT INTO "django_geo_db_location" VALUES(22488,NULL,'Dale, SC',9350,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22489,NULL,'Dale, SC 29914',9350,222,NULL,48,12846,0);
INSERT INTO "django_geo_db_location" VALUES(22490,NULL,'Daufuskie Island, SC',9351,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22491,NULL,'Daufuskie Island, SC 29915',9351,222,NULL,48,12847,0);
INSERT INTO "django_geo_db_location" VALUES(22492,NULL,'Early Branch, SC',9352,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22493,NULL,'Early Branch, SC 29916',9352,222,NULL,48,12848,0);
INSERT INTO "django_geo_db_location" VALUES(22494,NULL,'Estill, SC',9353,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22495,NULL,'Estill, SC 29918',9353,222,NULL,48,12849,0);
INSERT INTO "django_geo_db_location" VALUES(22496,NULL,'Saint Helena Island, SC',9354,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22497,NULL,'Saint Helena Island, SC 29920',9354,222,NULL,48,12850,0);
INSERT INTO "django_geo_db_location" VALUES(22498,NULL,'Furman, SC',9355,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22499,NULL,'Furman, SC 29921',9355,222,NULL,48,12851,0);
INSERT INTO "django_geo_db_location" VALUES(22500,NULL,'Garnett, SC',9356,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22501,NULL,'Garnett, SC 29922',9356,222,NULL,48,12852,0);
INSERT INTO "django_geo_db_location" VALUES(22502,NULL,'Gifford, SC',9357,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22503,NULL,'Gifford, SC 29923',9357,222,NULL,48,12853,0);
INSERT INTO "django_geo_db_location" VALUES(22504,NULL,'Hampton, SC',9358,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22505,NULL,'Hampton, SC 29924',9358,222,NULL,48,12854,0);
INSERT INTO "django_geo_db_location" VALUES(22506,NULL,'Hilton Head Island, SC 29925',9345,222,NULL,48,12855,0);
INSERT INTO "django_geo_db_location" VALUES(22507,NULL,'Hilton Head Island, SC 29926',9345,222,NULL,48,12856,0);
INSERT INTO "django_geo_db_location" VALUES(22508,NULL,'Hardeeville, SC',9359,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22509,NULL,'Hardeeville, SC 29927',9359,222,NULL,48,12857,0);
INSERT INTO "django_geo_db_location" VALUES(22510,NULL,'Hilton Head Island, SC 29928',9345,222,NULL,48,12858,0);
INSERT INTO "django_geo_db_location" VALUES(22511,NULL,'Islandton, SC',9360,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22512,NULL,'Islandton, SC 29929',9360,222,NULL,48,12859,0);
INSERT INTO "django_geo_db_location" VALUES(22513,NULL,'Lobeco, SC',9361,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22514,NULL,'Lobeco, SC 29931',9361,222,NULL,48,12860,0);
INSERT INTO "django_geo_db_location" VALUES(22515,NULL,'Luray, SC',9362,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22516,NULL,'Luray, SC 29932',9362,222,NULL,48,12861,0);
INSERT INTO "django_geo_db_location" VALUES(22517,NULL,'Miley, SC',9363,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22518,NULL,'Miley, SC 29933',9363,222,NULL,48,12862,0);
INSERT INTO "django_geo_db_location" VALUES(22519,NULL,'Pineland, SC',9364,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22520,NULL,'Pineland, SC 29934',9364,222,NULL,48,12863,0);
INSERT INTO "django_geo_db_location" VALUES(22521,NULL,'Port Royal, SC',9365,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22522,NULL,'Port Royal, SC 29935',9365,222,NULL,48,12864,0);
INSERT INTO "django_geo_db_location" VALUES(22523,NULL,'Ridgeland, SC',9366,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22524,NULL,'Ridgeland, SC 29936',9366,222,NULL,48,12865,0);
INSERT INTO "django_geo_db_location" VALUES(22525,NULL,'Hilton Head Island, SC 29938',9345,222,NULL,48,12866,0);
INSERT INTO "django_geo_db_location" VALUES(22526,NULL,'Scotia, SC',9367,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22527,NULL,'Scotia, SC 29939',9367,222,NULL,48,12867,0);
INSERT INTO "django_geo_db_location" VALUES(22528,NULL,'Seabrook, SC',9368,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22529,NULL,'Seabrook, SC 29940',9368,222,NULL,48,12868,0);
INSERT INTO "django_geo_db_location" VALUES(22530,NULL,'Sheldon, SC',9369,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22531,NULL,'Sheldon, SC 29941',9369,222,NULL,48,12869,0);
INSERT INTO "django_geo_db_location" VALUES(22532,NULL,'Hampton, SC 29942',9358,222,NULL,48,12870,0);
INSERT INTO "django_geo_db_location" VALUES(22533,NULL,'Tillman, SC',9370,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22534,NULL,'Tillman, SC 29943',9370,222,NULL,48,12871,0);
INSERT INTO "django_geo_db_location" VALUES(22535,NULL,'Varnville, SC',9371,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22536,NULL,'Varnville, SC 29944',9371,222,NULL,48,12872,0);
INSERT INTO "django_geo_db_location" VALUES(22537,NULL,'Yemassee, SC',9372,222,NULL,48,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22538,NULL,'Yemassee, SC 29945',9372,222,NULL,48,12873,0);
INSERT INTO "django_geo_db_location" VALUES(22539,NULL,'Hilton Head Island, SC 29982',9345,222,NULL,48,12874,0);
INSERT INTO "django_geo_db_location" VALUES(22540,NULL,'Avondale Estates, GA',9373,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22541,NULL,'Avondale Estates, GA 30002',9373,222,NULL,13,12875,0);
INSERT INTO "django_geo_db_location" VALUES(22542,NULL,'Norcross, GA',9374,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22543,NULL,'Norcross, GA 30003',9374,222,NULL,13,12876,0);
INSERT INTO "django_geo_db_location" VALUES(22544,NULL,'Alpharetta, GA',9375,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22545,NULL,'Alpharetta, GA 30004',9375,222,NULL,13,12877,0);
INSERT INTO "django_geo_db_location" VALUES(22546,NULL,'Alpharetta, GA 30005',9375,222,NULL,13,12878,0);
INSERT INTO "django_geo_db_location" VALUES(22547,NULL,'Marietta, GA',9376,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22548,NULL,'Marietta, GA 30006',9376,222,NULL,13,12879,0);
INSERT INTO "django_geo_db_location" VALUES(22549,NULL,'Marietta, GA 30007',9376,222,NULL,13,12880,0);
INSERT INTO "django_geo_db_location" VALUES(22550,NULL,'Marietta, GA 30008',9376,222,NULL,13,12881,0);
INSERT INTO "django_geo_db_location" VALUES(22551,NULL,'Alpharetta, GA 30009',9375,222,NULL,13,12882,0);
INSERT INTO "django_geo_db_location" VALUES(22552,NULL,'Norcross, GA 30010',9374,222,NULL,13,12883,0);
INSERT INTO "django_geo_db_location" VALUES(22553,NULL,'Auburn, GA',9377,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22554,NULL,'Auburn, GA 30011',9377,222,NULL,13,12884,0);
INSERT INTO "django_geo_db_location" VALUES(22555,NULL,'Conyers, GA',9378,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22556,NULL,'Conyers, GA 30012',9378,222,NULL,13,12885,0);
INSERT INTO "django_geo_db_location" VALUES(22557,NULL,'Conyers, GA 30013',9378,222,NULL,13,12886,0);
INSERT INTO "django_geo_db_location" VALUES(22558,NULL,'Covington, GA',9379,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22559,NULL,'Covington, GA 30014',9379,222,NULL,13,12887,0);
INSERT INTO "django_geo_db_location" VALUES(22560,NULL,'Covington, GA 30015',9379,222,NULL,13,12888,0);
INSERT INTO "django_geo_db_location" VALUES(22561,NULL,'Covington, GA 30016',9379,222,NULL,13,12889,0);
INSERT INTO "django_geo_db_location" VALUES(22562,NULL,'Grayson, GA',9380,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22563,NULL,'Grayson, GA 30017',9380,222,NULL,13,12890,0);
INSERT INTO "django_geo_db_location" VALUES(22564,NULL,'Jersey, GA',9381,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22565,NULL,'Jersey, GA 30018',9381,222,NULL,13,12891,0);
INSERT INTO "django_geo_db_location" VALUES(22566,NULL,'Dacula, GA',9382,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22567,NULL,'Dacula, GA 30019',9382,222,NULL,13,12892,0);
INSERT INTO "django_geo_db_location" VALUES(22568,NULL,'Clarkston, GA',9383,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22569,NULL,'Clarkston, GA 30021',9383,222,NULL,13,12893,0);
INSERT INTO "django_geo_db_location" VALUES(22570,NULL,'Alpharetta, GA 30022',9375,222,NULL,13,12894,0);
INSERT INTO "django_geo_db_location" VALUES(22571,NULL,'Alpharetta, GA 30023',9375,222,NULL,13,12895,0);
INSERT INTO "django_geo_db_location" VALUES(22572,NULL,'Suwanee, GA',9384,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22573,NULL,'Suwanee, GA 30024',9384,222,NULL,13,12896,0);
INSERT INTO "django_geo_db_location" VALUES(22574,NULL,'Social Circle, GA',9385,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22575,NULL,'Social Circle, GA 30025',9385,222,NULL,13,12897,0);
INSERT INTO "django_geo_db_location" VALUES(22576,NULL,'Duluth, GA',9386,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22577,NULL,'Duluth, GA 30026',9386,222,NULL,13,12898,0);
INSERT INTO "django_geo_db_location" VALUES(22578,NULL,'Cumming, GA',9387,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22579,NULL,'Cumming, GA 30028',9387,222,NULL,13,12899,0);
INSERT INTO "django_geo_db_location" VALUES(22580,NULL,'Duluth, GA 30029',9386,222,NULL,13,12900,0);
INSERT INTO "django_geo_db_location" VALUES(22581,NULL,'Decatur, GA',9388,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22582,NULL,'Decatur, GA 30030',9388,222,NULL,13,12901,0);
INSERT INTO "django_geo_db_location" VALUES(22583,NULL,'Decatur, GA 30031',9388,222,NULL,13,12902,0);
INSERT INTO "django_geo_db_location" VALUES(22584,NULL,'Decatur, GA 30032',9388,222,NULL,13,12903,0);
INSERT INTO "django_geo_db_location" VALUES(22585,NULL,'Decatur, GA 30033',9388,222,NULL,13,12904,0);
INSERT INTO "django_geo_db_location" VALUES(22586,NULL,'Decatur, GA 30034',9388,222,NULL,13,12905,0);
INSERT INTO "django_geo_db_location" VALUES(22587,NULL,'Decatur, GA 30035',9388,222,NULL,13,12906,0);
INSERT INTO "django_geo_db_location" VALUES(22588,NULL,'Decatur, GA 30036',9388,222,NULL,13,12907,0);
INSERT INTO "django_geo_db_location" VALUES(22589,NULL,'Decatur, GA 30037',9388,222,NULL,13,12908,0);
INSERT INTO "django_geo_db_location" VALUES(22590,NULL,'Lithonia, GA',9389,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22591,NULL,'Lithonia, GA 30038',9389,222,NULL,13,12909,0);
INSERT INTO "django_geo_db_location" VALUES(22592,NULL,'Snellville, GA',9390,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22593,NULL,'Snellville, GA 30039',9390,222,NULL,13,12910,0);
INSERT INTO "django_geo_db_location" VALUES(22594,NULL,'Cumming, GA 30040',9387,222,NULL,13,12911,0);
INSERT INTO "django_geo_db_location" VALUES(22595,NULL,'Cumming, GA 30041',9387,222,NULL,13,12912,0);
INSERT INTO "django_geo_db_location" VALUES(22596,NULL,'Lawrenceville, GA',9391,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22597,NULL,'Lawrenceville, GA 30042',9391,222,NULL,13,12913,0);
INSERT INTO "django_geo_db_location" VALUES(22598,NULL,'Lawrenceville, GA 30043',9391,222,NULL,13,12914,0);
INSERT INTO "django_geo_db_location" VALUES(22599,NULL,'Lawrenceville, GA 30044',9391,222,NULL,13,12915,0);
INSERT INTO "django_geo_db_location" VALUES(22600,NULL,'Lawrenceville, GA 30045',9391,222,NULL,13,12916,0);
INSERT INTO "django_geo_db_location" VALUES(22601,NULL,'Lawrenceville, GA 30046',9391,222,NULL,13,12917,0);
INSERT INTO "django_geo_db_location" VALUES(22602,NULL,'Lilburn, GA',9392,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22603,NULL,'Lilburn, GA 30047',9392,222,NULL,13,12918,0);
INSERT INTO "django_geo_db_location" VALUES(22604,NULL,'Lilburn, GA 30048',9392,222,NULL,13,12919,0);
INSERT INTO "django_geo_db_location" VALUES(22605,NULL,'Loganville, GA',9393,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22606,NULL,'Loganville, GA 30052',9393,222,NULL,13,12920,0);
INSERT INTO "django_geo_db_location" VALUES(22607,NULL,'Oxford, GA',9394,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22608,NULL,'Oxford, GA 30054',9394,222,NULL,13,12921,0);
INSERT INTO "django_geo_db_location" VALUES(22609,NULL,'Mansfield, GA',9395,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22610,NULL,'Mansfield, GA 30055',9395,222,NULL,13,12922,0);
INSERT INTO "django_geo_db_location" VALUES(22611,NULL,'Newborn, GA',9396,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22612,NULL,'Newborn, GA 30056',9396,222,NULL,13,12923,0);
INSERT INTO "django_geo_db_location" VALUES(22613,NULL,'Lithonia, GA 30058',9389,222,NULL,13,12924,0);
INSERT INTO "django_geo_db_location" VALUES(22614,NULL,'Marietta, GA 30060',9376,222,NULL,13,12925,0);
INSERT INTO "django_geo_db_location" VALUES(22615,NULL,'Marietta, GA 30061',9376,222,NULL,13,12926,0);
INSERT INTO "django_geo_db_location" VALUES(22616,NULL,'Marietta, GA 30062',9376,222,NULL,13,12927,0);
INSERT INTO "django_geo_db_location" VALUES(22617,NULL,'Marietta, GA 30063',9376,222,NULL,13,12928,0);
INSERT INTO "django_geo_db_location" VALUES(22618,NULL,'Marietta, GA 30064',9376,222,NULL,13,12929,0);
INSERT INTO "django_geo_db_location" VALUES(22619,NULL,'Marietta, GA 30065',9376,222,NULL,13,12930,0);
INSERT INTO "django_geo_db_location" VALUES(22620,NULL,'Marietta, GA 30066',9376,222,NULL,13,12931,0);
INSERT INTO "django_geo_db_location" VALUES(22621,NULL,'Marietta, GA 30067',9376,222,NULL,13,12932,0);
INSERT INTO "django_geo_db_location" VALUES(22622,NULL,'Marietta, GA 30068',9376,222,NULL,13,12933,0);
INSERT INTO "django_geo_db_location" VALUES(22623,NULL,'Marietta, GA 30069',9376,222,NULL,13,12934,0);
INSERT INTO "django_geo_db_location" VALUES(22624,NULL,'Porterdale, GA',9397,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22625,NULL,'Porterdale, GA 30070',9397,222,NULL,13,12935,0);
INSERT INTO "django_geo_db_location" VALUES(22626,NULL,'Norcross, GA 30071',9374,222,NULL,13,12936,0);
INSERT INTO "django_geo_db_location" VALUES(22627,NULL,'Pine Lake, GA',9398,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22628,NULL,'Pine Lake, GA 30072',9398,222,NULL,13,12937,0);
INSERT INTO "django_geo_db_location" VALUES(22629,NULL,'Redan, GA',9399,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22630,NULL,'Redan, GA 30074',9399,222,NULL,13,12938,0);
INSERT INTO "django_geo_db_location" VALUES(22631,NULL,'Roswell, GA',9400,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22632,NULL,'Roswell, GA 30075',9400,222,NULL,13,12939,0);
INSERT INTO "django_geo_db_location" VALUES(22633,NULL,'Roswell, GA 30076',9400,222,NULL,13,12940,0);
INSERT INTO "django_geo_db_location" VALUES(22634,NULL,'Roswell, GA 30077',9400,222,NULL,13,12941,0);
INSERT INTO "django_geo_db_location" VALUES(22635,NULL,'Snellville, GA 30078',9390,222,NULL,13,12942,0);
INSERT INTO "django_geo_db_location" VALUES(22636,NULL,'Scottdale, GA',9401,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22637,NULL,'Scottdale, GA 30079',9401,222,NULL,13,12943,0);
INSERT INTO "django_geo_db_location" VALUES(22638,NULL,'Smyrna, GA',9402,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22639,NULL,'Smyrna, GA 30080',9402,222,NULL,13,12944,0);
INSERT INTO "django_geo_db_location" VALUES(22640,NULL,'Smyrna, GA 30081',9402,222,NULL,13,12945,0);
INSERT INTO "django_geo_db_location" VALUES(22641,NULL,'Smyrna, GA 30082',9402,222,NULL,13,12946,0);
INSERT INTO "django_geo_db_location" VALUES(22642,NULL,'Stone Mountain, GA',9403,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22643,NULL,'Stone Mountain, GA 30083',9403,222,NULL,13,12947,0);
INSERT INTO "django_geo_db_location" VALUES(22644,NULL,'Tucker, GA',9404,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22645,NULL,'Tucker, GA 30084',9404,222,NULL,13,12948,0);
INSERT INTO "django_geo_db_location" VALUES(22646,NULL,'Tucker, GA 30085',9404,222,NULL,13,12949,0);
INSERT INTO "django_geo_db_location" VALUES(22647,NULL,'Stone Mountain, GA 30086',9403,222,NULL,13,12950,0);
INSERT INTO "django_geo_db_location" VALUES(22648,NULL,'Stone Mountain, GA 30087',9403,222,NULL,13,12951,0);
INSERT INTO "django_geo_db_location" VALUES(22649,NULL,'Stone Mountain, GA 30088',9403,222,NULL,13,12952,0);
INSERT INTO "django_geo_db_location" VALUES(22650,NULL,'Marietta, GA 30090',9376,222,NULL,13,12953,0);
INSERT INTO "django_geo_db_location" VALUES(22651,NULL,'Norcross, GA 30091',9374,222,NULL,13,12954,0);
INSERT INTO "django_geo_db_location" VALUES(22652,NULL,'Norcross, GA 30092',9374,222,NULL,13,12955,0);
INSERT INTO "django_geo_db_location" VALUES(22653,NULL,'Norcross, GA 30093',9374,222,NULL,13,12956,0);
INSERT INTO "django_geo_db_location" VALUES(22654,NULL,'Conyers, GA 30094',9378,222,NULL,13,12957,0);
INSERT INTO "django_geo_db_location" VALUES(22655,NULL,'Duluth, GA 30095',9386,222,NULL,13,12958,0);
INSERT INTO "django_geo_db_location" VALUES(22656,NULL,'Duluth, GA 30096',9386,222,NULL,13,12959,0);
INSERT INTO "django_geo_db_location" VALUES(22657,NULL,'Duluth, GA 30097',9386,222,NULL,13,12960,0);
INSERT INTO "django_geo_db_location" VALUES(22658,NULL,'Duluth, GA 30098',9386,222,NULL,13,12961,0);
INSERT INTO "django_geo_db_location" VALUES(22659,NULL,'Duluth, GA 30099',9386,222,NULL,13,12962,0);
INSERT INTO "django_geo_db_location" VALUES(22660,NULL,'Acworth, GA',9405,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22661,NULL,'Acworth, GA 30101',9405,222,NULL,13,12963,0);
INSERT INTO "django_geo_db_location" VALUES(22662,NULL,'Acworth, GA 30102',9405,222,NULL,13,12964,0);
INSERT INTO "django_geo_db_location" VALUES(22663,NULL,'Adairsville, GA',9406,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22664,NULL,'Adairsville, GA 30103',9406,222,NULL,13,12965,0);
INSERT INTO "django_geo_db_location" VALUES(22665,NULL,'Aragon, GA',9407,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22666,NULL,'Aragon, GA 30104',9407,222,NULL,13,12966,0);
INSERT INTO "django_geo_db_location" VALUES(22667,NULL,'Armuchee, GA',9408,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22668,NULL,'Armuchee, GA 30105',9408,222,NULL,13,12967,0);
INSERT INTO "django_geo_db_location" VALUES(22669,NULL,'Austell, GA',9409,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22670,NULL,'Austell, GA 30106',9409,222,NULL,13,12968,0);
INSERT INTO "django_geo_db_location" VALUES(22671,NULL,'Ball Ground, GA',9410,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22672,NULL,'Ball Ground, GA 30107',9410,222,NULL,13,12969,0);
INSERT INTO "django_geo_db_location" VALUES(22673,NULL,'Bowdon, GA',9411,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22674,NULL,'Bowdon, GA 30108',9411,222,NULL,13,12970,0);
INSERT INTO "django_geo_db_location" VALUES(22675,NULL,'Bowdon Junction, GA',9412,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22676,NULL,'Bowdon Junction, GA 30109',9412,222,NULL,13,12971,0);
INSERT INTO "django_geo_db_location" VALUES(22677,NULL,'Bremen, GA',9413,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22678,NULL,'Bremen, GA 30110',9413,222,NULL,13,12972,0);
INSERT INTO "django_geo_db_location" VALUES(22679,NULL,'Clarkdale, GA',9414,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22680,NULL,'Clarkdale, GA 30111',9414,222,NULL,13,12973,0);
INSERT INTO "django_geo_db_location" VALUES(22681,NULL,'Buchanan, GA',9415,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22682,NULL,'Buchanan, GA 30113',9415,222,NULL,13,12974,0);
INSERT INTO "django_geo_db_location" VALUES(22683,NULL,'Canton, GA',9416,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22684,NULL,'Canton, GA 30114',9416,222,NULL,13,12975,0);
INSERT INTO "django_geo_db_location" VALUES(22685,NULL,'Canton, GA 30115',9416,222,NULL,13,12976,0);
INSERT INTO "django_geo_db_location" VALUES(22686,NULL,'Carrollton, GA',9417,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22687,NULL,'Carrollton, GA 30116',9417,222,NULL,13,12977,0);
INSERT INTO "django_geo_db_location" VALUES(22688,NULL,'Carrollton, GA 30117',9417,222,NULL,13,12978,0);
INSERT INTO "django_geo_db_location" VALUES(22689,NULL,'Carrollton, GA 30118',9417,222,NULL,13,12979,0);
INSERT INTO "django_geo_db_location" VALUES(22690,NULL,'Carrollton, GA 30119',9417,222,NULL,13,12980,0);
INSERT INTO "django_geo_db_location" VALUES(22691,NULL,'Cartersville, GA',9418,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22692,NULL,'Cartersville, GA 30120',9418,222,NULL,13,12981,0);
INSERT INTO "django_geo_db_location" VALUES(22693,NULL,'Cartersville, GA 30121',9418,222,NULL,13,12982,0);
INSERT INTO "django_geo_db_location" VALUES(22694,NULL,'Lithia Springs, GA',9419,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22695,NULL,'Lithia Springs, GA 30122',9419,222,NULL,13,12983,0);
INSERT INTO "django_geo_db_location" VALUES(22696,NULL,'Cassville, GA',9420,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22697,NULL,'Cassville, GA 30123',9420,222,NULL,13,12984,0);
INSERT INTO "django_geo_db_location" VALUES(22698,NULL,'Cave Spring, GA',9421,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22699,NULL,'Cave Spring, GA 30124',9421,222,NULL,13,12985,0);
INSERT INTO "django_geo_db_location" VALUES(22700,NULL,'Cedartown, GA',9422,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22701,NULL,'Cedartown, GA 30125',9422,222,NULL,13,12986,0);
INSERT INTO "django_geo_db_location" VALUES(22702,NULL,'Mableton, GA',9423,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22703,NULL,'Mableton, GA 30126',9423,222,NULL,13,12987,0);
INSERT INTO "django_geo_db_location" VALUES(22704,NULL,'Powder Springs, GA',9424,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22705,NULL,'Powder Springs, GA 30127',9424,222,NULL,13,12988,0);
INSERT INTO "django_geo_db_location" VALUES(22706,NULL,'Coosa, GA',9425,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22707,NULL,'Coosa, GA 30129',9425,222,NULL,13,12989,0);
INSERT INTO "django_geo_db_location" VALUES(22708,NULL,'Dallas, GA',9426,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22709,NULL,'Dallas, GA 30132',9426,222,NULL,13,12990,0);
INSERT INTO "django_geo_db_location" VALUES(22710,NULL,'Douglasville, GA',9427,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22711,NULL,'Douglasville, GA 30133',9427,222,NULL,13,12991,0);
INSERT INTO "django_geo_db_location" VALUES(22712,NULL,'Douglasville, GA 30134',9427,222,NULL,13,12992,0);
INSERT INTO "django_geo_db_location" VALUES(22713,NULL,'Douglasville, GA 30135',9427,222,NULL,13,12993,0);
INSERT INTO "django_geo_db_location" VALUES(22714,NULL,'Emerson, GA',9428,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22715,NULL,'Emerson, GA 30137',9428,222,NULL,13,12994,0);
INSERT INTO "django_geo_db_location" VALUES(22716,NULL,'Esom Hill, GA',9429,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22717,NULL,'Esom Hill, GA 30138',9429,222,NULL,13,12995,0);
INSERT INTO "django_geo_db_location" VALUES(22718,NULL,'Fairmount, GA',9430,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22719,NULL,'Fairmount, GA 30139',9430,222,NULL,13,12996,0);
INSERT INTO "django_geo_db_location" VALUES(22720,NULL,'Felton, GA',9431,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22721,NULL,'Felton, GA 30140',9431,222,NULL,13,12997,0);
INSERT INTO "django_geo_db_location" VALUES(22722,NULL,'Hiram, GA',9432,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22723,NULL,'Hiram, GA 30141',9432,222,NULL,13,12998,0);
INSERT INTO "django_geo_db_location" VALUES(22724,NULL,'Holly Springs, GA',9433,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22725,NULL,'Holly Springs, GA 30142',9433,222,NULL,13,12999,0);
INSERT INTO "django_geo_db_location" VALUES(22726,NULL,'Jasper, GA',9434,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22727,NULL,'Jasper, GA 30143',9434,222,NULL,13,13000,0);
INSERT INTO "django_geo_db_location" VALUES(22728,NULL,'Kennesaw, GA',9435,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22729,NULL,'Kennesaw, GA 30144',9435,222,NULL,13,13001,0);
INSERT INTO "django_geo_db_location" VALUES(22730,NULL,'Kingston, GA',9436,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22731,NULL,'Kingston, GA 30145',9436,222,NULL,13,13002,0);
INSERT INTO "django_geo_db_location" VALUES(22732,NULL,'Lebanon, GA',9437,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22733,NULL,'Lebanon, GA 30146',9437,222,NULL,13,13003,0);
INSERT INTO "django_geo_db_location" VALUES(22734,NULL,'Lindale, GA',9438,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22735,NULL,'Lindale, GA 30147',9438,222,NULL,13,13004,0);
INSERT INTO "django_geo_db_location" VALUES(22736,NULL,'Marble Hill, GA',9439,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22737,NULL,'Marble Hill, GA 30148',9439,222,NULL,13,13005,0);
INSERT INTO "django_geo_db_location" VALUES(22738,NULL,'Mount Berry, GA',9440,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22739,NULL,'Mount Berry, GA 30149',9440,222,NULL,13,13006,0);
INSERT INTO "django_geo_db_location" VALUES(22740,NULL,'Mount Zion, GA',9441,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22741,NULL,'Mount Zion, GA 30150',9441,222,NULL,13,13007,0);
INSERT INTO "django_geo_db_location" VALUES(22742,NULL,'Nelson, GA',9442,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22743,NULL,'Nelson, GA 30151',9442,222,NULL,13,13008,0);
INSERT INTO "django_geo_db_location" VALUES(22744,NULL,'Kennesaw, GA 30152',9435,222,NULL,13,13009,0);
INSERT INTO "django_geo_db_location" VALUES(22745,NULL,'Rockmart, GA',9443,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22746,NULL,'Rockmart, GA 30153',9443,222,NULL,13,13010,0);
INSERT INTO "django_geo_db_location" VALUES(22747,NULL,'Douglasville, GA 30154',9427,222,NULL,13,13011,0);
INSERT INTO "django_geo_db_location" VALUES(22748,NULL,'Dallas, GA 30157',9426,222,NULL,13,13012,0);
INSERT INTO "django_geo_db_location" VALUES(22749,NULL,'Rome, GA',9444,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22750,NULL,'Rome, GA 30161',9444,222,NULL,13,13013,0);
INSERT INTO "django_geo_db_location" VALUES(22751,NULL,'Rome, GA 30162',9444,222,NULL,13,13014,0);
INSERT INTO "django_geo_db_location" VALUES(22752,NULL,'Rome, GA 30163',9444,222,NULL,13,13015,0);
INSERT INTO "django_geo_db_location" VALUES(22753,NULL,'Rome, GA 30164',9444,222,NULL,13,13016,0);
INSERT INTO "django_geo_db_location" VALUES(22754,NULL,'Rome, GA 30165',9444,222,NULL,13,13017,0);
INSERT INTO "django_geo_db_location" VALUES(22755,NULL,'Carrollton, GA 30166',9417,222,NULL,13,13018,0);
INSERT INTO "django_geo_db_location" VALUES(22756,NULL,'Austell, GA 30168',9409,222,NULL,13,13019,0);
INSERT INTO "django_geo_db_location" VALUES(22757,NULL,'Roopville, GA',9445,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22758,NULL,'Roopville, GA 30170',9445,222,NULL,13,13020,0);
INSERT INTO "django_geo_db_location" VALUES(22759,NULL,'Rydal, GA',9446,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22760,NULL,'Rydal, GA 30171',9446,222,NULL,13,13021,0);
INSERT INTO "django_geo_db_location" VALUES(22761,NULL,'Shannon, GA',9447,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22762,NULL,'Shannon, GA 30172',9447,222,NULL,13,13022,0);
INSERT INTO "django_geo_db_location" VALUES(22763,NULL,'Silver Creek, GA',9448,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22764,NULL,'Silver Creek, GA 30173',9448,222,NULL,13,13023,0);
INSERT INTO "django_geo_db_location" VALUES(22765,NULL,'Talking Rock, GA',9449,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22766,NULL,'Talking Rock, GA 30175',9449,222,NULL,13,13024,0);
INSERT INTO "django_geo_db_location" VALUES(22767,NULL,'Tallapoosa, GA',9450,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22768,NULL,'Tallapoosa, GA 30176',9450,222,NULL,13,13025,0);
INSERT INTO "django_geo_db_location" VALUES(22769,NULL,'Tate, GA',9451,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22770,NULL,'Tate, GA 30177',9451,222,NULL,13,13026,0);
INSERT INTO "django_geo_db_location" VALUES(22771,NULL,'Taylorsville, GA',9452,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22772,NULL,'Taylorsville, GA 30178',9452,222,NULL,13,13027,0);
INSERT INTO "django_geo_db_location" VALUES(22773,NULL,'Temple, GA',9453,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22774,NULL,'Temple, GA 30179',9453,222,NULL,13,13028,0);
INSERT INTO "django_geo_db_location" VALUES(22775,NULL,'Villa Rica, GA',9454,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22776,NULL,'Villa Rica, GA 30180',9454,222,NULL,13,13029,0);
INSERT INTO "django_geo_db_location" VALUES(22777,NULL,'Waco, GA',9455,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22778,NULL,'Waco, GA 30182',9455,222,NULL,13,13030,0);
INSERT INTO "django_geo_db_location" VALUES(22779,NULL,'Waleska, GA',9456,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22780,NULL,'Waleska, GA 30183',9456,222,NULL,13,13031,0);
INSERT INTO "django_geo_db_location" VALUES(22781,NULL,'White, GA',9457,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22782,NULL,'White, GA 30184',9457,222,NULL,13,13032,0);
INSERT INTO "django_geo_db_location" VALUES(22783,NULL,'Whitesburg, GA',9458,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22784,NULL,'Whitesburg, GA 30185',9458,222,NULL,13,13033,0);
INSERT INTO "django_geo_db_location" VALUES(22785,NULL,'Winston, GA',9459,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22786,NULL,'Winston, GA 30187',9459,222,NULL,13,13034,0);
INSERT INTO "django_geo_db_location" VALUES(22787,NULL,'Woodstock, GA',9460,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22788,NULL,'Woodstock, GA 30188',9460,222,NULL,13,13035,0);
INSERT INTO "django_geo_db_location" VALUES(22789,NULL,'Woodstock, GA 30189',9460,222,NULL,13,13036,0);
INSERT INTO "django_geo_db_location" VALUES(22790,NULL,'Alpharetta, GA 30202',9375,222,NULL,13,13037,0);
INSERT INTO "django_geo_db_location" VALUES(22791,NULL,'Brooks, GA',9461,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22792,NULL,'Brooks, GA 30203',9461,222,NULL,13,13038,0);
INSERT INTO "django_geo_db_location" VALUES(22793,NULL,'Barnesville, GA',9462,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22794,NULL,'Barnesville, GA 30204',9462,222,NULL,13,13039,0);
INSERT INTO "django_geo_db_location" VALUES(22795,NULL,'Brooks, GA 30205',9461,222,NULL,13,13040,0);
INSERT INTO "django_geo_db_location" VALUES(22796,NULL,'Concord, GA',9463,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22797,NULL,'Concord, GA 30206',9463,222,NULL,13,13041,0);
INSERT INTO "django_geo_db_location" VALUES(22798,NULL,'Experiment, GA',9464,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22799,NULL,'Experiment, GA 30212',9464,222,NULL,13,13042,0);
INSERT INTO "django_geo_db_location" VALUES(22800,NULL,'Fairburn, GA',9465,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22801,NULL,'Fairburn, GA 30213',9465,222,NULL,13,13043,0);
INSERT INTO "django_geo_db_location" VALUES(22802,NULL,'Fayetteville, GA',9466,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22803,NULL,'Fayetteville, GA 30214',9466,222,NULL,13,13044,0);
INSERT INTO "django_geo_db_location" VALUES(22804,NULL,'Fayetteville, GA 30215',9466,222,NULL,13,13045,0);
INSERT INTO "django_geo_db_location" VALUES(22805,NULL,'Flovilla, GA',9467,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22806,NULL,'Flovilla, GA 30216',9467,222,NULL,13,13046,0);
INSERT INTO "django_geo_db_location" VALUES(22807,NULL,'Franklin, GA',9468,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22808,NULL,'Franklin, GA 30217',9468,222,NULL,13,13047,0);
INSERT INTO "django_geo_db_location" VALUES(22809,NULL,'Gay, GA',9469,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22810,NULL,'Gay, GA 30218',9469,222,NULL,13,13048,0);
INSERT INTO "django_geo_db_location" VALUES(22811,NULL,'Glenn, GA',9470,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22812,NULL,'Glenn, GA 30219',9470,222,NULL,13,13049,0);
INSERT INTO "django_geo_db_location" VALUES(22813,NULL,'Grantville, GA',9471,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22814,NULL,'Grantville, GA 30220',9471,222,NULL,13,13050,0);
INSERT INTO "django_geo_db_location" VALUES(22815,NULL,'Greenville, GA',9472,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22816,NULL,'Greenville, GA 30222',9472,222,NULL,13,13051,0);
INSERT INTO "django_geo_db_location" VALUES(22817,NULL,'Griffin, GA',9473,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22818,NULL,'Griffin, GA 30223',9473,222,NULL,13,13052,0);
INSERT INTO "django_geo_db_location" VALUES(22819,NULL,'Griffin, GA 30224',9473,222,NULL,13,13053,0);
INSERT INTO "django_geo_db_location" VALUES(22820,NULL,'Hampton, GA',9474,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22821,NULL,'Hampton, GA 30228',9474,222,NULL,13,13054,0);
INSERT INTO "django_geo_db_location" VALUES(22822,NULL,'Haralson, GA',9475,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22823,NULL,'Haralson, GA 30229',9475,222,NULL,13,13055,0);
INSERT INTO "django_geo_db_location" VALUES(22824,NULL,'Hogansville, GA',9476,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22825,NULL,'Hogansville, GA 30230',9476,222,NULL,13,13056,0);
INSERT INTO "django_geo_db_location" VALUES(22826,NULL,'Inman, GA',9477,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22827,NULL,'Inman, GA 30232',9477,222,NULL,13,13057,0);
INSERT INTO "django_geo_db_location" VALUES(22828,NULL,'Jackson, GA',9478,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22829,NULL,'Jackson, GA 30233',9478,222,NULL,13,13058,0);
INSERT INTO "django_geo_db_location" VALUES(22830,NULL,'Jenkinsburg, GA',9479,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22831,NULL,'Jenkinsburg, GA 30234',9479,222,NULL,13,13059,0);
INSERT INTO "django_geo_db_location" VALUES(22832,NULL,'Jonesboro, GA',9480,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22833,NULL,'Jonesboro, GA 30236',9480,222,NULL,13,13060,0);
INSERT INTO "django_geo_db_location" VALUES(22834,NULL,'Jonesboro, GA 30237',9480,222,NULL,13,13061,0);
INSERT INTO "django_geo_db_location" VALUES(22835,NULL,'Jonesboro, GA 30238',9480,222,NULL,13,13062,0);
INSERT INTO "django_geo_db_location" VALUES(22836,NULL,'Lagrange, GA',9481,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22837,NULL,'Lagrange, GA 30240',9481,222,NULL,13,13063,0);
INSERT INTO "django_geo_db_location" VALUES(22838,NULL,'Lagrange, GA 30241',9481,222,NULL,13,13064,0);
INSERT INTO "django_geo_db_location" VALUES(22839,NULL,'Locust Grove, GA',9482,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22840,NULL,'Locust Grove, GA 30248',9482,222,NULL,13,13065,0);
INSERT INTO "django_geo_db_location" VALUES(22841,NULL,'Lovejoy, GA',9483,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22842,NULL,'Lovejoy, GA 30250',9483,222,NULL,13,13066,0);
INSERT INTO "django_geo_db_location" VALUES(22843,NULL,'Luthersville, GA',9484,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22844,NULL,'Luthersville, GA 30251',9484,222,NULL,13,13067,0);
INSERT INTO "django_geo_db_location" VALUES(22845,NULL,'Mcdonough, GA',9485,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22846,NULL,'Mcdonough, GA 30252',9485,222,NULL,13,13068,0);
INSERT INTO "django_geo_db_location" VALUES(22847,NULL,'Mcdonough, GA 30253',9485,222,NULL,13,13069,0);
INSERT INTO "django_geo_db_location" VALUES(22848,NULL,'Meansville, GA',9486,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22849,NULL,'Meansville, GA 30256',9486,222,NULL,13,13070,0);
INSERT INTO "django_geo_db_location" VALUES(22850,NULL,'Milner, GA',9487,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22851,NULL,'Milner, GA 30257',9487,222,NULL,13,13071,0);
INSERT INTO "django_geo_db_location" VALUES(22852,NULL,'Molena, GA',9488,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22853,NULL,'Molena, GA 30258',9488,222,NULL,13,13072,0);
INSERT INTO "django_geo_db_location" VALUES(22854,NULL,'Moreland, GA',9489,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22855,NULL,'Moreland, GA 30259',9489,222,NULL,13,13073,0);
INSERT INTO "django_geo_db_location" VALUES(22856,NULL,'Morrow, GA',9490,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22857,NULL,'Morrow, GA 30260',9490,222,NULL,13,13074,0);
INSERT INTO "django_geo_db_location" VALUES(22858,NULL,'Lagrange, GA 30261',9481,222,NULL,13,13075,0);
INSERT INTO "django_geo_db_location" VALUES(22859,NULL,'Newnan, GA',9491,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22860,NULL,'Newnan, GA 30263',9491,222,NULL,13,13076,0);
INSERT INTO "django_geo_db_location" VALUES(22861,NULL,'Newnan, GA 30264',9491,222,NULL,13,13077,0);
INSERT INTO "django_geo_db_location" VALUES(22862,NULL,'Newnan, GA 30265',9491,222,NULL,13,13078,0);
INSERT INTO "django_geo_db_location" VALUES(22863,NULL,'Orchard Hill, GA',9492,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22864,NULL,'Orchard Hill, GA 30266',9492,222,NULL,13,13079,0);
INSERT INTO "django_geo_db_location" VALUES(22865,NULL,'Palmetto, GA',9493,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22866,NULL,'Palmetto, GA 30268',9493,222,NULL,13,13080,0);
INSERT INTO "django_geo_db_location" VALUES(22867,NULL,'Peachtree City, GA',9494,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22868,NULL,'Peachtree City, GA 30269',9494,222,NULL,13,13081,0);
INSERT INTO "django_geo_db_location" VALUES(22869,NULL,'Newnan, GA 30271',9491,222,NULL,13,13082,0);
INSERT INTO "django_geo_db_location" VALUES(22870,NULL,'Red Oak, GA',9495,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22871,NULL,'Red Oak, GA 30272',9495,222,NULL,13,13083,0);
INSERT INTO "django_geo_db_location" VALUES(22872,NULL,'Rex, GA',9496,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22873,NULL,'Rex, GA 30273',9496,222,NULL,13,13084,0);
INSERT INTO "django_geo_db_location" VALUES(22874,NULL,'Riverdale, GA',9497,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22875,NULL,'Riverdale, GA 30274',9497,222,NULL,13,13085,0);
INSERT INTO "django_geo_db_location" VALUES(22876,NULL,'Sargent, GA',9498,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22877,NULL,'Sargent, GA 30275',9498,222,NULL,13,13086,0);
INSERT INTO "django_geo_db_location" VALUES(22878,NULL,'Senoia, GA',9499,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22879,NULL,'Senoia, GA 30276',9499,222,NULL,13,13087,0);
INSERT INTO "django_geo_db_location" VALUES(22880,NULL,'Sharpsburg, GA',9500,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22881,NULL,'Sharpsburg, GA 30277',9500,222,NULL,13,13088,0);
INSERT INTO "django_geo_db_location" VALUES(22882,NULL,'Stockbridge, GA',9501,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22883,NULL,'Stockbridge, GA 30281',9501,222,NULL,13,13089,0);
INSERT INTO "django_geo_db_location" VALUES(22884,NULL,'Jackson, GA 30283',9478,222,NULL,13,13090,0);
INSERT INTO "django_geo_db_location" VALUES(22885,NULL,'Sunny Side, GA',9502,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22886,NULL,'Sunny Side, GA 30284',9502,222,NULL,13,13091,0);
INSERT INTO "django_geo_db_location" VALUES(22887,NULL,'The Rock, GA',9503,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22888,NULL,'The Rock, GA 30285',9503,222,NULL,13,13092,0);
INSERT INTO "django_geo_db_location" VALUES(22889,NULL,'Thomaston, GA',9504,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22890,NULL,'Thomaston, GA 30286',9504,222,NULL,13,13093,0);
INSERT INTO "django_geo_db_location" VALUES(22891,NULL,'Morrow, GA 30287',9490,222,NULL,13,13094,0);
INSERT INTO "django_geo_db_location" VALUES(22892,NULL,'Conley, GA',9505,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22893,NULL,'Conley, GA 30288',9505,222,NULL,13,13095,0);
INSERT INTO "django_geo_db_location" VALUES(22894,NULL,'Turin, GA',9506,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22895,NULL,'Turin, GA 30289',9506,222,NULL,13,13096,0);
INSERT INTO "django_geo_db_location" VALUES(22896,NULL,'Tyrone, GA',9507,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22897,NULL,'Tyrone, GA 30290',9507,222,NULL,13,13097,0);
INSERT INTO "django_geo_db_location" VALUES(22898,NULL,'Union City, GA',9508,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22899,NULL,'Union City, GA 30291',9508,222,NULL,13,13098,0);
INSERT INTO "django_geo_db_location" VALUES(22900,NULL,'Williamson, GA',9509,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22901,NULL,'Williamson, GA 30292',9509,222,NULL,13,13099,0);
INSERT INTO "django_geo_db_location" VALUES(22902,NULL,'Woodbury, GA',9510,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22903,NULL,'Woodbury, GA 30293',9510,222,NULL,13,13100,0);
INSERT INTO "django_geo_db_location" VALUES(22904,NULL,'Ellenwood, GA',9511,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22905,NULL,'Ellenwood, GA 30294',9511,222,NULL,13,13101,0);
INSERT INTO "django_geo_db_location" VALUES(22906,NULL,'Zebulon, GA',9512,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22907,NULL,'Zebulon, GA 30295',9512,222,NULL,13,13102,0);
INSERT INTO "django_geo_db_location" VALUES(22908,NULL,'Riverdale, GA 30296',9497,222,NULL,13,13103,0);
INSERT INTO "django_geo_db_location" VALUES(22909,NULL,'Forest Park, GA',9513,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22910,NULL,'Forest Park, GA 30297',9513,222,NULL,13,13104,0);
INSERT INTO "django_geo_db_location" VALUES(22911,NULL,'Forest Park, GA 30298',9513,222,NULL,13,13105,0);
INSERT INTO "django_geo_db_location" VALUES(22912,NULL,'Atlanta, GA',9514,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(22913,NULL,'Atlanta, GA 30301',9514,222,NULL,13,13106,0);
INSERT INTO "django_geo_db_location" VALUES(22914,NULL,'Atlanta, GA 30302',9514,222,NULL,13,13107,0);
INSERT INTO "django_geo_db_location" VALUES(22915,NULL,'Atlanta, GA 30303',9514,222,NULL,13,13108,0);
INSERT INTO "django_geo_db_location" VALUES(22916,NULL,'Atlanta, GA 30304',9514,222,NULL,13,13109,0);
INSERT INTO "django_geo_db_location" VALUES(22917,NULL,'Atlanta, GA 30305',9514,222,NULL,13,13110,0);
INSERT INTO "django_geo_db_location" VALUES(22918,NULL,'Atlanta, GA 30306',9514,222,NULL,13,13111,0);
INSERT INTO "django_geo_db_location" VALUES(22919,NULL,'Atlanta, GA 30307',9514,222,NULL,13,13112,0);
INSERT INTO "django_geo_db_location" VALUES(22920,NULL,'Atlanta, GA 30308',9514,222,NULL,13,13113,0);
INSERT INTO "django_geo_db_location" VALUES(22921,NULL,'Atlanta, GA 30309',9514,222,NULL,13,13114,0);
INSERT INTO "django_geo_db_location" VALUES(22922,NULL,'Atlanta, GA 30310',9514,222,NULL,13,13115,0);
INSERT INTO "django_geo_db_location" VALUES(22923,NULL,'Atlanta, GA 30311',9514,222,NULL,13,13116,0);
INSERT INTO "django_geo_db_location" VALUES(22924,NULL,'Atlanta, GA 30312',9514,222,NULL,13,13117,0);
INSERT INTO "django_geo_db_location" VALUES(22925,NULL,'Atlanta, GA 30313',9514,222,NULL,13,13118,0);
INSERT INTO "django_geo_db_location" VALUES(22926,NULL,'Atlanta, GA 30314',9514,222,NULL,13,13119,0);
INSERT INTO "django_geo_db_location" VALUES(22927,NULL,'Atlanta, GA 30315',9514,222,NULL,13,13120,0);
INSERT INTO "django_geo_db_location" VALUES(22928,NULL,'Atlanta, GA 30316',9514,222,NULL,13,13121,0);
INSERT INTO "django_geo_db_location" VALUES(22929,NULL,'Atlanta, GA 30317',9514,222,NULL,13,13122,0);
INSERT INTO "django_geo_db_location" VALUES(22930,NULL,'Atlanta, GA 30318',9514,222,NULL,13,13123,0);
INSERT INTO "django_geo_db_location" VALUES(22931,NULL,'Atlanta, GA 30319',9514,222,NULL,13,13124,0);
INSERT INTO "django_geo_db_location" VALUES(22932,NULL,'Atlanta, GA 30320',9514,222,NULL,13,13125,0);
INSERT INTO "django_geo_db_location" VALUES(22933,NULL,'Atlanta, GA 30321',9514,222,NULL,13,13126,0);
INSERT INTO "django_geo_db_location" VALUES(22934,NULL,'Atlanta, GA 30322',9514,222,NULL,13,13127,0);
INSERT INTO "django_geo_db_location" VALUES(22935,NULL,'Atlanta, GA 30323',9514,222,NULL,13,13128,0);
INSERT INTO "django_geo_db_location" VALUES(22936,NULL,'Atlanta, GA 30324',9514,222,NULL,13,13129,0);
INSERT INTO "django_geo_db_location" VALUES(22937,NULL,'Atlanta, GA 30325',9514,222,NULL,13,13130,0);
INSERT INTO "django_geo_db_location" VALUES(22938,NULL,'Atlanta, GA 30326',9514,222,NULL,13,13131,0);
INSERT INTO "django_geo_db_location" VALUES(22939,NULL,'Atlanta, GA 30327',9514,222,NULL,13,13132,0);
INSERT INTO "django_geo_db_location" VALUES(22940,NULL,'Atlanta, GA 30328',9514,222,NULL,13,13133,0);
INSERT INTO "django_geo_db_location" VALUES(22941,NULL,'Atlanta, GA 30329',9514,222,NULL,13,13134,0);
INSERT INTO "django_geo_db_location" VALUES(22942,NULL,'Atlanta, GA 30330',9514,222,NULL,13,13135,0);
INSERT INTO "django_geo_db_location" VALUES(22943,NULL,'Atlanta, GA 30331',9514,222,NULL,13,13136,0);
INSERT INTO "django_geo_db_location" VALUES(22944,NULL,'Atlanta, GA 30332',9514,222,NULL,13,13137,0);
INSERT INTO "django_geo_db_location" VALUES(22945,NULL,'Atlanta, GA 30333',9514,222,NULL,13,13138,0);
INSERT INTO "django_geo_db_location" VALUES(22946,NULL,'Atlanta, GA 30334',9514,222,NULL,13,13139,0);
INSERT INTO "django_geo_db_location" VALUES(22947,NULL,'Atlanta, GA 30335',9514,222,NULL,13,13140,0);
INSERT INTO "django_geo_db_location" VALUES(22948,NULL,'Atlanta, GA 30336',9514,222,NULL,13,13141,0);
INSERT INTO "django_geo_db_location" VALUES(22949,NULL,'Atlanta, GA 30337',9514,222,NULL,13,13142,0);
INSERT INTO "django_geo_db_location" VALUES(22950,NULL,'Atlanta, GA 30338',9514,222,NULL,13,13143,0);
INSERT INTO "django_geo_db_location" VALUES(22951,NULL,'Atlanta, GA 30339',9514,222,NULL,13,13144,0);
INSERT INTO "django_geo_db_location" VALUES(22952,NULL,'Atlanta, GA 30340',9514,222,NULL,13,13145,0);
INSERT INTO "django_geo_db_location" VALUES(22953,NULL,'Atlanta, GA 30341',9514,222,NULL,13,13146,0);
INSERT INTO "django_geo_db_location" VALUES(22954,NULL,'Atlanta, GA 30342',9514,222,NULL,13,13147,0);
INSERT INTO "django_geo_db_location" VALUES(22955,NULL,'Atlanta, GA 30343',9514,222,NULL,13,13148,0);
INSERT INTO "django_geo_db_location" VALUES(22956,NULL,'Atlanta, GA 30344',9514,222,NULL,13,13149,0);
INSERT INTO "django_geo_db_location" VALUES(22957,NULL,'Atlanta, GA 30345',9514,222,NULL,13,13150,0);
INSERT INTO "django_geo_db_location" VALUES(22958,NULL,'Atlanta, GA 30346',9514,222,NULL,13,13151,0);
INSERT INTO "django_geo_db_location" VALUES(22959,NULL,'Atlanta, GA 30347',9514,222,NULL,13,13152,0);
INSERT INTO "django_geo_db_location" VALUES(22960,NULL,'Atlanta, GA 30348',9514,222,NULL,13,13153,0);
INSERT INTO "django_geo_db_location" VALUES(22961,NULL,'Atlanta, GA 30349',9514,222,NULL,13,13154,0);
INSERT INTO "django_geo_db_location" VALUES(22962,NULL,'Atlanta, GA 30350',9514,222,NULL,13,13155,0);
INSERT INTO "django_geo_db_location" VALUES(22963,NULL,'Atlanta, GA 30351',9514,222,NULL,13,13156,0);
INSERT INTO "django_geo_db_location" VALUES(22964,NULL,'Atlanta, GA 30353',9514,222,NULL,13,13157,0);
INSERT INTO "django_geo_db_location" VALUES(22965,NULL,'Atlanta, GA 30354',9514,222,NULL,13,13158,0);
INSERT INTO "django_geo_db_location" VALUES(22966,NULL,'Atlanta, GA 30355',9514,222,NULL,13,13159,0);
INSERT INTO "django_geo_db_location" VALUES(22967,NULL,'Atlanta, GA 30356',9514,222,NULL,13,13160,0);
INSERT INTO "django_geo_db_location" VALUES(22968,NULL,'Atlanta, GA 30357',9514,222,NULL,13,13161,0);
INSERT INTO "django_geo_db_location" VALUES(22969,NULL,'Atlanta, GA 30358',9514,222,NULL,13,13162,0);
INSERT INTO "django_geo_db_location" VALUES(22970,NULL,'Atlanta, GA 30359',9514,222,NULL,13,13163,0);
INSERT INTO "django_geo_db_location" VALUES(22971,NULL,'Atlanta, GA 30360',9514,222,NULL,13,13164,0);
INSERT INTO "django_geo_db_location" VALUES(22972,NULL,'Atlanta, GA 30361',9514,222,NULL,13,13165,0);
INSERT INTO "django_geo_db_location" VALUES(22973,NULL,'Atlanta, GA 30362',9514,222,NULL,13,13166,0);
INSERT INTO "django_geo_db_location" VALUES(22974,NULL,'Atlanta, GA 30363',9514,222,NULL,13,13167,0);
INSERT INTO "django_geo_db_location" VALUES(22975,NULL,'Atlanta, GA 30364',9514,222,NULL,13,13168,0);
INSERT INTO "django_geo_db_location" VALUES(22976,NULL,'Atlanta, GA 30365',9514,222,NULL,13,13169,0);
INSERT INTO "django_geo_db_location" VALUES(22977,NULL,'Atlanta, GA 30366',9514,222,NULL,13,13170,0);
INSERT INTO "django_geo_db_location" VALUES(22978,NULL,'Atlanta, GA 30367',9514,222,NULL,13,13171,0);
INSERT INTO "django_geo_db_location" VALUES(22979,NULL,'Atlanta, GA 30368',9514,222,NULL,13,13172,0);
INSERT INTO "django_geo_db_location" VALUES(22980,NULL,'Atlanta, GA 30369',9514,222,NULL,13,13173,0);
INSERT INTO "django_geo_db_location" VALUES(22981,NULL,'Atlanta, GA 30370',9514,222,NULL,13,13174,0);
INSERT INTO "django_geo_db_location" VALUES(22982,NULL,'Atlanta, GA 30371',9514,222,NULL,13,13175,0);
INSERT INTO "django_geo_db_location" VALUES(22983,NULL,'Atlanta, GA 30374',9514,222,NULL,13,13176,0);
INSERT INTO "django_geo_db_location" VALUES(22984,NULL,'Atlanta, GA 30375',9514,222,NULL,13,13177,0);
INSERT INTO "django_geo_db_location" VALUES(22985,NULL,'Atlanta, GA 30376',9514,222,NULL,13,13178,0);
INSERT INTO "django_geo_db_location" VALUES(22986,NULL,'Atlanta, GA 30377',9514,222,NULL,13,13179,0);
INSERT INTO "django_geo_db_location" VALUES(22987,NULL,'Atlanta, GA 30378',9514,222,NULL,13,13180,0);
INSERT INTO "django_geo_db_location" VALUES(22988,NULL,'Atlanta, GA 30379',9514,222,NULL,13,13181,0);
INSERT INTO "django_geo_db_location" VALUES(22989,NULL,'Atlanta, GA 30380',9514,222,NULL,13,13182,0);
INSERT INTO "django_geo_db_location" VALUES(22990,NULL,'Atlanta, GA 30381',9514,222,NULL,13,13183,0);
INSERT INTO "django_geo_db_location" VALUES(22991,NULL,'Atlanta, GA 30384',9514,222,NULL,13,13184,0);
INSERT INTO "django_geo_db_location" VALUES(22992,NULL,'Atlanta, GA 30385',9514,222,NULL,13,13185,0);
INSERT INTO "django_geo_db_location" VALUES(22993,NULL,'Atlanta, GA 30386',9514,222,NULL,13,13186,0);
INSERT INTO "django_geo_db_location" VALUES(22994,NULL,'Atlanta, GA 30387',9514,222,NULL,13,13187,0);
INSERT INTO "django_geo_db_location" VALUES(22995,NULL,'Atlanta, GA 30388',9514,222,NULL,13,13188,0);
INSERT INTO "django_geo_db_location" VALUES(22996,NULL,'Atlanta, GA 30389',9514,222,NULL,13,13189,0);
INSERT INTO "django_geo_db_location" VALUES(22997,NULL,'Atlanta, GA 30390',9514,222,NULL,13,13190,0);
INSERT INTO "django_geo_db_location" VALUES(22998,NULL,'Atlanta, GA 30392',9514,222,NULL,13,13191,0);
INSERT INTO "django_geo_db_location" VALUES(22999,NULL,'Atlanta, GA 30394',9514,222,NULL,13,13192,0);
INSERT INTO "django_geo_db_location" VALUES(23000,NULL,'Atlanta, GA 30396',9514,222,NULL,13,13193,0);
INSERT INTO "django_geo_db_location" VALUES(23001,NULL,'Atlanta, GA 30398',9514,222,NULL,13,13194,0);
INSERT INTO "django_geo_db_location" VALUES(23002,NULL,'Atlanta, GA 30399',9514,222,NULL,13,13195,0);
INSERT INTO "django_geo_db_location" VALUES(23003,NULL,'Swainsboro, GA',9515,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23004,NULL,'Swainsboro, GA 30401',9515,222,NULL,13,13196,0);
INSERT INTO "django_geo_db_location" VALUES(23005,NULL,'Ailey, GA',9516,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23006,NULL,'Ailey, GA 30410',9516,222,NULL,13,13197,0);
INSERT INTO "django_geo_db_location" VALUES(23007,NULL,'Alamo, GA',9517,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23008,NULL,'Alamo, GA 30411',9517,222,NULL,13,13198,0);
INSERT INTO "django_geo_db_location" VALUES(23009,NULL,'Alston, GA',9518,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23010,NULL,'Alston, GA 30412',9518,222,NULL,13,13199,0);
INSERT INTO "django_geo_db_location" VALUES(23011,NULL,'Bartow, GA',9519,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23012,NULL,'Bartow, GA 30413',9519,222,NULL,13,13200,0);
INSERT INTO "django_geo_db_location" VALUES(23013,NULL,'Bellville, GA',9520,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23014,NULL,'Bellville, GA 30414',9520,222,NULL,13,13201,0);
INSERT INTO "django_geo_db_location" VALUES(23015,NULL,'Brooklet, GA',9521,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23016,NULL,'Brooklet, GA 30415',9521,222,NULL,13,13202,0);
INSERT INTO "django_geo_db_location" VALUES(23017,NULL,'Claxton, GA',9522,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23018,NULL,'Claxton, GA 30417',9522,222,NULL,13,13203,0);
INSERT INTO "django_geo_db_location" VALUES(23019,NULL,'Cobbtown, GA',9523,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23020,NULL,'Cobbtown, GA 30420',9523,222,NULL,13,13204,0);
INSERT INTO "django_geo_db_location" VALUES(23021,NULL,'Collins, GA',9524,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23022,NULL,'Collins, GA 30421',9524,222,NULL,13,13205,0);
INSERT INTO "django_geo_db_location" VALUES(23023,NULL,'Daisy, GA',9525,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23024,NULL,'Daisy, GA 30423',9525,222,NULL,13,13206,0);
INSERT INTO "django_geo_db_location" VALUES(23025,NULL,'Dover, GA',9526,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23026,NULL,'Dover, GA 30424',9526,222,NULL,13,13207,0);
INSERT INTO "django_geo_db_location" VALUES(23027,NULL,'Garfield, GA',9527,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23028,NULL,'Garfield, GA 30425',9527,222,NULL,13,13208,0);
INSERT INTO "django_geo_db_location" VALUES(23029,NULL,'Girard, GA',9528,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23030,NULL,'Girard, GA 30426',9528,222,NULL,13,13209,0);
INSERT INTO "django_geo_db_location" VALUES(23031,NULL,'Glennville, GA',9529,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23032,NULL,'Glennville, GA 30427',9529,222,NULL,13,13210,0);
INSERT INTO "django_geo_db_location" VALUES(23033,NULL,'Glenwood, GA',9530,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23034,NULL,'Glenwood, GA 30428',9530,222,NULL,13,13211,0);
INSERT INTO "django_geo_db_location" VALUES(23035,NULL,'Hagan, GA',9531,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23036,NULL,'Hagan, GA 30429',9531,222,NULL,13,13212,0);
INSERT INTO "django_geo_db_location" VALUES(23037,NULL,'Louisville, GA',9532,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23038,NULL,'Louisville, GA 30434',9532,222,NULL,13,13213,0);
INSERT INTO "django_geo_db_location" VALUES(23039,NULL,'Lyons, GA',9533,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23040,NULL,'Lyons, GA 30436',9533,222,NULL,13,13214,0);
INSERT INTO "django_geo_db_location" VALUES(23041,NULL,'Manassas, GA',9534,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23042,NULL,'Manassas, GA 30438',9534,222,NULL,13,13215,0);
INSERT INTO "django_geo_db_location" VALUES(23043,NULL,'Metter, GA',9535,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23044,NULL,'Metter, GA 30439',9535,222,NULL,13,13216,0);
INSERT INTO "django_geo_db_location" VALUES(23045,NULL,'Midville, GA',9536,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23046,NULL,'Midville, GA 30441',9536,222,NULL,13,13217,0);
INSERT INTO "django_geo_db_location" VALUES(23047,NULL,'Millen, GA',9537,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23048,NULL,'Millen, GA 30442',9537,222,NULL,13,13218,0);
INSERT INTO "django_geo_db_location" VALUES(23049,NULL,'East Point, GA',9538,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23050,NULL,'East Point, GA 30444',9538,222,NULL,13,13219,0);
INSERT INTO "django_geo_db_location" VALUES(23051,NULL,'Mount Vernon, GA',9539,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23052,NULL,'Mount Vernon, GA 30445',9539,222,NULL,13,13220,0);
INSERT INTO "django_geo_db_location" VALUES(23053,NULL,'Newington, GA',9540,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23054,NULL,'Newington, GA 30446',9540,222,NULL,13,13221,0);
INSERT INTO "django_geo_db_location" VALUES(23055,NULL,'Norristown, GA',9541,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23056,NULL,'Norristown, GA 30447',9541,222,NULL,13,13222,0);
INSERT INTO "django_geo_db_location" VALUES(23057,NULL,'Nunez, GA',9542,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23058,NULL,'Nunez, GA 30448',9542,222,NULL,13,13223,0);
INSERT INTO "django_geo_db_location" VALUES(23059,NULL,'Oliver, GA',9543,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23060,NULL,'Oliver, GA 30449',9543,222,NULL,13,13224,0);
INSERT INTO "django_geo_db_location" VALUES(23061,NULL,'Portal, GA',9544,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23062,NULL,'Portal, GA 30450',9544,222,NULL,13,13225,0);
INSERT INTO "django_geo_db_location" VALUES(23063,NULL,'Pulaski, GA',9545,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23064,NULL,'Pulaski, GA 30451',9545,222,NULL,13,13226,0);
INSERT INTO "django_geo_db_location" VALUES(23065,NULL,'Register, GA',9546,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23066,NULL,'Register, GA 30452',9546,222,NULL,13,13227,0);
INSERT INTO "django_geo_db_location" VALUES(23067,NULL,'Reidsville, GA',9547,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23068,NULL,'Reidsville, GA 30453',9547,222,NULL,13,13228,0);
INSERT INTO "django_geo_db_location" VALUES(23069,NULL,'Rockledge, GA',9548,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23070,NULL,'Rockledge, GA 30454',9548,222,NULL,13,13229,0);
INSERT INTO "django_geo_db_location" VALUES(23071,NULL,'Rocky Ford, GA',9549,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23072,NULL,'Rocky Ford, GA 30455',9549,222,NULL,13,13230,0);
INSERT INTO "django_geo_db_location" VALUES(23073,NULL,'Sardis, GA',9550,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23074,NULL,'Sardis, GA 30456',9550,222,NULL,13,13231,0);
INSERT INTO "django_geo_db_location" VALUES(23075,NULL,'Soperton, GA',9551,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23076,NULL,'Soperton, GA 30457',9551,222,NULL,13,13232,0);
INSERT INTO "django_geo_db_location" VALUES(23077,NULL,'Statesboro, GA',9552,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23078,NULL,'Statesboro, GA 30458',9552,222,NULL,13,13233,0);
INSERT INTO "django_geo_db_location" VALUES(23079,NULL,'Statesboro, GA 30459',9552,222,NULL,13,13234,0);
INSERT INTO "django_geo_db_location" VALUES(23080,NULL,'Statesboro, GA 30460',9552,222,NULL,13,13235,0);
INSERT INTO "django_geo_db_location" VALUES(23081,NULL,'Statesboro, GA 30461',9552,222,NULL,13,13236,0);
INSERT INTO "django_geo_db_location" VALUES(23082,NULL,'Stillmore, GA',9553,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23083,NULL,'Stillmore, GA 30464',9553,222,NULL,13,13237,0);
INSERT INTO "django_geo_db_location" VALUES(23084,NULL,'Summertown, GA',9554,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23085,NULL,'Summertown, GA 30466',9554,222,NULL,13,13238,0);
INSERT INTO "django_geo_db_location" VALUES(23086,NULL,'Sylvania, GA',9555,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23087,NULL,'Sylvania, GA 30467',9555,222,NULL,13,13239,0);
INSERT INTO "django_geo_db_location" VALUES(23088,NULL,'Tarrytown, GA',9556,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23089,NULL,'Tarrytown, GA 30470',9556,222,NULL,13,13240,0);
INSERT INTO "django_geo_db_location" VALUES(23090,NULL,'Twin City, GA',9557,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23091,NULL,'Twin City, GA 30471',9557,222,NULL,13,13241,0);
INSERT INTO "django_geo_db_location" VALUES(23092,NULL,'Uvalda, GA',9558,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23093,NULL,'Uvalda, GA 30473',9558,222,NULL,13,13242,0);
INSERT INTO "django_geo_db_location" VALUES(23094,NULL,'Vidalia, GA',9559,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23095,NULL,'Vidalia, GA 30474',9559,222,NULL,13,13243,0);
INSERT INTO "django_geo_db_location" VALUES(23096,NULL,'Vidalia, GA 30475',9559,222,NULL,13,13244,0);
INSERT INTO "django_geo_db_location" VALUES(23097,NULL,'Wadley, GA',9560,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23098,NULL,'Wadley, GA 30477',9560,222,NULL,13,13245,0);
INSERT INTO "django_geo_db_location" VALUES(23099,NULL,'Reidsville, GA 30499',9547,222,NULL,13,13246,0);
INSERT INTO "django_geo_db_location" VALUES(23100,NULL,'Gainesville, GA',9561,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23101,NULL,'Gainesville, GA 30501',9561,222,NULL,13,13247,0);
INSERT INTO "django_geo_db_location" VALUES(23102,NULL,'Chestnut Mountain, GA',9562,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23103,NULL,'Chestnut Mountain, GA 30502',9562,222,NULL,13,13248,0);
INSERT INTO "django_geo_db_location" VALUES(23104,NULL,'Gainesville, GA 30503',9561,222,NULL,13,13249,0);
INSERT INTO "django_geo_db_location" VALUES(23105,NULL,'Gainesville, GA 30504',9561,222,NULL,13,13250,0);
INSERT INTO "django_geo_db_location" VALUES(23106,NULL,'Gainesville, GA 30505',9561,222,NULL,13,13251,0);
INSERT INTO "django_geo_db_location" VALUES(23107,NULL,'Gainesville, GA 30506',9561,222,NULL,13,13252,0);
INSERT INTO "django_geo_db_location" VALUES(23108,NULL,'Gainesville, GA 30507',9561,222,NULL,13,13253,0);
INSERT INTO "django_geo_db_location" VALUES(23109,NULL,'Alto, GA',9563,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23110,NULL,'Alto, GA 30510',9563,222,NULL,13,13254,0);
INSERT INTO "django_geo_db_location" VALUES(23111,NULL,'Baldwin, GA',9564,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23112,NULL,'Baldwin, GA 30511',9564,222,NULL,13,13255,0);
INSERT INTO "django_geo_db_location" VALUES(23113,NULL,'Blairsville, GA',9565,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23114,NULL,'Blairsville, GA 30512',9565,222,NULL,13,13256,0);
INSERT INTO "django_geo_db_location" VALUES(23115,NULL,'Blue Ridge, GA',9566,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23116,NULL,'Blue Ridge, GA 30513',9566,222,NULL,13,13257,0);
INSERT INTO "django_geo_db_location" VALUES(23117,NULL,'Blairsville, GA 30514',9565,222,NULL,13,13258,0);
INSERT INTO "django_geo_db_location" VALUES(23118,NULL,'Buford, GA',9567,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23119,NULL,'Buford, GA 30515',9567,222,NULL,13,13259,0);
INSERT INTO "django_geo_db_location" VALUES(23120,NULL,'Bowersville, GA',9568,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23121,NULL,'Bowersville, GA 30516',9568,222,NULL,13,13260,0);
INSERT INTO "django_geo_db_location" VALUES(23122,NULL,'Braselton, GA',9569,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23123,NULL,'Braselton, GA 30517',9569,222,NULL,13,13261,0);
INSERT INTO "django_geo_db_location" VALUES(23124,NULL,'Buford, GA 30518',9567,222,NULL,13,13262,0);
INSERT INTO "django_geo_db_location" VALUES(23125,NULL,'Buford, GA 30519',9567,222,NULL,13,13263,0);
INSERT INTO "django_geo_db_location" VALUES(23126,NULL,'Canon, GA',9570,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23127,NULL,'Canon, GA 30520',9570,222,NULL,13,13264,0);
INSERT INTO "django_geo_db_location" VALUES(23128,NULL,'Carnesville, GA',9571,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23129,NULL,'Carnesville, GA 30521',9571,222,NULL,13,13265,0);
INSERT INTO "django_geo_db_location" VALUES(23130,NULL,'Cherrylog, GA',9572,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23131,NULL,'Cherrylog, GA 30522',9572,222,NULL,13,13266,0);
INSERT INTO "django_geo_db_location" VALUES(23132,NULL,'Clarkesville, GA',9573,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23133,NULL,'Clarkesville, GA 30523',9573,222,NULL,13,13267,0);
INSERT INTO "django_geo_db_location" VALUES(23134,NULL,'Clayton, GA',9574,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23135,NULL,'Clayton, GA 30525',9574,222,NULL,13,13268,0);
INSERT INTO "django_geo_db_location" VALUES(23136,NULL,'Clermont, GA',9575,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23137,NULL,'Clermont, GA 30527',9575,222,NULL,13,13269,0);
INSERT INTO "django_geo_db_location" VALUES(23138,NULL,'Cleveland, GA',9576,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23139,NULL,'Cleveland, GA 30528',9576,222,NULL,13,13270,0);
INSERT INTO "django_geo_db_location" VALUES(23140,NULL,'Commerce, GA',9577,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23141,NULL,'Commerce, GA 30529',9577,222,NULL,13,13271,0);
INSERT INTO "django_geo_db_location" VALUES(23142,NULL,'Commerce, GA 30530',9577,222,NULL,13,13272,0);
INSERT INTO "django_geo_db_location" VALUES(23143,NULL,'Cornelia, GA',9578,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23144,NULL,'Cornelia, GA 30531',9578,222,NULL,13,13273,0);
INSERT INTO "django_geo_db_location" VALUES(23145,NULL,'Dahlonega, GA',9579,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23146,NULL,'Dahlonega, GA 30533',9579,222,NULL,13,13274,0);
INSERT INTO "django_geo_db_location" VALUES(23147,NULL,'Dawsonville, GA',9580,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23148,NULL,'Dawsonville, GA 30534',9580,222,NULL,13,13275,0);
INSERT INTO "django_geo_db_location" VALUES(23149,NULL,'Demorest, GA',9581,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23150,NULL,'Demorest, GA 30535',9581,222,NULL,13,13276,0);
INSERT INTO "django_geo_db_location" VALUES(23151,NULL,'Dillard, GA',9582,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23152,NULL,'Dillard, GA 30537',9582,222,NULL,13,13277,0);
INSERT INTO "django_geo_db_location" VALUES(23153,NULL,'Eastanollee, GA',9583,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23154,NULL,'Eastanollee, GA 30538',9583,222,NULL,13,13278,0);
INSERT INTO "django_geo_db_location" VALUES(23155,NULL,'East Ellijay, GA',9584,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23156,NULL,'East Ellijay, GA 30539',9584,222,NULL,13,13279,0);
INSERT INTO "django_geo_db_location" VALUES(23157,NULL,'Ellijay, GA',9585,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23158,NULL,'Ellijay, GA 30540',9585,222,NULL,13,13280,0);
INSERT INTO "django_geo_db_location" VALUES(23159,NULL,'Epworth, GA',9586,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23160,NULL,'Epworth, GA 30541',9586,222,NULL,13,13281,0);
INSERT INTO "django_geo_db_location" VALUES(23161,NULL,'Flowery Branch, GA',9587,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23162,NULL,'Flowery Branch, GA 30542',9587,222,NULL,13,13282,0);
INSERT INTO "django_geo_db_location" VALUES(23163,NULL,'Gillsville, GA',9588,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23164,NULL,'Gillsville, GA 30543',9588,222,NULL,13,13283,0);
INSERT INTO "django_geo_db_location" VALUES(23165,NULL,'Demorest, GA 30544',9581,222,NULL,13,13284,0);
INSERT INTO "django_geo_db_location" VALUES(23166,NULL,'Helen, GA',9589,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23167,NULL,'Helen, GA 30545',9589,222,NULL,13,13285,0);
INSERT INTO "django_geo_db_location" VALUES(23168,NULL,'Hiawassee, GA',9590,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23169,NULL,'Hiawassee, GA 30546',9590,222,NULL,13,13286,0);
INSERT INTO "django_geo_db_location" VALUES(23170,NULL,'Homer, GA',9591,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23171,NULL,'Homer, GA 30547',9591,222,NULL,13,13287,0);
INSERT INTO "django_geo_db_location" VALUES(23172,NULL,'Hoschton, GA',9592,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23173,NULL,'Hoschton, GA 30548',9592,222,NULL,13,13288,0);
INSERT INTO "django_geo_db_location" VALUES(23174,NULL,'Jefferson, GA',9593,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23175,NULL,'Jefferson, GA 30549',9593,222,NULL,13,13289,0);
INSERT INTO "django_geo_db_location" VALUES(23176,NULL,'Lakemont, GA',9594,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23177,NULL,'Lakemont, GA 30552',9594,222,NULL,13,13290,0);
INSERT INTO "django_geo_db_location" VALUES(23178,NULL,'Lavonia, GA',9595,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23179,NULL,'Lavonia, GA 30553',9595,222,NULL,13,13291,0);
INSERT INTO "django_geo_db_location" VALUES(23180,NULL,'Lula, GA',9596,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23181,NULL,'Lula, GA 30554',9596,222,NULL,13,13292,0);
INSERT INTO "django_geo_db_location" VALUES(23182,NULL,'McCaysville, GA',9597,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23183,NULL,'McCaysville, GA 30555',9597,222,NULL,13,13293,0);
INSERT INTO "django_geo_db_location" VALUES(23184,NULL,'Martin, GA',9598,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23185,NULL,'Martin, GA 30557',9598,222,NULL,13,13294,0);
INSERT INTO "django_geo_db_location" VALUES(23186,NULL,'Maysville, GA',9599,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23187,NULL,'Maysville, GA 30558',9599,222,NULL,13,13295,0);
INSERT INTO "django_geo_db_location" VALUES(23188,NULL,'Mineral Bluff, GA',9600,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23189,NULL,'Mineral Bluff, GA 30559',9600,222,NULL,13,13296,0);
INSERT INTO "django_geo_db_location" VALUES(23190,NULL,'Morganton, GA',9601,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23191,NULL,'Morganton, GA 30560',9601,222,NULL,13,13297,0);
INSERT INTO "django_geo_db_location" VALUES(23192,NULL,'Mountain City, GA',9602,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23193,NULL,'Mountain City, GA 30562',9602,222,NULL,13,13298,0);
INSERT INTO "django_geo_db_location" VALUES(23194,NULL,'Mount Airy, GA',9603,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23195,NULL,'Mount Airy, GA 30563',9603,222,NULL,13,13299,0);
INSERT INTO "django_geo_db_location" VALUES(23196,NULL,'Murrayville, GA',9604,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23197,NULL,'Murrayville, GA 30564',9604,222,NULL,13,13300,0);
INSERT INTO "django_geo_db_location" VALUES(23198,NULL,'Nicholson, GA',9605,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23199,NULL,'Nicholson, GA 30565',9605,222,NULL,13,13301,0);
INSERT INTO "django_geo_db_location" VALUES(23200,NULL,'Oakwood, GA',9606,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23201,NULL,'Oakwood, GA 30566',9606,222,NULL,13,13302,0);
INSERT INTO "django_geo_db_location" VALUES(23202,NULL,'Pendergrass, GA',9607,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23203,NULL,'Pendergrass, GA 30567',9607,222,NULL,13,13303,0);
INSERT INTO "django_geo_db_location" VALUES(23204,NULL,'Rabun Gap, GA',9608,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23205,NULL,'Rabun Gap, GA 30568',9608,222,NULL,13,13304,0);
INSERT INTO "django_geo_db_location" VALUES(23206,NULL,'Sautee Nacoochee, GA',9609,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23207,NULL,'Sautee Nacoochee, GA 30571',9609,222,NULL,13,13305,0);
INSERT INTO "django_geo_db_location" VALUES(23208,NULL,'Suches, GA',9610,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23209,NULL,'Suches, GA 30572',9610,222,NULL,13,13306,0);
INSERT INTO "django_geo_db_location" VALUES(23210,NULL,'Tallulah Falls, GA',9611,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23211,NULL,'Tallulah Falls, GA 30573',9611,222,NULL,13,13307,0);
INSERT INTO "django_geo_db_location" VALUES(23212,NULL,'Talmo, GA',9612,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23213,NULL,'Talmo, GA 30575',9612,222,NULL,13,13308,0);
INSERT INTO "django_geo_db_location" VALUES(23214,NULL,'Tiger, GA',9613,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23215,NULL,'Tiger, GA 30576',9613,222,NULL,13,13309,0);
INSERT INTO "django_geo_db_location" VALUES(23216,NULL,'Toccoa, GA',9614,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23217,NULL,'Toccoa, GA 30577',9614,222,NULL,13,13310,0);
INSERT INTO "django_geo_db_location" VALUES(23218,NULL,'Turnerville, GA',9615,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23219,NULL,'Turnerville, GA 30580',9615,222,NULL,13,13311,0);
INSERT INTO "django_geo_db_location" VALUES(23220,NULL,'Wiley, GA',9616,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23221,NULL,'Wiley, GA 30581',9616,222,NULL,13,13312,0);
INSERT INTO "django_geo_db_location" VALUES(23222,NULL,'Young Harris, GA',9617,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23223,NULL,'Young Harris, GA 30582',9617,222,NULL,13,13313,0);
INSERT INTO "django_geo_db_location" VALUES(23224,NULL,'Alto, GA 30596',9563,222,NULL,13,13314,0);
INSERT INTO "django_geo_db_location" VALUES(23225,NULL,'Dahlonega, GA 30597',9579,222,NULL,13,13315,0);
INSERT INTO "django_geo_db_location" VALUES(23226,NULL,'Toccoa, GA 30598',9614,222,NULL,13,13316,0);
INSERT INTO "django_geo_db_location" VALUES(23227,NULL,'Commerce, GA 30599',9577,222,NULL,13,13317,0);
INSERT INTO "django_geo_db_location" VALUES(23228,NULL,'Athens, GA',9618,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23229,NULL,'Athens, GA 30601',9618,222,NULL,13,13318,0);
INSERT INTO "django_geo_db_location" VALUES(23230,NULL,'Athens, GA 30602',9618,222,NULL,13,13319,0);
INSERT INTO "django_geo_db_location" VALUES(23231,NULL,'Athens, GA 30603',9618,222,NULL,13,13320,0);
INSERT INTO "django_geo_db_location" VALUES(23232,NULL,'Athens, GA 30604',9618,222,NULL,13,13321,0);
INSERT INTO "django_geo_db_location" VALUES(23233,NULL,'Athens, GA 30605',9618,222,NULL,13,13322,0);
INSERT INTO "django_geo_db_location" VALUES(23234,NULL,'Athens, GA 30606',9618,222,NULL,13,13323,0);
INSERT INTO "django_geo_db_location" VALUES(23235,NULL,'Athens, GA 30607',9618,222,NULL,13,13324,0);
INSERT INTO "django_geo_db_location" VALUES(23236,NULL,'Athens, GA 30608',9618,222,NULL,13,13325,0);
INSERT INTO "django_geo_db_location" VALUES(23237,NULL,'Athens, GA 30609',9618,222,NULL,13,13326,0);
INSERT INTO "django_geo_db_location" VALUES(23238,NULL,'Athens, GA 30610',9618,222,NULL,13,13327,0);
INSERT INTO "django_geo_db_location" VALUES(23239,NULL,'Athens, GA 30612',9618,222,NULL,13,13328,0);
INSERT INTO "django_geo_db_location" VALUES(23240,NULL,'Athens, GA 30613',9618,222,NULL,13,13329,0);
INSERT INTO "django_geo_db_location" VALUES(23241,NULL,'Arnoldsville, GA',9619,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23242,NULL,'Arnoldsville, GA 30619',9619,222,NULL,13,13330,0);
INSERT INTO "django_geo_db_location" VALUES(23243,NULL,'Bethlehem, GA',9620,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23244,NULL,'Bethlehem, GA 30620',9620,222,NULL,13,13331,0);
INSERT INTO "django_geo_db_location" VALUES(23245,NULL,'Bishop, GA',9621,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23246,NULL,'Bishop, GA 30621',9621,222,NULL,13,13332,0);
INSERT INTO "django_geo_db_location" VALUES(23247,NULL,'Bogart, GA',9622,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23248,NULL,'Bogart, GA 30622',9622,222,NULL,13,13333,0);
INSERT INTO "django_geo_db_location" VALUES(23249,NULL,'Bostwick, GA',9623,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23250,NULL,'Bostwick, GA 30623',9623,222,NULL,13,13334,0);
INSERT INTO "django_geo_db_location" VALUES(23251,NULL,'Bowman, GA',9624,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23252,NULL,'Bowman, GA 30624',9624,222,NULL,13,13335,0);
INSERT INTO "django_geo_db_location" VALUES(23253,NULL,'Buckhead, GA',9625,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23254,NULL,'Buckhead, GA 30625',9625,222,NULL,13,13336,0);
INSERT INTO "django_geo_db_location" VALUES(23255,NULL,'Carlton, GA',9626,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23256,NULL,'Carlton, GA 30627',9626,222,NULL,13,13337,0);
INSERT INTO "django_geo_db_location" VALUES(23257,NULL,'Colbert, GA',9627,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23258,NULL,'Colbert, GA 30628',9627,222,NULL,13,13338,0);
INSERT INTO "django_geo_db_location" VALUES(23259,NULL,'Comer, GA',9628,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23260,NULL,'Comer, GA 30629',9628,222,NULL,13,13339,0);
INSERT INTO "django_geo_db_location" VALUES(23261,NULL,'Crawford, GA',9629,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23262,NULL,'Crawford, GA 30630',9629,222,NULL,13,13340,0);
INSERT INTO "django_geo_db_location" VALUES(23263,NULL,'Crawfordville, GA',9630,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23264,NULL,'Crawfordville, GA 30631',9630,222,NULL,13,13341,0);
INSERT INTO "django_geo_db_location" VALUES(23265,NULL,'Danielsville, GA',9631,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23266,NULL,'Danielsville, GA 30633',9631,222,NULL,13,13342,0);
INSERT INTO "django_geo_db_location" VALUES(23267,NULL,'Dewy Rose, GA',9632,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23268,NULL,'Dewy Rose, GA 30634',9632,222,NULL,13,13343,0);
INSERT INTO "django_geo_db_location" VALUES(23269,NULL,'Elberton, GA',9633,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23270,NULL,'Elberton, GA 30635',9633,222,NULL,13,13344,0);
INSERT INTO "django_geo_db_location" VALUES(23271,NULL,'Farmington, GA',9634,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23272,NULL,'Farmington, GA 30638',9634,222,NULL,13,13345,0);
INSERT INTO "django_geo_db_location" VALUES(23273,NULL,'Franklin Springs, GA',9635,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23274,NULL,'Franklin Springs, GA 30639',9635,222,NULL,13,13346,0);
INSERT INTO "django_geo_db_location" VALUES(23275,NULL,'Good Hope, GA',9636,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23276,NULL,'Good Hope, GA 30641',9636,222,NULL,13,13347,0);
INSERT INTO "django_geo_db_location" VALUES(23277,NULL,'Greensboro, GA',9637,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23278,NULL,'Greensboro, GA 30642',9637,222,NULL,13,13348,0);
INSERT INTO "django_geo_db_location" VALUES(23279,NULL,'Hartwell, GA',9638,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23280,NULL,'Hartwell, GA 30643',9638,222,NULL,13,13349,0);
INSERT INTO "django_geo_db_location" VALUES(23281,NULL,'High Shoals, GA',9639,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23282,NULL,'High Shoals, GA 30645',9639,222,NULL,13,13350,0);
INSERT INTO "django_geo_db_location" VALUES(23283,NULL,'Hull, GA',9640,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23284,NULL,'Hull, GA 30646',9640,222,NULL,13,13351,0);
INSERT INTO "django_geo_db_location" VALUES(23285,NULL,'Ila, GA',9641,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23286,NULL,'Ila, GA 30647',9641,222,NULL,13,13352,0);
INSERT INTO "django_geo_db_location" VALUES(23287,NULL,'Lexington, GA',9642,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23288,NULL,'Lexington, GA 30648',9642,222,NULL,13,13353,0);
INSERT INTO "django_geo_db_location" VALUES(23289,NULL,'Madison, GA',9643,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23290,NULL,'Madison, GA 30650',9643,222,NULL,13,13354,0);
INSERT INTO "django_geo_db_location" VALUES(23291,NULL,'Greensboro, GA 30652',9637,222,NULL,13,13355,0);
INSERT INTO "django_geo_db_location" VALUES(23292,NULL,'Monroe, GA',9644,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23293,NULL,'Monroe, GA 30655',9644,222,NULL,13,13356,0);
INSERT INTO "django_geo_db_location" VALUES(23294,NULL,'Monroe, GA 30656',9644,222,NULL,13,13357,0);
INSERT INTO "django_geo_db_location" VALUES(23295,NULL,'Rayle, GA',9645,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23296,NULL,'Rayle, GA 30660',9645,222,NULL,13,13358,0);
INSERT INTO "django_geo_db_location" VALUES(23297,NULL,'Royston, GA',9646,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23298,NULL,'Royston, GA 30662',9646,222,NULL,13,13359,0);
INSERT INTO "django_geo_db_location" VALUES(23299,NULL,'Rutledge, GA',9647,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23300,NULL,'Rutledge, GA 30663',9647,222,NULL,13,13360,0);
INSERT INTO "django_geo_db_location" VALUES(23301,NULL,'Sharon, GA',9648,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23302,NULL,'Sharon, GA 30664',9648,222,NULL,13,13361,0);
INSERT INTO "django_geo_db_location" VALUES(23303,NULL,'Siloam, GA',9649,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23304,NULL,'Siloam, GA 30665',9649,222,NULL,13,13362,0);
INSERT INTO "django_geo_db_location" VALUES(23305,NULL,'Statham, GA',9650,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23306,NULL,'Statham, GA 30666',9650,222,NULL,13,13363,0);
INSERT INTO "django_geo_db_location" VALUES(23307,NULL,'Stephens, GA',9651,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23308,NULL,'Stephens, GA 30667',9651,222,NULL,13,13364,0);
INSERT INTO "django_geo_db_location" VALUES(23309,NULL,'Tignall, GA',9652,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23310,NULL,'Tignall, GA 30668',9652,222,NULL,13,13365,0);
INSERT INTO "django_geo_db_location" VALUES(23311,NULL,'Union Point, GA',9653,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23312,NULL,'Union Point, GA 30669',9653,222,NULL,13,13366,0);
INSERT INTO "django_geo_db_location" VALUES(23313,NULL,'Maxeys, GA',9654,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23314,NULL,'Maxeys, GA 30671',9654,222,NULL,13,13367,0);
INSERT INTO "django_geo_db_location" VALUES(23315,NULL,'Washington, GA',9655,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23316,NULL,'Washington, GA 30673',9655,222,NULL,13,13368,0);
INSERT INTO "django_geo_db_location" VALUES(23317,NULL,'Watkinsville, GA',9656,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23318,NULL,'Watkinsville, GA 30677',9656,222,NULL,13,13369,0);
INSERT INTO "django_geo_db_location" VALUES(23319,NULL,'White Plains, GA',9657,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23320,NULL,'White Plains, GA 30678',9657,222,NULL,13,13370,0);
INSERT INTO "django_geo_db_location" VALUES(23321,NULL,'Winder, GA',9658,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23322,NULL,'Winder, GA 30680',9658,222,NULL,13,13371,0);
INSERT INTO "django_geo_db_location" VALUES(23323,NULL,'Winterville, GA',9659,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23324,NULL,'Winterville, GA 30683',9659,222,NULL,13,13372,0);
INSERT INTO "django_geo_db_location" VALUES(23325,NULL,'Calhoun, GA',9660,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23326,NULL,'Calhoun, GA 30701',9660,222,NULL,13,13373,0);
INSERT INTO "django_geo_db_location" VALUES(23327,NULL,'Calhoun, GA 30703',9660,222,NULL,13,13374,0);
INSERT INTO "django_geo_db_location" VALUES(23328,NULL,'Chatsworth, GA',9661,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23329,NULL,'Chatsworth, GA 30705',9661,222,NULL,13,13375,0);
INSERT INTO "django_geo_db_location" VALUES(23330,NULL,'Chickamauga, GA',9662,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23331,NULL,'Chickamauga, GA 30707',9662,222,NULL,13,13376,0);
INSERT INTO "django_geo_db_location" VALUES(23332,NULL,'Cisco, GA',9663,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23333,NULL,'Cisco, GA 30708',9663,222,NULL,13,13377,0);
INSERT INTO "django_geo_db_location" VALUES(23334,NULL,'Cohutta, GA',9664,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23335,NULL,'Cohutta, GA 30710',9664,222,NULL,13,13378,0);
INSERT INTO "django_geo_db_location" VALUES(23336,NULL,'Crandall, GA',9665,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23337,NULL,'Crandall, GA 30711',9665,222,NULL,13,13379,0);
INSERT INTO "django_geo_db_location" VALUES(23338,NULL,'Tallapoosa, GA 30716',9450,222,NULL,13,13380,0);
INSERT INTO "django_geo_db_location" VALUES(23339,NULL,'Dalton, GA',9666,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23340,NULL,'Dalton, GA 30719',9666,222,NULL,13,13381,0);
INSERT INTO "django_geo_db_location" VALUES(23341,NULL,'Dalton, GA 30720',9666,222,NULL,13,13382,0);
INSERT INTO "django_geo_db_location" VALUES(23342,NULL,'Dalton, GA 30721',9666,222,NULL,13,13383,0);
INSERT INTO "django_geo_db_location" VALUES(23343,NULL,'Dalton, GA 30722',9666,222,NULL,13,13384,0);
INSERT INTO "django_geo_db_location" VALUES(23344,NULL,'Eton, GA',9667,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23345,NULL,'Eton, GA 30724',9667,222,NULL,13,13385,0);
INSERT INTO "django_geo_db_location" VALUES(23346,NULL,'Flintstone, GA',9668,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23347,NULL,'Flintstone, GA 30725',9668,222,NULL,13,13386,0);
INSERT INTO "django_geo_db_location" VALUES(23348,NULL,'Graysville, GA',9669,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23349,NULL,'Graysville, GA 30726',9669,222,NULL,13,13387,0);
INSERT INTO "django_geo_db_location" VALUES(23350,NULL,'La Fayette, GA',9670,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23351,NULL,'La Fayette, GA 30728',9670,222,NULL,13,13388,0);
INSERT INTO "django_geo_db_location" VALUES(23352,NULL,'Lyerly, GA',9671,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23353,NULL,'Lyerly, GA 30730',9671,222,NULL,13,13389,0);
INSERT INTO "django_geo_db_location" VALUES(23354,NULL,'Menlo, GA',9672,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23355,NULL,'Menlo, GA 30731',9672,222,NULL,13,13390,0);
INSERT INTO "django_geo_db_location" VALUES(23356,NULL,'Oakman, GA',9673,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23357,NULL,'Oakman, GA 30732',9673,222,NULL,13,13391,0);
INSERT INTO "django_geo_db_location" VALUES(23358,NULL,'Plainville, GA',9674,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23359,NULL,'Plainville, GA 30733',9674,222,NULL,13,13392,0);
INSERT INTO "django_geo_db_location" VALUES(23360,NULL,'Ranger, GA',9675,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23361,NULL,'Ranger, GA 30734',9675,222,NULL,13,13393,0);
INSERT INTO "django_geo_db_location" VALUES(23362,NULL,'Resaca, GA',9676,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23363,NULL,'Resaca, GA 30735',9676,222,NULL,13,13394,0);
INSERT INTO "django_geo_db_location" VALUES(23364,NULL,'Ringgold, GA',9677,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23365,NULL,'Ringgold, GA 30736',9677,222,NULL,13,13395,0);
INSERT INTO "django_geo_db_location" VALUES(23366,NULL,'Rising Fawn, GA',9678,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23367,NULL,'Rising Fawn, GA 30738',9678,222,NULL,13,13396,0);
INSERT INTO "django_geo_db_location" VALUES(23368,NULL,'Rock Spring, GA',9679,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23369,NULL,'Rock Spring, GA 30739',9679,222,NULL,13,13397,0);
INSERT INTO "django_geo_db_location" VALUES(23370,NULL,'Rocky Face, GA',9680,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23371,NULL,'Rocky Face, GA 30740',9680,222,NULL,13,13398,0);
INSERT INTO "django_geo_db_location" VALUES(23372,NULL,'Rossville, GA',9681,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23373,NULL,'Rossville, GA 30741',9681,222,NULL,13,13399,0);
INSERT INTO "django_geo_db_location" VALUES(23374,NULL,'Fort Oglethorpe, GA',9682,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23375,NULL,'Fort Oglethorpe, GA 30742',9682,222,NULL,13,13400,0);
INSERT INTO "django_geo_db_location" VALUES(23376,NULL,'Sugar Valley, GA',9683,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23377,NULL,'Sugar Valley, GA 30746',9683,222,NULL,13,13401,0);
INSERT INTO "django_geo_db_location" VALUES(23378,NULL,'Summerville, GA',9684,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23379,NULL,'Summerville, GA 30747',9684,222,NULL,13,13402,0);
INSERT INTO "django_geo_db_location" VALUES(23380,NULL,'Lookout Mountain, GA',9685,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23381,NULL,'Lookout Mountain, GA 30750',9685,222,NULL,13,13403,0);
INSERT INTO "django_geo_db_location" VALUES(23382,NULL,'Tennga, GA',9686,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23383,NULL,'Tennga, GA 30751',9686,222,NULL,13,13404,0);
INSERT INTO "django_geo_db_location" VALUES(23384,NULL,'Trenton, GA',9687,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23385,NULL,'Trenton, GA 30752',9687,222,NULL,13,13405,0);
INSERT INTO "django_geo_db_location" VALUES(23386,NULL,'Trion, GA',9688,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23387,NULL,'Trion, GA 30753',9688,222,NULL,13,13406,0);
INSERT INTO "django_geo_db_location" VALUES(23388,NULL,'Summerville, GA 30754',9684,222,NULL,13,13407,0);
INSERT INTO "django_geo_db_location" VALUES(23389,NULL,'Tunnel Hill, GA',9689,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23390,NULL,'Tunnel Hill, GA 30755',9689,222,NULL,13,13408,0);
INSERT INTO "django_geo_db_location" VALUES(23391,NULL,'Varnell, GA',9690,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23392,NULL,'Varnell, GA 30756',9690,222,NULL,13,13409,0);
INSERT INTO "django_geo_db_location" VALUES(23393,NULL,'Wildwood, GA',9691,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23394,NULL,'Wildwood, GA 30757',9691,222,NULL,13,13410,0);
INSERT INTO "django_geo_db_location" VALUES(23395,NULL,'Appling, GA',9692,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23396,NULL,'Appling, GA 30802',9692,222,NULL,13,13411,0);
INSERT INTO "django_geo_db_location" VALUES(23397,NULL,'Avera, GA',9693,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23398,NULL,'Avera, GA 30803',9693,222,NULL,13,13412,0);
INSERT INTO "django_geo_db_location" VALUES(23399,NULL,'Blythe, GA',9694,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23400,NULL,'Blythe, GA 30805',9694,222,NULL,13,13413,0);
INSERT INTO "django_geo_db_location" VALUES(23401,NULL,'Boneville, GA',9695,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23402,NULL,'Boneville, GA 30806',9695,222,NULL,13,13414,0);
INSERT INTO "django_geo_db_location" VALUES(23403,NULL,'Camak, GA',9696,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23404,NULL,'Camak, GA 30807',9696,222,NULL,13,13415,0);
INSERT INTO "django_geo_db_location" VALUES(23405,NULL,'Dearing, GA',9697,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23406,NULL,'Dearing, GA 30808',9697,222,NULL,13,13416,0);
INSERT INTO "django_geo_db_location" VALUES(23407,NULL,'Evans, GA',9698,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23408,NULL,'Evans, GA 30809',9698,222,NULL,13,13417,0);
INSERT INTO "django_geo_db_location" VALUES(23409,NULL,'Gibson, GA',9699,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23410,NULL,'Gibson, GA 30810',9699,222,NULL,13,13418,0);
INSERT INTO "django_geo_db_location" VALUES(23411,NULL,'Gough, GA',9700,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23412,NULL,'Gough, GA 30811',9700,222,NULL,13,13419,0);
INSERT INTO "django_geo_db_location" VALUES(23413,NULL,'Gracewood, GA',9701,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23414,NULL,'Gracewood, GA 30812',9701,222,NULL,13,13420,0);
INSERT INTO "django_geo_db_location" VALUES(23415,NULL,'Grovetown, GA',9702,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23416,NULL,'Grovetown, GA 30813',9702,222,NULL,13,13421,0);
INSERT INTO "django_geo_db_location" VALUES(23417,NULL,'Harlem, GA',9703,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23418,NULL,'Harlem, GA 30814',9703,222,NULL,13,13422,0);
INSERT INTO "django_geo_db_location" VALUES(23419,NULL,'Hephzibah, GA',9704,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23420,NULL,'Hephzibah, GA 30815',9704,222,NULL,13,13423,0);
INSERT INTO "django_geo_db_location" VALUES(23421,NULL,'Keysville, GA',9705,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23422,NULL,'Keysville, GA 30816',9705,222,NULL,13,13424,0);
INSERT INTO "django_geo_db_location" VALUES(23423,NULL,'Lincolnton, GA',9706,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23424,NULL,'Lincolnton, GA 30817',9706,222,NULL,13,13425,0);
INSERT INTO "django_geo_db_location" VALUES(23425,NULL,'Matthews, GA',9707,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23426,NULL,'Matthews, GA 30818',9707,222,NULL,13,13426,0);
INSERT INTO "django_geo_db_location" VALUES(23427,NULL,'Mesena, GA',9708,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23428,NULL,'Mesena, GA 30819',9708,222,NULL,13,13427,0);
INSERT INTO "django_geo_db_location" VALUES(23429,NULL,'Mitchell, GA',9709,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23430,NULL,'Mitchell, GA 30820',9709,222,NULL,13,13428,0);
INSERT INTO "django_geo_db_location" VALUES(23431,NULL,'Norwood, GA',9710,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23432,NULL,'Norwood, GA 30821',9710,222,NULL,13,13429,0);
INSERT INTO "django_geo_db_location" VALUES(23433,NULL,'Perkins, GA',9711,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23434,NULL,'Perkins, GA 30822',9711,222,NULL,13,13430,0);
INSERT INTO "django_geo_db_location" VALUES(23435,NULL,'Stapleton, GA',9712,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23436,NULL,'Stapleton, GA 30823',9712,222,NULL,13,13431,0);
INSERT INTO "django_geo_db_location" VALUES(23437,NULL,'Thomson, GA',9713,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23438,NULL,'Thomson, GA 30824',9713,222,NULL,13,13432,0);
INSERT INTO "django_geo_db_location" VALUES(23439,NULL,'Warrenton, GA',9714,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23440,NULL,'Warrenton, GA 30828',9714,222,NULL,13,13433,0);
INSERT INTO "django_geo_db_location" VALUES(23441,NULL,'Waynesboro, GA',9715,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23442,NULL,'Waynesboro, GA 30830',9715,222,NULL,13,13434,0);
INSERT INTO "django_geo_db_location" VALUES(23443,NULL,'Wrens, GA',9716,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23444,NULL,'Wrens, GA 30833',9716,222,NULL,13,13435,0);
INSERT INTO "django_geo_db_location" VALUES(23445,NULL,'Atlanta, GA 30881',9514,222,NULL,13,13436,0);
INSERT INTO "django_geo_db_location" VALUES(23446,NULL,'Augusta, GA',9717,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23447,NULL,'Augusta, GA 30901',9717,222,NULL,13,13437,0);
INSERT INTO "django_geo_db_location" VALUES(23448,NULL,'Augusta, GA 30903',9717,222,NULL,13,13438,0);
INSERT INTO "django_geo_db_location" VALUES(23449,NULL,'Augusta, GA 30904',9717,222,NULL,13,13439,0);
INSERT INTO "django_geo_db_location" VALUES(23450,NULL,'Augusta, GA 30905',9717,222,NULL,13,13440,0);
INSERT INTO "django_geo_db_location" VALUES(23451,NULL,'Augusta, GA 30906',9717,222,NULL,13,13441,0);
INSERT INTO "django_geo_db_location" VALUES(23452,NULL,'Augusta, GA 30907',9717,222,NULL,13,13442,0);
INSERT INTO "django_geo_db_location" VALUES(23453,NULL,'Augusta, GA 30909',9717,222,NULL,13,13443,0);
INSERT INTO "django_geo_db_location" VALUES(23454,NULL,'Augusta, GA 30910',9717,222,NULL,13,13444,0);
INSERT INTO "django_geo_db_location" VALUES(23455,NULL,'Augusta, GA 30911',9717,222,NULL,13,13445,0);
INSERT INTO "django_geo_db_location" VALUES(23456,NULL,'Augusta, GA 30912',9717,222,NULL,13,13446,0);
INSERT INTO "django_geo_db_location" VALUES(23457,NULL,'Augusta, GA 30913',9717,222,NULL,13,13447,0);
INSERT INTO "django_geo_db_location" VALUES(23458,NULL,'Augusta, GA 30914',9717,222,NULL,13,13448,0);
INSERT INTO "django_geo_db_location" VALUES(23459,NULL,'Augusta, GA 30916',9717,222,NULL,13,13449,0);
INSERT INTO "django_geo_db_location" VALUES(23460,NULL,'Augusta, GA 30917',9717,222,NULL,13,13450,0);
INSERT INTO "django_geo_db_location" VALUES(23461,NULL,'Augusta, GA 30919',9717,222,NULL,13,13451,0);
INSERT INTO "django_geo_db_location" VALUES(23462,NULL,'Augusta, GA 30999',9717,222,NULL,13,13452,0);
INSERT INTO "django_geo_db_location" VALUES(23463,NULL,'Abbeville, GA',9718,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23464,NULL,'Abbeville, GA 31001',9718,222,NULL,13,13453,0);
INSERT INTO "django_geo_db_location" VALUES(23465,NULL,'Adrian, GA',9719,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23466,NULL,'Adrian, GA 31002',9719,222,NULL,13,13454,0);
INSERT INTO "django_geo_db_location" VALUES(23467,NULL,'Allentown, GA',9720,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23468,NULL,'Allentown, GA 31003',9720,222,NULL,13,13455,0);
INSERT INTO "django_geo_db_location" VALUES(23469,NULL,'Bolingbroke, GA',9721,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23470,NULL,'Bolingbroke, GA 31004',9721,222,NULL,13,13456,0);
INSERT INTO "django_geo_db_location" VALUES(23471,NULL,'Bonaire, GA',9722,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23472,NULL,'Bonaire, GA 31005',9722,222,NULL,13,13457,0);
INSERT INTO "django_geo_db_location" VALUES(23473,NULL,'Butler, GA',9723,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23474,NULL,'Butler, GA 31006',9723,222,NULL,13,13458,0);
INSERT INTO "django_geo_db_location" VALUES(23475,NULL,'Byromville, GA',9724,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23476,NULL,'Byromville, GA 31007',9724,222,NULL,13,13459,0);
INSERT INTO "django_geo_db_location" VALUES(23477,NULL,'Byron, GA',9725,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23478,NULL,'Byron, GA 31008',9725,222,NULL,13,13460,0);
INSERT INTO "django_geo_db_location" VALUES(23479,NULL,'Cadwell, GA',9726,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23480,NULL,'Cadwell, GA 31009',9726,222,NULL,13,13461,0);
INSERT INTO "django_geo_db_location" VALUES(23481,NULL,'Cordele, GA',9727,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23482,NULL,'Cordele, GA 31010',9727,222,NULL,13,13462,0);
INSERT INTO "django_geo_db_location" VALUES(23483,NULL,'Chauncey, GA',9728,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23484,NULL,'Chauncey, GA 31011',9728,222,NULL,13,13463,0);
INSERT INTO "django_geo_db_location" VALUES(23485,NULL,'Chester, GA',9729,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23486,NULL,'Chester, GA 31012',9729,222,NULL,13,13464,0);
INSERT INTO "django_geo_db_location" VALUES(23487,NULL,'Clinchfield, GA',9730,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23488,NULL,'Clinchfield, GA 31013',9730,222,NULL,13,13465,0);
INSERT INTO "django_geo_db_location" VALUES(23489,NULL,'Cochran, GA',9731,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23490,NULL,'Cochran, GA 31014',9731,222,NULL,13,13466,0);
INSERT INTO "django_geo_db_location" VALUES(23491,NULL,'Cordele, GA 31015',9727,222,NULL,13,13467,0);
INSERT INTO "django_geo_db_location" VALUES(23492,NULL,'Culloden, GA',9732,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23493,NULL,'Culloden, GA 31016',9732,222,NULL,13,13468,0);
INSERT INTO "django_geo_db_location" VALUES(23494,NULL,'Danville, GA',9733,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23495,NULL,'Danville, GA 31017',9733,222,NULL,13,13469,0);
INSERT INTO "django_geo_db_location" VALUES(23496,NULL,'Davisboro, GA',9734,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23497,NULL,'Davisboro, GA 31018',9734,222,NULL,13,13470,0);
INSERT INTO "django_geo_db_location" VALUES(23498,NULL,'Dexter, GA',9735,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23499,NULL,'Dexter, GA 31019',9735,222,NULL,13,13471,0);
INSERT INTO "django_geo_db_location" VALUES(23500,NULL,'Dry Branch, GA',9736,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23501,NULL,'Dry Branch, GA 31020',9736,222,NULL,13,13472,0);
INSERT INTO "django_geo_db_location" VALUES(23502,NULL,'Dublin, GA',9737,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23503,NULL,'Dublin, GA 31021',9737,222,NULL,13,13473,0);
INSERT INTO "django_geo_db_location" VALUES(23504,NULL,'Dudley, GA',9738,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23505,NULL,'Dudley, GA 31022',9738,222,NULL,13,13474,0);
INSERT INTO "django_geo_db_location" VALUES(23506,NULL,'Eastman, GA',9739,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23507,NULL,'Eastman, GA 31023',9739,222,NULL,13,13475,0);
INSERT INTO "django_geo_db_location" VALUES(23508,NULL,'Eatonton, GA',9740,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23509,NULL,'Eatonton, GA 31024',9740,222,NULL,13,13476,0);
INSERT INTO "django_geo_db_location" VALUES(23510,NULL,'Elko, GA',9741,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23511,NULL,'Elko, GA 31025',9741,222,NULL,13,13477,0);
INSERT INTO "django_geo_db_location" VALUES(23512,NULL,'Dublin, GA 31027',9737,222,NULL,13,13478,0);
INSERT INTO "django_geo_db_location" VALUES(23513,NULL,'Centerville, GA',9742,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23514,NULL,'Centerville, GA 31028',9742,222,NULL,13,13479,0);
INSERT INTO "django_geo_db_location" VALUES(23515,NULL,'Forsyth, GA',9743,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23516,NULL,'Forsyth, GA 31029',9743,222,NULL,13,13480,0);
INSERT INTO "django_geo_db_location" VALUES(23517,NULL,'Fort Valley, GA',9744,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23518,NULL,'Fort Valley, GA 31030',9744,222,NULL,13,13481,0);
INSERT INTO "django_geo_db_location" VALUES(23519,NULL,'Gordon, GA',9745,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23520,NULL,'Gordon, GA 31031',9745,222,NULL,13,13482,0);
INSERT INTO "django_geo_db_location" VALUES(23521,NULL,'Gray, GA',9746,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23522,NULL,'Gray, GA 31032',9746,222,NULL,13,13483,0);
INSERT INTO "django_geo_db_location" VALUES(23523,NULL,'Haddock, GA',9747,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23524,NULL,'Haddock, GA 31033',9747,222,NULL,13,13484,0);
INSERT INTO "django_geo_db_location" VALUES(23525,NULL,'Hardwick, GA',9748,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23526,NULL,'Hardwick, GA 31034',9748,222,NULL,13,13485,0);
INSERT INTO "django_geo_db_location" VALUES(23527,NULL,'Harrison, GA',9749,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23528,NULL,'Harrison, GA 31035',9749,222,NULL,13,13486,0);
INSERT INTO "django_geo_db_location" VALUES(23529,NULL,'Hawkinsville, GA',9750,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23530,NULL,'Hawkinsville, GA 31036',9750,222,NULL,13,13487,0);
INSERT INTO "django_geo_db_location" VALUES(23531,NULL,'Helena, GA',9751,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23532,NULL,'Helena, GA 31037',9751,222,NULL,13,13488,0);
INSERT INTO "django_geo_db_location" VALUES(23533,NULL,'Hillsboro, GA',9752,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23534,NULL,'Hillsboro, GA 31038',9752,222,NULL,13,13489,0);
INSERT INTO "django_geo_db_location" VALUES(23535,NULL,'Howard, GA',9753,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23536,NULL,'Howard, GA 31039',9753,222,NULL,13,13490,0);
INSERT INTO "django_geo_db_location" VALUES(23537,NULL,'Dublin, GA 31040',9737,222,NULL,13,13491,0);
INSERT INTO "django_geo_db_location" VALUES(23538,NULL,'Ideal, GA',9754,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23539,NULL,'Ideal, GA 31041',9754,222,NULL,13,13492,0);
INSERT INTO "django_geo_db_location" VALUES(23540,NULL,'Irwinton, GA',9755,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23541,NULL,'Irwinton, GA 31042',9755,222,NULL,13,13493,0);
INSERT INTO "django_geo_db_location" VALUES(23542,NULL,'Jeffersonville, GA',9756,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23543,NULL,'Jeffersonville, GA 31044',9756,222,NULL,13,13494,0);
INSERT INTO "django_geo_db_location" VALUES(23544,NULL,'Jewell, GA',9757,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23545,NULL,'Jewell, GA 31045',9757,222,NULL,13,13495,0);
INSERT INTO "django_geo_db_location" VALUES(23546,NULL,'Juliette, GA',9758,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23547,NULL,'Juliette, GA 31046',9758,222,NULL,13,13496,0);
INSERT INTO "django_geo_db_location" VALUES(23548,NULL,'Kathleen, GA',9759,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23549,NULL,'Kathleen, GA 31047',9759,222,NULL,13,13497,0);
INSERT INTO "django_geo_db_location" VALUES(23550,NULL,'Kite, GA',9760,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23551,NULL,'Kite, GA 31049',9760,222,NULL,13,13498,0);
INSERT INTO "django_geo_db_location" VALUES(23552,NULL,'Knoxville, GA',9761,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23553,NULL,'Knoxville, GA 31050',9761,222,NULL,13,13499,0);
INSERT INTO "django_geo_db_location" VALUES(23554,NULL,'Lilly, GA',9762,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23555,NULL,'Lilly, GA 31051',9762,222,NULL,13,13500,0);
INSERT INTO "django_geo_db_location" VALUES(23556,NULL,'Lizella, GA',9763,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23557,NULL,'Lizella, GA 31052',9763,222,NULL,13,13501,0);
INSERT INTO "django_geo_db_location" VALUES(23558,NULL,'McIntyre, GA',9764,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23559,NULL,'McIntyre, GA 31054',9764,222,NULL,13,13502,0);
INSERT INTO "django_geo_db_location" VALUES(23560,NULL,'McRae, GA',9765,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23561,NULL,'McRae, GA 31055',9765,222,NULL,13,13503,0);
INSERT INTO "django_geo_db_location" VALUES(23562,NULL,'Marshallville, GA',9766,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23563,NULL,'Marshallville, GA 31057',9766,222,NULL,13,13504,0);
INSERT INTO "django_geo_db_location" VALUES(23564,NULL,'Mauk, GA',9767,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23565,NULL,'Mauk, GA 31058',9767,222,NULL,13,13505,0);
INSERT INTO "django_geo_db_location" VALUES(23566,NULL,'Milan, GA',9768,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23567,NULL,'Milan, GA 31060',9768,222,NULL,13,13506,0);
INSERT INTO "django_geo_db_location" VALUES(23568,NULL,'Milledgeville, GA',9769,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23569,NULL,'Milledgeville, GA 31061',9769,222,NULL,13,13507,0);
INSERT INTO "django_geo_db_location" VALUES(23570,NULL,'Milledgeville, GA 31062',9769,222,NULL,13,13508,0);
INSERT INTO "django_geo_db_location" VALUES(23571,NULL,'Montezuma, GA',9770,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23572,NULL,'Montezuma, GA 31063',9770,222,NULL,13,13509,0);
INSERT INTO "django_geo_db_location" VALUES(23573,NULL,'Monticello, GA',9771,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23574,NULL,'Monticello, GA 31064',9771,222,NULL,13,13510,0);
INSERT INTO "django_geo_db_location" VALUES(23575,NULL,'Montrose, GA',9772,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23576,NULL,'Montrose, GA 31065',9772,222,NULL,13,13511,0);
INSERT INTO "django_geo_db_location" VALUES(23577,NULL,'Musella, GA',9773,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23578,NULL,'Musella, GA 31066',9773,222,NULL,13,13512,0);
INSERT INTO "django_geo_db_location" VALUES(23579,NULL,'Oconee, GA',9774,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23580,NULL,'Oconee, GA 31067',9774,222,NULL,13,13513,0);
INSERT INTO "django_geo_db_location" VALUES(23581,NULL,'Oglethorpe, GA',9775,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23582,NULL,'Oglethorpe, GA 31068',9775,222,NULL,13,13514,0);
INSERT INTO "django_geo_db_location" VALUES(23583,NULL,'Perry, GA',9776,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23584,NULL,'Perry, GA 31069',9776,222,NULL,13,13515,0);
INSERT INTO "django_geo_db_location" VALUES(23585,NULL,'Pinehurst, GA',9777,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23586,NULL,'Pinehurst, GA 31070',9777,222,NULL,13,13516,0);
INSERT INTO "django_geo_db_location" VALUES(23587,NULL,'Pineview, GA',9778,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23588,NULL,'Pineview, GA 31071',9778,222,NULL,13,13517,0);
INSERT INTO "django_geo_db_location" VALUES(23589,NULL,'Pitts, GA',9779,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23590,NULL,'Pitts, GA 31072',9779,222,NULL,13,13518,0);
INSERT INTO "django_geo_db_location" VALUES(23591,NULL,'Plainfield, GA',9780,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23592,NULL,'Plainfield, GA 31073',9780,222,NULL,13,13519,0);
INSERT INTO "django_geo_db_location" VALUES(23593,NULL,'Rentz, GA',9781,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23594,NULL,'Rentz, GA 31075',9781,222,NULL,13,13520,0);
INSERT INTO "django_geo_db_location" VALUES(23595,NULL,'Reynolds, GA',9782,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23596,NULL,'Reynolds, GA 31076',9782,222,NULL,13,13521,0);
INSERT INTO "django_geo_db_location" VALUES(23597,NULL,'Rhine, GA',9783,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23598,NULL,'Rhine, GA 31077',9783,222,NULL,13,13522,0);
INSERT INTO "django_geo_db_location" VALUES(23599,NULL,'Roberta, GA',9784,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23600,NULL,'Roberta, GA 31078',9784,222,NULL,13,13523,0);
INSERT INTO "django_geo_db_location" VALUES(23601,NULL,'Rochelle, GA',9785,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23602,NULL,'Rochelle, GA 31079',9785,222,NULL,13,13524,0);
INSERT INTO "django_geo_db_location" VALUES(23603,NULL,'Rupert, GA',9786,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23604,NULL,'Rupert, GA 31081',9786,222,NULL,13,13525,0);
INSERT INTO "django_geo_db_location" VALUES(23605,NULL,'Sandersville, GA',9787,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23606,NULL,'Sandersville, GA 31082',9787,222,NULL,13,13526,0);
INSERT INTO "django_geo_db_location" VALUES(23607,NULL,'Scotland, GA',9788,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23608,NULL,'Scotland, GA 31083',9788,222,NULL,13,13527,0);
INSERT INTO "django_geo_db_location" VALUES(23609,NULL,'Seville, GA',9789,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23610,NULL,'Seville, GA 31084',9789,222,NULL,13,13528,0);
INSERT INTO "django_geo_db_location" VALUES(23611,NULL,'Shady Dale, GA',9790,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23612,NULL,'Shady Dale, GA 31085',9790,222,NULL,13,13529,0);
INSERT INTO "django_geo_db_location" VALUES(23613,NULL,'Smarr, GA',9791,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23614,NULL,'Smarr, GA 31086',9791,222,NULL,13,13530,0);
INSERT INTO "django_geo_db_location" VALUES(23615,NULL,'Sparta, GA',9792,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23616,NULL,'Sparta, GA 31087',9792,222,NULL,13,13531,0);
INSERT INTO "django_geo_db_location" VALUES(23617,NULL,'Warner Robins, GA',9793,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23618,NULL,'Warner Robins, GA 31088',9793,222,NULL,13,13532,0);
INSERT INTO "django_geo_db_location" VALUES(23619,NULL,'Tennille, GA',9794,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23620,NULL,'Tennille, GA 31089',9794,222,NULL,13,13533,0);
INSERT INTO "django_geo_db_location" VALUES(23621,NULL,'Toomsboro, GA',9795,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23622,NULL,'Toomsboro, GA 31090',9795,222,NULL,13,13534,0);
INSERT INTO "django_geo_db_location" VALUES(23623,NULL,'Unadilla, GA',9796,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23624,NULL,'Unadilla, GA 31091',9796,222,NULL,13,13535,0);
INSERT INTO "django_geo_db_location" VALUES(23625,NULL,'Vienna, GA',9797,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23626,NULL,'Vienna, GA 31092',9797,222,NULL,13,13536,0);
INSERT INTO "django_geo_db_location" VALUES(23627,NULL,'Warner Robins, GA 31093',9793,222,NULL,13,13537,0);
INSERT INTO "django_geo_db_location" VALUES(23628,NULL,'Warthen, GA',9798,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23629,NULL,'Warthen, GA 31094',9798,222,NULL,13,13538,0);
INSERT INTO "django_geo_db_location" VALUES(23630,NULL,'Warner Robins, GA 31095',9793,222,NULL,13,13539,0);
INSERT INTO "django_geo_db_location" VALUES(23631,NULL,'Wrightsville, GA',9799,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23632,NULL,'Wrightsville, GA 31096',9799,222,NULL,13,13540,0);
INSERT INTO "django_geo_db_location" VALUES(23633,NULL,'Yatesville, GA',9800,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23634,NULL,'Yatesville, GA 31097',9800,222,NULL,13,13541,0);
INSERT INTO "django_geo_db_location" VALUES(23635,NULL,'Warner Robins, GA 31098',9793,222,NULL,13,13542,0);
INSERT INTO "django_geo_db_location" VALUES(23636,NULL,'Warner Robins, GA 31099',9793,222,NULL,13,13543,0);
INSERT INTO "django_geo_db_location" VALUES(23637,NULL,'Atlanta, GA 31106',9514,222,NULL,13,13544,0);
INSERT INTO "django_geo_db_location" VALUES(23638,NULL,'Atlanta, GA 31107',9514,222,NULL,13,13545,0);
INSERT INTO "django_geo_db_location" VALUES(23639,NULL,'Atlanta, GA 31119',9514,222,NULL,13,13546,0);
INSERT INTO "django_geo_db_location" VALUES(23640,NULL,'Atlanta, GA 31126',9514,222,NULL,13,13547,0);
INSERT INTO "django_geo_db_location" VALUES(23641,NULL,'Atlanta, GA 31131',9514,222,NULL,13,13548,0);
INSERT INTO "django_geo_db_location" VALUES(23642,NULL,'Atlanta, GA 31139',9514,222,NULL,13,13549,0);
INSERT INTO "django_geo_db_location" VALUES(23643,NULL,'Atlanta, GA 31141',9514,222,NULL,13,13550,0);
INSERT INTO "django_geo_db_location" VALUES(23644,NULL,'Atlanta, GA 31145',9514,222,NULL,13,13551,0);
INSERT INTO "django_geo_db_location" VALUES(23645,NULL,'Atlanta, GA 31146',9514,222,NULL,13,13552,0);
INSERT INTO "django_geo_db_location" VALUES(23646,NULL,'Atlanta, GA 31150',9514,222,NULL,13,13553,0);
INSERT INTO "django_geo_db_location" VALUES(23647,NULL,'Atlanta, GA 31156',9514,222,NULL,13,13554,0);
INSERT INTO "django_geo_db_location" VALUES(23648,NULL,'Atlanta, GA 31191',9514,222,NULL,13,13555,0);
INSERT INTO "django_geo_db_location" VALUES(23649,NULL,'Atlanta, GA 31192',9514,222,NULL,13,13556,0);
INSERT INTO "django_geo_db_location" VALUES(23650,NULL,'Atlanta, GA 31193',9514,222,NULL,13,13557,0);
INSERT INTO "django_geo_db_location" VALUES(23651,NULL,'Atlanta, GA 31195',9514,222,NULL,13,13558,0);
INSERT INTO "django_geo_db_location" VALUES(23652,NULL,'Atlanta, GA 31196',9514,222,NULL,13,13559,0);
INSERT INTO "django_geo_db_location" VALUES(23653,NULL,'Atlanta, GA 31197',9514,222,NULL,13,13560,0);
INSERT INTO "django_geo_db_location" VALUES(23654,NULL,'Atlanta, GA 31198',9514,222,NULL,13,13561,0);
INSERT INTO "django_geo_db_location" VALUES(23655,NULL,'Atlanta, GA 31199',9514,222,NULL,13,13562,0);
INSERT INTO "django_geo_db_location" VALUES(23656,NULL,'Macon, GA',9801,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23657,NULL,'Macon, GA 31201',9801,222,NULL,13,13563,0);
INSERT INTO "django_geo_db_location" VALUES(23658,NULL,'Macon, GA 31202',9801,222,NULL,13,13564,0);
INSERT INTO "django_geo_db_location" VALUES(23659,NULL,'Macon, GA 31203',9801,222,NULL,13,13565,0);
INSERT INTO "django_geo_db_location" VALUES(23660,NULL,'Macon, GA 31204',9801,222,NULL,13,13566,0);
INSERT INTO "django_geo_db_location" VALUES(23661,NULL,'Macon, GA 31205',9801,222,NULL,13,13567,0);
INSERT INTO "django_geo_db_location" VALUES(23662,NULL,'Macon, GA 31206',9801,222,NULL,13,13568,0);
INSERT INTO "django_geo_db_location" VALUES(23663,NULL,'Macon, GA 31207',9801,222,NULL,13,13569,0);
INSERT INTO "django_geo_db_location" VALUES(23664,NULL,'Macon, GA 31208',9801,222,NULL,13,13570,0);
INSERT INTO "django_geo_db_location" VALUES(23665,NULL,'Macon, GA 31209',9801,222,NULL,13,13571,0);
INSERT INTO "django_geo_db_location" VALUES(23666,NULL,'Macon, GA 31210',9801,222,NULL,13,13572,0);
INSERT INTO "django_geo_db_location" VALUES(23667,NULL,'Macon, GA 31211',9801,222,NULL,13,13573,0);
INSERT INTO "django_geo_db_location" VALUES(23668,NULL,'Macon, GA 31212',9801,222,NULL,13,13574,0);
INSERT INTO "django_geo_db_location" VALUES(23669,NULL,'Macon, GA 31213',9801,222,NULL,13,13575,0);
INSERT INTO "django_geo_db_location" VALUES(23670,NULL,'Macon, GA 31216',9801,222,NULL,13,13576,0);
INSERT INTO "django_geo_db_location" VALUES(23671,NULL,'Macon, GA 31217',9801,222,NULL,13,13577,0);
INSERT INTO "django_geo_db_location" VALUES(23672,NULL,'Macon, GA 31220',9801,222,NULL,13,13578,0);
INSERT INTO "django_geo_db_location" VALUES(23673,NULL,'Macon, GA 31221',9801,222,NULL,13,13579,0);
INSERT INTO "django_geo_db_location" VALUES(23674,NULL,'Cecil, GA',9802,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23675,NULL,'Cecil, GA 31267',9802,222,NULL,13,13580,0);
INSERT INTO "django_geo_db_location" VALUES(23676,NULL,'Macon, GA 31294',9801,222,NULL,13,13581,0);
INSERT INTO "django_geo_db_location" VALUES(23677,NULL,'Macon, GA 31295',9801,222,NULL,13,13582,0);
INSERT INTO "django_geo_db_location" VALUES(23678,NULL,'Macon, GA 31296',9801,222,NULL,13,13583,0);
INSERT INTO "django_geo_db_location" VALUES(23679,NULL,'Macon, GA 31297',9801,222,NULL,13,13584,0);
INSERT INTO "django_geo_db_location" VALUES(23680,NULL,'Macon, GA 31298',9801,222,NULL,13,13585,0);
INSERT INTO "django_geo_db_location" VALUES(23681,NULL,'Macon, GA 31299',9801,222,NULL,13,13586,0);
INSERT INTO "django_geo_db_location" VALUES(23682,NULL,'Allenhurst, GA',9803,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23683,NULL,'Allenhurst, GA 31301',9803,222,NULL,13,13587,0);
INSERT INTO "django_geo_db_location" VALUES(23684,NULL,'Bloomingdale, GA',9804,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23685,NULL,'Bloomingdale, GA 31302',9804,222,NULL,13,13588,0);
INSERT INTO "django_geo_db_location" VALUES(23686,NULL,'Clyo, GA',9805,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23687,NULL,'Clyo, GA 31303',9805,222,NULL,13,13589,0);
INSERT INTO "django_geo_db_location" VALUES(23688,NULL,'Crescent, GA',9806,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23689,NULL,'Crescent, GA 31304',9806,222,NULL,13,13590,0);
INSERT INTO "django_geo_db_location" VALUES(23690,NULL,'Darien, GA',9807,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23691,NULL,'Darien, GA 31305',9807,222,NULL,13,13591,0);
INSERT INTO "django_geo_db_location" VALUES(23692,NULL,'Eden, GA',9808,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23693,NULL,'Eden, GA 31307',9808,222,NULL,13,13592,0);
INSERT INTO "django_geo_db_location" VALUES(23694,NULL,'Ellabell, GA',9809,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23695,NULL,'Ellabell, GA 31308',9809,222,NULL,13,13593,0);
INSERT INTO "django_geo_db_location" VALUES(23696,NULL,'Fleming, GA',9810,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23697,NULL,'Fleming, GA 31309',9810,222,NULL,13,13594,0);
INSERT INTO "django_geo_db_location" VALUES(23698,NULL,'Hinesville, GA',9811,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23699,NULL,'Hinesville, GA 31310',9811,222,NULL,13,13595,0);
INSERT INTO "django_geo_db_location" VALUES(23700,NULL,'Guyton, GA',9812,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23701,NULL,'Guyton, GA 31312',9812,222,NULL,13,13596,0);
INSERT INTO "django_geo_db_location" VALUES(23702,NULL,'Hinesville, GA 31313',9811,222,NULL,13,13597,0);
INSERT INTO "django_geo_db_location" VALUES(23703,NULL,'Fort Stewart, GA',9813,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23704,NULL,'Fort Stewart, GA 31314',9813,222,NULL,13,13598,0);
INSERT INTO "django_geo_db_location" VALUES(23705,NULL,'Fort Stewart, GA 31315',9813,222,NULL,13,13599,0);
INSERT INTO "django_geo_db_location" VALUES(23706,NULL,'Ludowici, GA',9814,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23707,NULL,'Ludowici, GA 31316',9814,222,NULL,13,13600,0);
INSERT INTO "django_geo_db_location" VALUES(23708,NULL,'Meldrim, GA',9815,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23709,NULL,'Meldrim, GA 31318',9815,222,NULL,13,13601,0);
INSERT INTO "django_geo_db_location" VALUES(23710,NULL,'Meridian, GA',9816,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23711,NULL,'Meridian, GA 31319',9816,222,NULL,13,13602,0);
INSERT INTO "django_geo_db_location" VALUES(23712,NULL,'Midway, GA',9817,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23713,NULL,'Midway, GA 31320',9817,222,NULL,13,13603,0);
INSERT INTO "django_geo_db_location" VALUES(23714,NULL,'Pembroke, GA',9818,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23715,NULL,'Pembroke, GA 31321',9818,222,NULL,13,13604,0);
INSERT INTO "django_geo_db_location" VALUES(23716,NULL,'Pooler, GA',9819,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23717,NULL,'Pooler, GA 31322',9819,222,NULL,13,13605,0);
INSERT INTO "django_geo_db_location" VALUES(23718,NULL,'Riceboro, GA',9820,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23719,NULL,'Riceboro, GA 31323',9820,222,NULL,13,13606,0);
INSERT INTO "django_geo_db_location" VALUES(23720,NULL,'Richmond Hill, GA',9821,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23721,NULL,'Richmond Hill, GA 31324',9821,222,NULL,13,13607,0);
INSERT INTO "django_geo_db_location" VALUES(23722,NULL,'Rincon, GA',9822,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23723,NULL,'Rincon, GA 31326',9822,222,NULL,13,13608,0);
INSERT INTO "django_geo_db_location" VALUES(23724,NULL,'Sapelo Island, GA',9823,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23725,NULL,'Sapelo Island, GA 31327',9823,222,NULL,13,13609,0);
INSERT INTO "django_geo_db_location" VALUES(23726,NULL,'Tybee Island, GA',9824,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23727,NULL,'Tybee Island, GA 31328',9824,222,NULL,13,13610,0);
INSERT INTO "django_geo_db_location" VALUES(23728,NULL,'Springfield, GA',9825,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23729,NULL,'Springfield, GA 31329',9825,222,NULL,13,13611,0);
INSERT INTO "django_geo_db_location" VALUES(23730,NULL,'Townsend, GA',9826,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23731,NULL,'Townsend, GA 31331',9826,222,NULL,13,13612,0);
INSERT INTO "django_geo_db_location" VALUES(23732,NULL,'Valona, GA',9827,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23733,NULL,'Valona, GA 31332',9827,222,NULL,13,13613,0);
INSERT INTO "django_geo_db_location" VALUES(23734,NULL,'Walthourville, GA',9828,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23735,NULL,'Walthourville, GA 31333',9828,222,NULL,13,13614,0);
INSERT INTO "django_geo_db_location" VALUES(23736,NULL,'Lenox, GA',9829,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23737,NULL,'Lenox, GA 31337',9829,222,NULL,13,13615,0);
INSERT INTO "django_geo_db_location" VALUES(23738,NULL,'Savannah, GA',9830,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23739,NULL,'Savannah, GA 31401',9830,222,NULL,13,13616,0);
INSERT INTO "django_geo_db_location" VALUES(23740,NULL,'Savannah, GA 31402',9830,222,NULL,13,13617,0);
INSERT INTO "django_geo_db_location" VALUES(23741,NULL,'Savannah, GA 31403',9830,222,NULL,13,13618,0);
INSERT INTO "django_geo_db_location" VALUES(23742,NULL,'Savannah, GA 31404',9830,222,NULL,13,13619,0);
INSERT INTO "django_geo_db_location" VALUES(23743,NULL,'Savannah, GA 31405',9830,222,NULL,13,13620,0);
INSERT INTO "django_geo_db_location" VALUES(23744,NULL,'Savannah, GA 31406',9830,222,NULL,13,13621,0);
INSERT INTO "django_geo_db_location" VALUES(23745,NULL,'Savannah, GA 31407',9830,222,NULL,13,13622,0);
INSERT INTO "django_geo_db_location" VALUES(23746,NULL,'Savannah, GA 31408',9830,222,NULL,13,13623,0);
INSERT INTO "django_geo_db_location" VALUES(23747,NULL,'Savannah, GA 31409',9830,222,NULL,13,13624,0);
INSERT INTO "django_geo_db_location" VALUES(23748,NULL,'Savannah, GA 31410',9830,222,NULL,13,13625,0);
INSERT INTO "django_geo_db_location" VALUES(23749,NULL,'Savannah, GA 31411',9830,222,NULL,13,13626,0);
INSERT INTO "django_geo_db_location" VALUES(23750,NULL,'Savannah, GA 31412',9830,222,NULL,13,13627,0);
INSERT INTO "django_geo_db_location" VALUES(23751,NULL,'Savannah, GA 31414',9830,222,NULL,13,13628,0);
INSERT INTO "django_geo_db_location" VALUES(23752,NULL,'Savannah, GA 31415',9830,222,NULL,13,13629,0);
INSERT INTO "django_geo_db_location" VALUES(23753,NULL,'Savannah, GA 31416',9830,222,NULL,13,13630,0);
INSERT INTO "django_geo_db_location" VALUES(23754,NULL,'Savannah, GA 31418',9830,222,NULL,13,13631,0);
INSERT INTO "django_geo_db_location" VALUES(23755,NULL,'Savannah, GA 31419',9830,222,NULL,13,13632,0);
INSERT INTO "django_geo_db_location" VALUES(23756,NULL,'Savannah, GA 31420',9830,222,NULL,13,13633,0);
INSERT INTO "django_geo_db_location" VALUES(23757,NULL,'Savannah, GA 31421',9830,222,NULL,13,13634,0);
INSERT INTO "django_geo_db_location" VALUES(23758,NULL,'Savannah, GA 31422',9830,222,NULL,13,13635,0);
INSERT INTO "django_geo_db_location" VALUES(23759,NULL,'Richmond Hill, GA 31424',9821,222,NULL,13,13636,0);
INSERT INTO "django_geo_db_location" VALUES(23760,NULL,'Savannah, GA 31441',9830,222,NULL,13,13637,0);
INSERT INTO "django_geo_db_location" VALUES(23761,NULL,'Savannah, GA 31498',9830,222,NULL,13,13638,0);
INSERT INTO "django_geo_db_location" VALUES(23762,NULL,'Savannah, GA 31499',9830,222,NULL,13,13639,0);
INSERT INTO "django_geo_db_location" VALUES(23763,NULL,'Waycross, GA',9831,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23764,NULL,'Waycross, GA 31501',9831,222,NULL,13,13640,0);
INSERT INTO "django_geo_db_location" VALUES(23765,NULL,'Waycross, GA 31502',9831,222,NULL,13,13641,0);
INSERT INTO "django_geo_db_location" VALUES(23766,NULL,'Waycross, GA 31503',9831,222,NULL,13,13642,0);
INSERT INTO "django_geo_db_location" VALUES(23767,NULL,'Marshallville, GA 31507',9766,222,NULL,13,13643,0);
INSERT INTO "django_geo_db_location" VALUES(23768,NULL,'Alma, GA',9832,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23769,NULL,'Alma, GA 31510',9832,222,NULL,13,13644,0);
INSERT INTO "django_geo_db_location" VALUES(23770,NULL,'Ambrose, GA',9833,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23771,NULL,'Ambrose, GA 31512',9833,222,NULL,13,13645,0);
INSERT INTO "django_geo_db_location" VALUES(23772,NULL,'Baxley, GA',9834,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23773,NULL,'Baxley, GA 31513',9834,222,NULL,13,13646,0);
INSERT INTO "django_geo_db_location" VALUES(23774,NULL,'Baxley, GA 31515',9834,222,NULL,13,13647,0);
INSERT INTO "django_geo_db_location" VALUES(23775,NULL,'Blackshear, GA',9835,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23776,NULL,'Blackshear, GA 31516',9835,222,NULL,13,13648,0);
INSERT INTO "django_geo_db_location" VALUES(23777,NULL,'Bristol, GA',9836,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23778,NULL,'Bristol, GA 31518',9836,222,NULL,13,13649,0);
INSERT INTO "django_geo_db_location" VALUES(23779,NULL,'Broxton, GA',9837,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23780,NULL,'Broxton, GA 31519',9837,222,NULL,13,13650,0);
INSERT INTO "django_geo_db_location" VALUES(23781,NULL,'Brunswick, GA',9838,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23782,NULL,'Brunswick, GA 31520',9838,222,NULL,13,13651,0);
INSERT INTO "django_geo_db_location" VALUES(23783,NULL,'Brunswick, GA 31521',9838,222,NULL,13,13652,0);
INSERT INTO "django_geo_db_location" VALUES(23784,NULL,'Saint Simons Island, GA',9839,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23785,NULL,'Saint Simons Island, GA 31522',9839,222,NULL,13,13653,0);
INSERT INTO "django_geo_db_location" VALUES(23786,NULL,'Brunswick, GA 31523',9838,222,NULL,13,13654,0);
INSERT INTO "django_geo_db_location" VALUES(23787,NULL,'Brunswick, GA 31524',9838,222,NULL,13,13655,0);
INSERT INTO "django_geo_db_location" VALUES(23788,NULL,'Brunswick, GA 31525',9838,222,NULL,13,13656,0);
INSERT INTO "django_geo_db_location" VALUES(23789,NULL,'Jekyll Island, GA',9840,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23790,NULL,'Jekyll Island, GA 31527',9840,222,NULL,13,13657,0);
INSERT INTO "django_geo_db_location" VALUES(23791,NULL,'Denton, GA',9841,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23792,NULL,'Denton, GA 31532',9841,222,NULL,13,13658,0);
INSERT INTO "django_geo_db_location" VALUES(23793,NULL,'Douglas, GA',9842,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23794,NULL,'Douglas, GA 31533',9842,222,NULL,13,13659,0);
INSERT INTO "django_geo_db_location" VALUES(23795,NULL,'Douglas, GA 31534',9842,222,NULL,13,13660,0);
INSERT INTO "django_geo_db_location" VALUES(23796,NULL,'Douglas, GA 31535',9842,222,NULL,13,13661,0);
INSERT INTO "django_geo_db_location" VALUES(23797,NULL,'Folkston, GA',9843,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23798,NULL,'Folkston, GA 31537',9843,222,NULL,13,13662,0);
INSERT INTO "django_geo_db_location" VALUES(23799,NULL,'Hazlehurst, GA',9844,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23800,NULL,'Hazlehurst, GA 31539',9844,222,NULL,13,13663,0);
INSERT INTO "django_geo_db_location" VALUES(23801,NULL,'Hoboken, GA',9845,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23802,NULL,'Hoboken, GA 31542',9845,222,NULL,13,13664,0);
INSERT INTO "django_geo_db_location" VALUES(23803,NULL,'Hortense, GA',9846,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23804,NULL,'Hortense, GA 31543',9846,222,NULL,13,13665,0);
INSERT INTO "django_geo_db_location" VALUES(23805,NULL,'Jacksonville, GA',9847,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23806,NULL,'Jacksonville, GA 31544',9847,222,NULL,13,13666,0);
INSERT INTO "django_geo_db_location" VALUES(23807,NULL,'Jesup, GA',9848,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23808,NULL,'Jesup, GA 31545',9848,222,NULL,13,13667,0);
INSERT INTO "django_geo_db_location" VALUES(23809,NULL,'Jesup, GA 31546',9848,222,NULL,13,13668,0);
INSERT INTO "django_geo_db_location" VALUES(23810,NULL,'Kings Bay, GA',9849,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23811,NULL,'Kings Bay, GA 31547',9849,222,NULL,13,13669,0);
INSERT INTO "django_geo_db_location" VALUES(23812,NULL,'Kingsland, GA',9850,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23813,NULL,'Kingsland, GA 31548',9850,222,NULL,13,13670,0);
INSERT INTO "django_geo_db_location" VALUES(23814,NULL,'Lumber City, GA',9851,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23815,NULL,'Lumber City, GA 31549',9851,222,NULL,13,13671,0);
INSERT INTO "django_geo_db_location" VALUES(23816,NULL,'Manor, GA',9852,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23817,NULL,'Manor, GA 31550',9852,222,NULL,13,13672,0);
INSERT INTO "django_geo_db_location" VALUES(23818,NULL,'Mershon, GA',9853,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23819,NULL,'Mershon, GA 31551',9853,222,NULL,13,13673,0);
INSERT INTO "django_geo_db_location" VALUES(23820,NULL,'Millwood, GA',9854,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23821,NULL,'Millwood, GA 31552',9854,222,NULL,13,13674,0);
INSERT INTO "django_geo_db_location" VALUES(23822,NULL,'Nahunta, GA',9855,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23823,NULL,'Nahunta, GA 31553',9855,222,NULL,13,13675,0);
INSERT INTO "django_geo_db_location" VALUES(23824,NULL,'Nicholls, GA',9856,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23825,NULL,'Nicholls, GA 31554',9856,222,NULL,13,13676,0);
INSERT INTO "django_geo_db_location" VALUES(23826,NULL,'Odum, GA',9857,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23827,NULL,'Odum, GA 31555',9857,222,NULL,13,13677,0);
INSERT INTO "django_geo_db_location" VALUES(23828,NULL,'Offerman, GA',9858,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23829,NULL,'Offerman, GA 31556',9858,222,NULL,13,13678,0);
INSERT INTO "django_geo_db_location" VALUES(23830,NULL,'Patterson, GA',9859,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23831,NULL,'Patterson, GA 31557',9859,222,NULL,13,13679,0);
INSERT INTO "django_geo_db_location" VALUES(23832,NULL,'Saint Marys, GA',9860,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23833,NULL,'Saint Marys, GA 31558',9860,222,NULL,13,13680,0);
INSERT INTO "django_geo_db_location" VALUES(23834,NULL,'Screven, GA',9861,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23835,NULL,'Screven, GA 31560',9861,222,NULL,13,13681,0);
INSERT INTO "django_geo_db_location" VALUES(23836,NULL,'Sea Island, GA',9862,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23837,NULL,'Sea Island, GA 31561',9862,222,NULL,13,13682,0);
INSERT INTO "django_geo_db_location" VALUES(23838,NULL,'Surrency, GA',9863,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23839,NULL,'Surrency, GA 31563',9863,222,NULL,13,13683,0);
INSERT INTO "django_geo_db_location" VALUES(23840,NULL,'Waresboro, GA',9864,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23841,NULL,'Waresboro, GA 31564',9864,222,NULL,13,13684,0);
INSERT INTO "django_geo_db_location" VALUES(23842,NULL,'Waverly, GA',9865,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23843,NULL,'Waverly, GA 31565',9865,222,NULL,13,13685,0);
INSERT INTO "django_geo_db_location" VALUES(23844,NULL,'Waynesville, GA',9866,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23845,NULL,'Waynesville, GA 31566',9866,222,NULL,13,13686,0);
INSERT INTO "django_geo_db_location" VALUES(23846,NULL,'West Green, GA',9867,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23847,NULL,'West Green, GA 31567',9867,222,NULL,13,13687,0);
INSERT INTO "django_geo_db_location" VALUES(23848,NULL,'White Oak, GA',9868,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23849,NULL,'White Oak, GA 31568',9868,222,NULL,13,13688,0);
INSERT INTO "django_geo_db_location" VALUES(23850,NULL,'Woodbine, GA',9869,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23851,NULL,'Woodbine, GA 31569',9869,222,NULL,13,13689,0);
INSERT INTO "django_geo_db_location" VALUES(23852,NULL,'Jesup, GA 31598',9848,222,NULL,13,13690,0);
INSERT INTO "django_geo_db_location" VALUES(23853,NULL,'Jesup, GA 31599',9848,222,NULL,13,13691,0);
INSERT INTO "django_geo_db_location" VALUES(23854,NULL,'Valdosta, GA',9870,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23855,NULL,'Valdosta, GA 31601',9870,222,NULL,13,13692,0);
INSERT INTO "django_geo_db_location" VALUES(23856,NULL,'Valdosta, GA 31602',9870,222,NULL,13,13693,0);
INSERT INTO "django_geo_db_location" VALUES(23857,NULL,'Valdosta, GA 31603',9870,222,NULL,13,13694,0);
INSERT INTO "django_geo_db_location" VALUES(23858,NULL,'Valdosta, GA 31604',9870,222,NULL,13,13695,0);
INSERT INTO "django_geo_db_location" VALUES(23859,NULL,'Valdosta, GA 31605',9870,222,NULL,13,13696,0);
INSERT INTO "django_geo_db_location" VALUES(23860,NULL,'Valdosta, GA 31606',9870,222,NULL,13,13697,0);
INSERT INTO "django_geo_db_location" VALUES(23861,NULL,'Valdosta, GA 31607',9870,222,NULL,13,13698,0);
INSERT INTO "django_geo_db_location" VALUES(23862,NULL,'Sparks, GA',9871,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23863,NULL,'Sparks, GA 31610',9871,222,NULL,13,13699,0);
INSERT INTO "django_geo_db_location" VALUES(23864,NULL,'Adel, GA',9872,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23865,NULL,'Adel, GA 31620',9872,222,NULL,13,13700,0);
INSERT INTO "django_geo_db_location" VALUES(23866,NULL,'Alapaha, GA',9873,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23867,NULL,'Alapaha, GA 31622',9873,222,NULL,13,13701,0);
INSERT INTO "django_geo_db_location" VALUES(23868,NULL,'Argyle, GA',9874,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23869,NULL,'Argyle, GA 31623',9874,222,NULL,13,13702,0);
INSERT INTO "django_geo_db_location" VALUES(23870,NULL,'Axson, GA',9875,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23871,NULL,'Axson, GA 31624',9875,222,NULL,13,13703,0);
INSERT INTO "django_geo_db_location" VALUES(23872,NULL,'Barney, GA',9876,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23873,NULL,'Barney, GA 31625',9876,222,NULL,13,13704,0);
INSERT INTO "django_geo_db_location" VALUES(23874,NULL,'Boston, GA',9877,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23875,NULL,'Boston, GA 31626',9877,222,NULL,13,13705,0);
INSERT INTO "django_geo_db_location" VALUES(23876,NULL,'Cecil, GA 31627',9802,222,NULL,13,13706,0);
INSERT INTO "django_geo_db_location" VALUES(23877,NULL,'Dixie, GA',9878,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23878,NULL,'Dixie, GA 31629',9878,222,NULL,13,13707,0);
INSERT INTO "django_geo_db_location" VALUES(23879,NULL,'Du Pont, GA',9879,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23880,NULL,'Du Pont, GA 31630',9879,222,NULL,13,13708,0);
INSERT INTO "django_geo_db_location" VALUES(23881,NULL,'Fargo, GA',9880,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23882,NULL,'Fargo, GA 31631',9880,222,NULL,13,13709,0);
INSERT INTO "django_geo_db_location" VALUES(23883,NULL,'Hahira, GA',9881,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23884,NULL,'Hahira, GA 31632',9881,222,NULL,13,13710,0);
INSERT INTO "django_geo_db_location" VALUES(23885,NULL,'Homerville, GA',9882,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23886,NULL,'Homerville, GA 31634',9882,222,NULL,13,13711,0);
INSERT INTO "django_geo_db_location" VALUES(23887,NULL,'Lakeland, GA',9883,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23888,NULL,'Lakeland, GA 31635',9883,222,NULL,13,13712,0);
INSERT INTO "django_geo_db_location" VALUES(23889,NULL,'Lake Park, GA',9884,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23890,NULL,'Lake Park, GA 31636',9884,222,NULL,13,13713,0);
INSERT INTO "django_geo_db_location" VALUES(23891,NULL,'Lenox, GA 31637',9829,222,NULL,13,13714,0);
INSERT INTO "django_geo_db_location" VALUES(23892,NULL,'Morven, GA',9885,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23893,NULL,'Morven, GA 31638',9885,222,NULL,13,13715,0);
INSERT INTO "django_geo_db_location" VALUES(23894,NULL,'Nashville, GA',9886,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23895,NULL,'Nashville, GA 31639',9886,222,NULL,13,13716,0);
INSERT INTO "django_geo_db_location" VALUES(23896,NULL,'Naylor, GA',9887,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23897,NULL,'Naylor, GA 31641',9887,222,NULL,13,13717,0);
INSERT INTO "django_geo_db_location" VALUES(23898,NULL,'Pearson, GA',9888,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23899,NULL,'Pearson, GA 31642',9888,222,NULL,13,13718,0);
INSERT INTO "django_geo_db_location" VALUES(23900,NULL,'Quitman, GA',9889,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23901,NULL,'Quitman, GA 31643',9889,222,NULL,13,13719,0);
INSERT INTO "django_geo_db_location" VALUES(23902,NULL,'Ray City, GA',9890,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23903,NULL,'Ray City, GA 31645',9890,222,NULL,13,13720,0);
INSERT INTO "django_geo_db_location" VALUES(23904,NULL,'Saint George, GA',9891,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23905,NULL,'Saint George, GA 31646',9891,222,NULL,13,13721,0);
INSERT INTO "django_geo_db_location" VALUES(23906,NULL,'Sparks, GA 31647',9871,222,NULL,13,13722,0);
INSERT INTO "django_geo_db_location" VALUES(23907,NULL,'Statenville, GA',9892,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23908,NULL,'Statenville, GA 31648',9892,222,NULL,13,13723,0);
INSERT INTO "django_geo_db_location" VALUES(23909,NULL,'Stockton, GA',9893,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23910,NULL,'Stockton, GA 31649',9893,222,NULL,13,13724,0);
INSERT INTO "django_geo_db_location" VALUES(23911,NULL,'Willacoochee, GA',9894,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23912,NULL,'Willacoochee, GA 31650',9894,222,NULL,13,13725,0);
INSERT INTO "django_geo_db_location" VALUES(23913,NULL,'Nashville, GA 31659',9886,222,NULL,13,13726,0);
INSERT INTO "django_geo_db_location" VALUES(23914,NULL,'Valdosta, GA 31698',9870,222,NULL,13,13727,0);
INSERT INTO "django_geo_db_location" VALUES(23915,NULL,'Valdosta, GA 31699',9870,222,NULL,13,13728,0);
INSERT INTO "django_geo_db_location" VALUES(23916,NULL,'Albany, GA',9895,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23917,NULL,'Albany, GA 31700',9895,222,NULL,13,13729,0);
INSERT INTO "django_geo_db_location" VALUES(23918,NULL,'Albany, GA 31701',9895,222,NULL,13,13730,0);
INSERT INTO "django_geo_db_location" VALUES(23919,NULL,'Albany, GA 31702',9895,222,NULL,13,13731,0);
INSERT INTO "django_geo_db_location" VALUES(23920,NULL,'Albany, GA 31703',9895,222,NULL,13,13732,0);
INSERT INTO "django_geo_db_location" VALUES(23921,NULL,'Albany, GA 31704',9895,222,NULL,13,13733,0);
INSERT INTO "django_geo_db_location" VALUES(23922,NULL,'Albany, GA 31705',9895,222,NULL,13,13734,0);
INSERT INTO "django_geo_db_location" VALUES(23923,NULL,'Albany, GA 31706',9895,222,NULL,13,13735,0);
INSERT INTO "django_geo_db_location" VALUES(23924,NULL,'Albany, GA 31707',9895,222,NULL,13,13736,0);
INSERT INTO "django_geo_db_location" VALUES(23925,NULL,'Albany, GA 31708',9895,222,NULL,13,13737,0);
INSERT INTO "django_geo_db_location" VALUES(23926,NULL,'Americus, GA',9896,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23927,NULL,'Americus, GA 31709',9896,222,NULL,13,13738,0);
INSERT INTO "django_geo_db_location" VALUES(23928,NULL,'Americus, GA 31710',9896,222,NULL,13,13739,0);
INSERT INTO "django_geo_db_location" VALUES(23929,NULL,'Andersonville, GA',9897,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23930,NULL,'Andersonville, GA 31711',9897,222,NULL,13,13740,0);
INSERT INTO "django_geo_db_location" VALUES(23931,NULL,'Arabi, GA',9898,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23932,NULL,'Arabi, GA 31712',9898,222,NULL,13,13741,0);
INSERT INTO "django_geo_db_location" VALUES(23933,NULL,'Arlington, GA',9899,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23934,NULL,'Arlington, GA 31713',9899,222,NULL,13,13742,0);
INSERT INTO "django_geo_db_location" VALUES(23935,NULL,'Ashburn, GA',9900,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23936,NULL,'Ashburn, GA 31714',9900,222,NULL,13,13743,0);
INSERT INTO "django_geo_db_location" VALUES(23937,NULL,'Attapulgus, GA',9901,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23938,NULL,'Attapulgus, GA 31715',9901,222,NULL,13,13744,0);
INSERT INTO "django_geo_db_location" VALUES(23939,NULL,'Baconton, GA',9902,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23940,NULL,'Baconton, GA 31716',9902,222,NULL,13,13745,0);
INSERT INTO "django_geo_db_location" VALUES(23941,NULL,'Bainbridge, GA',9903,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23942,NULL,'Bainbridge, GA 31717',9903,222,NULL,13,13746,0);
INSERT INTO "django_geo_db_location" VALUES(23943,NULL,'Bainbridge, GA 31718',9903,222,NULL,13,13747,0);
INSERT INTO "django_geo_db_location" VALUES(23944,NULL,'Americus, GA 31719',9896,222,NULL,13,13748,0);
INSERT INTO "django_geo_db_location" VALUES(23945,NULL,'Barwick, GA',9904,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23946,NULL,'Barwick, GA 31720',9904,222,NULL,13,13749,0);
INSERT INTO "django_geo_db_location" VALUES(23947,NULL,'Albany, GA 31721',9895,222,NULL,13,13750,0);
INSERT INTO "django_geo_db_location" VALUES(23948,NULL,'Berlin, GA',9905,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23949,NULL,'Berlin, GA 31722',9905,222,NULL,13,13751,0);
INSERT INTO "django_geo_db_location" VALUES(23950,NULL,'Blakely, GA',9906,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23951,NULL,'Blakely, GA 31723',9906,222,NULL,13,13752,0);
INSERT INTO "django_geo_db_location" VALUES(23952,NULL,'Bluffton, GA',9907,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23953,NULL,'Bluffton, GA 31724',9907,222,NULL,13,13753,0);
INSERT INTO "django_geo_db_location" VALUES(23954,NULL,'Brinson, GA',9908,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23955,NULL,'Brinson, GA 31725',9908,222,NULL,13,13754,0);
INSERT INTO "django_geo_db_location" VALUES(23956,NULL,'Bronwood, GA',9909,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23957,NULL,'Bronwood, GA 31726',9909,222,NULL,13,13755,0);
INSERT INTO "django_geo_db_location" VALUES(23958,NULL,'Brookfield, GA',9910,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23959,NULL,'Brookfield, GA 31727',9910,222,NULL,13,13756,0);
INSERT INTO "django_geo_db_location" VALUES(23960,NULL,'Cairo, GA',9911,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23961,NULL,'Cairo, GA 31728',9911,222,NULL,13,13757,0);
INSERT INTO "django_geo_db_location" VALUES(23962,NULL,'Calvary, GA',9912,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23963,NULL,'Calvary, GA 31729',9912,222,NULL,13,13758,0);
INSERT INTO "django_geo_db_location" VALUES(23964,NULL,'Camilla, GA',9913,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23965,NULL,'Camilla, GA 31730',9913,222,NULL,13,13759,0);
INSERT INTO "django_geo_db_location" VALUES(23966,NULL,'Cedar Springs, GA',9914,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23967,NULL,'Cedar Springs, GA 31732',9914,222,NULL,13,13760,0);
INSERT INTO "django_geo_db_location" VALUES(23968,NULL,'Chula, GA',9915,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23969,NULL,'Chula, GA 31733',9915,222,NULL,13,13761,0);
INSERT INTO "django_geo_db_location" VALUES(23970,NULL,'Climax, GA',9916,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23971,NULL,'Climax, GA 31734',9916,222,NULL,13,13762,0);
INSERT INTO "django_geo_db_location" VALUES(23972,NULL,'Cobb, GA',9917,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23973,NULL,'Cobb, GA 31735',9917,222,NULL,13,13763,0);
INSERT INTO "django_geo_db_location" VALUES(23974,NULL,'Coleman, GA',9918,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23975,NULL,'Coleman, GA 31736',9918,222,NULL,13,13764,0);
INSERT INTO "django_geo_db_location" VALUES(23976,NULL,'Colquitt, GA',9919,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23977,NULL,'Colquitt, GA 31737',9919,222,NULL,13,13765,0);
INSERT INTO "django_geo_db_location" VALUES(23978,NULL,'Coolidge, GA',9920,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23979,NULL,'Coolidge, GA 31738',9920,222,NULL,13,13766,0);
INSERT INTO "django_geo_db_location" VALUES(23980,NULL,'Cotton, GA',9921,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23981,NULL,'Cotton, GA 31739',9921,222,NULL,13,13767,0);
INSERT INTO "django_geo_db_location" VALUES(23982,NULL,'Cuthbert, GA',9922,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23983,NULL,'Cuthbert, GA 31740',9922,222,NULL,13,13768,0);
INSERT INTO "django_geo_db_location" VALUES(23984,NULL,'Damascus, GA',9923,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23985,NULL,'Damascus, GA 31741',9923,222,NULL,13,13769,0);
INSERT INTO "django_geo_db_location" VALUES(23986,NULL,'Dawson, GA',9924,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23987,NULL,'Dawson, GA 31742',9924,222,NULL,13,13770,0);
INSERT INTO "django_geo_db_location" VALUES(23988,NULL,'De Soto, GA',9925,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23989,NULL,'De Soto, GA 31743',9925,222,NULL,13,13771,0);
INSERT INTO "django_geo_db_location" VALUES(23990,NULL,'Doerun, GA',9926,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23991,NULL,'Doerun, GA 31744',9926,222,NULL,13,13772,0);
INSERT INTO "django_geo_db_location" VALUES(23992,NULL,'Donalsonville, GA',9927,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23993,NULL,'Donalsonville, GA 31745',9927,222,NULL,13,13773,0);
INSERT INTO "django_geo_db_location" VALUES(23994,NULL,'Edison, GA',9928,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23995,NULL,'Edison, GA 31746',9928,222,NULL,13,13774,0);
INSERT INTO "django_geo_db_location" VALUES(23996,NULL,'Ellenton, GA',9929,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23997,NULL,'Ellenton, GA 31747',9929,222,NULL,13,13775,0);
INSERT INTO "django_geo_db_location" VALUES(23998,NULL,'Enigma, GA',9930,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(23999,NULL,'Enigma, GA 31749',9930,222,NULL,13,13776,0);
INSERT INTO "django_geo_db_location" VALUES(24000,NULL,'Fitzgerald, GA',9931,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24001,NULL,'Fitzgerald, GA 31750',9931,222,NULL,13,13777,0);
INSERT INTO "django_geo_db_location" VALUES(24002,NULL,'Fort Gaines, GA',9932,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24003,NULL,'Fort Gaines, GA 31751',9932,222,NULL,13,13778,0);
INSERT INTO "django_geo_db_location" VALUES(24004,NULL,'Fowlstown, GA',9933,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24005,NULL,'Fowlstown, GA 31752',9933,222,NULL,13,13779,0);
INSERT INTO "django_geo_db_location" VALUES(24006,NULL,'Funston, GA',9934,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24007,NULL,'Funston, GA 31753',9934,222,NULL,13,13780,0);
INSERT INTO "django_geo_db_location" VALUES(24008,NULL,'Georgetown, GA',9935,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24009,NULL,'Georgetown, GA 31754',9935,222,NULL,13,13781,0);
INSERT INTO "django_geo_db_location" VALUES(24010,NULL,'Hartsfield, GA',9936,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24011,NULL,'Hartsfield, GA 31756',9936,222,NULL,13,13782,0);
INSERT INTO "django_geo_db_location" VALUES(24012,NULL,'Thomasville, GA',9937,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24013,NULL,'Thomasville, GA 31757',9937,222,NULL,13,13783,0);
INSERT INTO "django_geo_db_location" VALUES(24014,NULL,'Thomasville, GA 31758',9937,222,NULL,13,13784,0);
INSERT INTO "django_geo_db_location" VALUES(24015,NULL,'Iron City, GA',9938,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24016,NULL,'Iron City, GA 31759',9938,222,NULL,13,13785,0);
INSERT INTO "django_geo_db_location" VALUES(24017,NULL,'Irwinville, GA',9939,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24018,NULL,'Irwinville, GA 31760',9939,222,NULL,13,13786,0);
INSERT INTO "django_geo_db_location" VALUES(24019,NULL,'Jakin, GA',9940,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24020,NULL,'Jakin, GA 31761',9940,222,NULL,13,13787,0);
INSERT INTO "django_geo_db_location" VALUES(24021,NULL,'Leary, GA',9941,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24022,NULL,'Leary, GA 31762',9941,222,NULL,13,13788,0);
INSERT INTO "django_geo_db_location" VALUES(24023,NULL,'Leesburg, GA',9942,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24024,NULL,'Leesburg, GA 31763',9942,222,NULL,13,13789,0);
INSERT INTO "django_geo_db_location" VALUES(24025,NULL,'Leslie, GA',9943,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24026,NULL,'Leslie, GA 31764',9943,222,NULL,13,13790,0);
INSERT INTO "django_geo_db_location" VALUES(24027,NULL,'Meigs, GA',9944,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24028,NULL,'Meigs, GA 31765',9944,222,NULL,13,13791,0);
INSERT INTO "django_geo_db_location" VALUES(24029,NULL,'Morgan, GA',9945,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24030,NULL,'Morgan, GA 31766',9945,222,NULL,13,13792,0);
INSERT INTO "django_geo_db_location" VALUES(24031,NULL,'Morris, GA',9946,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24032,NULL,'Morris, GA 31767',9946,222,NULL,13,13793,0);
INSERT INTO "django_geo_db_location" VALUES(24033,NULL,'Moultrie, GA',9947,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24034,NULL,'Moultrie, GA 31768',9947,222,NULL,13,13794,0);
INSERT INTO "django_geo_db_location" VALUES(24035,NULL,'Mystic, GA',9948,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24036,NULL,'Mystic, GA 31769',9948,222,NULL,13,13795,0);
INSERT INTO "django_geo_db_location" VALUES(24037,NULL,'Newton, GA',9949,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24038,NULL,'Newton, GA 31770',9949,222,NULL,13,13796,0);
INSERT INTO "django_geo_db_location" VALUES(24039,NULL,'Norman Park, GA',9950,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24040,NULL,'Norman Park, GA 31771',9950,222,NULL,13,13797,0);
INSERT INTO "django_geo_db_location" VALUES(24041,NULL,'Oakfield, GA',9951,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24042,NULL,'Oakfield, GA 31772',9951,222,NULL,13,13798,0);
INSERT INTO "django_geo_db_location" VALUES(24043,NULL,'Ochlocknee, GA',9952,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24044,NULL,'Ochlocknee, GA 31773',9952,222,NULL,13,13799,0);
INSERT INTO "django_geo_db_location" VALUES(24045,NULL,'Ocilla, GA',9953,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24046,NULL,'Ocilla, GA 31774',9953,222,NULL,13,13800,0);
INSERT INTO "django_geo_db_location" VALUES(24047,NULL,'Omega, GA',9954,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24048,NULL,'Omega, GA 31775',9954,222,NULL,13,13801,0);
INSERT INTO "django_geo_db_location" VALUES(24049,NULL,'Moultrie, GA 31776',9947,222,NULL,13,13802,0);
INSERT INTO "django_geo_db_location" VALUES(24050,NULL,'Parrott, GA',9955,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24051,NULL,'Parrott, GA 31777',9955,222,NULL,13,13803,0);
INSERT INTO "django_geo_db_location" VALUES(24052,NULL,'Pavo, GA',9956,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24053,NULL,'Pavo, GA 31778',9956,222,NULL,13,13804,0);
INSERT INTO "django_geo_db_location" VALUES(24054,NULL,'Pelham, GA',9957,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24055,NULL,'Pelham, GA 31779',9957,222,NULL,13,13805,0);
INSERT INTO "django_geo_db_location" VALUES(24056,NULL,'Plains, GA',9958,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24057,NULL,'Plains, GA 31780',9958,222,NULL,13,13806,0);
INSERT INTO "django_geo_db_location" VALUES(24058,NULL,'Poulan, GA',9959,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24059,NULL,'Poulan, GA 31781',9959,222,NULL,13,13807,0);
INSERT INTO "django_geo_db_location" VALUES(24060,NULL,'Putney, GA',9960,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24061,NULL,'Putney, GA 31782',9960,222,NULL,13,13808,0);
INSERT INTO "django_geo_db_location" VALUES(24062,NULL,'Rebecca, GA',9961,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24063,NULL,'Rebecca, GA 31783',9961,222,NULL,13,13809,0);
INSERT INTO "django_geo_db_location" VALUES(24064,NULL,'Sale City, GA',9962,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24065,NULL,'Sale City, GA 31784',9962,222,NULL,13,13810,0);
INSERT INTO "django_geo_db_location" VALUES(24066,NULL,'Sasser, GA',9963,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24067,NULL,'Sasser, GA 31785',9963,222,NULL,13,13811,0);
INSERT INTO "django_geo_db_location" VALUES(24068,NULL,'Shellman, GA',9964,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24069,NULL,'Shellman, GA 31786',9964,222,NULL,13,13812,0);
INSERT INTO "django_geo_db_location" VALUES(24070,NULL,'Smithville, GA',9965,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24071,NULL,'Smithville, GA 31787',9965,222,NULL,13,13813,0);
INSERT INTO "django_geo_db_location" VALUES(24072,NULL,'White House, TN',9966,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24073,NULL,'White House, TN 31788',9966,222,NULL,50,13814,0);
INSERT INTO "django_geo_db_location" VALUES(24074,NULL,'Sumner, GA',9967,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24075,NULL,'Sumner, GA 31789',9967,222,NULL,13,13815,0);
INSERT INTO "django_geo_db_location" VALUES(24076,NULL,'Sycamore, GA',9968,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24077,NULL,'Sycamore, GA 31790',9968,222,NULL,13,13816,0);
INSERT INTO "django_geo_db_location" VALUES(24078,NULL,'Sylvester, GA',9969,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24079,NULL,'Sylvester, GA 31791',9969,222,NULL,13,13817,0);
INSERT INTO "django_geo_db_location" VALUES(24080,NULL,'Thomasville, GA 31792',9937,222,NULL,13,13818,0);
INSERT INTO "django_geo_db_location" VALUES(24081,NULL,'Tifton, GA',9970,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24082,NULL,'Tifton, GA 31793',9970,222,NULL,13,13819,0);
INSERT INTO "django_geo_db_location" VALUES(24083,NULL,'Tifton, GA 31794',9970,222,NULL,13,13820,0);
INSERT INTO "django_geo_db_location" VALUES(24084,NULL,'Ty Ty, GA',9971,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24085,NULL,'Ty Ty, GA 31795',9971,222,NULL,13,13821,0);
INSERT INTO "django_geo_db_location" VALUES(24086,NULL,'Warwick, GA',9972,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24087,NULL,'Warwick, GA 31796',9972,222,NULL,13,13822,0);
INSERT INTO "django_geo_db_location" VALUES(24088,NULL,'Whigham, GA',9973,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24089,NULL,'Whigham, GA 31797',9973,222,NULL,13,13823,0);
INSERT INTO "django_geo_db_location" VALUES(24090,NULL,'Wray, GA',9974,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24091,NULL,'Wray, GA 31798',9974,222,NULL,13,13824,0);
INSERT INTO "django_geo_db_location" VALUES(24092,NULL,'Thomasville, GA 31799',9937,222,NULL,13,13825,0);
INSERT INTO "django_geo_db_location" VALUES(24093,NULL,'Box Springs, GA',9975,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24094,NULL,'Box Springs, GA 31801',9975,222,NULL,13,13826,0);
INSERT INTO "django_geo_db_location" VALUES(24095,NULL,'Buena Vista, GA',9976,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24096,NULL,'Buena Vista, GA 31803',9976,222,NULL,13,13827,0);
INSERT INTO "django_geo_db_location" VALUES(24097,NULL,'Cataula, GA',9977,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24098,NULL,'Cataula, GA 31804',9977,222,NULL,13,13828,0);
INSERT INTO "django_geo_db_location" VALUES(24099,NULL,'Cusseta, GA',9978,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24100,NULL,'Cusseta, GA 31805',9978,222,NULL,13,13829,0);
INSERT INTO "django_geo_db_location" VALUES(24101,NULL,'Ellaville, GA',9979,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24102,NULL,'Ellaville, GA 31806',9979,222,NULL,13,13830,0);
INSERT INTO "django_geo_db_location" VALUES(24103,NULL,'Ellerslie, GA',9980,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24104,NULL,'Ellerslie, GA 31807',9980,222,NULL,13,13831,0);
INSERT INTO "django_geo_db_location" VALUES(24105,NULL,'Fortson, GA',9981,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24106,NULL,'Fortson, GA 31808',9981,222,NULL,13,13832,0);
INSERT INTO "django_geo_db_location" VALUES(24107,NULL,'Geneva, GA',9982,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24108,NULL,'Geneva, GA 31810',9982,222,NULL,13,13833,0);
INSERT INTO "django_geo_db_location" VALUES(24109,NULL,'Hamilton, GA',9983,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24110,NULL,'Hamilton, GA 31811',9983,222,NULL,13,13834,0);
INSERT INTO "django_geo_db_location" VALUES(24111,NULL,'Junction City, GA',9984,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24112,NULL,'Junction City, GA 31812',9984,222,NULL,13,13835,0);
INSERT INTO "django_geo_db_location" VALUES(24113,NULL,'Louvale, GA',9985,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24114,NULL,'Louvale, GA 31814',9985,222,NULL,13,13836,0);
INSERT INTO "django_geo_db_location" VALUES(24115,NULL,'Lumpkin, GA',9986,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24116,NULL,'Lumpkin, GA 31815',9986,222,NULL,13,13837,0);
INSERT INTO "django_geo_db_location" VALUES(24117,NULL,'Manchester, GA',9987,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24118,NULL,'Manchester, GA 31816',9987,222,NULL,13,13838,0);
INSERT INTO "django_geo_db_location" VALUES(24119,NULL,'Midland, GA',9988,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24120,NULL,'Midland, GA 31820',9988,222,NULL,13,13839,0);
INSERT INTO "django_geo_db_location" VALUES(24121,NULL,'Omaha, GA',9989,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24122,NULL,'Omaha, GA 31821',9989,222,NULL,13,13840,0);
INSERT INTO "django_geo_db_location" VALUES(24123,NULL,'Pine Mountain, GA',9990,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24124,NULL,'Pine Mountain, GA 31822',9990,222,NULL,13,13841,0);
INSERT INTO "django_geo_db_location" VALUES(24125,NULL,'Pine Mountain Valley, GA',9991,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24126,NULL,'Pine Mountain Valley, GA 31823',9991,222,NULL,13,13842,0);
INSERT INTO "django_geo_db_location" VALUES(24127,NULL,'Preston, GA',9992,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24128,NULL,'Preston, GA 31824',9992,222,NULL,13,13843,0);
INSERT INTO "django_geo_db_location" VALUES(24129,NULL,'Richland, GA',9993,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24130,NULL,'Richland, GA 31825',9993,222,NULL,13,13844,0);
INSERT INTO "django_geo_db_location" VALUES(24131,NULL,'Shiloh, GA',9994,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24132,NULL,'Shiloh, GA 31826',9994,222,NULL,13,13845,0);
INSERT INTO "django_geo_db_location" VALUES(24133,NULL,'Talbotton, GA',9995,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24134,NULL,'Talbotton, GA 31827',9995,222,NULL,13,13846,0);
INSERT INTO "django_geo_db_location" VALUES(24135,NULL,'Upatoi, GA',9996,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24136,NULL,'Upatoi, GA 31829',9996,222,NULL,13,13847,0);
INSERT INTO "django_geo_db_location" VALUES(24137,NULL,'Warm Springs, GA',9997,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24138,NULL,'Warm Springs, GA 31830',9997,222,NULL,13,13848,0);
INSERT INTO "django_geo_db_location" VALUES(24139,NULL,'Waverly Hall, GA',9998,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24140,NULL,'Waverly Hall, GA 31831',9998,222,NULL,13,13849,0);
INSERT INTO "django_geo_db_location" VALUES(24141,NULL,'Weston, GA',9999,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24142,NULL,'Weston, GA 31832',9999,222,NULL,13,13850,0);
INSERT INTO "django_geo_db_location" VALUES(24143,NULL,'West Point, GA',10000,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24144,NULL,'West Point, GA 31833',10000,222,NULL,13,13851,0);
INSERT INTO "django_geo_db_location" VALUES(24145,NULL,'Woodland, GA',10001,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24146,NULL,'Woodland, GA 31836',10001,222,NULL,13,13852,0);
INSERT INTO "django_geo_db_location" VALUES(24147,NULL,'Columbus, GA',10002,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24148,NULL,'Columbus, GA 31901',10002,222,NULL,13,13853,0);
INSERT INTO "django_geo_db_location" VALUES(24149,NULL,'Columbus, GA 31902',10002,222,NULL,13,13854,0);
INSERT INTO "django_geo_db_location" VALUES(24150,NULL,'Columbus, GA 31903',10002,222,NULL,13,13855,0);
INSERT INTO "django_geo_db_location" VALUES(24151,NULL,'Columbus, GA 31904',10002,222,NULL,13,13856,0);
INSERT INTO "django_geo_db_location" VALUES(24152,NULL,'Fort Benning, GA',10003,222,NULL,13,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24153,NULL,'Fort Benning, GA 31905',10003,222,NULL,13,13857,0);
INSERT INTO "django_geo_db_location" VALUES(24154,NULL,'Columbus, GA 31906',10002,222,NULL,13,13858,0);
INSERT INTO "django_geo_db_location" VALUES(24155,NULL,'Columbus, GA 31907',10002,222,NULL,13,13859,0);
INSERT INTO "django_geo_db_location" VALUES(24156,NULL,'Columbus, GA 31908',10002,222,NULL,13,13860,0);
INSERT INTO "django_geo_db_location" VALUES(24157,NULL,'Columbus, GA 31909',10002,222,NULL,13,13861,0);
INSERT INTO "django_geo_db_location" VALUES(24158,NULL,'Columbus, GA 31914',10002,222,NULL,13,13862,0);
INSERT INTO "django_geo_db_location" VALUES(24159,NULL,'Columbus, GA 31917',10002,222,NULL,13,13863,0);
INSERT INTO "django_geo_db_location" VALUES(24160,NULL,'Columbus, GA 31993',10002,222,NULL,13,13864,0);
INSERT INTO "django_geo_db_location" VALUES(24161,NULL,'Columbus, GA 31994',10002,222,NULL,13,13865,0);
INSERT INTO "django_geo_db_location" VALUES(24162,NULL,'Fort Benning, GA 31995',10003,222,NULL,13,13866,0);
INSERT INTO "django_geo_db_location" VALUES(24163,NULL,'Columbus, GA 31997',10002,222,NULL,13,13867,0);
INSERT INTO "django_geo_db_location" VALUES(24164,NULL,'Columbus, GA 31998',10002,222,NULL,13,13868,0);
INSERT INTO "django_geo_db_location" VALUES(24165,NULL,'Columbus, GA 31999',10002,222,NULL,13,13869,0);
INSERT INTO "django_geo_db_location" VALUES(24166,NULL,'Ponte Vedra Beach, FL',10004,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24167,NULL,'Ponte Vedra Beach, FL 32004',10004,222,NULL,11,13870,0);
INSERT INTO "django_geo_db_location" VALUES(24168,NULL,'Bostwick, FL',10005,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24169,NULL,'Bostwick, FL 32007',10005,222,NULL,11,13871,0);
INSERT INTO "django_geo_db_location" VALUES(24170,NULL,'Branford, FL',10006,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24171,NULL,'Branford, FL 32008',10006,222,NULL,11,13872,0);
INSERT INTO "django_geo_db_location" VALUES(24172,NULL,'Bryceville, FL',10007,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24173,NULL,'Bryceville, FL 32009',10007,222,NULL,11,13873,0);
INSERT INTO "django_geo_db_location" VALUES(24174,NULL,'Callahan, FL',10008,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24175,NULL,'Callahan, FL 32011',10008,222,NULL,11,13874,0);
INSERT INTO "django_geo_db_location" VALUES(24176,NULL,'Day, FL',10009,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24177,NULL,'Day, FL 32013',10009,222,NULL,11,13875,0);
INSERT INTO "django_geo_db_location" VALUES(24178,NULL,'Lake City, FL',10010,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24179,NULL,'Lake City, FL 32024',10010,222,NULL,11,13876,0);
INSERT INTO "django_geo_db_location" VALUES(24180,NULL,'Lake City, FL 32025',10010,222,NULL,11,13877,0);
INSERT INTO "django_geo_db_location" VALUES(24181,NULL,'Doctors Inlet, FL',10011,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24182,NULL,'Doctors Inlet, FL 32030',10011,222,NULL,11,13878,0);
INSERT INTO "django_geo_db_location" VALUES(24183,NULL,'Elkton, FL',10012,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24184,NULL,'Elkton, FL 32033',10012,222,NULL,11,13879,0);
INSERT INTO "django_geo_db_location" VALUES(24185,NULL,'Fernandina Beach, FL',10013,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24186,NULL,'Fernandina Beach, FL 32034',10013,222,NULL,11,13880,0);
INSERT INTO "django_geo_db_location" VALUES(24187,NULL,'Fernandina Beach, FL 32035',10013,222,NULL,11,13881,0);
INSERT INTO "django_geo_db_location" VALUES(24188,NULL,'Fort White, FL',10014,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24189,NULL,'Fort White, FL 32038',10014,222,NULL,11,13882,0);
INSERT INTO "django_geo_db_location" VALUES(24190,NULL,'Glen Saint Mary, FL',10015,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24191,NULL,'Glen Saint Mary, FL 32040',10015,222,NULL,11,13883,0);
INSERT INTO "django_geo_db_location" VALUES(24192,NULL,'Yulee, FL',10016,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24193,NULL,'Yulee, FL 32041',10016,222,NULL,11,13884,0);
INSERT INTO "django_geo_db_location" VALUES(24194,NULL,'Graham, FL',10017,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24195,NULL,'Graham, FL 32042',10017,222,NULL,11,13885,0);
INSERT INTO "django_geo_db_location" VALUES(24196,NULL,'Green Cove Springs, FL',10018,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24197,NULL,'Green Cove Springs, FL 32043',10018,222,NULL,11,13886,0);
INSERT INTO "django_geo_db_location" VALUES(24198,NULL,'Hampton, FL',10019,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24199,NULL,'Hampton, FL 32044',10019,222,NULL,11,13887,0);
INSERT INTO "django_geo_db_location" VALUES(24200,NULL,'Hilliard, FL',10020,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24201,NULL,'Hilliard, FL 32046',10020,222,NULL,11,13888,0);
INSERT INTO "django_geo_db_location" VALUES(24202,NULL,'Yulee, FL 32047',10016,222,NULL,11,13889,0);
INSERT INTO "django_geo_db_location" VALUES(24203,NULL,'Middleburg, FL',10021,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24204,NULL,'Middleburg, FL 32050',10021,222,NULL,11,13890,0);
INSERT INTO "django_geo_db_location" VALUES(24205,NULL,'Jasper, FL',10022,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24206,NULL,'Jasper, FL 32052',10022,222,NULL,11,13891,0);
INSERT INTO "django_geo_db_location" VALUES(24207,NULL,'Jennings, FL',10023,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24208,NULL,'Jennings, FL 32053',10023,222,NULL,11,13892,0);
INSERT INTO "django_geo_db_location" VALUES(24209,NULL,'Lake Butler, FL',10024,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24210,NULL,'Lake Butler, FL 32054',10024,222,NULL,11,13893,0);
INSERT INTO "django_geo_db_location" VALUES(24211,NULL,'Lake City, FL 32055',10010,222,NULL,11,13894,0);
INSERT INTO "django_geo_db_location" VALUES(24212,NULL,'Lake City, FL 32056',10010,222,NULL,11,13895,0);
INSERT INTO "django_geo_db_location" VALUES(24213,NULL,'Lawtey, FL',10025,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24214,NULL,'Lawtey, FL 32058',10025,222,NULL,11,13896,0);
INSERT INTO "django_geo_db_location" VALUES(24215,NULL,'Lee, FL',10026,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24216,NULL,'Lee, FL 32059',10026,222,NULL,11,13897,0);
INSERT INTO "django_geo_db_location" VALUES(24217,NULL,'Live Oak, FL',10027,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24218,NULL,'Live Oak, FL 32060',10027,222,NULL,11,13898,0);
INSERT INTO "django_geo_db_location" VALUES(24219,NULL,'Lulu, FL',10028,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24220,NULL,'Lulu, FL 32061',10028,222,NULL,11,13899,0);
INSERT INTO "django_geo_db_location" VALUES(24221,NULL,'McAlpin, FL',10029,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24222,NULL,'McAlpin, FL 32062',10029,222,NULL,11,13900,0);
INSERT INTO "django_geo_db_location" VALUES(24223,NULL,'Macclenny, FL',10030,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24224,NULL,'Macclenny, FL 32063',10030,222,NULL,11,13901,0);
INSERT INTO "django_geo_db_location" VALUES(24225,NULL,'Live Oak, FL 32064',10027,222,NULL,11,13902,0);
INSERT INTO "django_geo_db_location" VALUES(24226,NULL,'Orange Park, FL',10031,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24227,NULL,'Orange Park, FL 32065',10031,222,NULL,11,13903,0);
INSERT INTO "django_geo_db_location" VALUES(24228,NULL,'Mayo, FL',10032,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24229,NULL,'Mayo, FL 32066',10032,222,NULL,11,13904,0);
INSERT INTO "django_geo_db_location" VALUES(24230,NULL,'Orange Park, FL 32067',10031,222,NULL,11,13905,0);
INSERT INTO "django_geo_db_location" VALUES(24231,NULL,'Middleburg, FL 32068',10021,222,NULL,11,13906,0);
INSERT INTO "django_geo_db_location" VALUES(24232,NULL,'O Brien, FL',10033,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24233,NULL,'O Brien, FL 32071',10033,222,NULL,11,13907,0);
INSERT INTO "django_geo_db_location" VALUES(24234,NULL,'Olustee, FL',10034,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24235,NULL,'Olustee, FL 32072',10034,222,NULL,11,13908,0);
INSERT INTO "django_geo_db_location" VALUES(24236,NULL,'Orange Park, FL 32073',10031,222,NULL,11,13909,0);
INSERT INTO "django_geo_db_location" VALUES(24237,NULL,'Penney Farms, FL',10035,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24238,NULL,'Penney Farms, FL 32079',10035,222,NULL,11,13910,0);
INSERT INTO "django_geo_db_location" VALUES(24239,NULL,'St. Augustine, FL',10036,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24240,NULL,'St. Augustine, FL 32080',10036,222,NULL,11,13911,0);
INSERT INTO "django_geo_db_location" VALUES(24241,NULL,'Pomona Park, FL',10037,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24242,NULL,'Pomona Park, FL 32081',10037,222,NULL,11,13912,0);
INSERT INTO "django_geo_db_location" VALUES(24243,NULL,'Ponte Vedra Beach, FL 32082',10004,222,NULL,11,13913,0);
INSERT INTO "django_geo_db_location" VALUES(24244,NULL,'Raiford, FL',10038,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24245,NULL,'Raiford, FL 32083',10038,222,NULL,11,13914,0);
INSERT INTO "django_geo_db_location" VALUES(24246,NULL,'Saint Augustine, FL',10039,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24247,NULL,'Saint Augustine, FL 32084',10039,222,NULL,11,13915,0);
INSERT INTO "django_geo_db_location" VALUES(24248,NULL,'Saint Augustine, FL 32085',10039,222,NULL,11,13916,0);
INSERT INTO "django_geo_db_location" VALUES(24249,NULL,'Saint Augustine, FL 32086',10039,222,NULL,11,13917,0);
INSERT INTO "django_geo_db_location" VALUES(24250,NULL,'Sanderson, FL',10040,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24251,NULL,'Sanderson, FL 32087',10040,222,NULL,11,13918,0);
INSERT INTO "django_geo_db_location" VALUES(24252,NULL,'Starke, FL',10041,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24253,NULL,'Starke, FL 32091',10041,222,NULL,11,13919,0);
INSERT INTO "django_geo_db_location" VALUES(24254,NULL,'Saint Augustine, FL 32092',10039,222,NULL,11,13920,0);
INSERT INTO "django_geo_db_location" VALUES(24255,NULL,'Wellborn, FL',10042,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24256,NULL,'Wellborn, FL 32094',10042,222,NULL,11,13921,0);
INSERT INTO "django_geo_db_location" VALUES(24257,NULL,'Saint Augustine, FL 32095',10039,222,NULL,11,13922,0);
INSERT INTO "django_geo_db_location" VALUES(24258,NULL,'White Springs, FL',10043,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24259,NULL,'White Springs, FL 32096',10043,222,NULL,11,13923,0);
INSERT INTO "django_geo_db_location" VALUES(24260,NULL,'Yulee, FL 32097',10016,222,NULL,11,13924,0);
INSERT INTO "django_geo_db_location" VALUES(24261,NULL,'Palm Valley, FL',10044,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24262,NULL,'Palm Valley, FL 32098',10044,222,NULL,11,13925,0);
INSERT INTO "django_geo_db_location" VALUES(24263,NULL,'Jacksonville, FL',10045,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24264,NULL,'Jacksonville, FL 32099',10045,222,NULL,11,13926,0);
INSERT INTO "django_geo_db_location" VALUES(24265,NULL,'Astor, FL',10046,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24266,NULL,'Astor, FL 32102',10046,222,NULL,11,13927,0);
INSERT INTO "django_geo_db_location" VALUES(24267,NULL,'Barberville, FL',10047,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24268,NULL,'Barberville, FL 32105',10047,222,NULL,11,13928,0);
INSERT INTO "django_geo_db_location" VALUES(24269,NULL,'Bunnell, FL',10048,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24270,NULL,'Bunnell, FL 32110',10048,222,NULL,11,13929,0);
INSERT INTO "django_geo_db_location" VALUES(24271,NULL,'Candler, FL',10049,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24272,NULL,'Candler, FL 32111',10049,222,NULL,11,13930,0);
INSERT INTO "django_geo_db_location" VALUES(24273,NULL,'Crescent City, FL',10050,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24274,NULL,'Crescent City, FL 32112',10050,222,NULL,11,13931,0);
INSERT INTO "django_geo_db_location" VALUES(24275,NULL,'Citra, FL',10051,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24276,NULL,'Citra, FL 32113',10051,222,NULL,11,13932,0);
INSERT INTO "django_geo_db_location" VALUES(24277,NULL,'Daytona Beach, FL',10052,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24278,NULL,'Daytona Beach, FL 32114',10052,222,NULL,11,13933,0);
INSERT INTO "django_geo_db_location" VALUES(24279,NULL,'Daytona Beach, FL 32115',10052,222,NULL,11,13934,0);
INSERT INTO "django_geo_db_location" VALUES(24280,NULL,'Daytona Beach, FL 32116',10052,222,NULL,11,13935,0);
INSERT INTO "django_geo_db_location" VALUES(24281,NULL,'Daytona Beach, FL 32117',10052,222,NULL,11,13936,0);
INSERT INTO "django_geo_db_location" VALUES(24282,NULL,'Daytona Beach, FL 32118',10052,222,NULL,11,13937,0);
INSERT INTO "django_geo_db_location" VALUES(24283,NULL,'Daytona Beach, FL 32119',10052,222,NULL,11,13938,0);
INSERT INTO "django_geo_db_location" VALUES(24284,NULL,'Daytona Beach, FL 32120',10052,222,NULL,11,13939,0);
INSERT INTO "django_geo_db_location" VALUES(24285,NULL,'Daytona Beach, FL 32121',10052,222,NULL,11,13940,0);
INSERT INTO "django_geo_db_location" VALUES(24286,NULL,'Daytona Beach, FL 32122',10052,222,NULL,11,13941,0);
INSERT INTO "django_geo_db_location" VALUES(24287,NULL,'Daytona Beach, FL 32123',10052,222,NULL,11,13942,0);
INSERT INTO "django_geo_db_location" VALUES(24288,NULL,'Daytona Beach, FL 32124',10052,222,NULL,11,13943,0);
INSERT INTO "django_geo_db_location" VALUES(24289,NULL,'Daytona Beach, FL 32125',10052,222,NULL,11,13944,0);
INSERT INTO "django_geo_db_location" VALUES(24290,NULL,'Daytona Beach, FL 32126',10052,222,NULL,11,13945,0);
INSERT INTO "django_geo_db_location" VALUES(24291,NULL,'Daytona Beach, FL 32127',10052,222,NULL,11,13946,0);
INSERT INTO "django_geo_db_location" VALUES(24292,NULL,'Port Orange, FL',10053,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24293,NULL,'Port Orange, FL 32128',10053,222,NULL,11,13947,0);
INSERT INTO "django_geo_db_location" VALUES(24294,NULL,'Port Orange, FL 32129',10053,222,NULL,11,13948,0);
INSERT INTO "django_geo_db_location" VALUES(24295,NULL,'De Leon Springs, FL',10054,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24296,NULL,'De Leon Springs, FL 32130',10054,222,NULL,11,13949,0);
INSERT INTO "django_geo_db_location" VALUES(24297,NULL,'East Palatka, FL',10055,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24298,NULL,'East Palatka, FL 32131',10055,222,NULL,11,13950,0);
INSERT INTO "django_geo_db_location" VALUES(24299,NULL,'Edgewater, FL',10056,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24300,NULL,'Edgewater, FL 32132',10056,222,NULL,11,13951,0);
INSERT INTO "django_geo_db_location" VALUES(24301,NULL,'Eastlake Weir, FL',10057,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24302,NULL,'Eastlake Weir, FL 32133',10057,222,NULL,11,13952,0);
INSERT INTO "django_geo_db_location" VALUES(24303,NULL,'Fort McCoy, FL',10058,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24304,NULL,'Fort McCoy, FL 32134',10058,222,NULL,11,13953,0);
INSERT INTO "django_geo_db_location" VALUES(24305,NULL,'Palm Coast, FL',10059,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24306,NULL,'Palm Coast, FL 32135',10059,222,NULL,11,13954,0);
INSERT INTO "django_geo_db_location" VALUES(24307,NULL,'Flagler Beach, FL',10060,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24308,NULL,'Flagler Beach, FL 32136',10060,222,NULL,11,13955,0);
INSERT INTO "django_geo_db_location" VALUES(24309,NULL,'Palm Coast, FL 32137',10059,222,NULL,11,13956,0);
INSERT INTO "django_geo_db_location" VALUES(24310,NULL,'Grandin, FL',10061,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24311,NULL,'Grandin, FL 32138',10061,222,NULL,11,13957,0);
INSERT INTO "django_geo_db_location" VALUES(24312,NULL,'Georgetown, FL',10062,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24313,NULL,'Georgetown, FL 32139',10062,222,NULL,11,13958,0);
INSERT INTO "django_geo_db_location" VALUES(24314,NULL,'Florahome, FL',10063,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24315,NULL,'Florahome, FL 32140',10063,222,NULL,11,13959,0);
INSERT INTO "django_geo_db_location" VALUES(24316,NULL,'Edgewater, FL 32141',10056,222,NULL,11,13960,0);
INSERT INTO "django_geo_db_location" VALUES(24317,NULL,'Palm Coast, FL 32142',10059,222,NULL,11,13961,0);
INSERT INTO "django_geo_db_location" VALUES(24318,NULL,'Hastings, FL',10064,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24319,NULL,'Hastings, FL 32145',10064,222,NULL,11,13962,0);
INSERT INTO "django_geo_db_location" VALUES(24320,NULL,'Hollister, FL',10065,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24321,NULL,'Hollister, FL 32147',10065,222,NULL,11,13963,0);
INSERT INTO "django_geo_db_location" VALUES(24322,NULL,'Interlachen, FL',10066,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24323,NULL,'Interlachen, FL 32148',10066,222,NULL,11,13964,0);
INSERT INTO "django_geo_db_location" VALUES(24324,NULL,'Interlachen, FL 32149',10066,222,NULL,11,13965,0);
INSERT INTO "django_geo_db_location" VALUES(24325,NULL,'Flagler Beach, FL 32151',10060,222,NULL,11,13966,0);
INSERT INTO "django_geo_db_location" VALUES(24326,NULL,'Lake Como, FL',10067,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24327,NULL,'Lake Como, FL 32157',10067,222,NULL,11,13967,0);
INSERT INTO "django_geo_db_location" VALUES(24328,NULL,'Lady Lake, FL',10068,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24329,NULL,'Lady Lake, FL 32158',10068,222,NULL,11,13968,0);
INSERT INTO "django_geo_db_location" VALUES(24330,NULL,'Lady Lake, FL 32159',10068,222,NULL,11,13969,0);
INSERT INTO "django_geo_db_location" VALUES(24331,NULL,'Lake Geneva, FL',10069,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24332,NULL,'Lake Geneva, FL 32160',10069,222,NULL,11,13970,0);
INSERT INTO "django_geo_db_location" VALUES(24333,NULL,'The Villages, FL',10070,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24334,NULL,'The Villages, FL 32162',10070,222,NULL,11,13971,0);
INSERT INTO "django_geo_db_location" VALUES(24335,NULL,'Palm Coast, FL 32164',10059,222,NULL,11,13972,0);
INSERT INTO "django_geo_db_location" VALUES(24336,NULL,'New Smyrna Beach, FL',10071,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24337,NULL,'New Smyrna Beach, FL 32168',10071,222,NULL,11,13973,0);
INSERT INTO "django_geo_db_location" VALUES(24338,NULL,'New Smyrna Beach, FL 32169',10071,222,NULL,11,13974,0);
INSERT INTO "django_geo_db_location" VALUES(24339,NULL,'New Smyrna Beach, FL 32170',10071,222,NULL,11,13975,0);
INSERT INTO "django_geo_db_location" VALUES(24340,NULL,'Ormond Beach, FL',10072,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24341,NULL,'Ormond Beach, FL 32173',10072,222,NULL,11,13976,0);
INSERT INTO "django_geo_db_location" VALUES(24342,NULL,'Ormond Beach, FL 32174',10072,222,NULL,11,13977,0);
INSERT INTO "django_geo_db_location" VALUES(24343,NULL,'Ormond Beach, FL 32175',10072,222,NULL,11,13978,0);
INSERT INTO "django_geo_db_location" VALUES(24344,NULL,'Ormond Beach, FL 32176',10072,222,NULL,11,13979,0);
INSERT INTO "django_geo_db_location" VALUES(24345,NULL,'Palatka, FL',10073,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24346,NULL,'Palatka, FL 32177',10073,222,NULL,11,13980,0);
INSERT INTO "django_geo_db_location" VALUES(24347,NULL,'Palatka, FL 32178',10073,222,NULL,11,13981,0);
INSERT INTO "django_geo_db_location" VALUES(24348,NULL,'Ocklawaha, FL',10074,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24349,NULL,'Ocklawaha, FL 32179',10074,222,NULL,11,13982,0);
INSERT INTO "django_geo_db_location" VALUES(24350,NULL,'Pierson, FL',10075,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24351,NULL,'Pierson, FL 32180',10075,222,NULL,11,13983,0);
INSERT INTO "django_geo_db_location" VALUES(24352,NULL,'Pomona Park, FL 32181',10037,222,NULL,11,13984,0);
INSERT INTO "django_geo_db_location" VALUES(24353,NULL,'Orange Springs, FL',10076,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24354,NULL,'Orange Springs, FL 32182',10076,222,NULL,11,13985,0);
INSERT INTO "django_geo_db_location" VALUES(24355,NULL,'Ocklawaha, FL 32183',10074,222,NULL,11,13986,0);
INSERT INTO "django_geo_db_location" VALUES(24356,NULL,'Putnam Hall, FL',10077,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24357,NULL,'Putnam Hall, FL 32185',10077,222,NULL,11,13987,0);
INSERT INTO "django_geo_db_location" VALUES(24358,NULL,'San Mateo, FL',10078,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24359,NULL,'San Mateo, FL 32187',10078,222,NULL,11,13988,0);
INSERT INTO "django_geo_db_location" VALUES(24360,NULL,'Satsuma, FL',10079,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24361,NULL,'Satsuma, FL 32189',10079,222,NULL,11,13989,0);
INSERT INTO "django_geo_db_location" VALUES(24362,NULL,'Seville, FL',10080,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24363,NULL,'Seville, FL 32190',10080,222,NULL,11,13990,0);
INSERT INTO "django_geo_db_location" VALUES(24364,NULL,'Sparr, FL',10081,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24365,NULL,'Sparr, FL 32192',10081,222,NULL,11,13991,0);
INSERT INTO "django_geo_db_location" VALUES(24366,NULL,'Welaka, FL',10082,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24367,NULL,'Welaka, FL 32193',10082,222,NULL,11,13992,0);
INSERT INTO "django_geo_db_location" VALUES(24368,NULL,'Weirsdale, FL',10083,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24369,NULL,'Weirsdale, FL 32195',10083,222,NULL,11,13993,0);
INSERT INTO "django_geo_db_location" VALUES(24370,NULL,'Daytona Beach, FL 32198',10052,222,NULL,11,13994,0);
INSERT INTO "django_geo_db_location" VALUES(24371,NULL,'Jacksonville, FL 32201',10045,222,NULL,11,13995,0);
INSERT INTO "django_geo_db_location" VALUES(24372,NULL,'Jacksonville, FL 32202',10045,222,NULL,11,13996,0);
INSERT INTO "django_geo_db_location" VALUES(24373,NULL,'Jacksonville, FL 32203',10045,222,NULL,11,13997,0);
INSERT INTO "django_geo_db_location" VALUES(24374,NULL,'Jacksonville, FL 32204',10045,222,NULL,11,13998,0);
INSERT INTO "django_geo_db_location" VALUES(24375,NULL,'Jacksonville, FL 32205',10045,222,NULL,11,13999,0);
INSERT INTO "django_geo_db_location" VALUES(24376,NULL,'Jacksonville, FL 32206',10045,222,NULL,11,14000,0);
INSERT INTO "django_geo_db_location" VALUES(24377,NULL,'Jacksonville, FL 32207',10045,222,NULL,11,14001,0);
INSERT INTO "django_geo_db_location" VALUES(24378,NULL,'Jacksonville, FL 32208',10045,222,NULL,11,14002,0);
INSERT INTO "django_geo_db_location" VALUES(24379,NULL,'Jacksonville, FL 32209',10045,222,NULL,11,14003,0);
INSERT INTO "django_geo_db_location" VALUES(24380,NULL,'Jacksonville, FL 32210',10045,222,NULL,11,14004,0);
INSERT INTO "django_geo_db_location" VALUES(24381,NULL,'Jacksonville, FL 32211',10045,222,NULL,11,14005,0);
INSERT INTO "django_geo_db_location" VALUES(24382,NULL,'Jacksonville, FL 32212',10045,222,NULL,11,14006,0);
INSERT INTO "django_geo_db_location" VALUES(24383,NULL,'Jacksonville, FL 32214',10045,222,NULL,11,14007,0);
INSERT INTO "django_geo_db_location" VALUES(24384,NULL,'Jacksonville, FL 32215',10045,222,NULL,11,14008,0);
INSERT INTO "django_geo_db_location" VALUES(24385,NULL,'Jacksonville, FL 32216',10045,222,NULL,11,14009,0);
INSERT INTO "django_geo_db_location" VALUES(24386,NULL,'Jacksonville, FL 32217',10045,222,NULL,11,14010,0);
INSERT INTO "django_geo_db_location" VALUES(24387,NULL,'Jacksonville, FL 32218',10045,222,NULL,11,14011,0);
INSERT INTO "django_geo_db_location" VALUES(24388,NULL,'Jacksonville, FL 32219',10045,222,NULL,11,14012,0);
INSERT INTO "django_geo_db_location" VALUES(24389,NULL,'Jacksonville, FL 32220',10045,222,NULL,11,14013,0);
INSERT INTO "django_geo_db_location" VALUES(24390,NULL,'Jacksonville, FL 32221',10045,222,NULL,11,14014,0);
INSERT INTO "django_geo_db_location" VALUES(24391,NULL,'Jacksonville, FL 32222',10045,222,NULL,11,14015,0);
INSERT INTO "django_geo_db_location" VALUES(24392,NULL,'Jacksonville, FL 32223',10045,222,NULL,11,14016,0);
INSERT INTO "django_geo_db_location" VALUES(24393,NULL,'Jacksonville, FL 32224',10045,222,NULL,11,14017,0);
INSERT INTO "django_geo_db_location" VALUES(24394,NULL,'Jacksonville, FL 32225',10045,222,NULL,11,14018,0);
INSERT INTO "django_geo_db_location" VALUES(24395,NULL,'Jacksonville, FL 32226',10045,222,NULL,11,14019,0);
INSERT INTO "django_geo_db_location" VALUES(24396,NULL,'Jacksonville, FL 32227',10045,222,NULL,11,14020,0);
INSERT INTO "django_geo_db_location" VALUES(24397,NULL,'Jacksonville, FL 32228',10045,222,NULL,11,14021,0);
INSERT INTO "django_geo_db_location" VALUES(24398,NULL,'Jacksonville, FL 32229',10045,222,NULL,11,14022,0);
INSERT INTO "django_geo_db_location" VALUES(24399,NULL,'Jacksonville, FL 32230',10045,222,NULL,11,14023,0);
INSERT INTO "django_geo_db_location" VALUES(24400,NULL,'Jacksonville, FL 32231',10045,222,NULL,11,14024,0);
INSERT INTO "django_geo_db_location" VALUES(24401,NULL,'Jacksonville, FL 32232',10045,222,NULL,11,14025,0);
INSERT INTO "django_geo_db_location" VALUES(24402,NULL,'Atlantic Beach, FL',10084,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24403,NULL,'Atlantic Beach, FL 32233',10084,222,NULL,11,14026,0);
INSERT INTO "django_geo_db_location" VALUES(24404,NULL,'Jacksonville, FL 32234',10045,222,NULL,11,14027,0);
INSERT INTO "django_geo_db_location" VALUES(24405,NULL,'Jacksonville, FL 32235',10045,222,NULL,11,14028,0);
INSERT INTO "django_geo_db_location" VALUES(24406,NULL,'Jacksonville, FL 32236',10045,222,NULL,11,14029,0);
INSERT INTO "django_geo_db_location" VALUES(24407,NULL,'Jacksonville, FL 32237',10045,222,NULL,11,14030,0);
INSERT INTO "django_geo_db_location" VALUES(24408,NULL,'Jacksonville, FL 32238',10045,222,NULL,11,14031,0);
INSERT INTO "django_geo_db_location" VALUES(24409,NULL,'Jacksonville, FL 32239',10045,222,NULL,11,14032,0);
INSERT INTO "django_geo_db_location" VALUES(24410,NULL,'Jacksonville Beach, FL',10085,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24411,NULL,'Jacksonville Beach, FL 32240',10085,222,NULL,11,14033,0);
INSERT INTO "django_geo_db_location" VALUES(24412,NULL,'Jacksonville, FL 32241',10045,222,NULL,11,14034,0);
INSERT INTO "django_geo_db_location" VALUES(24413,NULL,'Jacksonville, FL 32244',10045,222,NULL,11,14035,0);
INSERT INTO "django_geo_db_location" VALUES(24414,NULL,'Jacksonville, FL 32245',10045,222,NULL,11,14036,0);
INSERT INTO "django_geo_db_location" VALUES(24415,NULL,'Jacksonville, FL 32246',10045,222,NULL,11,14037,0);
INSERT INTO "django_geo_db_location" VALUES(24416,NULL,'Jacksonville, FL 32247',10045,222,NULL,11,14038,0);
INSERT INTO "django_geo_db_location" VALUES(24417,NULL,'Jacksonville Beach, FL 32250',10085,222,NULL,11,14039,0);
INSERT INTO "django_geo_db_location" VALUES(24418,NULL,'Jacksonville, FL 32254',10045,222,NULL,11,14040,0);
INSERT INTO "django_geo_db_location" VALUES(24419,NULL,'Jacksonville, FL 32255',10045,222,NULL,11,14041,0);
INSERT INTO "django_geo_db_location" VALUES(24420,NULL,'Jacksonville, FL 32256',10045,222,NULL,11,14042,0);
INSERT INTO "django_geo_db_location" VALUES(24421,NULL,'Jacksonville, FL 32257',10045,222,NULL,11,14043,0);
INSERT INTO "django_geo_db_location" VALUES(24422,NULL,'Jacksonville, FL 32258',10045,222,NULL,11,14044,0);
INSERT INTO "django_geo_db_location" VALUES(24423,NULL,'Jacksonville, FL 32259',10045,222,NULL,11,14045,0);
INSERT INTO "django_geo_db_location" VALUES(24424,NULL,'Jacksonville, FL 32260',10045,222,NULL,11,14046,0);
INSERT INTO "django_geo_db_location" VALUES(24425,NULL,'Neptune Beach, FL',10086,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24426,NULL,'Neptune Beach, FL 32266',10086,222,NULL,11,14047,0);
INSERT INTO "django_geo_db_location" VALUES(24427,NULL,'Jacksonville, FL 32267',10045,222,NULL,11,14048,0);
INSERT INTO "django_geo_db_location" VALUES(24428,NULL,'Jacksonville, FL 32276',10045,222,NULL,11,14049,0);
INSERT INTO "django_geo_db_location" VALUES(24429,NULL,'Jacksonville, FL 32277',10045,222,NULL,11,14050,0);
INSERT INTO "django_geo_db_location" VALUES(24430,NULL,'Tallahassee, FL',10087,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24431,NULL,'Tallahassee, FL 32301',10087,222,NULL,11,14051,0);
INSERT INTO "django_geo_db_location" VALUES(24432,NULL,'Tallahassee, FL 32302',10087,222,NULL,11,14052,0);
INSERT INTO "django_geo_db_location" VALUES(24433,NULL,'Tallahassee, FL 32303',10087,222,NULL,11,14053,0);
INSERT INTO "django_geo_db_location" VALUES(24434,NULL,'Tallahassee, FL 32304',10087,222,NULL,11,14054,0);
INSERT INTO "django_geo_db_location" VALUES(24435,NULL,'Wakulla Springs, FL',10088,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24436,NULL,'Wakulla Springs, FL 32305',10088,222,NULL,11,14055,0);
INSERT INTO "django_geo_db_location" VALUES(24437,NULL,'Tallahassee, FL 32306',10087,222,NULL,11,14056,0);
INSERT INTO "django_geo_db_location" VALUES(24438,NULL,'Tallahassee, FL 32307',10087,222,NULL,11,14057,0);
INSERT INTO "django_geo_db_location" VALUES(24439,NULL,'Tallahassee, FL 32308',10087,222,NULL,11,14058,0);
INSERT INTO "django_geo_db_location" VALUES(24440,NULL,'Miccosukee Cpo, FL',10089,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24441,NULL,'Miccosukee Cpo, FL 32309',10089,222,NULL,11,14059,0);
INSERT INTO "django_geo_db_location" VALUES(24442,NULL,'Tallahassee, FL 32310',10087,222,NULL,11,14060,0);
INSERT INTO "django_geo_db_location" VALUES(24443,NULL,'Tallahassee, FL 32311',10087,222,NULL,11,14061,0);
INSERT INTO "django_geo_db_location" VALUES(24444,NULL,'Tallahassee, FL 32312',10087,222,NULL,11,14062,0);
INSERT INTO "django_geo_db_location" VALUES(24445,NULL,'Tallahassee, FL 32313',10087,222,NULL,11,14063,0);
INSERT INTO "django_geo_db_location" VALUES(24446,NULL,'Tallahassee, FL 32314',10087,222,NULL,11,14064,0);
INSERT INTO "django_geo_db_location" VALUES(24447,NULL,'Tallahassee, FL 32315',10087,222,NULL,11,14065,0);
INSERT INTO "django_geo_db_location" VALUES(24448,NULL,'Tallahassee, FL 32316',10087,222,NULL,11,14066,0);
INSERT INTO "django_geo_db_location" VALUES(24449,NULL,'Tallahassee, FL 32317',10087,222,NULL,11,14067,0);
INSERT INTO "django_geo_db_location" VALUES(24450,NULL,'Apalachicola, FL',10090,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24451,NULL,'Apalachicola, FL 32320',10090,222,NULL,11,14068,0);
INSERT INTO "django_geo_db_location" VALUES(24452,NULL,'Bristol, FL',10091,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24453,NULL,'Bristol, FL 32321',10091,222,NULL,11,14069,0);
INSERT INTO "django_geo_db_location" VALUES(24454,NULL,'Carrabelle, FL',10092,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24455,NULL,'Carrabelle, FL 32322',10092,222,NULL,11,14070,0);
INSERT INTO "django_geo_db_location" VALUES(24456,NULL,'Lanark Village, FL',10093,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24457,NULL,'Lanark Village, FL 32323',10093,222,NULL,11,14071,0);
INSERT INTO "django_geo_db_location" VALUES(24458,NULL,'Chattahoochee, FL',10094,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24459,NULL,'Chattahoochee, FL 32324',10094,222,NULL,11,14072,0);
INSERT INTO "django_geo_db_location" VALUES(24460,NULL,'Crawfordville, FL',10095,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24461,NULL,'Crawfordville, FL 32326',10095,222,NULL,11,14073,0);
INSERT INTO "django_geo_db_location" VALUES(24462,NULL,'Crawfordville, FL 32327',10095,222,NULL,11,14074,0);
INSERT INTO "django_geo_db_location" VALUES(24463,NULL,'Eastpoint, FL',10096,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24464,NULL,'Eastpoint, FL 32328',10096,222,NULL,11,14075,0);
INSERT INTO "django_geo_db_location" VALUES(24465,NULL,'Apalachicola, FL 32329',10090,222,NULL,11,14076,0);
INSERT INTO "django_geo_db_location" VALUES(24466,NULL,'Greensboro, FL',10097,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24467,NULL,'Greensboro, FL 32330',10097,222,NULL,11,14077,0);
INSERT INTO "django_geo_db_location" VALUES(24468,NULL,'Greenville, FL',10098,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24469,NULL,'Greenville, FL 32331',10098,222,NULL,11,14078,0);
INSERT INTO "django_geo_db_location" VALUES(24470,NULL,'Gretna, FL',10099,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24471,NULL,'Gretna, FL 32332',10099,222,NULL,11,14079,0);
INSERT INTO "django_geo_db_location" VALUES(24472,NULL,'Havana, FL',10100,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24473,NULL,'Havana, FL 32333',10100,222,NULL,11,14080,0);
INSERT INTO "django_geo_db_location" VALUES(24474,NULL,'Hosford, FL',10101,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24475,NULL,'Hosford, FL 32334',10101,222,NULL,11,14081,0);
INSERT INTO "django_geo_db_location" VALUES(24476,NULL,'Sumatra, FL',10102,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24477,NULL,'Sumatra, FL 32335',10102,222,NULL,11,14082,0);
INSERT INTO "django_geo_db_location" VALUES(24478,NULL,'Lamont, FL',10103,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24479,NULL,'Lamont, FL 32336',10103,222,NULL,11,14083,0);
INSERT INTO "django_geo_db_location" VALUES(24480,NULL,'Lloyd, FL',10104,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24481,NULL,'Lloyd, FL 32337',10104,222,NULL,11,14084,0);
INSERT INTO "django_geo_db_location" VALUES(24482,NULL,'Madison, FL',10105,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24483,NULL,'Madison, FL 32340',10105,222,NULL,11,14085,0);
INSERT INTO "django_geo_db_location" VALUES(24484,NULL,'Madison, FL 32341',10105,222,NULL,11,14086,0);
INSERT INTO "django_geo_db_location" VALUES(24485,NULL,'Midway, FL',10106,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24486,NULL,'Midway, FL 32342',10106,222,NULL,11,14087,0);
INSERT INTO "django_geo_db_location" VALUES(24487,NULL,'Midway, FL 32343',10106,222,NULL,11,14088,0);
INSERT INTO "django_geo_db_location" VALUES(24488,NULL,'Monticello, FL',10107,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24489,NULL,'Monticello, FL 32344',10107,222,NULL,11,14089,0);
INSERT INTO "django_geo_db_location" VALUES(24490,NULL,'Monticello, FL 32345',10107,222,NULL,11,14090,0);
INSERT INTO "django_geo_db_location" VALUES(24491,NULL,'Panacea, FL',10108,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24492,NULL,'Panacea, FL 32346',10108,222,NULL,11,14091,0);
INSERT INTO "django_geo_db_location" VALUES(24493,NULL,'Perry, FL',10109,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24494,NULL,'Perry, FL 32347',10109,222,NULL,11,14092,0);
INSERT INTO "django_geo_db_location" VALUES(24495,NULL,'Perry, FL 32348',10109,222,NULL,11,14093,0);
INSERT INTO "django_geo_db_location" VALUES(24496,NULL,'Perry, FL 32349',10109,222,NULL,11,14094,0);
INSERT INTO "django_geo_db_location" VALUES(24497,NULL,'Pinetta, FL',10110,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24498,NULL,'Pinetta, FL 32350',10110,222,NULL,11,14095,0);
INSERT INTO "django_geo_db_location" VALUES(24499,NULL,'Quincy, FL',10111,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24500,NULL,'Quincy, FL 32351',10111,222,NULL,11,14096,0);
INSERT INTO "django_geo_db_location" VALUES(24501,NULL,'Mount Pleasant, FL',10112,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24502,NULL,'Mount Pleasant, FL 32352',10112,222,NULL,11,14097,0);
INSERT INTO "django_geo_db_location" VALUES(24503,NULL,'Quincy, FL 32353',10111,222,NULL,11,14098,0);
INSERT INTO "django_geo_db_location" VALUES(24504,NULL,'Saint Marks, FL',10113,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24505,NULL,'Saint Marks, FL 32355',10113,222,NULL,11,14099,0);
INSERT INTO "django_geo_db_location" VALUES(24506,NULL,'Salem, FL',10114,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24507,NULL,'Salem, FL 32356',10114,222,NULL,11,14100,0);
INSERT INTO "django_geo_db_location" VALUES(24508,NULL,'Shady Grove, FL',10115,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24509,NULL,'Shady Grove, FL 32357',10115,222,NULL,11,14101,0);
INSERT INTO "django_geo_db_location" VALUES(24510,NULL,'Sopchoppy, FL',10116,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24511,NULL,'Sopchoppy, FL 32358',10116,222,NULL,11,14102,0);
INSERT INTO "django_geo_db_location" VALUES(24512,NULL,'Steinhatchee, FL',10117,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24513,NULL,'Steinhatchee, FL 32359',10117,222,NULL,11,14103,0);
INSERT INTO "django_geo_db_location" VALUES(24514,NULL,'Telogia, FL',10118,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24515,NULL,'Telogia, FL 32360',10118,222,NULL,11,14104,0);
INSERT INTO "django_geo_db_location" VALUES(24516,NULL,'Wacissa, FL',10119,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24517,NULL,'Wacissa, FL 32361',10119,222,NULL,11,14105,0);
INSERT INTO "django_geo_db_location" VALUES(24518,NULL,'Woodville, FL',10120,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24519,NULL,'Woodville, FL 32362',10120,222,NULL,11,14106,0);
INSERT INTO "django_geo_db_location" VALUES(24520,NULL,'Tallahassee, FL 32395',10087,222,NULL,11,14107,0);
INSERT INTO "django_geo_db_location" VALUES(24521,NULL,'Tallahassee, FL 32399',10087,222,NULL,11,14108,0);
INSERT INTO "django_geo_db_location" VALUES(24522,NULL,'Panama City, FL',10121,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24523,NULL,'Panama City, FL 32401',10121,222,NULL,11,14109,0);
INSERT INTO "django_geo_db_location" VALUES(24524,NULL,'Panama City, FL 32402',10121,222,NULL,11,14110,0);
INSERT INTO "django_geo_db_location" VALUES(24525,NULL,'Panama City, FL 32403',10121,222,NULL,11,14111,0);
INSERT INTO "django_geo_db_location" VALUES(24526,NULL,'Panama City, FL 32404',10121,222,NULL,11,14112,0);
INSERT INTO "django_geo_db_location" VALUES(24527,NULL,'Panama City, FL 32405',10121,222,NULL,11,14113,0);
INSERT INTO "django_geo_db_location" VALUES(24528,NULL,'Panama City, FL 32406',10121,222,NULL,11,14114,0);
INSERT INTO "django_geo_db_location" VALUES(24529,NULL,'Panama City Beach, FL',10122,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24530,NULL,'Panama City Beach, FL 32407',10122,222,NULL,11,14115,0);
INSERT INTO "django_geo_db_location" VALUES(24531,NULL,'Panama City, FL 32408',10121,222,NULL,11,14116,0);
INSERT INTO "django_geo_db_location" VALUES(24532,NULL,'Panama City, FL 32409',10121,222,NULL,11,14117,0);
INSERT INTO "django_geo_db_location" VALUES(24533,NULL,'Mexico Beach, FL',10123,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24534,NULL,'Mexico Beach, FL 32410',10123,222,NULL,11,14118,0);
INSERT INTO "django_geo_db_location" VALUES(24535,NULL,'Panama City, FL 32411',10121,222,NULL,11,14119,0);
INSERT INTO "django_geo_db_location" VALUES(24536,NULL,'Panama City, FL 32412',10121,222,NULL,11,14120,0);
INSERT INTO "django_geo_db_location" VALUES(24537,NULL,'Panama City Beach, FL 32413',10122,222,NULL,11,14121,0);
INSERT INTO "django_geo_db_location" VALUES(24538,NULL,'Panama City, FL 32417',10121,222,NULL,11,14122,0);
INSERT INTO "django_geo_db_location" VALUES(24539,NULL,'Alford, FL',10124,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24540,NULL,'Alford, FL 32420',10124,222,NULL,11,14123,0);
INSERT INTO "django_geo_db_location" VALUES(24541,NULL,'Altha, FL',10125,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24542,NULL,'Altha, FL 32421',10125,222,NULL,11,14124,0);
INSERT INTO "django_geo_db_location" VALUES(24543,NULL,'Argyle, FL',10126,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24544,NULL,'Argyle, FL 32422',10126,222,NULL,11,14125,0);
INSERT INTO "django_geo_db_location" VALUES(24545,NULL,'Bascom, FL',10127,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24546,NULL,'Bascom, FL 32423',10127,222,NULL,11,14126,0);
INSERT INTO "django_geo_db_location" VALUES(24547,NULL,'Blountstown, FL',10128,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24548,NULL,'Blountstown, FL 32424',10128,222,NULL,11,14127,0);
INSERT INTO "django_geo_db_location" VALUES(24549,NULL,'Bonifay, FL',10129,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24550,NULL,'Bonifay, FL 32425',10129,222,NULL,11,14128,0);
INSERT INTO "django_geo_db_location" VALUES(24551,NULL,'Campbellton, FL',10130,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24552,NULL,'Campbellton, FL 32426',10130,222,NULL,11,14129,0);
INSERT INTO "django_geo_db_location" VALUES(24553,NULL,'Caryville, FL',10131,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24554,NULL,'Caryville, FL 32427',10131,222,NULL,11,14130,0);
INSERT INTO "django_geo_db_location" VALUES(24555,NULL,'Chipley, FL',10132,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24556,NULL,'Chipley, FL 32428',10132,222,NULL,11,14131,0);
INSERT INTO "django_geo_db_location" VALUES(24557,NULL,'Clarksville, FL',10133,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24558,NULL,'Clarksville, FL 32430',10133,222,NULL,11,14132,0);
INSERT INTO "django_geo_db_location" VALUES(24559,NULL,'Cottondale, FL',10134,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24560,NULL,'Cottondale, FL 32431',10134,222,NULL,11,14133,0);
INSERT INTO "django_geo_db_location" VALUES(24561,NULL,'Cypress, FL',10135,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24562,NULL,'Cypress, FL 32432',10135,222,NULL,11,14134,0);
INSERT INTO "django_geo_db_location" VALUES(24563,NULL,'Defuniak Springs, FL',10136,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24564,NULL,'Defuniak Springs, FL 32433',10136,222,NULL,11,14135,0);
INSERT INTO "django_geo_db_location" VALUES(24565,NULL,'Mossy Head, FL',10137,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24566,NULL,'Mossy Head, FL 32434',10137,222,NULL,11,14136,0);
INSERT INTO "django_geo_db_location" VALUES(24567,NULL,'Defuniak Springs, FL 32435',10136,222,NULL,11,14137,0);
INSERT INTO "django_geo_db_location" VALUES(24568,NULL,'Wewahitchka, FL',10138,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24569,NULL,'Wewahitchka, FL 32436',10138,222,NULL,11,14138,0);
INSERT INTO "django_geo_db_location" VALUES(24570,NULL,'Ebro, FL',10139,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24571,NULL,'Ebro, FL 32437',10139,222,NULL,11,14139,0);
INSERT INTO "django_geo_db_location" VALUES(24572,NULL,'Fountain, FL',10140,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24573,NULL,'Fountain, FL 32438',10140,222,NULL,11,14140,0);
INSERT INTO "django_geo_db_location" VALUES(24574,NULL,'Freeport, FL',10141,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24575,NULL,'Freeport, FL 32439',10141,222,NULL,11,14141,0);
INSERT INTO "django_geo_db_location" VALUES(24576,NULL,'Graceville, FL',10142,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24577,NULL,'Graceville, FL 32440',10142,222,NULL,11,14142,0);
INSERT INTO "django_geo_db_location" VALUES(24578,NULL,'Grand Ridge, FL',10143,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24579,NULL,'Grand Ridge, FL 32442',10143,222,NULL,11,14143,0);
INSERT INTO "django_geo_db_location" VALUES(24580,NULL,'Greenwood, FL',10144,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24581,NULL,'Greenwood, FL 32443',10144,222,NULL,11,14144,0);
INSERT INTO "django_geo_db_location" VALUES(24582,NULL,'Lynn Haven, FL',10145,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24583,NULL,'Lynn Haven, FL 32444',10145,222,NULL,11,14145,0);
INSERT INTO "django_geo_db_location" VALUES(24584,NULL,'Malone, FL',10146,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24585,NULL,'Malone, FL 32445',10146,222,NULL,11,14146,0);
INSERT INTO "django_geo_db_location" VALUES(24586,NULL,'Marianna, FL',10147,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24587,NULL,'Marianna, FL 32446',10147,222,NULL,11,14147,0);
INSERT INTO "django_geo_db_location" VALUES(24588,NULL,'Marianna, FL 32447',10147,222,NULL,11,14148,0);
INSERT INTO "django_geo_db_location" VALUES(24589,NULL,'Marianna, FL 32448',10147,222,NULL,11,14149,0);
INSERT INTO "django_geo_db_location" VALUES(24590,NULL,'Kinard, FL',10148,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24591,NULL,'Kinard, FL 32449',10148,222,NULL,11,14150,0);
INSERT INTO "django_geo_db_location" VALUES(24592,NULL,'Noma, FL',10149,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24593,NULL,'Noma, FL 32452',10149,222,NULL,11,14151,0);
INSERT INTO "django_geo_db_location" VALUES(24594,NULL,'Point Washington, FL',10150,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24595,NULL,'Point Washington, FL 32454',10150,222,NULL,11,14152,0);
INSERT INTO "django_geo_db_location" VALUES(24596,NULL,'Ponce De Leon, FL',10151,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24597,NULL,'Ponce De Leon, FL 32455',10151,222,NULL,11,14153,0);
INSERT INTO "django_geo_db_location" VALUES(24598,NULL,'Port Saint Joe, FL',10152,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24599,NULL,'Port Saint Joe, FL 32456',10152,222,NULL,11,14154,0);
INSERT INTO "django_geo_db_location" VALUES(24600,NULL,'Port Saint Joe, FL 32457',10152,222,NULL,11,14155,0);
INSERT INTO "django_geo_db_location" VALUES(24601,NULL,'Santa Rosa Beach, FL',10153,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24602,NULL,'Santa Rosa Beach, FL 32459',10153,222,NULL,11,14156,0);
INSERT INTO "django_geo_db_location" VALUES(24603,NULL,'Sneads, FL',10154,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24604,NULL,'Sneads, FL 32460',10154,222,NULL,11,14157,0);
INSERT INTO "django_geo_db_location" VALUES(24605,NULL,'Sunnyside, FL',10155,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24606,NULL,'Sunnyside, FL 32461',10155,222,NULL,11,14158,0);
INSERT INTO "django_geo_db_location" VALUES(24607,NULL,'Vernon, FL',10156,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24608,NULL,'Vernon, FL 32462',10156,222,NULL,11,14159,0);
INSERT INTO "django_geo_db_location" VALUES(24609,NULL,'Wausau, FL',10157,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24610,NULL,'Wausau, FL 32463',10157,222,NULL,11,14160,0);
INSERT INTO "django_geo_db_location" VALUES(24611,NULL,'Westville, FL',10158,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24612,NULL,'Westville, FL 32464',10158,222,NULL,11,14161,0);
INSERT INTO "django_geo_db_location" VALUES(24613,NULL,'Wewahitchka, FL 32465',10138,222,NULL,11,14162,0);
INSERT INTO "django_geo_db_location" VALUES(24614,NULL,'Youngstown, FL',10159,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24615,NULL,'Youngstown, FL 32466',10159,222,NULL,11,14163,0);
INSERT INTO "django_geo_db_location" VALUES(24616,NULL,'Lake Mary, FL',10160,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24617,NULL,'Lake Mary, FL 32476',10160,222,NULL,11,14164,0);
INSERT INTO "django_geo_db_location" VALUES(24618,NULL,'Chipley, FL 32478',10132,222,NULL,11,14165,0);
INSERT INTO "django_geo_db_location" VALUES(24619,NULL,'Pensacola, FL',10161,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24620,NULL,'Pensacola, FL 32501',10161,222,NULL,11,14166,0);
INSERT INTO "django_geo_db_location" VALUES(24621,NULL,'Pensacola, FL 32502',10161,222,NULL,11,14167,0);
INSERT INTO "django_geo_db_location" VALUES(24622,NULL,'Pensacola, FL 32503',10161,222,NULL,11,14168,0);
INSERT INTO "django_geo_db_location" VALUES(24623,NULL,'Pensacola, FL 32504',10161,222,NULL,11,14169,0);
INSERT INTO "django_geo_db_location" VALUES(24624,NULL,'Pensacola, FL 32505',10161,222,NULL,11,14170,0);
INSERT INTO "django_geo_db_location" VALUES(24625,NULL,'Pensacola, FL 32506',10161,222,NULL,11,14171,0);
INSERT INTO "django_geo_db_location" VALUES(24626,NULL,'Pensacola, FL 32507',10161,222,NULL,11,14172,0);
INSERT INTO "django_geo_db_location" VALUES(24627,NULL,'Pensacola, FL 32508',10161,222,NULL,11,14173,0);
INSERT INTO "django_geo_db_location" VALUES(24628,NULL,'Pensacola, FL 32509',10161,222,NULL,11,14174,0);
INSERT INTO "django_geo_db_location" VALUES(24629,NULL,'Pensacola, FL 32511',10161,222,NULL,11,14175,0);
INSERT INTO "django_geo_db_location" VALUES(24630,NULL,'Pensacola, FL 32512',10161,222,NULL,11,14176,0);
INSERT INTO "django_geo_db_location" VALUES(24631,NULL,'Pensacola, FL 32513',10161,222,NULL,11,14177,0);
INSERT INTO "django_geo_db_location" VALUES(24632,NULL,'Pensacola, FL 32514',10161,222,NULL,11,14178,0);
INSERT INTO "django_geo_db_location" VALUES(24633,NULL,'Pensacola, FL 32516',10161,222,NULL,11,14179,0);
INSERT INTO "django_geo_db_location" VALUES(24634,NULL,'Pensacola, FL 32520',10161,222,NULL,11,14180,0);
INSERT INTO "django_geo_db_location" VALUES(24635,NULL,'Pensacola, FL 32521',10161,222,NULL,11,14181,0);
INSERT INTO "django_geo_db_location" VALUES(24636,NULL,'Pensacola, FL 32522',10161,222,NULL,11,14182,0);
INSERT INTO "django_geo_db_location" VALUES(24637,NULL,'Pensacola, FL 32523',10161,222,NULL,11,14183,0);
INSERT INTO "django_geo_db_location" VALUES(24638,NULL,'Pensacola, FL 32524',10161,222,NULL,11,14184,0);
INSERT INTO "django_geo_db_location" VALUES(24639,NULL,'Pensacola, FL 32526',10161,222,NULL,11,14185,0);
INSERT INTO "django_geo_db_location" VALUES(24640,NULL,'Bagdad, FL',10162,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24641,NULL,'Bagdad, FL 32530',10162,222,NULL,11,14186,0);
INSERT INTO "django_geo_db_location" VALUES(24642,NULL,'Baker, FL',10163,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24643,NULL,'Baker, FL 32531',10163,222,NULL,11,14187,0);
INSERT INTO "django_geo_db_location" VALUES(24644,NULL,'Cantonment, FL',10164,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24645,NULL,'Cantonment, FL 32533',10164,222,NULL,11,14188,0);
INSERT INTO "django_geo_db_location" VALUES(24646,NULL,'Pensacola, FL 32534',10161,222,NULL,11,14189,0);
INSERT INTO "django_geo_db_location" VALUES(24647,NULL,'Century, FL',10165,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24648,NULL,'Century, FL 32535',10165,222,NULL,11,14190,0);
INSERT INTO "django_geo_db_location" VALUES(24649,NULL,'Crestview, FL',10166,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24650,NULL,'Crestview, FL 32536',10166,222,NULL,11,14191,0);
INSERT INTO "django_geo_db_location" VALUES(24651,NULL,'Milligan, FL',10167,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24652,NULL,'Milligan, FL 32537',10167,222,NULL,11,14192,0);
INSERT INTO "django_geo_db_location" VALUES(24653,NULL,'Paxton, FL',10168,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24654,NULL,'Paxton, FL 32538',10168,222,NULL,11,14193,0);
INSERT INTO "django_geo_db_location" VALUES(24655,NULL,'Crestview, FL 32539',10166,222,NULL,11,14194,0);
INSERT INTO "django_geo_db_location" VALUES(24656,NULL,'Destin, FL',10169,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24657,NULL,'Destin, FL 32540',10169,222,NULL,11,14195,0);
INSERT INTO "django_geo_db_location" VALUES(24658,NULL,'Destin, FL 32541',10169,222,NULL,11,14196,0);
INSERT INTO "django_geo_db_location" VALUES(24659,NULL,'Eglin AFB, FL',10170,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24660,NULL,'Eglin AFB, FL 32542',10170,222,NULL,11,14197,0);
INSERT INTO "django_geo_db_location" VALUES(24661,NULL,'Hurlburt Field, FL',10171,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24662,NULL,'Hurlburt Field, FL 32544',10171,222,NULL,11,14198,0);
INSERT INTO "django_geo_db_location" VALUES(24663,NULL,'Myrtle Grove, FL',10172,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24664,NULL,'Myrtle Grove, FL 32546',10172,222,NULL,11,14199,0);
INSERT INTO "django_geo_db_location" VALUES(24665,NULL,'Fort Walton Beach, FL',10173,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24666,NULL,'Fort Walton Beach, FL 32547',10173,222,NULL,11,14200,0);
INSERT INTO "django_geo_db_location" VALUES(24667,NULL,'Fort Walton Beach, FL 32548',10173,222,NULL,11,14201,0);
INSERT INTO "django_geo_db_location" VALUES(24668,NULL,'Fort Walton Beach, FL 32549',10173,222,NULL,11,14202,0);
INSERT INTO "django_geo_db_location" VALUES(24669,NULL,'Miramar Beach, FL',10174,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24670,NULL,'Miramar Beach, FL 32550',10174,222,NULL,11,14203,0);
INSERT INTO "django_geo_db_location" VALUES(24671,NULL,'Pensacola, FL 32559',10161,222,NULL,11,14204,0);
INSERT INTO "django_geo_db_location" VALUES(24672,NULL,'Gonzalez, FL',10175,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24673,NULL,'Gonzalez, FL 32560',10175,222,NULL,11,14205,0);
INSERT INTO "django_geo_db_location" VALUES(24674,NULL,'Gulf Breeze, FL',10176,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24675,NULL,'Gulf Breeze, FL 32561',10176,222,NULL,11,14206,0);
INSERT INTO "django_geo_db_location" VALUES(24676,NULL,'Gulf Breeze, FL 32562',10176,222,NULL,11,14207,0);
INSERT INTO "django_geo_db_location" VALUES(24677,NULL,'Harold, FL',10177,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24678,NULL,'Harold, FL 32563',10177,222,NULL,11,14208,0);
INSERT INTO "django_geo_db_location" VALUES(24679,NULL,'Holt, FL',10178,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24680,NULL,'Holt, FL 32564',10178,222,NULL,11,14209,0);
INSERT INTO "django_geo_db_location" VALUES(24681,NULL,'Jay, FL',10179,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24682,NULL,'Jay, FL 32565',10179,222,NULL,11,14210,0);
INSERT INTO "django_geo_db_location" VALUES(24683,NULL,'Gulf Breeze, FL 32566',10176,222,NULL,11,14211,0);
INSERT INTO "django_geo_db_location" VALUES(24684,NULL,'Laurel Hill, FL',10180,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24685,NULL,'Laurel Hill, FL 32567',10180,222,NULL,11,14212,0);
INSERT INTO "django_geo_db_location" VALUES(24686,NULL,'McDavid, FL',10181,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24687,NULL,'McDavid, FL 32568',10181,222,NULL,11,14213,0);
INSERT INTO "django_geo_db_location" VALUES(24688,NULL,'Mary Esther, FL',10182,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24689,NULL,'Mary Esther, FL 32569',10182,222,NULL,11,14214,0);
INSERT INTO "django_geo_db_location" VALUES(24690,NULL,'Milton, FL',10183,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24691,NULL,'Milton, FL 32570',10183,222,NULL,11,14215,0);
INSERT INTO "django_geo_db_location" VALUES(24692,NULL,'Milton, FL 32571',10183,222,NULL,11,14216,0);
INSERT INTO "django_geo_db_location" VALUES(24693,NULL,'Milton, FL 32572',10183,222,NULL,11,14217,0);
INSERT INTO "django_geo_db_location" VALUES(24694,NULL,'Pensacola, FL 32573',10161,222,NULL,11,14218,0);
INSERT INTO "django_geo_db_location" VALUES(24695,NULL,'Pensacola, FL 32574',10161,222,NULL,11,14219,0);
INSERT INTO "django_geo_db_location" VALUES(24696,NULL,'Pensacola, FL 32575',10161,222,NULL,11,14220,0);
INSERT INTO "django_geo_db_location" VALUES(24697,NULL,'Pensacola, FL 32576',10161,222,NULL,11,14221,0);
INSERT INTO "django_geo_db_location" VALUES(24698,NULL,'Molino, FL',10184,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24699,NULL,'Molino, FL 32577',10184,222,NULL,11,14222,0);
INSERT INTO "django_geo_db_location" VALUES(24700,NULL,'Niceville, FL',10185,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24701,NULL,'Niceville, FL 32578',10185,222,NULL,11,14223,0);
INSERT INTO "django_geo_db_location" VALUES(24702,NULL,'Shalimar, FL',10186,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24703,NULL,'Shalimar, FL 32579',10186,222,NULL,11,14224,0);
INSERT INTO "django_geo_db_location" VALUES(24704,NULL,'Valparaiso, FL',10187,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24705,NULL,'Valparaiso, FL 32580',10187,222,NULL,11,14225,0);
INSERT INTO "django_geo_db_location" VALUES(24706,NULL,'Pensacola, FL 32581',10161,222,NULL,11,14226,0);
INSERT INTO "django_geo_db_location" VALUES(24707,NULL,'Pensacola, FL 32582',10161,222,NULL,11,14227,0);
INSERT INTO "django_geo_db_location" VALUES(24708,NULL,'Milton, FL 32583',10183,222,NULL,11,14228,0);
INSERT INTO "django_geo_db_location" VALUES(24709,NULL,'Niceville, FL 32588',10185,222,NULL,11,14229,0);
INSERT INTO "django_geo_db_location" VALUES(24710,NULL,'Pensacola, FL 32589',10161,222,NULL,11,14230,0);
INSERT INTO "django_geo_db_location" VALUES(24711,NULL,'Pensacola, FL 32590',10161,222,NULL,11,14231,0);
INSERT INTO "django_geo_db_location" VALUES(24712,NULL,'Pensacola, FL 32591',10161,222,NULL,11,14232,0);
INSERT INTO "django_geo_db_location" VALUES(24713,NULL,'Pensacola, FL 32592',10161,222,NULL,11,14233,0);
INSERT INTO "django_geo_db_location" VALUES(24714,NULL,'Pensacola, FL 32593',10161,222,NULL,11,14234,0);
INSERT INTO "django_geo_db_location" VALUES(24715,NULL,'Pensacola, FL 32594',10161,222,NULL,11,14235,0);
INSERT INTO "django_geo_db_location" VALUES(24716,NULL,'Pensacola, FL 32595',10161,222,NULL,11,14236,0);
INSERT INTO "django_geo_db_location" VALUES(24717,NULL,'Pensacola, FL 32596',10161,222,NULL,11,14237,0);
INSERT INTO "django_geo_db_location" VALUES(24718,NULL,'Pensacola, FL 32597',10161,222,NULL,11,14238,0);
INSERT INTO "django_geo_db_location" VALUES(24719,NULL,'Pensacola, FL 32598',10161,222,NULL,11,14239,0);
INSERT INTO "django_geo_db_location" VALUES(24720,NULL,'Gainesville, FL',10188,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24721,NULL,'Gainesville, FL 32601',10188,222,NULL,11,14240,0);
INSERT INTO "django_geo_db_location" VALUES(24722,NULL,'Gainesville, FL 32602',10188,222,NULL,11,14241,0);
INSERT INTO "django_geo_db_location" VALUES(24723,NULL,'Gainesville, FL 32603',10188,222,NULL,11,14242,0);
INSERT INTO "django_geo_db_location" VALUES(24724,NULL,'Gainesville, FL 32604',10188,222,NULL,11,14243,0);
INSERT INTO "django_geo_db_location" VALUES(24725,NULL,'Gainesville, FL 32605',10188,222,NULL,11,14244,0);
INSERT INTO "django_geo_db_location" VALUES(24726,NULL,'Gainesville, FL 32606',10188,222,NULL,11,14245,0);
INSERT INTO "django_geo_db_location" VALUES(24727,NULL,'Gainesville, FL 32607',10188,222,NULL,11,14246,0);
INSERT INTO "django_geo_db_location" VALUES(24728,NULL,'Gainesville, FL 32608',10188,222,NULL,11,14247,0);
INSERT INTO "django_geo_db_location" VALUES(24729,NULL,'Gainesville, FL 32609',10188,222,NULL,11,14248,0);
INSERT INTO "django_geo_db_location" VALUES(24730,NULL,'Gainesville, FL 32610',10188,222,NULL,11,14249,0);
INSERT INTO "django_geo_db_location" VALUES(24731,NULL,'Gainesville, FL 32611',10188,222,NULL,11,14250,0);
INSERT INTO "django_geo_db_location" VALUES(24732,NULL,'Gainesville, FL 32612',10188,222,NULL,11,14251,0);
INSERT INTO "django_geo_db_location" VALUES(24733,NULL,'Gainesville, FL 32613',10188,222,NULL,11,14252,0);
INSERT INTO "django_geo_db_location" VALUES(24734,NULL,'Gainesville, FL 32614',10188,222,NULL,11,14253,0);
INSERT INTO "django_geo_db_location" VALUES(24735,NULL,'Alachua, FL',10189,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24736,NULL,'Alachua, FL 32615',10189,222,NULL,11,14254,0);
INSERT INTO "django_geo_db_location" VALUES(24737,NULL,'Alachua, FL 32616',10189,222,NULL,11,14255,0);
INSERT INTO "django_geo_db_location" VALUES(24738,NULL,'Anthony, FL',10190,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24739,NULL,'Anthony, FL 32617',10190,222,NULL,11,14256,0);
INSERT INTO "django_geo_db_location" VALUES(24740,NULL,'Archer, FL',10191,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24741,NULL,'Archer, FL 32618',10191,222,NULL,11,14257,0);
INSERT INTO "django_geo_db_location" VALUES(24742,NULL,'Bell, FL',10192,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24743,NULL,'Bell, FL 32619',10192,222,NULL,11,14258,0);
INSERT INTO "django_geo_db_location" VALUES(24744,NULL,'Bronson, FL',10193,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24745,NULL,'Bronson, FL 32621',10193,222,NULL,11,14259,0);
INSERT INTO "django_geo_db_location" VALUES(24746,NULL,'Brooker, FL',10194,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24747,NULL,'Brooker, FL 32622',10194,222,NULL,11,14260,0);
INSERT INTO "django_geo_db_location" VALUES(24748,NULL,'Cedar Key, FL',10195,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24749,NULL,'Cedar Key, FL 32625',10195,222,NULL,11,14261,0);
INSERT INTO "django_geo_db_location" VALUES(24750,NULL,'Chiefland, FL',10196,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24751,NULL,'Chiefland, FL 32626',10196,222,NULL,11,14262,0);
INSERT INTO "django_geo_db_location" VALUES(24752,NULL,'Gainesville, FL 32627',10188,222,NULL,11,14263,0);
INSERT INTO "django_geo_db_location" VALUES(24753,NULL,'Cross City, FL',10197,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24754,NULL,'Cross City, FL 32628',10197,222,NULL,11,14264,0);
INSERT INTO "django_geo_db_location" VALUES(24755,NULL,'Earleton, FL',10198,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24756,NULL,'Earleton, FL 32631',10198,222,NULL,11,14265,0);
INSERT INTO "django_geo_db_location" VALUES(24757,NULL,'Evinston, FL',10199,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24758,NULL,'Evinston, FL 32633',10199,222,NULL,11,14266,0);
INSERT INTO "django_geo_db_location" VALUES(24759,NULL,'Fairfield, FL',10200,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24760,NULL,'Fairfield, FL 32634',10200,222,NULL,11,14267,0);
INSERT INTO "django_geo_db_location" VALUES(24761,NULL,'Gainesville, FL 32635',10188,222,NULL,11,14268,0);
INSERT INTO "django_geo_db_location" VALUES(24762,NULL,'Trenton, FL',10201,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24763,NULL,'Trenton, FL 32638',10201,222,NULL,11,14269,0);
INSERT INTO "django_geo_db_location" VALUES(24764,NULL,'Gulf Hammock, FL',10202,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24765,NULL,'Gulf Hammock, FL 32639',10202,222,NULL,11,14270,0);
INSERT INTO "django_geo_db_location" VALUES(24766,NULL,'Hawthorne, FL',10203,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24767,NULL,'Hawthorne, FL 32640',10203,222,NULL,11,14271,0);
INSERT INTO "django_geo_db_location" VALUES(24768,NULL,'Gainesville, FL 32641',10188,222,NULL,11,14272,0);
INSERT INTO "django_geo_db_location" VALUES(24769,NULL,'High Springs, FL',10204,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24770,NULL,'High Springs, FL 32643',10204,222,NULL,11,14273,0);
INSERT INTO "django_geo_db_location" VALUES(24771,NULL,'Chiefland, FL 32644',10196,222,NULL,11,14274,0);
INSERT INTO "django_geo_db_location" VALUES(24772,NULL,'Horseshoe Beach, FL',10205,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24773,NULL,'Horseshoe Beach, FL 32648',10205,222,NULL,11,14275,0);
INSERT INTO "django_geo_db_location" VALUES(24774,NULL,'Gainesville, FL 32653',10188,222,NULL,11,14276,0);
INSERT INTO "django_geo_db_location" VALUES(24775,NULL,'Island Grove, FL',10206,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24776,NULL,'Island Grove, FL 32654',10206,222,NULL,11,14277,0);
INSERT INTO "django_geo_db_location" VALUES(24777,NULL,'High Springs, FL 32655',10204,222,NULL,11,14278,0);
INSERT INTO "django_geo_db_location" VALUES(24778,NULL,'Keystone Heights, FL',10207,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24779,NULL,'Keystone Heights, FL 32656',10207,222,NULL,11,14279,0);
INSERT INTO "django_geo_db_location" VALUES(24780,NULL,'La Crosse, FL',10208,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24781,NULL,'La Crosse, FL 32658',10208,222,NULL,11,14280,0);
INSERT INTO "django_geo_db_location" VALUES(24782,NULL,'Lochloosa, FL',10209,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24783,NULL,'Lochloosa, FL 32662',10209,222,NULL,11,14281,0);
INSERT INTO "django_geo_db_location" VALUES(24784,NULL,'Lowell, FL',10210,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24785,NULL,'Lowell, FL 32663',10210,222,NULL,11,14282,0);
INSERT INTO "django_geo_db_location" VALUES(24786,NULL,'McIntosh, FL',10211,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24787,NULL,'McIntosh, FL 32664',10211,222,NULL,11,14283,0);
INSERT INTO "django_geo_db_location" VALUES(24788,NULL,'Melrose, FL',10212,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24789,NULL,'Melrose, FL 32666',10212,222,NULL,11,14284,0);
INSERT INTO "django_geo_db_location" VALUES(24790,NULL,'Micanopy, FL',10213,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24791,NULL,'Micanopy, FL 32667',10213,222,NULL,11,14285,0);
INSERT INTO "django_geo_db_location" VALUES(24792,NULL,'Morriston, FL',10214,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24793,NULL,'Morriston, FL 32668',10214,222,NULL,11,14286,0);
INSERT INTO "django_geo_db_location" VALUES(24794,NULL,'Newberry, FL',10215,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24795,NULL,'Newberry, FL 32669',10215,222,NULL,11,14287,0);
INSERT INTO "django_geo_db_location" VALUES(24796,NULL,'Old Town, FL',10216,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24797,NULL,'Old Town, FL 32680',10216,222,NULL,11,14288,0);
INSERT INTO "django_geo_db_location" VALUES(24798,NULL,'Orange Lake, FL',10217,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24799,NULL,'Orange Lake, FL 32681',10217,222,NULL,11,14289,0);
INSERT INTO "django_geo_db_location" VALUES(24800,NULL,'Otter Creek, FL',10218,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24801,NULL,'Otter Creek, FL 32683',10218,222,NULL,11,14290,0);
INSERT INTO "django_geo_db_location" VALUES(24802,NULL,'Reddick, FL',10219,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24803,NULL,'Reddick, FL 32686',10219,222,NULL,11,14291,0);
INSERT INTO "django_geo_db_location" VALUES(24804,NULL,'Suwannee, FL',10220,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24805,NULL,'Suwannee, FL 32692',10220,222,NULL,11,14292,0);
INSERT INTO "django_geo_db_location" VALUES(24806,NULL,'Trenton, FL 32693',10201,222,NULL,11,14293,0);
INSERT INTO "django_geo_db_location" VALUES(24807,NULL,'Waldo, FL',10221,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24808,NULL,'Waldo, FL 32694',10221,222,NULL,11,14294,0);
INSERT INTO "django_geo_db_location" VALUES(24809,NULL,'Williston, FL',10222,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24810,NULL,'Williston, FL 32696',10222,222,NULL,11,14295,0);
INSERT INTO "django_geo_db_location" VALUES(24811,NULL,'Worthington Springs, FL',10223,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24812,NULL,'Worthington Springs, FL 32697',10223,222,NULL,11,14296,0);
INSERT INTO "django_geo_db_location" VALUES(24813,NULL,'Newberry, FL 32699',10215,222,NULL,11,14297,0);
INSERT INTO "django_geo_db_location" VALUES(24814,NULL,'Altamonte Springs, FL',10224,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24815,NULL,'Altamonte Springs, FL 32701',10224,222,NULL,11,14298,0);
INSERT INTO "django_geo_db_location" VALUES(24816,NULL,'Altoona, FL',10225,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24817,NULL,'Altoona, FL 32702',10225,222,NULL,11,14299,0);
INSERT INTO "django_geo_db_location" VALUES(24818,NULL,'Apopka, FL',10226,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24819,NULL,'Apopka, FL 32703',10226,222,NULL,11,14300,0);
INSERT INTO "django_geo_db_location" VALUES(24820,NULL,'Apopka, FL 32704',10226,222,NULL,11,14301,0);
INSERT INTO "django_geo_db_location" VALUES(24821,NULL,'Cassadaga, FL',10227,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24822,NULL,'Cassadaga, FL 32706',10227,222,NULL,11,14302,0);
INSERT INTO "django_geo_db_location" VALUES(24823,NULL,'Casselberry, FL',10228,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24824,NULL,'Casselberry, FL 32707',10228,222,NULL,11,14303,0);
INSERT INTO "django_geo_db_location" VALUES(24825,NULL,'Winter Springs, FL',10229,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24826,NULL,'Winter Springs, FL 32708',10229,222,NULL,11,14304,0);
INSERT INTO "django_geo_db_location" VALUES(24827,NULL,'Christmas, FL',10230,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24828,NULL,'Christmas, FL 32709',10230,222,NULL,11,14305,0);
INSERT INTO "django_geo_db_location" VALUES(24829,NULL,'Clarcona, FL',10231,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24830,NULL,'Clarcona, FL 32710',10231,222,NULL,11,14306,0);
INSERT INTO "django_geo_db_location" VALUES(24831,NULL,'Apopka, FL 32712',10226,222,NULL,11,14307,0);
INSERT INTO "django_geo_db_location" VALUES(24832,NULL,'Debary, FL',10232,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24833,NULL,'Debary, FL 32713',10232,222,NULL,11,14308,0);
INSERT INTO "django_geo_db_location" VALUES(24834,NULL,'Altamonte Springs, FL 32714',10224,222,NULL,11,14309,0);
INSERT INTO "django_geo_db_location" VALUES(24835,NULL,'Altamonte Springs, FL 32715',10224,222,NULL,11,14310,0);
INSERT INTO "django_geo_db_location" VALUES(24836,NULL,'Altamonte Springs, FL 32716',10224,222,NULL,11,14311,0);
INSERT INTO "django_geo_db_location" VALUES(24837,NULL,'Casselberry, FL 32718',10228,222,NULL,11,14312,0);
INSERT INTO "django_geo_db_location" VALUES(24838,NULL,'Winter Springs, FL 32719',10229,222,NULL,11,14313,0);
INSERT INTO "django_geo_db_location" VALUES(24839,NULL,'Deland, FL',10233,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24840,NULL,'Deland, FL 32720',10233,222,NULL,11,14314,0);
INSERT INTO "django_geo_db_location" VALUES(24841,NULL,'Deland, FL 32721',10233,222,NULL,11,14315,0);
INSERT INTO "django_geo_db_location" VALUES(24842,NULL,'Glenwood, FL',10234,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24843,NULL,'Glenwood, FL 32722',10234,222,NULL,11,14316,0);
INSERT INTO "django_geo_db_location" VALUES(24844,NULL,'Deland, FL 32724',10233,222,NULL,11,14317,0);
INSERT INTO "django_geo_db_location" VALUES(24845,NULL,'Deltona, FL',10235,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24846,NULL,'Deltona, FL 32725',10235,222,NULL,11,14318,0);
INSERT INTO "django_geo_db_location" VALUES(24847,NULL,'Eustis, FL',10236,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24848,NULL,'Eustis, FL 32726',10236,222,NULL,11,14319,0);
INSERT INTO "django_geo_db_location" VALUES(24849,NULL,'Eustis, FL 32727',10236,222,NULL,11,14320,0);
INSERT INTO "django_geo_db_location" VALUES(24850,NULL,'Deltona, FL 32728',10235,222,NULL,11,14321,0);
INSERT INTO "django_geo_db_location" VALUES(24851,NULL,'Casselberry, FL 32730',10228,222,NULL,11,14322,0);
INSERT INTO "django_geo_db_location" VALUES(24852,NULL,'Geneva, FL',10237,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24853,NULL,'Geneva, FL 32732',10237,222,NULL,11,14323,0);
INSERT INTO "django_geo_db_location" VALUES(24854,NULL,'Goldenrod, FL',10238,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24855,NULL,'Goldenrod, FL 32733',10238,222,NULL,11,14324,0);
INSERT INTO "django_geo_db_location" VALUES(24856,NULL,'Grand Island, FL',10239,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24857,NULL,'Grand Island, FL 32735',10239,222,NULL,11,14325,0);
INSERT INTO "django_geo_db_location" VALUES(24858,NULL,'Eustis, FL 32736',10236,222,NULL,11,14326,0);
INSERT INTO "django_geo_db_location" VALUES(24859,NULL,'Deltona, FL 32738',10235,222,NULL,11,14327,0);
INSERT INTO "django_geo_db_location" VALUES(24860,NULL,'Deltona, FL 32739',10235,222,NULL,11,14328,0);
INSERT INTO "django_geo_db_location" VALUES(24861,NULL,'Lake Helen, FL',10240,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24862,NULL,'Lake Helen, FL 32744',10240,222,NULL,11,14329,0);
INSERT INTO "django_geo_db_location" VALUES(24863,NULL,'Heathrow, FL',10241,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24864,NULL,'Heathrow, FL 32745',10241,222,NULL,11,14330,0);
INSERT INTO "django_geo_db_location" VALUES(24865,NULL,'Lake Mary, FL 32746',10160,222,NULL,11,14331,0);
INSERT INTO "django_geo_db_location" VALUES(24866,NULL,'Lake Monroe, FL',10242,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24867,NULL,'Lake Monroe, FL 32747',10242,222,NULL,11,14332,0);
INSERT INTO "django_geo_db_location" VALUES(24868,NULL,'Longwood, FL',10243,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24869,NULL,'Longwood, FL 32750',10243,222,NULL,11,14333,0);
INSERT INTO "django_geo_db_location" VALUES(24870,NULL,'Maitland, FL',10244,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24871,NULL,'Maitland, FL 32751',10244,222,NULL,11,14334,0);
INSERT INTO "django_geo_db_location" VALUES(24872,NULL,'Longwood, FL 32752',10243,222,NULL,11,14335,0);
INSERT INTO "django_geo_db_location" VALUES(24873,NULL,'Mims, FL',10245,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24874,NULL,'Mims, FL 32754',10245,222,NULL,11,14336,0);
INSERT INTO "django_geo_db_location" VALUES(24875,NULL,'Mount Dora, FL',10246,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24876,NULL,'Mount Dora, FL 32756',10246,222,NULL,11,14337,0);
INSERT INTO "django_geo_db_location" VALUES(24877,NULL,'Mount Dora, FL 32757',10246,222,NULL,11,14338,0);
INSERT INTO "django_geo_db_location" VALUES(24878,NULL,'Oak Hill, FL',10247,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24879,NULL,'Oak Hill, FL 32759',10247,222,NULL,11,14339,0);
INSERT INTO "django_geo_db_location" VALUES(24880,NULL,'Oviedo, FL',10248,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24881,NULL,'Oviedo, FL 32762',10248,222,NULL,11,14340,0);
INSERT INTO "django_geo_db_location" VALUES(24882,NULL,'Orange City, FL',10249,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24883,NULL,'Orange City, FL 32763',10249,222,NULL,11,14341,0);
INSERT INTO "django_geo_db_location" VALUES(24884,NULL,'Osteen, FL',10250,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24885,NULL,'Osteen, FL 32764',10250,222,NULL,11,14342,0);
INSERT INTO "django_geo_db_location" VALUES(24886,NULL,'Oviedo, FL 32765',10248,222,NULL,11,14343,0);
INSERT INTO "django_geo_db_location" VALUES(24887,NULL,'Oviedo, FL 32766',10248,222,NULL,11,14344,0);
INSERT INTO "django_geo_db_location" VALUES(24888,NULL,'Paisley, FL',10251,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24889,NULL,'Paisley, FL 32767',10251,222,NULL,11,14345,0);
INSERT INTO "django_geo_db_location" VALUES(24890,NULL,'Plymouth, FL',10252,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24891,NULL,'Plymouth, FL 32768',10252,222,NULL,11,14346,0);
INSERT INTO "django_geo_db_location" VALUES(24892,NULL,'Oak Hill, FL 32769',10247,222,NULL,11,14347,0);
INSERT INTO "django_geo_db_location" VALUES(24893,NULL,'Sanford, FL',10253,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24894,NULL,'Sanford, FL 32771',10253,222,NULL,11,14348,0);
INSERT INTO "django_geo_db_location" VALUES(24895,NULL,'Sanford, FL 32772',10253,222,NULL,11,14349,0);
INSERT INTO "django_geo_db_location" VALUES(24896,NULL,'Sanford, FL 32773',10253,222,NULL,11,14350,0);
INSERT INTO "django_geo_db_location" VALUES(24897,NULL,'Orange City, FL 32774',10249,222,NULL,11,14351,0);
INSERT INTO "django_geo_db_location" VALUES(24898,NULL,'Scottsmoor, FL',10254,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24899,NULL,'Scottsmoor, FL 32775',10254,222,NULL,11,14352,0);
INSERT INTO "django_geo_db_location" VALUES(24900,NULL,'Sorrento, FL',10255,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24901,NULL,'Sorrento, FL 32776',10255,222,NULL,11,14353,0);
INSERT INTO "django_geo_db_location" VALUES(24902,NULL,'Tangerine, FL',10256,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24903,NULL,'Tangerine, FL 32777',10256,222,NULL,11,14354,0);
INSERT INTO "django_geo_db_location" VALUES(24904,NULL,'Tavares, FL',10257,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24905,NULL,'Tavares, FL 32778',10257,222,NULL,11,14355,0);
INSERT INTO "django_geo_db_location" VALUES(24906,NULL,'Longwood, FL 32779',10243,222,NULL,11,14356,0);
INSERT INTO "django_geo_db_location" VALUES(24907,NULL,'Titusville, FL',10258,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24908,NULL,'Titusville, FL 32780',10258,222,NULL,11,14357,0);
INSERT INTO "django_geo_db_location" VALUES(24909,NULL,'Titusville, FL 32781',10258,222,NULL,11,14358,0);
INSERT INTO "django_geo_db_location" VALUES(24910,NULL,'Titusville, FL 32782',10258,222,NULL,11,14359,0);
INSERT INTO "django_geo_db_location" VALUES(24911,NULL,'Titusville, FL 32783',10258,222,NULL,11,14360,0);
INSERT INTO "django_geo_db_location" VALUES(24912,NULL,'Umatilla, FL',10259,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24913,NULL,'Umatilla, FL 32784',10259,222,NULL,11,14361,0);
INSERT INTO "django_geo_db_location" VALUES(24914,NULL,'Winter Park, FL',10260,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24915,NULL,'Winter Park, FL 32789',10260,222,NULL,11,14362,0);
INSERT INTO "django_geo_db_location" VALUES(24916,NULL,'Winter Park, FL 32790',10260,222,NULL,11,14363,0);
INSERT INTO "django_geo_db_location" VALUES(24917,NULL,'Longwood, FL 32791',10243,222,NULL,11,14364,0);
INSERT INTO "django_geo_db_location" VALUES(24918,NULL,'Winter Park, FL 32792',10260,222,NULL,11,14365,0);
INSERT INTO "django_geo_db_location" VALUES(24919,NULL,'Winter Park, FL 32793',10260,222,NULL,11,14366,0);
INSERT INTO "django_geo_db_location" VALUES(24920,NULL,'Maitland, FL 32794',10244,222,NULL,11,14367,0);
INSERT INTO "django_geo_db_location" VALUES(24921,NULL,'Lake Mary, FL 32795',10160,222,NULL,11,14368,0);
INSERT INTO "django_geo_db_location" VALUES(24922,NULL,'Titusville, FL 32796',10258,222,NULL,11,14369,0);
INSERT INTO "django_geo_db_location" VALUES(24923,NULL,'Zellwood, FL',10261,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24924,NULL,'Zellwood, FL 32798',10261,222,NULL,11,14370,0);
INSERT INTO "django_geo_db_location" VALUES(24925,NULL,'Mid Florida, FL',10262,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24926,NULL,'Mid Florida, FL 32799',10262,222,NULL,11,14371,0);
INSERT INTO "django_geo_db_location" VALUES(24927,NULL,'Orlando, FL',10263,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24928,NULL,'Orlando, FL 32801',10263,222,NULL,11,14372,0);
INSERT INTO "django_geo_db_location" VALUES(24929,NULL,'Orlando, FL 32802',10263,222,NULL,11,14373,0);
INSERT INTO "django_geo_db_location" VALUES(24930,NULL,'Orlando, FL 32803',10263,222,NULL,11,14374,0);
INSERT INTO "django_geo_db_location" VALUES(24931,NULL,'Orlando, FL 32804',10263,222,NULL,11,14375,0);
INSERT INTO "django_geo_db_location" VALUES(24932,NULL,'Orlando, FL 32805',10263,222,NULL,11,14376,0);
INSERT INTO "django_geo_db_location" VALUES(24933,NULL,'Orlando, FL 32806',10263,222,NULL,11,14377,0);
INSERT INTO "django_geo_db_location" VALUES(24934,NULL,'Orlando, FL 32807',10263,222,NULL,11,14378,0);
INSERT INTO "django_geo_db_location" VALUES(24935,NULL,'Orlando, FL 32808',10263,222,NULL,11,14379,0);
INSERT INTO "django_geo_db_location" VALUES(24936,NULL,'Orlando, FL 32809',10263,222,NULL,11,14380,0);
INSERT INTO "django_geo_db_location" VALUES(24937,NULL,'Orlando, FL 32810',10263,222,NULL,11,14381,0);
INSERT INTO "django_geo_db_location" VALUES(24938,NULL,'Orlando, FL 32811',10263,222,NULL,11,14382,0);
INSERT INTO "django_geo_db_location" VALUES(24939,NULL,'Orlando, FL 32812',10263,222,NULL,11,14383,0);
INSERT INTO "django_geo_db_location" VALUES(24940,NULL,'Orlando, FL 32813',10263,222,NULL,11,14384,0);
INSERT INTO "django_geo_db_location" VALUES(24941,NULL,'Orlando, FL 32814',10263,222,NULL,11,14385,0);
INSERT INTO "django_geo_db_location" VALUES(24942,NULL,'Orlando, FL 32815',10263,222,NULL,11,14386,0);
INSERT INTO "django_geo_db_location" VALUES(24943,NULL,'Orlando, FL 32816',10263,222,NULL,11,14387,0);
INSERT INTO "django_geo_db_location" VALUES(24944,NULL,'Orlando, FL 32817',10263,222,NULL,11,14388,0);
INSERT INTO "django_geo_db_location" VALUES(24945,NULL,'Orlando, FL 32818',10263,222,NULL,11,14389,0);
INSERT INTO "django_geo_db_location" VALUES(24946,NULL,'Orlando, FL 32819',10263,222,NULL,11,14390,0);
INSERT INTO "django_geo_db_location" VALUES(24947,NULL,'Orlando, FL 32820',10263,222,NULL,11,14391,0);
INSERT INTO "django_geo_db_location" VALUES(24948,NULL,'Orlando, FL 32821',10263,222,NULL,11,14392,0);
INSERT INTO "django_geo_db_location" VALUES(24949,NULL,'Orlando, FL 32822',10263,222,NULL,11,14393,0);
INSERT INTO "django_geo_db_location" VALUES(24950,NULL,'Orlando, FL 32824',10263,222,NULL,11,14394,0);
INSERT INTO "django_geo_db_location" VALUES(24951,NULL,'Orlando, FL 32825',10263,222,NULL,11,14395,0);
INSERT INTO "django_geo_db_location" VALUES(24952,NULL,'Orlando, FL 32826',10263,222,NULL,11,14396,0);
INSERT INTO "django_geo_db_location" VALUES(24953,NULL,'Orlando, FL 32827',10263,222,NULL,11,14397,0);
INSERT INTO "django_geo_db_location" VALUES(24954,NULL,'Orlando, FL 32828',10263,222,NULL,11,14398,0);
INSERT INTO "django_geo_db_location" VALUES(24955,NULL,'Orlando, FL 32829',10263,222,NULL,11,14399,0);
INSERT INTO "django_geo_db_location" VALUES(24956,NULL,'Orlando, FL 32830',10263,222,NULL,11,14400,0);
INSERT INTO "django_geo_db_location" VALUES(24957,NULL,'Orlando, FL 32831',10263,222,NULL,11,14401,0);
INSERT INTO "django_geo_db_location" VALUES(24958,NULL,'Orlando, FL 32832',10263,222,NULL,11,14402,0);
INSERT INTO "django_geo_db_location" VALUES(24959,NULL,'Orlando, FL 32833',10263,222,NULL,11,14403,0);
INSERT INTO "django_geo_db_location" VALUES(24960,NULL,'Orlando, FL 32834',10263,222,NULL,11,14404,0);
INSERT INTO "django_geo_db_location" VALUES(24961,NULL,'Orlando, FL 32835',10263,222,NULL,11,14405,0);
INSERT INTO "django_geo_db_location" VALUES(24962,NULL,'Orlando, FL 32836',10263,222,NULL,11,14406,0);
INSERT INTO "django_geo_db_location" VALUES(24963,NULL,'Orlando, FL 32837',10263,222,NULL,11,14407,0);
INSERT INTO "django_geo_db_location" VALUES(24964,NULL,'Orlando, FL 32839',10263,222,NULL,11,14408,0);
INSERT INTO "django_geo_db_location" VALUES(24965,NULL,'Orlando, FL 32853',10263,222,NULL,11,14409,0);
INSERT INTO "django_geo_db_location" VALUES(24966,NULL,'Orlando, FL 32854',10263,222,NULL,11,14410,0);
INSERT INTO "django_geo_db_location" VALUES(24967,NULL,'Orlando, FL 32855',10263,222,NULL,11,14411,0);
INSERT INTO "django_geo_db_location" VALUES(24968,NULL,'Orlando, FL 32856',10263,222,NULL,11,14412,0);
INSERT INTO "django_geo_db_location" VALUES(24969,NULL,'Orlando, FL 32857',10263,222,NULL,11,14413,0);
INSERT INTO "django_geo_db_location" VALUES(24970,NULL,'Orlando, FL 32858',10263,222,NULL,11,14414,0);
INSERT INTO "django_geo_db_location" VALUES(24971,NULL,'Orlando, FL 32859',10263,222,NULL,11,14415,0);
INSERT INTO "django_geo_db_location" VALUES(24972,NULL,'Orlando, FL 32860',10263,222,NULL,11,14416,0);
INSERT INTO "django_geo_db_location" VALUES(24973,NULL,'Orlando, FL 32861',10263,222,NULL,11,14417,0);
INSERT INTO "django_geo_db_location" VALUES(24974,NULL,'Orlando, FL 32862',10263,222,NULL,11,14418,0);
INSERT INTO "django_geo_db_location" VALUES(24975,NULL,'Orlando, FL 32867',10263,222,NULL,11,14419,0);
INSERT INTO "django_geo_db_location" VALUES(24976,NULL,'Orlando, FL 32868',10263,222,NULL,11,14420,0);
INSERT INTO "django_geo_db_location" VALUES(24977,NULL,'Orlando, FL 32869',10263,222,NULL,11,14421,0);
INSERT INTO "django_geo_db_location" VALUES(24978,NULL,'Orlando, FL 32872',10263,222,NULL,11,14422,0);
INSERT INTO "django_geo_db_location" VALUES(24979,NULL,'Orlando, FL 32877',10263,222,NULL,11,14423,0);
INSERT INTO "django_geo_db_location" VALUES(24980,NULL,'Orlando, FL 32878',10263,222,NULL,11,14424,0);
INSERT INTO "django_geo_db_location" VALUES(24981,NULL,'Orlando, FL 32886',10263,222,NULL,11,14425,0);
INSERT INTO "django_geo_db_location" VALUES(24982,NULL,'Orlando, FL 32887',10263,222,NULL,11,14426,0);
INSERT INTO "django_geo_db_location" VALUES(24983,NULL,'Orlando, FL 32889',10263,222,NULL,11,14427,0);
INSERT INTO "django_geo_db_location" VALUES(24984,NULL,'Orlando, FL 32890',10263,222,NULL,11,14428,0);
INSERT INTO "django_geo_db_location" VALUES(24985,NULL,'Orlando, FL 32891',10263,222,NULL,11,14429,0);
INSERT INTO "django_geo_db_location" VALUES(24986,NULL,'Orlando, FL 32893',10263,222,NULL,11,14430,0);
INSERT INTO "django_geo_db_location" VALUES(24987,NULL,'Orlando, FL 32897',10263,222,NULL,11,14431,0);
INSERT INTO "django_geo_db_location" VALUES(24988,NULL,'Orlando, FL 32898',10263,222,NULL,11,14432,0);
INSERT INTO "django_geo_db_location" VALUES(24989,NULL,'Orlando, FL 32899',10263,222,NULL,11,14433,0);
INSERT INTO "django_geo_db_location" VALUES(24990,NULL,'Melbourne, FL',10264,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24991,NULL,'Melbourne, FL 32901',10264,222,NULL,11,14434,0);
INSERT INTO "django_geo_db_location" VALUES(24992,NULL,'Melbourne, FL 32902',10264,222,NULL,11,14435,0);
INSERT INTO "django_geo_db_location" VALUES(24993,NULL,'Indialantic, FL',10265,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24994,NULL,'Indialantic, FL 32903',10265,222,NULL,11,14436,0);
INSERT INTO "django_geo_db_location" VALUES(24995,NULL,'Melbourne, FL 32904',10264,222,NULL,11,14437,0);
INSERT INTO "django_geo_db_location" VALUES(24996,NULL,'Palm Bay, FL',10266,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(24997,NULL,'Palm Bay, FL 32905',10266,222,NULL,11,14438,0);
INSERT INTO "django_geo_db_location" VALUES(24998,NULL,'Palm Bay, FL 32906',10266,222,NULL,11,14439,0);
INSERT INTO "django_geo_db_location" VALUES(24999,NULL,'Palm Bay, FL 32907',10266,222,NULL,11,14440,0);
INSERT INTO "django_geo_db_location" VALUES(25000,NULL,'Palm Bay, FL 32908',10266,222,NULL,11,14441,0);
INSERT INTO "django_geo_db_location" VALUES(25001,NULL,'Palm Bay, FL 32909',10266,222,NULL,11,14442,0);
INSERT INTO "django_geo_db_location" VALUES(25002,NULL,'Palm Bay, FL 32910',10266,222,NULL,11,14443,0);
INSERT INTO "django_geo_db_location" VALUES(25003,NULL,'Palm Bay, FL 32911',10266,222,NULL,11,14444,0);
INSERT INTO "django_geo_db_location" VALUES(25004,NULL,'Melbourne, FL 32912',10264,222,NULL,11,14445,0);
INSERT INTO "django_geo_db_location" VALUES(25005,NULL,'Melbourne, FL 32919',10264,222,NULL,11,14446,0);
INSERT INTO "django_geo_db_location" VALUES(25006,NULL,'Cape Canaveral, FL',10267,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25007,NULL,'Cape Canaveral, FL 32920',10267,222,NULL,11,14447,0);
INSERT INTO "django_geo_db_location" VALUES(25008,NULL,'Cocoa, FL',10268,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25009,NULL,'Cocoa, FL 32922',10268,222,NULL,11,14448,0);
INSERT INTO "django_geo_db_location" VALUES(25010,NULL,'Cocoa, FL 32923',10268,222,NULL,11,14449,0);
INSERT INTO "django_geo_db_location" VALUES(25011,NULL,'Cocoa, FL 32924',10268,222,NULL,11,14450,0);
INSERT INTO "django_geo_db_location" VALUES(25012,NULL,'Patrick AFB, FL',10269,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25013,NULL,'Patrick AFB, FL 32925',10269,222,NULL,11,14451,0);
INSERT INTO "django_geo_db_location" VALUES(25014,NULL,'Cocoa, FL 32926',10268,222,NULL,11,14452,0);
INSERT INTO "django_geo_db_location" VALUES(25015,NULL,'Cocoa, FL 32927',10268,222,NULL,11,14453,0);
INSERT INTO "django_geo_db_location" VALUES(25016,NULL,'Cocoa Beach, FL',10270,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25017,NULL,'Cocoa Beach, FL 32931',10270,222,NULL,11,14454,0);
INSERT INTO "django_geo_db_location" VALUES(25018,NULL,'Cocoa Beach, FL 32932',10270,222,NULL,11,14455,0);
INSERT INTO "django_geo_db_location" VALUES(25019,NULL,'Melbourne, FL 32934',10264,222,NULL,11,14456,0);
INSERT INTO "django_geo_db_location" VALUES(25020,NULL,'Melbourne, FL 32935',10264,222,NULL,11,14457,0);
INSERT INTO "django_geo_db_location" VALUES(25021,NULL,'Melbourne, FL 32936',10264,222,NULL,11,14458,0);
INSERT INTO "django_geo_db_location" VALUES(25022,NULL,'Satellite Beach, FL',10271,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25023,NULL,'Satellite Beach, FL 32937',10271,222,NULL,11,14459,0);
INSERT INTO "django_geo_db_location" VALUES(25024,NULL,'Melbourne, FL 32940',10264,222,NULL,11,14460,0);
INSERT INTO "django_geo_db_location" VALUES(25025,NULL,'Melbourne, FL 32941',10264,222,NULL,11,14461,0);
INSERT INTO "django_geo_db_location" VALUES(25026,NULL,'Fellsmere, FL',10272,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25027,NULL,'Fellsmere, FL 32948',10272,222,NULL,11,14462,0);
INSERT INTO "django_geo_db_location" VALUES(25028,NULL,'Grant, FL',10273,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25029,NULL,'Grant, FL 32949',10273,222,NULL,11,14463,0);
INSERT INTO "django_geo_db_location" VALUES(25030,NULL,'Malabar, FL',10274,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25031,NULL,'Malabar, FL 32950',10274,222,NULL,11,14464,0);
INSERT INTO "django_geo_db_location" VALUES(25032,NULL,'Melbourne Beach, FL',10275,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25033,NULL,'Melbourne Beach, FL 32951',10275,222,NULL,11,14465,0);
INSERT INTO "django_geo_db_location" VALUES(25034,NULL,'Merritt Island, FL',10276,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25035,NULL,'Merritt Island, FL 32952',10276,222,NULL,11,14466,0);
INSERT INTO "django_geo_db_location" VALUES(25036,NULL,'Merritt Island, FL 32953',10276,222,NULL,11,14467,0);
INSERT INTO "django_geo_db_location" VALUES(25037,NULL,'Merritt Island, FL 32954',10276,222,NULL,11,14468,0);
INSERT INTO "django_geo_db_location" VALUES(25038,NULL,'Rockledge, FL',10277,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25039,NULL,'Rockledge, FL 32955',10277,222,NULL,11,14469,0);
INSERT INTO "django_geo_db_location" VALUES(25040,NULL,'Rockledge, FL 32956',10277,222,NULL,11,14470,0);
INSERT INTO "django_geo_db_location" VALUES(25041,NULL,'Roseland, FL',10278,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25042,NULL,'Roseland, FL 32957',10278,222,NULL,11,14471,0);
INSERT INTO "django_geo_db_location" VALUES(25043,NULL,'Sebastian, FL',10279,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25044,NULL,'Sebastian, FL 32958',10279,222,NULL,11,14472,0);
INSERT INTO "django_geo_db_location" VALUES(25045,NULL,'Sharpes, FL',10280,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25046,NULL,'Sharpes, FL 32959',10280,222,NULL,11,14473,0);
INSERT INTO "django_geo_db_location" VALUES(25047,NULL,'Vero Beach, FL',10281,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25048,NULL,'Vero Beach, FL 32960',10281,222,NULL,11,14474,0);
INSERT INTO "django_geo_db_location" VALUES(25049,NULL,'Vero Beach, FL 32961',10281,222,NULL,11,14475,0);
INSERT INTO "django_geo_db_location" VALUES(25050,NULL,'Vero Beach, FL 32962',10281,222,NULL,11,14476,0);
INSERT INTO "django_geo_db_location" VALUES(25051,NULL,'Vero Beach, FL 32963',10281,222,NULL,11,14477,0);
INSERT INTO "django_geo_db_location" VALUES(25052,NULL,'Vero Beach, FL 32964',10281,222,NULL,11,14478,0);
INSERT INTO "django_geo_db_location" VALUES(25053,NULL,'Vero Beach, FL 32965',10281,222,NULL,11,14479,0);
INSERT INTO "django_geo_db_location" VALUES(25054,NULL,'Vero Beach, FL 32966',10281,222,NULL,11,14480,0);
INSERT INTO "django_geo_db_location" VALUES(25055,NULL,'Vero Beach, FL 32967',10281,222,NULL,11,14481,0);
INSERT INTO "django_geo_db_location" VALUES(25056,NULL,'Vero Beach, FL 32968',10281,222,NULL,11,14482,0);
INSERT INTO "django_geo_db_location" VALUES(25057,NULL,'Vero Beach, FL 32969',10281,222,NULL,11,14483,0);
INSERT INTO "django_geo_db_location" VALUES(25058,NULL,'Wabasso, FL',10282,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25059,NULL,'Wabasso, FL 32970',10282,222,NULL,11,14484,0);
INSERT INTO "django_geo_db_location" VALUES(25060,NULL,'Winter Beach, FL',10283,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25061,NULL,'Winter Beach, FL 32971',10283,222,NULL,11,14485,0);
INSERT INTO "django_geo_db_location" VALUES(25062,NULL,'Sebastian, FL 32976',10279,222,NULL,11,14486,0);
INSERT INTO "django_geo_db_location" VALUES(25063,NULL,'Winter Beach, FL 32977',10283,222,NULL,11,14487,0);
INSERT INTO "django_geo_db_location" VALUES(25064,NULL,'Sebastian, FL 32978',10279,222,NULL,11,14488,0);
INSERT INTO "django_geo_db_location" VALUES(25065,NULL,'Long Key, FL',10284,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25066,NULL,'Long Key, FL 33001',10284,222,NULL,11,14489,0);
INSERT INTO "django_geo_db_location" VALUES(25067,NULL,'Hialeah, FL',10285,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25068,NULL,'Hialeah, FL 33002',10285,222,NULL,11,14490,0);
INSERT INTO "django_geo_db_location" VALUES(25069,NULL,'Florida City, FL',10286,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25070,NULL,'Florida City, FL 33003',10286,222,NULL,11,14491,0);
INSERT INTO "django_geo_db_location" VALUES(25071,NULL,'Dania, FL',10287,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25072,NULL,'Dania, FL 33004',10287,222,NULL,11,14492,0);
INSERT INTO "django_geo_db_location" VALUES(25073,NULL,'Hallandale, FL',10288,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25074,NULL,'Hallandale, FL 33008',10288,222,NULL,11,14493,0);
INSERT INTO "django_geo_db_location" VALUES(25075,NULL,'Hallandale, FL 33009',10288,222,NULL,11,14494,0);
INSERT INTO "django_geo_db_location" VALUES(25076,NULL,'Hialeah, FL 33010',10285,222,NULL,11,14495,0);
INSERT INTO "django_geo_db_location" VALUES(25077,NULL,'Hialeah, FL 33011',10285,222,NULL,11,14496,0);
INSERT INTO "django_geo_db_location" VALUES(25078,NULL,'Hialeah, FL 33012',10285,222,NULL,11,14497,0);
INSERT INTO "django_geo_db_location" VALUES(25079,NULL,'Hialeah, FL 33013',10285,222,NULL,11,14498,0);
INSERT INTO "django_geo_db_location" VALUES(25080,NULL,'Hialeah, FL 33014',10285,222,NULL,11,14499,0);
INSERT INTO "django_geo_db_location" VALUES(25081,NULL,'Hialeah, FL 33015',10285,222,NULL,11,14500,0);
INSERT INTO "django_geo_db_location" VALUES(25082,NULL,'Hialeah, FL 33016',10285,222,NULL,11,14501,0);
INSERT INTO "django_geo_db_location" VALUES(25083,NULL,'Hialeah, FL 33017',10285,222,NULL,11,14502,0);
INSERT INTO "django_geo_db_location" VALUES(25084,NULL,'Hialeah, FL 33018',10285,222,NULL,11,14503,0);
INSERT INTO "django_geo_db_location" VALUES(25085,NULL,'Hollywood, FL',10289,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25086,NULL,'Hollywood, FL 33019',10289,222,NULL,11,14504,0);
INSERT INTO "django_geo_db_location" VALUES(25087,NULL,'Hollywood, FL 33020',10289,222,NULL,11,14505,0);
INSERT INTO "django_geo_db_location" VALUES(25088,NULL,'Hollywood, FL 33021',10289,222,NULL,11,14506,0);
INSERT INTO "django_geo_db_location" VALUES(25089,NULL,'Hollywood, FL 33022',10289,222,NULL,11,14507,0);
INSERT INTO "django_geo_db_location" VALUES(25090,NULL,'Hollywood, FL 33023',10289,222,NULL,11,14508,0);
INSERT INTO "django_geo_db_location" VALUES(25091,NULL,'Hollywood, FL 33024',10289,222,NULL,11,14509,0);
INSERT INTO "django_geo_db_location" VALUES(25092,NULL,'Hollywood, FL 33025',10289,222,NULL,11,14510,0);
INSERT INTO "django_geo_db_location" VALUES(25093,NULL,'Hollywood, FL 33026',10289,222,NULL,11,14511,0);
INSERT INTO "django_geo_db_location" VALUES(25094,NULL,'Hollywood, FL 33027',10289,222,NULL,11,14512,0);
INSERT INTO "django_geo_db_location" VALUES(25095,NULL,'Pembroke Pines, FL',10290,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25096,NULL,'Pembroke Pines, FL 33028',10290,222,NULL,11,14513,0);
INSERT INTO "django_geo_db_location" VALUES(25097,NULL,'Hollywood, FL 33029',10289,222,NULL,11,14514,0);
INSERT INTO "django_geo_db_location" VALUES(25098,NULL,'Homestead, FL',10291,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25099,NULL,'Homestead, FL 33030',10291,222,NULL,11,14515,0);
INSERT INTO "django_geo_db_location" VALUES(25100,NULL,'Homestead, FL 33031',10291,222,NULL,11,14516,0);
INSERT INTO "django_geo_db_location" VALUES(25101,NULL,'Homestead, FL 33032',10291,222,NULL,11,14517,0);
INSERT INTO "django_geo_db_location" VALUES(25102,NULL,'Homestead, FL 33033',10291,222,NULL,11,14518,0);
INSERT INTO "django_geo_db_location" VALUES(25103,NULL,'Homestead, FL 33034',10291,222,NULL,11,14519,0);
INSERT INTO "django_geo_db_location" VALUES(25104,NULL,'Homestead, FL 33035',10291,222,NULL,11,14520,0);
INSERT INTO "django_geo_db_location" VALUES(25105,NULL,'Islamorada, FL',10292,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25106,NULL,'Islamorada, FL 33036',10292,222,NULL,11,14521,0);
INSERT INTO "django_geo_db_location" VALUES(25107,NULL,'Key Largo, FL',10293,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25108,NULL,'Key Largo, FL 33037',10293,222,NULL,11,14522,0);
INSERT INTO "django_geo_db_location" VALUES(25109,NULL,'Homestead, FL 33039',10291,222,NULL,11,14523,0);
INSERT INTO "django_geo_db_location" VALUES(25110,NULL,'Key West, FL',10294,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25111,NULL,'Key West, FL 33040',10294,222,NULL,11,14524,0);
INSERT INTO "django_geo_db_location" VALUES(25112,NULL,'Key West, FL 33041',10294,222,NULL,11,14525,0);
INSERT INTO "django_geo_db_location" VALUES(25113,NULL,'Summerland Key, FL',10295,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25114,NULL,'Summerland Key, FL 33042',10295,222,NULL,11,14526,0);
INSERT INTO "django_geo_db_location" VALUES(25115,NULL,'Big Pine Key, FL',10296,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25116,NULL,'Big Pine Key, FL 33043',10296,222,NULL,11,14527,0);
INSERT INTO "django_geo_db_location" VALUES(25117,NULL,'Sugarloaf Shores, FL',10297,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25118,NULL,'Sugarloaf Shores, FL 33044',10297,222,NULL,11,14528,0);
INSERT INTO "django_geo_db_location" VALUES(25119,NULL,'Key West, FL 33045',10294,222,NULL,11,14529,0);
INSERT INTO "django_geo_db_location" VALUES(25120,NULL,'West Little River, FL',10298,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25121,NULL,'West Little River, FL 33047',10298,222,NULL,11,14530,0);
INSERT INTO "django_geo_db_location" VALUES(25122,NULL,'Marathon, FL',10299,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25123,NULL,'Marathon, FL 33050',10299,222,NULL,11,14531,0);
INSERT INTO "django_geo_db_location" VALUES(25124,NULL,'Key Colony Beach, FL',10300,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25125,NULL,'Key Colony Beach, FL 33051',10300,222,NULL,11,14532,0);
INSERT INTO "django_geo_db_location" VALUES(25126,NULL,'Marathon Shores, FL',10301,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25127,NULL,'Marathon Shores, FL 33052',10301,222,NULL,11,14533,0);
INSERT INTO "django_geo_db_location" VALUES(25128,NULL,'Opa Locka, FL',10302,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25129,NULL,'Opa Locka, FL 33054',10302,222,NULL,11,14534,0);
INSERT INTO "django_geo_db_location" VALUES(25130,NULL,'Opa Locka, FL 33055',10302,222,NULL,11,14535,0);
INSERT INTO "django_geo_db_location" VALUES(25131,NULL,'Opa Locka, FL 33056',10302,222,NULL,11,14536,0);
INSERT INTO "django_geo_db_location" VALUES(25132,NULL,'Lake Lucerne, FL',10303,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25133,NULL,'Lake Lucerne, FL 33058',10303,222,NULL,11,14537,0);
INSERT INTO "django_geo_db_location" VALUES(25134,NULL,'Pompano Beach, FL',10304,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25135,NULL,'Pompano Beach, FL 33060',10304,222,NULL,11,14538,0);
INSERT INTO "django_geo_db_location" VALUES(25136,NULL,'Pompano Beach, FL 33061',10304,222,NULL,11,14539,0);
INSERT INTO "django_geo_db_location" VALUES(25137,NULL,'Pompano Beach, FL 33062',10304,222,NULL,11,14540,0);
INSERT INTO "django_geo_db_location" VALUES(25138,NULL,'Pompano Beach, FL 33063',10304,222,NULL,11,14541,0);
INSERT INTO "django_geo_db_location" VALUES(25139,NULL,'Pompano Beach, FL 33064',10304,222,NULL,11,14542,0);
INSERT INTO "django_geo_db_location" VALUES(25140,NULL,'Pompano Beach, FL 33065',10304,222,NULL,11,14543,0);
INSERT INTO "django_geo_db_location" VALUES(25141,NULL,'Pompano Beach, FL 33066',10304,222,NULL,11,14544,0);
INSERT INTO "django_geo_db_location" VALUES(25142,NULL,'Pompano Beach, FL 33067',10304,222,NULL,11,14545,0);
INSERT INTO "django_geo_db_location" VALUES(25143,NULL,'Pompano Beach, FL 33068',10304,222,NULL,11,14546,0);
INSERT INTO "django_geo_db_location" VALUES(25144,NULL,'Pompano Beach, FL 33069',10304,222,NULL,11,14547,0);
INSERT INTO "django_geo_db_location" VALUES(25145,NULL,'Tavernier, FL',10305,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25146,NULL,'Tavernier, FL 33070',10305,222,NULL,11,14548,0);
INSERT INTO "django_geo_db_location" VALUES(25147,NULL,'Pompano Beach, FL 33071',10304,222,NULL,11,14549,0);
INSERT INTO "django_geo_db_location" VALUES(25148,NULL,'Pompano Beach, FL 33072',10304,222,NULL,11,14550,0);
INSERT INTO "django_geo_db_location" VALUES(25149,NULL,'Pompano Beach, FL 33073',10304,222,NULL,11,14551,0);
INSERT INTO "django_geo_db_location" VALUES(25150,NULL,'Pompano Beach, FL 33074',10304,222,NULL,11,14552,0);
INSERT INTO "django_geo_db_location" VALUES(25151,NULL,'Pompano Beach, FL 33075',10304,222,NULL,11,14553,0);
INSERT INTO "django_geo_db_location" VALUES(25152,NULL,'Pompano Beach, FL 33076',10304,222,NULL,11,14554,0);
INSERT INTO "django_geo_db_location" VALUES(25153,NULL,'Pompano Beach, FL 33077',10304,222,NULL,11,14555,0);
INSERT INTO "django_geo_db_location" VALUES(25154,NULL,'Hollywood, FL 33081',10289,222,NULL,11,14556,0);
INSERT INTO "django_geo_db_location" VALUES(25155,NULL,'Pembroke Pines, FL 33082',10290,222,NULL,11,14557,0);
INSERT INTO "django_geo_db_location" VALUES(25156,NULL,'Hollywood, FL 33083',10289,222,NULL,11,14558,0);
INSERT INTO "django_geo_db_location" VALUES(25157,NULL,'Pembroke Pines, FL 33084',10290,222,NULL,11,14559,0);
INSERT INTO "django_geo_db_location" VALUES(25158,NULL,'Homestead, FL 33090',10291,222,NULL,11,14560,0);
INSERT INTO "django_geo_db_location" VALUES(25159,NULL,'Homestead, FL 33092',10291,222,NULL,11,14561,0);
INSERT INTO "django_geo_db_location" VALUES(25160,NULL,'Pompano Beach, FL 33093',10304,222,NULL,11,14562,0);
INSERT INTO "django_geo_db_location" VALUES(25161,NULL,'Pompano Beach, FL 33097',10304,222,NULL,11,14563,0);
INSERT INTO "django_geo_db_location" VALUES(25162,NULL,'Miami, FL',10306,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25163,NULL,'Miami, FL 33101',10306,222,NULL,11,14564,0);
INSERT INTO "django_geo_db_location" VALUES(25164,NULL,'Miami, FL 33102',10306,222,NULL,11,14565,0);
INSERT INTO "django_geo_db_location" VALUES(25165,NULL,'Miami, FL 33107',10306,222,NULL,11,14566,0);
INSERT INTO "django_geo_db_location" VALUES(25166,NULL,'Miami Beach, FL',10307,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25167,NULL,'Miami Beach, FL 33109',10307,222,NULL,11,14567,0);
INSERT INTO "django_geo_db_location" VALUES(25168,NULL,'Miami, FL 33110',10306,222,NULL,11,14568,0);
INSERT INTO "django_geo_db_location" VALUES(25169,NULL,'Miami, FL 33111',10306,222,NULL,11,14569,0);
INSERT INTO "django_geo_db_location" VALUES(25170,NULL,'Miami, FL 33114',10306,222,NULL,11,14570,0);
INSERT INTO "django_geo_db_location" VALUES(25171,NULL,'Miami, FL 33116',10306,222,NULL,11,14571,0);
INSERT INTO "django_geo_db_location" VALUES(25172,NULL,'Miami Beach, FL 33119',10307,222,NULL,11,14572,0);
INSERT INTO "django_geo_db_location" VALUES(25173,NULL,'Miami, FL 33121',10306,222,NULL,11,14573,0);
INSERT INTO "django_geo_db_location" VALUES(25174,NULL,'Miami, FL 33122',10306,222,NULL,11,14574,0);
INSERT INTO "django_geo_db_location" VALUES(25175,NULL,'Miami, FL 33124',10306,222,NULL,11,14575,0);
INSERT INTO "django_geo_db_location" VALUES(25176,NULL,'Miami, FL 33125',10306,222,NULL,11,14576,0);
INSERT INTO "django_geo_db_location" VALUES(25177,NULL,'Miami, FL 33126',10306,222,NULL,11,14577,0);
INSERT INTO "django_geo_db_location" VALUES(25178,NULL,'Miami, FL 33127',10306,222,NULL,11,14578,0);
INSERT INTO "django_geo_db_location" VALUES(25179,NULL,'Miami, FL 33128',10306,222,NULL,11,14579,0);
INSERT INTO "django_geo_db_location" VALUES(25180,NULL,'Miami, FL 33129',10306,222,NULL,11,14580,0);
INSERT INTO "django_geo_db_location" VALUES(25181,NULL,'Miami, FL 33130',10306,222,NULL,11,14581,0);
INSERT INTO "django_geo_db_location" VALUES(25182,NULL,'Miami, FL 33131',10306,222,NULL,11,14582,0);
INSERT INTO "django_geo_db_location" VALUES(25183,NULL,'Miami, FL 33132',10306,222,NULL,11,14583,0);
INSERT INTO "django_geo_db_location" VALUES(25184,NULL,'Miami, FL 33133',10306,222,NULL,11,14584,0);
INSERT INTO "django_geo_db_location" VALUES(25185,NULL,'Miami, FL 33134',10306,222,NULL,11,14585,0);
INSERT INTO "django_geo_db_location" VALUES(25186,NULL,'Miami, FL 33135',10306,222,NULL,11,14586,0);
INSERT INTO "django_geo_db_location" VALUES(25187,NULL,'Miami, FL 33136',10306,222,NULL,11,14587,0);
INSERT INTO "django_geo_db_location" VALUES(25188,NULL,'Miami, FL 33137',10306,222,NULL,11,14588,0);
INSERT INTO "django_geo_db_location" VALUES(25189,NULL,'Miami, FL 33138',10306,222,NULL,11,14589,0);
INSERT INTO "django_geo_db_location" VALUES(25190,NULL,'Miami Beach, FL 33139',10307,222,NULL,11,14590,0);
INSERT INTO "django_geo_db_location" VALUES(25191,NULL,'Miami Beach, FL 33140',10307,222,NULL,11,14591,0);
INSERT INTO "django_geo_db_location" VALUES(25192,NULL,'Miami Beach, FL 33141',10307,222,NULL,11,14592,0);
INSERT INTO "django_geo_db_location" VALUES(25193,NULL,'Miami, FL 33142',10306,222,NULL,11,14593,0);
INSERT INTO "django_geo_db_location" VALUES(25194,NULL,'Miami, FL 33143',10306,222,NULL,11,14594,0);
INSERT INTO "django_geo_db_location" VALUES(25195,NULL,'Miami, FL 33144',10306,222,NULL,11,14595,0);
INSERT INTO "django_geo_db_location" VALUES(25196,NULL,'Miami, FL 33145',10306,222,NULL,11,14596,0);
INSERT INTO "django_geo_db_location" VALUES(25197,NULL,'Miami, FL 33146',10306,222,NULL,11,14597,0);
INSERT INTO "django_geo_db_location" VALUES(25198,NULL,'Miami, FL 33147',10306,222,NULL,11,14598,0);
INSERT INTO "django_geo_db_location" VALUES(25199,NULL,'Miami, FL 33148',10306,222,NULL,11,14599,0);
INSERT INTO "django_geo_db_location" VALUES(25200,NULL,'Key Biscayne, FL',10308,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25201,NULL,'Key Biscayne, FL 33149',10308,222,NULL,11,14600,0);
INSERT INTO "django_geo_db_location" VALUES(25202,NULL,'Miami, FL 33150',10306,222,NULL,11,14601,0);
INSERT INTO "django_geo_db_location" VALUES(25203,NULL,'Miami, FL 33151',10306,222,NULL,11,14602,0);
INSERT INTO "django_geo_db_location" VALUES(25204,NULL,'Miami, FL 33152',10306,222,NULL,11,14603,0);
INSERT INTO "django_geo_db_location" VALUES(25205,NULL,'Miami, FL 33153',10306,222,NULL,11,14604,0);
INSERT INTO "django_geo_db_location" VALUES(25206,NULL,'Miami, FL 33154',10306,222,NULL,11,14605,0);
INSERT INTO "django_geo_db_location" VALUES(25207,NULL,'Miami, FL 33155',10306,222,NULL,11,14606,0);
INSERT INTO "django_geo_db_location" VALUES(25208,NULL,'Miami, FL 33156',10306,222,NULL,11,14607,0);
INSERT INTO "django_geo_db_location" VALUES(25209,NULL,'Miami, FL 33157',10306,222,NULL,11,14608,0);
INSERT INTO "django_geo_db_location" VALUES(25210,NULL,'Miami, FL 33158',10306,222,NULL,11,14609,0);
INSERT INTO "django_geo_db_location" VALUES(25211,NULL,'Miami, FL 33159',10306,222,NULL,11,14610,0);
INSERT INTO "django_geo_db_location" VALUES(25212,NULL,'North Miami Beach, FL',10309,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25213,NULL,'North Miami Beach, FL 33160',10309,222,NULL,11,14611,0);
INSERT INTO "django_geo_db_location" VALUES(25214,NULL,'Miami, FL 33161',10306,222,NULL,11,14612,0);
INSERT INTO "django_geo_db_location" VALUES(25215,NULL,'Miami, FL 33162',10306,222,NULL,11,14613,0);
INSERT INTO "django_geo_db_location" VALUES(25216,NULL,'Miami, FL 33163',10306,222,NULL,11,14614,0);
INSERT INTO "django_geo_db_location" VALUES(25217,NULL,'Miami, FL 33164',10306,222,NULL,11,14615,0);
INSERT INTO "django_geo_db_location" VALUES(25218,NULL,'Miami, FL 33165',10306,222,NULL,11,14616,0);
INSERT INTO "django_geo_db_location" VALUES(25219,NULL,'Miami, FL 33166',10306,222,NULL,11,14617,0);
INSERT INTO "django_geo_db_location" VALUES(25220,NULL,'Miami, FL 33167',10306,222,NULL,11,14618,0);
INSERT INTO "django_geo_db_location" VALUES(25221,NULL,'Miami, FL 33168',10306,222,NULL,11,14619,0);
INSERT INTO "django_geo_db_location" VALUES(25222,NULL,'Miami, FL 33169',10306,222,NULL,11,14620,0);
INSERT INTO "django_geo_db_location" VALUES(25223,NULL,'Miami, FL 33170',10306,222,NULL,11,14621,0);
INSERT INTO "django_geo_db_location" VALUES(25224,NULL,'Miami, FL 33172',10306,222,NULL,11,14622,0);
INSERT INTO "django_geo_db_location" VALUES(25225,NULL,'Miami, FL 33173',10306,222,NULL,11,14623,0);
INSERT INTO "django_geo_db_location" VALUES(25226,NULL,'Miami, FL 33174',10306,222,NULL,11,14624,0);
INSERT INTO "django_geo_db_location" VALUES(25227,NULL,'Miami, FL 33175',10306,222,NULL,11,14625,0);
INSERT INTO "django_geo_db_location" VALUES(25228,NULL,'Miami, FL 33176',10306,222,NULL,11,14626,0);
INSERT INTO "django_geo_db_location" VALUES(25229,NULL,'Miami, FL 33177',10306,222,NULL,11,14627,0);
INSERT INTO "django_geo_db_location" VALUES(25230,NULL,'Miami, FL 33178',10306,222,NULL,11,14628,0);
INSERT INTO "django_geo_db_location" VALUES(25231,NULL,'Miami, FL 33179',10306,222,NULL,11,14629,0);
INSERT INTO "django_geo_db_location" VALUES(25232,NULL,'Miami, FL 33180',10306,222,NULL,11,14630,0);
INSERT INTO "django_geo_db_location" VALUES(25233,NULL,'Miami, FL 33181',10306,222,NULL,11,14631,0);
INSERT INTO "django_geo_db_location" VALUES(25234,NULL,'Miami, FL 33182',10306,222,NULL,11,14632,0);
INSERT INTO "django_geo_db_location" VALUES(25235,NULL,'Miami, FL 33183',10306,222,NULL,11,14633,0);
INSERT INTO "django_geo_db_location" VALUES(25236,NULL,'Miami, FL 33184',10306,222,NULL,11,14634,0);
INSERT INTO "django_geo_db_location" VALUES(25237,NULL,'Miami, FL 33185',10306,222,NULL,11,14635,0);
INSERT INTO "django_geo_db_location" VALUES(25238,NULL,'Miami, FL 33186',10306,222,NULL,11,14636,0);
INSERT INTO "django_geo_db_location" VALUES(25239,NULL,'Miami, FL 33187',10306,222,NULL,11,14637,0);
INSERT INTO "django_geo_db_location" VALUES(25240,NULL,'Miami, FL 33188',10306,222,NULL,11,14638,0);
INSERT INTO "django_geo_db_location" VALUES(25241,NULL,'Miami, FL 33189',10306,222,NULL,11,14639,0);
INSERT INTO "django_geo_db_location" VALUES(25242,NULL,'Miami, FL 33190',10306,222,NULL,11,14640,0);
INSERT INTO "django_geo_db_location" VALUES(25243,NULL,'Miami, FL 33192',10306,222,NULL,11,14641,0);
INSERT INTO "django_geo_db_location" VALUES(25244,NULL,'Miami, FL 33193',10306,222,NULL,11,14642,0);
INSERT INTO "django_geo_db_location" VALUES(25245,NULL,'Miami, FL 33194',10306,222,NULL,11,14643,0);
INSERT INTO "django_geo_db_location" VALUES(25246,NULL,'Miami, FL 33195',10306,222,NULL,11,14644,0);
INSERT INTO "django_geo_db_location" VALUES(25247,NULL,'Miami, FL 33196',10306,222,NULL,11,14645,0);
INSERT INTO "django_geo_db_location" VALUES(25248,NULL,'Miami, FL 33197',10306,222,NULL,11,14646,0);
INSERT INTO "django_geo_db_location" VALUES(25249,NULL,'Miami, FL 33199',10306,222,NULL,11,14647,0);
INSERT INTO "django_geo_db_location" VALUES(25250,NULL,'Hollywood, FL 33201',10289,222,NULL,11,14648,0);
INSERT INTO "django_geo_db_location" VALUES(25251,NULL,'Miami, FL 33231',10306,222,NULL,11,14649,0);
INSERT INTO "django_geo_db_location" VALUES(25252,NULL,'Miami, FL 33233',10306,222,NULL,11,14650,0);
INSERT INTO "django_geo_db_location" VALUES(25253,NULL,'Miami, FL 33234',10306,222,NULL,11,14651,0);
INSERT INTO "django_geo_db_location" VALUES(25254,NULL,'Miami, FL 33238',10306,222,NULL,11,14652,0);
INSERT INTO "django_geo_db_location" VALUES(25255,NULL,'Miami Beach, FL 33239',10307,222,NULL,11,14653,0);
INSERT INTO "django_geo_db_location" VALUES(25256,NULL,'Miami, FL 33242',10306,222,NULL,11,14654,0);
INSERT INTO "django_geo_db_location" VALUES(25257,NULL,'Miami, FL 33243',10306,222,NULL,11,14655,0);
INSERT INTO "django_geo_db_location" VALUES(25258,NULL,'Miami, FL 33245',10306,222,NULL,11,14656,0);
INSERT INTO "django_geo_db_location" VALUES(25259,NULL,'Miami, FL 33247',10306,222,NULL,11,14657,0);
INSERT INTO "django_geo_db_location" VALUES(25260,NULL,'Miami, FL 33255',10306,222,NULL,11,14658,0);
INSERT INTO "django_geo_db_location" VALUES(25261,NULL,'Miami, FL 33256',10306,222,NULL,11,14659,0);
INSERT INTO "django_geo_db_location" VALUES(25262,NULL,'Miami, FL 33257',10306,222,NULL,11,14660,0);
INSERT INTO "django_geo_db_location" VALUES(25263,NULL,'Miami, FL 33261',10306,222,NULL,11,14661,0);
INSERT INTO "django_geo_db_location" VALUES(25264,NULL,'Miami, FL 33265',10306,222,NULL,11,14662,0);
INSERT INTO "django_geo_db_location" VALUES(25265,NULL,'Miami, FL 33266',10306,222,NULL,11,14663,0);
INSERT INTO "django_geo_db_location" VALUES(25266,NULL,'Miami, FL 33269',10306,222,NULL,11,14664,0);
INSERT INTO "django_geo_db_location" VALUES(25267,NULL,'Miami, FL 33280',10306,222,NULL,11,14665,0);
INSERT INTO "django_geo_db_location" VALUES(25268,NULL,'Miami, FL 33283',10306,222,NULL,11,14666,0);
INSERT INTO "django_geo_db_location" VALUES(25269,NULL,'Miami, FL 33296',10306,222,NULL,11,14667,0);
INSERT INTO "django_geo_db_location" VALUES(25270,NULL,'Miami, FL 33299',10306,222,NULL,11,14668,0);
INSERT INTO "django_geo_db_location" VALUES(25271,NULL,'Fort Lauderdale, FL',10310,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25272,NULL,'Fort Lauderdale, FL 33301',10310,222,NULL,11,14669,0);
INSERT INTO "django_geo_db_location" VALUES(25273,NULL,'Fort Lauderdale, FL 33302',10310,222,NULL,11,14670,0);
INSERT INTO "django_geo_db_location" VALUES(25274,NULL,'Fort Lauderdale, FL 33303',10310,222,NULL,11,14671,0);
INSERT INTO "django_geo_db_location" VALUES(25275,NULL,'Fort Lauderdale, FL 33304',10310,222,NULL,11,14672,0);
INSERT INTO "django_geo_db_location" VALUES(25276,NULL,'Fort Lauderdale, FL 33305',10310,222,NULL,11,14673,0);
INSERT INTO "django_geo_db_location" VALUES(25277,NULL,'Fort Lauderdale, FL 33306',10310,222,NULL,11,14674,0);
INSERT INTO "django_geo_db_location" VALUES(25278,NULL,'Fort Lauderdale, FL 33307',10310,222,NULL,11,14675,0);
INSERT INTO "django_geo_db_location" VALUES(25279,NULL,'Fort Lauderdale, FL 33308',10310,222,NULL,11,14676,0);
INSERT INTO "django_geo_db_location" VALUES(25280,NULL,'Fort Lauderdale, FL 33309',10310,222,NULL,11,14677,0);
INSERT INTO "django_geo_db_location" VALUES(25281,NULL,'Fort Lauderdale, FL 33310',10310,222,NULL,11,14678,0);
INSERT INTO "django_geo_db_location" VALUES(25282,NULL,'Fort Lauderdale, FL 33311',10310,222,NULL,11,14679,0);
INSERT INTO "django_geo_db_location" VALUES(25283,NULL,'Fort Lauderdale, FL 33312',10310,222,NULL,11,14680,0);
INSERT INTO "django_geo_db_location" VALUES(25284,NULL,'Fort Lauderdale, FL 33313',10310,222,NULL,11,14681,0);
INSERT INTO "django_geo_db_location" VALUES(25285,NULL,'Fort Lauderdale, FL 33314',10310,222,NULL,11,14682,0);
INSERT INTO "django_geo_db_location" VALUES(25286,NULL,'Fort Lauderdale, FL 33315',10310,222,NULL,11,14683,0);
INSERT INTO "django_geo_db_location" VALUES(25287,NULL,'Fort Lauderdale, FL 33316',10310,222,NULL,11,14684,0);
INSERT INTO "django_geo_db_location" VALUES(25288,NULL,'Fort Lauderdale, FL 33317',10310,222,NULL,11,14685,0);
INSERT INTO "django_geo_db_location" VALUES(25289,NULL,'Fort Lauderdale, FL 33318',10310,222,NULL,11,14686,0);
INSERT INTO "django_geo_db_location" VALUES(25290,NULL,'Fort Lauderdale, FL 33319',10310,222,NULL,11,14687,0);
INSERT INTO "django_geo_db_location" VALUES(25291,NULL,'Fort Lauderdale, FL 33320',10310,222,NULL,11,14688,0);
INSERT INTO "django_geo_db_location" VALUES(25292,NULL,'Fort Lauderdale, FL 33321',10310,222,NULL,11,14689,0);
INSERT INTO "django_geo_db_location" VALUES(25293,NULL,'Fort Lauderdale, FL 33322',10310,222,NULL,11,14690,0);
INSERT INTO "django_geo_db_location" VALUES(25294,NULL,'Fort Lauderdale, FL 33323',10310,222,NULL,11,14691,0);
INSERT INTO "django_geo_db_location" VALUES(25295,NULL,'Fort Lauderdale, FL 33324',10310,222,NULL,11,14692,0);
INSERT INTO "django_geo_db_location" VALUES(25296,NULL,'Fort Lauderdale, FL 33325',10310,222,NULL,11,14693,0);
INSERT INTO "django_geo_db_location" VALUES(25297,NULL,'Weston, FL',10311,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25298,NULL,'Weston, FL 33326',10311,222,NULL,11,14694,0);
INSERT INTO "django_geo_db_location" VALUES(25299,NULL,'Weston, FL 33327',10311,222,NULL,11,14695,0);
INSERT INTO "django_geo_db_location" VALUES(25300,NULL,'Fort Lauderdale, FL 33328',10310,222,NULL,11,14696,0);
INSERT INTO "django_geo_db_location" VALUES(25301,NULL,'Fort Lauderdale, FL 33329',10310,222,NULL,11,14697,0);
INSERT INTO "django_geo_db_location" VALUES(25302,NULL,'Fort Lauderdale, FL 33330',10310,222,NULL,11,14698,0);
INSERT INTO "django_geo_db_location" VALUES(25303,NULL,'Fort Lauderdale, FL 33331',10310,222,NULL,11,14699,0);
INSERT INTO "django_geo_db_location" VALUES(25304,NULL,'Fort Lauderdale, FL 33332',10310,222,NULL,11,14700,0);
INSERT INTO "django_geo_db_location" VALUES(25305,NULL,'Fort Lauderdale, FL 33334',10310,222,NULL,11,14701,0);
INSERT INTO "django_geo_db_location" VALUES(25306,NULL,'Fort Lauderdale, FL 33335',10310,222,NULL,11,14702,0);
INSERT INTO "django_geo_db_location" VALUES(25307,NULL,'Fort Lauderdale, FL 33337',10310,222,NULL,11,14703,0);
INSERT INTO "django_geo_db_location" VALUES(25308,NULL,'Fort Lauderdale, FL 33338',10310,222,NULL,11,14704,0);
INSERT INTO "django_geo_db_location" VALUES(25309,NULL,'Fort Lauderdale, FL 33339',10310,222,NULL,11,14705,0);
INSERT INTO "django_geo_db_location" VALUES(25310,NULL,'Fort Lauderdale, FL 33340',10310,222,NULL,11,14706,0);
INSERT INTO "django_geo_db_location" VALUES(25311,NULL,'Fort Lauderdale, FL 33345',10310,222,NULL,11,14707,0);
INSERT INTO "django_geo_db_location" VALUES(25312,NULL,'Fort Lauderdale, FL 33346',10310,222,NULL,11,14708,0);
INSERT INTO "django_geo_db_location" VALUES(25313,NULL,'Fort Lauderdale, FL 33348',10310,222,NULL,11,14709,0);
INSERT INTO "django_geo_db_location" VALUES(25314,NULL,'Fort Lauderdale, FL 33349',10310,222,NULL,11,14710,0);
INSERT INTO "django_geo_db_location" VALUES(25315,NULL,'Fort Lauderdale, FL 33351',10310,222,NULL,11,14711,0);
INSERT INTO "django_geo_db_location" VALUES(25316,NULL,'Pine Island Ridge, FL',10312,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25317,NULL,'Pine Island Ridge, FL 33352',10312,222,NULL,11,14712,0);
INSERT INTO "django_geo_db_location" VALUES(25318,NULL,'Fort Lauderdale, FL 33355',10310,222,NULL,11,14713,0);
INSERT INTO "django_geo_db_location" VALUES(25319,NULL,'Fort Lauderdale, FL 33359',10310,222,NULL,11,14714,0);
INSERT INTO "django_geo_db_location" VALUES(25320,NULL,'Winter Haven, FL',10313,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25321,NULL,'Winter Haven, FL 33380',10313,222,NULL,11,14715,0);
INSERT INTO "django_geo_db_location" VALUES(25322,NULL,'Fort Lauderdale, FL 33388',10310,222,NULL,11,14716,0);
INSERT INTO "django_geo_db_location" VALUES(25323,NULL,'Fort Lauderdale, FL 33394',10310,222,NULL,11,14717,0);
INSERT INTO "django_geo_db_location" VALUES(25324,NULL,'West Palm Beach, FL',10314,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25325,NULL,'West Palm Beach, FL 33401',10314,222,NULL,11,14718,0);
INSERT INTO "django_geo_db_location" VALUES(25326,NULL,'West Palm Beach, FL 33402',10314,222,NULL,11,14719,0);
INSERT INTO "django_geo_db_location" VALUES(25327,NULL,'West Palm Beach, FL 33403',10314,222,NULL,11,14720,0);
INSERT INTO "django_geo_db_location" VALUES(25328,NULL,'West Palm Beach, FL 33404',10314,222,NULL,11,14721,0);
INSERT INTO "django_geo_db_location" VALUES(25329,NULL,'West Palm Beach, FL 33405',10314,222,NULL,11,14722,0);
INSERT INTO "django_geo_db_location" VALUES(25330,NULL,'West Palm Beach, FL 33406',10314,222,NULL,11,14723,0);
INSERT INTO "django_geo_db_location" VALUES(25331,NULL,'West Palm Beach, FL 33407',10314,222,NULL,11,14724,0);
INSERT INTO "django_geo_db_location" VALUES(25332,NULL,'North Palm Beach, FL',10315,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25333,NULL,'North Palm Beach, FL 33408',10315,222,NULL,11,14725,0);
INSERT INTO "django_geo_db_location" VALUES(25334,NULL,'West Palm Beach, FL 33409',10314,222,NULL,11,14726,0);
INSERT INTO "django_geo_db_location" VALUES(25335,NULL,'West Palm Beach, FL 33410',10314,222,NULL,11,14727,0);
INSERT INTO "django_geo_db_location" VALUES(25336,NULL,'West Palm Beach, FL 33411',10314,222,NULL,11,14728,0);
INSERT INTO "django_geo_db_location" VALUES(25337,NULL,'West Palm Beach, FL 33412',10314,222,NULL,11,14729,0);
INSERT INTO "django_geo_db_location" VALUES(25338,NULL,'West Palm Beach, FL 33413',10314,222,NULL,11,14730,0);
INSERT INTO "django_geo_db_location" VALUES(25339,NULL,'West Palm Beach, FL 33414',10314,222,NULL,11,14731,0);
INSERT INTO "django_geo_db_location" VALUES(25340,NULL,'West Palm Beach, FL 33415',10314,222,NULL,11,14732,0);
INSERT INTO "django_geo_db_location" VALUES(25341,NULL,'West Palm Beach, FL 33416',10314,222,NULL,11,14733,0);
INSERT INTO "django_geo_db_location" VALUES(25342,NULL,'West Palm Beach, FL 33417',10314,222,NULL,11,14734,0);
INSERT INTO "django_geo_db_location" VALUES(25343,NULL,'West Palm Beach, FL 33418',10314,222,NULL,11,14735,0);
INSERT INTO "django_geo_db_location" VALUES(25344,NULL,'West Palm Beach, FL 33419',10314,222,NULL,11,14736,0);
INSERT INTO "django_geo_db_location" VALUES(25345,NULL,'West Palm Beach, FL 33420',10314,222,NULL,11,14737,0);
INSERT INTO "django_geo_db_location" VALUES(25346,NULL,'West Palm Beach, FL 33421',10314,222,NULL,11,14738,0);
INSERT INTO "django_geo_db_location" VALUES(25347,NULL,'West Palm Beach, FL 33422',10314,222,NULL,11,14739,0);
INSERT INTO "django_geo_db_location" VALUES(25348,NULL,'Boynton Beach, FL',10316,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25349,NULL,'Boynton Beach, FL 33424',10316,222,NULL,11,14740,0);
INSERT INTO "django_geo_db_location" VALUES(25350,NULL,'Boynton Beach, FL 33425',10316,222,NULL,11,14741,0);
INSERT INTO "django_geo_db_location" VALUES(25351,NULL,'Boynton Beach, FL 33426',10316,222,NULL,11,14742,0);
INSERT INTO "django_geo_db_location" VALUES(25352,NULL,'Boca Raton, FL',10317,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25353,NULL,'Boca Raton, FL 33427',10317,222,NULL,11,14743,0);
INSERT INTO "django_geo_db_location" VALUES(25354,NULL,'Boca Raton, FL 33428',10317,222,NULL,11,14744,0);
INSERT INTO "django_geo_db_location" VALUES(25355,NULL,'Boca Raton, FL 33429',10317,222,NULL,11,14745,0);
INSERT INTO "django_geo_db_location" VALUES(25356,NULL,'Belle Glade, FL',10318,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25357,NULL,'Belle Glade, FL 33430',10318,222,NULL,11,14746,0);
INSERT INTO "django_geo_db_location" VALUES(25358,NULL,'Boca Raton, FL 33431',10317,222,NULL,11,14747,0);
INSERT INTO "django_geo_db_location" VALUES(25359,NULL,'Boca Raton, FL 33432',10317,222,NULL,11,14748,0);
INSERT INTO "django_geo_db_location" VALUES(25360,NULL,'Boca Raton, FL 33433',10317,222,NULL,11,14749,0);
INSERT INTO "django_geo_db_location" VALUES(25361,NULL,'Boca Raton, FL 33434',10317,222,NULL,11,14750,0);
INSERT INTO "django_geo_db_location" VALUES(25362,NULL,'Boynton Beach, FL 33435',10316,222,NULL,11,14751,0);
INSERT INTO "django_geo_db_location" VALUES(25363,NULL,'Boynton Beach, FL 33436',10316,222,NULL,11,14752,0);
INSERT INTO "django_geo_db_location" VALUES(25364,NULL,'Boynton Beach, FL 33437',10316,222,NULL,11,14753,0);
INSERT INTO "django_geo_db_location" VALUES(25365,NULL,'Canal Point, FL',10319,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25366,NULL,'Canal Point, FL 33438',10319,222,NULL,11,14754,0);
INSERT INTO "django_geo_db_location" VALUES(25367,NULL,'Bryant, FL',10320,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25368,NULL,'Bryant, FL 33439',10320,222,NULL,11,14755,0);
INSERT INTO "django_geo_db_location" VALUES(25369,NULL,'Clewiston, FL',10321,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25370,NULL,'Clewiston, FL 33440',10321,222,NULL,11,14756,0);
INSERT INTO "django_geo_db_location" VALUES(25371,NULL,'Deerfield Beach, FL',10322,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25372,NULL,'Deerfield Beach, FL 33441',10322,222,NULL,11,14757,0);
INSERT INTO "django_geo_db_location" VALUES(25373,NULL,'Deerfield Beach, FL 33442',10322,222,NULL,11,14758,0);
INSERT INTO "django_geo_db_location" VALUES(25374,NULL,'Deerfield Beach, FL 33443',10322,222,NULL,11,14759,0);
INSERT INTO "django_geo_db_location" VALUES(25375,NULL,'Delray Beach, FL',10323,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25376,NULL,'Delray Beach, FL 33444',10323,222,NULL,11,14760,0);
INSERT INTO "django_geo_db_location" VALUES(25377,NULL,'Delray Beach, FL 33445',10323,222,NULL,11,14761,0);
INSERT INTO "django_geo_db_location" VALUES(25378,NULL,'Delray Beach, FL 33446',10323,222,NULL,11,14762,0);
INSERT INTO "django_geo_db_location" VALUES(25379,NULL,'Delray Beach, FL 33447',10323,222,NULL,11,14763,0);
INSERT INTO "django_geo_db_location" VALUES(25380,NULL,'Delray Beach, FL 33448',10323,222,NULL,11,14764,0);
INSERT INTO "django_geo_db_location" VALUES(25381,NULL,'Lantana, FL',10324,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25382,NULL,'Lantana, FL 33452',10324,222,NULL,11,14765,0);
INSERT INTO "django_geo_db_location" VALUES(25383,NULL,'Lake Worth, FL',10325,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25384,NULL,'Lake Worth, FL 33454',10325,222,NULL,11,14766,0);
INSERT INTO "django_geo_db_location" VALUES(25385,NULL,'Hobe Sound, FL',10326,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25386,NULL,'Hobe Sound, FL 33455',10326,222,NULL,11,14767,0);
INSERT INTO "django_geo_db_location" VALUES(25387,NULL,'Jupiter, FL',10327,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25388,NULL,'Jupiter, FL 33458',10327,222,NULL,11,14768,0);
INSERT INTO "django_geo_db_location" VALUES(25389,NULL,'Lake Harbor, FL',10328,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25390,NULL,'Lake Harbor, FL 33459',10328,222,NULL,11,14769,0);
INSERT INTO "django_geo_db_location" VALUES(25391,NULL,'Lake Worth, FL 33460',10325,222,NULL,11,14770,0);
INSERT INTO "django_geo_db_location" VALUES(25392,NULL,'Lake Worth, FL 33461',10325,222,NULL,11,14771,0);
INSERT INTO "django_geo_db_location" VALUES(25393,NULL,'Lake Worth, FL 33462',10325,222,NULL,11,14772,0);
INSERT INTO "django_geo_db_location" VALUES(25394,NULL,'Lake Worth, FL 33463',10325,222,NULL,11,14773,0);
INSERT INTO "django_geo_db_location" VALUES(25395,NULL,'Lake Worth, FL 33464',10325,222,NULL,11,14774,0);
INSERT INTO "django_geo_db_location" VALUES(25396,NULL,'Lake Worth, FL 33465',10325,222,NULL,11,14775,0);
INSERT INTO "django_geo_db_location" VALUES(25397,NULL,'Lake Worth, FL 33466',10325,222,NULL,11,14776,0);
INSERT INTO "django_geo_db_location" VALUES(25398,NULL,'Lake Worth, FL 33467',10325,222,NULL,11,14777,0);
INSERT INTO "django_geo_db_location" VALUES(25399,NULL,'Jupiter, FL 33468',10327,222,NULL,11,14778,0);
INSERT INTO "django_geo_db_location" VALUES(25400,NULL,'Jupiter, FL 33469',10327,222,NULL,11,14779,0);
INSERT INTO "django_geo_db_location" VALUES(25401,NULL,'Loxahatchee, FL',10329,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25402,NULL,'Loxahatchee, FL 33470',10329,222,NULL,11,14780,0);
INSERT INTO "django_geo_db_location" VALUES(25403,NULL,'Moore Haven, FL',10330,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25404,NULL,'Moore Haven, FL 33471',10330,222,NULL,11,14781,0);
INSERT INTO "django_geo_db_location" VALUES(25405,NULL,'Boynton Beach, FL 33474',10316,222,NULL,11,14782,0);
INSERT INTO "django_geo_db_location" VALUES(25406,NULL,'Hobe Sound, FL 33475',10326,222,NULL,11,14783,0);
INSERT INTO "django_geo_db_location" VALUES(25407,NULL,'Pahokee, FL',10331,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25408,NULL,'Pahokee, FL 33476',10331,222,NULL,11,14784,0);
INSERT INTO "django_geo_db_location" VALUES(25409,NULL,'Jupiter, FL 33477',10327,222,NULL,11,14785,0);
INSERT INTO "django_geo_db_location" VALUES(25410,NULL,'Jupiter, FL 33478',10327,222,NULL,11,14786,0);
INSERT INTO "django_geo_db_location" VALUES(25411,NULL,'Palm Beach, FL',10332,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25412,NULL,'Palm Beach, FL 33480',10332,222,NULL,11,14787,0);
INSERT INTO "django_geo_db_location" VALUES(25413,NULL,'Boca Raton, FL 33481',10317,222,NULL,11,14788,0);
INSERT INTO "django_geo_db_location" VALUES(25414,NULL,'Delray Beach, FL 33482',10323,222,NULL,11,14789,0);
INSERT INTO "django_geo_db_location" VALUES(25415,NULL,'Delray Beach, FL 33483',10323,222,NULL,11,14790,0);
INSERT INTO "django_geo_db_location" VALUES(25416,NULL,'Delray Beach, FL 33484',10323,222,NULL,11,14791,0);
INSERT INTO "django_geo_db_location" VALUES(25417,NULL,'Boca Raton, FL 33486',10317,222,NULL,11,14792,0);
INSERT INTO "django_geo_db_location" VALUES(25418,NULL,'Boca Raton, FL 33487',10317,222,NULL,11,14793,0);
INSERT INTO "django_geo_db_location" VALUES(25419,NULL,'Boca Raton, FL 33488',10317,222,NULL,11,14794,0);
INSERT INTO "django_geo_db_location" VALUES(25420,NULL,'South Bay, FL',10333,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25421,NULL,'South Bay, FL 33493',10333,222,NULL,11,14795,0);
INSERT INTO "django_geo_db_location" VALUES(25422,NULL,'Boca Raton, FL 33496',10317,222,NULL,11,14796,0);
INSERT INTO "django_geo_db_location" VALUES(25423,NULL,'Boca Raton, FL 33497',10317,222,NULL,11,14797,0);
INSERT INTO "django_geo_db_location" VALUES(25424,NULL,'Boca Raton, FL 33498',10317,222,NULL,11,14798,0);
INSERT INTO "django_geo_db_location" VALUES(25425,NULL,'Boca Raton, FL 33499',10317,222,NULL,11,14799,0);
INSERT INTO "django_geo_db_location" VALUES(25426,NULL,'Brandon, FL',10334,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25427,NULL,'Brandon, FL 33501',10334,222,NULL,11,14800,0);
INSERT INTO "django_geo_db_location" VALUES(25428,NULL,'Balm, FL',10335,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25429,NULL,'Balm, FL 33503',10335,222,NULL,11,14801,0);
INSERT INTO "django_geo_db_location" VALUES(25430,NULL,'Brandon, FL 33509',10334,222,NULL,11,14802,0);
INSERT INTO "django_geo_db_location" VALUES(25431,NULL,'Brandon, FL 33510',10334,222,NULL,11,14803,0);
INSERT INTO "django_geo_db_location" VALUES(25432,NULL,'Brandon, FL 33511',10334,222,NULL,11,14804,0);
INSERT INTO "django_geo_db_location" VALUES(25433,NULL,'Bushnell, FL',10336,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25434,NULL,'Bushnell, FL 33513',10336,222,NULL,11,14805,0);
INSERT INTO "django_geo_db_location" VALUES(25435,NULL,'Center Hill, FL',10337,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25436,NULL,'Center Hill, FL 33514',10337,222,NULL,11,14806,0);
INSERT INTO "django_geo_db_location" VALUES(25437,NULL,'Fort Lauderdale, FL 33515',10310,222,NULL,11,14807,0);
INSERT INTO "django_geo_db_location" VALUES(25438,NULL,'Coleman, FL',10338,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25439,NULL,'Coleman, FL 33521',10338,222,NULL,11,14808,0);
INSERT INTO "django_geo_db_location" VALUES(25440,NULL,'Dade City, FL',10339,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25441,NULL,'Dade City, FL 33523',10339,222,NULL,11,14809,0);
INSERT INTO "django_geo_db_location" VALUES(25442,NULL,'Crystal Springs, FL',10340,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25443,NULL,'Crystal Springs, FL 33524',10340,222,NULL,11,14810,0);
INSERT INTO "django_geo_db_location" VALUES(25444,NULL,'Dade City, FL 33525',10339,222,NULL,11,14811,0);
INSERT INTO "django_geo_db_location" VALUES(25445,NULL,'Dade City, FL 33526',10339,222,NULL,11,14812,0);
INSERT INTO "django_geo_db_location" VALUES(25446,NULL,'Dover, FL',10341,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25447,NULL,'Dover, FL 33527',10341,222,NULL,11,14813,0);
INSERT INTO "django_geo_db_location" VALUES(25448,NULL,'Lake Panasoffkee, FL',10342,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25449,NULL,'Lake Panasoffkee, FL 33528',10342,222,NULL,11,14814,0);
INSERT INTO "django_geo_db_location" VALUES(25450,NULL,'Durant, FL',10343,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25451,NULL,'Durant, FL 33530',10343,222,NULL,11,14815,0);
INSERT INTO "django_geo_db_location" VALUES(25452,NULL,'Gibsonton, FL',10344,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25453,NULL,'Gibsonton, FL 33534',10344,222,NULL,11,14816,0);
INSERT INTO "django_geo_db_location" VALUES(25454,NULL,'Lacoochee, FL',10345,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25455,NULL,'Lacoochee, FL 33537',10345,222,NULL,11,14817,0);
INSERT INTO "django_geo_db_location" VALUES(25456,NULL,'Lake Panasoffkee, FL 33538',10342,222,NULL,11,14818,0);
INSERT INTO "django_geo_db_location" VALUES(25457,NULL,'Zephyrhills, FL',10346,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25458,NULL,'Zephyrhills, FL 33539',10346,222,NULL,11,14819,0);
INSERT INTO "django_geo_db_location" VALUES(25459,NULL,'Zephyrhills, FL 33540',10346,222,NULL,11,14820,0);
INSERT INTO "django_geo_db_location" VALUES(25460,NULL,'Zephyrhills, FL 33541',10346,222,NULL,11,14821,0);
INSERT INTO "django_geo_db_location" VALUES(25461,NULL,'Zephyrhills, FL 33542',10346,222,NULL,11,14822,0);
INSERT INTO "django_geo_db_location" VALUES(25462,NULL,'Zephyrhills, FL 33543',10346,222,NULL,11,14823,0);
INSERT INTO "django_geo_db_location" VALUES(25463,NULL,'Zephyrhills, FL 33544',10346,222,NULL,11,14824,0);
INSERT INTO "django_geo_db_location" VALUES(25464,NULL,'Lithia, FL',10347,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25465,NULL,'Lithia, FL 33547',10347,222,NULL,11,14825,0);
INSERT INTO "django_geo_db_location" VALUES(25466,NULL,'Lutz, FL',10348,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25467,NULL,'Lutz, FL 33548',10348,222,NULL,11,14826,0);
INSERT INTO "django_geo_db_location" VALUES(25468,NULL,'Lutz, FL 33549',10348,222,NULL,11,14827,0);
INSERT INTO "django_geo_db_location" VALUES(25469,NULL,'Mango, FL',10349,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25470,NULL,'Mango, FL 33550',10349,222,NULL,11,14828,0);
INSERT INTO "django_geo_db_location" VALUES(25471,NULL,'Odessa, FL',10350,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25472,NULL,'Odessa, FL 33556',10350,222,NULL,11,14829,0);
INSERT INTO "django_geo_db_location" VALUES(25473,NULL,'Land O'' Lakes, FL',10351,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25474,NULL,'Land O'' Lakes, FL 33558',10351,222,NULL,11,14830,0);
INSERT INTO "django_geo_db_location" VALUES(25475,NULL,'Land O'' Lakes, FL 33559',10351,222,NULL,11,14831,0);
INSERT INTO "django_geo_db_location" VALUES(25476,NULL,'Plant City, FL',10352,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25477,NULL,'Plant City, FL 33563',10352,222,NULL,11,14832,0);
INSERT INTO "django_geo_db_location" VALUES(25478,NULL,'Plant City, FL 33564',10352,222,NULL,11,14833,0);
INSERT INTO "django_geo_db_location" VALUES(25479,NULL,'Plant City, FL 33565',10352,222,NULL,11,14834,0);
INSERT INTO "django_geo_db_location" VALUES(25480,NULL,'Plant City, FL 33566',10352,222,NULL,11,14835,0);
INSERT INTO "django_geo_db_location" VALUES(25481,NULL,'Plant City, FL 33567',10352,222,NULL,11,14836,0);
INSERT INTO "django_geo_db_location" VALUES(25482,NULL,'Riverview, FL',10353,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25483,NULL,'Riverview, FL 33568',10353,222,NULL,11,14837,0);
INSERT INTO "django_geo_db_location" VALUES(25484,NULL,'Riverview, FL 33569',10353,222,NULL,11,14838,0);
INSERT INTO "django_geo_db_location" VALUES(25485,NULL,'Ruskin, FL',10354,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25486,NULL,'Ruskin, FL 33570',10354,222,NULL,11,14839,0);
INSERT INTO "django_geo_db_location" VALUES(25487,NULL,'Sun City Center, FL',10355,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25488,NULL,'Sun City Center, FL 33571',10355,222,NULL,11,14840,0);
INSERT INTO "django_geo_db_location" VALUES(25489,NULL,'Apollo Beach, FL',10356,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25490,NULL,'Apollo Beach, FL 33572',10356,222,NULL,11,14841,0);
INSERT INTO "django_geo_db_location" VALUES(25491,NULL,'Sun City Center, FL 33573',10355,222,NULL,11,14842,0);
INSERT INTO "django_geo_db_location" VALUES(25492,NULL,'Saint Leo, FL',10357,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25493,NULL,'Saint Leo, FL 33574',10357,222,NULL,11,14843,0);
INSERT INTO "django_geo_db_location" VALUES(25494,NULL,'San Antonio, FL',10358,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25495,NULL,'San Antonio, FL 33576',10358,222,NULL,11,14844,0);
INSERT INTO "django_geo_db_location" VALUES(25496,NULL,'St. Leo, FL',10359,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25497,NULL,'St. Leo, FL 33578',10359,222,NULL,11,14845,0);
INSERT INTO "django_geo_db_location" VALUES(25498,NULL,'Seffner, FL',10360,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25499,NULL,'Seffner, FL 33583',10360,222,NULL,11,14846,0);
INSERT INTO "django_geo_db_location" VALUES(25500,NULL,'Seffner, FL 33584',10360,222,NULL,11,14847,0);
INSERT INTO "django_geo_db_location" VALUES(25501,NULL,'Sumterville, FL',10361,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25502,NULL,'Sumterville, FL 33585',10361,222,NULL,11,14848,0);
INSERT INTO "django_geo_db_location" VALUES(25503,NULL,'Sun City, FL',10362,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25504,NULL,'Sun City, FL 33586',10362,222,NULL,11,14849,0);
INSERT INTO "django_geo_db_location" VALUES(25505,NULL,'Sydney, FL',10363,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25506,NULL,'Sydney, FL 33587',10363,222,NULL,11,14850,0);
INSERT INTO "django_geo_db_location" VALUES(25507,NULL,'Thonotosassa, FL',10364,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25508,NULL,'Thonotosassa, FL 33592',10364,222,NULL,11,14851,0);
INSERT INTO "django_geo_db_location" VALUES(25509,NULL,'Trilby, FL',10365,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25510,NULL,'Trilby, FL 33593',10365,222,NULL,11,14852,0);
INSERT INTO "django_geo_db_location" VALUES(25511,NULL,'Valrico, FL',10366,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25512,NULL,'Valrico, FL 33594',10366,222,NULL,11,14853,0);
INSERT INTO "django_geo_db_location" VALUES(25513,NULL,'Valrico, FL 33595',10366,222,NULL,11,14854,0);
INSERT INTO "django_geo_db_location" VALUES(25514,NULL,'Webster, FL',10367,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25515,NULL,'Webster, FL 33597',10367,222,NULL,11,14855,0);
INSERT INTO "django_geo_db_location" VALUES(25516,NULL,'Wimauma, FL',10368,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25517,NULL,'Wimauma, FL 33598',10368,222,NULL,11,14856,0);
INSERT INTO "django_geo_db_location" VALUES(25518,NULL,'Punta Gorda, FL',10369,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25519,NULL,'Punta Gorda, FL 33599',10369,222,NULL,11,14857,0);
INSERT INTO "django_geo_db_location" VALUES(25520,NULL,'Tampa, FL',10370,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25521,NULL,'Tampa, FL 33601',10370,222,NULL,11,14858,0);
INSERT INTO "django_geo_db_location" VALUES(25522,NULL,'Tampa, FL 33602',10370,222,NULL,11,14859,0);
INSERT INTO "django_geo_db_location" VALUES(25523,NULL,'Tampa, FL 33603',10370,222,NULL,11,14860,0);
INSERT INTO "django_geo_db_location" VALUES(25524,NULL,'Tampa, FL 33604',10370,222,NULL,11,14861,0);
INSERT INTO "django_geo_db_location" VALUES(25525,NULL,'Tampa, FL 33605',10370,222,NULL,11,14862,0);
INSERT INTO "django_geo_db_location" VALUES(25526,NULL,'Tampa, FL 33606',10370,222,NULL,11,14863,0);
INSERT INTO "django_geo_db_location" VALUES(25527,NULL,'Tampa, FL 33607',10370,222,NULL,11,14864,0);
INSERT INTO "django_geo_db_location" VALUES(25528,NULL,'Tampa, FL 33608',10370,222,NULL,11,14865,0);
INSERT INTO "django_geo_db_location" VALUES(25529,NULL,'Tampa, FL 33609',10370,222,NULL,11,14866,0);
INSERT INTO "django_geo_db_location" VALUES(25530,NULL,'Tampa, FL 33610',10370,222,NULL,11,14867,0);
INSERT INTO "django_geo_db_location" VALUES(25531,NULL,'Tampa, FL 33611',10370,222,NULL,11,14868,0);
INSERT INTO "django_geo_db_location" VALUES(25532,NULL,'Tampa, FL 33612',10370,222,NULL,11,14869,0);
INSERT INTO "django_geo_db_location" VALUES(25533,NULL,'Tampa, FL 33613',10370,222,NULL,11,14870,0);
INSERT INTO "django_geo_db_location" VALUES(25534,NULL,'Tampa, FL 33614',10370,222,NULL,11,14871,0);
INSERT INTO "django_geo_db_location" VALUES(25535,NULL,'Tampa, FL 33615',10370,222,NULL,11,14872,0);
INSERT INTO "django_geo_db_location" VALUES(25536,NULL,'Tampa, FL 33616',10370,222,NULL,11,14873,0);
INSERT INTO "django_geo_db_location" VALUES(25537,NULL,'Tampa, FL 33617',10370,222,NULL,11,14874,0);
INSERT INTO "django_geo_db_location" VALUES(25538,NULL,'Tampa, FL 33618',10370,222,NULL,11,14875,0);
INSERT INTO "django_geo_db_location" VALUES(25539,NULL,'Tampa, FL 33619',10370,222,NULL,11,14876,0);
INSERT INTO "django_geo_db_location" VALUES(25540,NULL,'Tampa, FL 33620',10370,222,NULL,11,14877,0);
INSERT INTO "django_geo_db_location" VALUES(25541,NULL,'Tampa, FL 33621',10370,222,NULL,11,14878,0);
INSERT INTO "django_geo_db_location" VALUES(25542,NULL,'Tampa, FL 33622',10370,222,NULL,11,14879,0);
INSERT INTO "django_geo_db_location" VALUES(25543,NULL,'Tampa, FL 33623',10370,222,NULL,11,14880,0);
INSERT INTO "django_geo_db_location" VALUES(25544,NULL,'Tampa, FL 33624',10370,222,NULL,11,14881,0);
INSERT INTO "django_geo_db_location" VALUES(25545,NULL,'Tampa, FL 33625',10370,222,NULL,11,14882,0);
INSERT INTO "django_geo_db_location" VALUES(25546,NULL,'Tampa, FL 33626',10370,222,NULL,11,14883,0);
INSERT INTO "django_geo_db_location" VALUES(25547,NULL,'Tampa, FL 33629',10370,222,NULL,11,14884,0);
INSERT INTO "django_geo_db_location" VALUES(25548,NULL,'Tampa, FL 33630',10370,222,NULL,11,14885,0);
INSERT INTO "django_geo_db_location" VALUES(25549,NULL,'Tampa, FL 33631',10370,222,NULL,11,14886,0);
INSERT INTO "django_geo_db_location" VALUES(25550,NULL,'Tampa, FL 33633',10370,222,NULL,11,14887,0);
INSERT INTO "django_geo_db_location" VALUES(25551,NULL,'Tampa, FL 33634',10370,222,NULL,11,14888,0);
INSERT INTO "django_geo_db_location" VALUES(25552,NULL,'Tampa, FL 33635',10370,222,NULL,11,14889,0);
INSERT INTO "django_geo_db_location" VALUES(25553,NULL,'Tampa, FL 33637',10370,222,NULL,11,14890,0);
INSERT INTO "django_geo_db_location" VALUES(25554,NULL,'Tampa, FL 33643',10370,222,NULL,11,14891,0);
INSERT INTO "django_geo_db_location" VALUES(25555,NULL,'Tampa, FL 33647',10370,222,NULL,11,14892,0);
INSERT INTO "django_geo_db_location" VALUES(25556,NULL,'Tampa, FL 33650',10370,222,NULL,11,14893,0);
INSERT INTO "django_geo_db_location" VALUES(25557,NULL,'Tampa, FL 33651',10370,222,NULL,11,14894,0);
INSERT INTO "django_geo_db_location" VALUES(25558,NULL,'Tampa, FL 33655',10370,222,NULL,11,14895,0);
INSERT INTO "django_geo_db_location" VALUES(25559,NULL,'Palm River-Clair Mel, FL',10371,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25560,NULL,'Palm River-Clair Mel, FL 33659',10371,222,NULL,11,14896,0);
INSERT INTO "django_geo_db_location" VALUES(25561,NULL,'Tampa, FL 33660',10370,222,NULL,11,14897,0);
INSERT INTO "django_geo_db_location" VALUES(25562,NULL,'Tampa, FL 33661',10370,222,NULL,11,14898,0);
INSERT INTO "django_geo_db_location" VALUES(25563,NULL,'Tampa, FL 33662',10370,222,NULL,11,14899,0);
INSERT INTO "django_geo_db_location" VALUES(25564,NULL,'Tampa, FL 33663',10370,222,NULL,11,14900,0);
INSERT INTO "django_geo_db_location" VALUES(25565,NULL,'Tampa, FL 33664',10370,222,NULL,11,14901,0);
INSERT INTO "django_geo_db_location" VALUES(25566,NULL,'Tampa, FL 33672',10370,222,NULL,11,14902,0);
INSERT INTO "django_geo_db_location" VALUES(25567,NULL,'Tampa, FL 33673',10370,222,NULL,11,14903,0);
INSERT INTO "django_geo_db_location" VALUES(25568,NULL,'Tampa, FL 33674',10370,222,NULL,11,14904,0);
INSERT INTO "django_geo_db_location" VALUES(25569,NULL,'Tampa, FL 33675',10370,222,NULL,11,14905,0);
INSERT INTO "django_geo_db_location" VALUES(25570,NULL,'Tampa, FL 33677',10370,222,NULL,11,14906,0);
INSERT INTO "django_geo_db_location" VALUES(25571,NULL,'Tampa, FL 33679',10370,222,NULL,11,14907,0);
INSERT INTO "django_geo_db_location" VALUES(25572,NULL,'Tampa, FL 33680',10370,222,NULL,11,14908,0);
INSERT INTO "django_geo_db_location" VALUES(25573,NULL,'Tampa, FL 33681',10370,222,NULL,11,14909,0);
INSERT INTO "django_geo_db_location" VALUES(25574,NULL,'Tampa, FL 33682',10370,222,NULL,11,14910,0);
INSERT INTO "django_geo_db_location" VALUES(25575,NULL,'Tampa, FL 33684',10370,222,NULL,11,14911,0);
INSERT INTO "django_geo_db_location" VALUES(25576,NULL,'Tampa, FL 33685',10370,222,NULL,11,14912,0);
INSERT INTO "django_geo_db_location" VALUES(25577,NULL,'Tampa, FL 33686',10370,222,NULL,11,14913,0);
INSERT INTO "django_geo_db_location" VALUES(25578,NULL,'Tampa, FL 33687',10370,222,NULL,11,14914,0);
INSERT INTO "django_geo_db_location" VALUES(25579,NULL,'Tampa, FL 33688',10370,222,NULL,11,14915,0);
INSERT INTO "django_geo_db_location" VALUES(25580,NULL,'Tampa, FL 33689',10370,222,NULL,11,14916,0);
INSERT INTO "django_geo_db_location" VALUES(25581,NULL,'Tampa, FL 33690',10370,222,NULL,11,14917,0);
INSERT INTO "django_geo_db_location" VALUES(25582,NULL,'Tampa, FL 33694',10370,222,NULL,11,14918,0);
INSERT INTO "django_geo_db_location" VALUES(25583,NULL,'Tampa, FL 33697',10370,222,NULL,11,14919,0);
INSERT INTO "django_geo_db_location" VALUES(25584,NULL,'Saint Petersburg, FL',10372,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25585,NULL,'Saint Petersburg, FL 33701',10372,222,NULL,11,14920,0);
INSERT INTO "django_geo_db_location" VALUES(25586,NULL,'Saint Petersburg, FL 33702',10372,222,NULL,11,14921,0);
INSERT INTO "django_geo_db_location" VALUES(25587,NULL,'Saint Petersburg, FL 33703',10372,222,NULL,11,14922,0);
INSERT INTO "django_geo_db_location" VALUES(25588,NULL,'Saint Petersburg, FL 33704',10372,222,NULL,11,14923,0);
INSERT INTO "django_geo_db_location" VALUES(25589,NULL,'Saint Petersburg, FL 33705',10372,222,NULL,11,14924,0);
INSERT INTO "django_geo_db_location" VALUES(25590,NULL,'Saint Petersburg, FL 33706',10372,222,NULL,11,14925,0);
INSERT INTO "django_geo_db_location" VALUES(25591,NULL,'Saint Petersburg, FL 33707',10372,222,NULL,11,14926,0);
INSERT INTO "django_geo_db_location" VALUES(25592,NULL,'Saint Petersburg, FL 33708',10372,222,NULL,11,14927,0);
INSERT INTO "django_geo_db_location" VALUES(25593,NULL,'Saint Petersburg, FL 33709',10372,222,NULL,11,14928,0);
INSERT INTO "django_geo_db_location" VALUES(25594,NULL,'Saint Petersburg, FL 33710',10372,222,NULL,11,14929,0);
INSERT INTO "django_geo_db_location" VALUES(25595,NULL,'Saint Petersburg, FL 33711',10372,222,NULL,11,14930,0);
INSERT INTO "django_geo_db_location" VALUES(25596,NULL,'Saint Petersburg, FL 33712',10372,222,NULL,11,14931,0);
INSERT INTO "django_geo_db_location" VALUES(25597,NULL,'Saint Petersburg, FL 33713',10372,222,NULL,11,14932,0);
INSERT INTO "django_geo_db_location" VALUES(25598,NULL,'Saint Petersburg, FL 33714',10372,222,NULL,11,14933,0);
INSERT INTO "django_geo_db_location" VALUES(25599,NULL,'Saint Petersburg, FL 33715',10372,222,NULL,11,14934,0);
INSERT INTO "django_geo_db_location" VALUES(25600,NULL,'Saint Petersburg, FL 33716',10372,222,NULL,11,14935,0);
INSERT INTO "django_geo_db_location" VALUES(25601,NULL,'Saint Petersburg, FL 33728',10372,222,NULL,11,14936,0);
INSERT INTO "django_geo_db_location" VALUES(25602,NULL,'Saint Petersburg, FL 33729',10372,222,NULL,11,14937,0);
INSERT INTO "django_geo_db_location" VALUES(25603,NULL,'Saint Petersburg, FL 33730',10372,222,NULL,11,14938,0);
INSERT INTO "django_geo_db_location" VALUES(25604,NULL,'Saint Petersburg, FL 33731',10372,222,NULL,11,14939,0);
INSERT INTO "django_geo_db_location" VALUES(25605,NULL,'Saint Petersburg, FL 33732',10372,222,NULL,11,14940,0);
INSERT INTO "django_geo_db_location" VALUES(25606,NULL,'Saint Petersburg, FL 33733',10372,222,NULL,11,14941,0);
INSERT INTO "django_geo_db_location" VALUES(25607,NULL,'Saint Petersburg, FL 33734',10372,222,NULL,11,14942,0);
INSERT INTO "django_geo_db_location" VALUES(25608,NULL,'Saint Petersburg, FL 33736',10372,222,NULL,11,14943,0);
INSERT INTO "django_geo_db_location" VALUES(25609,NULL,'Saint Petersburg, FL 33737',10372,222,NULL,11,14944,0);
INSERT INTO "django_geo_db_location" VALUES(25610,NULL,'Saint Petersburg, FL 33738',10372,222,NULL,11,14945,0);
INSERT INTO "django_geo_db_location" VALUES(25611,NULL,'Saint Petersburg, FL 33740',10372,222,NULL,11,14946,0);
INSERT INTO "django_geo_db_location" VALUES(25612,NULL,'Saint Petersburg, FL 33741',10372,222,NULL,11,14947,0);
INSERT INTO "django_geo_db_location" VALUES(25613,NULL,'Saint Petersburg, FL 33742',10372,222,NULL,11,14948,0);
INSERT INTO "django_geo_db_location" VALUES(25614,NULL,'Saint Petersburg, FL 33743',10372,222,NULL,11,14949,0);
INSERT INTO "django_geo_db_location" VALUES(25615,NULL,'Bay Pines, FL',10373,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25616,NULL,'Bay Pines, FL 33744',10373,222,NULL,11,14950,0);
INSERT INTO "django_geo_db_location" VALUES(25617,NULL,'Saint Petersburg, FL 33747',10372,222,NULL,11,14951,0);
INSERT INTO "django_geo_db_location" VALUES(25618,NULL,'Clearwater, FL',10374,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25619,NULL,'Clearwater, FL 33755',10374,222,NULL,11,14952,0);
INSERT INTO "django_geo_db_location" VALUES(25620,NULL,'Clearwater, FL 33756',10374,222,NULL,11,14953,0);
INSERT INTO "django_geo_db_location" VALUES(25621,NULL,'Clearwater, FL 33757',10374,222,NULL,11,14954,0);
INSERT INTO "django_geo_db_location" VALUES(25622,NULL,'Clearwater, FL 33758',10374,222,NULL,11,14955,0);
INSERT INTO "django_geo_db_location" VALUES(25623,NULL,'Clearwater, FL 33759',10374,222,NULL,11,14956,0);
INSERT INTO "django_geo_db_location" VALUES(25624,NULL,'Clearwater, FL 33760',10374,222,NULL,11,14957,0);
INSERT INTO "django_geo_db_location" VALUES(25625,NULL,'Clearwater, FL 33761',10374,222,NULL,11,14958,0);
INSERT INTO "django_geo_db_location" VALUES(25626,NULL,'Clearwater, FL 33762',10374,222,NULL,11,14959,0);
INSERT INTO "django_geo_db_location" VALUES(25627,NULL,'Clearwater, FL 33763',10374,222,NULL,11,14960,0);
INSERT INTO "django_geo_db_location" VALUES(25628,NULL,'Clearwater, FL 33764',10374,222,NULL,11,14961,0);
INSERT INTO "django_geo_db_location" VALUES(25629,NULL,'Clearwater, FL 33765',10374,222,NULL,11,14962,0);
INSERT INTO "django_geo_db_location" VALUES(25630,NULL,'Clearwater, FL 33766',10374,222,NULL,11,14963,0);
INSERT INTO "django_geo_db_location" VALUES(25631,NULL,'Clearwater Beach, FL',10375,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25632,NULL,'Clearwater Beach, FL 33767',10375,222,NULL,11,14964,0);
INSERT INTO "django_geo_db_location" VALUES(25633,NULL,'Clearwater, FL 33769',10374,222,NULL,11,14965,0);
INSERT INTO "django_geo_db_location" VALUES(25634,NULL,'Largo, FL',10376,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25635,NULL,'Largo, FL 33770',10376,222,NULL,11,14966,0);
INSERT INTO "django_geo_db_location" VALUES(25636,NULL,'Largo, FL 33771',10376,222,NULL,11,14967,0);
INSERT INTO "django_geo_db_location" VALUES(25637,NULL,'Seminole, FL',10377,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25638,NULL,'Seminole, FL 33772',10377,222,NULL,11,14968,0);
INSERT INTO "django_geo_db_location" VALUES(25639,NULL,'Largo, FL 33773',10376,222,NULL,11,14969,0);
INSERT INTO "django_geo_db_location" VALUES(25640,NULL,'Largo, FL 33774',10376,222,NULL,11,14970,0);
INSERT INTO "django_geo_db_location" VALUES(25641,NULL,'Seminole, FL 33775',10377,222,NULL,11,14971,0);
INSERT INTO "django_geo_db_location" VALUES(25642,NULL,'Seminole, FL 33776',10377,222,NULL,11,14972,0);
INSERT INTO "django_geo_db_location" VALUES(25643,NULL,'Largo, FL 33777',10376,222,NULL,11,14973,0);
INSERT INTO "django_geo_db_location" VALUES(25644,NULL,'Largo, FL 33778',10376,222,NULL,11,14974,0);
INSERT INTO "django_geo_db_location" VALUES(25645,NULL,'Largo, FL 33779',10376,222,NULL,11,14975,0);
INSERT INTO "django_geo_db_location" VALUES(25646,NULL,'Pinellas Park, FL',10378,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25647,NULL,'Pinellas Park, FL 33780',10378,222,NULL,11,14976,0);
INSERT INTO "django_geo_db_location" VALUES(25648,NULL,'Pinellas Park, FL 33781',10378,222,NULL,11,14977,0);
INSERT INTO "django_geo_db_location" VALUES(25649,NULL,'Pinellas Park, FL 33782',10378,222,NULL,11,14978,0);
INSERT INTO "django_geo_db_location" VALUES(25650,NULL,'Saint Petersburg, FL 33784',10372,222,NULL,11,14979,0);
INSERT INTO "django_geo_db_location" VALUES(25651,NULL,'Indian Rocks Beach, FL',10379,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25652,NULL,'Indian Rocks Beach, FL 33785',10379,222,NULL,11,14980,0);
INSERT INTO "django_geo_db_location" VALUES(25653,NULL,'Belleair Beach, FL',10380,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25654,NULL,'Belleair Beach, FL 33786',10380,222,NULL,11,14981,0);
INSERT INTO "django_geo_db_location" VALUES(25655,NULL,'Lakeland, FL',10381,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25656,NULL,'Lakeland, FL 33801',10381,222,NULL,11,14982,0);
INSERT INTO "django_geo_db_location" VALUES(25657,NULL,'Lakeland, FL 33802',10381,222,NULL,11,14983,0);
INSERT INTO "django_geo_db_location" VALUES(25658,NULL,'Lakeland, FL 33803',10381,222,NULL,11,14984,0);
INSERT INTO "django_geo_db_location" VALUES(25659,NULL,'Lakeland, FL 33804',10381,222,NULL,11,14985,0);
INSERT INTO "django_geo_db_location" VALUES(25660,NULL,'Lakeland, FL 33805',10381,222,NULL,11,14986,0);
INSERT INTO "django_geo_db_location" VALUES(25661,NULL,'Lakeland, FL 33806',10381,222,NULL,11,14987,0);
INSERT INTO "django_geo_db_location" VALUES(25662,NULL,'Lakeland, FL 33807',10381,222,NULL,11,14988,0);
INSERT INTO "django_geo_db_location" VALUES(25663,NULL,'Lakeland, FL 33809',10381,222,NULL,11,14989,0);
INSERT INTO "django_geo_db_location" VALUES(25664,NULL,'Lakeland, FL 33810',10381,222,NULL,11,14990,0);
INSERT INTO "django_geo_db_location" VALUES(25665,NULL,'Lakeland, FL 33811',10381,222,NULL,11,14991,0);
INSERT INTO "django_geo_db_location" VALUES(25666,NULL,'Lakeland, FL 33813',10381,222,NULL,11,14992,0);
INSERT INTO "django_geo_db_location" VALUES(25667,NULL,'Lakeland, FL 33815',10381,222,NULL,11,14993,0);
INSERT INTO "django_geo_db_location" VALUES(25668,NULL,'Alturas, FL',10382,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25669,NULL,'Alturas, FL 33820',10382,222,NULL,11,14994,0);
INSERT INTO "django_geo_db_location" VALUES(25670,NULL,'Auburndale, FL',10383,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25671,NULL,'Auburndale, FL 33823',10383,222,NULL,11,14995,0);
INSERT INTO "django_geo_db_location" VALUES(25672,NULL,'Avon Park, FL',10384,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25673,NULL,'Avon Park, FL 33825',10384,222,NULL,11,14996,0);
INSERT INTO "django_geo_db_location" VALUES(25674,NULL,'Avon Park, FL 33826',10384,222,NULL,11,14997,0);
INSERT INTO "django_geo_db_location" VALUES(25675,NULL,'Babson Park, FL',10385,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25676,NULL,'Babson Park, FL 33827',10385,222,NULL,11,14998,0);
INSERT INTO "django_geo_db_location" VALUES(25677,NULL,'Bartow, FL',10386,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25678,NULL,'Bartow, FL 33830',10386,222,NULL,11,14999,0);
INSERT INTO "django_geo_db_location" VALUES(25679,NULL,'Bartow, FL 33831',10386,222,NULL,11,15000,0);
INSERT INTO "django_geo_db_location" VALUES(25680,NULL,'Bowling Green, FL',10387,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25681,NULL,'Bowling Green, FL 33834',10387,222,NULL,11,15001,0);
INSERT INTO "django_geo_db_location" VALUES(25682,NULL,'Bradley, FL',10388,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25683,NULL,'Bradley, FL 33835',10388,222,NULL,11,15002,0);
INSERT INTO "django_geo_db_location" VALUES(25684,NULL,'Davenport, FL',10389,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25685,NULL,'Davenport, FL 33836',10389,222,NULL,11,15003,0);
INSERT INTO "django_geo_db_location" VALUES(25686,NULL,'Davenport, FL 33837',10389,222,NULL,11,15004,0);
INSERT INTO "django_geo_db_location" VALUES(25687,NULL,'Dundee, FL',10390,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25688,NULL,'Dundee, FL 33838',10390,222,NULL,11,15005,0);
INSERT INTO "django_geo_db_location" VALUES(25689,NULL,'Eagle Lake, FL',10391,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25690,NULL,'Eagle Lake, FL 33839',10391,222,NULL,11,15006,0);
INSERT INTO "django_geo_db_location" VALUES(25691,NULL,'Eaton Park, FL',10392,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25692,NULL,'Eaton Park, FL 33840',10392,222,NULL,11,15007,0);
INSERT INTO "django_geo_db_location" VALUES(25693,NULL,'Fort Meade, FL',10393,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25694,NULL,'Fort Meade, FL 33841',10393,222,NULL,11,15008,0);
INSERT INTO "django_geo_db_location" VALUES(25695,NULL,'Frostproof, FL',10394,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25696,NULL,'Frostproof, FL 33843',10394,222,NULL,11,15009,0);
INSERT INTO "django_geo_db_location" VALUES(25697,NULL,'Haines City, FL',10395,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25698,NULL,'Haines City, FL 33844',10395,222,NULL,11,15010,0);
INSERT INTO "django_geo_db_location" VALUES(25699,NULL,'Haines City, FL 33845',10395,222,NULL,11,15011,0);
INSERT INTO "django_geo_db_location" VALUES(25700,NULL,'Highland City, FL',10396,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25701,NULL,'Highland City, FL 33846',10396,222,NULL,11,15012,0);
INSERT INTO "django_geo_db_location" VALUES(25702,NULL,'Homeland, FL',10397,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25703,NULL,'Homeland, FL 33847',10397,222,NULL,11,15013,0);
INSERT INTO "django_geo_db_location" VALUES(25704,NULL,'Intercession City, FL',10398,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25705,NULL,'Intercession City, FL 33848',10398,222,NULL,11,15014,0);
INSERT INTO "django_geo_db_location" VALUES(25706,NULL,'Kathleen, FL',10399,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25707,NULL,'Kathleen, FL 33849',10399,222,NULL,11,15015,0);
INSERT INTO "django_geo_db_location" VALUES(25708,NULL,'Lake Alfred, FL',10400,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25709,NULL,'Lake Alfred, FL 33850',10400,222,NULL,11,15016,0);
INSERT INTO "django_geo_db_location" VALUES(25710,NULL,'Lake Hamilton, FL',10401,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25711,NULL,'Lake Hamilton, FL 33851',10401,222,NULL,11,15017,0);
INSERT INTO "django_geo_db_location" VALUES(25712,NULL,'Lake Placid, FL',10402,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25713,NULL,'Lake Placid, FL 33852',10402,222,NULL,11,15018,0);
INSERT INTO "django_geo_db_location" VALUES(25714,NULL,'Lake Wales, FL',10403,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25715,NULL,'Lake Wales, FL 33853',10403,222,NULL,11,15019,0);
INSERT INTO "django_geo_db_location" VALUES(25716,NULL,'Fedhaven, FL',10404,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25717,NULL,'Fedhaven, FL 33854',10404,222,NULL,11,15020,0);
INSERT INTO "django_geo_db_location" VALUES(25718,NULL,'Indian Lake Estates, FL',10405,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25719,NULL,'Indian Lake Estates, FL 33855',10405,222,NULL,11,15021,0);
INSERT INTO "django_geo_db_location" VALUES(25720,NULL,'Nalcrest, FL',10406,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25721,NULL,'Nalcrest, FL 33856',10406,222,NULL,11,15022,0);
INSERT INTO "django_geo_db_location" VALUES(25722,NULL,'Lorida, FL',10407,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25723,NULL,'Lorida, FL 33857',10407,222,NULL,11,15023,0);
INSERT INTO "django_geo_db_location" VALUES(25724,NULL,'Loughman, FL',10408,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25725,NULL,'Loughman, FL 33858',10408,222,NULL,11,15024,0);
INSERT INTO "django_geo_db_location" VALUES(25726,NULL,'Lake Wales, FL 33859',10403,222,NULL,11,15025,0);
INSERT INTO "django_geo_db_location" VALUES(25727,NULL,'Mulberry, FL',10409,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25728,NULL,'Mulberry, FL 33860',10409,222,NULL,11,15026,0);
INSERT INTO "django_geo_db_location" VALUES(25729,NULL,'Lake Placid, FL 33862',10402,222,NULL,11,15027,0);
INSERT INTO "django_geo_db_location" VALUES(25730,NULL,'Nichols, FL',10410,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25731,NULL,'Nichols, FL 33863',10410,222,NULL,11,15028,0);
INSERT INTO "django_geo_db_location" VALUES(25732,NULL,'Ona, FL',10411,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25733,NULL,'Ona, FL 33865',10411,222,NULL,11,15029,0);
INSERT INTO "django_geo_db_location" VALUES(25734,NULL,'River Ranch, FL',10412,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25735,NULL,'River Ranch, FL 33867',10412,222,NULL,11,15030,0);
INSERT INTO "django_geo_db_location" VALUES(25736,NULL,'Polk City, FL',10413,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25737,NULL,'Polk City, FL 33868',10413,222,NULL,11,15031,0);
INSERT INTO "django_geo_db_location" VALUES(25738,NULL,'Sebring, FL',10414,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25739,NULL,'Sebring, FL 33870',10414,222,NULL,11,15032,0);
INSERT INTO "django_geo_db_location" VALUES(25740,NULL,'Sebring, FL 33871',10414,222,NULL,11,15033,0);
INSERT INTO "django_geo_db_location" VALUES(25741,NULL,'Sebring, FL 33872',10414,222,NULL,11,15034,0);
INSERT INTO "django_geo_db_location" VALUES(25742,NULL,'Wauchula, FL',10415,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25743,NULL,'Wauchula, FL 33873',10415,222,NULL,11,15035,0);
INSERT INTO "django_geo_db_location" VALUES(25744,NULL,'Sebring, FL 33875',10414,222,NULL,11,15036,0);
INSERT INTO "django_geo_db_location" VALUES(25745,NULL,'Sebring, FL 33876',10414,222,NULL,11,15037,0);
INSERT INTO "django_geo_db_location" VALUES(25746,NULL,'Waverly, FL',10416,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25747,NULL,'Waverly, FL 33877',10416,222,NULL,11,15038,0);
INSERT INTO "django_geo_db_location" VALUES(25748,NULL,'Winter Haven, FL 33880',10313,222,NULL,11,15039,0);
INSERT INTO "django_geo_db_location" VALUES(25749,NULL,'Winter Haven, FL 33881',10313,222,NULL,11,15040,0);
INSERT INTO "django_geo_db_location" VALUES(25750,NULL,'Winter Haven, FL 33882',10313,222,NULL,11,15041,0);
INSERT INTO "django_geo_db_location" VALUES(25751,NULL,'Winter Haven, FL 33883',10313,222,NULL,11,15042,0);
INSERT INTO "django_geo_db_location" VALUES(25752,NULL,'Winter Haven, FL 33884',10313,222,NULL,11,15043,0);
INSERT INTO "django_geo_db_location" VALUES(25753,NULL,'Winter Haven, FL 33885',10313,222,NULL,11,15044,0);
INSERT INTO "django_geo_db_location" VALUES(25754,NULL,'Winter Haven, FL 33888',10313,222,NULL,11,15045,0);
INSERT INTO "django_geo_db_location" VALUES(25755,NULL,'Zolfo Springs, FL',10417,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25756,NULL,'Zolfo Springs, FL 33890',10417,222,NULL,11,15046,0);
INSERT INTO "django_geo_db_location" VALUES(25757,NULL,'Loughman, FL 33896',10408,222,NULL,11,15047,0);
INSERT INTO "django_geo_db_location" VALUES(25758,NULL,'Citrus Ridge, FL',10418,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25759,NULL,'Citrus Ridge, FL 33897',10418,222,NULL,11,15048,0);
INSERT INTO "django_geo_db_location" VALUES(25760,NULL,'Highland Park, FL',10419,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25761,NULL,'Highland Park, FL 33898',10419,222,NULL,11,15049,0);
INSERT INTO "django_geo_db_location" VALUES(25762,NULL,'Fort Myers, FL',10420,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25763,NULL,'Fort Myers, FL 33901',10420,222,NULL,11,15050,0);
INSERT INTO "django_geo_db_location" VALUES(25764,NULL,'Fort Myers, FL 33902',10420,222,NULL,11,15051,0);
INSERT INTO "django_geo_db_location" VALUES(25765,NULL,'North Fort Myers, FL',10421,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25766,NULL,'North Fort Myers, FL 33903',10421,222,NULL,11,15052,0);
INSERT INTO "django_geo_db_location" VALUES(25767,NULL,'Cape Coral, FL',10422,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25768,NULL,'Cape Coral, FL 33904',10422,222,NULL,11,15053,0);
INSERT INTO "django_geo_db_location" VALUES(25769,NULL,'Fort Myers, FL 33905',10420,222,NULL,11,15054,0);
INSERT INTO "django_geo_db_location" VALUES(25770,NULL,'Fort Myers, FL 33906',10420,222,NULL,11,15055,0);
INSERT INTO "django_geo_db_location" VALUES(25771,NULL,'Fort Myers, FL 33907',10420,222,NULL,11,15056,0);
INSERT INTO "django_geo_db_location" VALUES(25772,NULL,'Fort Myers, FL 33908',10420,222,NULL,11,15057,0);
INSERT INTO "django_geo_db_location" VALUES(25773,NULL,'Cape Coral, FL 33909',10422,222,NULL,11,15058,0);
INSERT INTO "django_geo_db_location" VALUES(25774,NULL,'Cape Coral, FL 33910',10422,222,NULL,11,15059,0);
INSERT INTO "django_geo_db_location" VALUES(25775,NULL,'Fort Myers, FL 33911',10420,222,NULL,11,15060,0);
INSERT INTO "django_geo_db_location" VALUES(25776,NULL,'Fort Myers, FL 33912',10420,222,NULL,11,15061,0);
INSERT INTO "django_geo_db_location" VALUES(25777,NULL,'Fort Myers, FL 33913',10420,222,NULL,11,15062,0);
INSERT INTO "django_geo_db_location" VALUES(25778,NULL,'Cape Coral, FL 33914',10422,222,NULL,11,15063,0);
INSERT INTO "django_geo_db_location" VALUES(25779,NULL,'Cape Coral, FL 33915',10422,222,NULL,11,15064,0);
INSERT INTO "django_geo_db_location" VALUES(25780,NULL,'Fort Myers, FL 33916',10420,222,NULL,11,15065,0);
INSERT INTO "django_geo_db_location" VALUES(25781,NULL,'North Fort Myers, FL 33917',10421,222,NULL,11,15066,0);
INSERT INTO "django_geo_db_location" VALUES(25782,NULL,'North Fort Myers, FL 33918',10421,222,NULL,11,15067,0);
INSERT INTO "django_geo_db_location" VALUES(25783,NULL,'Fort Myers, FL 33919',10420,222,NULL,11,15068,0);
INSERT INTO "django_geo_db_location" VALUES(25784,NULL,'Alva, FL',10423,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25785,NULL,'Alva, FL 33920',10423,222,NULL,11,15069,0);
INSERT INTO "django_geo_db_location" VALUES(25786,NULL,'Boca Grande, FL',10424,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25787,NULL,'Boca Grande, FL 33921',10424,222,NULL,11,15070,0);
INSERT INTO "django_geo_db_location" VALUES(25788,NULL,'Bokeelia, FL',10425,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25789,NULL,'Bokeelia, FL 33922',10425,222,NULL,11,15071,0);
INSERT INTO "django_geo_db_location" VALUES(25790,NULL,'Captiva, FL',10426,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25791,NULL,'Captiva, FL 33924',10426,222,NULL,11,15072,0);
INSERT INTO "django_geo_db_location" VALUES(25792,NULL,'Punta Gorda, FL 33927',10369,222,NULL,11,15073,0);
INSERT INTO "django_geo_db_location" VALUES(25793,NULL,'Estero, FL',10427,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25794,NULL,'Estero, FL 33928',10427,222,NULL,11,15074,0);
INSERT INTO "django_geo_db_location" VALUES(25795,NULL,'Felda, FL',10428,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25796,NULL,'Felda, FL 33930',10428,222,NULL,11,15075,0);
INSERT INTO "django_geo_db_location" VALUES(25797,NULL,'Fort Myers Beach, FL',10429,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25798,NULL,'Fort Myers Beach, FL 33931',10429,222,NULL,11,15076,0);
INSERT INTO "django_geo_db_location" VALUES(25799,NULL,'Fort Myers Beach, FL 33932',10429,222,NULL,11,15077,0);
INSERT INTO "django_geo_db_location" VALUES(25800,NULL,'Labelle, FL',10430,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25801,NULL,'Labelle, FL 33935',10430,222,NULL,11,15078,0);
INSERT INTO "django_geo_db_location" VALUES(25802,NULL,'Lehigh Acres, FL',10431,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25803,NULL,'Lehigh Acres, FL 33936',10431,222,NULL,11,15079,0);
INSERT INTO "django_geo_db_location" VALUES(25804,NULL,'Murdock, FL',10432,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25805,NULL,'Murdock, FL 33938',10432,222,NULL,11,15080,0);
INSERT INTO "django_geo_db_location" VALUES(25806,NULL,'Palmdale, FL',10433,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25807,NULL,'Palmdale, FL 33944',10433,222,NULL,11,15081,0);
INSERT INTO "django_geo_db_location" VALUES(25808,NULL,'Pineland, FL',10434,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25809,NULL,'Pineland, FL 33945',10434,222,NULL,11,15082,0);
INSERT INTO "django_geo_db_location" VALUES(25810,NULL,'Placida, FL',10435,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25811,NULL,'Placida, FL 33946',10435,222,NULL,11,15083,0);
INSERT INTO "django_geo_db_location" VALUES(25812,NULL,'Rotonda West, FL',10436,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25813,NULL,'Rotonda West, FL 33947',10436,222,NULL,11,15084,0);
INSERT INTO "django_geo_db_location" VALUES(25814,NULL,'Port Charlotte, FL',10437,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25815,NULL,'Port Charlotte, FL 33948',10437,222,NULL,11,15085,0);
INSERT INTO "django_geo_db_location" VALUES(25816,NULL,'Port Charlotte, FL 33949',10437,222,NULL,11,15086,0);
INSERT INTO "django_geo_db_location" VALUES(25817,NULL,'Punta Gorda, FL 33950',10369,222,NULL,11,15087,0);
INSERT INTO "django_geo_db_location" VALUES(25818,NULL,'Punta Gorda, FL 33951',10369,222,NULL,11,15088,0);
INSERT INTO "django_geo_db_location" VALUES(25819,NULL,'Port Charlotte, FL 33952',10437,222,NULL,11,15089,0);
INSERT INTO "django_geo_db_location" VALUES(25820,NULL,'Port Charlotte, FL 33953',10437,222,NULL,11,15090,0);
INSERT INTO "django_geo_db_location" VALUES(25821,NULL,'Port Charlotte, FL 33954',10437,222,NULL,11,15091,0);
INSERT INTO "django_geo_db_location" VALUES(25822,NULL,'Punta Gorda, FL 33955',10369,222,NULL,11,15092,0);
INSERT INTO "django_geo_db_location" VALUES(25823,NULL,'Saint James City, FL',10438,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25824,NULL,'Saint James City, FL 33956',10438,222,NULL,11,15093,0);
INSERT INTO "django_geo_db_location" VALUES(25825,NULL,'Sanibel, FL',10439,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25826,NULL,'Sanibel, FL 33957',10439,222,NULL,11,15094,0);
INSERT INTO "django_geo_db_location" VALUES(25827,NULL,'Venus, FL',10440,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25828,NULL,'Venus, FL 33960',10440,222,NULL,11,15095,0);
INSERT INTO "django_geo_db_location" VALUES(25829,NULL,'Fort Myers, FL 33961',10420,222,NULL,11,15096,0);
INSERT INTO "django_geo_db_location" VALUES(25830,NULL,'Fort Myers, FL 33965',10420,222,NULL,11,15097,0);
INSERT INTO "django_geo_db_location" VALUES(25831,NULL,'Lehigh Acres, FL 33970',10431,222,NULL,11,15098,0);
INSERT INTO "django_geo_db_location" VALUES(25832,NULL,'Lehigh Acres, FL 33971',10431,222,NULL,11,15099,0);
INSERT INTO "django_geo_db_location" VALUES(25833,NULL,'Lehigh Acres, FL 33972',10431,222,NULL,11,15100,0);
INSERT INTO "django_geo_db_location" VALUES(25834,NULL,'Labelle, FL 33975',10430,222,NULL,11,15101,0);
INSERT INTO "django_geo_db_location" VALUES(25835,NULL,'Port Charlotte, FL 33980',10437,222,NULL,11,15102,0);
INSERT INTO "django_geo_db_location" VALUES(25836,NULL,'Port Charlotte, FL 33981',10437,222,NULL,11,15103,0);
INSERT INTO "django_geo_db_location" VALUES(25837,NULL,'Punta Gorda, FL 33982',10369,222,NULL,11,15104,0);
INSERT INTO "django_geo_db_location" VALUES(25838,NULL,'Punta Gorda, FL 33983',10369,222,NULL,11,15105,0);
INSERT INTO "django_geo_db_location" VALUES(25839,NULL,'Cape Coral, FL 33990',10422,222,NULL,11,15106,0);
INSERT INTO "django_geo_db_location" VALUES(25840,NULL,'Cape Coral, FL 33991',10422,222,NULL,11,15107,0);
INSERT INTO "django_geo_db_location" VALUES(25841,NULL,'Cape Coral, FL 33993',10422,222,NULL,11,15108,0);
INSERT INTO "django_geo_db_location" VALUES(25842,NULL,'Fort Myers, FL 33994',10420,222,NULL,11,15109,0);
INSERT INTO "django_geo_db_location" VALUES(25843,NULL,'Naples, FL',10441,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25844,NULL,'Naples, FL 34101',10441,222,NULL,11,15110,0);
INSERT INTO "django_geo_db_location" VALUES(25845,NULL,'Naples, FL 34102',10441,222,NULL,11,15111,0);
INSERT INTO "django_geo_db_location" VALUES(25846,NULL,'Naples, FL 34103',10441,222,NULL,11,15112,0);
INSERT INTO "django_geo_db_location" VALUES(25847,NULL,'Naples, FL 34104',10441,222,NULL,11,15113,0);
INSERT INTO "django_geo_db_location" VALUES(25848,NULL,'Naples, FL 34105',10441,222,NULL,11,15114,0);
INSERT INTO "django_geo_db_location" VALUES(25849,NULL,'Naples, FL 34106',10441,222,NULL,11,15115,0);
INSERT INTO "django_geo_db_location" VALUES(25850,NULL,'Vanderbilt Beach, FL',10442,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25851,NULL,'Vanderbilt Beach, FL 34107',10442,222,NULL,11,15116,0);
INSERT INTO "django_geo_db_location" VALUES(25852,NULL,'Naples, FL 34108',10441,222,NULL,11,15117,0);
INSERT INTO "django_geo_db_location" VALUES(25853,NULL,'Naples, FL 34109',10441,222,NULL,11,15118,0);
INSERT INTO "django_geo_db_location" VALUES(25854,NULL,'Naples, FL 34110',10441,222,NULL,11,15119,0);
INSERT INTO "django_geo_db_location" VALUES(25855,NULL,'Naples, FL 34112',10441,222,NULL,11,15120,0);
INSERT INTO "django_geo_db_location" VALUES(25856,NULL,'Naples, FL 34113',10441,222,NULL,11,15121,0);
INSERT INTO "django_geo_db_location" VALUES(25857,NULL,'Naples, FL 34114',10441,222,NULL,11,15122,0);
INSERT INTO "django_geo_db_location" VALUES(25858,NULL,'Naples, FL 34116',10441,222,NULL,11,15123,0);
INSERT INTO "django_geo_db_location" VALUES(25859,NULL,'Naples, FL 34117',10441,222,NULL,11,15124,0);
INSERT INTO "django_geo_db_location" VALUES(25860,NULL,'Naples, FL 34119',10441,222,NULL,11,15125,0);
INSERT INTO "django_geo_db_location" VALUES(25861,NULL,'Naples, FL 34120',10441,222,NULL,11,15126,0);
INSERT INTO "django_geo_db_location" VALUES(25862,NULL,'Bonita Springs, FL',10443,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25863,NULL,'Bonita Springs, FL 34133',10443,222,NULL,11,15127,0);
INSERT INTO "django_geo_db_location" VALUES(25864,NULL,'Bonita Springs, FL 34134',10443,222,NULL,11,15128,0);
INSERT INTO "django_geo_db_location" VALUES(25865,NULL,'Bonita Springs, FL 34135',10443,222,NULL,11,15129,0);
INSERT INTO "django_geo_db_location" VALUES(25866,NULL,'Bonita Springs, FL 34136',10443,222,NULL,11,15130,0);
INSERT INTO "django_geo_db_location" VALUES(25867,NULL,'Copeland, FL',10444,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25868,NULL,'Copeland, FL 34137',10444,222,NULL,11,15131,0);
INSERT INTO "django_geo_db_location" VALUES(25869,NULL,'Chokoloskee, FL',10445,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25870,NULL,'Chokoloskee, FL 34138',10445,222,NULL,11,15132,0);
INSERT INTO "django_geo_db_location" VALUES(25871,NULL,'Everglades City, FL',10446,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25872,NULL,'Everglades City, FL 34139',10446,222,NULL,11,15133,0);
INSERT INTO "django_geo_db_location" VALUES(25873,NULL,'Goodland, FL',10447,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25874,NULL,'Goodland, FL 34140',10447,222,NULL,11,15134,0);
INSERT INTO "django_geo_db_location" VALUES(25875,NULL,'Ochopee, FL',10448,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25876,NULL,'Ochopee, FL 34141',10448,222,NULL,11,15135,0);
INSERT INTO "django_geo_db_location" VALUES(25877,NULL,'Immokalee, FL',10449,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25878,NULL,'Immokalee, FL 34142',10449,222,NULL,11,15136,0);
INSERT INTO "django_geo_db_location" VALUES(25879,NULL,'Immokalee, FL 34143',10449,222,NULL,11,15137,0);
INSERT INTO "django_geo_db_location" VALUES(25880,NULL,'Marco Island, FL',10450,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25881,NULL,'Marco Island, FL 34145',10450,222,NULL,11,15138,0);
INSERT INTO "django_geo_db_location" VALUES(25882,NULL,'Marco Island, FL 34146',10450,222,NULL,11,15139,0);
INSERT INTO "django_geo_db_location" VALUES(25883,NULL,'Goodland, FL 34154',10447,222,NULL,11,15140,0);
INSERT INTO "django_geo_db_location" VALUES(25884,NULL,'Chokoloskee, FL 34168',10445,222,NULL,11,15141,0);
INSERT INTO "django_geo_db_location" VALUES(25885,NULL,'Bradenton, FL',10451,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25886,NULL,'Bradenton, FL 34201',10451,222,NULL,11,15142,0);
INSERT INTO "django_geo_db_location" VALUES(25887,NULL,'Bradenton, FL 34202',10451,222,NULL,11,15143,0);
INSERT INTO "django_geo_db_location" VALUES(25888,NULL,'Bradenton, FL 34203',10451,222,NULL,11,15144,0);
INSERT INTO "django_geo_db_location" VALUES(25889,NULL,'Bradenton, FL 34204',10451,222,NULL,11,15145,0);
INSERT INTO "django_geo_db_location" VALUES(25890,NULL,'Bradenton, FL 34205',10451,222,NULL,11,15146,0);
INSERT INTO "django_geo_db_location" VALUES(25891,NULL,'Bradenton, FL 34206',10451,222,NULL,11,15147,0);
INSERT INTO "django_geo_db_location" VALUES(25892,NULL,'Bradenton, FL 34207',10451,222,NULL,11,15148,0);
INSERT INTO "django_geo_db_location" VALUES(25893,NULL,'Bradenton, FL 34208',10451,222,NULL,11,15149,0);
INSERT INTO "django_geo_db_location" VALUES(25894,NULL,'Bradenton, FL 34209',10451,222,NULL,11,15150,0);
INSERT INTO "django_geo_db_location" VALUES(25895,NULL,'Bradenton, FL 34210',10451,222,NULL,11,15151,0);
INSERT INTO "django_geo_db_location" VALUES(25896,NULL,'Memphis, FL',10452,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25897,NULL,'Memphis, FL 34211',10452,222,NULL,11,15152,0);
INSERT INTO "django_geo_db_location" VALUES(25898,NULL,'Cortez, FL',10453,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25899,NULL,'Cortez, FL 34215',10453,222,NULL,11,15153,0);
INSERT INTO "django_geo_db_location" VALUES(25900,NULL,'Anna Maria, FL',10454,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25901,NULL,'Anna Maria, FL 34216',10454,222,NULL,11,15154,0);
INSERT INTO "django_geo_db_location" VALUES(25902,NULL,'Bradenton Beach, FL',10455,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25903,NULL,'Bradenton Beach, FL 34217',10455,222,NULL,11,15155,0);
INSERT INTO "django_geo_db_location" VALUES(25904,NULL,'Holmes Beach, FL',10456,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25905,NULL,'Holmes Beach, FL 34218',10456,222,NULL,11,15156,0);
INSERT INTO "django_geo_db_location" VALUES(25906,NULL,'Parrish, FL',10457,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25907,NULL,'Parrish, FL 34219',10457,222,NULL,11,15157,0);
INSERT INTO "django_geo_db_location" VALUES(25908,NULL,'Palmetto, FL',10458,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25909,NULL,'Palmetto, FL 34220',10458,222,NULL,11,15158,0);
INSERT INTO "django_geo_db_location" VALUES(25910,NULL,'Palmetto, FL 34221',10458,222,NULL,11,15159,0);
INSERT INTO "django_geo_db_location" VALUES(25911,NULL,'Ellenton, FL',10459,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25912,NULL,'Ellenton, FL 34222',10459,222,NULL,11,15160,0);
INSERT INTO "django_geo_db_location" VALUES(25913,NULL,'Englewood, FL',10460,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25914,NULL,'Englewood, FL 34223',10460,222,NULL,11,15161,0);
INSERT INTO "django_geo_db_location" VALUES(25915,NULL,'Englewood, FL 34224',10460,222,NULL,11,15162,0);
INSERT INTO "django_geo_db_location" VALUES(25916,NULL,'Longboat Key, FL',10461,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25917,NULL,'Longboat Key, FL 34228',10461,222,NULL,11,15163,0);
INSERT INTO "django_geo_db_location" VALUES(25918,NULL,'Osprey, FL',10462,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25919,NULL,'Osprey, FL 34229',10462,222,NULL,11,15164,0);
INSERT INTO "django_geo_db_location" VALUES(25920,NULL,'Sarasota, FL',10463,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25921,NULL,'Sarasota, FL 34230',10463,222,NULL,11,15165,0);
INSERT INTO "django_geo_db_location" VALUES(25922,NULL,'Sarasota, FL 34231',10463,222,NULL,11,15166,0);
INSERT INTO "django_geo_db_location" VALUES(25923,NULL,'Sarasota, FL 34232',10463,222,NULL,11,15167,0);
INSERT INTO "django_geo_db_location" VALUES(25924,NULL,'Sarasota, FL 34233',10463,222,NULL,11,15168,0);
INSERT INTO "django_geo_db_location" VALUES(25925,NULL,'Sarasota, FL 34234',10463,222,NULL,11,15169,0);
INSERT INTO "django_geo_db_location" VALUES(25926,NULL,'Sarasota, FL 34235',10463,222,NULL,11,15170,0);
INSERT INTO "django_geo_db_location" VALUES(25927,NULL,'Sarasota, FL 34236',10463,222,NULL,11,15171,0);
INSERT INTO "django_geo_db_location" VALUES(25928,NULL,'Sarasota, FL 34237',10463,222,NULL,11,15172,0);
INSERT INTO "django_geo_db_location" VALUES(25929,NULL,'Sarasota, FL 34238',10463,222,NULL,11,15173,0);
INSERT INTO "django_geo_db_location" VALUES(25930,NULL,'Sarasota, FL 34239',10463,222,NULL,11,15174,0);
INSERT INTO "django_geo_db_location" VALUES(25931,NULL,'Sarasota, FL 34240',10463,222,NULL,11,15175,0);
INSERT INTO "django_geo_db_location" VALUES(25932,NULL,'Sarasota, FL 34241',10463,222,NULL,11,15176,0);
INSERT INTO "django_geo_db_location" VALUES(25933,NULL,'Sarasota, FL 34242',10463,222,NULL,11,15177,0);
INSERT INTO "django_geo_db_location" VALUES(25934,NULL,'Sarasota, FL 34243',10463,222,NULL,11,15178,0);
INSERT INTO "django_geo_db_location" VALUES(25935,NULL,'Terra Ceia, FL',10464,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25936,NULL,'Terra Ceia, FL 34250',10464,222,NULL,11,15179,0);
INSERT INTO "django_geo_db_location" VALUES(25937,NULL,'Myakka City, FL',10465,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25938,NULL,'Myakka City, FL 34251',10465,222,NULL,11,15180,0);
INSERT INTO "django_geo_db_location" VALUES(25939,NULL,'Manasota, FL',10466,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25940,NULL,'Manasota, FL 34260',10466,222,NULL,11,15181,0);
INSERT INTO "django_geo_db_location" VALUES(25941,NULL,'Oneco, FL',10467,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25942,NULL,'Oneco, FL 34264',10467,222,NULL,11,15182,0);
INSERT INTO "django_geo_db_location" VALUES(25943,NULL,'Arcadia, FL',10468,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25944,NULL,'Arcadia, FL 34265',10468,222,NULL,11,15183,0);
INSERT INTO "django_geo_db_location" VALUES(25945,NULL,'Arcadia, FL 34266',10468,222,NULL,11,15184,0);
INSERT INTO "django_geo_db_location" VALUES(25946,NULL,'Fort Ogden, FL',10469,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25947,NULL,'Fort Ogden, FL 34267',10469,222,NULL,11,15185,0);
INSERT INTO "django_geo_db_location" VALUES(25948,NULL,'Nocatee, FL',10470,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25949,NULL,'Nocatee, FL 34268',10470,222,NULL,11,15186,0);
INSERT INTO "django_geo_db_location" VALUES(25950,NULL,'Tallevast, FL',10471,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25951,NULL,'Tallevast, FL 34270',10471,222,NULL,11,15187,0);
INSERT INTO "django_geo_db_location" VALUES(25952,NULL,'Laurel, FL',10472,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25953,NULL,'Laurel, FL 34272',10472,222,NULL,11,15188,0);
INSERT INTO "django_geo_db_location" VALUES(25954,NULL,'Nokomis, FL',10473,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25955,NULL,'Nokomis, FL 34274',10473,222,NULL,11,15189,0);
INSERT INTO "django_geo_db_location" VALUES(25956,NULL,'Nokomis, FL 34275',10473,222,NULL,11,15190,0);
INSERT INTO "django_geo_db_location" VALUES(25957,NULL,'Sarasota, FL 34276',10463,222,NULL,11,15191,0);
INSERT INTO "django_geo_db_location" VALUES(25958,NULL,'Sarasota, FL 34277',10463,222,NULL,11,15192,0);
INSERT INTO "django_geo_db_location" VALUES(25959,NULL,'Sarasota, FL 34278',10463,222,NULL,11,15193,0);
INSERT INTO "django_geo_db_location" VALUES(25960,NULL,'Bradenton, FL 34280',10451,222,NULL,11,15194,0);
INSERT INTO "django_geo_db_location" VALUES(25961,NULL,'Bradenton, FL 34281',10451,222,NULL,11,15195,0);
INSERT INTO "django_geo_db_location" VALUES(25962,NULL,'Bradenton, FL 34282',10451,222,NULL,11,15196,0);
INSERT INTO "django_geo_db_location" VALUES(25963,NULL,'Venice, FL',10474,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25964,NULL,'Venice, FL 34284',10474,222,NULL,11,15197,0);
INSERT INTO "django_geo_db_location" VALUES(25965,NULL,'Venice, FL 34285',10474,222,NULL,11,15198,0);
INSERT INTO "django_geo_db_location" VALUES(25966,NULL,'North Port, FL',10475,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25967,NULL,'North Port, FL 34286',10475,222,NULL,11,15199,0);
INSERT INTO "django_geo_db_location" VALUES(25968,NULL,'North Port, FL 34287',10475,222,NULL,11,15200,0);
INSERT INTO "django_geo_db_location" VALUES(25969,NULL,'North Port, FL 34288',10475,222,NULL,11,15201,0);
INSERT INTO "django_geo_db_location" VALUES(25970,NULL,'North Port, FL 34289',10475,222,NULL,11,15202,0);
INSERT INTO "django_geo_db_location" VALUES(25971,NULL,'Venice, FL 34292',10474,222,NULL,11,15203,0);
INSERT INTO "django_geo_db_location" VALUES(25972,NULL,'Venice, FL 34293',10474,222,NULL,11,15204,0);
INSERT INTO "django_geo_db_location" VALUES(25973,NULL,'Englewood, FL 34295',10460,222,NULL,11,15205,0);
INSERT INTO "django_geo_db_location" VALUES(25974,NULL,'Grove City, FL',10476,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25975,NULL,'Grove City, FL 34334',10476,222,NULL,11,15206,0);
INSERT INTO "django_geo_db_location" VALUES(25976,NULL,'Belleview, FL',10477,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25977,NULL,'Belleview, FL 34420',10477,222,NULL,11,15207,0);
INSERT INTO "django_geo_db_location" VALUES(25978,NULL,'Belleview, FL 34421',10477,222,NULL,11,15208,0);
INSERT INTO "django_geo_db_location" VALUES(25979,NULL,'Crystal River, FL',10478,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25980,NULL,'Crystal River, FL 34423',10478,222,NULL,11,15209,0);
INSERT INTO "django_geo_db_location" VALUES(25981,NULL,'Crystal River, FL 34424',10478,222,NULL,11,15210,0);
INSERT INTO "django_geo_db_location" VALUES(25982,NULL,'Pine Ridge, FL',10479,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25983,NULL,'Pine Ridge, FL 34426',10479,222,NULL,11,15211,0);
INSERT INTO "django_geo_db_location" VALUES(25984,NULL,'Crystal River, FL 34428',10478,222,NULL,11,15212,0);
INSERT INTO "django_geo_db_location" VALUES(25985,NULL,'Crystal River, FL 34429',10478,222,NULL,11,15213,0);
INSERT INTO "django_geo_db_location" VALUES(25986,NULL,'Dunnellon, FL',10480,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25987,NULL,'Dunnellon, FL 34430',10480,222,NULL,11,15214,0);
INSERT INTO "django_geo_db_location" VALUES(25988,NULL,'Dunnellon, FL 34431',10480,222,NULL,11,15215,0);
INSERT INTO "django_geo_db_location" VALUES(25989,NULL,'Dunnellon, FL 34432',10480,222,NULL,11,15216,0);
INSERT INTO "django_geo_db_location" VALUES(25990,NULL,'Dunnellon, FL 34433',10480,222,NULL,11,15217,0);
INSERT INTO "django_geo_db_location" VALUES(25991,NULL,'Dunnellon, FL 34434',10480,222,NULL,11,15218,0);
INSERT INTO "django_geo_db_location" VALUES(25992,NULL,'Floral City, FL',10481,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25993,NULL,'Floral City, FL 34436',10481,222,NULL,11,15219,0);
INSERT INTO "django_geo_db_location" VALUES(25994,NULL,'Hernando, FL',10482,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25995,NULL,'Hernando, FL 34442',10482,222,NULL,11,15220,0);
INSERT INTO "django_geo_db_location" VALUES(25996,NULL,'Holder, FL',10483,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25997,NULL,'Holder, FL 34445',10483,222,NULL,11,15221,0);
INSERT INTO "django_geo_db_location" VALUES(25998,NULL,'Homosassa, FL',10484,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(25999,NULL,'Homosassa, FL 34446',10484,222,NULL,11,15222,0);
INSERT INTO "django_geo_db_location" VALUES(26000,NULL,'Homosassa Springs, FL',10485,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26001,NULL,'Homosassa Springs, FL 34447',10485,222,NULL,11,15223,0);
INSERT INTO "django_geo_db_location" VALUES(26002,NULL,'Homosassa, FL 34448',10484,222,NULL,11,15224,0);
INSERT INTO "django_geo_db_location" VALUES(26003,NULL,'Inglis, FL',10486,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26004,NULL,'Inglis, FL 34449',10486,222,NULL,11,15225,0);
INSERT INTO "django_geo_db_location" VALUES(26005,NULL,'Inverness, FL',10487,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26006,NULL,'Inverness, FL 34450',10487,222,NULL,11,15226,0);
INSERT INTO "django_geo_db_location" VALUES(26007,NULL,'Inverness, FL 34451',10487,222,NULL,11,15227,0);
INSERT INTO "django_geo_db_location" VALUES(26008,NULL,'Inverness, FL 34452',10487,222,NULL,11,15228,0);
INSERT INTO "django_geo_db_location" VALUES(26009,NULL,'Inverness, FL 34453',10487,222,NULL,11,15229,0);
INSERT INTO "django_geo_db_location" VALUES(26010,NULL,'Lecanto, FL',10488,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26011,NULL,'Lecanto, FL 34460',10488,222,NULL,11,15230,0);
INSERT INTO "django_geo_db_location" VALUES(26012,NULL,'Lecanto, FL 34461',10488,222,NULL,11,15231,0);
INSERT INTO "django_geo_db_location" VALUES(26013,NULL,'Beverly Hills, FL',10489,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26014,NULL,'Beverly Hills, FL 34464',10489,222,NULL,11,15232,0);
INSERT INTO "django_geo_db_location" VALUES(26015,NULL,'Beverly Hills, FL 34465',10489,222,NULL,11,15233,0);
INSERT INTO "django_geo_db_location" VALUES(26016,NULL,'Ocala, FL',10490,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26017,NULL,'Ocala, FL 34470',10490,222,NULL,11,15234,0);
INSERT INTO "django_geo_db_location" VALUES(26018,NULL,'Ocala, FL 34471',10490,222,NULL,11,15235,0);
INSERT INTO "django_geo_db_location" VALUES(26019,NULL,'Ocala, FL 34472',10490,222,NULL,11,15236,0);
INSERT INTO "django_geo_db_location" VALUES(26020,NULL,'Ocala, FL 34473',10490,222,NULL,11,15237,0);
INSERT INTO "django_geo_db_location" VALUES(26021,NULL,'Ocala, FL 34474',10490,222,NULL,11,15238,0);
INSERT INTO "django_geo_db_location" VALUES(26022,NULL,'Ocala, FL 34475',10490,222,NULL,11,15239,0);
INSERT INTO "django_geo_db_location" VALUES(26023,NULL,'Ocala, FL 34476',10490,222,NULL,11,15240,0);
INSERT INTO "django_geo_db_location" VALUES(26024,NULL,'Ocala, FL 34477',10490,222,NULL,11,15241,0);
INSERT INTO "django_geo_db_location" VALUES(26025,NULL,'Ocala, FL 34478',10490,222,NULL,11,15242,0);
INSERT INTO "django_geo_db_location" VALUES(26026,NULL,'Ocala, FL 34479',10490,222,NULL,11,15243,0);
INSERT INTO "django_geo_db_location" VALUES(26027,NULL,'Ocala, FL 34480',10490,222,NULL,11,15244,0);
INSERT INTO "django_geo_db_location" VALUES(26028,NULL,'Ocala, FL 34481',10490,222,NULL,11,15245,0);
INSERT INTO "django_geo_db_location" VALUES(26029,NULL,'Ocala, FL 34482',10490,222,NULL,11,15246,0);
INSERT INTO "django_geo_db_location" VALUES(26030,NULL,'Ocala, FL 34483',10490,222,NULL,11,15247,0);
INSERT INTO "django_geo_db_location" VALUES(26031,NULL,'Oxford, FL',10491,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26032,NULL,'Oxford, FL 34484',10491,222,NULL,11,15248,0);
INSERT INTO "django_geo_db_location" VALUES(26033,NULL,'Homosassa, FL 34487',10484,222,NULL,11,15249,0);
INSERT INTO "django_geo_db_location" VALUES(26034,NULL,'Silver Springs, FL',10492,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26035,NULL,'Silver Springs, FL 34488',10492,222,NULL,11,15250,0);
INSERT INTO "django_geo_db_location" VALUES(26036,NULL,'Silver Springs, FL 34489',10492,222,NULL,11,15251,0);
INSERT INTO "django_geo_db_location" VALUES(26037,NULL,'Summerfield, FL',10493,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26038,NULL,'Summerfield, FL 34491',10493,222,NULL,11,15252,0);
INSERT INTO "django_geo_db_location" VALUES(26039,NULL,'Summerfield, FL 34492',10493,222,NULL,11,15253,0);
INSERT INTO "django_geo_db_location" VALUES(26040,NULL,'Yankeetown, FL',10494,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26041,NULL,'Yankeetown, FL 34498',10494,222,NULL,11,15254,0);
INSERT INTO "django_geo_db_location" VALUES(26042,NULL,'Port St. Lucie, FL',10495,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26043,NULL,'Port St. Lucie, FL 34592',10495,222,NULL,11,15255,0);
INSERT INTO "django_geo_db_location" VALUES(26044,NULL,'Brooksville, FL',10496,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26045,NULL,'Brooksville, FL 34601',10496,222,NULL,11,15256,0);
INSERT INTO "django_geo_db_location" VALUES(26046,NULL,'Brooksville, FL 34602',10496,222,NULL,11,15257,0);
INSERT INTO "django_geo_db_location" VALUES(26047,NULL,'Brooksville, FL 34603',10496,222,NULL,11,15258,0);
INSERT INTO "django_geo_db_location" VALUES(26048,NULL,'Spring Hill, FL',10497,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26049,NULL,'Spring Hill, FL 34604',10497,222,NULL,11,15259,0);
INSERT INTO "django_geo_db_location" VALUES(26050,NULL,'Brooksville, FL 34605',10496,222,NULL,11,15260,0);
INSERT INTO "django_geo_db_location" VALUES(26051,NULL,'Spring Hill, FL 34606',10497,222,NULL,11,15261,0);
INSERT INTO "django_geo_db_location" VALUES(26052,NULL,'Spring Hill, FL 34607',10497,222,NULL,11,15262,0);
INSERT INTO "django_geo_db_location" VALUES(26053,NULL,'Spring Hill, FL 34608',10497,222,NULL,11,15263,0);
INSERT INTO "django_geo_db_location" VALUES(26054,NULL,'Brooksville, FL 34609',10496,222,NULL,11,15264,0);
INSERT INTO "django_geo_db_location" VALUES(26055,NULL,'Brooksville, FL 34610',10496,222,NULL,11,15265,0);
INSERT INTO "django_geo_db_location" VALUES(26056,NULL,'Spring Hill, FL 34611',10497,222,NULL,11,15266,0);
INSERT INTO "django_geo_db_location" VALUES(26057,NULL,'Brooksville, FL 34613',10496,222,NULL,11,15267,0);
INSERT INTO "django_geo_db_location" VALUES(26058,NULL,'Brooksville, FL 34614',10496,222,NULL,11,15268,0);
INSERT INTO "django_geo_db_location" VALUES(26059,NULL,'Istachatta, FL',10498,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26060,NULL,'Istachatta, FL 34636',10498,222,NULL,11,15269,0);
INSERT INTO "django_geo_db_location" VALUES(26061,NULL,'Land O Lakes, FL',10499,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26062,NULL,'Land O Lakes, FL 34639',10499,222,NULL,11,15270,0);
INSERT INTO "django_geo_db_location" VALUES(26063,NULL,'New Port Richey, FL',10500,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26064,NULL,'New Port Richey, FL 34652',10500,222,NULL,11,15271,0);
INSERT INTO "django_geo_db_location" VALUES(26065,NULL,'New Port Richey, FL 34653',10500,222,NULL,11,15272,0);
INSERT INTO "django_geo_db_location" VALUES(26066,NULL,'New Port Richey, FL 34654',10500,222,NULL,11,15273,0);
INSERT INTO "django_geo_db_location" VALUES(26067,NULL,'New Port Richey, FL 34655',10500,222,NULL,11,15274,0);
INSERT INTO "django_geo_db_location" VALUES(26068,NULL,'New Port Richey, FL 34656',10500,222,NULL,11,15275,0);
INSERT INTO "django_geo_db_location" VALUES(26069,NULL,'Ozona, FL',10501,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26070,NULL,'Ozona, FL 34660',10501,222,NULL,11,15276,0);
INSERT INTO "django_geo_db_location" VALUES(26071,NULL,'Nobleton, FL',10502,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26072,NULL,'Nobleton, FL 34661',10502,222,NULL,11,15277,0);
INSERT INTO "django_geo_db_location" VALUES(26073,NULL,'Hudson, FL',10503,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26074,NULL,'Hudson, FL 34667',10503,222,NULL,11,15278,0);
INSERT INTO "django_geo_db_location" VALUES(26075,NULL,'Port Richey, FL',10504,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26076,NULL,'Port Richey, FL 34668',10504,222,NULL,11,15279,0);
INSERT INTO "django_geo_db_location" VALUES(26077,NULL,'Hudson, FL 34669',10503,222,NULL,11,15280,0);
INSERT INTO "django_geo_db_location" VALUES(26078,NULL,'Port Richey, FL 34673',10504,222,NULL,11,15281,0);
INSERT INTO "django_geo_db_location" VALUES(26079,NULL,'Hudson, FL 34674',10503,222,NULL,11,15282,0);
INSERT INTO "django_geo_db_location" VALUES(26080,NULL,'Oldsmar, FL',10505,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26081,NULL,'Oldsmar, FL 34677',10505,222,NULL,11,15283,0);
INSERT INTO "django_geo_db_location" VALUES(26082,NULL,'Palm Harbor, FL',10506,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26083,NULL,'Palm Harbor, FL 34678',10506,222,NULL,11,15284,0);
INSERT INTO "django_geo_db_location" VALUES(26084,NULL,'Aripeka, FL',10507,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26085,NULL,'Aripeka, FL 34679',10507,222,NULL,11,15285,0);
INSERT INTO "django_geo_db_location" VALUES(26086,NULL,'Elfers, FL',10508,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26087,NULL,'Elfers, FL 34680',10508,222,NULL,11,15286,0);
INSERT INTO "django_geo_db_location" VALUES(26088,NULL,'Crystal Beach, FL',10509,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26089,NULL,'Crystal Beach, FL 34681',10509,222,NULL,11,15287,0);
INSERT INTO "django_geo_db_location" VALUES(26090,NULL,'Palm Harbor, FL 34682',10506,222,NULL,11,15288,0);
INSERT INTO "django_geo_db_location" VALUES(26091,NULL,'Palm Harbor, FL 34683',10506,222,NULL,11,15289,0);
INSERT INTO "django_geo_db_location" VALUES(26092,NULL,'Palm Harbor, FL 34684',10506,222,NULL,11,15290,0);
INSERT INTO "django_geo_db_location" VALUES(26093,NULL,'Palm Harbor, FL 34685',10506,222,NULL,11,15291,0);
INSERT INTO "django_geo_db_location" VALUES(26094,NULL,'Tarpon Springs, FL',10510,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26095,NULL,'Tarpon Springs, FL 34688',10510,222,NULL,11,15292,0);
INSERT INTO "django_geo_db_location" VALUES(26096,NULL,'Tarpon Springs, FL 34689',10510,222,NULL,11,15293,0);
INSERT INTO "django_geo_db_location" VALUES(26097,NULL,'Holiday, FL',10511,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26098,NULL,'Holiday, FL 34690',10511,222,NULL,11,15294,0);
INSERT INTO "django_geo_db_location" VALUES(26099,NULL,'Holiday, FL 34691',10511,222,NULL,11,15295,0);
INSERT INTO "django_geo_db_location" VALUES(26100,NULL,'Safety Harbor, FL',10512,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26101,NULL,'Safety Harbor, FL 34695',10512,222,NULL,11,15296,0);
INSERT INTO "django_geo_db_location" VALUES(26102,NULL,'Dunedin, FL',10513,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26103,NULL,'Dunedin, FL 34697',10513,222,NULL,11,15297,0);
INSERT INTO "django_geo_db_location" VALUES(26104,NULL,'Dunedin, FL 34698',10513,222,NULL,11,15298,0);
INSERT INTO "django_geo_db_location" VALUES(26105,NULL,'Astatula, FL',10514,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26106,NULL,'Astatula, FL 34703',10514,222,NULL,11,15299,0);
INSERT INTO "django_geo_db_location" VALUES(26107,NULL,'Astatula, FL 34705',10514,222,NULL,11,15300,0);
INSERT INTO "django_geo_db_location" VALUES(26108,NULL,'Clermont, FL',10515,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26109,NULL,'Clermont, FL 34711',10515,222,NULL,11,15301,0);
INSERT INTO "django_geo_db_location" VALUES(26110,NULL,'Clermont, FL 34712',10515,222,NULL,11,15302,0);
INSERT INTO "django_geo_db_location" VALUES(26111,NULL,'Clermont, FL 34713',10515,222,NULL,11,15303,0);
INSERT INTO "django_geo_db_location" VALUES(26112,NULL,'Ferndale, FL',10516,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26113,NULL,'Ferndale, FL 34729',10516,222,NULL,11,15304,0);
INSERT INTO "django_geo_db_location" VALUES(26114,NULL,'Fruitland Park, FL',10517,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26115,NULL,'Fruitland Park, FL 34731',10517,222,NULL,11,15305,0);
INSERT INTO "django_geo_db_location" VALUES(26116,NULL,'Gotha, FL',10518,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26117,NULL,'Gotha, FL 34734',10518,222,NULL,11,15306,0);
INSERT INTO "django_geo_db_location" VALUES(26118,NULL,'Groveland, FL',10519,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26119,NULL,'Groveland, FL 34736',10519,222,NULL,11,15307,0);
INSERT INTO "django_geo_db_location" VALUES(26120,NULL,'Howey In The Hills, FL',10520,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26121,NULL,'Howey In The Hills, FL 34737',10520,222,NULL,11,15308,0);
INSERT INTO "django_geo_db_location" VALUES(26122,NULL,'Kenansville, FL',10521,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26123,NULL,'Kenansville, FL 34739',10521,222,NULL,11,15309,0);
INSERT INTO "django_geo_db_location" VALUES(26124,NULL,'Killarney, FL',10522,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26125,NULL,'Killarney, FL 34740',10522,222,NULL,11,15310,0);
INSERT INTO "django_geo_db_location" VALUES(26126,NULL,'Kissimmee, FL',10523,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26127,NULL,'Kissimmee, FL 34741',10523,222,NULL,11,15311,0);
INSERT INTO "django_geo_db_location" VALUES(26128,NULL,'Kissimmee, FL 34742',10523,222,NULL,11,15312,0);
INSERT INTO "django_geo_db_location" VALUES(26129,NULL,'Kissimmee, FL 34743',10523,222,NULL,11,15313,0);
INSERT INTO "django_geo_db_location" VALUES(26130,NULL,'Kissimmee, FL 34744',10523,222,NULL,11,15314,0);
INSERT INTO "django_geo_db_location" VALUES(26131,NULL,'Kissimmee, FL 34745',10523,222,NULL,11,15315,0);
INSERT INTO "django_geo_db_location" VALUES(26132,NULL,'Kissimmee, FL 34746',10523,222,NULL,11,15316,0);
INSERT INTO "django_geo_db_location" VALUES(26133,NULL,'Kissimmee, FL 34747',10523,222,NULL,11,15317,0);
INSERT INTO "django_geo_db_location" VALUES(26134,NULL,'Leesburg, FL',10524,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26135,NULL,'Leesburg, FL 34748',10524,222,NULL,11,15318,0);
INSERT INTO "django_geo_db_location" VALUES(26136,NULL,'Leesburg, FL 34749',10524,222,NULL,11,15319,0);
INSERT INTO "django_geo_db_location" VALUES(26137,NULL,'Mascotte, FL',10525,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26138,NULL,'Mascotte, FL 34753',10525,222,NULL,11,15320,0);
INSERT INTO "django_geo_db_location" VALUES(26139,NULL,'Minneola, FL',10526,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26140,NULL,'Minneola, FL 34755',10526,222,NULL,11,15321,0);
INSERT INTO "django_geo_db_location" VALUES(26141,NULL,'Montverde, FL',10527,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26142,NULL,'Montverde, FL 34756',10527,222,NULL,11,15322,0);
INSERT INTO "django_geo_db_location" VALUES(26143,NULL,'Kissimmee, FL 34758',10523,222,NULL,11,15323,0);
INSERT INTO "django_geo_db_location" VALUES(26144,NULL,'Kissimmee, FL 34759',10523,222,NULL,11,15324,0);
INSERT INTO "django_geo_db_location" VALUES(26145,NULL,'Oakland, FL',10528,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26146,NULL,'Oakland, FL 34760',10528,222,NULL,11,15325,0);
INSERT INTO "django_geo_db_location" VALUES(26147,NULL,'Ocoee, FL',10529,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26148,NULL,'Ocoee, FL 34761',10529,222,NULL,11,15326,0);
INSERT INTO "django_geo_db_location" VALUES(26149,NULL,'Okahumpka, FL',10530,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26150,NULL,'Okahumpka, FL 34762',10530,222,NULL,11,15327,0);
INSERT INTO "django_geo_db_location" VALUES(26151,NULL,'Saint Cloud, FL',10531,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26152,NULL,'Saint Cloud, FL 34769',10531,222,NULL,11,15328,0);
INSERT INTO "django_geo_db_location" VALUES(26153,NULL,'Saint Cloud, FL 34770',10531,222,NULL,11,15329,0);
INSERT INTO "django_geo_db_location" VALUES(26154,NULL,'Saint Cloud, FL 34771',10531,222,NULL,11,15330,0);
INSERT INTO "django_geo_db_location" VALUES(26155,NULL,'Saint Cloud, FL 34772',10531,222,NULL,11,15331,0);
INSERT INTO "django_geo_db_location" VALUES(26156,NULL,'Saint Cloud, FL 34773',10531,222,NULL,11,15332,0);
INSERT INTO "django_geo_db_location" VALUES(26157,NULL,'Winter Garden, FL',10532,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26158,NULL,'Winter Garden, FL 34777',10532,222,NULL,11,15333,0);
INSERT INTO "django_geo_db_location" VALUES(26159,NULL,'Winter Garden, FL 34778',10532,222,NULL,11,15334,0);
INSERT INTO "django_geo_db_location" VALUES(26160,NULL,'Wildwood, FL',10533,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26161,NULL,'Wildwood, FL 34785',10533,222,NULL,11,15335,0);
INSERT INTO "django_geo_db_location" VALUES(26162,NULL,'Windermere, FL',10534,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26163,NULL,'Windermere, FL 34786',10534,222,NULL,11,15336,0);
INSERT INTO "django_geo_db_location" VALUES(26164,NULL,'Winter Garden, FL 34787',10532,222,NULL,11,15337,0);
INSERT INTO "django_geo_db_location" VALUES(26165,NULL,'Leesburg, FL 34788',10524,222,NULL,11,15338,0);
INSERT INTO "django_geo_db_location" VALUES(26166,NULL,'Leesburg, FL 34789',10524,222,NULL,11,15339,0);
INSERT INTO "django_geo_db_location" VALUES(26167,NULL,'Yalaha, FL',10535,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26168,NULL,'Yalaha, FL 34797',10535,222,NULL,11,15340,0);
INSERT INTO "django_geo_db_location" VALUES(26169,NULL,'Brooksville, FL 34801',10496,222,NULL,11,15341,0);
INSERT INTO "django_geo_db_location" VALUES(26170,NULL,'Hunters Creek, FL',10536,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26171,NULL,'Hunters Creek, FL 34837',10536,222,NULL,11,15342,0);
INSERT INTO "django_geo_db_location" VALUES(26172,NULL,'Tarpon Springs, FL 34869',10510,222,NULL,11,15343,0);
INSERT INTO "django_geo_db_location" VALUES(26173,NULL,'Lake Butter, FL',10537,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26174,NULL,'Lake Butter, FL 34876',10537,222,NULL,11,15344,0);
INSERT INTO "django_geo_db_location" VALUES(26175,NULL,'Okeechobee, FL',10538,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26176,NULL,'Okeechobee, FL 34924',10538,222,NULL,11,15345,0);
INSERT INTO "django_geo_db_location" VALUES(26177,NULL,'Fort Pierce, FL',10539,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26178,NULL,'Fort Pierce, FL 34945',10539,222,NULL,11,15346,0);
INSERT INTO "django_geo_db_location" VALUES(26179,NULL,'Fort Pierce, FL 34946',10539,222,NULL,11,15347,0);
INSERT INTO "django_geo_db_location" VALUES(26180,NULL,'Fort Pierce, FL 34947',10539,222,NULL,11,15348,0);
INSERT INTO "django_geo_db_location" VALUES(26181,NULL,'Fort Pierce, FL 34948',10539,222,NULL,11,15349,0);
INSERT INTO "django_geo_db_location" VALUES(26182,NULL,'Fort Pierce, FL 34949',10539,222,NULL,11,15350,0);
INSERT INTO "django_geo_db_location" VALUES(26183,NULL,'Fort Pierce, FL 34950',10539,222,NULL,11,15351,0);
INSERT INTO "django_geo_db_location" VALUES(26184,NULL,'Fort Pierce, FL 34951',10539,222,NULL,11,15352,0);
INSERT INTO "django_geo_db_location" VALUES(26185,NULL,'Port Saint Lucie, FL',10540,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26186,NULL,'Port Saint Lucie, FL 34952',10540,222,NULL,11,15353,0);
INSERT INTO "django_geo_db_location" VALUES(26187,NULL,'Port Saint Lucie, FL 34953',10540,222,NULL,11,15354,0);
INSERT INTO "django_geo_db_location" VALUES(26188,NULL,'Fort Pierce, FL 34954',10539,222,NULL,11,15355,0);
INSERT INTO "django_geo_db_location" VALUES(26189,NULL,'Indiantown, FL',10541,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26190,NULL,'Indiantown, FL 34956',10541,222,NULL,11,15356,0);
INSERT INTO "django_geo_db_location" VALUES(26191,NULL,'Jensen Beach, FL',10542,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26192,NULL,'Jensen Beach, FL 34957',10542,222,NULL,11,15357,0);
INSERT INTO "django_geo_db_location" VALUES(26193,NULL,'Jensen Beach, FL 34958',10542,222,NULL,11,15358,0);
INSERT INTO "django_geo_db_location" VALUES(26194,NULL,'Okeechobee, FL 34972',10538,222,NULL,11,15359,0);
INSERT INTO "django_geo_db_location" VALUES(26195,NULL,'Okeechobee, FL 34973',10538,222,NULL,11,15360,0);
INSERT INTO "django_geo_db_location" VALUES(26196,NULL,'Okeechobee, FL 34974',10538,222,NULL,11,15361,0);
INSERT INTO "django_geo_db_location" VALUES(26197,NULL,'Fort Pierce, FL 34979',10539,222,NULL,11,15362,0);
INSERT INTO "django_geo_db_location" VALUES(26198,NULL,'Fort Pierce, FL 34981',10539,222,NULL,11,15363,0);
INSERT INTO "django_geo_db_location" VALUES(26199,NULL,'Fort Pierce, FL 34982',10539,222,NULL,11,15364,0);
INSERT INTO "django_geo_db_location" VALUES(26200,NULL,'Port Saint Lucie, FL 34983',10540,222,NULL,11,15365,0);
INSERT INTO "django_geo_db_location" VALUES(26201,NULL,'Port Saint Lucie, FL 34984',10540,222,NULL,11,15366,0);
INSERT INTO "django_geo_db_location" VALUES(26202,NULL,'Port Saint Lucie, FL 34985',10540,222,NULL,11,15367,0);
INSERT INTO "django_geo_db_location" VALUES(26203,NULL,'Port Saint Lucie, FL 34986',10540,222,NULL,11,15368,0);
INSERT INTO "django_geo_db_location" VALUES(26204,NULL,'Port Saint Lucie, FL 34987',10540,222,NULL,11,15369,0);
INSERT INTO "django_geo_db_location" VALUES(26205,NULL,'Port Saint Lucie, FL 34988',10540,222,NULL,11,15370,0);
INSERT INTO "django_geo_db_location" VALUES(26206,NULL,'Palm City, FL',10543,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26207,NULL,'Palm City, FL 34990',10543,222,NULL,11,15371,0);
INSERT INTO "django_geo_db_location" VALUES(26208,NULL,'Palm City, FL 34991',10543,222,NULL,11,15372,0);
INSERT INTO "django_geo_db_location" VALUES(26209,NULL,'Port Salerno, FL',10544,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26210,NULL,'Port Salerno, FL 34992',10544,222,NULL,11,15373,0);
INSERT INTO "django_geo_db_location" VALUES(26211,NULL,'Stuart, FL',10545,222,NULL,11,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26212,NULL,'Stuart, FL 34994',10545,222,NULL,11,15374,0);
INSERT INTO "django_geo_db_location" VALUES(26213,NULL,'Stuart, FL 34995',10545,222,NULL,11,15375,0);
INSERT INTO "django_geo_db_location" VALUES(26214,NULL,'Stuart, FL 34996',10545,222,NULL,11,15376,0);
INSERT INTO "django_geo_db_location" VALUES(26215,NULL,'Stuart, FL 34997',10545,222,NULL,11,15377,0);
INSERT INTO "django_geo_db_location" VALUES(26216,NULL,'Moody, AL',10546,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26217,NULL,'Moody, AL 35004',10546,222,NULL,1,15378,0);
INSERT INTO "django_geo_db_location" VALUES(26218,NULL,'Adamsville, AL',10547,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26219,NULL,'Adamsville, AL 35005',10547,222,NULL,1,15379,0);
INSERT INTO "django_geo_db_location" VALUES(26220,NULL,'Adger, AL',10548,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26221,NULL,'Adger, AL 35006',10548,222,NULL,1,15380,0);
INSERT INTO "django_geo_db_location" VALUES(26222,NULL,'Alabaster, AL',10549,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26223,NULL,'Alabaster, AL 35007',10549,222,NULL,1,15381,0);
INSERT INTO "django_geo_db_location" VALUES(26224,NULL,'Alexander City, AL',10550,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26225,NULL,'Alexander City, AL 35010',10550,222,NULL,1,15382,0);
INSERT INTO "django_geo_db_location" VALUES(26226,NULL,'Alexander City, AL 35011',10550,222,NULL,1,15383,0);
INSERT INTO "django_geo_db_location" VALUES(26227,NULL,'Allgood, AL',10551,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26228,NULL,'Allgood, AL 35013',10551,222,NULL,1,15384,0);
INSERT INTO "django_geo_db_location" VALUES(26229,NULL,'Alpine, AL',10552,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26230,NULL,'Alpine, AL 35014',10552,222,NULL,1,15385,0);
INSERT INTO "django_geo_db_location" VALUES(26231,NULL,'Alton, AL',10553,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26232,NULL,'Alton, AL 35015',10553,222,NULL,1,15386,0);
INSERT INTO "django_geo_db_location" VALUES(26233,NULL,'Arab, AL',10554,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26234,NULL,'Arab, AL 35016',10554,222,NULL,1,15387,0);
INSERT INTO "django_geo_db_location" VALUES(26235,NULL,'Baileyton, AL',10555,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26236,NULL,'Baileyton, AL 35019',10555,222,NULL,1,15388,0);
INSERT INTO "django_geo_db_location" VALUES(26237,NULL,'Bessemer, AL',10556,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26238,NULL,'Bessemer, AL 35020',10556,222,NULL,1,15389,0);
INSERT INTO "django_geo_db_location" VALUES(26239,NULL,'Bessemer, AL 35021',10556,222,NULL,1,15390,0);
INSERT INTO "django_geo_db_location" VALUES(26240,NULL,'Bessemer, AL 35022',10556,222,NULL,1,15391,0);
INSERT INTO "django_geo_db_location" VALUES(26241,NULL,'Bessemer, AL 35023',10556,222,NULL,1,15392,0);
INSERT INTO "django_geo_db_location" VALUES(26242,NULL,'Clanton, AL',10557,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26243,NULL,'Clanton, AL 35026',10557,222,NULL,1,15393,0);
INSERT INTO "django_geo_db_location" VALUES(26244,NULL,'Blountsville, AL',10558,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26245,NULL,'Blountsville, AL 35031',10558,222,NULL,1,15394,0);
INSERT INTO "django_geo_db_location" VALUES(26246,NULL,'Bon Air, AL',10559,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26247,NULL,'Bon Air, AL 35032',10559,222,NULL,1,15395,0);
INSERT INTO "django_geo_db_location" VALUES(26248,NULL,'Bremen, AL',10560,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26249,NULL,'Bremen, AL 35033',10560,222,NULL,1,15396,0);
INSERT INTO "django_geo_db_location" VALUES(26250,NULL,'Brent, AL',10561,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26251,NULL,'Brent, AL 35034',10561,222,NULL,1,15397,0);
INSERT INTO "django_geo_db_location" VALUES(26252,NULL,'Brierfield, AL',10562,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26253,NULL,'Brierfield, AL 35035',10562,222,NULL,1,15398,0);
INSERT INTO "django_geo_db_location" VALUES(26254,NULL,'Brookside, AL',10563,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26255,NULL,'Brookside, AL 35036',10563,222,NULL,1,15399,0);
INSERT INTO "django_geo_db_location" VALUES(26256,NULL,'Burnwell, AL',10564,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26257,NULL,'Burnwell, AL 35038',10564,222,NULL,1,15400,0);
INSERT INTO "django_geo_db_location" VALUES(26258,NULL,'Brookside, AL 35039',10563,222,NULL,1,15401,0);
INSERT INTO "django_geo_db_location" VALUES(26259,NULL,'Calera, AL',10565,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26260,NULL,'Calera, AL 35040',10565,222,NULL,1,15402,0);
INSERT INTO "django_geo_db_location" VALUES(26261,NULL,'Cardiff, AL',10566,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26262,NULL,'Cardiff, AL 35041',10566,222,NULL,1,15403,0);
INSERT INTO "django_geo_db_location" VALUES(26263,NULL,'Centreville, AL',10567,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26264,NULL,'Centreville, AL 35042',10567,222,NULL,1,15404,0);
INSERT INTO "django_geo_db_location" VALUES(26265,NULL,'Chelsea, AL',10568,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26266,NULL,'Chelsea, AL 35043',10568,222,NULL,1,15405,0);
INSERT INTO "django_geo_db_location" VALUES(26267,NULL,'Childersburg, AL',10569,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26268,NULL,'Childersburg, AL 35044',10569,222,NULL,1,15406,0);
INSERT INTO "django_geo_db_location" VALUES(26269,NULL,'Clanton, AL 35045',10557,222,NULL,1,15407,0);
INSERT INTO "django_geo_db_location" VALUES(26270,NULL,'Clanton, AL 35046',10557,222,NULL,1,15408,0);
INSERT INTO "django_geo_db_location" VALUES(26271,NULL,'Clay, AL',10570,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26272,NULL,'Clay, AL 35048',10570,222,NULL,1,15409,0);
INSERT INTO "django_geo_db_location" VALUES(26273,NULL,'Cleveland, AL',10571,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26274,NULL,'Cleveland, AL 35049',10571,222,NULL,1,15410,0);
INSERT INTO "django_geo_db_location" VALUES(26275,NULL,'Columbiana, AL',10572,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26276,NULL,'Columbiana, AL 35050',10572,222,NULL,1,15411,0);
INSERT INTO "django_geo_db_location" VALUES(26277,NULL,'Columbiana, AL 35051',10572,222,NULL,1,15412,0);
INSERT INTO "django_geo_db_location" VALUES(26278,NULL,'Cook Springs, AL',10573,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26279,NULL,'Cook Springs, AL 35052',10573,222,NULL,1,15413,0);
INSERT INTO "django_geo_db_location" VALUES(26280,NULL,'Crane Hill, AL',10574,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26281,NULL,'Crane Hill, AL 35053',10574,222,NULL,1,15414,0);
INSERT INTO "django_geo_db_location" VALUES(26282,NULL,'Cropwell, AL',10575,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26283,NULL,'Cropwell, AL 35054',10575,222,NULL,1,15415,0);
INSERT INTO "django_geo_db_location" VALUES(26284,NULL,'Cullman, AL',10576,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26285,NULL,'Cullman, AL 35055',10576,222,NULL,1,15416,0);
INSERT INTO "django_geo_db_location" VALUES(26286,NULL,'Cullman, AL 35056',10576,222,NULL,1,15417,0);
INSERT INTO "django_geo_db_location" VALUES(26287,NULL,'Cullman, AL 35057',10576,222,NULL,1,15418,0);
INSERT INTO "django_geo_db_location" VALUES(26288,NULL,'Cullman, AL 35058',10576,222,NULL,1,15419,0);
INSERT INTO "django_geo_db_location" VALUES(26289,NULL,'Docena, AL',10577,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26290,NULL,'Docena, AL 35060',10577,222,NULL,1,15420,0);
INSERT INTO "django_geo_db_location" VALUES(26291,NULL,'Dolomite, AL',10578,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26292,NULL,'Dolomite, AL 35061',10578,222,NULL,1,15421,0);
INSERT INTO "django_geo_db_location" VALUES(26293,NULL,'Dora, AL',10579,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26294,NULL,'Dora, AL 35062',10579,222,NULL,1,15422,0);
INSERT INTO "django_geo_db_location" VALUES(26295,NULL,'Empire, AL',10580,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26296,NULL,'Empire, AL 35063',10580,222,NULL,1,15423,0);
INSERT INTO "django_geo_db_location" VALUES(26297,NULL,'Fairfield, AL',10581,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26298,NULL,'Fairfield, AL 35064',10581,222,NULL,1,15424,0);
INSERT INTO "django_geo_db_location" VALUES(26299,NULL,'Fultondale, AL',10582,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26300,NULL,'Fultondale, AL 35068',10582,222,NULL,1,15425,0);
INSERT INTO "django_geo_db_location" VALUES(26301,NULL,'Garden City, AL',10583,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26302,NULL,'Garden City, AL 35070',10583,222,NULL,1,15426,0);
INSERT INTO "django_geo_db_location" VALUES(26303,NULL,'Gardendale, AL',10584,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26304,NULL,'Gardendale, AL 35071',10584,222,NULL,1,15427,0);
INSERT INTO "django_geo_db_location" VALUES(26305,NULL,'Goodwater, AL',10585,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26306,NULL,'Goodwater, AL 35072',10585,222,NULL,1,15428,0);
INSERT INTO "django_geo_db_location" VALUES(26307,NULL,'Graysville, AL',10586,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26308,NULL,'Graysville, AL 35073',10586,222,NULL,1,15429,0);
INSERT INTO "django_geo_db_location" VALUES(26309,NULL,'Green Pond, AL',10587,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26310,NULL,'Green Pond, AL 35074',10587,222,NULL,1,15430,0);
INSERT INTO "django_geo_db_location" VALUES(26311,NULL,'Hanceville, AL',10588,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26312,NULL,'Hanceville, AL 35077',10588,222,NULL,1,15431,0);
INSERT INTO "django_geo_db_location" VALUES(26313,NULL,'Harpersville, AL',10589,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26314,NULL,'Harpersville, AL 35078',10589,222,NULL,1,15432,0);
INSERT INTO "django_geo_db_location" VALUES(26315,NULL,'Hayden, AL',10590,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26316,NULL,'Hayden, AL 35079',10590,222,NULL,1,15433,0);
INSERT INTO "django_geo_db_location" VALUES(26317,NULL,'Helena, AL',10591,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26318,NULL,'Helena, AL 35080',10591,222,NULL,1,15434,0);
INSERT INTO "django_geo_db_location" VALUES(26319,NULL,'Hollins, AL',10592,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26320,NULL,'Hollins, AL 35082',10592,222,NULL,1,15435,0);
INSERT INTO "django_geo_db_location" VALUES(26321,NULL,'Holly Pond, AL',10593,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26322,NULL,'Holly Pond, AL 35083',10593,222,NULL,1,15436,0);
INSERT INTO "django_geo_db_location" VALUES(26323,NULL,'Jemison, AL',10594,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26324,NULL,'Jemison, AL 35085',10594,222,NULL,1,15437,0);
INSERT INTO "django_geo_db_location" VALUES(26325,NULL,'Joppa, AL',10595,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26326,NULL,'Joppa, AL 35087',10595,222,NULL,1,15438,0);
INSERT INTO "django_geo_db_location" VALUES(26327,NULL,'Kellyton, AL',10596,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26328,NULL,'Kellyton, AL 35089',10596,222,NULL,1,15439,0);
INSERT INTO "django_geo_db_location" VALUES(26329,NULL,'Kimberly, AL',10597,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26330,NULL,'Kimberly, AL 35091',10597,222,NULL,1,15440,0);
INSERT INTO "django_geo_db_location" VALUES(26331,NULL,'Leeds, AL',10598,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26332,NULL,'Leeds, AL 35094',10598,222,NULL,1,15441,0);
INSERT INTO "django_geo_db_location" VALUES(26333,NULL,'Lincoln, AL',10599,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26334,NULL,'Lincoln, AL 35096',10599,222,NULL,1,15442,0);
INSERT INTO "django_geo_db_location" VALUES(26335,NULL,'Locust Fork, AL',10600,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26336,NULL,'Locust Fork, AL 35097',10600,222,NULL,1,15443,0);
INSERT INTO "django_geo_db_location" VALUES(26337,NULL,'Logan, AL',10601,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26338,NULL,'Logan, AL 35098',10601,222,NULL,1,15444,0);
INSERT INTO "django_geo_db_location" VALUES(26339,NULL,'McCalla, AL',10602,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26340,NULL,'McCalla, AL 35111',10602,222,NULL,1,15445,0);
INSERT INTO "django_geo_db_location" VALUES(26341,NULL,'Margaret, AL',10603,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26342,NULL,'Margaret, AL 35112',10603,222,NULL,1,15446,0);
INSERT INTO "django_geo_db_location" VALUES(26343,NULL,'Maylene, AL',10604,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26344,NULL,'Maylene, AL 35114',10604,222,NULL,1,15447,0);
INSERT INTO "django_geo_db_location" VALUES(26345,NULL,'Montevallo, AL',10605,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26346,NULL,'Montevallo, AL 35115',10605,222,NULL,1,15448,0);
INSERT INTO "django_geo_db_location" VALUES(26347,NULL,'Morris, AL',10606,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26348,NULL,'Morris, AL 35116',10606,222,NULL,1,15449,0);
INSERT INTO "django_geo_db_location" VALUES(26349,NULL,'Mount Olive, AL',10607,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26350,NULL,'Mount Olive, AL 35117',10607,222,NULL,1,15450,0);
INSERT INTO "django_geo_db_location" VALUES(26351,NULL,'Mulga, AL',10608,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26352,NULL,'Mulga, AL 35118',10608,222,NULL,1,15451,0);
INSERT INTO "django_geo_db_location" VALUES(26353,NULL,'New Castle, AL',10609,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26354,NULL,'New Castle, AL 35119',10609,222,NULL,1,15452,0);
INSERT INTO "django_geo_db_location" VALUES(26355,NULL,'Odenville, AL',10610,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26356,NULL,'Odenville, AL 35120',10610,222,NULL,1,15453,0);
INSERT INTO "django_geo_db_location" VALUES(26357,NULL,'Oneonta, AL',10611,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26358,NULL,'Oneonta, AL 35121',10611,222,NULL,1,15454,0);
INSERT INTO "django_geo_db_location" VALUES(26359,NULL,'Palmerdale, AL',10612,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26360,NULL,'Palmerdale, AL 35123',10612,222,NULL,1,15455,0);
INSERT INTO "django_geo_db_location" VALUES(26361,NULL,'Pelham, AL',10613,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26362,NULL,'Pelham, AL 35124',10613,222,NULL,1,15456,0);
INSERT INTO "django_geo_db_location" VALUES(26363,NULL,'Pell City, AL',10614,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26364,NULL,'Pell City, AL 35125',10614,222,NULL,1,15457,0);
INSERT INTO "django_geo_db_location" VALUES(26365,NULL,'Pinson, AL',10615,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26366,NULL,'Pinson, AL 35126',10615,222,NULL,1,15458,0);
INSERT INTO "django_geo_db_location" VALUES(26367,NULL,'Pleasant Grove, AL',10616,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26368,NULL,'Pleasant Grove, AL 35127',10616,222,NULL,1,15459,0);
INSERT INTO "django_geo_db_location" VALUES(26369,NULL,'Pell City, AL 35128',10614,222,NULL,1,15460,0);
INSERT INTO "django_geo_db_location" VALUES(26370,NULL,'Quinton, AL',10617,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26371,NULL,'Quinton, AL 35130',10617,222,NULL,1,15461,0);
INSERT INTO "django_geo_db_location" VALUES(26372,NULL,'Ragland, AL',10618,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26373,NULL,'Ragland, AL 35131',10618,222,NULL,1,15462,0);
INSERT INTO "django_geo_db_location" VALUES(26374,NULL,'Remlap, AL',10619,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26375,NULL,'Remlap, AL 35133',10619,222,NULL,1,15463,0);
INSERT INTO "django_geo_db_location" VALUES(26376,NULL,'Riverside, AL',10620,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26377,NULL,'Riverside, AL 35135',10620,222,NULL,1,15464,0);
INSERT INTO "django_geo_db_location" VALUES(26378,NULL,'Rockford, AL',10621,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26379,NULL,'Rockford, AL 35136',10621,222,NULL,1,15465,0);
INSERT INTO "django_geo_db_location" VALUES(26380,NULL,'Saginaw, AL',10622,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26381,NULL,'Saginaw, AL 35137',10622,222,NULL,1,15466,0);
INSERT INTO "django_geo_db_location" VALUES(26382,NULL,'Sayre, AL',10623,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26383,NULL,'Sayre, AL 35139',10623,222,NULL,1,15467,0);
INSERT INTO "django_geo_db_location" VALUES(26384,NULL,'Shannon, AL',10624,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26385,NULL,'Shannon, AL 35142',10624,222,NULL,1,15468,0);
INSERT INTO "django_geo_db_location" VALUES(26386,NULL,'Shelby, AL',10625,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26387,NULL,'Shelby, AL 35143',10625,222,NULL,1,15469,0);
INSERT INTO "django_geo_db_location" VALUES(26388,NULL,'Siluria, AL',10626,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26389,NULL,'Siluria, AL 35144',10626,222,NULL,1,15470,0);
INSERT INTO "django_geo_db_location" VALUES(26390,NULL,'Springville, AL',10627,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26391,NULL,'Springville, AL 35146',10627,222,NULL,1,15471,0);
INSERT INTO "django_geo_db_location" VALUES(26392,NULL,'Sterrett, AL',10628,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26393,NULL,'Sterrett, AL 35147',10628,222,NULL,1,15472,0);
INSERT INTO "django_geo_db_location" VALUES(26394,NULL,'Sumiton, AL',10629,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26395,NULL,'Sumiton, AL 35148',10629,222,NULL,1,15473,0);
INSERT INTO "django_geo_db_location" VALUES(26396,NULL,'Sycamore, AL',10630,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26397,NULL,'Sycamore, AL 35149',10630,222,NULL,1,15474,0);
INSERT INTO "django_geo_db_location" VALUES(26398,NULL,'Sylacauga, AL',10631,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26399,NULL,'Sylacauga, AL 35150',10631,222,NULL,1,15475,0);
INSERT INTO "django_geo_db_location" VALUES(26400,NULL,'Sylacauga, AL 35151',10631,222,NULL,1,15476,0);
INSERT INTO "django_geo_db_location" VALUES(26401,NULL,'Talladega, AL',10632,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26402,NULL,'Talladega, AL 35160',10632,222,NULL,1,15477,0);
INSERT INTO "django_geo_db_location" VALUES(26403,NULL,'Talladega, AL 35161',10632,222,NULL,1,15478,0);
INSERT INTO "django_geo_db_location" VALUES(26404,NULL,'Thorsby, AL',10633,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26405,NULL,'Thorsby, AL 35171',10633,222,NULL,1,15479,0);
INSERT INTO "django_geo_db_location" VALUES(26406,NULL,'Trafford, AL',10634,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26407,NULL,'Trafford, AL 35172',10634,222,NULL,1,15480,0);
INSERT INTO "django_geo_db_location" VALUES(26408,NULL,'Trussville, AL',10635,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26409,NULL,'Trussville, AL 35173',10635,222,NULL,1,15481,0);
INSERT INTO "django_geo_db_location" VALUES(26410,NULL,'Union Grove, AL',10636,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26411,NULL,'Union Grove, AL 35175',10636,222,NULL,1,15482,0);
INSERT INTO "django_geo_db_location" VALUES(26412,NULL,'Vandiver, AL',10637,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26413,NULL,'Vandiver, AL 35176',10637,222,NULL,1,15483,0);
INSERT INTO "django_geo_db_location" VALUES(26414,NULL,'Vincent, AL',10638,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26415,NULL,'Vincent, AL 35178',10638,222,NULL,1,15484,0);
INSERT INTO "django_geo_db_location" VALUES(26416,NULL,'Vinemont, AL',10639,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26417,NULL,'Vinemont, AL 35179',10639,222,NULL,1,15485,0);
INSERT INTO "django_geo_db_location" VALUES(26418,NULL,'Warrior, AL',10640,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26419,NULL,'Warrior, AL 35180',10640,222,NULL,1,15486,0);
INSERT INTO "django_geo_db_location" VALUES(26420,NULL,'Watson, AL',10641,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26421,NULL,'Watson, AL 35181',10641,222,NULL,1,15487,0);
INSERT INTO "django_geo_db_location" VALUES(26422,NULL,'Wattsville, AL',10642,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26423,NULL,'Wattsville, AL 35182',10642,222,NULL,1,15488,0);
INSERT INTO "django_geo_db_location" VALUES(26424,NULL,'Weogufka, AL',10643,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26425,NULL,'Weogufka, AL 35183',10643,222,NULL,1,15489,0);
INSERT INTO "django_geo_db_location" VALUES(26426,NULL,'West Blocton, AL',10644,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26427,NULL,'West Blocton, AL 35184',10644,222,NULL,1,15490,0);
INSERT INTO "django_geo_db_location" VALUES(26428,NULL,'Westover, AL',10645,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26429,NULL,'Westover, AL 35185',10645,222,NULL,1,15491,0);
INSERT INTO "django_geo_db_location" VALUES(26430,NULL,'Wilsonville, AL',10646,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26431,NULL,'Wilsonville, AL 35186',10646,222,NULL,1,15492,0);
INSERT INTO "django_geo_db_location" VALUES(26432,NULL,'Wilton, AL',10647,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26433,NULL,'Wilton, AL 35187',10647,222,NULL,1,15493,0);
INSERT INTO "django_geo_db_location" VALUES(26434,NULL,'Woodstock, AL',10648,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26435,NULL,'Woodstock, AL 35188',10648,222,NULL,1,15494,0);
INSERT INTO "django_geo_db_location" VALUES(26436,NULL,'Birmingham, AL',10649,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26437,NULL,'Birmingham, AL 35201',10649,222,NULL,1,15495,0);
INSERT INTO "django_geo_db_location" VALUES(26438,NULL,'Birmingham, AL 35202',10649,222,NULL,1,15496,0);
INSERT INTO "django_geo_db_location" VALUES(26439,NULL,'Birmingham, AL 35203',10649,222,NULL,1,15497,0);
INSERT INTO "django_geo_db_location" VALUES(26440,NULL,'Birmingham, AL 35204',10649,222,NULL,1,15498,0);
INSERT INTO "django_geo_db_location" VALUES(26441,NULL,'Birmingham, AL 35205',10649,222,NULL,1,15499,0);
INSERT INTO "django_geo_db_location" VALUES(26442,NULL,'Birmingham, AL 35206',10649,222,NULL,1,15500,0);
INSERT INTO "django_geo_db_location" VALUES(26443,NULL,'Birmingham, AL 35207',10649,222,NULL,1,15501,0);
INSERT INTO "django_geo_db_location" VALUES(26444,NULL,'Birmingham, AL 35208',10649,222,NULL,1,15502,0);
INSERT INTO "django_geo_db_location" VALUES(26445,NULL,'Birmingham, AL 35209',10649,222,NULL,1,15503,0);
INSERT INTO "django_geo_db_location" VALUES(26446,NULL,'Birmingham, AL 35210',10649,222,NULL,1,15504,0);
INSERT INTO "django_geo_db_location" VALUES(26447,NULL,'Birmingham, AL 35211',10649,222,NULL,1,15505,0);
INSERT INTO "django_geo_db_location" VALUES(26448,NULL,'Birmingham, AL 35212',10649,222,NULL,1,15506,0);
INSERT INTO "django_geo_db_location" VALUES(26449,NULL,'Birmingham, AL 35213',10649,222,NULL,1,15507,0);
INSERT INTO "django_geo_db_location" VALUES(26450,NULL,'Birmingham, AL 35214',10649,222,NULL,1,15508,0);
INSERT INTO "django_geo_db_location" VALUES(26451,NULL,'Birmingham, AL 35215',10649,222,NULL,1,15509,0);
INSERT INTO "django_geo_db_location" VALUES(26452,NULL,'Birmingham, AL 35216',10649,222,NULL,1,15510,0);
INSERT INTO "django_geo_db_location" VALUES(26453,NULL,'Birmingham, AL 35217',10649,222,NULL,1,15511,0);
INSERT INTO "django_geo_db_location" VALUES(26454,NULL,'Birmingham, AL 35218',10649,222,NULL,1,15512,0);
INSERT INTO "django_geo_db_location" VALUES(26455,NULL,'Birmingham, AL 35219',10649,222,NULL,1,15513,0);
INSERT INTO "django_geo_db_location" VALUES(26456,NULL,'Birmingham, AL 35220',10649,222,NULL,1,15514,0);
INSERT INTO "django_geo_db_location" VALUES(26457,NULL,'Birmingham, AL 35221',10649,222,NULL,1,15515,0);
INSERT INTO "django_geo_db_location" VALUES(26458,NULL,'Birmingham, AL 35222',10649,222,NULL,1,15516,0);
INSERT INTO "django_geo_db_location" VALUES(26459,NULL,'Birmingham, AL 35223',10649,222,NULL,1,15517,0);
INSERT INTO "django_geo_db_location" VALUES(26460,NULL,'Birmingham, AL 35224',10649,222,NULL,1,15518,0);
INSERT INTO "django_geo_db_location" VALUES(26461,NULL,'Birmingham, AL 35225',10649,222,NULL,1,15519,0);
INSERT INTO "django_geo_db_location" VALUES(26462,NULL,'Birmingham, AL 35226',10649,222,NULL,1,15520,0);
INSERT INTO "django_geo_db_location" VALUES(26463,NULL,'Birmingham, AL 35228',10649,222,NULL,1,15521,0);
INSERT INTO "django_geo_db_location" VALUES(26464,NULL,'Birmingham, AL 35229',10649,222,NULL,1,15522,0);
INSERT INTO "django_geo_db_location" VALUES(26465,NULL,'Birmingham, AL 35230',10649,222,NULL,1,15523,0);
INSERT INTO "django_geo_db_location" VALUES(26466,NULL,'Birmingham, AL 35231',10649,222,NULL,1,15524,0);
INSERT INTO "django_geo_db_location" VALUES(26467,NULL,'Birmingham, AL 35232',10649,222,NULL,1,15525,0);
INSERT INTO "django_geo_db_location" VALUES(26468,NULL,'Birmingham, AL 35233',10649,222,NULL,1,15526,0);
INSERT INTO "django_geo_db_location" VALUES(26469,NULL,'Birmingham, AL 35234',10649,222,NULL,1,15527,0);
INSERT INTO "django_geo_db_location" VALUES(26470,NULL,'Birmingham, AL 35235',10649,222,NULL,1,15528,0);
INSERT INTO "django_geo_db_location" VALUES(26471,NULL,'Birmingham, AL 35236',10649,222,NULL,1,15529,0);
INSERT INTO "django_geo_db_location" VALUES(26472,NULL,'Birmingham, AL 35237',10649,222,NULL,1,15530,0);
INSERT INTO "django_geo_db_location" VALUES(26473,NULL,'Birmingham, AL 35238',10649,222,NULL,1,15531,0);
INSERT INTO "django_geo_db_location" VALUES(26474,NULL,'Birmingham, AL 35240',10649,222,NULL,1,15532,0);
INSERT INTO "django_geo_db_location" VALUES(26475,NULL,'Birmingham, AL 35242',10649,222,NULL,1,15533,0);
INSERT INTO "django_geo_db_location" VALUES(26476,NULL,'Birmingham, AL 35243',10649,222,NULL,1,15534,0);
INSERT INTO "django_geo_db_location" VALUES(26477,NULL,'Birmingham, AL 35244',10649,222,NULL,1,15535,0);
INSERT INTO "django_geo_db_location" VALUES(26478,NULL,'Birmingham, AL 35245',10649,222,NULL,1,15536,0);
INSERT INTO "django_geo_db_location" VALUES(26479,NULL,'Birmingham, AL 35246',10649,222,NULL,1,15537,0);
INSERT INTO "django_geo_db_location" VALUES(26480,NULL,'Birmingham, AL 35249',10649,222,NULL,1,15538,0);
INSERT INTO "django_geo_db_location" VALUES(26481,NULL,'Birmingham, AL 35253',10649,222,NULL,1,15539,0);
INSERT INTO "django_geo_db_location" VALUES(26482,NULL,'Birmingham, AL 35254',10649,222,NULL,1,15540,0);
INSERT INTO "django_geo_db_location" VALUES(26483,NULL,'Birmingham, AL 35255',10649,222,NULL,1,15541,0);
INSERT INTO "django_geo_db_location" VALUES(26484,NULL,'Birmingham, AL 35259',10649,222,NULL,1,15542,0);
INSERT INTO "django_geo_db_location" VALUES(26485,NULL,'Birmingham, AL 35260',10649,222,NULL,1,15543,0);
INSERT INTO "django_geo_db_location" VALUES(26486,NULL,'Birmingham, AL 35261',10649,222,NULL,1,15544,0);
INSERT INTO "django_geo_db_location" VALUES(26487,NULL,'Birmingham, AL 35263',10649,222,NULL,1,15545,0);
INSERT INTO "django_geo_db_location" VALUES(26488,NULL,'Birmingham, AL 35266',10649,222,NULL,1,15546,0);
INSERT INTO "django_geo_db_location" VALUES(26489,NULL,'Birmingham, AL 35277',10649,222,NULL,1,15547,0);
INSERT INTO "django_geo_db_location" VALUES(26490,NULL,'Birmingham, AL 35278',10649,222,NULL,1,15548,0);
INSERT INTO "django_geo_db_location" VALUES(26491,NULL,'Birmingham, AL 35279',10649,222,NULL,1,15549,0);
INSERT INTO "django_geo_db_location" VALUES(26492,NULL,'Birmingham, AL 35280',10649,222,NULL,1,15550,0);
INSERT INTO "django_geo_db_location" VALUES(26493,NULL,'Birmingham, AL 35281',10649,222,NULL,1,15551,0);
INSERT INTO "django_geo_db_location" VALUES(26494,NULL,'Birmingham, AL 35282',10649,222,NULL,1,15552,0);
INSERT INTO "django_geo_db_location" VALUES(26495,NULL,'Birmingham, AL 35283',10649,222,NULL,1,15553,0);
INSERT INTO "django_geo_db_location" VALUES(26496,NULL,'Birmingham, AL 35285',10649,222,NULL,1,15554,0);
INSERT INTO "django_geo_db_location" VALUES(26497,NULL,'Birmingham, AL 35286',10649,222,NULL,1,15555,0);
INSERT INTO "django_geo_db_location" VALUES(26498,NULL,'Birmingham, AL 35287',10649,222,NULL,1,15556,0);
INSERT INTO "django_geo_db_location" VALUES(26499,NULL,'Birmingham, AL 35288',10649,222,NULL,1,15557,0);
INSERT INTO "django_geo_db_location" VALUES(26500,NULL,'Birmingham, AL 35289',10649,222,NULL,1,15558,0);
INSERT INTO "django_geo_db_location" VALUES(26501,NULL,'Birmingham, AL 35290',10649,222,NULL,1,15559,0);
INSERT INTO "django_geo_db_location" VALUES(26502,NULL,'Birmingham, AL 35291',10649,222,NULL,1,15560,0);
INSERT INTO "django_geo_db_location" VALUES(26503,NULL,'Birmingham, AL 35292',10649,222,NULL,1,15561,0);
INSERT INTO "django_geo_db_location" VALUES(26504,NULL,'Birmingham, AL 35293',10649,222,NULL,1,15562,0);
INSERT INTO "django_geo_db_location" VALUES(26505,NULL,'Birmingham, AL 35294',10649,222,NULL,1,15563,0);
INSERT INTO "django_geo_db_location" VALUES(26506,NULL,'Birmingham, AL 35295',10649,222,NULL,1,15564,0);
INSERT INTO "django_geo_db_location" VALUES(26507,NULL,'Birmingham, AL 35296',10649,222,NULL,1,15565,0);
INSERT INTO "django_geo_db_location" VALUES(26508,NULL,'Birmingham, AL 35297',10649,222,NULL,1,15566,0);
INSERT INTO "django_geo_db_location" VALUES(26509,NULL,'Birmingham, AL 35298',10649,222,NULL,1,15567,0);
INSERT INTO "django_geo_db_location" VALUES(26510,NULL,'Birmingham, AL 35299',10649,222,NULL,1,15568,0);
INSERT INTO "django_geo_db_location" VALUES(26511,NULL,'Dora, AL 35308',10579,222,NULL,1,15569,0);
INSERT INTO "django_geo_db_location" VALUES(26512,NULL,'Tuscaloosa, AL',10650,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26513,NULL,'Tuscaloosa, AL 35401',10650,222,NULL,1,15570,0);
INSERT INTO "django_geo_db_location" VALUES(26514,NULL,'Tuscaloosa, AL 35402',10650,222,NULL,1,15571,0);
INSERT INTO "django_geo_db_location" VALUES(26515,NULL,'Tuscaloosa, AL 35403',10650,222,NULL,1,15572,0);
INSERT INTO "django_geo_db_location" VALUES(26516,NULL,'Tuscaloosa, AL 35404',10650,222,NULL,1,15573,0);
INSERT INTO "django_geo_db_location" VALUES(26517,NULL,'Tuscaloosa, AL 35405',10650,222,NULL,1,15574,0);
INSERT INTO "django_geo_db_location" VALUES(26518,NULL,'Tuscaloosa, AL 35406',10650,222,NULL,1,15575,0);
INSERT INTO "django_geo_db_location" VALUES(26519,NULL,'Tuscaloosa, AL 35407',10650,222,NULL,1,15576,0);
INSERT INTO "django_geo_db_location" VALUES(26520,NULL,'Abernant, AL',10651,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26521,NULL,'Abernant, AL 35440',10651,222,NULL,1,15577,0);
INSERT INTO "django_geo_db_location" VALUES(26522,NULL,'Akron, AL',10652,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26523,NULL,'Akron, AL 35441',10652,222,NULL,1,15578,0);
INSERT INTO "django_geo_db_location" VALUES(26524,NULL,'Aliceville, AL',10653,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26525,NULL,'Aliceville, AL 35442',10653,222,NULL,1,15579,0);
INSERT INTO "django_geo_db_location" VALUES(26526,NULL,'Boligee, AL',10654,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26527,NULL,'Boligee, AL 35443',10654,222,NULL,1,15580,0);
INSERT INTO "django_geo_db_location" VALUES(26528,NULL,'Brookwood, AL',10655,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26529,NULL,'Brookwood, AL 35444',10655,222,NULL,1,15581,0);
INSERT INTO "django_geo_db_location" VALUES(26530,NULL,'Buhl, AL',10656,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26531,NULL,'Buhl, AL 35446',10656,222,NULL,1,15582,0);
INSERT INTO "django_geo_db_location" VALUES(26532,NULL,'Carrollton, AL',10657,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26533,NULL,'Carrollton, AL 35447',10657,222,NULL,1,15583,0);
INSERT INTO "django_geo_db_location" VALUES(26534,NULL,'Clinton, AL',10658,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26535,NULL,'Clinton, AL 35448',10658,222,NULL,1,15584,0);
INSERT INTO "django_geo_db_location" VALUES(26536,NULL,'Coaling, AL',10659,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26537,NULL,'Coaling, AL 35449',10659,222,NULL,1,15585,0);
INSERT INTO "django_geo_db_location" VALUES(26538,NULL,'Coker, AL',10660,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26539,NULL,'Coker, AL 35452',10660,222,NULL,1,15586,0);
INSERT INTO "django_geo_db_location" VALUES(26540,NULL,'Cottondale, AL',10661,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26541,NULL,'Cottondale, AL 35453',10661,222,NULL,1,15587,0);
INSERT INTO "django_geo_db_location" VALUES(26542,NULL,'Duncanville, AL',10662,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26543,NULL,'Duncanville, AL 35456',10662,222,NULL,1,15588,0);
INSERT INTO "django_geo_db_location" VALUES(26544,NULL,'Echola, AL',10663,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26545,NULL,'Echola, AL 35457',10663,222,NULL,1,15589,0);
INSERT INTO "django_geo_db_location" VALUES(26546,NULL,'Elrod, AL',10664,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26547,NULL,'Elrod, AL 35458',10664,222,NULL,1,15590,0);
INSERT INTO "django_geo_db_location" VALUES(26548,NULL,'Emelle, AL',10665,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26549,NULL,'Emelle, AL 35459',10665,222,NULL,1,15591,0);
INSERT INTO "django_geo_db_location" VALUES(26550,NULL,'Epes, AL',10666,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26551,NULL,'Epes, AL 35460',10666,222,NULL,1,15592,0);
INSERT INTO "django_geo_db_location" VALUES(26552,NULL,'Ethelsville, AL',10667,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26553,NULL,'Ethelsville, AL 35461',10667,222,NULL,1,15593,0);
INSERT INTO "django_geo_db_location" VALUES(26554,NULL,'Eutaw, AL',10668,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26555,NULL,'Eutaw, AL 35462',10668,222,NULL,1,15594,0);
INSERT INTO "django_geo_db_location" VALUES(26556,NULL,'Fosters, AL',10669,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26557,NULL,'Fosters, AL 35463',10669,222,NULL,1,15595,0);
INSERT INTO "django_geo_db_location" VALUES(26558,NULL,'Gainesville, AL',10670,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26559,NULL,'Gainesville, AL 35464',10670,222,NULL,1,15596,0);
INSERT INTO "django_geo_db_location" VALUES(26560,NULL,'Gordo, AL',10671,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26561,NULL,'Gordo, AL 35466',10671,222,NULL,1,15597,0);
INSERT INTO "django_geo_db_location" VALUES(26562,NULL,'Kellerman, AL',10672,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26563,NULL,'Kellerman, AL 35468',10672,222,NULL,1,15598,0);
INSERT INTO "django_geo_db_location" VALUES(26564,NULL,'Knoxville, AL',10673,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26565,NULL,'Knoxville, AL 35469',10673,222,NULL,1,15599,0);
INSERT INTO "django_geo_db_location" VALUES(26566,NULL,'Livingston, AL',10674,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26567,NULL,'Livingston, AL 35470',10674,222,NULL,1,15600,0);
INSERT INTO "django_geo_db_location" VALUES(26568,NULL,'McShan, AL',10675,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26569,NULL,'McShan, AL 35471',10675,222,NULL,1,15601,0);
INSERT INTO "django_geo_db_location" VALUES(26570,NULL,'Northport, AL',10676,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26571,NULL,'Northport, AL 35473',10676,222,NULL,1,15602,0);
INSERT INTO "django_geo_db_location" VALUES(26572,NULL,'Moundville, AL',10677,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26573,NULL,'Moundville, AL 35474',10677,222,NULL,1,15603,0);
INSERT INTO "django_geo_db_location" VALUES(26574,NULL,'Northport, AL 35475',10676,222,NULL,1,15604,0);
INSERT INTO "django_geo_db_location" VALUES(26575,NULL,'Northport, AL 35476',10676,222,NULL,1,15605,0);
INSERT INTO "django_geo_db_location" VALUES(26576,NULL,'Panola, AL',10678,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26577,NULL,'Panola, AL 35477',10678,222,NULL,1,15606,0);
INSERT INTO "django_geo_db_location" VALUES(26578,NULL,'Peterson, AL',10679,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26579,NULL,'Peterson, AL 35478',10679,222,NULL,1,15607,0);
INSERT INTO "django_geo_db_location" VALUES(26580,NULL,'Ralph, AL',10680,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26581,NULL,'Ralph, AL 35480',10680,222,NULL,1,15608,0);
INSERT INTO "django_geo_db_location" VALUES(26582,NULL,'Reform, AL',10681,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26583,NULL,'Reform, AL 35481',10681,222,NULL,1,15609,0);
INSERT INTO "django_geo_db_location" VALUES(26584,NULL,'Samantha, AL',10682,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26585,NULL,'Samantha, AL 35482',10682,222,NULL,1,15610,0);
INSERT INTO "django_geo_db_location" VALUES(26586,NULL,'Tuscaloosa, AL 35485',10650,222,NULL,1,15611,0);
INSERT INTO "django_geo_db_location" VALUES(26587,NULL,'Tuscaloosa, AL 35486',10650,222,NULL,1,15612,0);
INSERT INTO "django_geo_db_location" VALUES(26588,NULL,'Tuscaloosa, AL 35487',10650,222,NULL,1,15613,0);
INSERT INTO "django_geo_db_location" VALUES(26589,NULL,'Vance, AL',10683,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26590,NULL,'Vance, AL 35490',10683,222,NULL,1,15614,0);
INSERT INTO "django_geo_db_location" VALUES(26591,NULL,'West Greene, AL',10684,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26592,NULL,'West Greene, AL 35491',10684,222,NULL,1,15615,0);
INSERT INTO "django_geo_db_location" VALUES(26593,NULL,'Jasper, AL',10685,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26594,NULL,'Jasper, AL 35501',10685,222,NULL,1,15616,0);
INSERT INTO "django_geo_db_location" VALUES(26595,NULL,'Jasper, AL 35502',10685,222,NULL,1,15617,0);
INSERT INTO "django_geo_db_location" VALUES(26596,NULL,'Jasper, AL 35503',10685,222,NULL,1,15618,0);
INSERT INTO "django_geo_db_location" VALUES(26597,NULL,'Jasper, AL 35504',10685,222,NULL,1,15619,0);
INSERT INTO "django_geo_db_location" VALUES(26598,NULL,'Addison, AL',10686,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26599,NULL,'Addison, AL 35540',10686,222,NULL,1,15620,0);
INSERT INTO "django_geo_db_location" VALUES(26600,NULL,'Arley, AL',10687,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26601,NULL,'Arley, AL 35541',10687,222,NULL,1,15621,0);
INSERT INTO "django_geo_db_location" VALUES(26602,NULL,'Bankston, AL',10688,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26603,NULL,'Bankston, AL 35542',10688,222,NULL,1,15622,0);
INSERT INTO "django_geo_db_location" VALUES(26604,NULL,'Bear Creek, AL',10689,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26605,NULL,'Bear Creek, AL 35543',10689,222,NULL,1,15623,0);
INSERT INTO "django_geo_db_location" VALUES(26606,NULL,'Beaverton, AL',10690,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26607,NULL,'Beaverton, AL 35544',10690,222,NULL,1,15624,0);
INSERT INTO "django_geo_db_location" VALUES(26608,NULL,'Belk, AL',10691,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26609,NULL,'Belk, AL 35545',10691,222,NULL,1,15625,0);
INSERT INTO "django_geo_db_location" VALUES(26610,NULL,'Berry, AL',10692,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26611,NULL,'Berry, AL 35546',10692,222,NULL,1,15626,0);
INSERT INTO "django_geo_db_location" VALUES(26612,NULL,'Brilliant, AL',10693,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26613,NULL,'Brilliant, AL 35548',10693,222,NULL,1,15627,0);
INSERT INTO "django_geo_db_location" VALUES(26614,NULL,'Carbon Hill, AL',10694,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26615,NULL,'Carbon Hill, AL 35549',10694,222,NULL,1,15628,0);
INSERT INTO "django_geo_db_location" VALUES(26616,NULL,'Cordova, AL',10695,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26617,NULL,'Cordova, AL 35550',10695,222,NULL,1,15629,0);
INSERT INTO "django_geo_db_location" VALUES(26618,NULL,'Delmar, AL',10696,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26619,NULL,'Delmar, AL 35551',10696,222,NULL,1,15630,0);
INSERT INTO "django_geo_db_location" VALUES(26620,NULL,'Detroit, AL',10697,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26621,NULL,'Detroit, AL 35552',10697,222,NULL,1,15631,0);
INSERT INTO "django_geo_db_location" VALUES(26622,NULL,'Double Springs, AL',10698,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26623,NULL,'Double Springs, AL 35553',10698,222,NULL,1,15632,0);
INSERT INTO "django_geo_db_location" VALUES(26624,NULL,'Eldridge, AL',10699,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26625,NULL,'Eldridge, AL 35554',10699,222,NULL,1,15633,0);
INSERT INTO "django_geo_db_location" VALUES(26626,NULL,'Fayette, AL',10700,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26627,NULL,'Fayette, AL 35555',10700,222,NULL,1,15634,0);
INSERT INTO "django_geo_db_location" VALUES(26628,NULL,'Glen Allen, AL',10701,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26629,NULL,'Glen Allen, AL 35559',10701,222,NULL,1,15635,0);
INSERT INTO "django_geo_db_location" VALUES(26630,NULL,'Goodsprings, AL',10702,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26631,NULL,'Goodsprings, AL 35560',10702,222,NULL,1,15636,0);
INSERT INTO "django_geo_db_location" VALUES(26632,NULL,'Guin, AL',10703,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26633,NULL,'Guin, AL 35563',10703,222,NULL,1,15637,0);
INSERT INTO "django_geo_db_location" VALUES(26634,NULL,'Hackleburg, AL',10704,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26635,NULL,'Hackleburg, AL 35564',10704,222,NULL,1,15638,0);
INSERT INTO "django_geo_db_location" VALUES(26636,NULL,'Haleyville, AL',10705,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26637,NULL,'Haleyville, AL 35565',10705,222,NULL,1,15639,0);
INSERT INTO "django_geo_db_location" VALUES(26638,NULL,'Hamilton, AL',10706,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26639,NULL,'Hamilton, AL 35570',10706,222,NULL,1,15640,0);
INSERT INTO "django_geo_db_location" VALUES(26640,NULL,'Hodges, AL',10707,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26641,NULL,'Hodges, AL 35571',10707,222,NULL,1,15641,0);
INSERT INTO "django_geo_db_location" VALUES(26642,NULL,'Houston, AL',10708,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26643,NULL,'Houston, AL 35572',10708,222,NULL,1,15642,0);
INSERT INTO "django_geo_db_location" VALUES(26644,NULL,'Kansas, AL',10709,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26645,NULL,'Kansas, AL 35573',10709,222,NULL,1,15643,0);
INSERT INTO "django_geo_db_location" VALUES(26646,NULL,'Kennedy, AL',10710,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26647,NULL,'Kennedy, AL 35574',10710,222,NULL,1,15644,0);
INSERT INTO "django_geo_db_location" VALUES(26648,NULL,'Lynn, AL',10711,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26649,NULL,'Lynn, AL 35575',10711,222,NULL,1,15645,0);
INSERT INTO "django_geo_db_location" VALUES(26650,NULL,'Millport, AL',10712,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26651,NULL,'Millport, AL 35576',10712,222,NULL,1,15646,0);
INSERT INTO "django_geo_db_location" VALUES(26652,NULL,'Natural Bridge, AL',10713,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26653,NULL,'Natural Bridge, AL 35577',10713,222,NULL,1,15647,0);
INSERT INTO "django_geo_db_location" VALUES(26654,NULL,'Nauvoo, AL',10714,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26655,NULL,'Nauvoo, AL 35578',10714,222,NULL,1,15648,0);
INSERT INTO "django_geo_db_location" VALUES(26656,NULL,'Oakman, AL',10715,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26657,NULL,'Oakman, AL 35579',10715,222,NULL,1,15649,0);
INSERT INTO "django_geo_db_location" VALUES(26658,NULL,'Parrish, AL',10716,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26659,NULL,'Parrish, AL 35580',10716,222,NULL,1,15650,0);
INSERT INTO "django_geo_db_location" VALUES(26660,NULL,'Phil Campbell, AL',10717,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26661,NULL,'Phil Campbell, AL 35581',10717,222,NULL,1,15651,0);
INSERT INTO "django_geo_db_location" VALUES(26662,NULL,'Red Bay, AL',10718,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26663,NULL,'Red Bay, AL 35582',10718,222,NULL,1,15652,0);
INSERT INTO "django_geo_db_location" VALUES(26664,NULL,'Sipsey, AL',10719,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26665,NULL,'Sipsey, AL 35584',10719,222,NULL,1,15653,0);
INSERT INTO "django_geo_db_location" VALUES(26666,NULL,'Spruce Pine, AL',10720,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26667,NULL,'Spruce Pine, AL 35585',10720,222,NULL,1,15654,0);
INSERT INTO "django_geo_db_location" VALUES(26668,NULL,'Sulligent, AL',10721,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26669,NULL,'Sulligent, AL 35586',10721,222,NULL,1,15655,0);
INSERT INTO "django_geo_db_location" VALUES(26670,NULL,'Townley, AL',10722,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26671,NULL,'Townley, AL 35587',10722,222,NULL,1,15656,0);
INSERT INTO "django_geo_db_location" VALUES(26672,NULL,'Vernon, AL',10723,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26673,NULL,'Vernon, AL 35592',10723,222,NULL,1,15657,0);
INSERT INTO "django_geo_db_location" VALUES(26674,NULL,'Vina, AL',10724,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26675,NULL,'Vina, AL 35593',10724,222,NULL,1,15658,0);
INSERT INTO "django_geo_db_location" VALUES(26676,NULL,'Winfield, AL',10725,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26677,NULL,'Winfield, AL 35594',10725,222,NULL,1,15659,0);
INSERT INTO "django_geo_db_location" VALUES(26678,NULL,'Decatur, AL',10726,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26679,NULL,'Decatur, AL 35601',10726,222,NULL,1,15660,0);
INSERT INTO "django_geo_db_location" VALUES(26680,NULL,'Decatur, AL 35602',10726,222,NULL,1,15661,0);
INSERT INTO "django_geo_db_location" VALUES(26681,NULL,'Decatur, AL 35603',10726,222,NULL,1,15662,0);
INSERT INTO "django_geo_db_location" VALUES(26682,NULL,'Decatur, AL 35609',10726,222,NULL,1,15663,0);
INSERT INTO "django_geo_db_location" VALUES(26683,NULL,'Anderson, AL',10727,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26684,NULL,'Anderson, AL 35610',10727,222,NULL,1,15664,0);
INSERT INTO "django_geo_db_location" VALUES(26685,NULL,'Athens, AL',10728,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26686,NULL,'Athens, AL 35611',10728,222,NULL,1,15665,0);
INSERT INTO "django_geo_db_location" VALUES(26687,NULL,'Athens, AL 35612',10728,222,NULL,1,15666,0);
INSERT INTO "django_geo_db_location" VALUES(26688,NULL,'Athens, AL 35613',10728,222,NULL,1,15667,0);
INSERT INTO "django_geo_db_location" VALUES(26689,NULL,'Athens, AL 35614',10728,222,NULL,1,15668,0);
INSERT INTO "django_geo_db_location" VALUES(26690,NULL,'Belle Mina, AL',10729,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26691,NULL,'Belle Mina, AL 35615',10729,222,NULL,1,15669,0);
INSERT INTO "django_geo_db_location" VALUES(26692,NULL,'Cherokee, AL',10730,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26693,NULL,'Cherokee, AL 35616',10730,222,NULL,1,15670,0);
INSERT INTO "django_geo_db_location" VALUES(26694,NULL,'Cloverdale, AL',10731,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26695,NULL,'Cloverdale, AL 35617',10731,222,NULL,1,15671,0);
INSERT INTO "django_geo_db_location" VALUES(26696,NULL,'Courtland, AL',10732,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26697,NULL,'Courtland, AL 35618',10732,222,NULL,1,15672,0);
INSERT INTO "django_geo_db_location" VALUES(26698,NULL,'Danville, AL',10733,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26699,NULL,'Danville, AL 35619',10733,222,NULL,1,15673,0);
INSERT INTO "django_geo_db_location" VALUES(26700,NULL,'Elkmont, AL',10734,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26701,NULL,'Elkmont, AL 35620',10734,222,NULL,1,15674,0);
INSERT INTO "django_geo_db_location" VALUES(26702,NULL,'Eva, AL',10735,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26703,NULL,'Eva, AL 35621',10735,222,NULL,1,15675,0);
INSERT INTO "django_geo_db_location" VALUES(26704,NULL,'Falkville, AL',10736,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26705,NULL,'Falkville, AL 35622',10736,222,NULL,1,15676,0);
INSERT INTO "django_geo_db_location" VALUES(26706,NULL,'Florence, AL',10737,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26707,NULL,'Florence, AL 35630',10737,222,NULL,1,15677,0);
INSERT INTO "django_geo_db_location" VALUES(26708,NULL,'Florence, AL 35631',10737,222,NULL,1,15678,0);
INSERT INTO "django_geo_db_location" VALUES(26709,NULL,'Florence, AL 35632',10737,222,NULL,1,15679,0);
INSERT INTO "django_geo_db_location" VALUES(26710,NULL,'Florence, AL 35633',10737,222,NULL,1,15680,0);
INSERT INTO "django_geo_db_location" VALUES(26711,NULL,'Florence, AL 35634',10737,222,NULL,1,15681,0);
INSERT INTO "django_geo_db_location" VALUES(26712,NULL,'Hartselle, AL',10738,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26713,NULL,'Hartselle, AL 35640',10738,222,NULL,1,15682,0);
INSERT INTO "django_geo_db_location" VALUES(26714,NULL,'Hillsboro, AL',10739,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26715,NULL,'Hillsboro, AL 35643',10739,222,NULL,1,15683,0);
INSERT INTO "django_geo_db_location" VALUES(26716,NULL,'Killen, AL',10740,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26717,NULL,'Killen, AL 35645',10740,222,NULL,1,15684,0);
INSERT INTO "django_geo_db_location" VALUES(26718,NULL,'Leighton, AL',10741,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26719,NULL,'Leighton, AL 35646',10741,222,NULL,1,15685,0);
INSERT INTO "django_geo_db_location" VALUES(26720,NULL,'Lester, AL',10742,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26721,NULL,'Lester, AL 35647',10742,222,NULL,1,15686,0);
INSERT INTO "django_geo_db_location" VALUES(26722,NULL,'Lexington, AL',10743,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26723,NULL,'Lexington, AL 35648',10743,222,NULL,1,15687,0);
INSERT INTO "django_geo_db_location" VALUES(26724,NULL,'Mooresville, AL',10744,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26725,NULL,'Mooresville, AL 35649',10744,222,NULL,1,15688,0);
INSERT INTO "django_geo_db_location" VALUES(26726,NULL,'Moulton, AL',10745,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26727,NULL,'Moulton, AL 35650',10745,222,NULL,1,15689,0);
INSERT INTO "django_geo_db_location" VALUES(26728,NULL,'Mount Hope, AL',10746,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26729,NULL,'Mount Hope, AL 35651',10746,222,NULL,1,15690,0);
INSERT INTO "django_geo_db_location" VALUES(26730,NULL,'Rogersville, AL',10747,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26731,NULL,'Rogersville, AL 35652',10747,222,NULL,1,15691,0);
INSERT INTO "django_geo_db_location" VALUES(26732,NULL,'Russellville, AL',10748,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26733,NULL,'Russellville, AL 35653',10748,222,NULL,1,15692,0);
INSERT INTO "django_geo_db_location" VALUES(26734,NULL,'Russellville, AL 35654',10748,222,NULL,1,15693,0);
INSERT INTO "django_geo_db_location" VALUES(26735,NULL,'Russellville, AL 35659',10748,222,NULL,1,15694,0);
INSERT INTO "django_geo_db_location" VALUES(26736,NULL,'Sheffield, AL',10749,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26737,NULL,'Sheffield, AL 35660',10749,222,NULL,1,15695,0);
INSERT INTO "django_geo_db_location" VALUES(26738,NULL,'Muscle Shoals, AL',10750,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26739,NULL,'Muscle Shoals, AL 35661',10750,222,NULL,1,15696,0);
INSERT INTO "django_geo_db_location" VALUES(26740,NULL,'Muscle Shoals, AL 35662',10750,222,NULL,1,15697,0);
INSERT INTO "django_geo_db_location" VALUES(26741,NULL,'Somerville, AL',10751,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26742,NULL,'Somerville, AL 35670',10751,222,NULL,1,15698,0);
INSERT INTO "django_geo_db_location" VALUES(26743,NULL,'Tanner, AL',10752,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26744,NULL,'Tanner, AL 35671',10752,222,NULL,1,15699,0);
INSERT INTO "django_geo_db_location" VALUES(26745,NULL,'Town Creek, AL',10753,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26746,NULL,'Town Creek, AL 35672',10753,222,NULL,1,15700,0);
INSERT INTO "django_geo_db_location" VALUES(26747,NULL,'Trinity, AL',10754,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26748,NULL,'Trinity, AL 35673',10754,222,NULL,1,15701,0);
INSERT INTO "django_geo_db_location" VALUES(26749,NULL,'Tuscumbia, AL',10755,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26750,NULL,'Tuscumbia, AL 35674',10755,222,NULL,1,15702,0);
INSERT INTO "django_geo_db_location" VALUES(26751,NULL,'Waterloo, AL',10756,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26752,NULL,'Waterloo, AL 35677',10756,222,NULL,1,15703,0);
INSERT INTO "django_geo_db_location" VALUES(26753,NULL,'Decatur, AL 35699',10726,222,NULL,1,15704,0);
INSERT INTO "django_geo_db_location" VALUES(26754,NULL,'Cardiff, AL 35703',10566,222,NULL,1,15705,0);
INSERT INTO "django_geo_db_location" VALUES(26755,NULL,'Montevallo, AL 35715',10605,222,NULL,1,15706,0);
INSERT INTO "django_geo_db_location" VALUES(26756,NULL,'Ardmore, AL',10757,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26757,NULL,'Ardmore, AL 35739',10757,222,NULL,1,15707,0);
INSERT INTO "django_geo_db_location" VALUES(26758,NULL,'Bridgeport, AL',10758,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26759,NULL,'Bridgeport, AL 35740',10758,222,NULL,1,15708,0);
INSERT INTO "django_geo_db_location" VALUES(26760,NULL,'Brownsboro, AL',10759,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26761,NULL,'Brownsboro, AL 35741',10759,222,NULL,1,15709,0);
INSERT INTO "django_geo_db_location" VALUES(26762,NULL,'Capshaw, AL',10760,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26763,NULL,'Capshaw, AL 35742',10760,222,NULL,1,15710,0);
INSERT INTO "django_geo_db_location" VALUES(26764,NULL,'Dutton, AL',10761,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26765,NULL,'Dutton, AL 35744',10761,222,NULL,1,15711,0);
INSERT INTO "django_geo_db_location" VALUES(26766,NULL,'Estillfork, AL',10762,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26767,NULL,'Estillfork, AL 35745',10762,222,NULL,1,15712,0);
INSERT INTO "django_geo_db_location" VALUES(26768,NULL,'Fackler, AL',10763,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26769,NULL,'Fackler, AL 35746',10763,222,NULL,1,15713,0);
INSERT INTO "django_geo_db_location" VALUES(26770,NULL,'Grant, AL',10764,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26771,NULL,'Grant, AL 35747',10764,222,NULL,1,15714,0);
INSERT INTO "django_geo_db_location" VALUES(26772,NULL,'Gurley, AL',10765,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26773,NULL,'Gurley, AL 35748',10765,222,NULL,1,15715,0);
INSERT INTO "django_geo_db_location" VALUES(26774,NULL,'Harvest, AL',10766,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26775,NULL,'Harvest, AL 35749',10766,222,NULL,1,15716,0);
INSERT INTO "django_geo_db_location" VALUES(26776,NULL,'Hazel Green, AL',10767,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26777,NULL,'Hazel Green, AL 35750',10767,222,NULL,1,15717,0);
INSERT INTO "django_geo_db_location" VALUES(26778,NULL,'Hollytree, AL',10768,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26779,NULL,'Hollytree, AL 35751',10768,222,NULL,1,15718,0);
INSERT INTO "django_geo_db_location" VALUES(26780,NULL,'Hollywood, AL',10769,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26781,NULL,'Hollywood, AL 35752',10769,222,NULL,1,15719,0);
INSERT INTO "django_geo_db_location" VALUES(26782,NULL,'Laceys Spring, AL',10770,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26783,NULL,'Laceys Spring, AL 35754',10770,222,NULL,1,15720,0);
INSERT INTO "django_geo_db_location" VALUES(26784,NULL,'Langston, AL',10771,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26785,NULL,'Langston, AL 35755',10771,222,NULL,1,15721,0);
INSERT INTO "django_geo_db_location" VALUES(26786,NULL,'Madison, AL',10772,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26787,NULL,'Madison, AL 35756',10772,222,NULL,1,15722,0);
INSERT INTO "django_geo_db_location" VALUES(26788,NULL,'Madison, AL 35757',10772,222,NULL,1,15723,0);
INSERT INTO "django_geo_db_location" VALUES(26789,NULL,'Madison, AL 35758',10772,222,NULL,1,15724,0);
INSERT INTO "django_geo_db_location" VALUES(26790,NULL,'Meridianville, AL',10773,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26791,NULL,'Meridianville, AL 35759',10773,222,NULL,1,15725,0);
INSERT INTO "django_geo_db_location" VALUES(26792,NULL,'New Hope, AL',10774,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26793,NULL,'New Hope, AL 35760',10774,222,NULL,1,15726,0);
INSERT INTO "django_geo_db_location" VALUES(26794,NULL,'New Market, AL',10775,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26795,NULL,'New Market, AL 35761',10775,222,NULL,1,15727,0);
INSERT INTO "django_geo_db_location" VALUES(26796,NULL,'Normal, AL',10776,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26797,NULL,'Normal, AL 35762',10776,222,NULL,1,15728,0);
INSERT INTO "django_geo_db_location" VALUES(26798,NULL,'Owens Cross Roads, AL',10777,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26799,NULL,'Owens Cross Roads, AL 35763',10777,222,NULL,1,15729,0);
INSERT INTO "django_geo_db_location" VALUES(26800,NULL,'Paint Rock, AL',10778,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26801,NULL,'Paint Rock, AL 35764',10778,222,NULL,1,15730,0);
INSERT INTO "django_geo_db_location" VALUES(26802,NULL,'Pisgah, AL',10779,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26803,NULL,'Pisgah, AL 35765',10779,222,NULL,1,15731,0);
INSERT INTO "django_geo_db_location" VALUES(26804,NULL,'Princeton, AL',10780,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26805,NULL,'Princeton, AL 35766',10780,222,NULL,1,15732,0);
INSERT INTO "django_geo_db_location" VALUES(26806,NULL,'Ryland, AL',10781,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26807,NULL,'Ryland, AL 35767',10781,222,NULL,1,15733,0);
INSERT INTO "django_geo_db_location" VALUES(26808,NULL,'Scottsboro, AL',10782,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26809,NULL,'Scottsboro, AL 35768',10782,222,NULL,1,15734,0);
INSERT INTO "django_geo_db_location" VALUES(26810,NULL,'Scottsboro, AL 35769',10782,222,NULL,1,15735,0);
INSERT INTO "django_geo_db_location" VALUES(26811,NULL,'Section, AL',10783,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26812,NULL,'Section, AL 35771',10783,222,NULL,1,15736,0);
INSERT INTO "django_geo_db_location" VALUES(26813,NULL,'Stevenson, AL',10784,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26814,NULL,'Stevenson, AL 35772',10784,222,NULL,1,15737,0);
INSERT INTO "django_geo_db_location" VALUES(26815,NULL,'Toney, AL',10785,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26816,NULL,'Toney, AL 35773',10785,222,NULL,1,15738,0);
INSERT INTO "django_geo_db_location" VALUES(26817,NULL,'Trenton, AL',10786,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26818,NULL,'Trenton, AL 35774',10786,222,NULL,1,15739,0);
INSERT INTO "django_geo_db_location" VALUES(26819,NULL,'Valhermoso Springs, AL',10787,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26820,NULL,'Valhermoso Springs, AL 35775',10787,222,NULL,1,15740,0);
INSERT INTO "django_geo_db_location" VALUES(26821,NULL,'Woodville, AL',10788,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26822,NULL,'Woodville, AL 35776',10788,222,NULL,1,15741,0);
INSERT INTO "django_geo_db_location" VALUES(26823,NULL,'Huntsville, AL',10789,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26824,NULL,'Huntsville, AL 35801',10789,222,NULL,1,15742,0);
INSERT INTO "django_geo_db_location" VALUES(26825,NULL,'Huntsville, AL 35802',10789,222,NULL,1,15743,0);
INSERT INTO "django_geo_db_location" VALUES(26826,NULL,'Huntsville, AL 35803',10789,222,NULL,1,15744,0);
INSERT INTO "django_geo_db_location" VALUES(26827,NULL,'Huntsville, AL 35804',10789,222,NULL,1,15745,0);
INSERT INTO "django_geo_db_location" VALUES(26828,NULL,'Huntsville, AL 35805',10789,222,NULL,1,15746,0);
INSERT INTO "django_geo_db_location" VALUES(26829,NULL,'Huntsville, AL 35806',10789,222,NULL,1,15747,0);
INSERT INTO "django_geo_db_location" VALUES(26830,NULL,'Huntsville, AL 35807',10789,222,NULL,1,15748,0);
INSERT INTO "django_geo_db_location" VALUES(26831,NULL,'Huntsville, AL 35808',10789,222,NULL,1,15749,0);
INSERT INTO "django_geo_db_location" VALUES(26832,NULL,'Huntsville, AL 35809',10789,222,NULL,1,15750,0);
INSERT INTO "django_geo_db_location" VALUES(26833,NULL,'Huntsville, AL 35810',10789,222,NULL,1,15751,0);
INSERT INTO "django_geo_db_location" VALUES(26834,NULL,'Huntsville, AL 35811',10789,222,NULL,1,15752,0);
INSERT INTO "django_geo_db_location" VALUES(26835,NULL,'Huntsville, AL 35812',10789,222,NULL,1,15753,0);
INSERT INTO "django_geo_db_location" VALUES(26836,NULL,'Huntsville, AL 35813',10789,222,NULL,1,15754,0);
INSERT INTO "django_geo_db_location" VALUES(26837,NULL,'Huntsville, AL 35814',10789,222,NULL,1,15755,0);
INSERT INTO "django_geo_db_location" VALUES(26838,NULL,'Huntsville, AL 35815',10789,222,NULL,1,15756,0);
INSERT INTO "django_geo_db_location" VALUES(26839,NULL,'Huntsville, AL 35816',10789,222,NULL,1,15757,0);
INSERT INTO "django_geo_db_location" VALUES(26840,NULL,'Huntsville, AL 35824',10789,222,NULL,1,15758,0);
INSERT INTO "django_geo_db_location" VALUES(26841,NULL,'Huntsville, AL 35893',10789,222,NULL,1,15759,0);
INSERT INTO "django_geo_db_location" VALUES(26842,NULL,'Huntsville, AL 35894',10789,222,NULL,1,15760,0);
INSERT INTO "django_geo_db_location" VALUES(26843,NULL,'Huntsville, AL 35895',10789,222,NULL,1,15761,0);
INSERT INTO "django_geo_db_location" VALUES(26844,NULL,'Huntsville, AL 35896',10789,222,NULL,1,15762,0);
INSERT INTO "django_geo_db_location" VALUES(26845,NULL,'Huntsville, AL 35897',10789,222,NULL,1,15763,0);
INSERT INTO "django_geo_db_location" VALUES(26846,NULL,'Huntsville, AL 35898',10789,222,NULL,1,15764,0);
INSERT INTO "django_geo_db_location" VALUES(26847,NULL,'Huntsville, AL 35899',10789,222,NULL,1,15765,0);
INSERT INTO "django_geo_db_location" VALUES(26848,NULL,'Gadsden, AL',10790,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26849,NULL,'Gadsden, AL 35901',10790,222,NULL,1,15766,0);
INSERT INTO "django_geo_db_location" VALUES(26850,NULL,'Gadsden, AL 35902',10790,222,NULL,1,15767,0);
INSERT INTO "django_geo_db_location" VALUES(26851,NULL,'Gadsden, AL 35903',10790,222,NULL,1,15768,0);
INSERT INTO "django_geo_db_location" VALUES(26852,NULL,'Gadsden, AL 35904',10790,222,NULL,1,15769,0);
INSERT INTO "django_geo_db_location" VALUES(26853,NULL,'Gadsden, AL 35905',10790,222,NULL,1,15770,0);
INSERT INTO "django_geo_db_location" VALUES(26854,NULL,'Rainbow City, AL',10791,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26855,NULL,'Rainbow City, AL 35906',10791,222,NULL,1,15771,0);
INSERT INTO "django_geo_db_location" VALUES(26856,NULL,'Gadsden, AL 35907',10790,222,NULL,1,15772,0);
INSERT INTO "django_geo_db_location" VALUES(26857,NULL,'Albertville, AL',10792,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26858,NULL,'Albertville, AL 35950',10792,222,NULL,1,15773,0);
INSERT INTO "django_geo_db_location" VALUES(26859,NULL,'Albertville, AL 35951',10792,222,NULL,1,15774,0);
INSERT INTO "django_geo_db_location" VALUES(26860,NULL,'Altoona, AL',10793,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26861,NULL,'Altoona, AL 35952',10793,222,NULL,1,15775,0);
INSERT INTO "django_geo_db_location" VALUES(26862,NULL,'Ashville, AL',10794,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26863,NULL,'Ashville, AL 35953',10794,222,NULL,1,15776,0);
INSERT INTO "django_geo_db_location" VALUES(26864,NULL,'Attalla, AL',10795,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26865,NULL,'Attalla, AL 35954',10795,222,NULL,1,15777,0);
INSERT INTO "django_geo_db_location" VALUES(26866,NULL,'Boaz, AL',10796,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26867,NULL,'Boaz, AL 35956',10796,222,NULL,1,15778,0);
INSERT INTO "django_geo_db_location" VALUES(26868,NULL,'Boaz, AL 35957',10796,222,NULL,1,15779,0);
INSERT INTO "django_geo_db_location" VALUES(26869,NULL,'Bryant, AL',10797,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26870,NULL,'Bryant, AL 35958',10797,222,NULL,1,15780,0);
INSERT INTO "django_geo_db_location" VALUES(26871,NULL,'Cedar Bluff, AL',10798,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26872,NULL,'Cedar Bluff, AL 35959',10798,222,NULL,1,15781,0);
INSERT INTO "django_geo_db_location" VALUES(26873,NULL,'Centre, AL',10799,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26874,NULL,'Centre, AL 35960',10799,222,NULL,1,15782,0);
INSERT INTO "django_geo_db_location" VALUES(26875,NULL,'Collinsville, AL',10800,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26876,NULL,'Collinsville, AL 35961',10800,222,NULL,1,15783,0);
INSERT INTO "django_geo_db_location" VALUES(26877,NULL,'Crossville, AL',10801,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26878,NULL,'Crossville, AL 35962',10801,222,NULL,1,15784,0);
INSERT INTO "django_geo_db_location" VALUES(26879,NULL,'Dawson, AL',10802,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26880,NULL,'Dawson, AL 35963',10802,222,NULL,1,15785,0);
INSERT INTO "django_geo_db_location" VALUES(26881,NULL,'Douglas, AL',10803,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26882,NULL,'Douglas, AL 35964',10803,222,NULL,1,15786,0);
INSERT INTO "django_geo_db_location" VALUES(26883,NULL,'Flat Rock, AL',10804,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26884,NULL,'Flat Rock, AL 35966',10804,222,NULL,1,15787,0);
INSERT INTO "django_geo_db_location" VALUES(26885,NULL,'Fort Payne, AL',10805,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26886,NULL,'Fort Payne, AL 35967',10805,222,NULL,1,15788,0);
INSERT INTO "django_geo_db_location" VALUES(26887,NULL,'Fort Payne, AL 35968',10805,222,NULL,1,15789,0);
INSERT INTO "django_geo_db_location" VALUES(26888,NULL,'Fort Payne, AL 35969',10805,222,NULL,1,15790,0);
INSERT INTO "django_geo_db_location" VALUES(26889,NULL,'Fyffe, AL',10806,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26890,NULL,'Fyffe, AL 35971',10806,222,NULL,1,15791,0);
INSERT INTO "django_geo_db_location" VALUES(26891,NULL,'Gallant, AL',10807,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26892,NULL,'Gallant, AL 35972',10807,222,NULL,1,15792,0);
INSERT INTO "django_geo_db_location" VALUES(26893,NULL,'Gaylesville, AL',10808,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26894,NULL,'Gaylesville, AL 35973',10808,222,NULL,1,15793,0);
INSERT INTO "django_geo_db_location" VALUES(26895,NULL,'Geraldine, AL',10809,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26896,NULL,'Geraldine, AL 35974',10809,222,NULL,1,15794,0);
INSERT INTO "django_geo_db_location" VALUES(26897,NULL,'Groveoak, AL',10810,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26898,NULL,'Groveoak, AL 35975',10810,222,NULL,1,15795,0);
INSERT INTO "django_geo_db_location" VALUES(26899,NULL,'Guntersville, AL',10811,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26900,NULL,'Guntersville, AL 35976',10811,222,NULL,1,15796,0);
INSERT INTO "django_geo_db_location" VALUES(26901,NULL,'Henagar, AL',10812,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26902,NULL,'Henagar, AL 35978',10812,222,NULL,1,15797,0);
INSERT INTO "django_geo_db_location" VALUES(26903,NULL,'Higdon, AL',10813,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26904,NULL,'Higdon, AL 35979',10813,222,NULL,1,15798,0);
INSERT INTO "django_geo_db_location" VALUES(26905,NULL,'Horton, AL',10814,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26906,NULL,'Horton, AL 35980',10814,222,NULL,1,15799,0);
INSERT INTO "django_geo_db_location" VALUES(26907,NULL,'Ider, AL',10815,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26908,NULL,'Ider, AL 35981',10815,222,NULL,1,15800,0);
INSERT INTO "django_geo_db_location" VALUES(26909,NULL,'Leesburg, AL',10816,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26910,NULL,'Leesburg, AL 35983',10816,222,NULL,1,15801,0);
INSERT INTO "django_geo_db_location" VALUES(26911,NULL,'Mentone, AL',10817,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26912,NULL,'Mentone, AL 35984',10817,222,NULL,1,15802,0);
INSERT INTO "django_geo_db_location" VALUES(26913,NULL,'Rainsville, AL',10818,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26914,NULL,'Rainsville, AL 35986',10818,222,NULL,1,15803,0);
INSERT INTO "django_geo_db_location" VALUES(26915,NULL,'Steele, AL',10819,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26916,NULL,'Steele, AL 35987',10819,222,NULL,1,15804,0);
INSERT INTO "django_geo_db_location" VALUES(26917,NULL,'Sylvania, AL',10820,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26918,NULL,'Sylvania, AL 35988',10820,222,NULL,1,15805,0);
INSERT INTO "django_geo_db_location" VALUES(26919,NULL,'Valley Head, AL',10821,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26920,NULL,'Valley Head, AL 35989',10821,222,NULL,1,15806,0);
INSERT INTO "django_geo_db_location" VALUES(26921,NULL,'Walnut Grove, AL',10822,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26922,NULL,'Walnut Grove, AL 35990',10822,222,NULL,1,15807,0);
INSERT INTO "django_geo_db_location" VALUES(26923,NULL,'Autaugaville, AL',10823,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26924,NULL,'Autaugaville, AL 36003',10823,222,NULL,1,15808,0);
INSERT INTO "django_geo_db_location" VALUES(26925,NULL,'Banks, AL',10824,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26926,NULL,'Banks, AL 36005',10824,222,NULL,1,15809,0);
INSERT INTO "django_geo_db_location" VALUES(26927,NULL,'Billingsley, AL',10825,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26928,NULL,'Billingsley, AL 36006',10825,222,NULL,1,15810,0);
INSERT INTO "django_geo_db_location" VALUES(26929,NULL,'Booth, AL',10826,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26930,NULL,'Booth, AL 36008',10826,222,NULL,1,15811,0);
INSERT INTO "django_geo_db_location" VALUES(26931,NULL,'Brantley, AL',10827,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26932,NULL,'Brantley, AL 36009',10827,222,NULL,1,15812,0);
INSERT INTO "django_geo_db_location" VALUES(26933,NULL,'Brundidge, AL',10828,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26934,NULL,'Brundidge, AL 36010',10828,222,NULL,1,15813,0);
INSERT INTO "django_geo_db_location" VALUES(26935,NULL,'Cecil, AL',10829,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26936,NULL,'Cecil, AL 36013',10829,222,NULL,1,15814,0);
INSERT INTO "django_geo_db_location" VALUES(26937,NULL,'Chapman, AL',10830,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26938,NULL,'Chapman, AL 36015',10830,222,NULL,1,15815,0);
INSERT INTO "django_geo_db_location" VALUES(26939,NULL,'Clayton, AL',10831,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26940,NULL,'Clayton, AL 36016',10831,222,NULL,1,15816,0);
INSERT INTO "django_geo_db_location" VALUES(26941,NULL,'Clio, AL',10832,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26942,NULL,'Clio, AL 36017',10832,222,NULL,1,15817,0);
INSERT INTO "django_geo_db_location" VALUES(26943,NULL,'Coosada, AL',10833,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26944,NULL,'Coosada, AL 36020',10833,222,NULL,1,15818,0);
INSERT INTO "django_geo_db_location" VALUES(26945,NULL,'Deatsville, AL',10834,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26946,NULL,'Deatsville, AL 36022',10834,222,NULL,1,15819,0);
INSERT INTO "django_geo_db_location" VALUES(26947,NULL,'East Tallassee, AL',10835,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26948,NULL,'East Tallassee, AL 36023',10835,222,NULL,1,15820,0);
INSERT INTO "django_geo_db_location" VALUES(26949,NULL,'Eclectic, AL',10836,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26950,NULL,'Eclectic, AL 36024',10836,222,NULL,1,15821,0);
INSERT INTO "django_geo_db_location" VALUES(26951,NULL,'Elmore, AL',10837,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26952,NULL,'Elmore, AL 36025',10837,222,NULL,1,15822,0);
INSERT INTO "django_geo_db_location" VALUES(26953,NULL,'Equality, AL',10838,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26954,NULL,'Equality, AL 36026',10838,222,NULL,1,15823,0);
INSERT INTO "django_geo_db_location" VALUES(26955,NULL,'Eufaula, AL',10839,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26956,NULL,'Eufaula, AL 36027',10839,222,NULL,1,15824,0);
INSERT INTO "django_geo_db_location" VALUES(26957,NULL,'Dozier, AL',10840,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26958,NULL,'Dozier, AL 36028',10840,222,NULL,1,15825,0);
INSERT INTO "django_geo_db_location" VALUES(26959,NULL,'Fitzpatrick, AL',10841,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26960,NULL,'Fitzpatrick, AL 36029',10841,222,NULL,1,15826,0);
INSERT INTO "django_geo_db_location" VALUES(26961,NULL,'Forest Home, AL',10842,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26962,NULL,'Forest Home, AL 36030',10842,222,NULL,1,15827,0);
INSERT INTO "django_geo_db_location" VALUES(26963,NULL,'Fort Davis, AL',10843,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26964,NULL,'Fort Davis, AL 36031',10843,222,NULL,1,15828,0);
INSERT INTO "django_geo_db_location" VALUES(26965,NULL,'Fort Deposit, AL',10844,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26966,NULL,'Fort Deposit, AL 36032',10844,222,NULL,1,15829,0);
INSERT INTO "django_geo_db_location" VALUES(26967,NULL,'Georgiana, AL',10845,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26968,NULL,'Georgiana, AL 36033',10845,222,NULL,1,15830,0);
INSERT INTO "django_geo_db_location" VALUES(26969,NULL,'Glenwood, AL',10846,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26970,NULL,'Glenwood, AL 36034',10846,222,NULL,1,15831,0);
INSERT INTO "django_geo_db_location" VALUES(26971,NULL,'Goshen, AL',10847,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26972,NULL,'Goshen, AL 36035',10847,222,NULL,1,15832,0);
INSERT INTO "django_geo_db_location" VALUES(26973,NULL,'Grady, AL',10848,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26974,NULL,'Grady, AL 36036',10848,222,NULL,1,15833,0);
INSERT INTO "django_geo_db_location" VALUES(26975,NULL,'Greenville, AL',10849,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26976,NULL,'Greenville, AL 36037',10849,222,NULL,1,15834,0);
INSERT INTO "django_geo_db_location" VALUES(26977,NULL,'Gantt, AL',10850,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26978,NULL,'Gantt, AL 36038',10850,222,NULL,1,15835,0);
INSERT INTO "django_geo_db_location" VALUES(26979,NULL,'Hardaway, AL',10851,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26980,NULL,'Hardaway, AL 36039',10851,222,NULL,1,15836,0);
INSERT INTO "django_geo_db_location" VALUES(26981,NULL,'Hayneville, AL',10852,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26982,NULL,'Hayneville, AL 36040',10852,222,NULL,1,15837,0);
INSERT INTO "django_geo_db_location" VALUES(26983,NULL,'Highland Home, AL',10853,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26984,NULL,'Highland Home, AL 36041',10853,222,NULL,1,15838,0);
INSERT INTO "django_geo_db_location" VALUES(26985,NULL,'Honoraville, AL',10854,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26986,NULL,'Honoraville, AL 36042',10854,222,NULL,1,15839,0);
INSERT INTO "django_geo_db_location" VALUES(26987,NULL,'Hope Hull, AL',10855,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26988,NULL,'Hope Hull, AL 36043',10855,222,NULL,1,15840,0);
INSERT INTO "django_geo_db_location" VALUES(26989,NULL,'Kent, AL',10856,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26990,NULL,'Kent, AL 36045',10856,222,NULL,1,15841,0);
INSERT INTO "django_geo_db_location" VALUES(26991,NULL,'Lapine, AL',10857,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26992,NULL,'Lapine, AL 36046',10857,222,NULL,1,15842,0);
INSERT INTO "django_geo_db_location" VALUES(26993,NULL,'Letohatchee, AL',10858,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26994,NULL,'Letohatchee, AL 36047',10858,222,NULL,1,15843,0);
INSERT INTO "django_geo_db_location" VALUES(26995,NULL,'Louisville, AL',10859,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26996,NULL,'Louisville, AL 36048',10859,222,NULL,1,15844,0);
INSERT INTO "django_geo_db_location" VALUES(26997,NULL,'Luverne, AL',10860,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(26998,NULL,'Luverne, AL 36049',10860,222,NULL,1,15845,0);
INSERT INTO "django_geo_db_location" VALUES(26999,NULL,'Marbury, AL',10861,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27000,NULL,'Marbury, AL 36051',10861,222,NULL,1,15846,0);
INSERT INTO "django_geo_db_location" VALUES(27001,NULL,'Mathews, AL',10862,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27002,NULL,'Mathews, AL 36052',10862,222,NULL,1,15847,0);
INSERT INTO "django_geo_db_location" VALUES(27003,NULL,'Midway, AL',10863,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27004,NULL,'Midway, AL 36053',10863,222,NULL,1,15848,0);
INSERT INTO "django_geo_db_location" VALUES(27005,NULL,'Millbrook, AL',10864,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27006,NULL,'Millbrook, AL 36054',10864,222,NULL,1,15849,0);
INSERT INTO "django_geo_db_location" VALUES(27007,NULL,'Mount Meigs, AL',10865,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27008,NULL,'Mount Meigs, AL 36057',10865,222,NULL,1,15850,0);
INSERT INTO "django_geo_db_location" VALUES(27009,NULL,'Perote, AL',10866,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27010,NULL,'Perote, AL 36061',10866,222,NULL,1,15851,0);
INSERT INTO "django_geo_db_location" VALUES(27011,NULL,'Petrey, AL',10867,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27012,NULL,'Petrey, AL 36062',10867,222,NULL,1,15852,0);
INSERT INTO "django_geo_db_location" VALUES(27013,NULL,'Pike Road, AL',10868,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27014,NULL,'Pike Road, AL 36064',10868,222,NULL,1,15853,0);
INSERT INTO "django_geo_db_location" VALUES(27015,NULL,'Pine Level, AL',10869,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27016,NULL,'Pine Level, AL 36065',10869,222,NULL,1,15854,0);
INSERT INTO "django_geo_db_location" VALUES(27017,NULL,'Prattville, AL',10870,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27018,NULL,'Prattville, AL 36066',10870,222,NULL,1,15855,0);
INSERT INTO "django_geo_db_location" VALUES(27019,NULL,'Prattville, AL 36067',10870,222,NULL,1,15856,0);
INSERT INTO "django_geo_db_location" VALUES(27020,NULL,'Prattville, AL 36068',10870,222,NULL,1,15857,0);
INSERT INTO "django_geo_db_location" VALUES(27021,NULL,'Ramer, AL',10871,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27022,NULL,'Ramer, AL 36069',10871,222,NULL,1,15858,0);
INSERT INTO "django_geo_db_location" VALUES(27023,NULL,'Rutledge, AL',10872,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27024,NULL,'Rutledge, AL 36071',10872,222,NULL,1,15859,0);
INSERT INTO "django_geo_db_location" VALUES(27025,NULL,'Eufaula, AL 36072',10839,222,NULL,1,15860,0);
INSERT INTO "django_geo_db_location" VALUES(27026,NULL,'Shorter, AL',10873,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27027,NULL,'Shorter, AL 36075',10873,222,NULL,1,15861,0);
INSERT INTO "django_geo_db_location" VALUES(27028,NULL,'Tallassee, AL',10874,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27029,NULL,'Tallassee, AL 36078',10874,222,NULL,1,15862,0);
INSERT INTO "django_geo_db_location" VALUES(27030,NULL,'Troy, AL',10875,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27031,NULL,'Troy, AL 36079',10875,222,NULL,1,15863,0);
INSERT INTO "django_geo_db_location" VALUES(27032,NULL,'Titus, AL',10876,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27033,NULL,'Titus, AL 36080',10876,222,NULL,1,15864,0);
INSERT INTO "django_geo_db_location" VALUES(27034,NULL,'Troy, AL 36081',10875,222,NULL,1,15865,0);
INSERT INTO "django_geo_db_location" VALUES(27035,NULL,'Troy, AL 36082',10875,222,NULL,1,15866,0);
INSERT INTO "django_geo_db_location" VALUES(27036,NULL,'Tuskegee, AL',10877,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27037,NULL,'Tuskegee, AL 36083',10877,222,NULL,1,15867,0);
INSERT INTO "django_geo_db_location" VALUES(27038,NULL,'Tuskegee Institute, AL',10878,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27039,NULL,'Tuskegee Institute, AL 36087',10878,222,NULL,1,15868,0);
INSERT INTO "django_geo_db_location" VALUES(27040,NULL,'Tuskegee Institute, AL 36088',10878,222,NULL,1,15869,0);
INSERT INTO "django_geo_db_location" VALUES(27041,NULL,'Union Springs, AL',10879,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27042,NULL,'Union Springs, AL 36089',10879,222,NULL,1,15870,0);
INSERT INTO "django_geo_db_location" VALUES(27043,NULL,'Verbena, AL',10880,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27044,NULL,'Verbena, AL 36091',10880,222,NULL,1,15871,0);
INSERT INTO "django_geo_db_location" VALUES(27045,NULL,'Wetumpka, AL',10881,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27046,NULL,'Wetumpka, AL 36092',10881,222,NULL,1,15872,0);
INSERT INTO "django_geo_db_location" VALUES(27047,NULL,'Wetumpka, AL 36093',10881,222,NULL,1,15873,0);
INSERT INTO "django_geo_db_location" VALUES(27048,NULL,'Montgomery, AL',10882,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27049,NULL,'Montgomery, AL 36101',10882,222,NULL,1,15874,0);
INSERT INTO "django_geo_db_location" VALUES(27050,NULL,'Montgomery, AL 36102',10882,222,NULL,1,15875,0);
INSERT INTO "django_geo_db_location" VALUES(27051,NULL,'Montgomery, AL 36103',10882,222,NULL,1,15876,0);
INSERT INTO "django_geo_db_location" VALUES(27052,NULL,'Montgomery, AL 36104',10882,222,NULL,1,15877,0);
INSERT INTO "django_geo_db_location" VALUES(27053,NULL,'Montgomery, AL 36105',10882,222,NULL,1,15878,0);
INSERT INTO "django_geo_db_location" VALUES(27054,NULL,'Montgomery, AL 36106',10882,222,NULL,1,15879,0);
INSERT INTO "django_geo_db_location" VALUES(27055,NULL,'Montgomery, AL 36107',10882,222,NULL,1,15880,0);
INSERT INTO "django_geo_db_location" VALUES(27056,NULL,'Montgomery, AL 36108',10882,222,NULL,1,15881,0);
INSERT INTO "django_geo_db_location" VALUES(27057,NULL,'Montgomery, AL 36109',10882,222,NULL,1,15882,0);
INSERT INTO "django_geo_db_location" VALUES(27058,NULL,'Montgomery, AL 36110',10882,222,NULL,1,15883,0);
INSERT INTO "django_geo_db_location" VALUES(27059,NULL,'Montgomery, AL 36111',10882,222,NULL,1,15884,0);
INSERT INTO "django_geo_db_location" VALUES(27060,NULL,'Montgomery, AL 36112',10882,222,NULL,1,15885,0);
INSERT INTO "django_geo_db_location" VALUES(27061,NULL,'Montgomery, AL 36113',10882,222,NULL,1,15886,0);
INSERT INTO "django_geo_db_location" VALUES(27062,NULL,'Montgomery, AL 36114',10882,222,NULL,1,15887,0);
INSERT INTO "django_geo_db_location" VALUES(27063,NULL,'Montgomery, AL 36115',10882,222,NULL,1,15888,0);
INSERT INTO "django_geo_db_location" VALUES(27064,NULL,'Montgomery, AL 36116',10882,222,NULL,1,15889,0);
INSERT INTO "django_geo_db_location" VALUES(27065,NULL,'Montgomery, AL 36117',10882,222,NULL,1,15890,0);
INSERT INTO "django_geo_db_location" VALUES(27066,NULL,'Montgomery, AL 36118',10882,222,NULL,1,15891,0);
INSERT INTO "django_geo_db_location" VALUES(27067,NULL,'Montgomery, AL 36119',10882,222,NULL,1,15892,0);
INSERT INTO "django_geo_db_location" VALUES(27068,NULL,'Montgomery, AL 36120',10882,222,NULL,1,15893,0);
INSERT INTO "django_geo_db_location" VALUES(27069,NULL,'Montgomery, AL 36121',10882,222,NULL,1,15894,0);
INSERT INTO "django_geo_db_location" VALUES(27070,NULL,'Montgomery, AL 36123',10882,222,NULL,1,15895,0);
INSERT INTO "django_geo_db_location" VALUES(27071,NULL,'Montgomery, AL 36124',10882,222,NULL,1,15896,0);
INSERT INTO "django_geo_db_location" VALUES(27072,NULL,'Montgomery, AL 36125',10882,222,NULL,1,15897,0);
INSERT INTO "django_geo_db_location" VALUES(27073,NULL,'Montgomery, AL 36130',10882,222,NULL,1,15898,0);
INSERT INTO "django_geo_db_location" VALUES(27074,NULL,'Montgomery, AL 36131',10882,222,NULL,1,15899,0);
INSERT INTO "django_geo_db_location" VALUES(27075,NULL,'Montgomery, AL 36132',10882,222,NULL,1,15900,0);
INSERT INTO "django_geo_db_location" VALUES(27076,NULL,'Montgomery, AL 36133',10882,222,NULL,1,15901,0);
INSERT INTO "django_geo_db_location" VALUES(27077,NULL,'Montgomery, AL 36134',10882,222,NULL,1,15902,0);
INSERT INTO "django_geo_db_location" VALUES(27078,NULL,'Montgomery, AL 36135',10882,222,NULL,1,15903,0);
INSERT INTO "django_geo_db_location" VALUES(27079,NULL,'Montgomery, AL 36140',10882,222,NULL,1,15904,0);
INSERT INTO "django_geo_db_location" VALUES(27080,NULL,'Montgomery, AL 36141',10882,222,NULL,1,15905,0);
INSERT INTO "django_geo_db_location" VALUES(27081,NULL,'Montgomery, AL 36142',10882,222,NULL,1,15906,0);
INSERT INTO "django_geo_db_location" VALUES(27082,NULL,'Montgomery, AL 36177',10882,222,NULL,1,15907,0);
INSERT INTO "django_geo_db_location" VALUES(27083,NULL,'Montgomery, AL 36191',10882,222,NULL,1,15908,0);
INSERT INTO "django_geo_db_location" VALUES(27084,NULL,'Anniston, AL',10883,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27085,NULL,'Anniston, AL 36201',10883,222,NULL,1,15909,0);
INSERT INTO "django_geo_db_location" VALUES(27086,NULL,'Anniston, AL 36202',10883,222,NULL,1,15910,0);
INSERT INTO "django_geo_db_location" VALUES(27087,NULL,'Anniston, AL 36203',10883,222,NULL,1,15911,0);
INSERT INTO "django_geo_db_location" VALUES(27088,NULL,'Anniston, AL 36204',10883,222,NULL,1,15912,0);
INSERT INTO "django_geo_db_location" VALUES(27089,NULL,'Anniston, AL 36205',10883,222,NULL,1,15913,0);
INSERT INTO "django_geo_db_location" VALUES(27090,NULL,'Anniston, AL 36206',10883,222,NULL,1,15914,0);
INSERT INTO "django_geo_db_location" VALUES(27091,NULL,'Anniston, AL 36207',10883,222,NULL,1,15915,0);
INSERT INTO "django_geo_db_location" VALUES(27092,NULL,'Alexandria, AL',10884,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27093,NULL,'Alexandria, AL 36250',10884,222,NULL,1,15916,0);
INSERT INTO "django_geo_db_location" VALUES(27094,NULL,'Ashland, AL',10885,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27095,NULL,'Ashland, AL 36251',10885,222,NULL,1,15917,0);
INSERT INTO "django_geo_db_location" VALUES(27096,NULL,'Bynum, AL',10886,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27097,NULL,'Bynum, AL 36253',10886,222,NULL,1,15918,0);
INSERT INTO "django_geo_db_location" VALUES(27098,NULL,'Choccolocco, AL',10887,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27099,NULL,'Choccolocco, AL 36254',10887,222,NULL,1,15919,0);
INSERT INTO "django_geo_db_location" VALUES(27100,NULL,'Cragford, AL',10888,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27101,NULL,'Cragford, AL 36255',10888,222,NULL,1,15920,0);
INSERT INTO "django_geo_db_location" VALUES(27102,NULL,'Daviston, AL',10889,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27103,NULL,'Daviston, AL 36256',10889,222,NULL,1,15921,0);
INSERT INTO "django_geo_db_location" VALUES(27104,NULL,'De Armanville, AL',10890,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27105,NULL,'De Armanville, AL 36257',10890,222,NULL,1,15922,0);
INSERT INTO "django_geo_db_location" VALUES(27106,NULL,'Delta, AL',10891,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27107,NULL,'Delta, AL 36258',10891,222,NULL,1,15923,0);
INSERT INTO "django_geo_db_location" VALUES(27108,NULL,'Eastaboga, AL',10892,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27109,NULL,'Eastaboga, AL 36260',10892,222,NULL,1,15924,0);
INSERT INTO "django_geo_db_location" VALUES(27110,NULL,'Edwardsville, AL',10893,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27111,NULL,'Edwardsville, AL 36261',10893,222,NULL,1,15925,0);
INSERT INTO "django_geo_db_location" VALUES(27112,NULL,'Fruithurst, AL',10894,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27113,NULL,'Fruithurst, AL 36262',10894,222,NULL,1,15926,0);
INSERT INTO "django_geo_db_location" VALUES(27114,NULL,'Graham, AL',10895,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27115,NULL,'Graham, AL 36263',10895,222,NULL,1,15927,0);
INSERT INTO "django_geo_db_location" VALUES(27116,NULL,'Heflin, AL',10896,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27117,NULL,'Heflin, AL 36264',10896,222,NULL,1,15928,0);
INSERT INTO "django_geo_db_location" VALUES(27118,NULL,'Jacksonville, AL',10897,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27119,NULL,'Jacksonville, AL 36265',10897,222,NULL,1,15929,0);
INSERT INTO "django_geo_db_location" VALUES(27120,NULL,'Lineville, AL',10898,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27121,NULL,'Lineville, AL 36266',10898,222,NULL,1,15930,0);
INSERT INTO "django_geo_db_location" VALUES(27122,NULL,'Millerville, AL',10899,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27123,NULL,'Millerville, AL 36267',10899,222,NULL,1,15931,0);
INSERT INTO "django_geo_db_location" VALUES(27124,NULL,'Munford, AL',10900,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27125,NULL,'Munford, AL 36268',10900,222,NULL,1,15932,0);
INSERT INTO "django_geo_db_location" VALUES(27126,NULL,'Muscadine, AL',10901,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27127,NULL,'Muscadine, AL 36269',10901,222,NULL,1,15933,0);
INSERT INTO "django_geo_db_location" VALUES(27128,NULL,'Newell, AL',10902,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27129,NULL,'Newell, AL 36270',10902,222,NULL,1,15934,0);
INSERT INTO "django_geo_db_location" VALUES(27130,NULL,'Ohatchee, AL',10903,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27131,NULL,'Ohatchee, AL 36271',10903,222,NULL,1,15935,0);
INSERT INTO "django_geo_db_location" VALUES(27132,NULL,'Piedmont, AL',10904,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27133,NULL,'Piedmont, AL 36272',10904,222,NULL,1,15936,0);
INSERT INTO "django_geo_db_location" VALUES(27134,NULL,'Ranburne, AL',10905,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27135,NULL,'Ranburne, AL 36273',10905,222,NULL,1,15937,0);
INSERT INTO "django_geo_db_location" VALUES(27136,NULL,'Roanoke, AL',10906,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27137,NULL,'Roanoke, AL 36274',10906,222,NULL,1,15938,0);
INSERT INTO "django_geo_db_location" VALUES(27138,NULL,'Spring Garden, AL',10907,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27139,NULL,'Spring Garden, AL 36275',10907,222,NULL,1,15939,0);
INSERT INTO "django_geo_db_location" VALUES(27140,NULL,'Wadley, AL',10908,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27141,NULL,'Wadley, AL 36276',10908,222,NULL,1,15940,0);
INSERT INTO "django_geo_db_location" VALUES(27142,NULL,'Weaver, AL',10909,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27143,NULL,'Weaver, AL 36277',10909,222,NULL,1,15941,0);
INSERT INTO "django_geo_db_location" VALUES(27144,NULL,'Wedowee, AL',10910,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27145,NULL,'Wedowee, AL 36278',10910,222,NULL,1,15942,0);
INSERT INTO "django_geo_db_location" VALUES(27146,NULL,'Wellington, AL',10911,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27147,NULL,'Wellington, AL 36279',10911,222,NULL,1,15943,0);
INSERT INTO "django_geo_db_location" VALUES(27148,NULL,'Woodland, AL',10912,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27149,NULL,'Woodland, AL 36280',10912,222,NULL,1,15944,0);
INSERT INTO "django_geo_db_location" VALUES(27150,NULL,'Dothan, AL',10913,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27151,NULL,'Dothan, AL 36301',10913,222,NULL,1,15945,0);
INSERT INTO "django_geo_db_location" VALUES(27152,NULL,'Dothan, AL 36302',10913,222,NULL,1,15946,0);
INSERT INTO "django_geo_db_location" VALUES(27153,NULL,'Dothan, AL 36303',10913,222,NULL,1,15947,0);
INSERT INTO "django_geo_db_location" VALUES(27154,NULL,'Dothan, AL 36304',10913,222,NULL,1,15948,0);
INSERT INTO "django_geo_db_location" VALUES(27155,NULL,'Dothan, AL 36305',10913,222,NULL,1,15949,0);
INSERT INTO "django_geo_db_location" VALUES(27156,NULL,'Abbeville, AL',10914,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27157,NULL,'Abbeville, AL 36310',10914,222,NULL,1,15950,0);
INSERT INTO "django_geo_db_location" VALUES(27158,NULL,'Ariton, AL',10915,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27159,NULL,'Ariton, AL 36311',10915,222,NULL,1,15951,0);
INSERT INTO "django_geo_db_location" VALUES(27160,NULL,'Ashford, AL',10916,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27161,NULL,'Ashford, AL 36312',10916,222,NULL,1,15952,0);
INSERT INTO "django_geo_db_location" VALUES(27162,NULL,'Bellwood, AL',10917,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27163,NULL,'Bellwood, AL 36313',10917,222,NULL,1,15953,0);
INSERT INTO "django_geo_db_location" VALUES(27164,NULL,'Black, AL',10918,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27165,NULL,'Black, AL 36314',10918,222,NULL,1,15954,0);
INSERT INTO "django_geo_db_location" VALUES(27166,NULL,'Chancellor, AL',10919,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27167,NULL,'Chancellor, AL 36316',10919,222,NULL,1,15955,0);
INSERT INTO "django_geo_db_location" VALUES(27168,NULL,'Clopton, AL',10920,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27169,NULL,'Clopton, AL 36317',10920,222,NULL,1,15956,0);
INSERT INTO "django_geo_db_location" VALUES(27170,NULL,'Coffee Springs, AL',10921,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27171,NULL,'Coffee Springs, AL 36318',10921,222,NULL,1,15957,0);
INSERT INTO "django_geo_db_location" VALUES(27172,NULL,'Columbia, AL',10922,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27173,NULL,'Columbia, AL 36319',10922,222,NULL,1,15958,0);
INSERT INTO "django_geo_db_location" VALUES(27174,NULL,'Cottonwood, AL',10923,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27175,NULL,'Cottonwood, AL 36320',10923,222,NULL,1,15959,0);
INSERT INTO "django_geo_db_location" VALUES(27176,NULL,'Cowarts, AL',10924,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27177,NULL,'Cowarts, AL 36321',10924,222,NULL,1,15960,0);
INSERT INTO "django_geo_db_location" VALUES(27178,NULL,'Daleville, AL',10925,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27179,NULL,'Daleville, AL 36322',10925,222,NULL,1,15961,0);
INSERT INTO "django_geo_db_location" VALUES(27180,NULL,'Elba, AL',10926,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27181,NULL,'Elba, AL 36323',10926,222,NULL,1,15962,0);
INSERT INTO "django_geo_db_location" VALUES(27182,NULL,'Enterprise, AL',10927,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27183,NULL,'Enterprise, AL 36330',10927,222,NULL,1,15963,0);
INSERT INTO "django_geo_db_location" VALUES(27184,NULL,'Enterprise, AL 36331',10927,222,NULL,1,15964,0);
INSERT INTO "django_geo_db_location" VALUES(27185,NULL,'Geneva, AL',10928,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27186,NULL,'Geneva, AL 36340',10928,222,NULL,1,15965,0);
INSERT INTO "django_geo_db_location" VALUES(27187,NULL,'Gordon, AL',10929,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27188,NULL,'Gordon, AL 36343',10929,222,NULL,1,15966,0);
INSERT INTO "django_geo_db_location" VALUES(27189,NULL,'Hartford, AL',10930,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27190,NULL,'Hartford, AL 36344',10930,222,NULL,1,15967,0);
INSERT INTO "django_geo_db_location" VALUES(27191,NULL,'Headland, AL',10931,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27192,NULL,'Headland, AL 36345',10931,222,NULL,1,15968,0);
INSERT INTO "django_geo_db_location" VALUES(27193,NULL,'Jack, AL',10932,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27194,NULL,'Jack, AL 36346',10932,222,NULL,1,15969,0);
INSERT INTO "django_geo_db_location" VALUES(27195,NULL,'Malvern, AL',10933,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27196,NULL,'Malvern, AL 36349',10933,222,NULL,1,15970,0);
INSERT INTO "django_geo_db_location" VALUES(27197,NULL,'Midland City, AL',10934,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27198,NULL,'Midland City, AL 36350',10934,222,NULL,1,15971,0);
INSERT INTO "django_geo_db_location" VALUES(27199,NULL,'New Brockton, AL',10935,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27200,NULL,'New Brockton, AL 36351',10935,222,NULL,1,15972,0);
INSERT INTO "django_geo_db_location" VALUES(27201,NULL,'Newton, AL',10936,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27202,NULL,'Newton, AL 36352',10936,222,NULL,1,15973,0);
INSERT INTO "django_geo_db_location" VALUES(27203,NULL,'Newville, AL',10937,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27204,NULL,'Newville, AL 36353',10937,222,NULL,1,15974,0);
INSERT INTO "django_geo_db_location" VALUES(27205,NULL,'Ozark, AL',10938,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27206,NULL,'Ozark, AL 36360',10938,222,NULL,1,15975,0);
INSERT INTO "django_geo_db_location" VALUES(27207,NULL,'Ozark, AL 36361',10938,222,NULL,1,15976,0);
INSERT INTO "django_geo_db_location" VALUES(27208,NULL,'Fort Rucker, AL',10939,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27209,NULL,'Fort Rucker, AL 36362',10939,222,NULL,1,15977,0);
INSERT INTO "django_geo_db_location" VALUES(27210,NULL,'Pansey, AL',10940,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27211,NULL,'Pansey, AL 36370',10940,222,NULL,1,15978,0);
INSERT INTO "django_geo_db_location" VALUES(27212,NULL,'Pinckard, AL',10941,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27213,NULL,'Pinckard, AL 36371',10941,222,NULL,1,15979,0);
INSERT INTO "django_geo_db_location" VALUES(27214,NULL,'Shorterville, AL',10942,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27215,NULL,'Shorterville, AL 36373',10942,222,NULL,1,15980,0);
INSERT INTO "django_geo_db_location" VALUES(27216,NULL,'Skipperville, AL',10943,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27217,NULL,'Skipperville, AL 36374',10943,222,NULL,1,15981,0);
INSERT INTO "django_geo_db_location" VALUES(27218,NULL,'Slocomb, AL',10944,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27219,NULL,'Slocomb, AL 36375',10944,222,NULL,1,15982,0);
INSERT INTO "django_geo_db_location" VALUES(27220,NULL,'Webb, AL',10945,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27221,NULL,'Webb, AL 36376',10945,222,NULL,1,15983,0);
INSERT INTO "django_geo_db_location" VALUES(27222,NULL,'Lanett, AL',10946,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27223,NULL,'Lanett, AL 36383',10946,222,NULL,1,15984,0);
INSERT INTO "django_geo_db_location" VALUES(27224,NULL,'Malvern, AL 36395',10933,222,NULL,1,15985,0);
INSERT INTO "django_geo_db_location" VALUES(27225,NULL,'Evergreen, AL',10947,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27226,NULL,'Evergreen, AL 36401',10947,222,NULL,1,15986,0);
INSERT INTO "django_geo_db_location" VALUES(27227,NULL,'Andalusia, AL',10948,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27228,NULL,'Andalusia, AL 36420',10948,222,NULL,1,15987,0);
INSERT INTO "django_geo_db_location" VALUES(27229,NULL,'Lockhart, AL',10949,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27230,NULL,'Lockhart, AL 36422',10949,222,NULL,1,15988,0);
INSERT INTO "django_geo_db_location" VALUES(27231,NULL,'Beatrice, AL',10950,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27232,NULL,'Beatrice, AL 36425',10950,222,NULL,1,15989,0);
INSERT INTO "django_geo_db_location" VALUES(27233,NULL,'Brewton, AL',10951,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27234,NULL,'Brewton, AL 36426',10951,222,NULL,1,15990,0);
INSERT INTO "django_geo_db_location" VALUES(27235,NULL,'Brewton, AL 36427',10951,222,NULL,1,15991,0);
INSERT INTO "django_geo_db_location" VALUES(27236,NULL,'Brooklyn, AL',10952,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27237,NULL,'Brooklyn, AL 36429',10952,222,NULL,1,15992,0);
INSERT INTO "django_geo_db_location" VALUES(27238,NULL,'Burnt Corn, AL',10953,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27239,NULL,'Burnt Corn, AL 36431',10953,222,NULL,1,15993,0);
INSERT INTO "django_geo_db_location" VALUES(27240,NULL,'Castleberry, AL',10954,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27241,NULL,'Castleberry, AL 36432',10954,222,NULL,1,15994,0);
INSERT INTO "django_geo_db_location" VALUES(27242,NULL,'Coy, AL',10955,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27243,NULL,'Coy, AL 36435',10955,222,NULL,1,15995,0);
INSERT INTO "django_geo_db_location" VALUES(27244,NULL,'Dickinson, AL',10956,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27245,NULL,'Dickinson, AL 36436',10956,222,NULL,1,15996,0);
INSERT INTO "django_geo_db_location" VALUES(27246,NULL,'Excel, AL',10957,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27247,NULL,'Excel, AL 36439',10957,222,NULL,1,15997,0);
INSERT INTO "django_geo_db_location" VALUES(27248,NULL,'Flomaton, AL',10958,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27249,NULL,'Flomaton, AL 36441',10958,222,NULL,1,15998,0);
INSERT INTO "django_geo_db_location" VALUES(27250,NULL,'Florala, AL',10959,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27251,NULL,'Florala, AL 36442',10959,222,NULL,1,15999,0);
INSERT INTO "django_geo_db_location" VALUES(27252,NULL,'Franklin, AL',10960,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27253,NULL,'Franklin, AL 36444',10960,222,NULL,1,16000,0);
INSERT INTO "django_geo_db_location" VALUES(27254,NULL,'Frisco City, AL',10961,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27255,NULL,'Frisco City, AL 36445',10961,222,NULL,1,16001,0);
INSERT INTO "django_geo_db_location" VALUES(27256,NULL,'Fulton, AL',10962,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27257,NULL,'Fulton, AL 36446',10962,222,NULL,1,16002,0);
INSERT INTO "django_geo_db_location" VALUES(27258,NULL,'Goodway, AL',10963,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27259,NULL,'Goodway, AL 36449',10963,222,NULL,1,16003,0);
INSERT INTO "django_geo_db_location" VALUES(27260,NULL,'Grove Hill, AL',10964,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27261,NULL,'Grove Hill, AL 36451',10964,222,NULL,1,16004,0);
INSERT INTO "django_geo_db_location" VALUES(27262,NULL,'Kinston, AL',10965,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27263,NULL,'Kinston, AL 36453',10965,222,NULL,1,16005,0);
INSERT INTO "django_geo_db_location" VALUES(27264,NULL,'Lenox, AL',10966,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27265,NULL,'Lenox, AL 36454',10966,222,NULL,1,16006,0);
INSERT INTO "django_geo_db_location" VALUES(27266,NULL,'Lockhart, AL 36455',10949,222,NULL,1,16007,0);
INSERT INTO "django_geo_db_location" VALUES(27267,NULL,'McKenzie, AL',10967,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27268,NULL,'McKenzie, AL 36456',10967,222,NULL,1,16008,0);
INSERT INTO "django_geo_db_location" VALUES(27269,NULL,'Megargel, AL',10968,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27270,NULL,'Megargel, AL 36457',10968,222,NULL,1,16009,0);
INSERT INTO "django_geo_db_location" VALUES(27271,NULL,'Mexia, AL',10969,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27272,NULL,'Mexia, AL 36458',10969,222,NULL,1,16010,0);
INSERT INTO "django_geo_db_location" VALUES(27273,NULL,'Monroeville, AL',10970,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27274,NULL,'Monroeville, AL 36460',10970,222,NULL,1,16011,0);
INSERT INTO "django_geo_db_location" VALUES(27275,NULL,'Monroeville, AL 36461',10970,222,NULL,1,16012,0);
INSERT INTO "django_geo_db_location" VALUES(27276,NULL,'Monroeville, AL 36462',10970,222,NULL,1,16013,0);
INSERT INTO "django_geo_db_location" VALUES(27277,NULL,'Opp, AL',10971,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27278,NULL,'Opp, AL 36467',10971,222,NULL,1,16014,0);
INSERT INTO "django_geo_db_location" VALUES(27279,NULL,'Perdue Hill, AL',10972,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27280,NULL,'Perdue Hill, AL 36470',10972,222,NULL,1,16015,0);
INSERT INTO "django_geo_db_location" VALUES(27281,NULL,'Peterman, AL',10973,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27282,NULL,'Peterman, AL 36471',10973,222,NULL,1,16016,0);
INSERT INTO "django_geo_db_location" VALUES(27283,NULL,'Range, AL',10974,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27284,NULL,'Range, AL 36473',10974,222,NULL,1,16017,0);
INSERT INTO "django_geo_db_location" VALUES(27285,NULL,'Red Level, AL',10975,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27286,NULL,'Red Level, AL 36474',10975,222,NULL,1,16018,0);
INSERT INTO "django_geo_db_location" VALUES(27287,NULL,'Repton, AL',10976,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27288,NULL,'Repton, AL 36475',10976,222,NULL,1,16019,0);
INSERT INTO "django_geo_db_location" VALUES(27289,NULL,'River Falls, AL',10977,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27290,NULL,'River Falls, AL 36476',10977,222,NULL,1,16020,0);
INSERT INTO "django_geo_db_location" VALUES(27291,NULL,'Samson, AL',10978,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27292,NULL,'Samson, AL 36477',10978,222,NULL,1,16021,0);
INSERT INTO "django_geo_db_location" VALUES(27293,NULL,'Uriah, AL',10979,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27294,NULL,'Uriah, AL 36480',10979,222,NULL,1,16022,0);
INSERT INTO "django_geo_db_location" VALUES(27295,NULL,'Vredenburgh, AL',10980,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27296,NULL,'Vredenburgh, AL 36481',10980,222,NULL,1,16023,0);
INSERT INTO "django_geo_db_location" VALUES(27297,NULL,'Whatley, AL',10981,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27298,NULL,'Whatley, AL 36482',10981,222,NULL,1,16024,0);
INSERT INTO "django_geo_db_location" VALUES(27299,NULL,'Wing, AL',10982,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27300,NULL,'Wing, AL 36483',10982,222,NULL,1,16025,0);
INSERT INTO "django_geo_db_location" VALUES(27301,NULL,'Alma, AL',10983,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27302,NULL,'Alma, AL 36501',10983,222,NULL,1,16026,0);
INSERT INTO "django_geo_db_location" VALUES(27303,NULL,'Atmore, AL',10984,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27304,NULL,'Atmore, AL 36502',10984,222,NULL,1,16027,0);
INSERT INTO "django_geo_db_location" VALUES(27305,NULL,'Atmore, AL 36503',10984,222,NULL,1,16028,0);
INSERT INTO "django_geo_db_location" VALUES(27306,NULL,'Atmore, AL 36504',10984,222,NULL,1,16029,0);
INSERT INTO "django_geo_db_location" VALUES(27307,NULL,'Axis, AL',10985,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27308,NULL,'Axis, AL 36505',10985,222,NULL,1,16030,0);
INSERT INTO "django_geo_db_location" VALUES(27309,NULL,'Bay Minette, AL',10986,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27310,NULL,'Bay Minette, AL 36507',10986,222,NULL,1,16031,0);
INSERT INTO "django_geo_db_location" VALUES(27311,NULL,'Dauphin Island, AL',10987,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27312,NULL,'Dauphin Island, AL 36508',10987,222,NULL,1,16032,0);
INSERT INTO "django_geo_db_location" VALUES(27313,NULL,'Bayou La Batre, AL',10988,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27314,NULL,'Bayou La Batre, AL 36509',10988,222,NULL,1,16033,0);
INSERT INTO "django_geo_db_location" VALUES(27315,NULL,'Bon Secour, AL',10989,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27316,NULL,'Bon Secour, AL 36511',10989,222,NULL,1,16034,0);
INSERT INTO "django_geo_db_location" VALUES(27317,NULL,'Bucks, AL',10990,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27318,NULL,'Bucks, AL 36512',10990,222,NULL,1,16035,0);
INSERT INTO "django_geo_db_location" VALUES(27319,NULL,'Calvert, AL',10991,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27320,NULL,'Calvert, AL 36513',10991,222,NULL,1,16036,0);
INSERT INTO "django_geo_db_location" VALUES(27321,NULL,'Carlton, AL',10992,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27322,NULL,'Carlton, AL 36515',10992,222,NULL,1,16037,0);
INSERT INTO "django_geo_db_location" VALUES(27323,NULL,'Chatom, AL',10993,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27324,NULL,'Chatom, AL 36518',10993,222,NULL,1,16038,0);
INSERT INTO "django_geo_db_location" VALUES(27325,NULL,'Chunchula, AL',10994,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27326,NULL,'Chunchula, AL 36521',10994,222,NULL,1,16039,0);
INSERT INTO "django_geo_db_location" VALUES(27327,NULL,'Citronelle, AL',10995,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27328,NULL,'Citronelle, AL 36522',10995,222,NULL,1,16040,0);
INSERT INTO "django_geo_db_location" VALUES(27329,NULL,'Coden, AL',10996,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27330,NULL,'Coden, AL 36523',10996,222,NULL,1,16041,0);
INSERT INTO "django_geo_db_location" VALUES(27331,NULL,'Coffeeville, AL',10997,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27332,NULL,'Coffeeville, AL 36524',10997,222,NULL,1,16042,0);
INSERT INTO "django_geo_db_location" VALUES(27333,NULL,'Creola, AL',10998,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27334,NULL,'Creola, AL 36525',10998,222,NULL,1,16043,0);
INSERT INTO "django_geo_db_location" VALUES(27335,NULL,'Daphne, AL',10999,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27336,NULL,'Daphne, AL 36526',10999,222,NULL,1,16044,0);
INSERT INTO "django_geo_db_location" VALUES(27337,NULL,'Spanish Fort, AL',11000,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27338,NULL,'Spanish Fort, AL 36527',11000,222,NULL,1,16045,0);
INSERT INTO "django_geo_db_location" VALUES(27339,NULL,'Dauphin Island, AL 36528',10987,222,NULL,1,16046,0);
INSERT INTO "django_geo_db_location" VALUES(27340,NULL,'Deer Park, AL',11001,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27341,NULL,'Deer Park, AL 36529',11001,222,NULL,1,16047,0);
INSERT INTO "django_geo_db_location" VALUES(27342,NULL,'Elberta, AL',11002,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27343,NULL,'Elberta, AL 36530',11002,222,NULL,1,16048,0);
INSERT INTO "django_geo_db_location" VALUES(27344,NULL,'Loxley, AL',11003,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27345,NULL,'Loxley, AL 36531',11003,222,NULL,1,16049,0);
INSERT INTO "django_geo_db_location" VALUES(27346,NULL,'Fairhope, AL',11004,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27347,NULL,'Fairhope, AL 36532',11004,222,NULL,1,16050,0);
INSERT INTO "django_geo_db_location" VALUES(27348,NULL,'Fairhope, AL 36533',11004,222,NULL,1,16051,0);
INSERT INTO "django_geo_db_location" VALUES(27349,NULL,'Foley, AL',11005,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27350,NULL,'Foley, AL 36535',11005,222,NULL,1,16052,0);
INSERT INTO "django_geo_db_location" VALUES(27351,NULL,'Foley, AL 36536',11005,222,NULL,1,16053,0);
INSERT INTO "django_geo_db_location" VALUES(27352,NULL,'Frankville, AL',11006,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27353,NULL,'Frankville, AL 36538',11006,222,NULL,1,16054,0);
INSERT INTO "django_geo_db_location" VALUES(27354,NULL,'Fruitdale, AL',11007,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27355,NULL,'Fruitdale, AL 36539',11007,222,NULL,1,16055,0);
INSERT INTO "django_geo_db_location" VALUES(27356,NULL,'Gainestown, AL',11008,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27357,NULL,'Gainestown, AL 36540',11008,222,NULL,1,16056,0);
INSERT INTO "django_geo_db_location" VALUES(27358,NULL,'Grand Bay, AL',11009,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27359,NULL,'Grand Bay, AL 36541',11009,222,NULL,1,16057,0);
INSERT INTO "django_geo_db_location" VALUES(27360,NULL,'Gulf Shores, AL',11010,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27361,NULL,'Gulf Shores, AL 36542',11010,222,NULL,1,16058,0);
INSERT INTO "django_geo_db_location" VALUES(27362,NULL,'Huxford, AL',11011,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27363,NULL,'Huxford, AL 36543',11011,222,NULL,1,16059,0);
INSERT INTO "django_geo_db_location" VALUES(27364,NULL,'Irvington, AL',11012,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27365,NULL,'Irvington, AL 36544',11012,222,NULL,1,16060,0);
INSERT INTO "django_geo_db_location" VALUES(27366,NULL,'Jackson, AL',11013,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27367,NULL,'Jackson, AL 36545',11013,222,NULL,1,16061,0);
INSERT INTO "django_geo_db_location" VALUES(27368,NULL,'Gulf Shores, AL 36547',11010,222,NULL,1,16062,0);
INSERT INTO "django_geo_db_location" VALUES(27369,NULL,'Leroy, AL',11014,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27370,NULL,'Leroy, AL 36548',11014,222,NULL,1,16063,0);
INSERT INTO "django_geo_db_location" VALUES(27371,NULL,'Lillian, AL',11015,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27372,NULL,'Lillian, AL 36549',11015,222,NULL,1,16064,0);
INSERT INTO "django_geo_db_location" VALUES(27373,NULL,'Little River, AL',11016,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27374,NULL,'Little River, AL 36550',11016,222,NULL,1,16065,0);
INSERT INTO "django_geo_db_location" VALUES(27375,NULL,'Loxley, AL 36551',11003,222,NULL,1,16066,0);
INSERT INTO "django_geo_db_location" VALUES(27376,NULL,'McIntosh, AL',11017,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27377,NULL,'McIntosh, AL 36553',11017,222,NULL,1,16067,0);
INSERT INTO "django_geo_db_location" VALUES(27378,NULL,'Magnolia Springs, AL',11018,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27379,NULL,'Magnolia Springs, AL 36555',11018,222,NULL,1,16068,0);
INSERT INTO "django_geo_db_location" VALUES(27380,NULL,'Malcolm, AL',11019,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27381,NULL,'Malcolm, AL 36556',11019,222,NULL,1,16069,0);
INSERT INTO "django_geo_db_location" VALUES(27382,NULL,'Millry, AL',11020,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27383,NULL,'Millry, AL 36558',11020,222,NULL,1,16070,0);
INSERT INTO "django_geo_db_location" VALUES(27384,NULL,'Montrose, AL',11021,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27385,NULL,'Montrose, AL 36559',11021,222,NULL,1,16071,0);
INSERT INTO "django_geo_db_location" VALUES(27386,NULL,'Mount Vernon, AL',11022,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27387,NULL,'Mount Vernon, AL 36560',11022,222,NULL,1,16072,0);
INSERT INTO "django_geo_db_location" VALUES(27388,NULL,'Orange Beach, AL',11023,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27389,NULL,'Orange Beach, AL 36561',11023,222,NULL,1,16073,0);
INSERT INTO "django_geo_db_location" VALUES(27390,NULL,'Perdido, AL',11024,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27391,NULL,'Perdido, AL 36562',11024,222,NULL,1,16074,0);
INSERT INTO "django_geo_db_location" VALUES(27392,NULL,'Point Clear, AL',11025,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27393,NULL,'Point Clear, AL 36564',11025,222,NULL,1,16075,0);
INSERT INTO "django_geo_db_location" VALUES(27394,NULL,'Robertsdale, AL',11026,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27395,NULL,'Robertsdale, AL 36567',11026,222,NULL,1,16076,0);
INSERT INTO "django_geo_db_location" VALUES(27396,NULL,'Saint Elmo, AL',11027,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27397,NULL,'Saint Elmo, AL 36568',11027,222,NULL,1,16077,0);
INSERT INTO "django_geo_db_location" VALUES(27398,NULL,'Saint Stephens, AL',11028,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27399,NULL,'Saint Stephens, AL 36569',11028,222,NULL,1,16078,0);
INSERT INTO "django_geo_db_location" VALUES(27400,NULL,'Salitpa, AL',11029,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27401,NULL,'Salitpa, AL 36570',11029,222,NULL,1,16079,0);
INSERT INTO "django_geo_db_location" VALUES(27402,NULL,'Saraland, AL',11030,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27403,NULL,'Saraland, AL 36571',11030,222,NULL,1,16080,0);
INSERT INTO "django_geo_db_location" VALUES(27404,NULL,'Satsuma, AL',11031,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27405,NULL,'Satsuma, AL 36572',11031,222,NULL,1,16081,0);
INSERT INTO "django_geo_db_location" VALUES(27406,NULL,'Seminole, AL',11032,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27407,NULL,'Seminole, AL 36574',11032,222,NULL,1,16082,0);
INSERT INTO "django_geo_db_location" VALUES(27408,NULL,'Semmes, AL',11033,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27409,NULL,'Semmes, AL 36575',11033,222,NULL,1,16083,0);
INSERT INTO "django_geo_db_location" VALUES(27410,NULL,'Silverhill, AL',11034,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27411,NULL,'Silverhill, AL 36576',11034,222,NULL,1,16084,0);
INSERT INTO "django_geo_db_location" VALUES(27412,NULL,'Spanish Fort, AL 36577',11000,222,NULL,1,16085,0);
INSERT INTO "django_geo_db_location" VALUES(27413,NULL,'Stapleton, AL',11035,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27414,NULL,'Stapleton, AL 36578',11035,222,NULL,1,16086,0);
INSERT INTO "django_geo_db_location" VALUES(27415,NULL,'Stockton, AL',11036,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27416,NULL,'Stockton, AL 36579',11036,222,NULL,1,16087,0);
INSERT INTO "django_geo_db_location" VALUES(27417,NULL,'Summerdale, AL',11037,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27418,NULL,'Summerdale, AL 36580',11037,222,NULL,1,16088,0);
INSERT INTO "django_geo_db_location" VALUES(27419,NULL,'Sunflower, AL',11038,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27420,NULL,'Sunflower, AL 36581',11038,222,NULL,1,16089,0);
INSERT INTO "django_geo_db_location" VALUES(27421,NULL,'Theodore, AL',11039,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27422,NULL,'Theodore, AL 36582',11039,222,NULL,1,16090,0);
INSERT INTO "django_geo_db_location" VALUES(27423,NULL,'Tibbie, AL',11040,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27424,NULL,'Tibbie, AL 36583',11040,222,NULL,1,16091,0);
INSERT INTO "django_geo_db_location" VALUES(27425,NULL,'Vinegar Bend, AL',11041,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27426,NULL,'Vinegar Bend, AL 36584',11041,222,NULL,1,16092,0);
INSERT INTO "django_geo_db_location" VALUES(27427,NULL,'Wagarville, AL',11042,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27428,NULL,'Wagarville, AL 36585',11042,222,NULL,1,16093,0);
INSERT INTO "django_geo_db_location" VALUES(27429,NULL,'Walker Springs, AL',11043,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27430,NULL,'Walker Springs, AL 36586',11043,222,NULL,1,16094,0);
INSERT INTO "django_geo_db_location" VALUES(27431,NULL,'Wilmer, AL',11044,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27432,NULL,'Wilmer, AL 36587',11044,222,NULL,1,16095,0);
INSERT INTO "django_geo_db_location" VALUES(27433,NULL,'Theodore, AL 36590',11039,222,NULL,1,16096,0);
INSERT INTO "django_geo_db_location" VALUES(27434,NULL,'Mobile, AL',11045,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27435,NULL,'Mobile, AL 36601',11045,222,NULL,1,16097,0);
INSERT INTO "django_geo_db_location" VALUES(27436,NULL,'Mobile, AL 36602',11045,222,NULL,1,16098,0);
INSERT INTO "django_geo_db_location" VALUES(27437,NULL,'Mobile, AL 36603',11045,222,NULL,1,16099,0);
INSERT INTO "django_geo_db_location" VALUES(27438,NULL,'Mobile, AL 36604',11045,222,NULL,1,16100,0);
INSERT INTO "django_geo_db_location" VALUES(27439,NULL,'Mobile, AL 36605',11045,222,NULL,1,16101,0);
INSERT INTO "django_geo_db_location" VALUES(27440,NULL,'Mobile, AL 36606',11045,222,NULL,1,16102,0);
INSERT INTO "django_geo_db_location" VALUES(27441,NULL,'Mobile, AL 36607',11045,222,NULL,1,16103,0);
INSERT INTO "django_geo_db_location" VALUES(27442,NULL,'Mobile, AL 36608',11045,222,NULL,1,16104,0);
INSERT INTO "django_geo_db_location" VALUES(27443,NULL,'Mobile, AL 36609',11045,222,NULL,1,16105,0);
INSERT INTO "django_geo_db_location" VALUES(27444,NULL,'Mobile, AL 36610',11045,222,NULL,1,16106,0);
INSERT INTO "django_geo_db_location" VALUES(27445,NULL,'Mobile, AL 36611',11045,222,NULL,1,16107,0);
INSERT INTO "django_geo_db_location" VALUES(27446,NULL,'Mobile, AL 36612',11045,222,NULL,1,16108,0);
INSERT INTO "django_geo_db_location" VALUES(27447,NULL,'Eight Mile, AL',11046,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27448,NULL,'Eight Mile, AL 36613',11046,222,NULL,1,16109,0);
INSERT INTO "django_geo_db_location" VALUES(27449,NULL,'Mobile, AL 36614',11045,222,NULL,1,16110,0);
INSERT INTO "django_geo_db_location" VALUES(27450,NULL,'Mobile, AL 36615',11045,222,NULL,1,16111,0);
INSERT INTO "django_geo_db_location" VALUES(27451,NULL,'Mobile, AL 36616',11045,222,NULL,1,16112,0);
INSERT INTO "django_geo_db_location" VALUES(27452,NULL,'Mobile, AL 36617',11045,222,NULL,1,16113,0);
INSERT INTO "django_geo_db_location" VALUES(27453,NULL,'Mobile, AL 36618',11045,222,NULL,1,16114,0);
INSERT INTO "django_geo_db_location" VALUES(27454,NULL,'Mobile, AL 36619',11045,222,NULL,1,16115,0);
INSERT INTO "django_geo_db_location" VALUES(27455,NULL,'Mobile, AL 36621',11045,222,NULL,1,16116,0);
INSERT INTO "django_geo_db_location" VALUES(27456,NULL,'Mobile, AL 36622',11045,222,NULL,1,16117,0);
INSERT INTO "django_geo_db_location" VALUES(27457,NULL,'Mobile, AL 36623',11045,222,NULL,1,16118,0);
INSERT INTO "django_geo_db_location" VALUES(27458,NULL,'Mobile, AL 36625',11045,222,NULL,1,16119,0);
INSERT INTO "django_geo_db_location" VALUES(27459,NULL,'Mobile, AL 36626',11045,222,NULL,1,16120,0);
INSERT INTO "django_geo_db_location" VALUES(27460,NULL,'Mobile, AL 36628',11045,222,NULL,1,16121,0);
INSERT INTO "django_geo_db_location" VALUES(27461,NULL,'Mobile, AL 36630',11045,222,NULL,1,16122,0);
INSERT INTO "django_geo_db_location" VALUES(27462,NULL,'Mobile, AL 36631',11045,222,NULL,1,16123,0);
INSERT INTO "django_geo_db_location" VALUES(27463,NULL,'Mobile, AL 36633',11045,222,NULL,1,16124,0);
INSERT INTO "django_geo_db_location" VALUES(27464,NULL,'Mobile, AL 36640',11045,222,NULL,1,16125,0);
INSERT INTO "django_geo_db_location" VALUES(27465,NULL,'Mobile, AL 36641',11045,222,NULL,1,16126,0);
INSERT INTO "django_geo_db_location" VALUES(27466,NULL,'Mobile, AL 36644',11045,222,NULL,1,16127,0);
INSERT INTO "django_geo_db_location" VALUES(27467,NULL,'Mobile, AL 36652',11045,222,NULL,1,16128,0);
INSERT INTO "django_geo_db_location" VALUES(27468,NULL,'Mobile, AL 36660',11045,222,NULL,1,16129,0);
INSERT INTO "django_geo_db_location" VALUES(27469,NULL,'Mobile, AL 36663',11045,222,NULL,1,16130,0);
INSERT INTO "django_geo_db_location" VALUES(27470,NULL,'Mobile, AL 36670',11045,222,NULL,1,16131,0);
INSERT INTO "django_geo_db_location" VALUES(27471,NULL,'Mobile, AL 36671',11045,222,NULL,1,16132,0);
INSERT INTO "django_geo_db_location" VALUES(27472,NULL,'Mobile, AL 36675',11045,222,NULL,1,16133,0);
INSERT INTO "django_geo_db_location" VALUES(27473,NULL,'Mobile, AL 36685',11045,222,NULL,1,16134,0);
INSERT INTO "django_geo_db_location" VALUES(27474,NULL,'Mobile, AL 36688',11045,222,NULL,1,16135,0);
INSERT INTO "django_geo_db_location" VALUES(27475,NULL,'Mobile, AL 36689',11045,222,NULL,1,16136,0);
INSERT INTO "django_geo_db_location" VALUES(27476,NULL,'Mobile, AL 36690',11045,222,NULL,1,16137,0);
INSERT INTO "django_geo_db_location" VALUES(27477,NULL,'Mobile, AL 36691',11045,222,NULL,1,16138,0);
INSERT INTO "django_geo_db_location" VALUES(27478,NULL,'Mobile, AL 36693',11045,222,NULL,1,16139,0);
INSERT INTO "django_geo_db_location" VALUES(27479,NULL,'Mobile, AL 36695',11045,222,NULL,1,16140,0);
INSERT INTO "django_geo_db_location" VALUES(27480,NULL,'Selma, AL',11047,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27481,NULL,'Selma, AL 36701',11047,222,NULL,1,16141,0);
INSERT INTO "django_geo_db_location" VALUES(27482,NULL,'Selma, AL 36702',11047,222,NULL,1,16142,0);
INSERT INTO "django_geo_db_location" VALUES(27483,NULL,'Selma, AL 36703',11047,222,NULL,1,16143,0);
INSERT INTO "django_geo_db_location" VALUES(27484,NULL,'Alberta, AL',11048,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27485,NULL,'Alberta, AL 36720',11048,222,NULL,1,16144,0);
INSERT INTO "django_geo_db_location" VALUES(27486,NULL,'Annemanie, AL',11049,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27487,NULL,'Annemanie, AL 36721',11049,222,NULL,1,16145,0);
INSERT INTO "django_geo_db_location" VALUES(27488,NULL,'Arlington, AL',11050,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27489,NULL,'Arlington, AL 36722',11050,222,NULL,1,16146,0);
INSERT INTO "django_geo_db_location" VALUES(27490,NULL,'Boykin, AL',11051,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27491,NULL,'Boykin, AL 36723',11051,222,NULL,1,16147,0);
INSERT INTO "django_geo_db_location" VALUES(27492,NULL,'Camden, AL',11052,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27493,NULL,'Camden, AL 36726',11052,222,NULL,1,16148,0);
INSERT INTO "django_geo_db_location" VALUES(27494,NULL,'Campbell, AL',11053,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27495,NULL,'Campbell, AL 36727',11053,222,NULL,1,16149,0);
INSERT INTO "django_geo_db_location" VALUES(27496,NULL,'Catherine, AL',11054,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27497,NULL,'Catherine, AL 36728',11054,222,NULL,1,16150,0);
INSERT INTO "django_geo_db_location" VALUES(27498,NULL,'Demopolis, AL',11055,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27499,NULL,'Demopolis, AL 36732',11055,222,NULL,1,16151,0);
INSERT INTO "django_geo_db_location" VALUES(27500,NULL,'Dixons Mills, AL',11056,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27501,NULL,'Dixons Mills, AL 36736',11056,222,NULL,1,16152,0);
INSERT INTO "django_geo_db_location" VALUES(27502,NULL,'Faunsdale, AL',11057,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27503,NULL,'Faunsdale, AL 36738',11057,222,NULL,1,16153,0);
INSERT INTO "django_geo_db_location" VALUES(27504,NULL,'Forkland, AL',11058,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27505,NULL,'Forkland, AL 36740',11058,222,NULL,1,16154,0);
INSERT INTO "django_geo_db_location" VALUES(27506,NULL,'Furman, AL',11059,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27507,NULL,'Furman, AL 36741',11059,222,NULL,1,16155,0);
INSERT INTO "django_geo_db_location" VALUES(27508,NULL,'Gallion, AL',11060,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27509,NULL,'Gallion, AL 36742',11060,222,NULL,1,16156,0);
INSERT INTO "django_geo_db_location" VALUES(27510,NULL,'Greensboro, AL',11061,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27511,NULL,'Greensboro, AL 36744',11061,222,NULL,1,16157,0);
INSERT INTO "django_geo_db_location" VALUES(27512,NULL,'Jefferson, AL',11062,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27513,NULL,'Jefferson, AL 36745',11062,222,NULL,1,16158,0);
INSERT INTO "django_geo_db_location" VALUES(27514,NULL,'Linden, AL',11063,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27515,NULL,'Linden, AL 36748',11063,222,NULL,1,16159,0);
INSERT INTO "django_geo_db_location" VALUES(27516,NULL,'Jones, AL',11064,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27517,NULL,'Jones, AL 36749',11064,222,NULL,1,16160,0);
INSERT INTO "django_geo_db_location" VALUES(27518,NULL,'Maplesville, AL',11065,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27519,NULL,'Maplesville, AL 36750',11065,222,NULL,1,16161,0);
INSERT INTO "django_geo_db_location" VALUES(27520,NULL,'Lower Peach Tree, AL',11066,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27521,NULL,'Lower Peach Tree, AL 36751',11066,222,NULL,1,16162,0);
INSERT INTO "django_geo_db_location" VALUES(27522,NULL,'Lowndesboro, AL',11067,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27523,NULL,'Lowndesboro, AL 36752',11067,222,NULL,1,16163,0);
INSERT INTO "django_geo_db_location" VALUES(27524,NULL,'McWilliams, AL',11068,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27525,NULL,'McWilliams, AL 36753',11068,222,NULL,1,16164,0);
INSERT INTO "django_geo_db_location" VALUES(27526,NULL,'Magnolia, AL',11069,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27527,NULL,'Magnolia, AL 36754',11069,222,NULL,1,16165,0);
INSERT INTO "django_geo_db_location" VALUES(27528,NULL,'Greensboro, AL 36755',11061,222,NULL,1,16166,0);
INSERT INTO "django_geo_db_location" VALUES(27529,NULL,'Marion, AL',11070,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27530,NULL,'Marion, AL 36756',11070,222,NULL,1,16167,0);
INSERT INTO "django_geo_db_location" VALUES(27531,NULL,'Plantersville, AL',11071,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27532,NULL,'Plantersville, AL 36758',11071,222,NULL,1,16168,0);
INSERT INTO "django_geo_db_location" VALUES(27533,NULL,'Marion Junction, AL',11072,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27534,NULL,'Marion Junction, AL 36759',11072,222,NULL,1,16169,0);
INSERT INTO "django_geo_db_location" VALUES(27535,NULL,'Minter, AL',11073,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27536,NULL,'Minter, AL 36761',11073,222,NULL,1,16170,0);
INSERT INTO "django_geo_db_location" VALUES(27537,NULL,'Morvin, AL',11074,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27538,NULL,'Morvin, AL 36762',11074,222,NULL,1,16171,0);
INSERT INTO "django_geo_db_location" VALUES(27539,NULL,'Myrtlewood, AL',11075,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27540,NULL,'Myrtlewood, AL 36763',11075,222,NULL,1,16172,0);
INSERT INTO "django_geo_db_location" VALUES(27541,NULL,'Nanafalia, AL',11076,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27542,NULL,'Nanafalia, AL 36764',11076,222,NULL,1,16173,0);
INSERT INTO "django_geo_db_location" VALUES(27543,NULL,'Newbern, AL',11077,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27544,NULL,'Newbern, AL 36765',11077,222,NULL,1,16174,0);
INSERT INTO "django_geo_db_location" VALUES(27545,NULL,'Oak Hill, AL',11078,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27546,NULL,'Oak Hill, AL 36766',11078,222,NULL,1,16175,0);
INSERT INTO "django_geo_db_location" VALUES(27547,NULL,'Orrville, AL',11079,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27548,NULL,'Orrville, AL 36767',11079,222,NULL,1,16176,0);
INSERT INTO "django_geo_db_location" VALUES(27549,NULL,'Pine Apple, AL',11080,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27550,NULL,'Pine Apple, AL 36768',11080,222,NULL,1,16177,0);
INSERT INTO "django_geo_db_location" VALUES(27551,NULL,'Pine Hill, AL',11081,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27552,NULL,'Pine Hill, AL 36769',11081,222,NULL,1,16178,0);
INSERT INTO "django_geo_db_location" VALUES(27553,NULL,'Safford, AL',11082,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27554,NULL,'Safford, AL 36773',11082,222,NULL,1,16179,0);
INSERT INTO "django_geo_db_location" VALUES(27555,NULL,'Sardis, AL',11083,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27556,NULL,'Sardis, AL 36775',11083,222,NULL,1,16180,0);
INSERT INTO "django_geo_db_location" VALUES(27557,NULL,'Sawyerville, AL',11084,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27558,NULL,'Sawyerville, AL 36776',11084,222,NULL,1,16181,0);
INSERT INTO "django_geo_db_location" VALUES(27559,NULL,'Snow Hill, AL',11085,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27560,NULL,'Snow Hill, AL 36778',11085,222,NULL,1,16182,0);
INSERT INTO "django_geo_db_location" VALUES(27561,NULL,'Sprott, AL',11086,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27562,NULL,'Sprott, AL 36779',11086,222,NULL,1,16183,0);
INSERT INTO "django_geo_db_location" VALUES(27563,NULL,'Sweet Water, AL',11087,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27564,NULL,'Sweet Water, AL 36782',11087,222,NULL,1,16184,0);
INSERT INTO "django_geo_db_location" VALUES(27565,NULL,'Thomaston, AL',11088,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27566,NULL,'Thomaston, AL 36783',11088,222,NULL,1,16185,0);
INSERT INTO "django_geo_db_location" VALUES(27567,NULL,'Thomasville, AL',11089,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27568,NULL,'Thomasville, AL 36784',11089,222,NULL,1,16186,0);
INSERT INTO "django_geo_db_location" VALUES(27569,NULL,'Tyler, AL',11090,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27570,NULL,'Tyler, AL 36785',11090,222,NULL,1,16187,0);
INSERT INTO "django_geo_db_location" VALUES(27571,NULL,'Uniontown, AL',11091,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27572,NULL,'Uniontown, AL 36786',11091,222,NULL,1,16188,0);
INSERT INTO "django_geo_db_location" VALUES(27573,NULL,'Stanton, AL',11092,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27574,NULL,'Stanton, AL 36790',11092,222,NULL,1,16189,0);
INSERT INTO "django_geo_db_location" VALUES(27575,NULL,'Randolph, AL',11093,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27576,NULL,'Randolph, AL 36792',11093,222,NULL,1,16190,0);
INSERT INTO "django_geo_db_location" VALUES(27577,NULL,'Lawley, AL',11094,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27578,NULL,'Lawley, AL 36793',11094,222,NULL,1,16191,0);
INSERT INTO "django_geo_db_location" VALUES(27579,NULL,'Opelika, AL',11095,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27580,NULL,'Opelika, AL 36801',11095,222,NULL,1,16192,0);
INSERT INTO "django_geo_db_location" VALUES(27581,NULL,'Opelika, AL 36802',11095,222,NULL,1,16193,0);
INSERT INTO "django_geo_db_location" VALUES(27582,NULL,'Opelika, AL 36803',11095,222,NULL,1,16194,0);
INSERT INTO "django_geo_db_location" VALUES(27583,NULL,'Opelika, AL 36804',11095,222,NULL,1,16195,0);
INSERT INTO "django_geo_db_location" VALUES(27584,NULL,'Auburn, AL',11096,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27585,NULL,'Auburn, AL 36830',11096,222,NULL,1,16196,0);
INSERT INTO "django_geo_db_location" VALUES(27586,NULL,'Auburn, AL 36831',11096,222,NULL,1,16197,0);
INSERT INTO "django_geo_db_location" VALUES(27587,NULL,'Auburn, AL 36832',11096,222,NULL,1,16198,0);
INSERT INTO "django_geo_db_location" VALUES(27588,NULL,'Auburn University, AL',11097,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27589,NULL,'Auburn University, AL 36849',11097,222,NULL,1,16199,0);
INSERT INTO "django_geo_db_location" VALUES(27590,NULL,'Camp Hill, AL',11098,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27591,NULL,'Camp Hill, AL 36850',11098,222,NULL,1,16200,0);
INSERT INTO "django_geo_db_location" VALUES(27592,NULL,'Cottonton, AL',11099,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27593,NULL,'Cottonton, AL 36851',11099,222,NULL,1,16201,0);
INSERT INTO "django_geo_db_location" VALUES(27594,NULL,'Cusseta, AL',11100,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27595,NULL,'Cusseta, AL 36852',11100,222,NULL,1,16202,0);
INSERT INTO "django_geo_db_location" VALUES(27596,NULL,'Dadeville, AL',11101,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27597,NULL,'Dadeville, AL 36853',11101,222,NULL,1,16203,0);
INSERT INTO "django_geo_db_location" VALUES(27598,NULL,'Valley, AL',11102,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27599,NULL,'Valley, AL 36854',11102,222,NULL,1,16204,0);
INSERT INTO "django_geo_db_location" VALUES(27600,NULL,'Five Points, AL',11103,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27601,NULL,'Five Points, AL 36855',11103,222,NULL,1,16205,0);
INSERT INTO "django_geo_db_location" VALUES(27602,NULL,'Fort Mitchell, AL',11104,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27603,NULL,'Fort Mitchell, AL 36856',11104,222,NULL,1,16206,0);
INSERT INTO "django_geo_db_location" VALUES(27604,NULL,'Hatchechubbee, AL',11105,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27605,NULL,'Hatchechubbee, AL 36858',11105,222,NULL,1,16207,0);
INSERT INTO "django_geo_db_location" VALUES(27606,NULL,'Holy Trinity, AL',11106,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27607,NULL,'Holy Trinity, AL 36859',11106,222,NULL,1,16208,0);
INSERT INTO "django_geo_db_location" VALUES(27608,NULL,'Hurtsboro, AL',11107,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27609,NULL,'Hurtsboro, AL 36860',11107,222,NULL,1,16209,0);
INSERT INTO "django_geo_db_location" VALUES(27610,NULL,'Jacksons Gap, AL',11108,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27611,NULL,'Jacksons Gap, AL 36861',11108,222,NULL,1,16210,0);
INSERT INTO "django_geo_db_location" VALUES(27612,NULL,'Lafayette, AL',11109,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27613,NULL,'Lafayette, AL 36862',11109,222,NULL,1,16211,0);
INSERT INTO "django_geo_db_location" VALUES(27614,NULL,'Lanett, AL 36863',10946,222,NULL,1,16212,0);
INSERT INTO "django_geo_db_location" VALUES(27615,NULL,'Loachapoka, AL',11110,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27616,NULL,'Loachapoka, AL 36865',11110,222,NULL,1,16213,0);
INSERT INTO "django_geo_db_location" VALUES(27617,NULL,'Notasulga, AL',11111,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27618,NULL,'Notasulga, AL 36866',11111,222,NULL,1,16214,0);
INSERT INTO "django_geo_db_location" VALUES(27619,NULL,'Phenix City, AL',11112,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27620,NULL,'Phenix City, AL 36867',11112,222,NULL,1,16215,0);
INSERT INTO "django_geo_db_location" VALUES(27621,NULL,'Phenix City, AL 36868',11112,222,NULL,1,16216,0);
INSERT INTO "django_geo_db_location" VALUES(27622,NULL,'Phenix City, AL 36869',11112,222,NULL,1,16217,0);
INSERT INTO "django_geo_db_location" VALUES(27623,NULL,'Phenix City, AL 36870',11112,222,NULL,1,16218,0);
INSERT INTO "django_geo_db_location" VALUES(27624,NULL,'Pittsview, AL',11113,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27625,NULL,'Pittsview, AL 36871',11113,222,NULL,1,16219,0);
INSERT INTO "django_geo_db_location" VALUES(27626,NULL,'Valley, AL 36872',11102,222,NULL,1,16220,0);
INSERT INTO "django_geo_db_location" VALUES(27627,NULL,'Salem, AL',11114,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27628,NULL,'Salem, AL 36874',11114,222,NULL,1,16221,0);
INSERT INTO "django_geo_db_location" VALUES(27629,NULL,'Seale, AL',11115,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27630,NULL,'Seale, AL 36875',11115,222,NULL,1,16222,0);
INSERT INTO "django_geo_db_location" VALUES(27631,NULL,'Uniontown, AL 36876',11091,222,NULL,1,16223,0);
INSERT INTO "django_geo_db_location" VALUES(27632,NULL,'Smiths, AL',11116,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27633,NULL,'Smiths, AL 36877',11116,222,NULL,1,16224,0);
INSERT INTO "django_geo_db_location" VALUES(27634,NULL,'Waverly, AL',11117,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27635,NULL,'Waverly, AL 36879',11117,222,NULL,1,16225,0);
INSERT INTO "django_geo_db_location" VALUES(27636,NULL,'Bellamy, AL',11118,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27637,NULL,'Bellamy, AL 36901',11118,222,NULL,1,16226,0);
INSERT INTO "django_geo_db_location" VALUES(27638,NULL,'Butler, AL',11119,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27639,NULL,'Butler, AL 36904',11119,222,NULL,1,16227,0);
INSERT INTO "django_geo_db_location" VALUES(27640,NULL,'Cromwell, AL',11120,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27641,NULL,'Cromwell, AL 36906',11120,222,NULL,1,16228,0);
INSERT INTO "django_geo_db_location" VALUES(27642,NULL,'Cuba, AL',11121,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27643,NULL,'Cuba, AL 36907',11121,222,NULL,1,16229,0);
INSERT INTO "django_geo_db_location" VALUES(27644,NULL,'Gilbertown, AL',11122,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27645,NULL,'Gilbertown, AL 36908',11122,222,NULL,1,16230,0);
INSERT INTO "django_geo_db_location" VALUES(27646,NULL,'Jachin, AL',11123,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27647,NULL,'Jachin, AL 36910',11123,222,NULL,1,16231,0);
INSERT INTO "django_geo_db_location" VALUES(27648,NULL,'Lisman, AL',11124,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27649,NULL,'Lisman, AL 36912',11124,222,NULL,1,16232,0);
INSERT INTO "django_geo_db_location" VALUES(27650,NULL,'Melvin, AL',11125,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27651,NULL,'Melvin, AL 36913',11125,222,NULL,1,16233,0);
INSERT INTO "django_geo_db_location" VALUES(27652,NULL,'Needham, AL',11126,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27653,NULL,'Needham, AL 36915',11126,222,NULL,1,16234,0);
INSERT INTO "django_geo_db_location" VALUES(27654,NULL,'Pennington, AL',11127,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27655,NULL,'Pennington, AL 36916',11127,222,NULL,1,16235,0);
INSERT INTO "django_geo_db_location" VALUES(27656,NULL,'Silas, AL',11128,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27657,NULL,'Silas, AL 36919',11128,222,NULL,1,16236,0);
INSERT INTO "django_geo_db_location" VALUES(27658,NULL,'Toxey, AL',11129,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27659,NULL,'Toxey, AL 36921',11129,222,NULL,1,16237,0);
INSERT INTO "django_geo_db_location" VALUES(27660,NULL,'Ward, AL',11130,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27661,NULL,'Ward, AL 36922',11130,222,NULL,1,16238,0);
INSERT INTO "django_geo_db_location" VALUES(27662,NULL,'York, AL',11131,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27663,NULL,'York, AL 36925',11131,222,NULL,1,16239,0);
INSERT INTO "django_geo_db_location" VALUES(27664,NULL,'Adams, TN',11132,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27665,NULL,'Adams, TN 37010',11132,222,NULL,50,16240,0);
INSERT INTO "django_geo_db_location" VALUES(27666,NULL,'Antioch, TN',11133,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27667,NULL,'Antioch, TN 37011',11133,222,NULL,50,16241,0);
INSERT INTO "django_geo_db_location" VALUES(27668,NULL,'Alexandria, TN',11134,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27669,NULL,'Alexandria, TN 37012',11134,222,NULL,50,16242,0);
INSERT INTO "django_geo_db_location" VALUES(27670,NULL,'Antioch, TN 37013',11133,222,NULL,50,16243,0);
INSERT INTO "django_geo_db_location" VALUES(27671,NULL,'Arrington, TN',11135,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27672,NULL,'Arrington, TN 37014',11135,222,NULL,50,16244,0);
INSERT INTO "django_geo_db_location" VALUES(27673,NULL,'Ashland City, TN',11136,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27674,NULL,'Ashland City, TN 37015',11136,222,NULL,50,16245,0);
INSERT INTO "django_geo_db_location" VALUES(27675,NULL,'Auburntown, TN',11137,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27676,NULL,'Auburntown, TN 37016',11137,222,NULL,50,16246,0);
INSERT INTO "django_geo_db_location" VALUES(27677,NULL,'Beechgrove, TN',11138,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27678,NULL,'Beechgrove, TN 37018',11138,222,NULL,50,16247,0);
INSERT INTO "django_geo_db_location" VALUES(27679,NULL,'Belfast, TN',11139,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27680,NULL,'Belfast, TN 37019',11139,222,NULL,50,16248,0);
INSERT INTO "django_geo_db_location" VALUES(27681,NULL,'Bell Buckle, TN',11140,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27682,NULL,'Bell Buckle, TN 37020',11140,222,NULL,50,16249,0);
INSERT INTO "django_geo_db_location" VALUES(27683,NULL,'Bethpage, TN',11141,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27684,NULL,'Bethpage, TN 37022',11141,222,NULL,50,16250,0);
INSERT INTO "django_geo_db_location" VALUES(27685,NULL,'Big Rock, TN',11142,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27686,NULL,'Big Rock, TN 37023',11142,222,NULL,50,16251,0);
INSERT INTO "django_geo_db_location" VALUES(27687,NULL,'Brentwood, TN',11143,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27688,NULL,'Brentwood, TN 37024',11143,222,NULL,50,16252,0);
INSERT INTO "django_geo_db_location" VALUES(27689,NULL,'Bon Aqua, TN',11144,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27690,NULL,'Bon Aqua, TN 37025',11144,222,NULL,50,16253,0);
INSERT INTO "django_geo_db_location" VALUES(27691,NULL,'Bradyville, TN',11145,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27692,NULL,'Bradyville, TN 37026',11145,222,NULL,50,16254,0);
INSERT INTO "django_geo_db_location" VALUES(27693,NULL,'Brentwood, TN 37027',11143,222,NULL,50,16255,0);
INSERT INTO "django_geo_db_location" VALUES(27694,NULL,'Bumpus Mills, TN',11146,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27695,NULL,'Bumpus Mills, TN 37028',11146,222,NULL,50,16256,0);
INSERT INTO "django_geo_db_location" VALUES(27696,NULL,'Burns, TN',11147,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27697,NULL,'Burns, TN 37029',11147,222,NULL,50,16257,0);
INSERT INTO "django_geo_db_location" VALUES(27698,NULL,'Carthage, TN',11148,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27699,NULL,'Carthage, TN 37030',11148,222,NULL,50,16258,0);
INSERT INTO "django_geo_db_location" VALUES(27700,NULL,'Castalian Springs, TN',11149,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27701,NULL,'Castalian Springs, TN 37031',11149,222,NULL,50,16259,0);
INSERT INTO "django_geo_db_location" VALUES(27702,NULL,'Cedar Hill, TN',11150,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27703,NULL,'Cedar Hill, TN 37032',11150,222,NULL,50,16260,0);
INSERT INTO "django_geo_db_location" VALUES(27704,NULL,'Centerville, TN',11151,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27705,NULL,'Centerville, TN 37033',11151,222,NULL,50,16261,0);
INSERT INTO "django_geo_db_location" VALUES(27706,NULL,'Chapel Hill, TN',11152,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27707,NULL,'Chapel Hill, TN 37034',11152,222,NULL,50,16262,0);
INSERT INTO "django_geo_db_location" VALUES(27708,NULL,'Chapmansboro, TN',11153,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27709,NULL,'Chapmansboro, TN 37035',11153,222,NULL,50,16263,0);
INSERT INTO "django_geo_db_location" VALUES(27710,NULL,'Charlotte, TN',11154,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27711,NULL,'Charlotte, TN 37036',11154,222,NULL,50,16264,0);
INSERT INTO "django_geo_db_location" VALUES(27712,NULL,'Christiana, TN',11155,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27713,NULL,'Christiana, TN 37037',11155,222,NULL,50,16265,0);
INSERT INTO "django_geo_db_location" VALUES(27714,NULL,'Clarksville, TN',11156,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27715,NULL,'Clarksville, TN 37040',11156,222,NULL,50,16266,0);
INSERT INTO "django_geo_db_location" VALUES(27716,NULL,'Clarksville, TN 37041',11156,222,NULL,50,16267,0);
INSERT INTO "django_geo_db_location" VALUES(27717,NULL,'Clarksville, TN 37042',11156,222,NULL,50,16268,0);
INSERT INTO "django_geo_db_location" VALUES(27718,NULL,'Clarksville, TN 37043',11156,222,NULL,50,16269,0);
INSERT INTO "django_geo_db_location" VALUES(27719,NULL,'Clarksville, TN 37044',11156,222,NULL,50,16270,0);
INSERT INTO "django_geo_db_location" VALUES(27720,NULL,'College Grove, TN',11157,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27721,NULL,'College Grove, TN 37046',11157,222,NULL,50,16271,0);
INSERT INTO "django_geo_db_location" VALUES(27722,NULL,'Cornersville, TN',11158,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27723,NULL,'Cornersville, TN 37047',11158,222,NULL,50,16272,0);
INSERT INTO "django_geo_db_location" VALUES(27724,NULL,'Cottontown, TN',11159,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27725,NULL,'Cottontown, TN 37048',11159,222,NULL,50,16273,0);
INSERT INTO "django_geo_db_location" VALUES(27726,NULL,'Cross Plains, TN',11160,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27727,NULL,'Cross Plains, TN 37049',11160,222,NULL,50,16274,0);
INSERT INTO "django_geo_db_location" VALUES(27728,NULL,'Cumberland City, TN',11161,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27729,NULL,'Cumberland City, TN 37050',11161,222,NULL,50,16275,0);
INSERT INTO "django_geo_db_location" VALUES(27730,NULL,'Cumberland Furnace, TN',11162,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27731,NULL,'Cumberland Furnace, TN 37051',11162,222,NULL,50,16276,0);
INSERT INTO "django_geo_db_location" VALUES(27732,NULL,'Cunningham, TN',11163,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27733,NULL,'Cunningham, TN 37052',11163,222,NULL,50,16277,0);
INSERT INTO "django_geo_db_location" VALUES(27734,NULL,'Dickson, TN',11164,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27735,NULL,'Dickson, TN 37055',11164,222,NULL,50,16278,0);
INSERT INTO "django_geo_db_location" VALUES(27736,NULL,'Dickson, TN 37056',11164,222,NULL,50,16279,0);
INSERT INTO "django_geo_db_location" VALUES(27737,NULL,'Dixon Springs, TN',11165,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27738,NULL,'Dixon Springs, TN 37057',11165,222,NULL,50,16280,0);
INSERT INTO "django_geo_db_location" VALUES(27739,NULL,'Dover, TN',11166,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27740,NULL,'Dover, TN 37058',11166,222,NULL,50,16281,0);
INSERT INTO "django_geo_db_location" VALUES(27741,NULL,'Dowelltown, TN',11167,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27742,NULL,'Dowelltown, TN 37059',11167,222,NULL,50,16282,0);
INSERT INTO "django_geo_db_location" VALUES(27743,NULL,'Eagleville, TN',11168,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27744,NULL,'Eagleville, TN 37060',11168,222,NULL,50,16283,0);
INSERT INTO "django_geo_db_location" VALUES(27745,NULL,'Erin, TN',11169,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27746,NULL,'Erin, TN 37061',11169,222,NULL,50,16284,0);
INSERT INTO "django_geo_db_location" VALUES(27747,NULL,'Fairview, TN',11170,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27748,NULL,'Fairview, TN 37062',11170,222,NULL,50,16285,0);
INSERT INTO "django_geo_db_location" VALUES(27749,NULL,'Fosterville, TN',11171,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27750,NULL,'Fosterville, TN 37063',11171,222,NULL,50,16286,0);
INSERT INTO "django_geo_db_location" VALUES(27751,NULL,'Franklin, TN',11172,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27752,NULL,'Franklin, TN 37064',11172,222,NULL,50,16287,0);
INSERT INTO "django_geo_db_location" VALUES(27753,NULL,'Franklin, TN 37065',11172,222,NULL,50,16288,0);
INSERT INTO "django_geo_db_location" VALUES(27754,NULL,'Gallatin, TN',11173,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27755,NULL,'Gallatin, TN 37066',11173,222,NULL,50,16289,0);
INSERT INTO "django_geo_db_location" VALUES(27756,NULL,'Franklin, TN 37067',11172,222,NULL,50,16290,0);
INSERT INTO "django_geo_db_location" VALUES(27757,NULL,'Franklin, TN 37068',11172,222,NULL,50,16291,0);
INSERT INTO "django_geo_db_location" VALUES(27758,NULL,'Franklin, TN 37069',11172,222,NULL,50,16292,0);
INSERT INTO "django_geo_db_location" VALUES(27759,NULL,'Goodlettsville, TN',11174,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27760,NULL,'Goodlettsville, TN 37070',11174,222,NULL,50,16293,0);
INSERT INTO "django_geo_db_location" VALUES(27761,NULL,'Gladeville, TN',11175,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27762,NULL,'Gladeville, TN 37071',11175,222,NULL,50,16294,0);
INSERT INTO "django_geo_db_location" VALUES(27763,NULL,'Goodlettsville, TN 37072',11174,222,NULL,50,16295,0);
INSERT INTO "django_geo_db_location" VALUES(27764,NULL,'Greenbrier, TN',11176,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27765,NULL,'Greenbrier, TN 37073',11176,222,NULL,50,16296,0);
INSERT INTO "django_geo_db_location" VALUES(27766,NULL,'Hartsville, TN',11177,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27767,NULL,'Hartsville, TN 37074',11177,222,NULL,50,16297,0);
INSERT INTO "django_geo_db_location" VALUES(27768,NULL,'Hendersonville, TN',11178,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27769,NULL,'Hendersonville, TN 37075',11178,222,NULL,50,16298,0);
INSERT INTO "django_geo_db_location" VALUES(27770,NULL,'Hermitage, TN',11179,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27771,NULL,'Hermitage, TN 37076',11179,222,NULL,50,16299,0);
INSERT INTO "django_geo_db_location" VALUES(27772,NULL,'Hendersonville, TN 37077',11178,222,NULL,50,16300,0);
INSERT INTO "django_geo_db_location" VALUES(27773,NULL,'Hurricane Mills, TN',11180,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27774,NULL,'Hurricane Mills, TN 37078',11180,222,NULL,50,16301,0);
INSERT INTO "django_geo_db_location" VALUES(27775,NULL,'Indian Mound, TN',11181,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27776,NULL,'Indian Mound, TN 37079',11181,222,NULL,50,16302,0);
INSERT INTO "django_geo_db_location" VALUES(27777,NULL,'Joelton, TN',11182,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27778,NULL,'Joelton, TN 37080',11182,222,NULL,50,16303,0);
INSERT INTO "django_geo_db_location" VALUES(27779,NULL,'Kingston Springs, TN',11183,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27780,NULL,'Kingston Springs, TN 37082',11183,222,NULL,50,16304,0);
INSERT INTO "django_geo_db_location" VALUES(27781,NULL,'Lafayette, TN',11184,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27782,NULL,'Lafayette, TN 37083',11184,222,NULL,50,16305,0);
INSERT INTO "django_geo_db_location" VALUES(27783,NULL,'Lascassas, TN',11185,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27784,NULL,'Lascassas, TN 37085',11185,222,NULL,50,16306,0);
INSERT INTO "django_geo_db_location" VALUES(27785,NULL,'La Vergne, TN',11186,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27786,NULL,'La Vergne, TN 37086',11186,222,NULL,50,16307,0);
INSERT INTO "django_geo_db_location" VALUES(27787,NULL,'Lebanon, TN',11187,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27788,NULL,'Lebanon, TN 37087',11187,222,NULL,50,16308,0);
INSERT INTO "django_geo_db_location" VALUES(27789,NULL,'Lebanon, TN 37088',11187,222,NULL,50,16309,0);
INSERT INTO "django_geo_db_location" VALUES(27790,NULL,'La Vergne, TN 37089',11186,222,NULL,50,16310,0);
INSERT INTO "django_geo_db_location" VALUES(27791,NULL,'Lebanon, TN 37090',11187,222,NULL,50,16311,0);
INSERT INTO "django_geo_db_location" VALUES(27792,NULL,'Lewisburg, TN',11188,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27793,NULL,'Lewisburg, TN 37091',11188,222,NULL,50,16312,0);
INSERT INTO "django_geo_db_location" VALUES(27794,NULL,'Liberty, TN',11189,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27795,NULL,'Liberty, TN 37095',11189,222,NULL,50,16313,0);
INSERT INTO "django_geo_db_location" VALUES(27796,NULL,'Linden, TN',11190,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27797,NULL,'Linden, TN 37096',11190,222,NULL,50,16314,0);
INSERT INTO "django_geo_db_location" VALUES(27798,NULL,'Lobelville, TN',11191,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27799,NULL,'Lobelville, TN 37097',11191,222,NULL,50,16315,0);
INSERT INTO "django_geo_db_location" VALUES(27800,NULL,'Lyles, TN',11192,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27801,NULL,'Lyles, TN 37098',11192,222,NULL,50,16316,0);
INSERT INTO "django_geo_db_location" VALUES(27802,NULL,'McEwen, TN',11193,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27803,NULL,'McEwen, TN 37101',11193,222,NULL,50,16317,0);
INSERT INTO "django_geo_db_location" VALUES(27804,NULL,'McMinnville, TN',11194,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27805,NULL,'McMinnville, TN 37110',11194,222,NULL,50,16318,0);
INSERT INTO "django_geo_db_location" VALUES(27806,NULL,'McMinnville, TN 37111',11194,222,NULL,50,16319,0);
INSERT INTO "django_geo_db_location" VALUES(27807,NULL,'Madison, TN',11195,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27808,NULL,'Madison, TN 37115',11195,222,NULL,50,16320,0);
INSERT INTO "django_geo_db_location" VALUES(27809,NULL,'Madison, TN 37116',11195,222,NULL,50,16321,0);
INSERT INTO "django_geo_db_location" VALUES(27810,NULL,'Milton, TN',11196,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27811,NULL,'Milton, TN 37118',11196,222,NULL,50,16322,0);
INSERT INTO "django_geo_db_location" VALUES(27812,NULL,'Mitchellville, TN',11197,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27813,NULL,'Mitchellville, TN 37119',11197,222,NULL,50,16323,0);
INSERT INTO "django_geo_db_location" VALUES(27814,NULL,'Mount Juliet, TN',11198,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27815,NULL,'Mount Juliet, TN 37121',11198,222,NULL,50,16324,0);
INSERT INTO "django_geo_db_location" VALUES(27816,NULL,'Mount Juliet, TN 37122',11198,222,NULL,50,16325,0);
INSERT INTO "django_geo_db_location" VALUES(27817,NULL,'Murfreesboro, TN',11199,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27818,NULL,'Murfreesboro, TN 37127',11199,222,NULL,50,16326,0);
INSERT INTO "django_geo_db_location" VALUES(27819,NULL,'Murfreesboro, TN 37128',11199,222,NULL,50,16327,0);
INSERT INTO "django_geo_db_location" VALUES(27820,NULL,'Murfreesboro, TN 37129',11199,222,NULL,50,16328,0);
INSERT INTO "django_geo_db_location" VALUES(27821,NULL,'Murfreesboro, TN 37130',11199,222,NULL,50,16329,0);
INSERT INTO "django_geo_db_location" VALUES(27822,NULL,'Murfreesboro, TN 37131',11199,222,NULL,50,16330,0);
INSERT INTO "django_geo_db_location" VALUES(27823,NULL,'Murfreesboro, TN 37132',11199,222,NULL,50,16331,0);
INSERT INTO "django_geo_db_location" VALUES(27824,NULL,'Murfreesboro, TN 37133',11199,222,NULL,50,16332,0);
INSERT INTO "django_geo_db_location" VALUES(27825,NULL,'New Johnsonville, TN',11200,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27826,NULL,'New Johnsonville, TN 37134',11200,222,NULL,50,16333,0);
INSERT INTO "django_geo_db_location" VALUES(27827,NULL,'Nolensville, TN',11201,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27828,NULL,'Nolensville, TN 37135',11201,222,NULL,50,16334,0);
INSERT INTO "django_geo_db_location" VALUES(27829,NULL,'Norene, TN',11202,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27830,NULL,'Norene, TN 37136',11202,222,NULL,50,16335,0);
INSERT INTO "django_geo_db_location" VALUES(27831,NULL,'Nunnelly, TN',11203,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27832,NULL,'Nunnelly, TN 37137',11203,222,NULL,50,16336,0);
INSERT INTO "django_geo_db_location" VALUES(27833,NULL,'Old Hickory, TN',11204,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27834,NULL,'Old Hickory, TN 37138',11204,222,NULL,50,16337,0);
INSERT INTO "django_geo_db_location" VALUES(27835,NULL,'Only, TN',11205,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27836,NULL,'Only, TN 37140',11205,222,NULL,50,16338,0);
INSERT INTO "django_geo_db_location" VALUES(27837,NULL,'Orlinda, TN',11206,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27838,NULL,'Orlinda, TN 37141',11206,222,NULL,50,16339,0);
INSERT INTO "django_geo_db_location" VALUES(27839,NULL,'Palmyra, TN',11207,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27840,NULL,'Palmyra, TN 37142',11207,222,NULL,50,16340,0);
INSERT INTO "django_geo_db_location" VALUES(27841,NULL,'Pegram, TN',11208,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27842,NULL,'Pegram, TN 37143',11208,222,NULL,50,16341,0);
INSERT INTO "django_geo_db_location" VALUES(27843,NULL,'Petersburg, TN',11209,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27844,NULL,'Petersburg, TN 37144',11209,222,NULL,50,16342,0);
INSERT INTO "django_geo_db_location" VALUES(27845,NULL,'Pleasant Shade, TN',11210,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27846,NULL,'Pleasant Shade, TN 37145',11210,222,NULL,50,16343,0);
INSERT INTO "django_geo_db_location" VALUES(27847,NULL,'Pleasant View, TN',11211,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27848,NULL,'Pleasant View, TN 37146',11211,222,NULL,50,16344,0);
INSERT INTO "django_geo_db_location" VALUES(27849,NULL,'Pleasantville, TN',11212,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27850,NULL,'Pleasantville, TN 37147',11212,222,NULL,50,16345,0);
INSERT INTO "django_geo_db_location" VALUES(27851,NULL,'Portland, TN',11213,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27852,NULL,'Portland, TN 37148',11213,222,NULL,50,16346,0);
INSERT INTO "django_geo_db_location" VALUES(27853,NULL,'Readyville, TN',11214,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27854,NULL,'Readyville, TN 37149',11214,222,NULL,50,16347,0);
INSERT INTO "django_geo_db_location" VALUES(27855,NULL,'Red Boiling Springs, TN',11215,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27856,NULL,'Red Boiling Springs, TN 37150',11215,222,NULL,50,16348,0);
INSERT INTO "django_geo_db_location" VALUES(27857,NULL,'Riddleton, TN',11216,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27858,NULL,'Riddleton, TN 37151',11216,222,NULL,50,16349,0);
INSERT INTO "django_geo_db_location" VALUES(27859,NULL,'Ridgetop, TN',11217,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27860,NULL,'Ridgetop, TN 37152',11217,222,NULL,50,16350,0);
INSERT INTO "django_geo_db_location" VALUES(27861,NULL,'Rockvale, TN',11218,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27862,NULL,'Rockvale, TN 37153',11218,222,NULL,50,16351,0);
INSERT INTO "django_geo_db_location" VALUES(27863,NULL,'Saint Bethlehem, TN',11219,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27864,NULL,'Saint Bethlehem, TN 37155',11219,222,NULL,50,16352,0);
INSERT INTO "django_geo_db_location" VALUES(27865,NULL,'Shelbyville, TN',11220,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27866,NULL,'Shelbyville, TN 37160',11220,222,NULL,50,16353,0);
INSERT INTO "django_geo_db_location" VALUES(27867,NULL,'Shelbyville, TN 37161',11220,222,NULL,50,16354,0);
INSERT INTO "django_geo_db_location" VALUES(27868,NULL,'Shelbyville, TN 37162',11220,222,NULL,50,16355,0);
INSERT INTO "django_geo_db_location" VALUES(27869,NULL,'Slayden, TN',11221,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27870,NULL,'Slayden, TN 37165',11221,222,NULL,50,16356,0);
INSERT INTO "django_geo_db_location" VALUES(27871,NULL,'Smithville, TN',11222,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27872,NULL,'Smithville, TN 37166',11222,222,NULL,50,16357,0);
INSERT INTO "django_geo_db_location" VALUES(27873,NULL,'Smyrna, TN',11223,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27874,NULL,'Smyrna, TN 37167',11223,222,NULL,50,16358,0);
INSERT INTO "django_geo_db_location" VALUES(27875,NULL,'Southside, TN',11224,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27876,NULL,'Southside, TN 37171',11224,222,NULL,50,16359,0);
INSERT INTO "django_geo_db_location" VALUES(27877,NULL,'Springfield, TN',11225,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27878,NULL,'Springfield, TN 37172',11225,222,NULL,50,16360,0);
INSERT INTO "django_geo_db_location" VALUES(27879,NULL,'Spring Hill, TN',11226,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27880,NULL,'Spring Hill, TN 37174',11226,222,NULL,50,16361,0);
INSERT INTO "django_geo_db_location" VALUES(27881,NULL,'Stewart, TN',11227,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27882,NULL,'Stewart, TN 37175',11227,222,NULL,50,16362,0);
INSERT INTO "django_geo_db_location" VALUES(27883,NULL,'Tennessee Ridge, TN',11228,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27884,NULL,'Tennessee Ridge, TN 37178',11228,222,NULL,50,16363,0);
INSERT INTO "django_geo_db_location" VALUES(27885,NULL,'Thompsons Station, TN',11229,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27886,NULL,'Thompsons Station, TN 37179',11229,222,NULL,50,16364,0);
INSERT INTO "django_geo_db_location" VALUES(27887,NULL,'Unionville, TN',11230,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27888,NULL,'Unionville, TN 37180',11230,222,NULL,50,16365,0);
INSERT INTO "django_geo_db_location" VALUES(27889,NULL,'Vanleer, TN',11231,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27890,NULL,'Vanleer, TN 37181',11231,222,NULL,50,16366,0);
INSERT INTO "django_geo_db_location" VALUES(27891,NULL,'Wartrace, TN',11232,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27892,NULL,'Wartrace, TN 37183',11232,222,NULL,50,16367,0);
INSERT INTO "django_geo_db_location" VALUES(27893,NULL,'Watertown, TN',11233,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27894,NULL,'Watertown, TN 37184',11233,222,NULL,50,16368,0);
INSERT INTO "django_geo_db_location" VALUES(27895,NULL,'Waverly, TN',11234,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27896,NULL,'Waverly, TN 37185',11234,222,NULL,50,16369,0);
INSERT INTO "django_geo_db_location" VALUES(27897,NULL,'Westmoreland, TN',11235,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27898,NULL,'Westmoreland, TN 37186',11235,222,NULL,50,16370,0);
INSERT INTO "django_geo_db_location" VALUES(27899,NULL,'White Bluff, TN',11236,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27900,NULL,'White Bluff, TN 37187',11236,222,NULL,50,16371,0);
INSERT INTO "django_geo_db_location" VALUES(27901,NULL,'White House, TN 37188',9966,222,NULL,50,16372,0);
INSERT INTO "django_geo_db_location" VALUES(27902,NULL,'Whites Creek, TN',11237,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27903,NULL,'Whites Creek, TN 37189',11237,222,NULL,50,16373,0);
INSERT INTO "django_geo_db_location" VALUES(27904,NULL,'Woodbury, TN',11238,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27905,NULL,'Woodbury, TN 37190',11238,222,NULL,50,16374,0);
INSERT INTO "django_geo_db_location" VALUES(27906,NULL,'Woodlawn, TN',11239,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27907,NULL,'Woodlawn, TN 37191',11239,222,NULL,50,16375,0);
INSERT INTO "django_geo_db_location" VALUES(27908,NULL,'Nashville, TN',11240,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27909,NULL,'Nashville, TN 37201',11240,222,NULL,50,16376,0);
INSERT INTO "django_geo_db_location" VALUES(27910,NULL,'Nashville, TN 37202',11240,222,NULL,50,16377,0);
INSERT INTO "django_geo_db_location" VALUES(27911,NULL,'Nashville, TN 37203',11240,222,NULL,50,16378,0);
INSERT INTO "django_geo_db_location" VALUES(27912,NULL,'Nashville, TN 37204',11240,222,NULL,50,16379,0);
INSERT INTO "django_geo_db_location" VALUES(27913,NULL,'Nashville, TN 37205',11240,222,NULL,50,16380,0);
INSERT INTO "django_geo_db_location" VALUES(27914,NULL,'Nashville, TN 37206',11240,222,NULL,50,16381,0);
INSERT INTO "django_geo_db_location" VALUES(27915,NULL,'Nashville, TN 37207',11240,222,NULL,50,16382,0);
INSERT INTO "django_geo_db_location" VALUES(27916,NULL,'Nashville, TN 37208',11240,222,NULL,50,16383,0);
INSERT INTO "django_geo_db_location" VALUES(27917,NULL,'Nashville, TN 37209',11240,222,NULL,50,16384,0);
INSERT INTO "django_geo_db_location" VALUES(27918,NULL,'Nashville, TN 37210',11240,222,NULL,50,16385,0);
INSERT INTO "django_geo_db_location" VALUES(27919,NULL,'Nashville, TN 37211',11240,222,NULL,50,16386,0);
INSERT INTO "django_geo_db_location" VALUES(27920,NULL,'Nashville, TN 37212',11240,222,NULL,50,16387,0);
INSERT INTO "django_geo_db_location" VALUES(27921,NULL,'Nashville, TN 37213',11240,222,NULL,50,16388,0);
INSERT INTO "django_geo_db_location" VALUES(27922,NULL,'Nashville, TN 37214',11240,222,NULL,50,16389,0);
INSERT INTO "django_geo_db_location" VALUES(27923,NULL,'Nashville, TN 37215',11240,222,NULL,50,16390,0);
INSERT INTO "django_geo_db_location" VALUES(27924,NULL,'Nashville, TN 37216',11240,222,NULL,50,16391,0);
INSERT INTO "django_geo_db_location" VALUES(27925,NULL,'Nashville, TN 37217',11240,222,NULL,50,16392,0);
INSERT INTO "django_geo_db_location" VALUES(27926,NULL,'Nashville, TN 37218',11240,222,NULL,50,16393,0);
INSERT INTO "django_geo_db_location" VALUES(27927,NULL,'Nashville, TN 37219',11240,222,NULL,50,16394,0);
INSERT INTO "django_geo_db_location" VALUES(27928,NULL,'Nashville, TN 37220',11240,222,NULL,50,16395,0);
INSERT INTO "django_geo_db_location" VALUES(27929,NULL,'Nashville, TN 37221',11240,222,NULL,50,16396,0);
INSERT INTO "django_geo_db_location" VALUES(27930,NULL,'Nashville, TN 37222',11240,222,NULL,50,16397,0);
INSERT INTO "django_geo_db_location" VALUES(27931,NULL,'Nashville, TN 37224',11240,222,NULL,50,16398,0);
INSERT INTO "django_geo_db_location" VALUES(27932,NULL,'Nashville, TN 37227',11240,222,NULL,50,16399,0);
INSERT INTO "django_geo_db_location" VALUES(27933,NULL,'Nashville, TN 37228',11240,222,NULL,50,16400,0);
INSERT INTO "django_geo_db_location" VALUES(27934,NULL,'Nashville, TN 37229',11240,222,NULL,50,16401,0);
INSERT INTO "django_geo_db_location" VALUES(27935,NULL,'Nashville, TN 37230',11240,222,NULL,50,16402,0);
INSERT INTO "django_geo_db_location" VALUES(27936,NULL,'Nashville, TN 37232',11240,222,NULL,50,16403,0);
INSERT INTO "django_geo_db_location" VALUES(27937,NULL,'Nashville, TN 37234',11240,222,NULL,50,16404,0);
INSERT INTO "django_geo_db_location" VALUES(27938,NULL,'Nashville, TN 37235',11240,222,NULL,50,16405,0);
INSERT INTO "django_geo_db_location" VALUES(27939,NULL,'Nashville, TN 37236',11240,222,NULL,50,16406,0);
INSERT INTO "django_geo_db_location" VALUES(27940,NULL,'Nashville, TN 37237',11240,222,NULL,50,16407,0);
INSERT INTO "django_geo_db_location" VALUES(27941,NULL,'Nashville, TN 37238',11240,222,NULL,50,16408,0);
INSERT INTO "django_geo_db_location" VALUES(27942,NULL,'Nashville, TN 37239',11240,222,NULL,50,16409,0);
INSERT INTO "django_geo_db_location" VALUES(27943,NULL,'Nashville, TN 37240',11240,222,NULL,50,16410,0);
INSERT INTO "django_geo_db_location" VALUES(27944,NULL,'Nashville, TN 37241',11240,222,NULL,50,16411,0);
INSERT INTO "django_geo_db_location" VALUES(27945,NULL,'Nashville, TN 37242',11240,222,NULL,50,16412,0);
INSERT INTO "django_geo_db_location" VALUES(27946,NULL,'Nashville, TN 37243',11240,222,NULL,50,16413,0);
INSERT INTO "django_geo_db_location" VALUES(27947,NULL,'Nashville, TN 37244',11240,222,NULL,50,16414,0);
INSERT INTO "django_geo_db_location" VALUES(27948,NULL,'Nashville, TN 37245',11240,222,NULL,50,16415,0);
INSERT INTO "django_geo_db_location" VALUES(27949,NULL,'Nashville, TN 37246',11240,222,NULL,50,16416,0);
INSERT INTO "django_geo_db_location" VALUES(27950,NULL,'Nashville, TN 37247',11240,222,NULL,50,16417,0);
INSERT INTO "django_geo_db_location" VALUES(27951,NULL,'Nashville, TN 37248',11240,222,NULL,50,16418,0);
INSERT INTO "django_geo_db_location" VALUES(27952,NULL,'Nashville, TN 37249',11240,222,NULL,50,16419,0);
INSERT INTO "django_geo_db_location" VALUES(27953,NULL,'Nashville, TN 37250',11240,222,NULL,50,16420,0);
INSERT INTO "django_geo_db_location" VALUES(27954,NULL,'Altamont, TN',11241,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27955,NULL,'Altamont, TN 37301',11241,222,NULL,50,16421,0);
INSERT INTO "django_geo_db_location" VALUES(27956,NULL,'Apison, TN',11242,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27957,NULL,'Apison, TN 37302',11242,222,NULL,50,16422,0);
INSERT INTO "django_geo_db_location" VALUES(27958,NULL,'Athens, TN',11243,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27959,NULL,'Athens, TN 37303',11243,222,NULL,50,16423,0);
INSERT INTO "django_geo_db_location" VALUES(27960,NULL,'Bakewell, TN',11244,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27961,NULL,'Bakewell, TN 37304',11244,222,NULL,50,16424,0);
INSERT INTO "django_geo_db_location" VALUES(27962,NULL,'Beersheba Springs, TN',11245,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27963,NULL,'Beersheba Springs, TN 37305',11245,222,NULL,50,16425,0);
INSERT INTO "django_geo_db_location" VALUES(27964,NULL,'Belvidere, TN',11246,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27965,NULL,'Belvidere, TN 37306',11246,222,NULL,50,16426,0);
INSERT INTO "django_geo_db_location" VALUES(27966,NULL,'Benton, TN',11247,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27967,NULL,'Benton, TN 37307',11247,222,NULL,50,16427,0);
INSERT INTO "django_geo_db_location" VALUES(27968,NULL,'Birchwood, TN',11248,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27969,NULL,'Birchwood, TN 37308',11248,222,NULL,50,16428,0);
INSERT INTO "django_geo_db_location" VALUES(27970,NULL,'Calhoun, TN',11249,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27971,NULL,'Calhoun, TN 37309',11249,222,NULL,50,16429,0);
INSERT INTO "django_geo_db_location" VALUES(27972,NULL,'Charleston, TN',11250,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27973,NULL,'Charleston, TN 37310',11250,222,NULL,50,16430,0);
INSERT INTO "django_geo_db_location" VALUES(27974,NULL,'Cleveland, TN',11251,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27975,NULL,'Cleveland, TN 37311',11251,222,NULL,50,16431,0);
INSERT INTO "django_geo_db_location" VALUES(27976,NULL,'Cleveland, TN 37312',11251,222,NULL,50,16432,0);
INSERT INTO "django_geo_db_location" VALUES(27977,NULL,'Coalmont, TN',11252,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27978,NULL,'Coalmont, TN 37313',11252,222,NULL,50,16433,0);
INSERT INTO "django_geo_db_location" VALUES(27979,NULL,'Cokercreek, TN',11253,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27980,NULL,'Cokercreek, TN 37314',11253,222,NULL,50,16434,0);
INSERT INTO "django_geo_db_location" VALUES(27981,NULL,'Collegedale, TN',11254,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27982,NULL,'Collegedale, TN 37315',11254,222,NULL,50,16435,0);
INSERT INTO "django_geo_db_location" VALUES(27983,NULL,'Conasauga, TN',11255,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27984,NULL,'Conasauga, TN 37316',11255,222,NULL,50,16436,0);
INSERT INTO "django_geo_db_location" VALUES(27985,NULL,'Copperhill, TN',11256,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27986,NULL,'Copperhill, TN 37317',11256,222,NULL,50,16437,0);
INSERT INTO "django_geo_db_location" VALUES(27987,NULL,'Cowan, TN',11257,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27988,NULL,'Cowan, TN 37318',11257,222,NULL,50,16438,0);
INSERT INTO "django_geo_db_location" VALUES(27989,NULL,'Cleveland, TN 37320',11251,222,NULL,50,16439,0);
INSERT INTO "django_geo_db_location" VALUES(27990,NULL,'Dayton, TN',11258,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27991,NULL,'Dayton, TN 37321',11258,222,NULL,50,16440,0);
INSERT INTO "django_geo_db_location" VALUES(27992,NULL,'Decatur, TN',11259,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27993,NULL,'Decatur, TN 37322',11259,222,NULL,50,16441,0);
INSERT INTO "django_geo_db_location" VALUES(27994,NULL,'Cleveland, TN 37323',11251,222,NULL,50,16442,0);
INSERT INTO "django_geo_db_location" VALUES(27995,NULL,'Decherd, TN',11260,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27996,NULL,'Decherd, TN 37324',11260,222,NULL,50,16443,0);
INSERT INTO "django_geo_db_location" VALUES(27997,NULL,'Delano, TN',11261,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(27998,NULL,'Delano, TN 37325',11261,222,NULL,50,16444,0);
INSERT INTO "django_geo_db_location" VALUES(27999,NULL,'Ducktown, TN',11262,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28000,NULL,'Ducktown, TN 37326',11262,222,NULL,50,16445,0);
INSERT INTO "django_geo_db_location" VALUES(28001,NULL,'Dunlap, TN',11263,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28002,NULL,'Dunlap, TN 37327',11263,222,NULL,50,16446,0);
INSERT INTO "django_geo_db_location" VALUES(28003,NULL,'Elora, TN',11264,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28004,NULL,'Elora, TN 37328',11264,222,NULL,50,16447,0);
INSERT INTO "django_geo_db_location" VALUES(28005,NULL,'Englewood, TN',11265,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28006,NULL,'Englewood, TN 37329',11265,222,NULL,50,16448,0);
INSERT INTO "django_geo_db_location" VALUES(28007,NULL,'Estill Springs, TN',11266,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28008,NULL,'Estill Springs, TN 37330',11266,222,NULL,50,16449,0);
INSERT INTO "django_geo_db_location" VALUES(28009,NULL,'Etowah, TN',11267,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28010,NULL,'Etowah, TN 37331',11267,222,NULL,50,16450,0);
INSERT INTO "django_geo_db_location" VALUES(28011,NULL,'Evensville, TN',11268,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28012,NULL,'Evensville, TN 37332',11268,222,NULL,50,16451,0);
INSERT INTO "django_geo_db_location" VALUES(28013,NULL,'Farner, TN',11269,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28014,NULL,'Farner, TN 37333',11269,222,NULL,50,16452,0);
INSERT INTO "django_geo_db_location" VALUES(28015,NULL,'Fayetteville, TN',11270,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28016,NULL,'Fayetteville, TN 37334',11270,222,NULL,50,16453,0);
INSERT INTO "django_geo_db_location" VALUES(28017,NULL,'Flintville, TN',11271,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28018,NULL,'Flintville, TN 37335',11271,222,NULL,50,16454,0);
INSERT INTO "django_geo_db_location" VALUES(28019,NULL,'Georgetown, TN',11272,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28020,NULL,'Georgetown, TN 37336',11272,222,NULL,50,16455,0);
INSERT INTO "django_geo_db_location" VALUES(28021,NULL,'Grandview, TN',11273,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28022,NULL,'Grandview, TN 37337',11273,222,NULL,50,16456,0);
INSERT INTO "django_geo_db_location" VALUES(28023,NULL,'Graysville, TN',11274,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28024,NULL,'Graysville, TN 37338',11274,222,NULL,50,16457,0);
INSERT INTO "django_geo_db_location" VALUES(28025,NULL,'Gruetli Laager, TN',11275,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28026,NULL,'Gruetli Laager, TN 37339',11275,222,NULL,50,16458,0);
INSERT INTO "django_geo_db_location" VALUES(28027,NULL,'Guild, TN',11276,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28028,NULL,'Guild, TN 37340',11276,222,NULL,50,16459,0);
INSERT INTO "django_geo_db_location" VALUES(28029,NULL,'Harrison, TN',11277,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28030,NULL,'Harrison, TN 37341',11277,222,NULL,50,16460,0);
INSERT INTO "django_geo_db_location" VALUES(28031,NULL,'Hillsboro, TN',11278,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28032,NULL,'Hillsboro, TN 37342',11278,222,NULL,50,16461,0);
INSERT INTO "django_geo_db_location" VALUES(28033,NULL,'Hixson, TN',11279,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28034,NULL,'Hixson, TN 37343',11279,222,NULL,50,16462,0);
INSERT INTO "django_geo_db_location" VALUES(28035,NULL,'Huntland, TN',11280,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28036,NULL,'Huntland, TN 37345',11280,222,NULL,50,16463,0);
INSERT INTO "django_geo_db_location" VALUES(28037,NULL,'Jasper, TN',11281,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28038,NULL,'Jasper, TN 37347',11281,222,NULL,50,16464,0);
INSERT INTO "django_geo_db_location" VALUES(28039,NULL,'Kelso, TN',11282,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28040,NULL,'Kelso, TN 37348',11282,222,NULL,50,16465,0);
INSERT INTO "django_geo_db_location" VALUES(28041,NULL,'Manchester, TN',11283,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28042,NULL,'Manchester, TN 37349',11283,222,NULL,50,16466,0);
INSERT INTO "django_geo_db_location" VALUES(28043,NULL,'Lookout Mountain, TN',11284,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28044,NULL,'Lookout Mountain, TN 37350',11284,222,NULL,50,16467,0);
INSERT INTO "django_geo_db_location" VALUES(28045,NULL,'Lupton City, TN',11285,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28046,NULL,'Lupton City, TN 37351',11285,222,NULL,50,16468,0);
INSERT INTO "django_geo_db_location" VALUES(28047,NULL,'Lynchburg, TN',11286,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28048,NULL,'Lynchburg, TN 37352',11286,222,NULL,50,16469,0);
INSERT INTO "django_geo_db_location" VALUES(28049,NULL,'McDonald, TN',11287,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28050,NULL,'McDonald, TN 37353',11287,222,NULL,50,16470,0);
INSERT INTO "django_geo_db_location" VALUES(28051,NULL,'Madisonville, TN',11288,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28052,NULL,'Madisonville, TN 37354',11288,222,NULL,50,16471,0);
INSERT INTO "django_geo_db_location" VALUES(28053,NULL,'Manchester, TN 37355',11283,222,NULL,50,16472,0);
INSERT INTO "django_geo_db_location" VALUES(28054,NULL,'Monteagle, TN',11289,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28055,NULL,'Monteagle, TN 37356',11289,222,NULL,50,16473,0);
INSERT INTO "django_geo_db_location" VALUES(28056,NULL,'Morrison, TN',11290,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28057,NULL,'Morrison, TN 37357',11290,222,NULL,50,16474,0);
INSERT INTO "django_geo_db_location" VALUES(28058,NULL,'Mulberry, TN',11291,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28059,NULL,'Mulberry, TN 37359',11291,222,NULL,50,16475,0);
INSERT INTO "django_geo_db_location" VALUES(28060,NULL,'Normandy, TN',11292,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28061,NULL,'Normandy, TN 37360',11292,222,NULL,50,16476,0);
INSERT INTO "django_geo_db_location" VALUES(28062,NULL,'Ocoee, TN',11293,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28063,NULL,'Ocoee, TN 37361',11293,222,NULL,50,16477,0);
INSERT INTO "django_geo_db_location" VALUES(28064,NULL,'Oldfort, TN',11294,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28065,NULL,'Oldfort, TN 37362',11294,222,NULL,50,16478,0);
INSERT INTO "django_geo_db_location" VALUES(28066,NULL,'Ooltewah, TN',11295,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28067,NULL,'Ooltewah, TN 37363',11295,222,NULL,50,16479,0);
INSERT INTO "django_geo_db_location" VALUES(28068,NULL,'Cleveland, TN 37364',11251,222,NULL,50,16480,0);
INSERT INTO "django_geo_db_location" VALUES(28069,NULL,'Palmer, TN',11296,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28070,NULL,'Palmer, TN 37365',11296,222,NULL,50,16481,0);
INSERT INTO "django_geo_db_location" VALUES(28071,NULL,'Pelham, TN',11297,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28072,NULL,'Pelham, TN 37366',11297,222,NULL,50,16482,0);
INSERT INTO "django_geo_db_location" VALUES(28073,NULL,'Pikeville, TN',11298,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28074,NULL,'Pikeville, TN 37367',11298,222,NULL,50,16483,0);
INSERT INTO "django_geo_db_location" VALUES(28075,NULL,'Reliance, TN',11299,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28076,NULL,'Reliance, TN 37369',11299,222,NULL,50,16484,0);
INSERT INTO "django_geo_db_location" VALUES(28077,NULL,'Riceville, TN',11300,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28078,NULL,'Riceville, TN 37370',11300,222,NULL,50,16485,0);
INSERT INTO "django_geo_db_location" VALUES(28079,NULL,'Athens, TN 37371',11243,222,NULL,50,16486,0);
INSERT INTO "django_geo_db_location" VALUES(28080,NULL,'Saint Andrews, TN',11301,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28081,NULL,'Saint Andrews, TN 37372',11301,222,NULL,50,16487,0);
INSERT INTO "django_geo_db_location" VALUES(28082,NULL,'Sale Creek, TN',11302,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28083,NULL,'Sale Creek, TN 37373',11302,222,NULL,50,16488,0);
INSERT INTO "django_geo_db_location" VALUES(28084,NULL,'Sequatchie, TN',11303,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28085,NULL,'Sequatchie, TN 37374',11303,222,NULL,50,16489,0);
INSERT INTO "django_geo_db_location" VALUES(28086,NULL,'Sewanee, TN',11304,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28087,NULL,'Sewanee, TN 37375',11304,222,NULL,50,16490,0);
INSERT INTO "django_geo_db_location" VALUES(28088,NULL,'Sherwood, TN',11305,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28089,NULL,'Sherwood, TN 37376',11305,222,NULL,50,16491,0);
INSERT INTO "django_geo_db_location" VALUES(28090,NULL,'Signal Mountain, TN',11306,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28091,NULL,'Signal Mountain, TN 37377',11306,222,NULL,50,16492,0);
INSERT INTO "django_geo_db_location" VALUES(28092,NULL,'Smartt, TN',11307,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28093,NULL,'Smartt, TN 37378',11307,222,NULL,50,16493,0);
INSERT INTO "django_geo_db_location" VALUES(28094,NULL,'Soddy Daisy, TN',11308,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28095,NULL,'Soddy Daisy, TN 37379',11308,222,NULL,50,16494,0);
INSERT INTO "django_geo_db_location" VALUES(28096,NULL,'South Pittsburg, TN',11309,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28097,NULL,'South Pittsburg, TN 37380',11309,222,NULL,50,16495,0);
INSERT INTO "django_geo_db_location" VALUES(28098,NULL,'Spring City, TN',11310,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28099,NULL,'Spring City, TN 37381',11310,222,NULL,50,16496,0);
INSERT INTO "django_geo_db_location" VALUES(28100,NULL,'Summitville, TN',11311,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28101,NULL,'Summitville, TN 37382',11311,222,NULL,50,16497,0);
INSERT INTO "django_geo_db_location" VALUES(28102,NULL,'Sewanee, TN 37383',11304,222,NULL,50,16498,0);
INSERT INTO "django_geo_db_location" VALUES(28103,NULL,'Soddy Daisy, TN 37384',11308,222,NULL,50,16499,0);
INSERT INTO "django_geo_db_location" VALUES(28104,NULL,'Tellico Plains, TN',11312,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28105,NULL,'Tellico Plains, TN 37385',11312,222,NULL,50,16500,0);
INSERT INTO "django_geo_db_location" VALUES(28106,NULL,'Tracy City, TN',11313,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28107,NULL,'Tracy City, TN 37387',11313,222,NULL,50,16501,0);
INSERT INTO "django_geo_db_location" VALUES(28108,NULL,'Tullahoma, TN',11314,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28109,NULL,'Tullahoma, TN 37388',11314,222,NULL,50,16502,0);
INSERT INTO "django_geo_db_location" VALUES(28110,NULL,'Arnold AFB, TN',11315,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28111,NULL,'Arnold AFB, TN 37389',11315,222,NULL,50,16503,0);
INSERT INTO "django_geo_db_location" VALUES(28112,NULL,'Turtletown, TN',11316,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28113,NULL,'Turtletown, TN 37391',11316,222,NULL,50,16504,0);
INSERT INTO "django_geo_db_location" VALUES(28114,NULL,'Viola, TN',11317,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28115,NULL,'Viola, TN 37394',11317,222,NULL,50,16505,0);
INSERT INTO "django_geo_db_location" VALUES(28116,NULL,'Watts Bar Dam, TN',11318,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28117,NULL,'Watts Bar Dam, TN 37395',11318,222,NULL,50,16506,0);
INSERT INTO "django_geo_db_location" VALUES(28118,NULL,'Whiteside, TN',11319,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28119,NULL,'Whiteside, TN 37396',11319,222,NULL,50,16507,0);
INSERT INTO "django_geo_db_location" VALUES(28120,NULL,'Whitwell, TN',11320,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28121,NULL,'Whitwell, TN 37397',11320,222,NULL,50,16508,0);
INSERT INTO "django_geo_db_location" VALUES(28122,NULL,'Winchester, TN',11321,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28123,NULL,'Winchester, TN 37398',11321,222,NULL,50,16509,0);
INSERT INTO "django_geo_db_location" VALUES(28124,NULL,'Chattanooga, TN',11322,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28125,NULL,'Chattanooga, TN 37401',11322,222,NULL,50,16510,0);
INSERT INTO "django_geo_db_location" VALUES(28126,NULL,'Chattanooga, TN 37402',11322,222,NULL,50,16511,0);
INSERT INTO "django_geo_db_location" VALUES(28127,NULL,'Chattanooga, TN 37403',11322,222,NULL,50,16512,0);
INSERT INTO "django_geo_db_location" VALUES(28128,NULL,'Chattanooga, TN 37404',11322,222,NULL,50,16513,0);
INSERT INTO "django_geo_db_location" VALUES(28129,NULL,'Chattanooga, TN 37405',11322,222,NULL,50,16514,0);
INSERT INTO "django_geo_db_location" VALUES(28130,NULL,'Chattanooga, TN 37406',11322,222,NULL,50,16515,0);
INSERT INTO "django_geo_db_location" VALUES(28131,NULL,'Chattanooga, TN 37407',11322,222,NULL,50,16516,0);
INSERT INTO "django_geo_db_location" VALUES(28132,NULL,'Chattanooga, TN 37408',11322,222,NULL,50,16517,0);
INSERT INTO "django_geo_db_location" VALUES(28133,NULL,'Chattanooga, TN 37409',11322,222,NULL,50,16518,0);
INSERT INTO "django_geo_db_location" VALUES(28134,NULL,'Chattanooga, TN 37410',11322,222,NULL,50,16519,0);
INSERT INTO "django_geo_db_location" VALUES(28135,NULL,'Chattanooga, TN 37411',11322,222,NULL,50,16520,0);
INSERT INTO "django_geo_db_location" VALUES(28136,NULL,'Chattanooga, TN 37412',11322,222,NULL,50,16521,0);
INSERT INTO "django_geo_db_location" VALUES(28137,NULL,'Chattanooga, TN 37414',11322,222,NULL,50,16522,0);
INSERT INTO "django_geo_db_location" VALUES(28138,NULL,'Chattanooga, TN 37415',11322,222,NULL,50,16523,0);
INSERT INTO "django_geo_db_location" VALUES(28139,NULL,'Chattanooga, TN 37416',11322,222,NULL,50,16524,0);
INSERT INTO "django_geo_db_location" VALUES(28140,NULL,'Chattanooga, TN 37419',11322,222,NULL,50,16525,0);
INSERT INTO "django_geo_db_location" VALUES(28141,NULL,'Chattanooga, TN 37421',11322,222,NULL,50,16526,0);
INSERT INTO "django_geo_db_location" VALUES(28142,NULL,'Chattanooga, TN 37422',11322,222,NULL,50,16527,0);
INSERT INTO "django_geo_db_location" VALUES(28143,NULL,'Chattanooga, TN 37424',11322,222,NULL,50,16528,0);
INSERT INTO "django_geo_db_location" VALUES(28144,NULL,'Chattanooga, TN 37450',11322,222,NULL,50,16529,0);
INSERT INTO "django_geo_db_location" VALUES(28145,NULL,'Chattanooga, TN 37499',11322,222,NULL,50,16530,0);
INSERT INTO "django_geo_db_location" VALUES(28146,NULL,'Memphis, TN',11323,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28147,NULL,'Memphis, TN 37501',11323,222,NULL,50,16531,0);
INSERT INTO "django_geo_db_location" VALUES(28148,NULL,'Johnson City, TN',11324,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28149,NULL,'Johnson City, TN 37601',11324,222,NULL,50,16532,0);
INSERT INTO "django_geo_db_location" VALUES(28150,NULL,'Johnson City, TN 37602',11324,222,NULL,50,16533,0);
INSERT INTO "django_geo_db_location" VALUES(28151,NULL,'Johnson City, TN 37604',11324,222,NULL,50,16534,0);
INSERT INTO "django_geo_db_location" VALUES(28152,NULL,'Johnson City, TN 37605',11324,222,NULL,50,16535,0);
INSERT INTO "django_geo_db_location" VALUES(28153,NULL,'Johnson City, TN 37614',11324,222,NULL,50,16536,0);
INSERT INTO "django_geo_db_location" VALUES(28154,NULL,'Johnson City, TN 37615',11324,222,NULL,50,16537,0);
INSERT INTO "django_geo_db_location" VALUES(28155,NULL,'Afton, TN',11325,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28156,NULL,'Afton, TN 37616',11325,222,NULL,50,16538,0);
INSERT INTO "django_geo_db_location" VALUES(28157,NULL,'Blountville, TN',11326,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28158,NULL,'Blountville, TN 37617',11326,222,NULL,50,16539,0);
INSERT INTO "django_geo_db_location" VALUES(28159,NULL,'Bluff City, TN',11327,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28160,NULL,'Bluff City, TN 37618',11327,222,NULL,50,16540,0);
INSERT INTO "django_geo_db_location" VALUES(28161,NULL,'Bristol, TN',11328,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28162,NULL,'Bristol, TN 37620',11328,222,NULL,50,16541,0);
INSERT INTO "django_geo_db_location" VALUES(28163,NULL,'Bristol, TN 37621',11328,222,NULL,50,16542,0);
INSERT INTO "django_geo_db_location" VALUES(28164,NULL,'Bristol, TN 37625',11328,222,NULL,50,16543,0);
INSERT INTO "django_geo_db_location" VALUES(28165,NULL,'Butler, TN',11329,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28166,NULL,'Butler, TN 37640',11329,222,NULL,50,16544,0);
INSERT INTO "django_geo_db_location" VALUES(28167,NULL,'Chuckey, TN',11330,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28168,NULL,'Chuckey, TN 37641',11330,222,NULL,50,16545,0);
INSERT INTO "django_geo_db_location" VALUES(28169,NULL,'Church Hill, TN',11331,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28170,NULL,'Church Hill, TN 37642',11331,222,NULL,50,16546,0);
INSERT INTO "django_geo_db_location" VALUES(28171,NULL,'Elizabethton, TN',11332,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28172,NULL,'Elizabethton, TN 37643',11332,222,NULL,50,16547,0);
INSERT INTO "django_geo_db_location" VALUES(28173,NULL,'Elizabethton, TN 37644',11332,222,NULL,50,16548,0);
INSERT INTO "django_geo_db_location" VALUES(28174,NULL,'Mount Carmel, TN',11333,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28175,NULL,'Mount Carmel, TN 37645',11333,222,NULL,50,16549,0);
INSERT INTO "django_geo_db_location" VALUES(28176,NULL,'Erwin, TN',11334,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28177,NULL,'Erwin, TN 37650',11334,222,NULL,50,16550,0);
INSERT INTO "django_geo_db_location" VALUES(28178,NULL,'Fall Branch, TN',11335,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28179,NULL,'Fall Branch, TN 37656',11335,222,NULL,50,16551,0);
INSERT INTO "django_geo_db_location" VALUES(28180,NULL,'Flag Pond, TN',11336,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28181,NULL,'Flag Pond, TN 37657',11336,222,NULL,50,16552,0);
INSERT INTO "django_geo_db_location" VALUES(28182,NULL,'Hampton, TN',11337,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28183,NULL,'Hampton, TN 37658',11337,222,NULL,50,16553,0);
INSERT INTO "django_geo_db_location" VALUES(28184,NULL,'Jonesborough, TN',11338,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28185,NULL,'Jonesborough, TN 37659',11338,222,NULL,50,16554,0);
INSERT INTO "django_geo_db_location" VALUES(28186,NULL,'Kingsport, TN',11339,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28187,NULL,'Kingsport, TN 37660',11339,222,NULL,50,16555,0);
INSERT INTO "django_geo_db_location" VALUES(28188,NULL,'Kingsport, TN 37662',11339,222,NULL,50,16556,0);
INSERT INTO "django_geo_db_location" VALUES(28189,NULL,'Kingsport, TN 37663',11339,222,NULL,50,16557,0);
INSERT INTO "django_geo_db_location" VALUES(28190,NULL,'Kingsport, TN 37664',11339,222,NULL,50,16558,0);
INSERT INTO "django_geo_db_location" VALUES(28191,NULL,'Kingsport, TN 37665',11339,222,NULL,50,16559,0);
INSERT INTO "django_geo_db_location" VALUES(28192,NULL,'Kingsport, TN 37669',11339,222,NULL,50,16560,0);
INSERT INTO "django_geo_db_location" VALUES(28193,NULL,'Laurel Bloomery, TN',11340,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28194,NULL,'Laurel Bloomery, TN 37680',11340,222,NULL,50,16561,0);
INSERT INTO "django_geo_db_location" VALUES(28195,NULL,'Limestone, TN',11341,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28196,NULL,'Limestone, TN 37681',11341,222,NULL,50,16562,0);
INSERT INTO "django_geo_db_location" VALUES(28197,NULL,'Milligan College, TN',11342,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28198,NULL,'Milligan College, TN 37682',11342,222,NULL,50,16563,0);
INSERT INTO "django_geo_db_location" VALUES(28199,NULL,'Mountain City, TN',11343,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28200,NULL,'Mountain City, TN 37683',11343,222,NULL,50,16564,0);
INSERT INTO "django_geo_db_location" VALUES(28201,NULL,'Mountain Home, TN',11344,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28202,NULL,'Mountain Home, TN 37684',11344,222,NULL,50,16565,0);
INSERT INTO "django_geo_db_location" VALUES(28203,NULL,'Piney Flats, TN',11345,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28204,NULL,'Piney Flats, TN 37686',11345,222,NULL,50,16566,0);
INSERT INTO "django_geo_db_location" VALUES(28205,NULL,'Roan Mountain, TN',11346,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28206,NULL,'Roan Mountain, TN 37687',11346,222,NULL,50,16567,0);
INSERT INTO "django_geo_db_location" VALUES(28207,NULL,'Shady Valley, TN',11347,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28208,NULL,'Shady Valley, TN 37688',11347,222,NULL,50,16568,0);
INSERT INTO "django_geo_db_location" VALUES(28209,NULL,'Telford, TN',11348,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28210,NULL,'Telford, TN 37690',11348,222,NULL,50,16569,0);
INSERT INTO "django_geo_db_location" VALUES(28211,NULL,'Trade, TN',11349,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28212,NULL,'Trade, TN 37691',11349,222,NULL,50,16570,0);
INSERT INTO "django_geo_db_location" VALUES(28213,NULL,'Unicoi, TN',11350,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28214,NULL,'Unicoi, TN 37692',11350,222,NULL,50,16571,0);
INSERT INTO "django_geo_db_location" VALUES(28215,NULL,'Watauga, TN',11351,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28216,NULL,'Watauga, TN 37694',11351,222,NULL,50,16572,0);
INSERT INTO "django_geo_db_location" VALUES(28217,NULL,'Piney Flats, TN 37699',11345,222,NULL,50,16573,0);
INSERT INTO "django_geo_db_location" VALUES(28218,NULL,'Alcoa, TN',11352,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28219,NULL,'Alcoa, TN 37701',11352,222,NULL,50,16574,0);
INSERT INTO "django_geo_db_location" VALUES(28220,NULL,'Andersonville, TN',11353,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28221,NULL,'Andersonville, TN 37705',11353,222,NULL,50,16575,0);
INSERT INTO "django_geo_db_location" VALUES(28222,NULL,'Arthur, TN',11354,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28223,NULL,'Arthur, TN 37707',11354,222,NULL,50,16576,0);
INSERT INTO "django_geo_db_location" VALUES(28224,NULL,'Bean Station, TN',11355,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28225,NULL,'Bean Station, TN 37708',11355,222,NULL,50,16577,0);
INSERT INTO "django_geo_db_location" VALUES(28226,NULL,'Blaine, TN',11356,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28227,NULL,'Blaine, TN 37709',11356,222,NULL,50,16578,0);
INSERT INTO "django_geo_db_location" VALUES(28228,NULL,'Briceville, TN',11357,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28229,NULL,'Briceville, TN 37710',11357,222,NULL,50,16579,0);
INSERT INTO "django_geo_db_location" VALUES(28230,NULL,'Bulls Gap, TN',11358,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28231,NULL,'Bulls Gap, TN 37711',11358,222,NULL,50,16580,0);
INSERT INTO "django_geo_db_location" VALUES(28232,NULL,'Bybee, TN',11359,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28233,NULL,'Bybee, TN 37713',11359,222,NULL,50,16581,0);
INSERT INTO "django_geo_db_location" VALUES(28234,NULL,'Caryville, TN',11360,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28235,NULL,'Caryville, TN 37714',11360,222,NULL,50,16582,0);
INSERT INTO "django_geo_db_location" VALUES(28236,NULL,'Clairfield, TN',11361,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28237,NULL,'Clairfield, TN 37715',11361,222,NULL,50,16583,0);
INSERT INTO "django_geo_db_location" VALUES(28238,NULL,'Clinton, TN',11362,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28239,NULL,'Clinton, TN 37716',11362,222,NULL,50,16584,0);
INSERT INTO "django_geo_db_location" VALUES(28240,NULL,'Clinton, TN 37717',11362,222,NULL,50,16585,0);
INSERT INTO "django_geo_db_location" VALUES(28241,NULL,'Coalfield, TN',11363,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28242,NULL,'Coalfield, TN 37719',11363,222,NULL,50,16586,0);
INSERT INTO "django_geo_db_location" VALUES(28243,NULL,'Corryton, TN',11364,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28244,NULL,'Corryton, TN 37721',11364,222,NULL,50,16587,0);
INSERT INTO "django_geo_db_location" VALUES(28245,NULL,'Cosby, TN',11365,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28246,NULL,'Cosby, TN 37722',11365,222,NULL,50,16588,0);
INSERT INTO "django_geo_db_location" VALUES(28247,NULL,'Crab Orchard, TN',11366,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28248,NULL,'Crab Orchard, TN 37723',11366,222,NULL,50,16589,0);
INSERT INTO "django_geo_db_location" VALUES(28249,NULL,'Cumberland Gap, TN',11367,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28250,NULL,'Cumberland Gap, TN 37724',11367,222,NULL,50,16590,0);
INSERT INTO "django_geo_db_location" VALUES(28251,NULL,'Dandridge, TN',11368,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28252,NULL,'Dandridge, TN 37725',11368,222,NULL,50,16591,0);
INSERT INTO "django_geo_db_location" VALUES(28253,NULL,'Deer Lodge, TN',11369,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28254,NULL,'Deer Lodge, TN 37726',11369,222,NULL,50,16592,0);
INSERT INTO "django_geo_db_location" VALUES(28255,NULL,'Del Rio, TN',11370,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28256,NULL,'Del Rio, TN 37727',11370,222,NULL,50,16593,0);
INSERT INTO "django_geo_db_location" VALUES(28257,NULL,'Duff, TN',11371,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28258,NULL,'Duff, TN 37729',11371,222,NULL,50,16594,0);
INSERT INTO "django_geo_db_location" VALUES(28259,NULL,'Eagan, TN',11372,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28260,NULL,'Eagan, TN 37730',11372,222,NULL,50,16595,0);
INSERT INTO "django_geo_db_location" VALUES(28261,NULL,'Eidson, TN',11373,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28262,NULL,'Eidson, TN 37731',11373,222,NULL,50,16596,0);
INSERT INTO "django_geo_db_location" VALUES(28263,NULL,'Elgin, TN',11374,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28264,NULL,'Elgin, TN 37732',11374,222,NULL,50,16597,0);
INSERT INTO "django_geo_db_location" VALUES(28265,NULL,'Rugby, TN',11375,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28266,NULL,'Rugby, TN 37733',11375,222,NULL,50,16598,0);
INSERT INTO "django_geo_db_location" VALUES(28267,NULL,'Friendsville, TN',11376,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28268,NULL,'Friendsville, TN 37737',11376,222,NULL,50,16599,0);
INSERT INTO "django_geo_db_location" VALUES(28269,NULL,'Gatlinburg, TN',11377,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28270,NULL,'Gatlinburg, TN 37738',11377,222,NULL,50,16600,0);
INSERT INTO "django_geo_db_location" VALUES(28271,NULL,'Greenback, TN',11378,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28272,NULL,'Greenback, TN 37742',11378,222,NULL,50,16601,0);
INSERT INTO "django_geo_db_location" VALUES(28273,NULL,'Greeneville, TN',11379,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28274,NULL,'Greeneville, TN 37743',11379,222,NULL,50,16602,0);
INSERT INTO "django_geo_db_location" VALUES(28275,NULL,'Greeneville, TN 37744',11379,222,NULL,50,16603,0);
INSERT INTO "django_geo_db_location" VALUES(28276,NULL,'Greeneville, TN 37745',11379,222,NULL,50,16604,0);
INSERT INTO "django_geo_db_location" VALUES(28277,NULL,'Harriman, TN',11380,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28278,NULL,'Harriman, TN 37748',11380,222,NULL,50,16605,0);
INSERT INTO "django_geo_db_location" VALUES(28279,NULL,'Harrogate, TN',11381,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28280,NULL,'Harrogate, TN 37752',11381,222,NULL,50,16606,0);
INSERT INTO "django_geo_db_location" VALUES(28281,NULL,'Hartford, TN',11382,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28282,NULL,'Hartford, TN 37753',11382,222,NULL,50,16607,0);
INSERT INTO "django_geo_db_location" VALUES(28283,NULL,'Heiskell, TN',11383,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28284,NULL,'Heiskell, TN 37754',11383,222,NULL,50,16608,0);
INSERT INTO "django_geo_db_location" VALUES(28285,NULL,'Helenwood, TN',11384,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28286,NULL,'Helenwood, TN 37755',11384,222,NULL,50,16609,0);
INSERT INTO "django_geo_db_location" VALUES(28287,NULL,'Huntsville, TN',11385,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28288,NULL,'Huntsville, TN 37756',11385,222,NULL,50,16610,0);
INSERT INTO "django_geo_db_location" VALUES(28289,NULL,'Jacksboro, TN',11386,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28290,NULL,'Jacksboro, TN 37757',11386,222,NULL,50,16611,0);
INSERT INTO "django_geo_db_location" VALUES(28291,NULL,'Jefferson City, TN',11387,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28292,NULL,'Jefferson City, TN 37760',11387,222,NULL,50,16612,0);
INSERT INTO "django_geo_db_location" VALUES(28293,NULL,'Jellico, TN',11388,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28294,NULL,'Jellico, TN 37762',11388,222,NULL,50,16613,0);
INSERT INTO "django_geo_db_location" VALUES(28295,NULL,'Kingston, TN',11389,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28296,NULL,'Kingston, TN 37763',11389,222,NULL,50,16614,0);
INSERT INTO "django_geo_db_location" VALUES(28297,NULL,'Kodak, TN',11390,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28298,NULL,'Kodak, TN 37764',11390,222,NULL,50,16615,0);
INSERT INTO "django_geo_db_location" VALUES(28299,NULL,'Kyles Ford, TN',11391,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28300,NULL,'Kyles Ford, TN 37765',11391,222,NULL,50,16616,0);
INSERT INTO "django_geo_db_location" VALUES(28301,NULL,'La Follette, TN',11392,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28302,NULL,'La Follette, TN 37766',11392,222,NULL,50,16617,0);
INSERT INTO "django_geo_db_location" VALUES(28303,NULL,'Lake City, TN',11393,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28304,NULL,'Lake City, TN 37769',11393,222,NULL,50,16618,0);
INSERT INTO "django_geo_db_location" VALUES(28305,NULL,'Lancing, TN',11394,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28306,NULL,'Lancing, TN 37770',11394,222,NULL,50,16619,0);
INSERT INTO "django_geo_db_location" VALUES(28307,NULL,'Lenoir City, TN',11395,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28308,NULL,'Lenoir City, TN 37771',11395,222,NULL,50,16620,0);
INSERT INTO "django_geo_db_location" VALUES(28309,NULL,'Lenoir City, TN 37772',11395,222,NULL,50,16621,0);
INSERT INTO "django_geo_db_location" VALUES(28310,NULL,'Lone Mountain, TN',11396,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28311,NULL,'Lone Mountain, TN 37773',11396,222,NULL,50,16622,0);
INSERT INTO "django_geo_db_location" VALUES(28312,NULL,'Loudon, TN',11397,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28313,NULL,'Loudon, TN 37774',11397,222,NULL,50,16623,0);
INSERT INTO "django_geo_db_location" VALUES(28314,NULL,'Louisville, TN',11398,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28315,NULL,'Louisville, TN 37777',11398,222,NULL,50,16624,0);
INSERT INTO "django_geo_db_location" VALUES(28316,NULL,'Lowland, TN',11399,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28317,NULL,'Lowland, TN 37778',11399,222,NULL,50,16625,0);
INSERT INTO "django_geo_db_location" VALUES(28318,NULL,'Luttrell, TN',11400,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28319,NULL,'Luttrell, TN 37779',11400,222,NULL,50,16626,0);
INSERT INTO "django_geo_db_location" VALUES(28320,NULL,'Maryville, TN',11401,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28321,NULL,'Maryville, TN 37801',11401,222,NULL,50,16627,0);
INSERT INTO "django_geo_db_location" VALUES(28322,NULL,'Maryville, TN 37802',11401,222,NULL,50,16628,0);
INSERT INTO "django_geo_db_location" VALUES(28323,NULL,'Maryville, TN 37803',11401,222,NULL,50,16629,0);
INSERT INTO "django_geo_db_location" VALUES(28324,NULL,'Maryville, TN 37804',11401,222,NULL,50,16630,0);
INSERT INTO "django_geo_db_location" VALUES(28325,NULL,'Mascot, TN',11402,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28326,NULL,'Mascot, TN 37806',11402,222,NULL,50,16631,0);
INSERT INTO "django_geo_db_location" VALUES(28327,NULL,'Maynardville, TN',11403,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28328,NULL,'Maynardville, TN 37807',11403,222,NULL,50,16632,0);
INSERT INTO "django_geo_db_location" VALUES(28329,NULL,'Midway, TN',11404,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28330,NULL,'Midway, TN 37809',11404,222,NULL,50,16633,0);
INSERT INTO "django_geo_db_location" VALUES(28331,NULL,'Mohawk, TN',11405,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28332,NULL,'Mohawk, TN 37810',11405,222,NULL,50,16634,0);
INSERT INTO "django_geo_db_location" VALUES(28333,NULL,'Mooresburg, TN',11406,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28334,NULL,'Mooresburg, TN 37811',11406,222,NULL,50,16635,0);
INSERT INTO "django_geo_db_location" VALUES(28335,NULL,'Morristown, TN',11407,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28336,NULL,'Morristown, TN 37813',11407,222,NULL,50,16636,0);
INSERT INTO "django_geo_db_location" VALUES(28337,NULL,'Morristown, TN 37814',11407,222,NULL,50,16637,0);
INSERT INTO "django_geo_db_location" VALUES(28338,NULL,'Morristown, TN 37815',11407,222,NULL,50,16638,0);
INSERT INTO "django_geo_db_location" VALUES(28339,NULL,'Morristown, TN 37816',11407,222,NULL,50,16639,0);
INSERT INTO "django_geo_db_location" VALUES(28340,NULL,'Mosheim, TN',11408,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28341,NULL,'Mosheim, TN 37818',11408,222,NULL,50,16640,0);
INSERT INTO "django_geo_db_location" VALUES(28342,NULL,'Newcomb, TN',11409,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28343,NULL,'Newcomb, TN 37819',11409,222,NULL,50,16641,0);
INSERT INTO "django_geo_db_location" VALUES(28344,NULL,'New Market, TN',11410,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28345,NULL,'New Market, TN 37820',11410,222,NULL,50,16642,0);
INSERT INTO "django_geo_db_location" VALUES(28346,NULL,'Newport, TN',11411,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28347,NULL,'Newport, TN 37821',11411,222,NULL,50,16643,0);
INSERT INTO "django_geo_db_location" VALUES(28348,NULL,'Newport, TN 37822',11411,222,NULL,50,16644,0);
INSERT INTO "django_geo_db_location" VALUES(28349,NULL,'New Tazewell, TN',11412,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28350,NULL,'New Tazewell, TN 37824',11412,222,NULL,50,16645,0);
INSERT INTO "django_geo_db_location" VALUES(28351,NULL,'New Tazewell, TN 37825',11412,222,NULL,50,16646,0);
INSERT INTO "django_geo_db_location" VALUES(28352,NULL,'Niota, TN',11413,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28353,NULL,'Niota, TN 37826',11413,222,NULL,50,16647,0);
INSERT INTO "django_geo_db_location" VALUES(28354,NULL,'Norris, TN',11414,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28355,NULL,'Norris, TN 37828',11414,222,NULL,50,16648,0);
INSERT INTO "django_geo_db_location" VALUES(28356,NULL,'Oakdale, TN',11415,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28357,NULL,'Oakdale, TN 37829',11415,222,NULL,50,16649,0);
INSERT INTO "django_geo_db_location" VALUES(28358,NULL,'Oak Ridge, TN',11416,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28359,NULL,'Oak Ridge, TN 37830',11416,222,NULL,50,16650,0);
INSERT INTO "django_geo_db_location" VALUES(28360,NULL,'Oak Ridge, TN 37831',11416,222,NULL,50,16651,0);
INSERT INTO "django_geo_db_location" VALUES(28361,NULL,'Sewanee, TN 37838',11304,222,NULL,50,16652,0);
INSERT INTO "django_geo_db_location" VALUES(28362,NULL,'Oliver Springs, TN',11417,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28363,NULL,'Oliver Springs, TN 37840',11417,222,NULL,50,16653,0);
INSERT INTO "django_geo_db_location" VALUES(28364,NULL,'Oneida, TN',11418,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28365,NULL,'Oneida, TN 37841',11418,222,NULL,50,16654,0);
INSERT INTO "django_geo_db_location" VALUES(28366,NULL,'Ozone, TN',11419,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28367,NULL,'Ozone, TN 37842',11419,222,NULL,50,16655,0);
INSERT INTO "django_geo_db_location" VALUES(28368,NULL,'Parrottsville, TN',11420,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28369,NULL,'Parrottsville, TN 37843',11420,222,NULL,50,16656,0);
INSERT INTO "django_geo_db_location" VALUES(28370,NULL,'Petros, TN',11421,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28371,NULL,'Petros, TN 37845',11421,222,NULL,50,16657,0);
INSERT INTO "django_geo_db_location" VALUES(28372,NULL,'Philadelphia, TN',11422,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28373,NULL,'Philadelphia, TN 37846',11422,222,NULL,50,16658,0);
INSERT INTO "django_geo_db_location" VALUES(28374,NULL,'Pioneer, TN',11423,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28375,NULL,'Pioneer, TN 37847',11423,222,NULL,50,16659,0);
INSERT INTO "django_geo_db_location" VALUES(28376,NULL,'Powder Springs, TN',11424,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28377,NULL,'Powder Springs, TN 37848',11424,222,NULL,50,16660,0);
INSERT INTO "django_geo_db_location" VALUES(28378,NULL,'Powell, TN',11425,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28379,NULL,'Powell, TN 37849',11425,222,NULL,50,16661,0);
INSERT INTO "django_geo_db_location" VALUES(28380,NULL,'Pruden, TN',11426,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28381,NULL,'Pruden, TN 37851',11426,222,NULL,50,16662,0);
INSERT INTO "django_geo_db_location" VALUES(28382,NULL,'Robbins, TN',11427,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28383,NULL,'Robbins, TN 37852',11427,222,NULL,50,16663,0);
INSERT INTO "django_geo_db_location" VALUES(28384,NULL,'Rockford, TN',11428,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28385,NULL,'Rockford, TN 37853',11428,222,NULL,50,16664,0);
INSERT INTO "django_geo_db_location" VALUES(28386,NULL,'Rockwood, TN',11429,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28387,NULL,'Rockwood, TN 37854',11429,222,NULL,50,16665,0);
INSERT INTO "django_geo_db_location" VALUES(28388,NULL,'Rogersville, TN',11430,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28389,NULL,'Rogersville, TN 37857',11430,222,NULL,50,16666,0);
INSERT INTO "django_geo_db_location" VALUES(28390,NULL,'Russellville, TN',11431,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28391,NULL,'Russellville, TN 37860',11431,222,NULL,50,16667,0);
INSERT INTO "django_geo_db_location" VALUES(28392,NULL,'Rutledge, TN',11432,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28393,NULL,'Rutledge, TN 37861',11432,222,NULL,50,16668,0);
INSERT INTO "django_geo_db_location" VALUES(28394,NULL,'Sevierville, TN',11433,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28395,NULL,'Sevierville, TN 37862',11433,222,NULL,50,16669,0);
INSERT INTO "django_geo_db_location" VALUES(28396,NULL,'Pigeon Forge, TN',11434,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28397,NULL,'Pigeon Forge, TN 37863',11434,222,NULL,50,16670,0);
INSERT INTO "django_geo_db_location" VALUES(28398,NULL,'Sevierville, TN 37864',11433,222,NULL,50,16671,0);
INSERT INTO "django_geo_db_location" VALUES(28399,NULL,'Seymour, TN',11435,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28400,NULL,'Seymour, TN 37865',11435,222,NULL,50,16672,0);
INSERT INTO "django_geo_db_location" VALUES(28401,NULL,'Sharps Chapel, TN',11436,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28402,NULL,'Sharps Chapel, TN 37866',11436,222,NULL,50,16673,0);
INSERT INTO "django_geo_db_location" VALUES(28403,NULL,'Shawanee, TN',11437,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28404,NULL,'Shawanee, TN 37867',11437,222,NULL,50,16674,0);
INSERT INTO "django_geo_db_location" VALUES(28405,NULL,'Pigeon Forge, TN 37868',11434,222,NULL,50,16675,0);
INSERT INTO "django_geo_db_location" VALUES(28406,NULL,'Sneedville, TN',11438,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28407,NULL,'Sneedville, TN 37869',11438,222,NULL,50,16676,0);
INSERT INTO "django_geo_db_location" VALUES(28408,NULL,'Speedwell, TN',11439,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28409,NULL,'Speedwell, TN 37870',11439,222,NULL,50,16677,0);
INSERT INTO "django_geo_db_location" VALUES(28410,NULL,'Strawberry Plains, TN',11440,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28411,NULL,'Strawberry Plains, TN 37871',11440,222,NULL,50,16678,0);
INSERT INTO "django_geo_db_location" VALUES(28412,NULL,'Sunbright, TN',11441,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28413,NULL,'Sunbright, TN 37872',11441,222,NULL,50,16679,0);
INSERT INTO "django_geo_db_location" VALUES(28414,NULL,'Surgoinsville, TN',11442,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28415,NULL,'Surgoinsville, TN 37873',11442,222,NULL,50,16680,0);
INSERT INTO "django_geo_db_location" VALUES(28416,NULL,'Sweetwater, TN',11443,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28417,NULL,'Sweetwater, TN 37874',11443,222,NULL,50,16681,0);
INSERT INTO "django_geo_db_location" VALUES(28418,NULL,'Sevierville, TN 37876',11433,222,NULL,50,16682,0);
INSERT INTO "django_geo_db_location" VALUES(28419,NULL,'Talbott, TN',11444,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28420,NULL,'Talbott, TN 37877',11444,222,NULL,50,16683,0);
INSERT INTO "django_geo_db_location" VALUES(28421,NULL,'Tallassee, TN',11445,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28422,NULL,'Tallassee, TN 37878',11445,222,NULL,50,16684,0);
INSERT INTO "django_geo_db_location" VALUES(28423,NULL,'Tazewell, TN',11446,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28424,NULL,'Tazewell, TN 37879',11446,222,NULL,50,16685,0);
INSERT INTO "django_geo_db_location" VALUES(28425,NULL,'Ten Mile, TN',11447,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28426,NULL,'Ten Mile, TN 37880',11447,222,NULL,50,16686,0);
INSERT INTO "django_geo_db_location" VALUES(28427,NULL,'Thorn Hill, TN',11448,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28428,NULL,'Thorn Hill, TN 37881',11448,222,NULL,50,16687,0);
INSERT INTO "django_geo_db_location" VALUES(28429,NULL,'Townsend, TN',11449,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28430,NULL,'Townsend, TN 37882',11449,222,NULL,50,16688,0);
INSERT INTO "django_geo_db_location" VALUES(28431,NULL,'Vonore, TN',11450,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28432,NULL,'Vonore, TN 37885',11450,222,NULL,50,16689,0);
INSERT INTO "django_geo_db_location" VALUES(28433,NULL,'Walland, TN',11451,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28434,NULL,'Walland, TN 37886',11451,222,NULL,50,16690,0);
INSERT INTO "django_geo_db_location" VALUES(28435,NULL,'Wartburg, TN',11452,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28436,NULL,'Wartburg, TN 37887',11452,222,NULL,50,16691,0);
INSERT INTO "django_geo_db_location" VALUES(28437,NULL,'Washburn, TN',11453,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28438,NULL,'Washburn, TN 37888',11453,222,NULL,50,16692,0);
INSERT INTO "django_geo_db_location" VALUES(28439,NULL,'White Pine, TN',11454,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28440,NULL,'White Pine, TN 37890',11454,222,NULL,50,16693,0);
INSERT INTO "django_geo_db_location" VALUES(28441,NULL,'Whitesburg, TN',11455,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28442,NULL,'Whitesburg, TN 37891',11455,222,NULL,50,16694,0);
INSERT INTO "django_geo_db_location" VALUES(28443,NULL,'Winfield, TN',11456,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28444,NULL,'Winfield, TN 37892',11456,222,NULL,50,16695,0);
INSERT INTO "django_geo_db_location" VALUES(28445,NULL,'Winona, TN',11457,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28446,NULL,'Winona, TN 37893',11457,222,NULL,50,16696,0);
INSERT INTO "django_geo_db_location" VALUES(28447,NULL,'Knoxville, TN',11458,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28448,NULL,'Knoxville, TN 37901',11458,222,NULL,50,16697,0);
INSERT INTO "django_geo_db_location" VALUES(28449,NULL,'Knoxville, TN 37902',11458,222,NULL,50,16698,0);
INSERT INTO "django_geo_db_location" VALUES(28450,NULL,'Knoxville, TN 37909',11458,222,NULL,50,16699,0);
INSERT INTO "django_geo_db_location" VALUES(28451,NULL,'Knoxville, TN 37912',11458,222,NULL,50,16700,0);
INSERT INTO "django_geo_db_location" VALUES(28452,NULL,'Knoxville, TN 37913',11458,222,NULL,50,16701,0);
INSERT INTO "django_geo_db_location" VALUES(28453,NULL,'Knoxville, TN 37914',11458,222,NULL,50,16702,0);
INSERT INTO "django_geo_db_location" VALUES(28454,NULL,'Knoxville, TN 37915',11458,222,NULL,50,16703,0);
INSERT INTO "django_geo_db_location" VALUES(28455,NULL,'Knoxville, TN 37916',11458,222,NULL,50,16704,0);
INSERT INTO "django_geo_db_location" VALUES(28456,NULL,'Knoxville, TN 37917',11458,222,NULL,50,16705,0);
INSERT INTO "django_geo_db_location" VALUES(28457,NULL,'Knoxville, TN 37918',11458,222,NULL,50,16706,0);
INSERT INTO "django_geo_db_location" VALUES(28458,NULL,'Knoxville, TN 37919',11458,222,NULL,50,16707,0);
INSERT INTO "django_geo_db_location" VALUES(28459,NULL,'Knoxville, TN 37920',11458,222,NULL,50,16708,0);
INSERT INTO "django_geo_db_location" VALUES(28460,NULL,'Knoxville, TN 37921',11458,222,NULL,50,16709,0);
INSERT INTO "django_geo_db_location" VALUES(28461,NULL,'Knoxville, TN 37922',11458,222,NULL,50,16710,0);
INSERT INTO "django_geo_db_location" VALUES(28462,NULL,'Knoxville, TN 37923',11458,222,NULL,50,16711,0);
INSERT INTO "django_geo_db_location" VALUES(28463,NULL,'Knoxville, TN 37924',11458,222,NULL,50,16712,0);
INSERT INTO "django_geo_db_location" VALUES(28464,NULL,'Knoxville, TN 37927',11458,222,NULL,50,16713,0);
INSERT INTO "django_geo_db_location" VALUES(28465,NULL,'Knoxville, TN 37928',11458,222,NULL,50,16714,0);
INSERT INTO "django_geo_db_location" VALUES(28466,NULL,'Knoxville, TN 37929',11458,222,NULL,50,16715,0);
INSERT INTO "django_geo_db_location" VALUES(28467,NULL,'Knoxville, TN 37930',11458,222,NULL,50,16716,0);
INSERT INTO "django_geo_db_location" VALUES(28468,NULL,'Knoxville, TN 37931',11458,222,NULL,50,16717,0);
INSERT INTO "django_geo_db_location" VALUES(28469,NULL,'Knoxville, TN 37932',11458,222,NULL,50,16718,0);
INSERT INTO "django_geo_db_location" VALUES(28470,NULL,'Knoxville, TN 37933',11458,222,NULL,50,16719,0);
INSERT INTO "django_geo_db_location" VALUES(28471,NULL,'Powells Crossroads, TN',11459,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28472,NULL,'Powells Crossroads, TN 37937',11459,222,NULL,50,16720,0);
INSERT INTO "django_geo_db_location" VALUES(28473,NULL,'Knoxville, TN 37938',11458,222,NULL,50,16721,0);
INSERT INTO "django_geo_db_location" VALUES(28474,NULL,'Knoxville, TN 37939',11458,222,NULL,50,16722,0);
INSERT INTO "django_geo_db_location" VALUES(28475,NULL,'Knoxville, TN 37940',11458,222,NULL,50,16723,0);
INSERT INTO "django_geo_db_location" VALUES(28476,NULL,'Knoxville, TN 37950',11458,222,NULL,50,16724,0);
INSERT INTO "django_geo_db_location" VALUES(28477,NULL,'Knoxville, TN 37951',11458,222,NULL,50,16725,0);
INSERT INTO "django_geo_db_location" VALUES(28478,NULL,'Knoxville, TN 37990',11458,222,NULL,50,16726,0);
INSERT INTO "django_geo_db_location" VALUES(28479,NULL,'Knoxville, TN 37995',11458,222,NULL,50,16727,0);
INSERT INTO "django_geo_db_location" VALUES(28480,NULL,'Knoxville, TN 37996',11458,222,NULL,50,16728,0);
INSERT INTO "django_geo_db_location" VALUES(28481,NULL,'Knoxville, TN 37997',11458,222,NULL,50,16729,0);
INSERT INTO "django_geo_db_location" VALUES(28482,NULL,'Knoxville, TN 37998',11458,222,NULL,50,16730,0);
INSERT INTO "django_geo_db_location" VALUES(28483,NULL,'Knoxville, TN 37999',11458,222,NULL,50,16731,0);
INSERT INTO "django_geo_db_location" VALUES(28484,NULL,'Alamo, TN',11460,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28485,NULL,'Alamo, TN 38001',11460,222,NULL,50,16732,0);
INSERT INTO "django_geo_db_location" VALUES(28486,NULL,'Arlington, TN',11461,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28487,NULL,'Arlington, TN 38002',11461,222,NULL,50,16733,0);
INSERT INTO "django_geo_db_location" VALUES(28488,NULL,'Atoka, TN',11462,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28489,NULL,'Atoka, TN 38004',11462,222,NULL,50,16734,0);
INSERT INTO "django_geo_db_location" VALUES(28490,NULL,'Bells, TN',11463,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28491,NULL,'Bells, TN 38006',11463,222,NULL,50,16735,0);
INSERT INTO "django_geo_db_location" VALUES(28492,NULL,'Bogota, TN',11464,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28493,NULL,'Bogota, TN 38007',11464,222,NULL,50,16736,0);
INSERT INTO "django_geo_db_location" VALUES(28494,NULL,'Bolivar, TN',11465,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28495,NULL,'Bolivar, TN 38008',11465,222,NULL,50,16737,0);
INSERT INTO "django_geo_db_location" VALUES(28496,NULL,'Braden, TN',11466,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28497,NULL,'Braden, TN 38010',11466,222,NULL,50,16738,0);
INSERT INTO "django_geo_db_location" VALUES(28498,NULL,'Brighton, TN',11467,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28499,NULL,'Brighton, TN 38011',11467,222,NULL,50,16739,0);
INSERT INTO "django_geo_db_location" VALUES(28500,NULL,'Brownsville, TN',11468,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28501,NULL,'Brownsville, TN 38012',11468,222,NULL,50,16740,0);
INSERT INTO "django_geo_db_location" VALUES(28502,NULL,'Brunswick, TN',11469,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28503,NULL,'Brunswick, TN 38014',11469,222,NULL,50,16741,0);
INSERT INTO "django_geo_db_location" VALUES(28504,NULL,'Burlison, TN',11470,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28505,NULL,'Burlison, TN 38015',11470,222,NULL,50,16742,0);
INSERT INTO "django_geo_db_location" VALUES(28506,NULL,'Memphis, TN 38016',11323,222,NULL,50,16743,0);
INSERT INTO "django_geo_db_location" VALUES(28507,NULL,'Collierville, TN',11471,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28508,NULL,'Collierville, TN 38017',11471,222,NULL,50,16744,0);
INSERT INTO "django_geo_db_location" VALUES(28509,NULL,'Cordova, TN',11472,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28510,NULL,'Cordova, TN 38018',11472,222,NULL,50,16745,0);
INSERT INTO "django_geo_db_location" VALUES(28511,NULL,'Covington, TN',11473,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28512,NULL,'Covington, TN 38019',11473,222,NULL,50,16746,0);
INSERT INTO "django_geo_db_location" VALUES(28513,NULL,'Crockett Mills, TN',11474,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28514,NULL,'Crockett Mills, TN 38021',11474,222,NULL,50,16747,0);
INSERT INTO "django_geo_db_location" VALUES(28515,NULL,'Drummonds, TN',11475,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28516,NULL,'Drummonds, TN 38023',11475,222,NULL,50,16748,0);
INSERT INTO "django_geo_db_location" VALUES(28517,NULL,'Dyersburg, TN',11476,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28518,NULL,'Dyersburg, TN 38024',11476,222,NULL,50,16749,0);
INSERT INTO "django_geo_db_location" VALUES(28519,NULL,'Dyersburg, TN 38025',11476,222,NULL,50,16750,0);
INSERT INTO "django_geo_db_location" VALUES(28520,NULL,'Memphis, TN 38026',11323,222,NULL,50,16751,0);
INSERT INTO "django_geo_db_location" VALUES(28521,NULL,'Collierville, TN 38027',11471,222,NULL,50,16752,0);
INSERT INTO "django_geo_db_location" VALUES(28522,NULL,'Eads, TN',11477,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28523,NULL,'Eads, TN 38028',11477,222,NULL,50,16753,0);
INSERT INTO "django_geo_db_location" VALUES(28524,NULL,'Ellendale, TN',11478,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28525,NULL,'Ellendale, TN 38029',11478,222,NULL,50,16754,0);
INSERT INTO "django_geo_db_location" VALUES(28526,NULL,'Finley, TN',11479,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28527,NULL,'Finley, TN 38030',11479,222,NULL,50,16755,0);
INSERT INTO "django_geo_db_location" VALUES(28528,NULL,'Friendship, TN',11480,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28529,NULL,'Friendship, TN 38034',11480,222,NULL,50,16756,0);
INSERT INTO "django_geo_db_location" VALUES(28530,NULL,'Gallaway, TN',11481,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28531,NULL,'Gallaway, TN 38036',11481,222,NULL,50,16757,0);
INSERT INTO "django_geo_db_location" VALUES(28532,NULL,'Gates, TN',11482,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28533,NULL,'Gates, TN 38037',11482,222,NULL,50,16758,0);
INSERT INTO "django_geo_db_location" VALUES(28534,NULL,'Grand Junction, TN',11483,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28535,NULL,'Grand Junction, TN 38039',11483,222,NULL,50,16759,0);
INSERT INTO "django_geo_db_location" VALUES(28536,NULL,'Halls, TN',11484,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28537,NULL,'Halls, TN 38040',11484,222,NULL,50,16760,0);
INSERT INTO "django_geo_db_location" VALUES(28538,NULL,'Henning, AR',11485,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28539,NULL,'Henning, AR 38041',11485,222,NULL,4,16761,0);
INSERT INTO "django_geo_db_location" VALUES(28540,NULL,'Hickory Valley, TN',11486,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28541,NULL,'Hickory Valley, TN 38042',11486,222,NULL,50,16762,0);
INSERT INTO "django_geo_db_location" VALUES(28542,NULL,'Hickory Withe, TN',11487,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28543,NULL,'Hickory Withe, TN 38043',11487,222,NULL,50,16763,0);
INSERT INTO "django_geo_db_location" VALUES(28544,NULL,'Hornsby, TN',11488,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28545,NULL,'Hornsby, TN 38044',11488,222,NULL,50,16764,0);
INSERT INTO "django_geo_db_location" VALUES(28546,NULL,'Laconia, TN',11489,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28547,NULL,'Laconia, TN 38045',11489,222,NULL,50,16765,0);
INSERT INTO "django_geo_db_location" VALUES(28548,NULL,'La Grange, TN',11490,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28549,NULL,'La Grange, TN 38046',11490,222,NULL,50,16766,0);
INSERT INTO "django_geo_db_location" VALUES(28550,NULL,'Lenox, TN',11491,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28551,NULL,'Lenox, TN 38047',11491,222,NULL,50,16767,0);
INSERT INTO "django_geo_db_location" VALUES(28552,NULL,'Macon, TN',11492,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28553,NULL,'Macon, TN 38048',11492,222,NULL,50,16768,0);
INSERT INTO "django_geo_db_location" VALUES(28554,NULL,'Mason, TN',11493,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28555,NULL,'Mason, TN 38049',11493,222,NULL,50,16769,0);
INSERT INTO "django_geo_db_location" VALUES(28556,NULL,'Maury City, TN',11494,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28557,NULL,'Maury City, TN 38050',11494,222,NULL,50,16770,0);
INSERT INTO "django_geo_db_location" VALUES(28558,NULL,'Middleton, TN',11495,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28559,NULL,'Middleton, TN 38052',11495,222,NULL,50,16771,0);
INSERT INTO "django_geo_db_location" VALUES(28560,NULL,'Millington, TN',11496,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28561,NULL,'Millington, TN 38053',11496,222,NULL,50,16772,0);
INSERT INTO "django_geo_db_location" VALUES(28562,NULL,'Millington, TN 38054',11496,222,NULL,50,16773,0);
INSERT INTO "django_geo_db_location" VALUES(28563,NULL,'Millington, TN 38055',11496,222,NULL,50,16774,0);
INSERT INTO "django_geo_db_location" VALUES(28564,NULL,'Miston, TN',11497,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28565,NULL,'Miston, TN 38056',11497,222,NULL,50,16775,0);
INSERT INTO "django_geo_db_location" VALUES(28566,NULL,'Moscow, TN',11498,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28567,NULL,'Moscow, TN 38057',11498,222,NULL,50,16776,0);
INSERT INTO "django_geo_db_location" VALUES(28568,NULL,'Munford, TN',11499,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28569,NULL,'Munford, TN 38058',11499,222,NULL,50,16777,0);
INSERT INTO "django_geo_db_location" VALUES(28570,NULL,'Newbern, TN',11500,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28571,NULL,'Newbern, TN 38059',11500,222,NULL,50,16778,0);
INSERT INTO "django_geo_db_location" VALUES(28572,NULL,'Oakland, TN',11501,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28573,NULL,'Oakland, TN 38060',11501,222,NULL,50,16779,0);
INSERT INTO "django_geo_db_location" VALUES(28574,NULL,'Pocahontas, TN',11502,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28575,NULL,'Pocahontas, TN 38061',11502,222,NULL,50,16780,0);
INSERT INTO "django_geo_db_location" VALUES(28576,NULL,'Ripley, AR',11503,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28577,NULL,'Ripley, AR 38063',11503,222,NULL,4,16781,0);
INSERT INTO "django_geo_db_location" VALUES(28578,NULL,'Rossville, TN',11504,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28579,NULL,'Rossville, TN 38066',11504,222,NULL,50,16782,0);
INSERT INTO "django_geo_db_location" VALUES(28580,NULL,'Saulsbury, TN',11505,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28581,NULL,'Saulsbury, TN 38067',11505,222,NULL,50,16783,0);
INSERT INTO "django_geo_db_location" VALUES(28582,NULL,'Somerville, TN',11506,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28583,NULL,'Somerville, TN 38068',11506,222,NULL,50,16784,0);
INSERT INTO "django_geo_db_location" VALUES(28584,NULL,'Stanton, TN',11507,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28585,NULL,'Stanton, TN 38069',11507,222,NULL,50,16785,0);
INSERT INTO "django_geo_db_location" VALUES(28586,NULL,'Tigrett, TN',11508,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28587,NULL,'Tigrett, TN 38070',11508,222,NULL,50,16786,0);
INSERT INTO "django_geo_db_location" VALUES(28588,NULL,'Tipton, TN',11509,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28589,NULL,'Tipton, TN 38071',11509,222,NULL,50,16787,0);
INSERT INTO "django_geo_db_location" VALUES(28590,NULL,'Gates, TN 38073',11482,222,NULL,50,16788,0);
INSERT INTO "django_geo_db_location" VALUES(28591,NULL,'Bolivar, TN 38074',11465,222,NULL,50,16789,0);
INSERT INTO "django_geo_db_location" VALUES(28592,NULL,'Whiteville, TN',11510,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28593,NULL,'Whiteville, TN 38075',11510,222,NULL,50,16790,0);
INSERT INTO "django_geo_db_location" VALUES(28594,NULL,'Williston, TN',11511,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28595,NULL,'Williston, TN 38076',11511,222,NULL,50,16791,0);
INSERT INTO "django_geo_db_location" VALUES(28596,NULL,'Wynnburg, TN',11512,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28597,NULL,'Wynnburg, TN 38077',11512,222,NULL,50,16792,0);
INSERT INTO "django_geo_db_location" VALUES(28598,NULL,'Tiptonville, KY',11513,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28599,NULL,'Tiptonville, KY 38079',11513,222,NULL,21,16793,0);
INSERT INTO "django_geo_db_location" VALUES(28600,NULL,'Ridgely, TN',11514,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28601,NULL,'Ridgely, TN 38080',11514,222,NULL,50,16794,0);
INSERT INTO "django_geo_db_location" VALUES(28602,NULL,'Millington, TN 38083',11496,222,NULL,50,16795,0);
INSERT INTO "django_geo_db_location" VALUES(28603,NULL,'Cordova, TN 38088',11472,222,NULL,50,16796,0);
INSERT INTO "django_geo_db_location" VALUES(28604,NULL,'Memphis, TN 38101',11323,222,NULL,50,16797,0);
INSERT INTO "django_geo_db_location" VALUES(28605,NULL,'Memphis, TN 38103',11323,222,NULL,50,16798,0);
INSERT INTO "django_geo_db_location" VALUES(28606,NULL,'Memphis, TN 38104',11323,222,NULL,50,16799,0);
INSERT INTO "django_geo_db_location" VALUES(28607,NULL,'Memphis, TN 38105',11323,222,NULL,50,16800,0);
INSERT INTO "django_geo_db_location" VALUES(28608,NULL,'Memphis, TN 38106',11323,222,NULL,50,16801,0);
INSERT INTO "django_geo_db_location" VALUES(28609,NULL,'Memphis, TN 38107',11323,222,NULL,50,16802,0);
INSERT INTO "django_geo_db_location" VALUES(28610,NULL,'Memphis, TN 38108',11323,222,NULL,50,16803,0);
INSERT INTO "django_geo_db_location" VALUES(28611,NULL,'Memphis, TN 38109',11323,222,NULL,50,16804,0);
INSERT INTO "django_geo_db_location" VALUES(28612,NULL,'Memphis, TN 38110',11323,222,NULL,50,16805,0);
INSERT INTO "django_geo_db_location" VALUES(28613,NULL,'Memphis, TN 38111',11323,222,NULL,50,16806,0);
INSERT INTO "django_geo_db_location" VALUES(28614,NULL,'Memphis, TN 38112',11323,222,NULL,50,16807,0);
INSERT INTO "django_geo_db_location" VALUES(28615,NULL,'Memphis, TN 38113',11323,222,NULL,50,16808,0);
INSERT INTO "django_geo_db_location" VALUES(28616,NULL,'Memphis, TN 38114',11323,222,NULL,50,16809,0);
INSERT INTO "django_geo_db_location" VALUES(28617,NULL,'Memphis, TN 38115',11323,222,NULL,50,16810,0);
INSERT INTO "django_geo_db_location" VALUES(28618,NULL,'Memphis, TN 38116',11323,222,NULL,50,16811,0);
INSERT INTO "django_geo_db_location" VALUES(28619,NULL,'Memphis, TN 38117',11323,222,NULL,50,16812,0);
INSERT INTO "django_geo_db_location" VALUES(28620,NULL,'Memphis, TN 38118',11323,222,NULL,50,16813,0);
INSERT INTO "django_geo_db_location" VALUES(28621,NULL,'Memphis, TN 38119',11323,222,NULL,50,16814,0);
INSERT INTO "django_geo_db_location" VALUES(28622,NULL,'Memphis, TN 38120',11323,222,NULL,50,16815,0);
INSERT INTO "django_geo_db_location" VALUES(28623,NULL,'Memphis, TN 38122',11323,222,NULL,50,16816,0);
INSERT INTO "django_geo_db_location" VALUES(28624,NULL,'Memphis, TN 38124',11323,222,NULL,50,16817,0);
INSERT INTO "django_geo_db_location" VALUES(28625,NULL,'Memphis, TN 38125',11323,222,NULL,50,16818,0);
INSERT INTO "django_geo_db_location" VALUES(28626,NULL,'Memphis, TN 38126',11323,222,NULL,50,16819,0);
INSERT INTO "django_geo_db_location" VALUES(28627,NULL,'Memphis, TN 38127',11323,222,NULL,50,16820,0);
INSERT INTO "django_geo_db_location" VALUES(28628,NULL,'Memphis, TN 38128',11323,222,NULL,50,16821,0);
INSERT INTO "django_geo_db_location" VALUES(28629,NULL,'Memphis, TN 38130',11323,222,NULL,50,16822,0);
INSERT INTO "django_geo_db_location" VALUES(28630,NULL,'Memphis, TN 38131',11323,222,NULL,50,16823,0);
INSERT INTO "django_geo_db_location" VALUES(28631,NULL,'Memphis, TN 38132',11323,222,NULL,50,16824,0);
INSERT INTO "django_geo_db_location" VALUES(28632,NULL,'Memphis, TN 38133',11323,222,NULL,50,16825,0);
INSERT INTO "django_geo_db_location" VALUES(28633,NULL,'Memphis, TN 38134',11323,222,NULL,50,16826,0);
INSERT INTO "django_geo_db_location" VALUES(28634,NULL,'Memphis, TN 38135',11323,222,NULL,50,16827,0);
INSERT INTO "django_geo_db_location" VALUES(28635,NULL,'Memphis, TN 38136',11323,222,NULL,50,16828,0);
INSERT INTO "django_geo_db_location" VALUES(28636,NULL,'Memphis, TN 38137',11323,222,NULL,50,16829,0);
INSERT INTO "django_geo_db_location" VALUES(28637,NULL,'Germantown, TN',11515,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28638,NULL,'Germantown, TN 38138',11515,222,NULL,50,16830,0);
INSERT INTO "django_geo_db_location" VALUES(28639,NULL,'Germantown, TN 38139',11515,222,NULL,50,16831,0);
INSERT INTO "django_geo_db_location" VALUES(28640,NULL,'Memphis, TN 38140',11323,222,NULL,50,16832,0);
INSERT INTO "django_geo_db_location" VALUES(28641,NULL,'Memphis, TN 38141',11323,222,NULL,50,16833,0);
INSERT INTO "django_geo_db_location" VALUES(28642,NULL,'Memphis, TN 38142',11323,222,NULL,50,16834,0);
INSERT INTO "django_geo_db_location" VALUES(28643,NULL,'Memphis, TN 38143',11323,222,NULL,50,16835,0);
INSERT INTO "django_geo_db_location" VALUES(28644,NULL,'Memphis, TN 38145',11323,222,NULL,50,16836,0);
INSERT INTO "django_geo_db_location" VALUES(28645,NULL,'Memphis, TN 38146',11323,222,NULL,50,16837,0);
INSERT INTO "django_geo_db_location" VALUES(28646,NULL,'Memphis, TN 38147',11323,222,NULL,50,16838,0);
INSERT INTO "django_geo_db_location" VALUES(28647,NULL,'Memphis, TN 38148',11323,222,NULL,50,16839,0);
INSERT INTO "django_geo_db_location" VALUES(28648,NULL,'Memphis, TN 38150',11323,222,NULL,50,16840,0);
INSERT INTO "django_geo_db_location" VALUES(28649,NULL,'Memphis, TN 38151',11323,222,NULL,50,16841,0);
INSERT INTO "django_geo_db_location" VALUES(28650,NULL,'Memphis, TN 38152',11323,222,NULL,50,16842,0);
INSERT INTO "django_geo_db_location" VALUES(28651,NULL,'Memphis, TN 38157',11323,222,NULL,50,16843,0);
INSERT INTO "django_geo_db_location" VALUES(28652,NULL,'Memphis, TN 38159',11323,222,NULL,50,16844,0);
INSERT INTO "django_geo_db_location" VALUES(28653,NULL,'Metcalfe, MS',11516,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28654,NULL,'Metcalfe, MS 38160',11516,222,NULL,42,16845,0);
INSERT INTO "django_geo_db_location" VALUES(28655,NULL,'Memphis, TN 38161',11323,222,NULL,50,16846,0);
INSERT INTO "django_geo_db_location" VALUES(28656,NULL,'Memphis, TN 38163',11323,222,NULL,50,16847,0);
INSERT INTO "django_geo_db_location" VALUES(28657,NULL,'Memphis, TN 38165',11323,222,NULL,50,16848,0);
INSERT INTO "django_geo_db_location" VALUES(28658,NULL,'Memphis, TN 38166',11323,222,NULL,50,16849,0);
INSERT INTO "django_geo_db_location" VALUES(28659,NULL,'Memphis, TN 38167',11323,222,NULL,50,16850,0);
INSERT INTO "django_geo_db_location" VALUES(28660,NULL,'Memphis, TN 38168',11323,222,NULL,50,16851,0);
INSERT INTO "django_geo_db_location" VALUES(28661,NULL,'Memphis, TN 38173',11323,222,NULL,50,16852,0);
INSERT INTO "django_geo_db_location" VALUES(28662,NULL,'Memphis, TN 38174',11323,222,NULL,50,16853,0);
INSERT INTO "django_geo_db_location" VALUES(28663,NULL,'Memphis, TN 38175',11323,222,NULL,50,16854,0);
INSERT INTO "django_geo_db_location" VALUES(28664,NULL,'Memphis, TN 38177',11323,222,NULL,50,16855,0);
INSERT INTO "django_geo_db_location" VALUES(28665,NULL,'Memphis, TN 38181',11323,222,NULL,50,16856,0);
INSERT INTO "django_geo_db_location" VALUES(28666,NULL,'Memphis, TN 38182',11323,222,NULL,50,16857,0);
INSERT INTO "django_geo_db_location" VALUES(28667,NULL,'Germantown, TN 38183',11515,222,NULL,50,16858,0);
INSERT INTO "django_geo_db_location" VALUES(28668,NULL,'Memphis, TN 38184',11323,222,NULL,50,16859,0);
INSERT INTO "django_geo_db_location" VALUES(28669,NULL,'Memphis, TN 38186',11323,222,NULL,50,16860,0);
INSERT INTO "django_geo_db_location" VALUES(28670,NULL,'Memphis, TN 38187',11323,222,NULL,50,16861,0);
INSERT INTO "django_geo_db_location" VALUES(28671,NULL,'Memphis, TN 38188',11323,222,NULL,50,16862,0);
INSERT INTO "django_geo_db_location" VALUES(28672,NULL,'Memphis, TN 38190',11323,222,NULL,50,16863,0);
INSERT INTO "django_geo_db_location" VALUES(28673,NULL,'Memphis, TN 38193',11323,222,NULL,50,16864,0);
INSERT INTO "django_geo_db_location" VALUES(28674,NULL,'Memphis, TN 38194',11323,222,NULL,50,16865,0);
INSERT INTO "django_geo_db_location" VALUES(28675,NULL,'Memphis, TN 38195',11323,222,NULL,50,16866,0);
INSERT INTO "django_geo_db_location" VALUES(28676,NULL,'Memphis, TN 38197',11323,222,NULL,50,16867,0);
INSERT INTO "django_geo_db_location" VALUES(28677,NULL,'McKenzie, TN',11517,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28678,NULL,'McKenzie, TN 38201',11517,222,NULL,50,16868,0);
INSERT INTO "django_geo_db_location" VALUES(28679,NULL,'Atwood, TN',11518,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28680,NULL,'Atwood, TN 38220',11518,222,NULL,50,16869,0);
INSERT INTO "django_geo_db_location" VALUES(28681,NULL,'Big Sandy, TN',11519,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28682,NULL,'Big Sandy, TN 38221',11519,222,NULL,50,16870,0);
INSERT INTO "django_geo_db_location" VALUES(28683,NULL,'Buchanan, TN',11520,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28684,NULL,'Buchanan, TN 38222',11520,222,NULL,50,16871,0);
INSERT INTO "django_geo_db_location" VALUES(28685,NULL,'Como, TN',11521,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28686,NULL,'Como, TN 38223',11521,222,NULL,50,16872,0);
INSERT INTO "django_geo_db_location" VALUES(28687,NULL,'Cottage Grove, TN',11522,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28688,NULL,'Cottage Grove, TN 38224',11522,222,NULL,50,16873,0);
INSERT INTO "django_geo_db_location" VALUES(28689,NULL,'Dresden, TN',11523,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28690,NULL,'Dresden, TN 38225',11523,222,NULL,50,16874,0);
INSERT INTO "django_geo_db_location" VALUES(28691,NULL,'Dukedom, TN',11524,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28692,NULL,'Dukedom, TN 38226',11524,222,NULL,50,16875,0);
INSERT INTO "django_geo_db_location" VALUES(28693,NULL,'Gleason, TN',11525,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28694,NULL,'Gleason, TN 38229',11525,222,NULL,50,16876,0);
INSERT INTO "django_geo_db_location" VALUES(28695,NULL,'Greenfield, TN',11526,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28696,NULL,'Greenfield, TN 38230',11526,222,NULL,50,16877,0);
INSERT INTO "django_geo_db_location" VALUES(28697,NULL,'Henry, TN',11527,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28698,NULL,'Henry, TN 38231',11527,222,NULL,50,16878,0);
INSERT INTO "django_geo_db_location" VALUES(28699,NULL,'Hornbeak, TN',11528,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28700,NULL,'Hornbeak, TN 38232',11528,222,NULL,50,16879,0);
INSERT INTO "django_geo_db_location" VALUES(28701,NULL,'Kenton, TN',11529,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28702,NULL,'Kenton, TN 38233',11529,222,NULL,50,16880,0);
INSERT INTO "django_geo_db_location" VALUES(28703,NULL,'McLemoresville, TN',11530,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28704,NULL,'McLemoresville, TN 38235',11530,222,NULL,50,16881,0);
INSERT INTO "django_geo_db_location" VALUES(28705,NULL,'Mansfield, TN',11531,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28706,NULL,'Mansfield, TN 38236',11531,222,NULL,50,16882,0);
INSERT INTO "django_geo_db_location" VALUES(28707,NULL,'Martin, TN',11532,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28708,NULL,'Martin, TN 38237',11532,222,NULL,50,16883,0);
INSERT INTO "django_geo_db_location" VALUES(28709,NULL,'Martin, TN 38238',11532,222,NULL,50,16884,0);
INSERT INTO "django_geo_db_location" VALUES(28710,NULL,'Obion, TN',11533,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28711,NULL,'Obion, TN 38240',11533,222,NULL,50,16885,0);
INSERT INTO "django_geo_db_location" VALUES(28712,NULL,'Palmersville, TN',11534,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28713,NULL,'Palmersville, TN 38241',11534,222,NULL,50,16886,0);
INSERT INTO "django_geo_db_location" VALUES(28714,NULL,'Paris, TN',11535,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28715,NULL,'Paris, TN 38242',11535,222,NULL,50,16887,0);
INSERT INTO "django_geo_db_location" VALUES(28716,NULL,'Puryear, TN',11536,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28717,NULL,'Puryear, TN 38251',11536,222,NULL,50,16888,0);
INSERT INTO "django_geo_db_location" VALUES(28718,NULL,'Rives, TN',11537,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28719,NULL,'Rives, TN 38253',11537,222,NULL,50,16889,0);
INSERT INTO "django_geo_db_location" VALUES(28720,NULL,'Samburg, TN',11538,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28721,NULL,'Samburg, TN 38254',11538,222,NULL,50,16890,0);
INSERT INTO "django_geo_db_location" VALUES(28722,NULL,'Sharon, TN',11539,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28723,NULL,'Sharon, TN 38255',11539,222,NULL,50,16891,0);
INSERT INTO "django_geo_db_location" VALUES(28724,NULL,'Springville, TN',11540,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28725,NULL,'Springville, TN 38256',11540,222,NULL,50,16892,0);
INSERT INTO "django_geo_db_location" VALUES(28726,NULL,'South Fulton, TN',11541,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28727,NULL,'South Fulton, TN 38257',11541,222,NULL,50,16893,0);
INSERT INTO "django_geo_db_location" VALUES(28728,NULL,'Trezevant, TN',11542,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28729,NULL,'Trezevant, TN 38258',11542,222,NULL,50,16894,0);
INSERT INTO "django_geo_db_location" VALUES(28730,NULL,'Trimble, TN',11543,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28731,NULL,'Trimble, TN 38259',11543,222,NULL,50,16895,0);
INSERT INTO "django_geo_db_location" VALUES(28732,NULL,'Troy, TN',11544,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28733,NULL,'Troy, TN 38260',11544,222,NULL,50,16896,0);
INSERT INTO "django_geo_db_location" VALUES(28734,NULL,'Union City, TN',11545,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28735,NULL,'Union City, TN 38261',11545,222,NULL,50,16897,0);
INSERT INTO "django_geo_db_location" VALUES(28736,NULL,'Woodland Mills, TN',11546,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28737,NULL,'Woodland Mills, TN 38271',11546,222,NULL,50,16898,0);
INSERT INTO "django_geo_db_location" VALUES(28738,NULL,'Union City, TN 38281',11545,222,NULL,50,16899,0);
INSERT INTO "django_geo_db_location" VALUES(28739,NULL,'Jackson, TN',11547,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28740,NULL,'Jackson, TN 38301',11547,222,NULL,50,16900,0);
INSERT INTO "django_geo_db_location" VALUES(28741,NULL,'Jackson, TN 38302',11547,222,NULL,50,16901,0);
INSERT INTO "django_geo_db_location" VALUES(28742,NULL,'Jackson, TN 38303',11547,222,NULL,50,16902,0);
INSERT INTO "django_geo_db_location" VALUES(28743,NULL,'Jackson, TN 38305',11547,222,NULL,50,16903,0);
INSERT INTO "django_geo_db_location" VALUES(28744,NULL,'Jackson, TN 38308',11547,222,NULL,50,16904,0);
INSERT INTO "django_geo_db_location" VALUES(28745,NULL,'Adamsville, TN',11548,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28746,NULL,'Adamsville, TN 38310',11548,222,NULL,50,16905,0);
INSERT INTO "django_geo_db_location" VALUES(28747,NULL,'Bath Springs, TN',11549,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28748,NULL,'Bath Springs, TN 38311',11549,222,NULL,50,16906,0);
INSERT INTO "django_geo_db_location" VALUES(28749,NULL,'Beech Bluff, TN',11550,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28750,NULL,'Beech Bluff, TN 38313',11550,222,NULL,50,16907,0);
INSERT INTO "django_geo_db_location" VALUES(28751,NULL,'Jackson, TN 38314',11547,222,NULL,50,16908,0);
INSERT INTO "django_geo_db_location" VALUES(28752,NULL,'Bethel Springs, TN',11551,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28753,NULL,'Bethel Springs, TN 38315',11551,222,NULL,50,16909,0);
INSERT INTO "django_geo_db_location" VALUES(28754,NULL,'Bradford, TN',11552,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28755,NULL,'Bradford, TN 38316',11552,222,NULL,50,16910,0);
INSERT INTO "django_geo_db_location" VALUES(28756,NULL,'Bruceton, TN',11553,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28757,NULL,'Bruceton, TN 38317',11553,222,NULL,50,16911,0);
INSERT INTO "django_geo_db_location" VALUES(28758,NULL,'Buena Vista, TN',11554,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28759,NULL,'Buena Vista, TN 38318',11554,222,NULL,50,16912,0);
INSERT INTO "django_geo_db_location" VALUES(28760,NULL,'Camden, TN',11555,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28761,NULL,'Camden, TN 38320',11555,222,NULL,50,16913,0);
INSERT INTO "django_geo_db_location" VALUES(28762,NULL,'Cedar Grove, TN',11556,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28763,NULL,'Cedar Grove, TN 38321',11556,222,NULL,50,16914,0);
INSERT INTO "django_geo_db_location" VALUES(28764,NULL,'Clarksburg, TN',11557,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28765,NULL,'Clarksburg, TN 38324',11557,222,NULL,50,16915,0);
INSERT INTO "django_geo_db_location" VALUES(28766,NULL,'Counce, TN',11558,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28767,NULL,'Counce, TN 38326',11558,222,NULL,50,16916,0);
INSERT INTO "django_geo_db_location" VALUES(28768,NULL,'Crump, TN',11559,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28769,NULL,'Crump, TN 38327',11559,222,NULL,50,16917,0);
INSERT INTO "django_geo_db_location" VALUES(28770,NULL,'Darden, TN',11560,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28771,NULL,'Darden, TN 38328',11560,222,NULL,50,16918,0);
INSERT INTO "django_geo_db_location" VALUES(28772,NULL,'Decaturville, TN',11561,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28773,NULL,'Decaturville, TN 38329',11561,222,NULL,50,16919,0);
INSERT INTO "django_geo_db_location" VALUES(28774,NULL,'Dyer, TN',11562,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28775,NULL,'Dyer, TN 38330',11562,222,NULL,50,16920,0);
INSERT INTO "django_geo_db_location" VALUES(28776,NULL,'Eaton, TN',11563,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28777,NULL,'Eaton, TN 38331',11563,222,NULL,50,16921,0);
INSERT INTO "django_geo_db_location" VALUES(28778,NULL,'Enville, TN',11564,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28779,NULL,'Enville, TN 38332',11564,222,NULL,50,16922,0);
INSERT INTO "django_geo_db_location" VALUES(28780,NULL,'Eva, TN',11565,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28781,NULL,'Eva, TN 38333',11565,222,NULL,50,16923,0);
INSERT INTO "django_geo_db_location" VALUES(28782,NULL,'Finger, TN',11566,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28783,NULL,'Finger, TN 38334',11566,222,NULL,50,16924,0);
INSERT INTO "django_geo_db_location" VALUES(28784,NULL,'Fruitvale, TN',11567,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28785,NULL,'Fruitvale, TN 38336',11567,222,NULL,50,16925,0);
INSERT INTO "django_geo_db_location" VALUES(28786,NULL,'Gadsden, TN',11568,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28787,NULL,'Gadsden, TN 38337',11568,222,NULL,50,16926,0);
INSERT INTO "django_geo_db_location" VALUES(28788,NULL,'Gibson, TN',11569,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28789,NULL,'Gibson, TN 38338',11569,222,NULL,50,16927,0);
INSERT INTO "django_geo_db_location" VALUES(28790,NULL,'Guys, TN',11570,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28791,NULL,'Guys, TN 38339',11570,222,NULL,50,16928,0);
INSERT INTO "django_geo_db_location" VALUES(28792,NULL,'Henderson, TN',11571,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28793,NULL,'Henderson, TN 38340',11571,222,NULL,50,16929,0);
INSERT INTO "django_geo_db_location" VALUES(28794,NULL,'Holladay, TN',11572,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28795,NULL,'Holladay, TN 38341',11572,222,NULL,50,16930,0);
INSERT INTO "django_geo_db_location" VALUES(28796,NULL,'Hollow Rock, TN',11573,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28797,NULL,'Hollow Rock, TN 38342',11573,222,NULL,50,16931,0);
INSERT INTO "django_geo_db_location" VALUES(28798,NULL,'Humboldt, TN',11574,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28799,NULL,'Humboldt, TN 38343',11574,222,NULL,50,16932,0);
INSERT INTO "django_geo_db_location" VALUES(28800,NULL,'Huntingdon, TN',11575,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28801,NULL,'Huntingdon, TN 38344',11575,222,NULL,50,16933,0);
INSERT INTO "django_geo_db_location" VALUES(28802,NULL,'Huron, TN',11576,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28803,NULL,'Huron, TN 38345',11576,222,NULL,50,16934,0);
INSERT INTO "django_geo_db_location" VALUES(28804,NULL,'Idlewild, TN',11577,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28805,NULL,'Idlewild, TN 38346',11577,222,NULL,50,16935,0);
INSERT INTO "django_geo_db_location" VALUES(28806,NULL,'Jacks Creek, TN',11578,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28807,NULL,'Jacks Creek, TN 38347',11578,222,NULL,50,16936,0);
INSERT INTO "django_geo_db_location" VALUES(28808,NULL,'Lavinia, TN',11579,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28809,NULL,'Lavinia, TN 38348',11579,222,NULL,50,16937,0);
INSERT INTO "django_geo_db_location" VALUES(28810,NULL,'Collinwood, TN',11580,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28811,NULL,'Collinwood, TN 38350',11580,222,NULL,50,16938,0);
INSERT INTO "django_geo_db_location" VALUES(28812,NULL,'Lexington, TN',11581,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28813,NULL,'Lexington, TN 38351',11581,222,NULL,50,16939,0);
INSERT INTO "django_geo_db_location" VALUES(28814,NULL,'Luray, TN',11582,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28815,NULL,'Luray, TN 38352',11582,222,NULL,50,16940,0);
INSERT INTO "django_geo_db_location" VALUES(28816,NULL,'Medina, TN',11583,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28817,NULL,'Medina, TN 38355',11583,222,NULL,50,16941,0);
INSERT INTO "django_geo_db_location" VALUES(28818,NULL,'Medon, TN',11584,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28819,NULL,'Medon, TN 38356',11584,222,NULL,50,16942,0);
INSERT INTO "django_geo_db_location" VALUES(28820,NULL,'Michie, TN',11585,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28821,NULL,'Michie, TN 38357',11585,222,NULL,50,16943,0);
INSERT INTO "django_geo_db_location" VALUES(28822,NULL,'Milan, TN',11586,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28823,NULL,'Milan, TN 38358',11586,222,NULL,50,16944,0);
INSERT INTO "django_geo_db_location" VALUES(28824,NULL,'Milledgeville, TN',11587,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28825,NULL,'Milledgeville, TN 38359',11587,222,NULL,50,16945,0);
INSERT INTO "django_geo_db_location" VALUES(28826,NULL,'Morris Chapel, TN',11588,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28827,NULL,'Morris Chapel, TN 38361',11588,222,NULL,50,16946,0);
INSERT INTO "django_geo_db_location" VALUES(28828,NULL,'Oakfield, TN',11589,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28829,NULL,'Oakfield, TN 38362',11589,222,NULL,50,16947,0);
INSERT INTO "django_geo_db_location" VALUES(28830,NULL,'Parsons, TN',11590,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28831,NULL,'Parsons, TN 38363',11590,222,NULL,50,16948,0);
INSERT INTO "django_geo_db_location" VALUES(28832,NULL,'Pickwick Dam, TN',11591,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28833,NULL,'Pickwick Dam, TN 38365',11591,222,NULL,50,16949,0);
INSERT INTO "django_geo_db_location" VALUES(28834,NULL,'Pinson, TN',11592,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28835,NULL,'Pinson, TN 38366',11592,222,NULL,50,16950,0);
INSERT INTO "django_geo_db_location" VALUES(28836,NULL,'Ramer, TN',11593,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28837,NULL,'Ramer, TN 38367',11593,222,NULL,50,16951,0);
INSERT INTO "django_geo_db_location" VALUES(28838,NULL,'Reagan, TN',11594,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28839,NULL,'Reagan, TN 38368',11594,222,NULL,50,16952,0);
INSERT INTO "django_geo_db_location" VALUES(28840,NULL,'Rutherford, TN',11595,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28841,NULL,'Rutherford, TN 38369',11595,222,NULL,50,16953,0);
INSERT INTO "django_geo_db_location" VALUES(28842,NULL,'Saltillo, TN',11596,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28843,NULL,'Saltillo, TN 38370',11596,222,NULL,50,16954,0);
INSERT INTO "django_geo_db_location" VALUES(28844,NULL,'Sardis, TN',11597,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28845,NULL,'Sardis, TN 38371',11597,222,NULL,50,16955,0);
INSERT INTO "django_geo_db_location" VALUES(28846,NULL,'Savannah, TN',11598,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28847,NULL,'Savannah, TN 38372',11598,222,NULL,50,16956,0);
INSERT INTO "django_geo_db_location" VALUES(28848,NULL,'Scotts Hill, TN',11599,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28849,NULL,'Scotts Hill, TN 38374',11599,222,NULL,50,16957,0);
INSERT INTO "django_geo_db_location" VALUES(28850,NULL,'Selmer, TN',11600,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28851,NULL,'Selmer, TN 38375',11600,222,NULL,50,16958,0);
INSERT INTO "django_geo_db_location" VALUES(28852,NULL,'Shiloh, TN',11601,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28853,NULL,'Shiloh, TN 38376',11601,222,NULL,50,16959,0);
INSERT INTO "django_geo_db_location" VALUES(28854,NULL,'Silerton, TN',11602,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28855,NULL,'Silerton, TN 38377',11602,222,NULL,50,16960,0);
INSERT INTO "django_geo_db_location" VALUES(28856,NULL,'Spring Creek, TN',11603,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28857,NULL,'Spring Creek, TN 38378',11603,222,NULL,50,16961,0);
INSERT INTO "django_geo_db_location" VALUES(28858,NULL,'Stantonville, TN',11604,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28859,NULL,'Stantonville, TN 38379',11604,222,NULL,50,16962,0);
INSERT INTO "django_geo_db_location" VALUES(28860,NULL,'Sugar Tree, TN',11605,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28861,NULL,'Sugar Tree, TN 38380',11605,222,NULL,50,16963,0);
INSERT INTO "django_geo_db_location" VALUES(28862,NULL,'Toone, TN',11606,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28863,NULL,'Toone, TN 38381',11606,222,NULL,50,16964,0);
INSERT INTO "django_geo_db_location" VALUES(28864,NULL,'Trenton, TN',11607,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28865,NULL,'Trenton, TN 38382',11607,222,NULL,50,16965,0);
INSERT INTO "django_geo_db_location" VALUES(28866,NULL,'Toone, TN 38384',11606,222,NULL,50,16966,0);
INSERT INTO "django_geo_db_location" VALUES(28867,NULL,'Westport, TN',11608,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28868,NULL,'Westport, TN 38387',11608,222,NULL,50,16967,0);
INSERT INTO "django_geo_db_location" VALUES(28869,NULL,'Wildersville, TN',11609,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28870,NULL,'Wildersville, TN 38388',11609,222,NULL,50,16968,0);
INSERT INTO "django_geo_db_location" VALUES(28871,NULL,'Yorkville, TN',11610,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28872,NULL,'Yorkville, TN 38389',11610,222,NULL,50,16969,0);
INSERT INTO "django_geo_db_location" VALUES(28873,NULL,'Yuma, TN',11611,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28874,NULL,'Yuma, TN 38390',11611,222,NULL,50,16970,0);
INSERT INTO "django_geo_db_location" VALUES(28875,NULL,'Denmark, TN',11612,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28876,NULL,'Denmark, TN 38391',11612,222,NULL,50,16971,0);
INSERT INTO "django_geo_db_location" VALUES(28877,NULL,'Mercer, TN',11613,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28878,NULL,'Mercer, TN 38392',11613,222,NULL,50,16972,0);
INSERT INTO "django_geo_db_location" VALUES(28879,NULL,'Chewalla, TN',11614,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28880,NULL,'Chewalla, TN 38393',11614,222,NULL,50,16973,0);
INSERT INTO "django_geo_db_location" VALUES(28881,NULL,'Columbia, TN',11615,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28882,NULL,'Columbia, TN 38401',11615,222,NULL,50,16974,0);
INSERT INTO "django_geo_db_location" VALUES(28883,NULL,'Columbia, TN 38402',11615,222,NULL,50,16975,0);
INSERT INTO "django_geo_db_location" VALUES(28884,NULL,'Clifton, TN',11616,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28885,NULL,'Clifton, TN 38425',11616,222,NULL,50,16976,0);
INSERT INTO "django_geo_db_location" VALUES(28886,NULL,'Ardmore, TN',11617,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28887,NULL,'Ardmore, TN 38449',11617,222,NULL,50,16977,0);
INSERT INTO "django_geo_db_location" VALUES(28888,NULL,'Collinwood, TN 38450',11580,222,NULL,50,16978,0);
INSERT INTO "django_geo_db_location" VALUES(28889,NULL,'Culleoka, TN',11618,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28890,NULL,'Culleoka, TN 38451',11618,222,NULL,50,16979,0);
INSERT INTO "django_geo_db_location" VALUES(28891,NULL,'Cypress Inn, TN',11619,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28892,NULL,'Cypress Inn, TN 38452',11619,222,NULL,50,16980,0);
INSERT INTO "django_geo_db_location" VALUES(28893,NULL,'Dellrose, TN',11620,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28894,NULL,'Dellrose, TN 38453',11620,222,NULL,50,16981,0);
INSERT INTO "django_geo_db_location" VALUES(28895,NULL,'Duck River, TN',11621,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28896,NULL,'Duck River, TN 38454',11621,222,NULL,50,16982,0);
INSERT INTO "django_geo_db_location" VALUES(28897,NULL,'Elkton, TN',11622,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28898,NULL,'Elkton, TN 38455',11622,222,NULL,50,16983,0);
INSERT INTO "django_geo_db_location" VALUES(28899,NULL,'Ethridge, TN',11623,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28900,NULL,'Ethridge, TN 38456',11623,222,NULL,50,16984,0);
INSERT INTO "django_geo_db_location" VALUES(28901,NULL,'Five Points, TN',11624,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28902,NULL,'Five Points, TN 38457',11624,222,NULL,50,16985,0);
INSERT INTO "django_geo_db_location" VALUES(28903,NULL,'Frankewing, TN',11625,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28904,NULL,'Frankewing, TN 38459',11625,222,NULL,50,16986,0);
INSERT INTO "django_geo_db_location" VALUES(28905,NULL,'Goodspring, TN',11626,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28906,NULL,'Goodspring, TN 38460',11626,222,NULL,50,16987,0);
INSERT INTO "django_geo_db_location" VALUES(28907,NULL,'Hampshire, TN',11627,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28908,NULL,'Hampshire, TN 38461',11627,222,NULL,50,16988,0);
INSERT INTO "django_geo_db_location" VALUES(28909,NULL,'Hohenwald, TN',11628,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28910,NULL,'Hohenwald, TN 38462',11628,222,NULL,50,16989,0);
INSERT INTO "django_geo_db_location" VALUES(28911,NULL,'Iron City, TN',11629,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28912,NULL,'Iron City, TN 38463',11629,222,NULL,50,16990,0);
INSERT INTO "django_geo_db_location" VALUES(28913,NULL,'Lawrenceburg, TN',11630,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28914,NULL,'Lawrenceburg, TN 38464',11630,222,NULL,50,16991,0);
INSERT INTO "django_geo_db_location" VALUES(28915,NULL,'Leoma, TN',11631,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28916,NULL,'Leoma, TN 38468',11631,222,NULL,50,16992,0);
INSERT INTO "django_geo_db_location" VALUES(28917,NULL,'Loretto, TN',11632,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28918,NULL,'Loretto, TN 38469',11632,222,NULL,50,16993,0);
INSERT INTO "django_geo_db_location" VALUES(28919,NULL,'Lutts, TN',11633,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28920,NULL,'Lutts, TN 38471',11633,222,NULL,50,16994,0);
INSERT INTO "django_geo_db_location" VALUES(28921,NULL,'Lynnville, TN',11634,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28922,NULL,'Lynnville, TN 38472',11634,222,NULL,50,16995,0);
INSERT INTO "django_geo_db_location" VALUES(28923,NULL,'Minor Hill, TN',11635,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28924,NULL,'Minor Hill, TN 38473',11635,222,NULL,50,16996,0);
INSERT INTO "django_geo_db_location" VALUES(28925,NULL,'Mount Pleasant, TN',11636,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28926,NULL,'Mount Pleasant, TN 38474',11636,222,NULL,50,16997,0);
INSERT INTO "django_geo_db_location" VALUES(28927,NULL,'Olivehill, TN',11637,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28928,NULL,'Olivehill, TN 38475',11637,222,NULL,50,16998,0);
INSERT INTO "django_geo_db_location" VALUES(28929,NULL,'Primm Springs, TN',11638,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28930,NULL,'Primm Springs, TN 38476',11638,222,NULL,50,16999,0);
INSERT INTO "django_geo_db_location" VALUES(28931,NULL,'Prospect, TN',11639,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28932,NULL,'Prospect, TN 38477',11639,222,NULL,50,17000,0);
INSERT INTO "django_geo_db_location" VALUES(28933,NULL,'Pulaski, TN',11640,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28934,NULL,'Pulaski, TN 38478',11640,222,NULL,50,17001,0);
INSERT INTO "django_geo_db_location" VALUES(28935,NULL,'Saint Joseph, TN',11641,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28936,NULL,'Saint Joseph, TN 38481',11641,222,NULL,50,17002,0);
INSERT INTO "django_geo_db_location" VALUES(28937,NULL,'Santa Fe, TN',11642,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28938,NULL,'Santa Fe, TN 38482',11642,222,NULL,50,17003,0);
INSERT INTO "django_geo_db_location" VALUES(28939,NULL,'Summertown, TN',11643,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28940,NULL,'Summertown, TN 38483',11643,222,NULL,50,17004,0);
INSERT INTO "django_geo_db_location" VALUES(28941,NULL,'Waynesboro, TN',11644,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28942,NULL,'Waynesboro, TN 38485',11644,222,NULL,50,17005,0);
INSERT INTO "django_geo_db_location" VALUES(28943,NULL,'Westpoint, TN',11645,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28944,NULL,'Westpoint, TN 38486',11645,222,NULL,50,17006,0);
INSERT INTO "django_geo_db_location" VALUES(28945,NULL,'Williamsport, TN',11646,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28946,NULL,'Williamsport, TN 38487',11646,222,NULL,50,17007,0);
INSERT INTO "django_geo_db_location" VALUES(28947,NULL,'Taft, TN',11647,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28948,NULL,'Taft, TN 38488',11647,222,NULL,50,17008,0);
INSERT INTO "django_geo_db_location" VALUES(28949,NULL,'Cookeville, TN',11648,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28950,NULL,'Cookeville, TN 38501',11648,222,NULL,50,17009,0);
INSERT INTO "django_geo_db_location" VALUES(28951,NULL,'Cookeville, TN 38502',11648,222,NULL,50,17010,0);
INSERT INTO "django_geo_db_location" VALUES(28952,NULL,'Cookeville, TN 38503',11648,222,NULL,50,17011,0);
INSERT INTO "django_geo_db_location" VALUES(28953,NULL,'Allardt, TN',11649,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28954,NULL,'Allardt, TN 38504',11649,222,NULL,50,17012,0);
INSERT INTO "django_geo_db_location" VALUES(28955,NULL,'Cookeville, TN 38505',11648,222,NULL,50,17013,0);
INSERT INTO "django_geo_db_location" VALUES(28956,NULL,'Cookeville, TN 38506',11648,222,NULL,50,17014,0);
INSERT INTO "django_geo_db_location" VALUES(28957,NULL,'Clarksdale, MS',11650,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28958,NULL,'Clarksdale, MS 38514',11650,222,NULL,42,17015,0);
INSERT INTO "django_geo_db_location" VALUES(28959,NULL,'Trezevant, TN 38528',11542,222,NULL,50,17016,0);
INSERT INTO "django_geo_db_location" VALUES(28960,NULL,'Allons, TN',11651,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28961,NULL,'Allons, TN 38541',11651,222,NULL,50,17017,0);
INSERT INTO "django_geo_db_location" VALUES(28962,NULL,'Allred, TN',11652,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28963,NULL,'Allred, TN 38542',11652,222,NULL,50,17018,0);
INSERT INTO "django_geo_db_location" VALUES(28964,NULL,'Alpine, TN',11653,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28965,NULL,'Alpine, TN 38543',11653,222,NULL,50,17019,0);
INSERT INTO "django_geo_db_location" VALUES(28966,NULL,'Baxter, TN',11654,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28967,NULL,'Baxter, TN 38544',11654,222,NULL,50,17020,0);
INSERT INTO "django_geo_db_location" VALUES(28968,NULL,'Bloomington Springs, TN',11655,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28969,NULL,'Bloomington Springs, TN 38545',11655,222,NULL,50,17021,0);
INSERT INTO "django_geo_db_location" VALUES(28970,NULL,'Brush Creek, TN',11656,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28971,NULL,'Brush Creek, TN 38547',11656,222,NULL,50,17022,0);
INSERT INTO "django_geo_db_location" VALUES(28972,NULL,'Buffalo Valley, TN',11657,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28973,NULL,'Buffalo Valley, TN 38548',11657,222,NULL,50,17023,0);
INSERT INTO "django_geo_db_location" VALUES(28974,NULL,'Byrdstown, TN',11658,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28975,NULL,'Byrdstown, TN 38549',11658,222,NULL,50,17024,0);
INSERT INTO "django_geo_db_location" VALUES(28976,NULL,'Campaign, TN',11659,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28977,NULL,'Campaign, TN 38550',11659,222,NULL,50,17025,0);
INSERT INTO "django_geo_db_location" VALUES(28978,NULL,'Celina, TN',11660,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28979,NULL,'Celina, TN 38551',11660,222,NULL,50,17026,0);
INSERT INTO "django_geo_db_location" VALUES(28980,NULL,'Chestnut Mound, TN',11661,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28981,NULL,'Chestnut Mound, TN 38552',11661,222,NULL,50,17027,0);
INSERT INTO "django_geo_db_location" VALUES(28982,NULL,'Clarkrange, TN',11662,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28983,NULL,'Clarkrange, TN 38553',11662,222,NULL,50,17028,0);
INSERT INTO "django_geo_db_location" VALUES(28984,NULL,'Crawford, TN',11663,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28985,NULL,'Crawford, TN 38554',11663,222,NULL,50,17029,0);
INSERT INTO "django_geo_db_location" VALUES(28986,NULL,'Crossville, TN',11664,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28987,NULL,'Crossville, TN 38555',11664,222,NULL,50,17030,0);
INSERT INTO "django_geo_db_location" VALUES(28988,NULL,'Jamestown, TN',11665,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28989,NULL,'Jamestown, TN 38556',11665,222,NULL,50,17031,0);
INSERT INTO "django_geo_db_location" VALUES(28990,NULL,'Crossville, TN 38557',11664,222,NULL,50,17032,0);
INSERT INTO "django_geo_db_location" VALUES(28991,NULL,'Crossville, TN 38558',11664,222,NULL,50,17033,0);
INSERT INTO "django_geo_db_location" VALUES(28992,NULL,'Doyle, TN',11666,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28993,NULL,'Doyle, TN 38559',11666,222,NULL,50,17034,0);
INSERT INTO "django_geo_db_location" VALUES(28994,NULL,'Elmwood, TN',11667,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28995,NULL,'Elmwood, TN 38560',11667,222,NULL,50,17035,0);
INSERT INTO "django_geo_db_location" VALUES(28996,NULL,'Gainesboro, TN',11668,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28997,NULL,'Gainesboro, TN 38562',11668,222,NULL,50,17036,0);
INSERT INTO "django_geo_db_location" VALUES(28998,NULL,'Gordonsville, TN',11669,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(28999,NULL,'Gordonsville, TN 38563',11669,222,NULL,50,17037,0);
INSERT INTO "django_geo_db_location" VALUES(29000,NULL,'Granville, TN',11670,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29001,NULL,'Granville, TN 38564',11670,222,NULL,50,17038,0);
INSERT INTO "django_geo_db_location" VALUES(29002,NULL,'Grimsley, TN',11671,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29003,NULL,'Grimsley, TN 38565',11671,222,NULL,50,17039,0);
INSERT INTO "django_geo_db_location" VALUES(29004,NULL,'Hickman, TN',11672,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29005,NULL,'Hickman, TN 38567',11672,222,NULL,50,17040,0);
INSERT INTO "django_geo_db_location" VALUES(29006,NULL,'Hilham, TN',11673,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29007,NULL,'Hilham, TN 38568',11673,222,NULL,50,17041,0);
INSERT INTO "django_geo_db_location" VALUES(29008,NULL,'Lancaster, TN',11674,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29009,NULL,'Lancaster, TN 38569',11674,222,NULL,50,17042,0);
INSERT INTO "django_geo_db_location" VALUES(29010,NULL,'Livingston, TN',11675,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29011,NULL,'Livingston, TN 38570',11675,222,NULL,50,17043,0);
INSERT INTO "django_geo_db_location" VALUES(29012,NULL,'Crossville, TN 38571',11664,222,NULL,50,17044,0);
INSERT INTO "django_geo_db_location" VALUES(29013,NULL,'Pleasant Hill, TN',11676,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29014,NULL,'Pleasant Hill, TN 38572',11676,222,NULL,50,17045,0);
INSERT INTO "django_geo_db_location" VALUES(29015,NULL,'Monroe, TN',11677,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29016,NULL,'Monroe, TN 38573',11677,222,NULL,50,17046,0);
INSERT INTO "django_geo_db_location" VALUES(29017,NULL,'Monterey, TN',11678,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29018,NULL,'Monterey, TN 38574',11678,222,NULL,50,17047,0);
INSERT INTO "django_geo_db_location" VALUES(29019,NULL,'Moss, TN',11679,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29020,NULL,'Moss, TN 38575',11679,222,NULL,50,17048,0);
INSERT INTO "django_geo_db_location" VALUES(29021,NULL,'Pall Mall, TN',11680,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29022,NULL,'Pall Mall, TN 38577',11680,222,NULL,50,17049,0);
INSERT INTO "django_geo_db_location" VALUES(29023,NULL,'Pleasant Hill, TN 38578',11676,222,NULL,50,17050,0);
INSERT INTO "django_geo_db_location" VALUES(29024,NULL,'Quebeck, TN',11681,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29025,NULL,'Quebeck, TN 38579',11681,222,NULL,50,17051,0);
INSERT INTO "django_geo_db_location" VALUES(29026,NULL,'Rickman, TN',11682,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29027,NULL,'Rickman, TN 38580',11682,222,NULL,50,17052,0);
INSERT INTO "django_geo_db_location" VALUES(29028,NULL,'Rock Island, TN',11683,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29029,NULL,'Rock Island, TN 38581',11683,222,NULL,50,17053,0);
INSERT INTO "django_geo_db_location" VALUES(29030,NULL,'Silver Point, TN',11684,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29031,NULL,'Silver Point, TN 38582',11684,222,NULL,50,17054,0);
INSERT INTO "django_geo_db_location" VALUES(29032,NULL,'Sparta, TN',11685,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29033,NULL,'Sparta, TN 38583',11685,222,NULL,50,17055,0);
INSERT INTO "django_geo_db_location" VALUES(29034,NULL,'Spencer, TN',11686,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29035,NULL,'Spencer, TN 38585',11686,222,NULL,50,17056,0);
INSERT INTO "django_geo_db_location" VALUES(29036,NULL,'Walling, TN',11687,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29037,NULL,'Walling, TN 38587',11687,222,NULL,50,17057,0);
INSERT INTO "django_geo_db_location" VALUES(29038,NULL,'Whitleyville, TN',11688,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29039,NULL,'Whitleyville, TN 38588',11688,222,NULL,50,17058,0);
INSERT INTO "django_geo_db_location" VALUES(29040,NULL,'Wilder, TN',11689,222,NULL,50,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29041,NULL,'Wilder, TN 38589',11689,222,NULL,50,17059,0);
INSERT INTO "django_geo_db_location" VALUES(29042,NULL,'Sumner, MS',11690,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29043,NULL,'Sumner, MS 38597',11690,222,NULL,42,17060,0);
INSERT INTO "django_geo_db_location" VALUES(29044,NULL,'Abbeville, MS',11691,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29045,NULL,'Abbeville, MS 38601',11691,222,NULL,42,17061,0);
INSERT INTO "django_geo_db_location" VALUES(29046,NULL,'Arkabutla, MS',11692,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29047,NULL,'Arkabutla, MS 38602',11692,222,NULL,42,17062,0);
INSERT INTO "django_geo_db_location" VALUES(29048,NULL,'Ashland, MS',11693,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29049,NULL,'Ashland, MS 38603',11693,222,NULL,42,17063,0);
INSERT INTO "django_geo_db_location" VALUES(29050,NULL,'Batesville, MS',11694,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29051,NULL,'Batesville, MS 38606',11694,222,NULL,42,17064,0);
INSERT INTO "django_geo_db_location" VALUES(29052,NULL,'Belen, MS',11695,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29053,NULL,'Belen, MS 38609',11695,222,NULL,42,17065,0);
INSERT INTO "django_geo_db_location" VALUES(29054,NULL,'Blue Mountain, MS',11696,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29055,NULL,'Blue Mountain, MS 38610',11696,222,NULL,42,17066,0);
INSERT INTO "django_geo_db_location" VALUES(29056,NULL,'Byhalia, MS',11697,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29057,NULL,'Byhalia, MS 38611',11697,222,NULL,42,17067,0);
INSERT INTO "django_geo_db_location" VALUES(29058,NULL,'Clarksdale, MS 38614',11650,222,NULL,42,17068,0);
INSERT INTO "django_geo_db_location" VALUES(29059,NULL,'Coahoma, MS',11698,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29060,NULL,'Coahoma, MS 38617',11698,222,NULL,42,17069,0);
INSERT INTO "django_geo_db_location" VALUES(29061,NULL,'Coldwater, MS',11699,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29062,NULL,'Coldwater, MS 38618',11699,222,NULL,42,17070,0);
INSERT INTO "django_geo_db_location" VALUES(29063,NULL,'Como, MS',11700,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29064,NULL,'Como, MS 38619',11700,222,NULL,42,17071,0);
INSERT INTO "django_geo_db_location" VALUES(29065,NULL,'Courtland, MS',11701,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29066,NULL,'Courtland, MS 38620',11701,222,NULL,42,17072,0);
INSERT INTO "django_geo_db_location" VALUES(29067,NULL,'Crenshaw, MS',11702,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29068,NULL,'Crenshaw, MS 38621',11702,222,NULL,42,17073,0);
INSERT INTO "django_geo_db_location" VALUES(29069,NULL,'Crowder, MS',11703,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29070,NULL,'Crowder, MS 38622',11703,222,NULL,42,17074,0);
INSERT INTO "django_geo_db_location" VALUES(29071,NULL,'Darling, MS',11704,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29072,NULL,'Darling, MS 38623',11704,222,NULL,42,17075,0);
INSERT INTO "django_geo_db_location" VALUES(29073,NULL,'Dumas, MS',11705,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29074,NULL,'Dumas, MS 38625',11705,222,NULL,42,17076,0);
INSERT INTO "django_geo_db_location" VALUES(29075,NULL,'Dundee, MS',11706,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29076,NULL,'Dundee, MS 38626',11706,222,NULL,42,17077,0);
INSERT INTO "django_geo_db_location" VALUES(29077,NULL,'Etta, MS',11707,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29078,NULL,'Etta, MS 38627',11707,222,NULL,42,17078,0);
INSERT INTO "django_geo_db_location" VALUES(29079,NULL,'Falcon, MS',11708,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29080,NULL,'Falcon, MS 38628',11708,222,NULL,42,17079,0);
INSERT INTO "django_geo_db_location" VALUES(29081,NULL,'Falkner, MS',11709,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29082,NULL,'Falkner, MS 38629',11709,222,NULL,42,17080,0);
INSERT INTO "django_geo_db_location" VALUES(29083,NULL,'Farrell, MS',11710,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29084,NULL,'Farrell, MS 38630',11710,222,NULL,42,17081,0);
INSERT INTO "django_geo_db_location" VALUES(29085,NULL,'Friars Point, MS',11711,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29086,NULL,'Friars Point, MS 38631',11711,222,NULL,42,17082,0);
INSERT INTO "django_geo_db_location" VALUES(29087,NULL,'Hernando, MS',11712,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29088,NULL,'Hernando, MS 38632',11712,222,NULL,42,17083,0);
INSERT INTO "django_geo_db_location" VALUES(29089,NULL,'Hickory Flat, MS',11713,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29090,NULL,'Hickory Flat, MS 38633',11713,222,NULL,42,17084,0);
INSERT INTO "django_geo_db_location" VALUES(29091,NULL,'Holly Springs, MS',11714,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29092,NULL,'Holly Springs, MS 38634',11714,222,NULL,42,17085,0);
INSERT INTO "django_geo_db_location" VALUES(29093,NULL,'Holly Springs, MS 38635',11714,222,NULL,42,17086,0);
INSERT INTO "django_geo_db_location" VALUES(29094,NULL,'Horn Lake, MS',11715,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29095,NULL,'Horn Lake, MS 38637',11715,222,NULL,42,17087,0);
INSERT INTO "django_geo_db_location" VALUES(29096,NULL,'Independence, MS',11716,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29097,NULL,'Independence, MS 38638',11716,222,NULL,42,17088,0);
INSERT INTO "django_geo_db_location" VALUES(29098,NULL,'Jonestown, MS',11717,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29099,NULL,'Jonestown, MS 38639',11717,222,NULL,42,17089,0);
INSERT INTO "django_geo_db_location" VALUES(29100,NULL,'Lake Cormorant, MS',11718,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29101,NULL,'Lake Cormorant, MS 38641',11718,222,NULL,42,17090,0);
INSERT INTO "django_geo_db_location" VALUES(29102,NULL,'Lamar, MS',11719,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29103,NULL,'Lamar, MS 38642',11719,222,NULL,42,17091,0);
INSERT INTO "django_geo_db_location" VALUES(29104,NULL,'Lambert, MS',11720,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29105,NULL,'Lambert, MS 38643',11720,222,NULL,42,17092,0);
INSERT INTO "django_geo_db_location" VALUES(29106,NULL,'Lula, MS',11721,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29107,NULL,'Lula, MS 38644',11721,222,NULL,42,17093,0);
INSERT INTO "django_geo_db_location" VALUES(29108,NULL,'Lyon, MS',11722,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29109,NULL,'Lyon, MS 38645',11722,222,NULL,42,17094,0);
INSERT INTO "django_geo_db_location" VALUES(29110,NULL,'Marks, MS',11723,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29111,NULL,'Marks, MS 38646',11723,222,NULL,42,17095,0);
INSERT INTO "django_geo_db_location" VALUES(29112,NULL,'Michigan City, MS',11724,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29113,NULL,'Michigan City, MS 38647',11724,222,NULL,42,17096,0);
INSERT INTO "django_geo_db_location" VALUES(29114,NULL,'Mount Pleasant, MS',11725,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29115,NULL,'Mount Pleasant, MS 38649',11725,222,NULL,42,17097,0);
INSERT INTO "django_geo_db_location" VALUES(29116,NULL,'Myrtle, MS',11726,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29117,NULL,'Myrtle, MS 38650',11726,222,NULL,42,17098,0);
INSERT INTO "django_geo_db_location" VALUES(29118,NULL,'Nesbit, MS',11727,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29119,NULL,'Nesbit, MS 38651',11727,222,NULL,42,17099,0);
INSERT INTO "django_geo_db_location" VALUES(29120,NULL,'New Albany, MS',11728,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29121,NULL,'New Albany, MS 38652',11728,222,NULL,42,17100,0);
INSERT INTO "django_geo_db_location" VALUES(29122,NULL,'Olive Branch, MS',11729,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29123,NULL,'Olive Branch, MS 38654',11729,222,NULL,42,17101,0);
INSERT INTO "django_geo_db_location" VALUES(29124,NULL,'Oxford, MS',11730,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29125,NULL,'Oxford, MS 38655',11730,222,NULL,42,17102,0);
INSERT INTO "django_geo_db_location" VALUES(29126,NULL,'Pope, MS',11731,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29127,NULL,'Pope, MS 38658',11731,222,NULL,42,17103,0);
INSERT INTO "django_geo_db_location" VALUES(29128,NULL,'Potts Camp, MS',11732,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29129,NULL,'Potts Camp, MS 38659',11732,222,NULL,42,17104,0);
INSERT INTO "django_geo_db_location" VALUES(29130,NULL,'Red Banks, MS',11733,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29131,NULL,'Red Banks, MS 38661',11733,222,NULL,42,17105,0);
INSERT INTO "django_geo_db_location" VALUES(29132,NULL,'Ripley, MS',11734,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29133,NULL,'Ripley, MS 38663',11734,222,NULL,42,17106,0);
INSERT INTO "django_geo_db_location" VALUES(29134,NULL,'Robinsonville, MS',11735,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29135,NULL,'Robinsonville, MS 38664',11735,222,NULL,42,17107,0);
INSERT INTO "django_geo_db_location" VALUES(29136,NULL,'Sarah, MS',11736,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29137,NULL,'Sarah, MS 38665',11736,222,NULL,42,17108,0);
INSERT INTO "django_geo_db_location" VALUES(29138,NULL,'Sardis, MS',11737,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29139,NULL,'Sardis, MS 38666',11737,222,NULL,42,17109,0);
INSERT INTO "django_geo_db_location" VALUES(29140,NULL,'Senatobia, MS',11738,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29141,NULL,'Senatobia, MS 38668',11738,222,NULL,42,17110,0);
INSERT INTO "django_geo_db_location" VALUES(29142,NULL,'Sherard, MS',11739,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29143,NULL,'Sherard, MS 38669',11739,222,NULL,42,17111,0);
INSERT INTO "django_geo_db_location" VALUES(29144,NULL,'Sledge, MS',11740,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29145,NULL,'Sledge, MS 38670',11740,222,NULL,42,17112,0);
INSERT INTO "django_geo_db_location" VALUES(29146,NULL,'Southaven, MS',11741,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29147,NULL,'Southaven, MS 38671',11741,222,NULL,42,17113,0);
INSERT INTO "django_geo_db_location" VALUES(29148,NULL,'Southaven, MS 38672',11741,222,NULL,42,17114,0);
INSERT INTO "django_geo_db_location" VALUES(29149,NULL,'Taylor, MS',11742,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29150,NULL,'Taylor, MS 38673',11742,222,NULL,42,17115,0);
INSERT INTO "django_geo_db_location" VALUES(29151,NULL,'Tiplersville, MS',11743,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29152,NULL,'Tiplersville, MS 38674',11743,222,NULL,42,17116,0);
INSERT INTO "django_geo_db_location" VALUES(29153,NULL,'Tula, MS',11744,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29154,NULL,'Tula, MS 38675',11744,222,NULL,42,17117,0);
INSERT INTO "django_geo_db_location" VALUES(29155,NULL,'Tunica, MS',11745,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29156,NULL,'Tunica, MS 38676',11745,222,NULL,42,17118,0);
INSERT INTO "django_geo_db_location" VALUES(29157,NULL,'University, MS',11746,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29158,NULL,'University, MS 38677',11746,222,NULL,42,17119,0);
INSERT INTO "django_geo_db_location" VALUES(29159,NULL,'Victoria, MS',11747,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29160,NULL,'Victoria, MS 38679',11747,222,NULL,42,17120,0);
INSERT INTO "django_geo_db_location" VALUES(29161,NULL,'Walls, MS',11748,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29162,NULL,'Walls, MS 38680',11748,222,NULL,42,17121,0);
INSERT INTO "django_geo_db_location" VALUES(29163,NULL,'Walnut, MS',11749,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29164,NULL,'Walnut, MS 38683',11749,222,NULL,42,17122,0);
INSERT INTO "django_geo_db_location" VALUES(29165,NULL,'Waterford, MS',11750,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29166,NULL,'Waterford, MS 38685',11750,222,NULL,42,17123,0);
INSERT INTO "django_geo_db_location" VALUES(29167,NULL,'Walls, MS 38686',11748,222,NULL,42,17124,0);
INSERT INTO "django_geo_db_location" VALUES(29168,NULL,'Water Valley, MS',11751,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29169,NULL,'Water Valley, MS 38695',11751,222,NULL,42,17125,0);
INSERT INTO "django_geo_db_location" VALUES(29170,NULL,'Greenville, MS',11752,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29171,NULL,'Greenville, MS 38701',11752,222,NULL,42,17126,0);
INSERT INTO "django_geo_db_location" VALUES(29172,NULL,'Greenville, MS 38702',11752,222,NULL,42,17127,0);
INSERT INTO "django_geo_db_location" VALUES(29173,NULL,'Greenville, MS 38703',11752,222,NULL,42,17128,0);
INSERT INTO "django_geo_db_location" VALUES(29174,NULL,'Greenville, MS 38704',11752,222,NULL,42,17129,0);
INSERT INTO "django_geo_db_location" VALUES(29175,NULL,'Alligator, MS',11753,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29176,NULL,'Alligator, MS 38720',11753,222,NULL,42,17130,0);
INSERT INTO "django_geo_db_location" VALUES(29177,NULL,'Anguilla, MS',11754,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29178,NULL,'Anguilla, MS 38721',11754,222,NULL,42,17131,0);
INSERT INTO "django_geo_db_location" VALUES(29179,NULL,'Arcola, MS',11755,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29180,NULL,'Arcola, MS 38722',11755,222,NULL,42,17132,0);
INSERT INTO "django_geo_db_location" VALUES(29181,NULL,'Avon, MS',11756,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29182,NULL,'Avon, MS 38723',11756,222,NULL,42,17133,0);
INSERT INTO "django_geo_db_location" VALUES(29183,NULL,'Benoit, MS',11757,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29184,NULL,'Benoit, MS 38725',11757,222,NULL,42,17134,0);
INSERT INTO "django_geo_db_location" VALUES(29185,NULL,'Beulah, MS',11758,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29186,NULL,'Beulah, MS 38726',11758,222,NULL,42,17135,0);
INSERT INTO "django_geo_db_location" VALUES(29187,NULL,'Boyle, MS',11759,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29188,NULL,'Boyle, MS 38730',11759,222,NULL,42,17136,0);
INSERT INTO "django_geo_db_location" VALUES(29189,NULL,'Chatham, MS',11760,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29190,NULL,'Chatham, MS 38731',11760,222,NULL,42,17137,0);
INSERT INTO "django_geo_db_location" VALUES(29191,NULL,'Cleveland, MS',11761,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29192,NULL,'Cleveland, MS 38732',11761,222,NULL,42,17138,0);
INSERT INTO "django_geo_db_location" VALUES(29193,NULL,'Cleveland, MS 38733',11761,222,NULL,42,17139,0);
INSERT INTO "django_geo_db_location" VALUES(29194,NULL,'Doddsville, MS',11762,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29195,NULL,'Doddsville, MS 38736',11762,222,NULL,42,17140,0);
INSERT INTO "django_geo_db_location" VALUES(29196,NULL,'Drew, MS',11763,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29197,NULL,'Drew, MS 38737',11763,222,NULL,42,17141,0);
INSERT INTO "django_geo_db_location" VALUES(29198,NULL,'Parchman, MS',11764,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29199,NULL,'Parchman, MS 38738',11764,222,NULL,42,17142,0);
INSERT INTO "django_geo_db_location" VALUES(29200,NULL,'Dublin, MS',11765,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29201,NULL,'Dublin, MS 38739',11765,222,NULL,42,17143,0);
INSERT INTO "django_geo_db_location" VALUES(29202,NULL,'Duncan, MS',11766,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29203,NULL,'Duncan, MS 38740',11766,222,NULL,42,17144,0);
INSERT INTO "django_geo_db_location" VALUES(29204,NULL,'Glen Allan, MS',11767,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29205,NULL,'Glen Allan, MS 38744',11767,222,NULL,42,17145,0);
INSERT INTO "django_geo_db_location" VALUES(29206,NULL,'Grace, MS',11768,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29207,NULL,'Grace, MS 38745',11768,222,NULL,42,17146,0);
INSERT INTO "django_geo_db_location" VALUES(29208,NULL,'Gunnison, MS',11769,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29209,NULL,'Gunnison, MS 38746',11769,222,NULL,42,17147,0);
INSERT INTO "django_geo_db_location" VALUES(29210,NULL,'Hollandale, MS',11770,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29211,NULL,'Hollandale, MS 38748',11770,222,NULL,42,17148,0);
INSERT INTO "django_geo_db_location" VALUES(29212,NULL,'Holly Ridge, MS',11771,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29213,NULL,'Holly Ridge, MS 38749',11771,222,NULL,42,17149,0);
INSERT INTO "django_geo_db_location" VALUES(29214,NULL,'Indianola, MS',11772,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29215,NULL,'Indianola, MS 38751',11772,222,NULL,42,17150,0);
INSERT INTO "django_geo_db_location" VALUES(29216,NULL,'Inverness, MS',11773,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29217,NULL,'Inverness, MS 38753',11773,222,NULL,42,17151,0);
INSERT INTO "django_geo_db_location" VALUES(29218,NULL,'Isola, MS',11774,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29219,NULL,'Isola, MS 38754',11774,222,NULL,42,17152,0);
INSERT INTO "django_geo_db_location" VALUES(29220,NULL,'Leland, MS',11775,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29221,NULL,'Leland, MS 38756',11775,222,NULL,42,17153,0);
INSERT INTO "django_geo_db_location" VALUES(29222,NULL,'Mattson, MS',11776,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29223,NULL,'Mattson, MS 38758',11776,222,NULL,42,17154,0);
INSERT INTO "django_geo_db_location" VALUES(29224,NULL,'Merigold, MS',11777,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29225,NULL,'Merigold, MS 38759',11777,222,NULL,42,17155,0);
INSERT INTO "django_geo_db_location" VALUES(29226,NULL,'Metcalfe, MS 38760',11516,222,NULL,42,17156,0);
INSERT INTO "django_geo_db_location" VALUES(29227,NULL,'Moorhead, MS',11778,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29228,NULL,'Moorhead, MS 38761',11778,222,NULL,42,17157,0);
INSERT INTO "django_geo_db_location" VALUES(29229,NULL,'Mound Bayou, MS',11779,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29230,NULL,'Mound Bayou, MS 38762',11779,222,NULL,42,17158,0);
INSERT INTO "django_geo_db_location" VALUES(29231,NULL,'Nitta Yuma, MS',11780,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29232,NULL,'Nitta Yuma, MS 38763',11780,222,NULL,42,17159,0);
INSERT INTO "django_geo_db_location" VALUES(29233,NULL,'Pace, MS',11781,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29234,NULL,'Pace, MS 38764',11781,222,NULL,42,17160,0);
INSERT INTO "django_geo_db_location" VALUES(29235,NULL,'Panther Burn, MS',11782,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29236,NULL,'Panther Burn, MS 38765',11782,222,NULL,42,17161,0);
INSERT INTO "django_geo_db_location" VALUES(29237,NULL,'Rena Lara, MS',11783,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29238,NULL,'Rena Lara, MS 38767',11783,222,NULL,42,17162,0);
INSERT INTO "django_geo_db_location" VALUES(29239,NULL,'Rome, MS',11784,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29240,NULL,'Rome, MS 38768',11784,222,NULL,42,17163,0);
INSERT INTO "django_geo_db_location" VALUES(29241,NULL,'Rosedale, MS',11785,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29242,NULL,'Rosedale, MS 38769',11785,222,NULL,42,17164,0);
INSERT INTO "django_geo_db_location" VALUES(29243,NULL,'Ruleville, MS',11786,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29244,NULL,'Ruleville, MS 38771',11786,222,NULL,42,17165,0);
INSERT INTO "django_geo_db_location" VALUES(29245,NULL,'Scott, MS',11787,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29246,NULL,'Scott, MS 38772',11787,222,NULL,42,17166,0);
INSERT INTO "django_geo_db_location" VALUES(29247,NULL,'Shaw, MS',11788,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29248,NULL,'Shaw, MS 38773',11788,222,NULL,42,17167,0);
INSERT INTO "django_geo_db_location" VALUES(29249,NULL,'Shelby, MS',11789,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29250,NULL,'Shelby, MS 38774',11789,222,NULL,42,17168,0);
INSERT INTO "django_geo_db_location" VALUES(29251,NULL,'Stoneville, MS',11790,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29252,NULL,'Stoneville, MS 38776',11790,222,NULL,42,17169,0);
INSERT INTO "django_geo_db_location" VALUES(29253,NULL,'Sunflower, MS',11791,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29254,NULL,'Sunflower, MS 38778',11791,222,NULL,42,17170,0);
INSERT INTO "django_geo_db_location" VALUES(29255,NULL,'Wayside, MS',11792,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29256,NULL,'Wayside, MS 38780',11792,222,NULL,42,17171,0);
INSERT INTO "django_geo_db_location" VALUES(29257,NULL,'Winstonville, MS',11793,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29258,NULL,'Winstonville, MS 38781',11793,222,NULL,42,17172,0);
INSERT INTO "django_geo_db_location" VALUES(29259,NULL,'Winterville, MS',11794,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29260,NULL,'Winterville, MS 38782',11794,222,NULL,42,17173,0);
INSERT INTO "django_geo_db_location" VALUES(29261,NULL,'Tupelo, MS',11795,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29262,NULL,'Tupelo, MS 38801',11795,222,NULL,42,17174,0);
INSERT INTO "django_geo_db_location" VALUES(29263,NULL,'Tupelo, MS 38802',11795,222,NULL,42,17175,0);
INSERT INTO "django_geo_db_location" VALUES(29264,NULL,'Tupelo, MS 38803',11795,222,NULL,42,17176,0);
INSERT INTO "django_geo_db_location" VALUES(29265,NULL,'Tupelo, MS 38804',11795,222,NULL,42,17177,0);
INSERT INTO "django_geo_db_location" VALUES(29266,NULL,'Algoma, MS',11796,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29267,NULL,'Algoma, MS 38820',11796,222,NULL,42,17178,0);
INSERT INTO "django_geo_db_location" VALUES(29268,NULL,'Amory, MS',11797,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29269,NULL,'Amory, MS 38821',11797,222,NULL,42,17179,0);
INSERT INTO "django_geo_db_location" VALUES(29270,NULL,'Baldwyn, MS',11798,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29271,NULL,'Baldwyn, MS 38824',11798,222,NULL,42,17180,0);
INSERT INTO "django_geo_db_location" VALUES(29272,NULL,'Becker, MS',11799,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29273,NULL,'Becker, MS 38825',11799,222,NULL,42,17181,0);
INSERT INTO "django_geo_db_location" VALUES(29274,NULL,'Belden, MS',11800,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29275,NULL,'Belden, MS 38826',11800,222,NULL,42,17182,0);
INSERT INTO "django_geo_db_location" VALUES(29276,NULL,'Belmont, MS',11801,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29277,NULL,'Belmont, MS 38827',11801,222,NULL,42,17183,0);
INSERT INTO "django_geo_db_location" VALUES(29278,NULL,'Blue Springs, MS',11802,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29279,NULL,'Blue Springs, MS 38828',11802,222,NULL,42,17184,0);
INSERT INTO "django_geo_db_location" VALUES(29280,NULL,'Booneville, MS',11803,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29281,NULL,'Booneville, MS 38829',11803,222,NULL,42,17185,0);
INSERT INTO "django_geo_db_location" VALUES(29282,NULL,'Burnsville, MS',11804,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29283,NULL,'Burnsville, MS 38833',11804,222,NULL,42,17186,0);
INSERT INTO "django_geo_db_location" VALUES(29284,NULL,'Corinth, MS',11805,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29285,NULL,'Corinth, MS 38834',11805,222,NULL,42,17187,0);
INSERT INTO "django_geo_db_location" VALUES(29286,NULL,'Corinth, MS 38835',11805,222,NULL,42,17188,0);
INSERT INTO "django_geo_db_location" VALUES(29287,NULL,'Dennis, MS',11806,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29288,NULL,'Dennis, MS 38838',11806,222,NULL,42,17189,0);
INSERT INTO "django_geo_db_location" VALUES(29289,NULL,'Derma, MS',11807,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29290,NULL,'Derma, MS 38839',11807,222,NULL,42,17190,0);
INSERT INTO "django_geo_db_location" VALUES(29291,NULL,'Ecru, MS',11808,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29292,NULL,'Ecru, MS 38841',11808,222,NULL,42,17191,0);
INSERT INTO "django_geo_db_location" VALUES(29293,NULL,'Fulton, MS',11809,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29294,NULL,'Fulton, MS 38843',11809,222,NULL,42,17192,0);
INSERT INTO "django_geo_db_location" VALUES(29295,NULL,'Gattman, MS',11810,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29296,NULL,'Gattman, MS 38844',11810,222,NULL,42,17193,0);
INSERT INTO "django_geo_db_location" VALUES(29297,NULL,'Glen, MS',11811,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29298,NULL,'Glen, MS 38846',11811,222,NULL,42,17194,0);
INSERT INTO "django_geo_db_location" VALUES(29299,NULL,'Golden, MS',11812,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29300,NULL,'Golden, MS 38847',11812,222,NULL,42,17195,0);
INSERT INTO "django_geo_db_location" VALUES(29301,NULL,'Greenwood Springs, MS',11813,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29302,NULL,'Greenwood Springs, MS 38848',11813,222,NULL,42,17196,0);
INSERT INTO "django_geo_db_location" VALUES(29303,NULL,'Guntown, MS',11814,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29304,NULL,'Guntown, MS 38849',11814,222,NULL,42,17197,0);
INSERT INTO "django_geo_db_location" VALUES(29305,NULL,'Houlka, MS',11815,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29306,NULL,'Houlka, MS 38850',11815,222,NULL,42,17198,0);
INSERT INTO "django_geo_db_location" VALUES(29307,NULL,'Houston, MS',11816,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29308,NULL,'Houston, MS 38851',11816,222,NULL,42,17199,0);
INSERT INTO "django_geo_db_location" VALUES(29309,NULL,'Iuka, AL',11817,222,NULL,1,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29310,NULL,'Iuka, AL 38852',11817,222,NULL,1,17200,0);
INSERT INTO "django_geo_db_location" VALUES(29311,NULL,'McCondy, MS',11818,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29312,NULL,'McCondy, MS 38854',11818,222,NULL,42,17201,0);
INSERT INTO "django_geo_db_location" VALUES(29313,NULL,'Mantachie, MS',11819,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29314,NULL,'Mantachie, MS 38855',11819,222,NULL,42,17202,0);
INSERT INTO "django_geo_db_location" VALUES(29315,NULL,'Marietta, MS',11820,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29316,NULL,'Marietta, MS 38856',11820,222,NULL,42,17203,0);
INSERT INTO "django_geo_db_location" VALUES(29317,NULL,'Mooreville, MS',11821,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29318,NULL,'Mooreville, MS 38857',11821,222,NULL,42,17204,0);
INSERT INTO "django_geo_db_location" VALUES(29319,NULL,'Nettleton, MS',11822,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29320,NULL,'Nettleton, MS 38858',11822,222,NULL,42,17205,0);
INSERT INTO "django_geo_db_location" VALUES(29321,NULL,'New Site, MS',11823,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29322,NULL,'New Site, MS 38859',11823,222,NULL,42,17206,0);
INSERT INTO "django_geo_db_location" VALUES(29323,NULL,'Okolona, MS',11824,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29324,NULL,'Okolona, MS 38860',11824,222,NULL,42,17207,0);
INSERT INTO "django_geo_db_location" VALUES(29325,NULL,'Plantersville, MS',11825,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29326,NULL,'Plantersville, MS 38862',11825,222,NULL,42,17208,0);
INSERT INTO "django_geo_db_location" VALUES(29327,NULL,'Pontotoc, MS',11826,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29328,NULL,'Pontotoc, MS 38863',11826,222,NULL,42,17209,0);
INSERT INTO "django_geo_db_location" VALUES(29329,NULL,'Randolph, MS',11827,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29330,NULL,'Randolph, MS 38864',11827,222,NULL,42,17210,0);
INSERT INTO "django_geo_db_location" VALUES(29331,NULL,'Rienzi, MS',11828,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29332,NULL,'Rienzi, MS 38865',11828,222,NULL,42,17211,0);
INSERT INTO "django_geo_db_location" VALUES(29333,NULL,'Saltillo, MS',11829,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29334,NULL,'Saltillo, MS 38866',11829,222,NULL,42,17212,0);
INSERT INTO "django_geo_db_location" VALUES(29335,NULL,'Shannon, MS',11830,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29336,NULL,'Shannon, MS 38868',11830,222,NULL,42,17213,0);
INSERT INTO "django_geo_db_location" VALUES(29337,NULL,'Sherman, MS',11831,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29338,NULL,'Sherman, MS 38869',11831,222,NULL,42,17214,0);
INSERT INTO "django_geo_db_location" VALUES(29339,NULL,'Smithville, MS',11832,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29340,NULL,'Smithville, MS 38870',11832,222,NULL,42,17215,0);
INSERT INTO "django_geo_db_location" VALUES(29341,NULL,'Thaxton, MS',11833,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29342,NULL,'Thaxton, MS 38871',11833,222,NULL,42,17216,0);
INSERT INTO "django_geo_db_location" VALUES(29343,NULL,'Tishomingo, MS',11834,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29344,NULL,'Tishomingo, MS 38873',11834,222,NULL,42,17217,0);
INSERT INTO "django_geo_db_location" VALUES(29345,NULL,'Toccopola, MS',11835,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29346,NULL,'Toccopola, MS 38874',11835,222,NULL,42,17218,0);
INSERT INTO "django_geo_db_location" VALUES(29347,NULL,'Trebloc, MS',11836,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29348,NULL,'Trebloc, MS 38875',11836,222,NULL,42,17219,0);
INSERT INTO "django_geo_db_location" VALUES(29349,NULL,'Tremont, MS',11837,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29350,NULL,'Tremont, MS 38876',11837,222,NULL,42,17220,0);
INSERT INTO "django_geo_db_location" VALUES(29351,NULL,'Van Vleet, MS',11838,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29352,NULL,'Van Vleet, MS 38877',11838,222,NULL,42,17221,0);
INSERT INTO "django_geo_db_location" VALUES(29353,NULL,'Vardaman, MS',11839,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29354,NULL,'Vardaman, MS 38878',11839,222,NULL,42,17222,0);
INSERT INTO "django_geo_db_location" VALUES(29355,NULL,'Verona, MS',11840,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29356,NULL,'Verona, MS 38879',11840,222,NULL,42,17223,0);
INSERT INTO "django_geo_db_location" VALUES(29357,NULL,'Wheeler, MS',11841,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29358,NULL,'Wheeler, MS 38880',11841,222,NULL,42,17224,0);
INSERT INTO "django_geo_db_location" VALUES(29359,NULL,'Grenada, MS',11842,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29360,NULL,'Grenada, MS 38901',11842,222,NULL,42,17225,0);
INSERT INTO "django_geo_db_location" VALUES(29361,NULL,'Grenada, MS 38902',11842,222,NULL,42,17226,0);
INSERT INTO "django_geo_db_location" VALUES(29362,NULL,'Avalon, MS',11843,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29363,NULL,'Avalon, MS 38912',11843,222,NULL,42,17227,0);
INSERT INTO "django_geo_db_location" VALUES(29364,NULL,'Banner, MS',11844,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29365,NULL,'Banner, MS 38913',11844,222,NULL,42,17228,0);
INSERT INTO "django_geo_db_location" VALUES(29366,NULL,'Big Creek, MS',11845,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29367,NULL,'Big Creek, MS 38914',11845,222,NULL,42,17229,0);
INSERT INTO "django_geo_db_location" VALUES(29368,NULL,'Bruce, MS',11846,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29369,NULL,'Bruce, MS 38915',11846,222,NULL,42,17230,0);
INSERT INTO "django_geo_db_location" VALUES(29370,NULL,'Calhoun City, MS',11847,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29371,NULL,'Calhoun City, MS 38916',11847,222,NULL,42,17231,0);
INSERT INTO "django_geo_db_location" VALUES(29372,NULL,'Carrollton, MS',11848,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29373,NULL,'Carrollton, MS 38917',11848,222,NULL,42,17232,0);
INSERT INTO "django_geo_db_location" VALUES(29374,NULL,'Cascilla, MS',11849,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29375,NULL,'Cascilla, MS 38920',11849,222,NULL,42,17233,0);
INSERT INTO "django_geo_db_location" VALUES(29376,NULL,'Charleston, MS',11850,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29377,NULL,'Charleston, MS 38921',11850,222,NULL,42,17234,0);
INSERT INTO "django_geo_db_location" VALUES(29378,NULL,'Coffeeville, MS',11851,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29379,NULL,'Coffeeville, MS 38922',11851,222,NULL,42,17235,0);
INSERT INTO "django_geo_db_location" VALUES(29380,NULL,'Coila, MS',11852,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29381,NULL,'Coila, MS 38923',11852,222,NULL,42,17236,0);
INSERT INTO "django_geo_db_location" VALUES(29382,NULL,'Cruger, MS',11853,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29383,NULL,'Cruger, MS 38924',11853,222,NULL,42,17237,0);
INSERT INTO "django_geo_db_location" VALUES(29384,NULL,'Duck Hill, MS',11854,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29385,NULL,'Duck Hill, MS 38925',11854,222,NULL,42,17238,0);
INSERT INTO "django_geo_db_location" VALUES(29386,NULL,'Elliott, MS',11855,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29387,NULL,'Elliott, MS 38926',11855,222,NULL,42,17239,0);
INSERT INTO "django_geo_db_location" VALUES(29388,NULL,'Enid, MS',11856,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29389,NULL,'Enid, MS 38927',11856,222,NULL,42,17240,0);
INSERT INTO "django_geo_db_location" VALUES(29390,NULL,'Glendora, MS',11857,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29391,NULL,'Glendora, MS 38928',11857,222,NULL,42,17241,0);
INSERT INTO "django_geo_db_location" VALUES(29392,NULL,'Gore Springs, MS',11858,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29393,NULL,'Gore Springs, MS 38929',11858,222,NULL,42,17242,0);
INSERT INTO "django_geo_db_location" VALUES(29394,NULL,'Greenwood, MS',11859,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29395,NULL,'Greenwood, MS 38930',11859,222,NULL,42,17243,0);
INSERT INTO "django_geo_db_location" VALUES(29396,NULL,'Greenwood, MS 38935',11859,222,NULL,42,17244,0);
INSERT INTO "django_geo_db_location" VALUES(29397,NULL,'Holcomb, MS',11860,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29398,NULL,'Holcomb, MS 38940',11860,222,NULL,42,17245,0);
INSERT INTO "django_geo_db_location" VALUES(29399,NULL,'Itta Bena, MS',11861,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29400,NULL,'Itta Bena, MS 38941',11861,222,NULL,42,17246,0);
INSERT INTO "django_geo_db_location" VALUES(29401,NULL,'McCarley, MS',11862,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29402,NULL,'McCarley, MS 38943',11862,222,NULL,42,17247,0);
INSERT INTO "django_geo_db_location" VALUES(29403,NULL,'Minter City, MS',11863,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29404,NULL,'Minter City, MS 38944',11863,222,NULL,42,17248,0);
INSERT INTO "django_geo_db_location" VALUES(29405,NULL,'Money, MS',11864,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29406,NULL,'Money, MS 38945',11864,222,NULL,42,17249,0);
INSERT INTO "django_geo_db_location" VALUES(29407,NULL,'Morgan City, MS',11865,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29408,NULL,'Morgan City, MS 38946',11865,222,NULL,42,17250,0);
INSERT INTO "django_geo_db_location" VALUES(29409,NULL,'North Carrollton, MS',11866,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29410,NULL,'North Carrollton, MS 38947',11866,222,NULL,42,17251,0);
INSERT INTO "django_geo_db_location" VALUES(29411,NULL,'Oakland, MS',11867,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29412,NULL,'Oakland, MS 38948',11867,222,NULL,42,17252,0);
INSERT INTO "django_geo_db_location" VALUES(29413,NULL,'Paris, MS',11868,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29414,NULL,'Paris, MS 38949',11868,222,NULL,42,17253,0);
INSERT INTO "django_geo_db_location" VALUES(29415,NULL,'Philipp, MS',11869,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29416,NULL,'Philipp, MS 38950',11869,222,NULL,42,17254,0);
INSERT INTO "django_geo_db_location" VALUES(29417,NULL,'Pittsboro, MS',11870,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29418,NULL,'Pittsboro, MS 38951',11870,222,NULL,42,17255,0);
INSERT INTO "django_geo_db_location" VALUES(29419,NULL,'Schlater, MS',11871,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29420,NULL,'Schlater, MS 38952',11871,222,NULL,42,17256,0);
INSERT INTO "django_geo_db_location" VALUES(29421,NULL,'Scobey, MS',11872,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29422,NULL,'Scobey, MS 38953',11872,222,NULL,42,17257,0);
INSERT INTO "django_geo_db_location" VALUES(29423,NULL,'Sidon, MS',11873,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29424,NULL,'Sidon, MS 38954',11873,222,NULL,42,17258,0);
INSERT INTO "django_geo_db_location" VALUES(29425,NULL,'Slate Spring, MS',11874,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29426,NULL,'Slate Spring, MS 38955',11874,222,NULL,42,17259,0);
INSERT INTO "django_geo_db_location" VALUES(29427,NULL,'Sumner, MS 38957',11690,222,NULL,42,17260,0);
INSERT INTO "django_geo_db_location" VALUES(29428,NULL,'Swan Lake, MS',11875,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29429,NULL,'Swan Lake, MS 38958',11875,222,NULL,42,17261,0);
INSERT INTO "django_geo_db_location" VALUES(29430,NULL,'Swiftown, MS',11876,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29431,NULL,'Swiftown, MS 38959',11876,222,NULL,42,17262,0);
INSERT INTO "django_geo_db_location" VALUES(29432,NULL,'Tie Plant, MS',11877,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29433,NULL,'Tie Plant, MS 38960',11877,222,NULL,42,17263,0);
INSERT INTO "django_geo_db_location" VALUES(29434,NULL,'Tillatoba, MS',11878,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29435,NULL,'Tillatoba, MS 38961',11878,222,NULL,42,17264,0);
INSERT INTO "django_geo_db_location" VALUES(29436,NULL,'Tippo, MS',11879,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29437,NULL,'Tippo, MS 38962',11879,222,NULL,42,17265,0);
INSERT INTO "django_geo_db_location" VALUES(29438,NULL,'Tutwiler, MS',11880,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29439,NULL,'Tutwiler, MS 38963',11880,222,NULL,42,17266,0);
INSERT INTO "django_geo_db_location" VALUES(29440,NULL,'Vance, MS',11881,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29441,NULL,'Vance, MS 38964',11881,222,NULL,42,17267,0);
INSERT INTO "django_geo_db_location" VALUES(29442,NULL,'Water Valley, MS 38965',11751,222,NULL,42,17268,0);
INSERT INTO "django_geo_db_location" VALUES(29443,NULL,'Webb, MS',11882,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29444,NULL,'Webb, MS 38966',11882,222,NULL,42,17269,0);
INSERT INTO "django_geo_db_location" VALUES(29445,NULL,'Winona, MS',11883,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29446,NULL,'Winona, MS 38967',11883,222,NULL,42,17270,0);
INSERT INTO "django_geo_db_location" VALUES(29447,NULL,'Belzoni, MS',11884,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29448,NULL,'Belzoni, MS 39038',11884,222,NULL,42,17271,0);
INSERT INTO "django_geo_db_location" VALUES(29449,NULL,'Benton, MS',11885,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29450,NULL,'Benton, MS 39039',11885,222,NULL,42,17272,0);
INSERT INTO "django_geo_db_location" VALUES(29451,NULL,'Bentonia, MS',11886,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29452,NULL,'Bentonia, MS 39040',11886,222,NULL,42,17273,0);
INSERT INTO "django_geo_db_location" VALUES(29453,NULL,'Bolton, MS',11887,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29454,NULL,'Bolton, MS 39041',11887,222,NULL,42,17274,0);
INSERT INTO "django_geo_db_location" VALUES(29455,NULL,'Brandon, MS',11888,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29456,NULL,'Brandon, MS 39042',11888,222,NULL,42,17275,0);
INSERT INTO "django_geo_db_location" VALUES(29457,NULL,'Brandon, MS 39043',11888,222,NULL,42,17276,0);
INSERT INTO "django_geo_db_location" VALUES(29458,NULL,'Braxton, MS',11889,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29459,NULL,'Braxton, MS 39044',11889,222,NULL,42,17277,0);
INSERT INTO "django_geo_db_location" VALUES(29460,NULL,'Camden, MS',11890,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29461,NULL,'Camden, MS 39045',11890,222,NULL,42,17278,0);
INSERT INTO "django_geo_db_location" VALUES(29462,NULL,'Canton, MS',11891,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29463,NULL,'Canton, MS 39046',11891,222,NULL,42,17279,0);
INSERT INTO "django_geo_db_location" VALUES(29464,NULL,'Brandon, MS 39047',11888,222,NULL,42,17280,0);
INSERT INTO "django_geo_db_location" VALUES(29465,NULL,'Bentonia, MS 39048',11886,222,NULL,42,17281,0);
INSERT INTO "django_geo_db_location" VALUES(29466,NULL,'Carthage, MS',11892,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29467,NULL,'Carthage, MS 39051',11892,222,NULL,42,17282,0);
INSERT INTO "django_geo_db_location" VALUES(29468,NULL,'Cary, MS',11893,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29469,NULL,'Cary, MS 39054',11893,222,NULL,42,17283,0);
INSERT INTO "django_geo_db_location" VALUES(29470,NULL,'Clinton, MS',11894,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29471,NULL,'Clinton, MS 39056',11894,222,NULL,42,17284,0);
INSERT INTO "django_geo_db_location" VALUES(29472,NULL,'Conehatta, MS',11895,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29473,NULL,'Conehatta, MS 39057',11895,222,NULL,42,17285,0);
INSERT INTO "django_geo_db_location" VALUES(29474,NULL,'Clinton, MS 39058',11894,222,NULL,42,17286,0);
INSERT INTO "django_geo_db_location" VALUES(29475,NULL,'Crystal Springs, MS',11896,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29476,NULL,'Crystal Springs, MS 39059',11896,222,NULL,42,17287,0);
INSERT INTO "django_geo_db_location" VALUES(29477,NULL,'Clinton, MS 39060',11894,222,NULL,42,17288,0);
INSERT INTO "django_geo_db_location" VALUES(29478,NULL,'Delta City, MS',11897,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29479,NULL,'Delta City, MS 39061',11897,222,NULL,42,17289,0);
INSERT INTO "django_geo_db_location" VALUES(29480,NULL,'D Lo, MS',11898,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29481,NULL,'D Lo, MS 39062',11898,222,NULL,42,17290,0);
INSERT INTO "django_geo_db_location" VALUES(29482,NULL,'Durant, MS',11899,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29483,NULL,'Durant, MS 39063',11899,222,NULL,42,17291,0);
INSERT INTO "django_geo_db_location" VALUES(29484,NULL,'Edwards, MS',11900,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29485,NULL,'Edwards, MS 39066',11900,222,NULL,42,17292,0);
INSERT INTO "django_geo_db_location" VALUES(29486,NULL,'Ethel, MS',11901,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29487,NULL,'Ethel, MS 39067',11901,222,NULL,42,17293,0);
INSERT INTO "django_geo_db_location" VALUES(29488,NULL,'Fayette, MS',11902,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29489,NULL,'Fayette, MS 39069',11902,222,NULL,42,17294,0);
INSERT INTO "django_geo_db_location" VALUES(29490,NULL,'Flora, MS',11903,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29491,NULL,'Flora, MS 39071',11903,222,NULL,42,17295,0);
INSERT INTO "django_geo_db_location" VALUES(29492,NULL,'Pocahontas, MS',11904,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29493,NULL,'Pocahontas, MS 39072',11904,222,NULL,42,17296,0);
INSERT INTO "django_geo_db_location" VALUES(29494,NULL,'Florence, MS',11905,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29495,NULL,'Florence, MS 39073',11905,222,NULL,42,17297,0);
INSERT INTO "django_geo_db_location" VALUES(29496,NULL,'Forest, MS',11906,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29497,NULL,'Forest, MS 39074',11906,222,NULL,42,17298,0);
INSERT INTO "django_geo_db_location" VALUES(29498,NULL,'Gallman, MS',11907,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29499,NULL,'Gallman, MS 39077',11907,222,NULL,42,17299,0);
INSERT INTO "django_geo_db_location" VALUES(29500,NULL,'Georgetown, MS',11908,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29501,NULL,'Georgetown, MS 39078',11908,222,NULL,42,17300,0);
INSERT INTO "django_geo_db_location" VALUES(29502,NULL,'Goodman, MS',11909,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29503,NULL,'Goodman, MS 39079',11909,222,NULL,42,17301,0);
INSERT INTO "django_geo_db_location" VALUES(29504,NULL,'Harperville, MS',11910,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29505,NULL,'Harperville, MS 39080',11910,222,NULL,42,17302,0);
INSERT INTO "django_geo_db_location" VALUES(29506,NULL,'Harriston, MS',11911,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29507,NULL,'Harriston, MS 39081',11911,222,NULL,42,17303,0);
INSERT INTO "django_geo_db_location" VALUES(29508,NULL,'Harrisville, MS',11912,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29509,NULL,'Harrisville, MS 39082',11912,222,NULL,42,17304,0);
INSERT INTO "django_geo_db_location" VALUES(29510,NULL,'Hazlehurst, MS',11913,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29511,NULL,'Hazlehurst, MS 39083',11913,222,NULL,42,17305,0);
INSERT INTO "django_geo_db_location" VALUES(29512,NULL,'Hermanville, MS',11914,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29513,NULL,'Hermanville, MS 39086',11914,222,NULL,42,17306,0);
INSERT INTO "django_geo_db_location" VALUES(29514,NULL,'Hillsboro, MS',11915,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29515,NULL,'Hillsboro, MS 39087',11915,222,NULL,42,17307,0);
INSERT INTO "django_geo_db_location" VALUES(29516,NULL,'Holly Bluff, MS',11916,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29517,NULL,'Holly Bluff, MS 39088',11916,222,NULL,42,17308,0);
INSERT INTO "django_geo_db_location" VALUES(29518,NULL,'Kosciusko, MS',11917,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29519,NULL,'Kosciusko, MS 39090',11917,222,NULL,42,17309,0);
INSERT INTO "django_geo_db_location" VALUES(29520,NULL,'Lake, MS',11918,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29521,NULL,'Lake, MS 39092',11918,222,NULL,42,17310,0);
INSERT INTO "django_geo_db_location" VALUES(29522,NULL,'Lena, MS',11919,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29523,NULL,'Lena, MS 39094',11919,222,NULL,42,17311,0);
INSERT INTO "django_geo_db_location" VALUES(29524,NULL,'Lexington, MS',11920,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29525,NULL,'Lexington, MS 39095',11920,222,NULL,42,17312,0);
INSERT INTO "django_geo_db_location" VALUES(29526,NULL,'Lorman, MS',11921,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29527,NULL,'Lorman, MS 39096',11921,222,NULL,42,17313,0);
INSERT INTO "django_geo_db_location" VALUES(29528,NULL,'Louise, MS',11922,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29529,NULL,'Louise, MS 39097',11922,222,NULL,42,17314,0);
INSERT INTO "django_geo_db_location" VALUES(29530,NULL,'Ludlow, MS',11923,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29531,NULL,'Ludlow, MS 39098',11923,222,NULL,42,17315,0);
INSERT INTO "django_geo_db_location" VALUES(29532,NULL,'McAdams, MS',11924,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29533,NULL,'McAdams, MS 39107',11924,222,NULL,42,17316,0);
INSERT INTO "django_geo_db_location" VALUES(29534,NULL,'McCool, MS',11925,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29535,NULL,'McCool, MS 39108',11925,222,NULL,42,17317,0);
INSERT INTO "django_geo_db_location" VALUES(29536,NULL,'Madden, MS',11926,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29537,NULL,'Madden, MS 39109',11926,222,NULL,42,17318,0);
INSERT INTO "django_geo_db_location" VALUES(29538,NULL,'Madison, MS',11927,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29539,NULL,'Madison, MS 39110',11927,222,NULL,42,17319,0);
INSERT INTO "django_geo_db_location" VALUES(29540,NULL,'Magee, MS',11928,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29541,NULL,'Magee, MS 39111',11928,222,NULL,42,17320,0);
INSERT INTO "django_geo_db_location" VALUES(29542,NULL,'Sanatorium, MS',11929,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29543,NULL,'Sanatorium, MS 39112',11929,222,NULL,42,17321,0);
INSERT INTO "django_geo_db_location" VALUES(29544,NULL,'Mayersville, MS',11930,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29545,NULL,'Mayersville, MS 39113',11930,222,NULL,42,17322,0);
INSERT INTO "django_geo_db_location" VALUES(29546,NULL,'Mendenhall, MS',11931,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29547,NULL,'Mendenhall, MS 39114',11931,222,NULL,42,17323,0);
INSERT INTO "django_geo_db_location" VALUES(29548,NULL,'Midnight, MS',11932,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29549,NULL,'Midnight, MS 39115',11932,222,NULL,42,17324,0);
INSERT INTO "django_geo_db_location" VALUES(29550,NULL,'Mize, MS',11933,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29551,NULL,'Mize, MS 39116',11933,222,NULL,42,17325,0);
INSERT INTO "django_geo_db_location" VALUES(29552,NULL,'Morton, MS',11934,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29553,NULL,'Morton, MS 39117',11934,222,NULL,42,17326,0);
INSERT INTO "django_geo_db_location" VALUES(29554,NULL,'Mount Olive, MS',11935,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29555,NULL,'Mount Olive, MS 39119',11935,222,NULL,42,17327,0);
INSERT INTO "django_geo_db_location" VALUES(29556,NULL,'Natchez, MS',11936,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29557,NULL,'Natchez, MS 39120',11936,222,NULL,42,17328,0);
INSERT INTO "django_geo_db_location" VALUES(29558,NULL,'Natchez, MS 39121',11936,222,NULL,42,17329,0);
INSERT INTO "django_geo_db_location" VALUES(29559,NULL,'Natchez, MS 39122',11936,222,NULL,42,17330,0);
INSERT INTO "django_geo_db_location" VALUES(29560,NULL,'Madison, MS 39130',11927,222,NULL,42,17331,0);
INSERT INTO "django_geo_db_location" VALUES(29561,NULL,'Newhebron, MS',11937,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29562,NULL,'Newhebron, MS 39140',11937,222,NULL,42,17332,0);
INSERT INTO "django_geo_db_location" VALUES(29563,NULL,'Pattison, MS',11938,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29564,NULL,'Pattison, MS 39144',11938,222,NULL,42,17333,0);
INSERT INTO "django_geo_db_location" VALUES(29565,NULL,'Pelahatchie, MS',11939,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29566,NULL,'Pelahatchie, MS 39145',11939,222,NULL,42,17334,0);
INSERT INTO "django_geo_db_location" VALUES(29567,NULL,'Pickens, MS',11940,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29568,NULL,'Pickens, MS 39146',11940,222,NULL,42,17335,0);
INSERT INTO "django_geo_db_location" VALUES(29569,NULL,'Piney Woods, MS',11941,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29570,NULL,'Piney Woods, MS 39148',11941,222,NULL,42,17336,0);
INSERT INTO "django_geo_db_location" VALUES(29571,NULL,'Pinola, MS',11942,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29572,NULL,'Pinola, MS 39149',11942,222,NULL,42,17337,0);
INSERT INTO "django_geo_db_location" VALUES(29573,NULL,'Port Gibson, MS',11943,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29574,NULL,'Port Gibson, MS 39150',11943,222,NULL,42,17338,0);
INSERT INTO "django_geo_db_location" VALUES(29575,NULL,'Puckett, MS',11944,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29576,NULL,'Puckett, MS 39151',11944,222,NULL,42,17339,0);
INSERT INTO "django_geo_db_location" VALUES(29577,NULL,'Pulaski, MS',11945,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29578,NULL,'Pulaski, MS 39152',11945,222,NULL,42,17340,0);
INSERT INTO "django_geo_db_location" VALUES(29579,NULL,'Raleigh, MS',11946,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29580,NULL,'Raleigh, MS 39153',11946,222,NULL,42,17341,0);
INSERT INTO "django_geo_db_location" VALUES(29581,NULL,'Raymond, MS',11947,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29582,NULL,'Raymond, MS 39154',11947,222,NULL,42,17342,0);
INSERT INTO "django_geo_db_location" VALUES(29583,NULL,'Redwood, MS',11948,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29584,NULL,'Redwood, MS 39156',11948,222,NULL,42,17343,0);
INSERT INTO "django_geo_db_location" VALUES(29585,NULL,'Ridgeland, MS',11949,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29586,NULL,'Ridgeland, MS 39157',11949,222,NULL,42,17344,0);
INSERT INTO "django_geo_db_location" VALUES(29587,NULL,'Ridgeland, MS 39158',11949,222,NULL,42,17345,0);
INSERT INTO "django_geo_db_location" VALUES(29588,NULL,'Rolling Fork, MS',11950,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29589,NULL,'Rolling Fork, MS 39159',11950,222,NULL,42,17346,0);
INSERT INTO "django_geo_db_location" VALUES(29590,NULL,'Sallis, MS',11951,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29591,NULL,'Sallis, MS 39160',11951,222,NULL,42,17347,0);
INSERT INTO "django_geo_db_location" VALUES(29592,NULL,'Sandhill, MS',11952,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29593,NULL,'Sandhill, MS 39161',11952,222,NULL,42,17348,0);
INSERT INTO "django_geo_db_location" VALUES(29594,NULL,'Satartia, MS',11953,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29595,NULL,'Satartia, MS 39162',11953,222,NULL,42,17349,0);
INSERT INTO "django_geo_db_location" VALUES(29596,NULL,'Sharon, MS',11954,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29597,NULL,'Sharon, MS 39163',11954,222,NULL,42,17350,0);
INSERT INTO "django_geo_db_location" VALUES(29598,NULL,'Sibley, MS',11955,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29599,NULL,'Sibley, MS 39165',11955,222,NULL,42,17351,0);
INSERT INTO "django_geo_db_location" VALUES(29600,NULL,'Silver City, MS',11956,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29601,NULL,'Silver City, MS 39166',11956,222,NULL,42,17352,0);
INSERT INTO "django_geo_db_location" VALUES(29602,NULL,'Star, MS',11957,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29603,NULL,'Star, MS 39167',11957,222,NULL,42,17353,0);
INSERT INTO "django_geo_db_location" VALUES(29604,NULL,'Taylorsville, MS',11958,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29605,NULL,'Taylorsville, MS 39168',11958,222,NULL,42,17354,0);
INSERT INTO "django_geo_db_location" VALUES(29606,NULL,'Tchula, MS',11959,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29607,NULL,'Tchula, MS 39169',11959,222,NULL,42,17355,0);
INSERT INTO "django_geo_db_location" VALUES(29608,NULL,'Terry, MS',11960,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29609,NULL,'Terry, MS 39170',11960,222,NULL,42,17356,0);
INSERT INTO "django_geo_db_location" VALUES(29610,NULL,'Thomastown, MS',11961,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29611,NULL,'Thomastown, MS 39171',11961,222,NULL,42,17357,0);
INSERT INTO "django_geo_db_location" VALUES(29612,NULL,'Tinsley, MS',11962,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29613,NULL,'Tinsley, MS 39173',11962,222,NULL,42,17358,0);
INSERT INTO "django_geo_db_location" VALUES(29614,NULL,'Tougaloo, MS',11963,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29615,NULL,'Tougaloo, MS 39174',11963,222,NULL,42,17359,0);
INSERT INTO "django_geo_db_location" VALUES(29616,NULL,'Utica, MS',11964,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29617,NULL,'Utica, MS 39175',11964,222,NULL,42,17360,0);
INSERT INTO "django_geo_db_location" VALUES(29618,NULL,'Vaiden, MS',11965,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29619,NULL,'Vaiden, MS 39176',11965,222,NULL,42,17361,0);
INSERT INTO "django_geo_db_location" VALUES(29620,NULL,'Valley Park, MS',11966,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29621,NULL,'Valley Park, MS 39177',11966,222,NULL,42,17362,0);
INSERT INTO "django_geo_db_location" VALUES(29622,NULL,'Vaughan, MS',11967,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29623,NULL,'Vaughan, MS 39179',11967,222,NULL,42,17363,0);
INSERT INTO "django_geo_db_location" VALUES(29624,NULL,'Vicksburg, MS',11968,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29625,NULL,'Vicksburg, MS 39180',11968,222,NULL,42,17364,0);
INSERT INTO "django_geo_db_location" VALUES(29626,NULL,'Vicksburg, MS 39181',11968,222,NULL,42,17365,0);
INSERT INTO "django_geo_db_location" VALUES(29627,NULL,'Vicksburg, MS 39182',11968,222,NULL,42,17366,0);
INSERT INTO "django_geo_db_location" VALUES(29628,NULL,'Vicksburg, MS 39183',11968,222,NULL,42,17367,0);
INSERT INTO "django_geo_db_location" VALUES(29629,NULL,'Walnut Grove, MS',11969,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29630,NULL,'Walnut Grove, MS 39189',11969,222,NULL,42,17368,0);
INSERT INTO "django_geo_db_location" VALUES(29631,NULL,'Washington, MS',11970,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29632,NULL,'Washington, MS 39190',11970,222,NULL,42,17369,0);
INSERT INTO "django_geo_db_location" VALUES(29633,NULL,'Wesson, MS',11971,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29634,NULL,'Wesson, MS 39191',11971,222,NULL,42,17370,0);
INSERT INTO "django_geo_db_location" VALUES(29635,NULL,'West, MS',11972,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29636,NULL,'West, MS 39192',11972,222,NULL,42,17371,0);
INSERT INTO "django_geo_db_location" VALUES(29637,NULL,'Whitfield, MS',11973,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29638,NULL,'Whitfield, MS 39193',11973,222,NULL,42,17372,0);
INSERT INTO "django_geo_db_location" VALUES(29639,NULL,'Yazoo City, MS',11974,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29640,NULL,'Yazoo City, MS 39194',11974,222,NULL,42,17373,0);
INSERT INTO "django_geo_db_location" VALUES(29641,NULL,'Jackson, MS',11975,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29642,NULL,'Jackson, MS 39201',11975,222,NULL,42,17374,0);
INSERT INTO "django_geo_db_location" VALUES(29643,NULL,'Jackson, MS 39202',11975,222,NULL,42,17375,0);
INSERT INTO "django_geo_db_location" VALUES(29644,NULL,'Jackson, MS 39203',11975,222,NULL,42,17376,0);
INSERT INTO "django_geo_db_location" VALUES(29645,NULL,'Jackson, MS 39204',11975,222,NULL,42,17377,0);
INSERT INTO "django_geo_db_location" VALUES(29646,NULL,'Jackson, MS 39205',11975,222,NULL,42,17378,0);
INSERT INTO "django_geo_db_location" VALUES(29647,NULL,'Jackson, MS 39206',11975,222,NULL,42,17379,0);
INSERT INTO "django_geo_db_location" VALUES(29648,NULL,'Jackson, MS 39207',11975,222,NULL,42,17380,0);
INSERT INTO "django_geo_db_location" VALUES(29649,NULL,'Jackson, MS 39208',11975,222,NULL,42,17381,0);
INSERT INTO "django_geo_db_location" VALUES(29650,NULL,'Jackson, MS 39209',11975,222,NULL,42,17382,0);
INSERT INTO "django_geo_db_location" VALUES(29651,NULL,'Jackson, MS 39210',11975,222,NULL,42,17383,0);
INSERT INTO "django_geo_db_location" VALUES(29652,NULL,'Jackson, MS 39211',11975,222,NULL,42,17384,0);
INSERT INTO "django_geo_db_location" VALUES(29653,NULL,'Jackson, MS 39212',11975,222,NULL,42,17385,0);
INSERT INTO "django_geo_db_location" VALUES(29654,NULL,'Jackson, MS 39213',11975,222,NULL,42,17386,0);
INSERT INTO "django_geo_db_location" VALUES(29655,NULL,'Jackson, MS 39215',11975,222,NULL,42,17387,0);
INSERT INTO "django_geo_db_location" VALUES(29656,NULL,'Jackson, MS 39216',11975,222,NULL,42,17388,0);
INSERT INTO "django_geo_db_location" VALUES(29657,NULL,'Jackson, MS 39217',11975,222,NULL,42,17389,0);
INSERT INTO "django_geo_db_location" VALUES(29658,NULL,'Jackson, MS 39218',11975,222,NULL,42,17390,0);
INSERT INTO "django_geo_db_location" VALUES(29659,NULL,'Jackson, MS 39219',11975,222,NULL,42,17391,0);
INSERT INTO "django_geo_db_location" VALUES(29660,NULL,'Jackson, MS 39225',11975,222,NULL,42,17392,0);
INSERT INTO "django_geo_db_location" VALUES(29661,NULL,'Jackson, MS 39232',11975,222,NULL,42,17393,0);
INSERT INTO "django_geo_db_location" VALUES(29662,NULL,'Jackson, MS 39235',11975,222,NULL,42,17394,0);
INSERT INTO "django_geo_db_location" VALUES(29663,NULL,'Jackson, MS 39236',11975,222,NULL,42,17395,0);
INSERT INTO "django_geo_db_location" VALUES(29664,NULL,'Jackson, MS 39250',11975,222,NULL,42,17396,0);
INSERT INTO "django_geo_db_location" VALUES(29665,NULL,'Jackson, MS 39269',11975,222,NULL,42,17397,0);
INSERT INTO "django_geo_db_location" VALUES(29666,NULL,'Jackson, MS 39271',11975,222,NULL,42,17398,0);
INSERT INTO "django_geo_db_location" VALUES(29667,NULL,'Jackson, MS 39272',11975,222,NULL,42,17399,0);
INSERT INTO "django_geo_db_location" VALUES(29668,NULL,'Jackson, MS 39282',11975,222,NULL,42,17400,0);
INSERT INTO "django_geo_db_location" VALUES(29669,NULL,'Jackson, MS 39283',11975,222,NULL,42,17401,0);
INSERT INTO "django_geo_db_location" VALUES(29670,NULL,'Jackson, MS 39284',11975,222,NULL,42,17402,0);
INSERT INTO "django_geo_db_location" VALUES(29671,NULL,'Jackson, MS 39286',11975,222,NULL,42,17403,0);
INSERT INTO "django_geo_db_location" VALUES(29672,NULL,'Jackson, MS 39288',11975,222,NULL,42,17404,0);
INSERT INTO "django_geo_db_location" VALUES(29673,NULL,'Jackson, MS 39289',11975,222,NULL,42,17405,0);
INSERT INTO "django_geo_db_location" VALUES(29674,NULL,'Jackson, MS 39296',11975,222,NULL,42,17406,0);
INSERT INTO "django_geo_db_location" VALUES(29675,NULL,'Jackson, MS 39298',11975,222,NULL,42,17407,0);
INSERT INTO "django_geo_db_location" VALUES(29676,NULL,'Meridian, MS',11976,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29677,NULL,'Meridian, MS 39301',11976,222,NULL,42,17408,0);
INSERT INTO "django_geo_db_location" VALUES(29678,NULL,'Meridian, MS 39302',11976,222,NULL,42,17409,0);
INSERT INTO "django_geo_db_location" VALUES(29679,NULL,'Meridian, MS 39303',11976,222,NULL,42,17410,0);
INSERT INTO "django_geo_db_location" VALUES(29680,NULL,'Meridian, MS 39304',11976,222,NULL,42,17411,0);
INSERT INTO "django_geo_db_location" VALUES(29681,NULL,'Meridian, MS 39305',11976,222,NULL,42,17412,0);
INSERT INTO "django_geo_db_location" VALUES(29682,NULL,'Meridian, MS 39307',11976,222,NULL,42,17413,0);
INSERT INTO "django_geo_db_location" VALUES(29683,NULL,'Meridian, MS 39309',11976,222,NULL,42,17414,0);
INSERT INTO "django_geo_db_location" VALUES(29684,NULL,'Bailey, MS',11977,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29685,NULL,'Bailey, MS 39320',11977,222,NULL,42,17415,0);
INSERT INTO "django_geo_db_location" VALUES(29686,NULL,'Buckatunna, MS',11978,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29687,NULL,'Buckatunna, MS 39322',11978,222,NULL,42,17416,0);
INSERT INTO "django_geo_db_location" VALUES(29688,NULL,'Chunky, MS',11979,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29689,NULL,'Chunky, MS 39323',11979,222,NULL,42,17417,0);
INSERT INTO "django_geo_db_location" VALUES(29690,NULL,'Clara, MS',11980,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29691,NULL,'Clara, MS 39324',11980,222,NULL,42,17418,0);
INSERT INTO "django_geo_db_location" VALUES(29692,NULL,'Collinsville, MS',11981,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29693,NULL,'Collinsville, MS 39325',11981,222,NULL,42,17419,0);
INSERT INTO "django_geo_db_location" VALUES(29694,NULL,'Daleville, MS',11982,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29695,NULL,'Daleville, MS 39326',11982,222,NULL,42,17420,0);
INSERT INTO "django_geo_db_location" VALUES(29696,NULL,'Decatur, MS',11983,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29697,NULL,'Decatur, MS 39327',11983,222,NULL,42,17421,0);
INSERT INTO "django_geo_db_location" VALUES(29698,NULL,'De Kalb, MS',11984,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29699,NULL,'De Kalb, MS 39328',11984,222,NULL,42,17422,0);
INSERT INTO "django_geo_db_location" VALUES(29700,NULL,'Enterprise, MS',11985,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29701,NULL,'Enterprise, MS 39330',11985,222,NULL,42,17423,0);
INSERT INTO "django_geo_db_location" VALUES(29702,NULL,'Hickory, MS',11986,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29703,NULL,'Hickory, MS 39332',11986,222,NULL,42,17424,0);
INSERT INTO "django_geo_db_location" VALUES(29704,NULL,'Lauderdale, MS',11987,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29705,NULL,'Lauderdale, MS 39335',11987,222,NULL,42,17425,0);
INSERT INTO "django_geo_db_location" VALUES(29706,NULL,'Lawrence, MS',11988,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29707,NULL,'Lawrence, MS 39336',11988,222,NULL,42,17426,0);
INSERT INTO "django_geo_db_location" VALUES(29708,NULL,'Little Rock, MS',11989,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29709,NULL,'Little Rock, MS 39337',11989,222,NULL,42,17427,0);
INSERT INTO "django_geo_db_location" VALUES(29710,NULL,'Louin, MS',11990,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29711,NULL,'Louin, MS 39338',11990,222,NULL,42,17428,0);
INSERT INTO "django_geo_db_location" VALUES(29712,NULL,'Louisville, MS',11991,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29713,NULL,'Louisville, MS 39339',11991,222,NULL,42,17429,0);
INSERT INTO "django_geo_db_location" VALUES(29714,NULL,'Macon, MS',11992,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29715,NULL,'Macon, MS 39341',11992,222,NULL,42,17430,0);
INSERT INTO "django_geo_db_location" VALUES(29716,NULL,'Marion, MS',11993,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29717,NULL,'Marion, MS 39342',11993,222,NULL,42,17431,0);
INSERT INTO "django_geo_db_location" VALUES(29718,NULL,'Newton, MS',11994,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29719,NULL,'Newton, MS 39345',11994,222,NULL,42,17432,0);
INSERT INTO "django_geo_db_location" VALUES(29720,NULL,'Noxapater, MS',11995,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29721,NULL,'Noxapater, MS 39346',11995,222,NULL,42,17433,0);
INSERT INTO "django_geo_db_location" VALUES(29722,NULL,'Pachuta, MS',11996,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29723,NULL,'Pachuta, MS 39347',11996,222,NULL,42,17434,0);
INSERT INTO "django_geo_db_location" VALUES(29724,NULL,'Paulding, MS',11997,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29725,NULL,'Paulding, MS 39348',11997,222,NULL,42,17435,0);
INSERT INTO "django_geo_db_location" VALUES(29726,NULL,'Philadelphia, MS',11998,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29727,NULL,'Philadelphia, MS 39350',11998,222,NULL,42,17436,0);
INSERT INTO "django_geo_db_location" VALUES(29728,NULL,'Porterville, MS',11999,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29729,NULL,'Porterville, MS 39352',11999,222,NULL,42,17437,0);
INSERT INTO "django_geo_db_location" VALUES(29730,NULL,'Preston, MS',12000,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29731,NULL,'Preston, MS 39354',12000,222,NULL,42,17438,0);
INSERT INTO "django_geo_db_location" VALUES(29732,NULL,'Quitman, MS',12001,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29733,NULL,'Quitman, MS 39355',12001,222,NULL,42,17439,0);
INSERT INTO "django_geo_db_location" VALUES(29734,NULL,'Rose Hill, MS',12002,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29735,NULL,'Rose Hill, MS 39356',12002,222,NULL,42,17440,0);
INSERT INTO "django_geo_db_location" VALUES(29736,NULL,'Louisville, MS 39357',11991,222,NULL,42,17441,0);
INSERT INTO "django_geo_db_location" VALUES(29737,NULL,'Scooba, MS',12003,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29738,NULL,'Scooba, MS 39358',12003,222,NULL,42,17442,0);
INSERT INTO "django_geo_db_location" VALUES(29739,NULL,'Sebastopol, MS',12004,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29740,NULL,'Sebastopol, MS 39359',12004,222,NULL,42,17443,0);
INSERT INTO "django_geo_db_location" VALUES(29741,NULL,'Shubuta, MS',12005,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29742,NULL,'Shubuta, MS 39360',12005,222,NULL,42,17444,0);
INSERT INTO "django_geo_db_location" VALUES(29743,NULL,'Shuqualak, MS',12006,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29744,NULL,'Shuqualak, MS 39361',12006,222,NULL,42,17445,0);
INSERT INTO "django_geo_db_location" VALUES(29745,NULL,'State Line, MS',12007,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29746,NULL,'State Line, MS 39362',12007,222,NULL,42,17446,0);
INSERT INTO "django_geo_db_location" VALUES(29747,NULL,'Stonewall, MS',12008,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29748,NULL,'Stonewall, MS 39363',12008,222,NULL,42,17447,0);
INSERT INTO "django_geo_db_location" VALUES(29749,NULL,'Toomsuba, MS',12009,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29750,NULL,'Toomsuba, MS 39364',12009,222,NULL,42,17448,0);
INSERT INTO "django_geo_db_location" VALUES(29751,NULL,'Union, MS',12010,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29752,NULL,'Union, MS 39365',12010,222,NULL,42,17449,0);
INSERT INTO "django_geo_db_location" VALUES(29753,NULL,'Vossburg, MS',12011,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29754,NULL,'Vossburg, MS 39366',12011,222,NULL,42,17450,0);
INSERT INTO "django_geo_db_location" VALUES(29755,NULL,'Waynesboro, MS',12012,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29756,NULL,'Waynesboro, MS 39367',12012,222,NULL,42,17451,0);
INSERT INTO "django_geo_db_location" VALUES(29757,NULL,'Hattiesburg, MS',12013,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29758,NULL,'Hattiesburg, MS 39401',12013,222,NULL,42,17452,0);
INSERT INTO "django_geo_db_location" VALUES(29759,NULL,'Hattiesburg, MS 39402',12013,222,NULL,42,17453,0);
INSERT INTO "django_geo_db_location" VALUES(29760,NULL,'Hattiesburg, MS 39403',12013,222,NULL,42,17454,0);
INSERT INTO "django_geo_db_location" VALUES(29761,NULL,'Hattiesburg, MS 39404',12013,222,NULL,42,17455,0);
INSERT INTO "django_geo_db_location" VALUES(29762,NULL,'Hattiesburg, MS 39406',12013,222,NULL,42,17456,0);
INSERT INTO "django_geo_db_location" VALUES(29763,NULL,'Hattiesburg, MS 39407',12013,222,NULL,42,17457,0);
INSERT INTO "django_geo_db_location" VALUES(29764,NULL,'Bassfield, MS',12014,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29765,NULL,'Bassfield, MS 39421',12014,222,NULL,42,17458,0);
INSERT INTO "django_geo_db_location" VALUES(29766,NULL,'Bay Springs, MS',12015,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29767,NULL,'Bay Springs, MS 39422',12015,222,NULL,42,17459,0);
INSERT INTO "django_geo_db_location" VALUES(29768,NULL,'Beaumont, MS',12016,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29769,NULL,'Beaumont, MS 39423',12016,222,NULL,42,17460,0);
INSERT INTO "django_geo_db_location" VALUES(29770,NULL,'Brooklyn, MS',12017,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29771,NULL,'Brooklyn, MS 39425',12017,222,NULL,42,17461,0);
INSERT INTO "django_geo_db_location" VALUES(29772,NULL,'Carriere, MS',12018,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29773,NULL,'Carriere, MS 39426',12018,222,NULL,42,17462,0);
INSERT INTO "django_geo_db_location" VALUES(29774,NULL,'Carson, MS',12019,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29775,NULL,'Carson, MS 39427',12019,222,NULL,42,17463,0);
INSERT INTO "django_geo_db_location" VALUES(29776,NULL,'Collins, MS',12020,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29777,NULL,'Collins, MS 39428',12020,222,NULL,42,17464,0);
INSERT INTO "django_geo_db_location" VALUES(29778,NULL,'Columbia, MS',12021,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29779,NULL,'Columbia, MS 39429',12021,222,NULL,42,17465,0);
INSERT INTO "django_geo_db_location" VALUES(29780,NULL,'Eastabuchie, MS',12022,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29781,NULL,'Eastabuchie, MS 39436',12022,222,NULL,42,17466,0);
INSERT INTO "django_geo_db_location" VALUES(29782,NULL,'Ellisville, MS',12023,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29783,NULL,'Ellisville, MS 39437',12023,222,NULL,42,17467,0);
INSERT INTO "django_geo_db_location" VALUES(29784,NULL,'Heidelberg, MS',12024,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29785,NULL,'Heidelberg, MS 39439',12024,222,NULL,42,17468,0);
INSERT INTO "django_geo_db_location" VALUES(29786,NULL,'Laurel, MS',12025,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29787,NULL,'Laurel, MS 39440',12025,222,NULL,42,17469,0);
INSERT INTO "django_geo_db_location" VALUES(29788,NULL,'Laurel, MS 39441',12025,222,NULL,42,17470,0);
INSERT INTO "django_geo_db_location" VALUES(29789,NULL,'Laurel, MS 39442',12025,222,NULL,42,17471,0);
INSERT INTO "django_geo_db_location" VALUES(29790,NULL,'Laurel, MS 39443',12025,222,NULL,42,17472,0);
INSERT INTO "django_geo_db_location" VALUES(29791,NULL,'Leakesville, MS',12026,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29792,NULL,'Leakesville, MS 39451',12026,222,NULL,42,17473,0);
INSERT INTO "django_geo_db_location" VALUES(29793,NULL,'Lucedale, MS',12027,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29794,NULL,'Lucedale, MS 39452',12027,222,NULL,42,17474,0);
INSERT INTO "django_geo_db_location" VALUES(29795,NULL,'Lumberton, MS',12028,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29796,NULL,'Lumberton, MS 39455',12028,222,NULL,42,17475,0);
INSERT INTO "django_geo_db_location" VALUES(29797,NULL,'McLain, MS',12029,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29798,NULL,'McLain, MS 39456',12029,222,NULL,42,17476,0);
INSERT INTO "django_geo_db_location" VALUES(29799,NULL,'McNeill, MS',12030,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29800,NULL,'McNeill, MS 39457',12030,222,NULL,42,17477,0);
INSERT INTO "django_geo_db_location" VALUES(29801,NULL,'Moselle, MS',12031,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29802,NULL,'Moselle, MS 39459',12031,222,NULL,42,17478,0);
INSERT INTO "django_geo_db_location" VALUES(29803,NULL,'Moss, MS',12032,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29804,NULL,'Moss, MS 39460',12032,222,NULL,42,17479,0);
INSERT INTO "django_geo_db_location" VALUES(29805,NULL,'Neely, MS',12033,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29806,NULL,'Neely, MS 39461',12033,222,NULL,42,17480,0);
INSERT INTO "django_geo_db_location" VALUES(29807,NULL,'New Augusta, MS',12034,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29808,NULL,'New Augusta, MS 39462',12034,222,NULL,42,17481,0);
INSERT INTO "django_geo_db_location" VALUES(29809,NULL,'Nicholson, MS',12035,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29810,NULL,'Nicholson, MS 39463',12035,222,NULL,42,17482,0);
INSERT INTO "django_geo_db_location" VALUES(29811,NULL,'Ovett, MS',12036,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29812,NULL,'Ovett, MS 39464',12036,222,NULL,42,17483,0);
INSERT INTO "django_geo_db_location" VALUES(29813,NULL,'Petal, MS',12037,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29814,NULL,'Petal, MS 39465',12037,222,NULL,42,17484,0);
INSERT INTO "django_geo_db_location" VALUES(29815,NULL,'Picayune, MS',12038,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29816,NULL,'Picayune, MS 39466',12038,222,NULL,42,17485,0);
INSERT INTO "django_geo_db_location" VALUES(29817,NULL,'Poplarville, MS',12039,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29818,NULL,'Poplarville, MS 39470',12039,222,NULL,42,17486,0);
INSERT INTO "django_geo_db_location" VALUES(29819,NULL,'Prentiss, MS',12040,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29820,NULL,'Prentiss, MS 39474',12040,222,NULL,42,17487,0);
INSERT INTO "django_geo_db_location" VALUES(29821,NULL,'Purvis, MS',12041,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29822,NULL,'Purvis, MS 39475',12041,222,NULL,42,17488,0);
INSERT INTO "django_geo_db_location" VALUES(29823,NULL,'Richton, MS',12042,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29824,NULL,'Richton, MS 39476',12042,222,NULL,42,17489,0);
INSERT INTO "django_geo_db_location" VALUES(29825,NULL,'Sandersville, MS',12043,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29826,NULL,'Sandersville, MS 39477',12043,222,NULL,42,17490,0);
INSERT INTO "django_geo_db_location" VALUES(29827,NULL,'Sandy Hook, MS',12044,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29828,NULL,'Sandy Hook, MS 39478',12044,222,NULL,42,17491,0);
INSERT INTO "django_geo_db_location" VALUES(29829,NULL,'Seminary, MS',12045,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29830,NULL,'Seminary, MS 39479',12045,222,NULL,42,17492,0);
INSERT INTO "django_geo_db_location" VALUES(29831,NULL,'Soso, MS',12046,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29832,NULL,'Soso, MS 39480',12046,222,NULL,42,17493,0);
INSERT INTO "django_geo_db_location" VALUES(29833,NULL,'Stringer, MS',12047,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29834,NULL,'Stringer, MS 39481',12047,222,NULL,42,17494,0);
INSERT INTO "django_geo_db_location" VALUES(29835,NULL,'Sumrall, MS',12048,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29836,NULL,'Sumrall, MS 39482',12048,222,NULL,42,17495,0);
INSERT INTO "django_geo_db_location" VALUES(29837,NULL,'Foxworth, MS',12049,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29838,NULL,'Foxworth, MS 39483',12049,222,NULL,42,17496,0);
INSERT INTO "django_geo_db_location" VALUES(29839,NULL,'Gulfport, MS',12050,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29840,NULL,'Gulfport, MS 39501',12050,222,NULL,42,17497,0);
INSERT INTO "django_geo_db_location" VALUES(29841,NULL,'Gulfport, MS 39502',12050,222,NULL,42,17498,0);
INSERT INTO "django_geo_db_location" VALUES(29842,NULL,'Gulfport, MS 39503',12050,222,NULL,42,17499,0);
INSERT INTO "django_geo_db_location" VALUES(29843,NULL,'Gulfport, MS 39505',12050,222,NULL,42,17500,0);
INSERT INTO "django_geo_db_location" VALUES(29844,NULL,'Gulfport, MS 39506',12050,222,NULL,42,17501,0);
INSERT INTO "django_geo_db_location" VALUES(29845,NULL,'Gulfport, MS 39507',12050,222,NULL,42,17502,0);
INSERT INTO "django_geo_db_location" VALUES(29846,NULL,'Bay Saint Louis, MS',12051,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29847,NULL,'Bay Saint Louis, MS 39520',12051,222,NULL,42,17503,0);
INSERT INTO "django_geo_db_location" VALUES(29848,NULL,'Bay Saint Louis, MS 39521',12051,222,NULL,42,17504,0);
INSERT INTO "django_geo_db_location" VALUES(29849,NULL,'Stennis Space Center, MS',12052,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29850,NULL,'Stennis Space Center, MS 39522',12052,222,NULL,42,17505,0);
INSERT INTO "django_geo_db_location" VALUES(29851,NULL,'Diamondhead, MS',12053,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29852,NULL,'Diamondhead, MS 39525',12053,222,NULL,42,17506,0);
INSERT INTO "django_geo_db_location" VALUES(29853,NULL,'Stennis Space Center, MS 39529',12052,222,NULL,42,17507,0);
INSERT INTO "django_geo_db_location" VALUES(29854,NULL,'Biloxi, MS',12054,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29855,NULL,'Biloxi, MS 39530',12054,222,NULL,42,17508,0);
INSERT INTO "django_geo_db_location" VALUES(29856,NULL,'Biloxi, MS 39531',12054,222,NULL,42,17509,0);
INSERT INTO "django_geo_db_location" VALUES(29857,NULL,'Biloxi, MS 39532',12054,222,NULL,42,17510,0);
INSERT INTO "django_geo_db_location" VALUES(29858,NULL,'Biloxi, MS 39533',12054,222,NULL,42,17511,0);
INSERT INTO "django_geo_db_location" VALUES(29859,NULL,'Biloxi, MS 39534',12054,222,NULL,42,17512,0);
INSERT INTO "django_geo_db_location" VALUES(29860,NULL,'Biloxi, MS 39535',12054,222,NULL,42,17513,0);
INSERT INTO "django_geo_db_location" VALUES(29861,NULL,'D''Iberville, MS',12055,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29862,NULL,'D''Iberville, MS 39540',12055,222,NULL,42,17514,0);
INSERT INTO "django_geo_db_location" VALUES(29863,NULL,'Escatawpa, MS',12056,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29864,NULL,'Escatawpa, MS 39552',12056,222,NULL,42,17515,0);
INSERT INTO "django_geo_db_location" VALUES(29865,NULL,'Gautier, MS',12057,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29866,NULL,'Gautier, MS 39553',12057,222,NULL,42,17516,0);
INSERT INTO "django_geo_db_location" VALUES(29867,NULL,'Hurley, MS',12058,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29868,NULL,'Hurley, MS 39555',12058,222,NULL,42,17517,0);
INSERT INTO "django_geo_db_location" VALUES(29869,NULL,'Kiln, MS',12059,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29870,NULL,'Kiln, MS 39556',12059,222,NULL,42,17518,0);
INSERT INTO "django_geo_db_location" VALUES(29871,NULL,'Lakeshore, MS',12060,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29872,NULL,'Lakeshore, MS 39558',12060,222,NULL,42,17519,0);
INSERT INTO "django_geo_db_location" VALUES(29873,NULL,'Long Beach, MS',12061,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29874,NULL,'Long Beach, MS 39560',12061,222,NULL,42,17520,0);
INSERT INTO "django_geo_db_location" VALUES(29875,NULL,'McHenry, MS',12062,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29876,NULL,'McHenry, MS 39561',12062,222,NULL,42,17521,0);
INSERT INTO "django_geo_db_location" VALUES(29877,NULL,'Moss Point, MS',12063,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29878,NULL,'Moss Point, MS 39562',12063,222,NULL,42,17522,0);
INSERT INTO "django_geo_db_location" VALUES(29879,NULL,'Moss Point, MS 39563',12063,222,NULL,42,17523,0);
INSERT INTO "django_geo_db_location" VALUES(29880,NULL,'Ocean Springs, MS',12064,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29881,NULL,'Ocean Springs, MS 39564',12064,222,NULL,42,17524,0);
INSERT INTO "django_geo_db_location" VALUES(29882,NULL,'Ocean Springs, MS 39565',12064,222,NULL,42,17525,0);
INSERT INTO "django_geo_db_location" VALUES(29883,NULL,'Ocean Springs, MS 39566',12064,222,NULL,42,17526,0);
INSERT INTO "django_geo_db_location" VALUES(29884,NULL,'Pascagoula, MS',12065,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29885,NULL,'Pascagoula, MS 39567',12065,222,NULL,42,17527,0);
INSERT INTO "django_geo_db_location" VALUES(29886,NULL,'Pascagoula, MS 39568',12065,222,NULL,42,17528,0);
INSERT INTO "django_geo_db_location" VALUES(29887,NULL,'Pascagoula, MS 39569',12065,222,NULL,42,17529,0);
INSERT INTO "django_geo_db_location" VALUES(29888,NULL,'Pass Christian, MS',12066,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29889,NULL,'Pass Christian, MS 39571',12066,222,NULL,42,17530,0);
INSERT INTO "django_geo_db_location" VALUES(29890,NULL,'Pearlington, MS',12067,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29891,NULL,'Pearlington, MS 39572',12067,222,NULL,42,17531,0);
INSERT INTO "django_geo_db_location" VALUES(29892,NULL,'Perkinston, MS',12068,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29893,NULL,'Perkinston, MS 39573',12068,222,NULL,42,17532,0);
INSERT INTO "django_geo_db_location" VALUES(29894,NULL,'Saucier, MS',12069,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29895,NULL,'Saucier, MS 39574',12069,222,NULL,42,17533,0);
INSERT INTO "django_geo_db_location" VALUES(29896,NULL,'Waveland, MS',12070,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29897,NULL,'Waveland, MS 39576',12070,222,NULL,42,17534,0);
INSERT INTO "django_geo_db_location" VALUES(29898,NULL,'Wiggins, MS',12071,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29899,NULL,'Wiggins, MS 39577',12071,222,NULL,42,17535,0);
INSERT INTO "django_geo_db_location" VALUES(29900,NULL,'Pearlington, MS 39579',12067,222,NULL,42,17536,0);
INSERT INTO "django_geo_db_location" VALUES(29901,NULL,'Pascagoula, MS 39581',12065,222,NULL,42,17537,0);
INSERT INTO "django_geo_db_location" VALUES(29902,NULL,'Pascagoula, MS 39595',12065,222,NULL,42,17538,0);
INSERT INTO "django_geo_db_location" VALUES(29903,NULL,'Brookhaven, MS',12072,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29904,NULL,'Brookhaven, MS 39601',12072,222,NULL,42,17539,0);
INSERT INTO "django_geo_db_location" VALUES(29905,NULL,'Brookhaven, MS 39602',12072,222,NULL,42,17540,0);
INSERT INTO "django_geo_db_location" VALUES(29906,NULL,'Brookhaven, MS 39603',12072,222,NULL,42,17541,0);
INSERT INTO "django_geo_db_location" VALUES(29907,NULL,'Bogue Chitto, MS',12073,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29908,NULL,'Bogue Chitto, MS 39629',12073,222,NULL,42,17542,0);
INSERT INTO "django_geo_db_location" VALUES(29909,NULL,'Bude, MS',12074,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29910,NULL,'Bude, MS 39630',12074,222,NULL,42,17543,0);
INSERT INTO "django_geo_db_location" VALUES(29911,NULL,'Centreville, MS',12075,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29912,NULL,'Centreville, MS 39631',12075,222,NULL,42,17544,0);
INSERT INTO "django_geo_db_location" VALUES(29913,NULL,'Chatawa, MS',12076,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29914,NULL,'Chatawa, MS 39632',12076,222,NULL,42,17545,0);
INSERT INTO "django_geo_db_location" VALUES(29915,NULL,'Crosby, MS',12077,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29916,NULL,'Crosby, MS 39633',12077,222,NULL,42,17546,0);
INSERT INTO "django_geo_db_location" VALUES(29917,NULL,'Fernwood, MS',12078,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29918,NULL,'Fernwood, MS 39635',12078,222,NULL,42,17547,0);
INSERT INTO "django_geo_db_location" VALUES(29919,NULL,'Gloster, MS',12079,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29920,NULL,'Gloster, MS 39638',12079,222,NULL,42,17548,0);
INSERT INTO "django_geo_db_location" VALUES(29921,NULL,'Jayess, MS',12080,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29922,NULL,'Jayess, MS 39641',12080,222,NULL,42,17549,0);
INSERT INTO "django_geo_db_location" VALUES(29923,NULL,'Kokomo, MS',12081,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29924,NULL,'Kokomo, MS 39643',12081,222,NULL,42,17550,0);
INSERT INTO "django_geo_db_location" VALUES(29925,NULL,'Liberty, MS',12082,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29926,NULL,'Liberty, MS 39645',12082,222,NULL,42,17551,0);
INSERT INTO "django_geo_db_location" VALUES(29927,NULL,'McCall Creek, MS',12083,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29928,NULL,'McCall Creek, MS 39647',12083,222,NULL,42,17552,0);
INSERT INTO "django_geo_db_location" VALUES(29929,NULL,'Mccomb, MS',12084,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29930,NULL,'Mccomb, MS 39648',12084,222,NULL,42,17553,0);
INSERT INTO "django_geo_db_location" VALUES(29931,NULL,'Mccomb, MS 39649',12084,222,NULL,42,17554,0);
INSERT INTO "django_geo_db_location" VALUES(29932,NULL,'Magnolia, MS',12085,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29933,NULL,'Magnolia, MS 39652',12085,222,NULL,42,17555,0);
INSERT INTO "django_geo_db_location" VALUES(29934,NULL,'Meadville, MS',12086,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29935,NULL,'Meadville, MS 39653',12086,222,NULL,42,17556,0);
INSERT INTO "django_geo_db_location" VALUES(29936,NULL,'Monticello, MS',12087,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29937,NULL,'Monticello, MS 39654',12087,222,NULL,42,17557,0);
INSERT INTO "django_geo_db_location" VALUES(29938,NULL,'Oak Vale, MS',12088,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29939,NULL,'Oak Vale, MS 39656',12088,222,NULL,42,17558,0);
INSERT INTO "django_geo_db_location" VALUES(29940,NULL,'Osyka, MS',12089,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29941,NULL,'Osyka, MS 39657',12089,222,NULL,42,17559,0);
INSERT INTO "django_geo_db_location" VALUES(29942,NULL,'McComb, MS',12090,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29943,NULL,'McComb, MS 39660',12090,222,NULL,42,17560,0);
INSERT INTO "django_geo_db_location" VALUES(29944,NULL,'Roxie, MS',12091,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29945,NULL,'Roxie, MS 39661',12091,222,NULL,42,17561,0);
INSERT INTO "django_geo_db_location" VALUES(29946,NULL,'Ruth, MS',12092,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29947,NULL,'Ruth, MS 39662',12092,222,NULL,42,17562,0);
INSERT INTO "django_geo_db_location" VALUES(29948,NULL,'Silver Creek, MS',12093,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29949,NULL,'Silver Creek, MS 39663',12093,222,NULL,42,17563,0);
INSERT INTO "django_geo_db_location" VALUES(29950,NULL,'Smithdale, MS',12094,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29951,NULL,'Smithdale, MS 39664',12094,222,NULL,42,17564,0);
INSERT INTO "django_geo_db_location" VALUES(29952,NULL,'Sontag, MS',12095,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29953,NULL,'Sontag, MS 39665',12095,222,NULL,42,17565,0);
INSERT INTO "django_geo_db_location" VALUES(29954,NULL,'Summit, MS',12096,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29955,NULL,'Summit, MS 39666',12096,222,NULL,42,17566,0);
INSERT INTO "django_geo_db_location" VALUES(29956,NULL,'Tylertown, MS',12097,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29957,NULL,'Tylertown, MS 39667',12097,222,NULL,42,17567,0);
INSERT INTO "django_geo_db_location" VALUES(29958,NULL,'Union Church, MS',12098,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29959,NULL,'Union Church, MS 39668',12098,222,NULL,42,17568,0);
INSERT INTO "django_geo_db_location" VALUES(29960,NULL,'Woodville, MS',12099,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29961,NULL,'Woodville, MS 39669',12099,222,NULL,42,17569,0);
INSERT INTO "django_geo_db_location" VALUES(29962,NULL,'Columbus, MS',12100,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29963,NULL,'Columbus, MS 39701',12100,222,NULL,42,17570,0);
INSERT INTO "django_geo_db_location" VALUES(29964,NULL,'Columbus, MS 39702',12100,222,NULL,42,17571,0);
INSERT INTO "django_geo_db_location" VALUES(29965,NULL,'Columbus, MS 39703',12100,222,NULL,42,17572,0);
INSERT INTO "django_geo_db_location" VALUES(29966,NULL,'Columbus, MS 39704',12100,222,NULL,42,17573,0);
INSERT INTO "django_geo_db_location" VALUES(29967,NULL,'Columbus, MS 39705',12100,222,NULL,42,17574,0);
INSERT INTO "django_geo_db_location" VALUES(29968,NULL,'Columbus, MS 39710',12100,222,NULL,42,17575,0);
INSERT INTO "django_geo_db_location" VALUES(29969,NULL,'Aberdeen, MS',12101,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29970,NULL,'Aberdeen, MS 39730',12101,222,NULL,42,17576,0);
INSERT INTO "django_geo_db_location" VALUES(29971,NULL,'Brooksville, MS',12102,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29972,NULL,'Brooksville, MS 39731',12102,222,NULL,42,17577,0);
INSERT INTO "django_geo_db_location" VALUES(29973,NULL,'Ackerman, MS',12103,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29974,NULL,'Ackerman, MS 39735',12103,222,NULL,42,17578,0);
INSERT INTO "django_geo_db_location" VALUES(29975,NULL,'Artesia, MS',12104,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29976,NULL,'Artesia, MS 39736',12104,222,NULL,42,17579,0);
INSERT INTO "django_geo_db_location" VALUES(29977,NULL,'Bellefontaine, MS',12105,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29978,NULL,'Bellefontaine, MS 39737',12105,222,NULL,42,17580,0);
INSERT INTO "django_geo_db_location" VALUES(29979,NULL,'Brooksville, MS 39739',12102,222,NULL,42,17581,0);
INSERT INTO "django_geo_db_location" VALUES(29980,NULL,'Caledonia, MS',12106,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29981,NULL,'Caledonia, MS 39740',12106,222,NULL,42,17582,0);
INSERT INTO "django_geo_db_location" VALUES(29982,NULL,'Cedarbluff, MS',12107,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29983,NULL,'Cedarbluff, MS 39741',12107,222,NULL,42,17583,0);
INSERT INTO "django_geo_db_location" VALUES(29984,NULL,'Crawford, MS',12108,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29985,NULL,'Crawford, MS 39743',12108,222,NULL,42,17584,0);
INSERT INTO "django_geo_db_location" VALUES(29986,NULL,'Eupora, MS',12109,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29987,NULL,'Eupora, MS 39744',12109,222,NULL,42,17585,0);
INSERT INTO "django_geo_db_location" VALUES(29988,NULL,'French Camp, MS',12110,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29989,NULL,'French Camp, MS 39745',12110,222,NULL,42,17586,0);
INSERT INTO "django_geo_db_location" VALUES(29990,NULL,'Hamilton, MS',12111,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29991,NULL,'Hamilton, MS 39746',12111,222,NULL,42,17587,0);
INSERT INTO "django_geo_db_location" VALUES(29992,NULL,'Kilmichael, MS',12112,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29993,NULL,'Kilmichael, MS 39747',12112,222,NULL,42,17588,0);
INSERT INTO "django_geo_db_location" VALUES(29994,NULL,'Maben, MS',12113,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29995,NULL,'Maben, MS 39750',12113,222,NULL,42,17589,0);
INSERT INTO "django_geo_db_location" VALUES(29996,NULL,'Mantee, MS',12114,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29997,NULL,'Mantee, MS 39751',12114,222,NULL,42,17590,0);
INSERT INTO "django_geo_db_location" VALUES(29998,NULL,'Mathiston, MS',12115,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(29999,NULL,'Mathiston, MS 39752',12115,222,NULL,42,17591,0);
INSERT INTO "django_geo_db_location" VALUES(30000,NULL,'Mayhew, MS',12116,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30001,NULL,'Mayhew, MS 39753',12116,222,NULL,42,17592,0);
INSERT INTO "django_geo_db_location" VALUES(30002,NULL,'Montpelier, MS',12117,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30003,NULL,'Montpelier, MS 39754',12117,222,NULL,42,17593,0);
INSERT INTO "django_geo_db_location" VALUES(30004,NULL,'Pheba, MS',12118,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30005,NULL,'Pheba, MS 39755',12118,222,NULL,42,17594,0);
INSERT INTO "django_geo_db_location" VALUES(30006,NULL,'Prairie, MS',12119,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30007,NULL,'Prairie, MS 39756',12119,222,NULL,42,17595,0);
INSERT INTO "django_geo_db_location" VALUES(30008,NULL,'Sturgis, MS',12120,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30009,NULL,'Sturgis, MS 39758',12120,222,NULL,42,17596,0);
INSERT INTO "django_geo_db_location" VALUES(30010,NULL,'Starkville, MS',12121,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30011,NULL,'Starkville, MS 39759',12121,222,NULL,42,17597,0);
INSERT INTO "django_geo_db_location" VALUES(30012,NULL,'Starkville, MS 39760',12121,222,NULL,42,17598,0);
INSERT INTO "django_geo_db_location" VALUES(30013,NULL,'Mississippi State, MS',12122,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30014,NULL,'Mississippi State, MS 39762',12122,222,NULL,42,17599,0);
INSERT INTO "django_geo_db_location" VALUES(30015,NULL,'Steens, MS',12123,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30016,NULL,'Steens, MS 39766',12123,222,NULL,42,17600,0);
INSERT INTO "django_geo_db_location" VALUES(30017,NULL,'Stewart, MS',12124,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30018,NULL,'Stewart, MS 39767',12124,222,NULL,42,17601,0);
INSERT INTO "django_geo_db_location" VALUES(30019,NULL,'Sturgis, MS 39769',12120,222,NULL,42,17602,0);
INSERT INTO "django_geo_db_location" VALUES(30020,NULL,'Walthall, MS',12125,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30021,NULL,'Walthall, MS 39771',12125,222,NULL,42,17603,0);
INSERT INTO "django_geo_db_location" VALUES(30022,NULL,'Weir, MS',12126,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30023,NULL,'Weir, MS 39772',12126,222,NULL,42,17604,0);
INSERT INTO "django_geo_db_location" VALUES(30024,NULL,'West Point, MS',12127,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30025,NULL,'West Point, MS 39773',12127,222,NULL,42,17605,0);
INSERT INTO "django_geo_db_location" VALUES(30026,NULL,'Woodland, MS',12128,222,NULL,42,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30027,NULL,'Woodland, MS 39776',12128,222,NULL,42,17606,0);
INSERT INTO "django_geo_db_location" VALUES(30028,NULL,'Flora, MS 39871',11903,222,NULL,42,17607,0);
INSERT INTO "django_geo_db_location" VALUES(30029,NULL,'Atlanta, GA 39901',9514,222,NULL,13,17608,0);
INSERT INTO "django_geo_db_location" VALUES(30030,NULL,'Laurel, MS 39940',12025,222,NULL,42,17609,0);
INSERT INTO "django_geo_db_location" VALUES(30031,NULL,'Kiln, MS 39956',12059,222,NULL,42,17610,0);
INSERT INTO "django_geo_db_location" VALUES(30032,NULL,'Bagdad, KY',12129,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30033,NULL,'Bagdad, KY 40003',12129,222,NULL,21,17611,0);
INSERT INTO "django_geo_db_location" VALUES(30034,NULL,'Bardstown, KY',12130,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30035,NULL,'Bardstown, KY 40004',12130,222,NULL,21,17612,0);
INSERT INTO "django_geo_db_location" VALUES(30036,NULL,'Bedford, KY',12131,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30037,NULL,'Bedford, KY 40006',12131,222,NULL,21,17613,0);
INSERT INTO "django_geo_db_location" VALUES(30038,NULL,'Bethlehem, KY',12132,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30039,NULL,'Bethlehem, KY 40007',12132,222,NULL,21,17614,0);
INSERT INTO "django_geo_db_location" VALUES(30040,NULL,'Bloomfield, KY',12133,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30041,NULL,'Bloomfield, KY 40008',12133,222,NULL,21,17615,0);
INSERT INTO "django_geo_db_location" VALUES(30042,NULL,'Bradfordsville, KY',12134,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30043,NULL,'Bradfordsville, KY 40009',12134,222,NULL,21,17616,0);
INSERT INTO "django_geo_db_location" VALUES(30044,NULL,'Buckner, KY',12135,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30045,NULL,'Buckner, KY 40010',12135,222,NULL,21,17617,0);
INSERT INTO "django_geo_db_location" VALUES(30046,NULL,'Campbellsburg, KY',12136,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30047,NULL,'Campbellsburg, KY 40011',12136,222,NULL,21,17618,0);
INSERT INTO "django_geo_db_location" VALUES(30048,NULL,'Chaplin, KY',12137,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30049,NULL,'Chaplin, KY 40012',12137,222,NULL,21,17619,0);
INSERT INTO "django_geo_db_location" VALUES(30050,NULL,'Coxs Creek, KY',12138,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30051,NULL,'Coxs Creek, KY 40013',12138,222,NULL,21,17620,0);
INSERT INTO "django_geo_db_location" VALUES(30052,NULL,'Crestwood, KY',12139,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30053,NULL,'Crestwood, KY 40014',12139,222,NULL,21,17621,0);
INSERT INTO "django_geo_db_location" VALUES(30054,NULL,'Eastwood, KY',12140,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30055,NULL,'Eastwood, KY 40018',12140,222,NULL,21,17622,0);
INSERT INTO "django_geo_db_location" VALUES(30056,NULL,'Eminence, KY',12141,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30057,NULL,'Eminence, KY 40019',12141,222,NULL,21,17623,0);
INSERT INTO "django_geo_db_location" VALUES(30058,NULL,'Fairfield, KY',12142,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30059,NULL,'Fairfield, KY 40020',12142,222,NULL,21,17624,0);
INSERT INTO "django_geo_db_location" VALUES(30060,NULL,'Finchville, KY',12143,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30061,NULL,'Finchville, KY 40022',12143,222,NULL,21,17625,0);
INSERT INTO "django_geo_db_location" VALUES(30062,NULL,'Fisherville, KY',12144,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30063,NULL,'Fisherville, KY 40023',12144,222,NULL,21,17626,0);
INSERT INTO "django_geo_db_location" VALUES(30064,NULL,'Glenview, KY',12145,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30065,NULL,'Glenview, KY 40025',12145,222,NULL,21,17627,0);
INSERT INTO "django_geo_db_location" VALUES(30066,NULL,'Goshen, KY',12146,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30067,NULL,'Goshen, KY 40026',12146,222,NULL,21,17628,0);
INSERT INTO "django_geo_db_location" VALUES(30068,NULL,'Harrods Creek, KY',12147,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30069,NULL,'Harrods Creek, KY 40027',12147,222,NULL,21,17629,0);
INSERT INTO "django_geo_db_location" VALUES(30070,NULL,'La Grange, KY',12148,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30071,NULL,'La Grange, KY 40031',12148,222,NULL,21,17630,0);
INSERT INTO "django_geo_db_location" VALUES(30072,NULL,'La Grange, KY 40032',12148,222,NULL,21,17631,0);
INSERT INTO "django_geo_db_location" VALUES(30073,NULL,'Lebanon, KY',12149,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30074,NULL,'Lebanon, KY 40033',12149,222,NULL,21,17632,0);
INSERT INTO "django_geo_db_location" VALUES(30075,NULL,'Lockport, KY',12150,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30076,NULL,'Lockport, KY 40036',12150,222,NULL,21,17633,0);
INSERT INTO "django_geo_db_location" VALUES(30077,NULL,'Loretto, KY',12151,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30078,NULL,'Loretto, KY 40037',12151,222,NULL,21,17634,0);
INSERT INTO "django_geo_db_location" VALUES(30079,NULL,'Mackville, KY',12152,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30080,NULL,'Mackville, KY 40040',12152,222,NULL,21,17635,0);
INSERT INTO "django_geo_db_location" VALUES(30081,NULL,'Masonic Home, KY',12153,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30082,NULL,'Masonic Home, KY 40041',12153,222,NULL,21,17636,0);
INSERT INTO "django_geo_db_location" VALUES(30083,NULL,'Milton, KY',12154,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30084,NULL,'Milton, KY 40045',12154,222,NULL,21,17637,0);
INSERT INTO "django_geo_db_location" VALUES(30085,NULL,'Mount Eden, KY',12155,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30086,NULL,'Mount Eden, KY 40046',12155,222,NULL,21,17638,0);
INSERT INTO "django_geo_db_location" VALUES(30087,NULL,'Mount Washington, KY',12156,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30088,NULL,'Mount Washington, KY 40047',12156,222,NULL,21,17639,0);
INSERT INTO "django_geo_db_location" VALUES(30089,NULL,'Nazareth, KY',12157,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30090,NULL,'Nazareth, KY 40048',12157,222,NULL,21,17640,0);
INSERT INTO "django_geo_db_location" VALUES(30091,NULL,'Nerinx, KY',12158,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30092,NULL,'Nerinx, KY 40049',12158,222,NULL,21,17641,0);
INSERT INTO "django_geo_db_location" VALUES(30093,NULL,'New Castle, KY',12159,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30094,NULL,'New Castle, KY 40050',12159,222,NULL,21,17642,0);
INSERT INTO "django_geo_db_location" VALUES(30095,NULL,'New Haven, KY',12160,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30096,NULL,'New Haven, KY 40051',12160,222,NULL,21,17643,0);
INSERT INTO "django_geo_db_location" VALUES(30097,NULL,'New Hope, KY',12161,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30098,NULL,'New Hope, KY 40052',12161,222,NULL,21,17644,0);
INSERT INTO "django_geo_db_location" VALUES(30099,NULL,'Pewee Valley, KY',12162,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30100,NULL,'Pewee Valley, KY 40053',12162,222,NULL,21,17645,0);
INSERT INTO "django_geo_db_location" VALUES(30101,NULL,'Pendleton, KY',12163,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30102,NULL,'Pendleton, KY 40055',12163,222,NULL,21,17646,0);
INSERT INTO "django_geo_db_location" VALUES(30103,NULL,'Pewee Valley, KY 40056',12162,222,NULL,21,17647,0);
INSERT INTO "django_geo_db_location" VALUES(30104,NULL,'Pleasureville, KY',12164,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30105,NULL,'Pleasureville, KY 40057',12164,222,NULL,21,17648,0);
INSERT INTO "django_geo_db_location" VALUES(30106,NULL,'Port Royal, KY',12165,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30107,NULL,'Port Royal, KY 40058',12165,222,NULL,21,17649,0);
INSERT INTO "django_geo_db_location" VALUES(30108,NULL,'Prospect, KY',12166,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30109,NULL,'Prospect, KY 40059',12166,222,NULL,21,17650,0);
INSERT INTO "django_geo_db_location" VALUES(30110,NULL,'Raywick, KY',12167,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30111,NULL,'Raywick, KY 40060',12167,222,NULL,21,17651,0);
INSERT INTO "django_geo_db_location" VALUES(30112,NULL,'Saint Catharine, KY',12168,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30113,NULL,'Saint Catharine, KY 40061',12168,222,NULL,21,17652,0);
INSERT INTO "django_geo_db_location" VALUES(30114,NULL,'Saint Francis, KY',12169,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30115,NULL,'Saint Francis, KY 40062',12169,222,NULL,21,17653,0);
INSERT INTO "django_geo_db_location" VALUES(30116,NULL,'Saint Mary, KY',12170,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30117,NULL,'Saint Mary, KY 40063',12170,222,NULL,21,17654,0);
INSERT INTO "django_geo_db_location" VALUES(30118,NULL,'Shelbyville, KY',12171,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30119,NULL,'Shelbyville, KY 40065',12171,222,NULL,21,17655,0);
INSERT INTO "django_geo_db_location" VALUES(30120,NULL,'Shelbyville, KY 40066',12171,222,NULL,21,17656,0);
INSERT INTO "django_geo_db_location" VALUES(30121,NULL,'Simpsonville, KY',12172,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30122,NULL,'Simpsonville, KY 40067',12172,222,NULL,21,17657,0);
INSERT INTO "django_geo_db_location" VALUES(30123,NULL,'Smithfield, KY',12173,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30124,NULL,'Smithfield, KY 40068',12173,222,NULL,21,17658,0);
INSERT INTO "django_geo_db_location" VALUES(30125,NULL,'Springfield, KY',12174,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30126,NULL,'Springfield, KY 40069',12174,222,NULL,21,17659,0);
INSERT INTO "django_geo_db_location" VALUES(30127,NULL,'Sulphur, KY',12175,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30128,NULL,'Sulphur, KY 40070',12175,222,NULL,21,17660,0);
INSERT INTO "django_geo_db_location" VALUES(30129,NULL,'Taylorsville, KY',12176,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30130,NULL,'Taylorsville, KY 40071',12176,222,NULL,21,17661,0);
INSERT INTO "django_geo_db_location" VALUES(30131,NULL,'Turners Station, KY',12177,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30132,NULL,'Turners Station, KY 40075',12177,222,NULL,21,17662,0);
INSERT INTO "django_geo_db_location" VALUES(30133,NULL,'Waddy, KY',12178,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30134,NULL,'Waddy, KY 40076',12178,222,NULL,21,17663,0);
INSERT INTO "django_geo_db_location" VALUES(30135,NULL,'Westport, KY',12179,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30136,NULL,'Westport, KY 40077',12179,222,NULL,21,17664,0);
INSERT INTO "django_geo_db_location" VALUES(30137,NULL,'Willisburg, KY',12180,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30138,NULL,'Willisburg, KY 40078',12180,222,NULL,21,17665,0);
INSERT INTO "django_geo_db_location" VALUES(30139,NULL,'Fairfield, KY 40080',12142,222,NULL,21,17666,0);
INSERT INTO "django_geo_db_location" VALUES(30140,NULL,'Crestwood, KY 40081',12139,222,NULL,21,17667,0);
INSERT INTO "django_geo_db_location" VALUES(30141,NULL,'Battletown, KY',12181,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30142,NULL,'Battletown, KY 40104',12181,222,NULL,21,17668,0);
INSERT INTO "django_geo_db_location" VALUES(30143,NULL,'Big Spring, KY',12182,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30144,NULL,'Big Spring, KY 40106',12182,222,NULL,21,17669,0);
INSERT INTO "django_geo_db_location" VALUES(30145,NULL,'Boston, KY',12183,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30146,NULL,'Boston, KY 40107',12183,222,NULL,21,17670,0);
INSERT INTO "django_geo_db_location" VALUES(30147,NULL,'Brandenburg, KY',12184,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30148,NULL,'Brandenburg, KY 40108',12184,222,NULL,21,17671,0);
INSERT INTO "django_geo_db_location" VALUES(30149,NULL,'Brooks, KY',12185,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30150,NULL,'Brooks, KY 40109',12185,222,NULL,21,17672,0);
INSERT INTO "django_geo_db_location" VALUES(30151,NULL,'Clermont, KY',12186,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30152,NULL,'Clermont, KY 40110',12186,222,NULL,21,17673,0);
INSERT INTO "django_geo_db_location" VALUES(30153,NULL,'Cloverport, KY',12187,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30154,NULL,'Cloverport, KY 40111',12187,222,NULL,21,17674,0);
INSERT INTO "django_geo_db_location" VALUES(30155,NULL,'Custer, KY',12188,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30156,NULL,'Custer, KY 40115',12188,222,NULL,21,17675,0);
INSERT INTO "django_geo_db_location" VALUES(30157,NULL,'Ekron, KY',12189,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30158,NULL,'Ekron, KY 40117',12189,222,NULL,21,17676,0);
INSERT INTO "django_geo_db_location" VALUES(30159,NULL,'Fairdale, KY',12190,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30160,NULL,'Fairdale, KY 40118',12190,222,NULL,21,17677,0);
INSERT INTO "django_geo_db_location" VALUES(30161,NULL,'Falls Of Rough, KY',12191,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30162,NULL,'Falls Of Rough, KY 40119',12191,222,NULL,21,17678,0);
INSERT INTO "django_geo_db_location" VALUES(30163,NULL,'Fort Knox, KY',12192,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30164,NULL,'Fort Knox, KY 40121',12192,222,NULL,21,17679,0);
INSERT INTO "django_geo_db_location" VALUES(30165,NULL,'Garfield, KY',12193,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30166,NULL,'Garfield, KY 40140',12193,222,NULL,21,17680,0);
INSERT INTO "django_geo_db_location" VALUES(30167,NULL,'Guston, KY',12194,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30168,NULL,'Guston, KY 40142',12194,222,NULL,21,17681,0);
INSERT INTO "django_geo_db_location" VALUES(30169,NULL,'Hardinsburg, KY',12195,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30170,NULL,'Hardinsburg, KY 40143',12195,222,NULL,21,17682,0);
INSERT INTO "django_geo_db_location" VALUES(30171,NULL,'Harned, KY',12196,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30172,NULL,'Harned, KY 40144',12196,222,NULL,21,17683,0);
INSERT INTO "django_geo_db_location" VALUES(30173,NULL,'Hudson, KY',12197,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30174,NULL,'Hudson, KY 40145',12197,222,NULL,21,17684,0);
INSERT INTO "django_geo_db_location" VALUES(30175,NULL,'Irvington, KY',12198,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30176,NULL,'Irvington, KY 40146',12198,222,NULL,21,17685,0);
INSERT INTO "django_geo_db_location" VALUES(30177,NULL,'Lebanon Junction, KY',12199,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30178,NULL,'Lebanon Junction, KY 40150',12199,222,NULL,21,17686,0);
INSERT INTO "django_geo_db_location" VALUES(30179,NULL,'McDaniels, KY',12200,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30180,NULL,'McDaniels, KY 40152',12200,222,NULL,21,17687,0);
INSERT INTO "django_geo_db_location" VALUES(30181,NULL,'McQuady, KY',12201,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30182,NULL,'McQuady, KY 40153',12201,222,NULL,21,17688,0);
INSERT INTO "django_geo_db_location" VALUES(30183,NULL,'Muldraugh, KY',12202,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30184,NULL,'Muldraugh, KY 40155',12202,222,NULL,21,17689,0);
INSERT INTO "django_geo_db_location" VALUES(30185,NULL,'Payneville, KY',12203,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30186,NULL,'Payneville, KY 40157',12203,222,NULL,21,17690,0);
INSERT INTO "django_geo_db_location" VALUES(30187,NULL,'Radcliff, KY',12204,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30188,NULL,'Radcliff, KY 40159',12204,222,NULL,21,17691,0);
INSERT INTO "django_geo_db_location" VALUES(30189,NULL,'Radcliff, KY 40160',12204,222,NULL,21,17692,0);
INSERT INTO "django_geo_db_location" VALUES(30190,NULL,'Rhodelia, KY',12205,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30191,NULL,'Rhodelia, KY 40161',12205,222,NULL,21,17693,0);
INSERT INTO "django_geo_db_location" VALUES(30192,NULL,'Rineyville, KY',12206,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30193,NULL,'Rineyville, KY 40162',12206,222,NULL,21,17694,0);
INSERT INTO "django_geo_db_location" VALUES(30194,NULL,'Se Ree, KY',12207,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30195,NULL,'Se Ree, KY 40164',12207,222,NULL,21,17695,0);
INSERT INTO "django_geo_db_location" VALUES(30196,NULL,'Shepherdsville, KY',12208,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30197,NULL,'Shepherdsville, KY 40165',12208,222,NULL,21,17696,0);
INSERT INTO "django_geo_db_location" VALUES(30198,NULL,'Stephensport, KY',12209,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30199,NULL,'Stephensport, KY 40170',12209,222,NULL,21,17697,0);
INSERT INTO "django_geo_db_location" VALUES(30200,NULL,'Union Star, KY',12210,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30201,NULL,'Union Star, KY 40171',12210,222,NULL,21,17698,0);
INSERT INTO "django_geo_db_location" VALUES(30202,NULL,'Vine Grove, KY',12211,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30203,NULL,'Vine Grove, KY 40175',12211,222,NULL,21,17699,0);
INSERT INTO "django_geo_db_location" VALUES(30204,NULL,'Webster, KY',12212,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30205,NULL,'Webster, KY 40176',12212,222,NULL,21,17700,0);
INSERT INTO "django_geo_db_location" VALUES(30206,NULL,'West Point, KY',12213,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30207,NULL,'West Point, KY 40177',12213,222,NULL,21,17701,0);
INSERT INTO "django_geo_db_location" VALUES(30208,NULL,'Westview, KY',12214,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30209,NULL,'Westview, KY 40178',12214,222,NULL,21,17702,0);
INSERT INTO "django_geo_db_location" VALUES(30210,NULL,'West Point, KY 40179',12213,222,NULL,21,17703,0);
INSERT INTO "django_geo_db_location" VALUES(30211,NULL,'Louisville, KY',12215,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30212,NULL,'Louisville, KY 40201',12215,222,NULL,21,17704,0);
INSERT INTO "django_geo_db_location" VALUES(30213,NULL,'Louisville, KY 40202',12215,222,NULL,21,17705,0);
INSERT INTO "django_geo_db_location" VALUES(30214,NULL,'Louisville, KY 40203',12215,222,NULL,21,17706,0);
INSERT INTO "django_geo_db_location" VALUES(30215,NULL,'Louisville, KY 40204',12215,222,NULL,21,17707,0);
INSERT INTO "django_geo_db_location" VALUES(30216,NULL,'Louisville, KY 40205',12215,222,NULL,21,17708,0);
INSERT INTO "django_geo_db_location" VALUES(30217,NULL,'Louisville, KY 40206',12215,222,NULL,21,17709,0);
INSERT INTO "django_geo_db_location" VALUES(30218,NULL,'Louisville, KY 40207',12215,222,NULL,21,17710,0);
INSERT INTO "django_geo_db_location" VALUES(30219,NULL,'Louisville, KY 40208',12215,222,NULL,21,17711,0);
INSERT INTO "django_geo_db_location" VALUES(30220,NULL,'Louisville, KY 40209',12215,222,NULL,21,17712,0);
INSERT INTO "django_geo_db_location" VALUES(30221,NULL,'Louisville, KY 40210',12215,222,NULL,21,17713,0);
INSERT INTO "django_geo_db_location" VALUES(30222,NULL,'Louisville, KY 40211',12215,222,NULL,21,17714,0);
INSERT INTO "django_geo_db_location" VALUES(30223,NULL,'Louisville, KY 40212',12215,222,NULL,21,17715,0);
INSERT INTO "django_geo_db_location" VALUES(30224,NULL,'Louisville, KY 40213',12215,222,NULL,21,17716,0);
INSERT INTO "django_geo_db_location" VALUES(30225,NULL,'Louisville, KY 40214',12215,222,NULL,21,17717,0);
INSERT INTO "django_geo_db_location" VALUES(30226,NULL,'Louisville, KY 40215',12215,222,NULL,21,17718,0);
INSERT INTO "django_geo_db_location" VALUES(30227,NULL,'Louisville, KY 40216',12215,222,NULL,21,17719,0);
INSERT INTO "django_geo_db_location" VALUES(30228,NULL,'Louisville, KY 40217',12215,222,NULL,21,17720,0);
INSERT INTO "django_geo_db_location" VALUES(30229,NULL,'Louisville, KY 40218',12215,222,NULL,21,17721,0);
INSERT INTO "django_geo_db_location" VALUES(30230,NULL,'Louisville, KY 40219',12215,222,NULL,21,17722,0);
INSERT INTO "django_geo_db_location" VALUES(30231,NULL,'Louisville, KY 40220',12215,222,NULL,21,17723,0);
INSERT INTO "django_geo_db_location" VALUES(30232,NULL,'Louisville, KY 40221',12215,222,NULL,21,17724,0);
INSERT INTO "django_geo_db_location" VALUES(30233,NULL,'Louisville, KY 40222',12215,222,NULL,21,17725,0);
INSERT INTO "django_geo_db_location" VALUES(30234,NULL,'Louisville, KY 40223',12215,222,NULL,21,17726,0);
INSERT INTO "django_geo_db_location" VALUES(30235,NULL,'Louisville, KY 40224',12215,222,NULL,21,17727,0);
INSERT INTO "django_geo_db_location" VALUES(30236,NULL,'Louisville, KY 40225',12215,222,NULL,21,17728,0);
INSERT INTO "django_geo_db_location" VALUES(30237,NULL,'Louisville, KY 40228',12215,222,NULL,21,17729,0);
INSERT INTO "django_geo_db_location" VALUES(30238,NULL,'Louisville, KY 40229',12215,222,NULL,21,17730,0);
INSERT INTO "django_geo_db_location" VALUES(30239,NULL,'Louisville, KY 40231',12215,222,NULL,21,17731,0);
INSERT INTO "django_geo_db_location" VALUES(30240,NULL,'Louisville, KY 40232',12215,222,NULL,21,17732,0);
INSERT INTO "django_geo_db_location" VALUES(30241,NULL,'Louisville, KY 40233',12215,222,NULL,21,17733,0);
INSERT INTO "django_geo_db_location" VALUES(30242,NULL,'Louisville, KY 40241',12215,222,NULL,21,17734,0);
INSERT INTO "django_geo_db_location" VALUES(30243,NULL,'Louisville, KY 40242',12215,222,NULL,21,17735,0);
INSERT INTO "django_geo_db_location" VALUES(30244,NULL,'Louisville, KY 40243',12215,222,NULL,21,17736,0);
INSERT INTO "django_geo_db_location" VALUES(30245,NULL,'Louisville, KY 40245',12215,222,NULL,21,17737,0);
INSERT INTO "django_geo_db_location" VALUES(30246,NULL,'Louisville, KY 40250',12215,222,NULL,21,17738,0);
INSERT INTO "django_geo_db_location" VALUES(30247,NULL,'Louisville, KY 40251',12215,222,NULL,21,17739,0);
INSERT INTO "django_geo_db_location" VALUES(30248,NULL,'Louisville, KY 40252',12215,222,NULL,21,17740,0);
INSERT INTO "django_geo_db_location" VALUES(30249,NULL,'Louisville, KY 40253',12215,222,NULL,21,17741,0);
INSERT INTO "django_geo_db_location" VALUES(30250,NULL,'Louisville, KY 40255',12215,222,NULL,21,17742,0);
INSERT INTO "django_geo_db_location" VALUES(30251,NULL,'Louisville, KY 40256',12215,222,NULL,21,17743,0);
INSERT INTO "django_geo_db_location" VALUES(30252,NULL,'Louisville, KY 40257',12215,222,NULL,21,17744,0);
INSERT INTO "django_geo_db_location" VALUES(30253,NULL,'Louisville, KY 40258',12215,222,NULL,21,17745,0);
INSERT INTO "django_geo_db_location" VALUES(30254,NULL,'Louisville, KY 40259',12215,222,NULL,21,17746,0);
INSERT INTO "django_geo_db_location" VALUES(30255,NULL,'Louisville, KY 40261',12215,222,NULL,21,17747,0);
INSERT INTO "django_geo_db_location" VALUES(30256,NULL,'Louisville, KY 40266',12215,222,NULL,21,17748,0);
INSERT INTO "django_geo_db_location" VALUES(30257,NULL,'Louisville, KY 40268',12215,222,NULL,21,17749,0);
INSERT INTO "django_geo_db_location" VALUES(30258,NULL,'Louisville, KY 40269',12215,222,NULL,21,17750,0);
INSERT INTO "django_geo_db_location" VALUES(30259,NULL,'Louisville, KY 40270',12215,222,NULL,21,17751,0);
INSERT INTO "django_geo_db_location" VALUES(30260,NULL,'Louisville, KY 40272',12215,222,NULL,21,17752,0);
INSERT INTO "django_geo_db_location" VALUES(30261,NULL,'Louisville, KY 40280',12215,222,NULL,21,17753,0);
INSERT INTO "django_geo_db_location" VALUES(30262,NULL,'Louisville, KY 40281',12215,222,NULL,21,17754,0);
INSERT INTO "django_geo_db_location" VALUES(30263,NULL,'Louisville, KY 40282',12215,222,NULL,21,17755,0);
INSERT INTO "django_geo_db_location" VALUES(30264,NULL,'Louisville, KY 40283',12215,222,NULL,21,17756,0);
INSERT INTO "django_geo_db_location" VALUES(30265,NULL,'Louisville, KY 40285',12215,222,NULL,21,17757,0);
INSERT INTO "django_geo_db_location" VALUES(30266,NULL,'Louisville, KY 40287',12215,222,NULL,21,17758,0);
INSERT INTO "django_geo_db_location" VALUES(30267,NULL,'Louisville, KY 40289',12215,222,NULL,21,17759,0);
INSERT INTO "django_geo_db_location" VALUES(30268,NULL,'Louisville, KY 40290',12215,222,NULL,21,17760,0);
INSERT INTO "django_geo_db_location" VALUES(30269,NULL,'Louisville, KY 40291',12215,222,NULL,21,17761,0);
INSERT INTO "django_geo_db_location" VALUES(30270,NULL,'Louisville, KY 40292',12215,222,NULL,21,17762,0);
INSERT INTO "django_geo_db_location" VALUES(30271,NULL,'Louisville, KY 40293',12215,222,NULL,21,17763,0);
INSERT INTO "django_geo_db_location" VALUES(30272,NULL,'Louisville, KY 40294',12215,222,NULL,21,17764,0);
INSERT INTO "django_geo_db_location" VALUES(30273,NULL,'Louisville, KY 40295',12215,222,NULL,21,17765,0);
INSERT INTO "django_geo_db_location" VALUES(30274,NULL,'Louisville, KY 40296',12215,222,NULL,21,17766,0);
INSERT INTO "django_geo_db_location" VALUES(30275,NULL,'Louisville, KY 40297',12215,222,NULL,21,17767,0);
INSERT INTO "django_geo_db_location" VALUES(30276,NULL,'Louisville, KY 40298',12215,222,NULL,21,17768,0);
INSERT INTO "django_geo_db_location" VALUES(30277,NULL,'Louisville, KY 40299',12215,222,NULL,21,17769,0);
INSERT INTO "django_geo_db_location" VALUES(30278,NULL,'Burgin, KY',12216,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30279,NULL,'Burgin, KY 40310',12216,222,NULL,21,17770,0);
INSERT INTO "django_geo_db_location" VALUES(30280,NULL,'Carlisle, KY',12217,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30281,NULL,'Carlisle, KY 40311',12217,222,NULL,21,17771,0);
INSERT INTO "django_geo_db_location" VALUES(30282,NULL,'Clay City, KY',12218,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30283,NULL,'Clay City, KY 40312',12218,222,NULL,21,17772,0);
INSERT INTO "django_geo_db_location" VALUES(30284,NULL,'Clearfield, KY',12219,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30285,NULL,'Clearfield, KY 40313',12219,222,NULL,21,17773,0);
INSERT INTO "django_geo_db_location" VALUES(30286,NULL,'Denniston, KY',12220,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30287,NULL,'Denniston, KY 40316',12220,222,NULL,21,17774,0);
INSERT INTO "django_geo_db_location" VALUES(30288,NULL,'Elliottville, KY',12221,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30289,NULL,'Elliottville, KY 40317',12221,222,NULL,21,17775,0);
INSERT INTO "django_geo_db_location" VALUES(30290,NULL,'Farmers, KY',12222,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30291,NULL,'Farmers, KY 40319',12222,222,NULL,21,17776,0);
INSERT INTO "django_geo_db_location" VALUES(30292,NULL,'Ford, KY',12223,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30293,NULL,'Ford, KY 40320',12223,222,NULL,21,17777,0);
INSERT INTO "django_geo_db_location" VALUES(30294,NULL,'Frenchburg, KY',12224,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30295,NULL,'Frenchburg, KY 40322',12224,222,NULL,21,17778,0);
INSERT INTO "django_geo_db_location" VALUES(30296,NULL,'Georgetown, KY',12225,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30297,NULL,'Georgetown, KY 40324',12225,222,NULL,21,17779,0);
INSERT INTO "django_geo_db_location" VALUES(30298,NULL,'Gravel Switch, KY',12226,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30299,NULL,'Gravel Switch, KY 40328',12226,222,NULL,21,17780,0);
INSERT INTO "django_geo_db_location" VALUES(30300,NULL,'Haldeman, KY',12227,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30301,NULL,'Haldeman, KY 40329',12227,222,NULL,21,17781,0);
INSERT INTO "django_geo_db_location" VALUES(30302,NULL,'Harrodsburg, KY',12228,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30303,NULL,'Harrodsburg, KY 40330',12228,222,NULL,21,17782,0);
INSERT INTO "django_geo_db_location" VALUES(30304,NULL,'Hope, KY',12229,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30305,NULL,'Hope, KY 40334',12229,222,NULL,21,17783,0);
INSERT INTO "django_geo_db_location" VALUES(30306,NULL,'Irvine, KY',12230,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30307,NULL,'Irvine, KY 40336',12230,222,NULL,21,17784,0);
INSERT INTO "django_geo_db_location" VALUES(30308,NULL,'Jeffersonville, KY',12231,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30309,NULL,'Jeffersonville, KY 40337',12231,222,NULL,21,17785,0);
INSERT INTO "django_geo_db_location" VALUES(30310,NULL,'Keene, KY',12232,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30311,NULL,'Keene, KY 40339',12232,222,NULL,21,17786,0);
INSERT INTO "django_geo_db_location" VALUES(30312,NULL,'Nicholasville, KY',12233,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30313,NULL,'Nicholasville, KY 40340',12233,222,NULL,21,17787,0);
INSERT INTO "django_geo_db_location" VALUES(30314,NULL,'Lawrenceburg, KY',12234,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30315,NULL,'Lawrenceburg, KY 40342',12234,222,NULL,21,17788,0);
INSERT INTO "django_geo_db_location" VALUES(30316,NULL,'Means, KY',12235,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30317,NULL,'Means, KY 40346',12235,222,NULL,21,17789,0);
INSERT INTO "django_geo_db_location" VALUES(30318,NULL,'Midway, KY',12236,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30319,NULL,'Midway, KY 40347',12236,222,NULL,21,17790,0);
INSERT INTO "django_geo_db_location" VALUES(30320,NULL,'Millersburg, KY',12237,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30321,NULL,'Millersburg, KY 40348',12237,222,NULL,21,17791,0);
INSERT INTO "django_geo_db_location" VALUES(30322,NULL,'Moorefield, KY',12238,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30323,NULL,'Moorefield, KY 40350',12238,222,NULL,21,17792,0);
INSERT INTO "django_geo_db_location" VALUES(30324,NULL,'Morehead, KY',12239,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30325,NULL,'Morehead, KY 40351',12239,222,NULL,21,17793,0);
INSERT INTO "django_geo_db_location" VALUES(30326,NULL,'Mount Sterling, KY',12240,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30327,NULL,'Mount Sterling, KY 40353',12240,222,NULL,21,17794,0);
INSERT INTO "django_geo_db_location" VALUES(30328,NULL,'New Liberty, KY',12241,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30329,NULL,'New Liberty, KY 40355',12241,222,NULL,21,17795,0);
INSERT INTO "django_geo_db_location" VALUES(30330,NULL,'Nicholasville, KY 40356',12233,222,NULL,21,17796,0);
INSERT INTO "django_geo_db_location" VALUES(30331,NULL,'North Middletown, KY',12242,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30332,NULL,'North Middletown, KY 40357',12242,222,NULL,21,17797,0);
INSERT INTO "django_geo_db_location" VALUES(30333,NULL,'Olympia, KY',12243,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30334,NULL,'Olympia, KY 40358',12243,222,NULL,21,17798,0);
INSERT INTO "django_geo_db_location" VALUES(30335,NULL,'Owenton, KY',12244,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30336,NULL,'Owenton, KY 40359',12244,222,NULL,21,17799,0);
INSERT INTO "django_geo_db_location" VALUES(30337,NULL,'Owingsville, KY',12245,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30338,NULL,'Owingsville, KY 40360',12245,222,NULL,21,17800,0);
INSERT INTO "django_geo_db_location" VALUES(30339,NULL,'Paris, KY',12246,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30340,NULL,'Paris, KY 40361',12246,222,NULL,21,17801,0);
INSERT INTO "django_geo_db_location" VALUES(30341,NULL,'Paris, KY 40362',12246,222,NULL,21,17802,0);
INSERT INTO "django_geo_db_location" VALUES(30342,NULL,'Perry Park, KY',12247,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30343,NULL,'Perry Park, KY 40363',12247,222,NULL,21,17803,0);
INSERT INTO "django_geo_db_location" VALUES(30344,NULL,'Preston, KY',12248,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30345,NULL,'Preston, KY 40366',12248,222,NULL,21,17804,0);
INSERT INTO "django_geo_db_location" VALUES(30346,NULL,'Sadieville, KY',12249,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30347,NULL,'Sadieville, KY 40370',12249,222,NULL,21,17805,0);
INSERT INTO "django_geo_db_location" VALUES(30348,NULL,'Salt Lick, KY',12250,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30349,NULL,'Salt Lick, KY 40371',12250,222,NULL,21,17806,0);
INSERT INTO "django_geo_db_location" VALUES(30350,NULL,'Salvisa, KY',12251,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30351,NULL,'Salvisa, KY 40372',12251,222,NULL,21,17807,0);
INSERT INTO "django_geo_db_location" VALUES(30352,NULL,'Sharpsburg, KY',12252,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30353,NULL,'Sharpsburg, KY 40374',12252,222,NULL,21,17808,0);
INSERT INTO "django_geo_db_location" VALUES(30354,NULL,'Slade, KY',12253,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30355,NULL,'Slade, KY 40376',12253,222,NULL,21,17809,0);
INSERT INTO "django_geo_db_location" VALUES(30356,NULL,'Stamping Ground, KY',12254,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30357,NULL,'Stamping Ground, KY 40379',12254,222,NULL,21,17810,0);
INSERT INTO "django_geo_db_location" VALUES(30358,NULL,'Stanton, KY',12255,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30359,NULL,'Stanton, KY 40380',12255,222,NULL,21,17811,0);
INSERT INTO "django_geo_db_location" VALUES(30360,NULL,'Versailles, KY',12256,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30361,NULL,'Versailles, KY 40383',12256,222,NULL,21,17812,0);
INSERT INTO "django_geo_db_location" VALUES(30362,NULL,'Versailles, KY 40384',12256,222,NULL,21,17813,0);
INSERT INTO "django_geo_db_location" VALUES(30363,NULL,'Waco, KY',12257,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30364,NULL,'Waco, KY 40385',12257,222,NULL,21,17814,0);
INSERT INTO "django_geo_db_location" VALUES(30365,NULL,'Versailles, KY 40386',12256,222,NULL,21,17815,0);
INSERT INTO "django_geo_db_location" VALUES(30366,NULL,'Wellington, KY',12258,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30367,NULL,'Wellington, KY 40387',12258,222,NULL,21,17816,0);
INSERT INTO "django_geo_db_location" VALUES(30368,NULL,'Wilmore, KY',12259,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30369,NULL,'Wilmore, KY 40390',12259,222,NULL,21,17817,0);
INSERT INTO "django_geo_db_location" VALUES(30370,NULL,'Winchester, KY',12260,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30371,NULL,'Winchester, KY 40391',12260,222,NULL,21,17818,0);
INSERT INTO "django_geo_db_location" VALUES(30372,NULL,'Winchester, KY 40392',12260,222,NULL,21,17819,0);
INSERT INTO "django_geo_db_location" VALUES(30373,NULL,'Annville, KY',12261,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30374,NULL,'Annville, KY 40402',12261,222,NULL,21,17820,0);
INSERT INTO "django_geo_db_location" VALUES(30375,NULL,'Berea, KY',12262,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30376,NULL,'Berea, KY 40403',12262,222,NULL,21,17821,0);
INSERT INTO "django_geo_db_location" VALUES(30377,NULL,'Berea, KY 40404',12262,222,NULL,21,17822,0);
INSERT INTO "django_geo_db_location" VALUES(30378,NULL,'Bighill, KY',12263,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30379,NULL,'Bighill, KY 40405',12263,222,NULL,21,17823,0);
INSERT INTO "django_geo_db_location" VALUES(30380,NULL,'Brodhead, KY',12264,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30381,NULL,'Brodhead, KY 40409',12264,222,NULL,21,17824,0);
INSERT INTO "django_geo_db_location" VALUES(30382,NULL,'Bryantsville, KY',12265,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30383,NULL,'Bryantsville, KY 40410',12265,222,NULL,21,17825,0);
INSERT INTO "django_geo_db_location" VALUES(30384,NULL,'Crab Orchard, KY',12266,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30385,NULL,'Crab Orchard, KY 40419',12266,222,NULL,21,17826,0);
INSERT INTO "django_geo_db_location" VALUES(30386,NULL,'Dabolt, KY',12267,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30387,NULL,'Dabolt, KY 40421',12267,222,NULL,21,17827,0);
INSERT INTO "django_geo_db_location" VALUES(30388,NULL,'Danville, KY',12268,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30389,NULL,'Danville, KY 40422',12268,222,NULL,21,17828,0);
INSERT INTO "django_geo_db_location" VALUES(30390,NULL,'Danville, KY 40423',12268,222,NULL,21,17829,0);
INSERT INTO "django_geo_db_location" VALUES(30391,NULL,'Gray Hawk, KY',12269,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30392,NULL,'Gray Hawk, KY 40434',12269,222,NULL,21,17830,0);
INSERT INTO "django_geo_db_location" VALUES(30393,NULL,'Hustonville, KY',12270,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30394,NULL,'Hustonville, KY 40437',12270,222,NULL,21,17831,0);
INSERT INTO "django_geo_db_location" VALUES(30395,NULL,'Junction City, KY',12271,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30396,NULL,'Junction City, KY 40440',12271,222,NULL,21,17832,0);
INSERT INTO "django_geo_db_location" VALUES(30397,NULL,'Kings Mountain, KY',12272,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30398,NULL,'Kings Mountain, KY 40442',12272,222,NULL,21,17833,0);
INSERT INTO "django_geo_db_location" VALUES(30399,NULL,'Lancaster, KY',12273,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30400,NULL,'Lancaster, KY 40444',12273,222,NULL,21,17834,0);
INSERT INTO "django_geo_db_location" VALUES(30401,NULL,'Livingston, KY',12274,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30402,NULL,'Livingston, KY 40445',12274,222,NULL,21,17835,0);
INSERT INTO "django_geo_db_location" VALUES(30403,NULL,'Lancaster, KY 40446',12273,222,NULL,21,17836,0);
INSERT INTO "django_geo_db_location" VALUES(30404,NULL,'McKee, KY',12275,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30405,NULL,'McKee, KY 40447',12275,222,NULL,21,17837,0);
INSERT INTO "django_geo_db_location" VALUES(30406,NULL,'McKinney, KY',12276,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30407,NULL,'McKinney, KY 40448',12276,222,NULL,21,17838,0);
INSERT INTO "django_geo_db_location" VALUES(30408,NULL,'Mitchellsburg, KY',12277,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30409,NULL,'Mitchellsburg, KY 40452',12277,222,NULL,21,17839,0);
INSERT INTO "django_geo_db_location" VALUES(30410,NULL,'Mount Vernon, KY',12278,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30411,NULL,'Mount Vernon, KY 40456',12278,222,NULL,21,17840,0);
INSERT INTO "django_geo_db_location" VALUES(30412,NULL,'Orlando, KY',12279,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30413,NULL,'Orlando, KY 40460',12279,222,NULL,21,17841,0);
INSERT INTO "django_geo_db_location" VALUES(30414,NULL,'Paint Lick, KY',12280,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30415,NULL,'Paint Lick, KY 40461',12280,222,NULL,21,17842,0);
INSERT INTO "django_geo_db_location" VALUES(30416,NULL,'Parksville, KY',12281,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30417,NULL,'Parksville, KY 40464',12281,222,NULL,21,17843,0);
INSERT INTO "django_geo_db_location" VALUES(30418,NULL,'Peoples, KY',12282,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30419,NULL,'Peoples, KY 40467',12282,222,NULL,21,17844,0);
INSERT INTO "django_geo_db_location" VALUES(30420,NULL,'Perryville, KY',12283,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30421,NULL,'Perryville, KY 40468',12283,222,NULL,21,17845,0);
INSERT INTO "django_geo_db_location" VALUES(30422,NULL,'Brodhead, KY 40469',12264,222,NULL,21,17846,0);
INSERT INTO "django_geo_db_location" VALUES(30423,NULL,'Ravenna, KY',12284,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30424,NULL,'Ravenna, KY 40472',12284,222,NULL,21,17847,0);
INSERT INTO "django_geo_db_location" VALUES(30425,NULL,'Renfro Valley, KY',12285,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30426,NULL,'Renfro Valley, KY 40473',12285,222,NULL,21,17848,0);
INSERT INTO "django_geo_db_location" VALUES(30427,NULL,'Richmond, KY',12286,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30428,NULL,'Richmond, KY 40475',12286,222,NULL,21,17849,0);
INSERT INTO "django_geo_db_location" VALUES(30429,NULL,'Richmond, KY 40476',12286,222,NULL,21,17850,0);
INSERT INTO "django_geo_db_location" VALUES(30430,NULL,'Sandgap, KY',12287,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30431,NULL,'Sandgap, KY 40481',12287,222,NULL,21,17851,0);
INSERT INTO "django_geo_db_location" VALUES(30432,NULL,'Stanford, KY',12288,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30433,NULL,'Stanford, KY 40484',12288,222,NULL,21,17852,0);
INSERT INTO "django_geo_db_location" VALUES(30434,NULL,'Tyner, KY',12289,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30435,NULL,'Tyner, KY 40486',12289,222,NULL,21,17853,0);
INSERT INTO "django_geo_db_location" VALUES(30436,NULL,'Waneta, KY',12290,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30437,NULL,'Waneta, KY 40488',12290,222,NULL,21,17854,0);
INSERT INTO "django_geo_db_location" VALUES(30438,NULL,'Waynesburg, KY',12291,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30439,NULL,'Waynesburg, KY 40489',12291,222,NULL,21,17855,0);
INSERT INTO "django_geo_db_location" VALUES(30440,NULL,'Wildie, KY',12292,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30441,NULL,'Wildie, KY 40492',12292,222,NULL,21,17856,0);
INSERT INTO "django_geo_db_location" VALUES(30442,NULL,'Winston, KY',12293,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30443,NULL,'Winston, KY 40495',12293,222,NULL,21,17857,0);
INSERT INTO "django_geo_db_location" VALUES(30444,NULL,'Lexington, KY',12294,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30445,NULL,'Lexington, KY 40501',12294,222,NULL,21,17858,0);
INSERT INTO "django_geo_db_location" VALUES(30446,NULL,'Lexington, KY 40502',12294,222,NULL,21,17859,0);
INSERT INTO "django_geo_db_location" VALUES(30447,NULL,'Lexington, KY 40503',12294,222,NULL,21,17860,0);
INSERT INTO "django_geo_db_location" VALUES(30448,NULL,'Lexington, KY 40504',12294,222,NULL,21,17861,0);
INSERT INTO "django_geo_db_location" VALUES(30449,NULL,'Lexington, KY 40505',12294,222,NULL,21,17862,0);
INSERT INTO "django_geo_db_location" VALUES(30450,NULL,'Lexington, KY 40506',12294,222,NULL,21,17863,0);
INSERT INTO "django_geo_db_location" VALUES(30451,NULL,'Lexington, KY 40507',12294,222,NULL,21,17864,0);
INSERT INTO "django_geo_db_location" VALUES(30452,NULL,'Lexington, KY 40508',12294,222,NULL,21,17865,0);
INSERT INTO "django_geo_db_location" VALUES(30453,NULL,'Lexington, KY 40509',12294,222,NULL,21,17866,0);
INSERT INTO "django_geo_db_location" VALUES(30454,NULL,'Lexington, KY 40510',12294,222,NULL,21,17867,0);
INSERT INTO "django_geo_db_location" VALUES(30455,NULL,'Lexington, KY 40511',12294,222,NULL,21,17868,0);
INSERT INTO "django_geo_db_location" VALUES(30456,NULL,'Lexington, KY 40512',12294,222,NULL,21,17869,0);
INSERT INTO "django_geo_db_location" VALUES(30457,NULL,'Lexington, KY 40513',12294,222,NULL,21,17870,0);
INSERT INTO "django_geo_db_location" VALUES(30458,NULL,'Lexington, KY 40514',12294,222,NULL,21,17871,0);
INSERT INTO "django_geo_db_location" VALUES(30459,NULL,'Lexington, KY 40515',12294,222,NULL,21,17872,0);
INSERT INTO "django_geo_db_location" VALUES(30460,NULL,'Lexington, KY 40516',12294,222,NULL,21,17873,0);
INSERT INTO "django_geo_db_location" VALUES(30461,NULL,'Lexington, KY 40517',12294,222,NULL,21,17874,0);
INSERT INTO "django_geo_db_location" VALUES(30462,NULL,'Lexington, KY 40522',12294,222,NULL,21,17875,0);
INSERT INTO "django_geo_db_location" VALUES(30463,NULL,'Lexington, KY 40523',12294,222,NULL,21,17876,0);
INSERT INTO "django_geo_db_location" VALUES(30464,NULL,'Lexington, KY 40524',12294,222,NULL,21,17877,0);
INSERT INTO "django_geo_db_location" VALUES(30465,NULL,'Lexington, KY 40526',12294,222,NULL,21,17878,0);
INSERT INTO "django_geo_db_location" VALUES(30466,NULL,'Lexington, KY 40533',12294,222,NULL,21,17879,0);
INSERT INTO "django_geo_db_location" VALUES(30467,NULL,'Lexington, KY 40536',12294,222,NULL,21,17880,0);
INSERT INTO "django_geo_db_location" VALUES(30468,NULL,'Lexington, KY 40544',12294,222,NULL,21,17881,0);
INSERT INTO "django_geo_db_location" VALUES(30469,NULL,'Lexington, KY 40546',12294,222,NULL,21,17882,0);
INSERT INTO "django_geo_db_location" VALUES(30470,NULL,'Lexington, KY 40550',12294,222,NULL,21,17883,0);
INSERT INTO "django_geo_db_location" VALUES(30471,NULL,'Lexington, KY 40555',12294,222,NULL,21,17884,0);
INSERT INTO "django_geo_db_location" VALUES(30472,NULL,'Lexington, KY 40574',12294,222,NULL,21,17885,0);
INSERT INTO "django_geo_db_location" VALUES(30473,NULL,'Lexington, KY 40575',12294,222,NULL,21,17886,0);
INSERT INTO "django_geo_db_location" VALUES(30474,NULL,'Lexington, KY 40576',12294,222,NULL,21,17887,0);
INSERT INTO "django_geo_db_location" VALUES(30475,NULL,'Lexington, KY 40577',12294,222,NULL,21,17888,0);
INSERT INTO "django_geo_db_location" VALUES(30476,NULL,'Lexington, KY 40578',12294,222,NULL,21,17889,0);
INSERT INTO "django_geo_db_location" VALUES(30477,NULL,'Lexington, KY 40579',12294,222,NULL,21,17890,0);
INSERT INTO "django_geo_db_location" VALUES(30478,NULL,'Lexington, KY 40580',12294,222,NULL,21,17891,0);
INSERT INTO "django_geo_db_location" VALUES(30479,NULL,'Lexington, KY 40581',12294,222,NULL,21,17892,0);
INSERT INTO "django_geo_db_location" VALUES(30480,NULL,'Lexington, KY 40582',12294,222,NULL,21,17893,0);
INSERT INTO "django_geo_db_location" VALUES(30481,NULL,'Lexington, KY 40583',12294,222,NULL,21,17894,0);
INSERT INTO "django_geo_db_location" VALUES(30482,NULL,'Lexington, KY 40584',12294,222,NULL,21,17895,0);
INSERT INTO "django_geo_db_location" VALUES(30483,NULL,'Lexington, KY 40585',12294,222,NULL,21,17896,0);
INSERT INTO "django_geo_db_location" VALUES(30484,NULL,'Lexington, KY 40586',12294,222,NULL,21,17897,0);
INSERT INTO "django_geo_db_location" VALUES(30485,NULL,'Lexington, KY 40587',12294,222,NULL,21,17898,0);
INSERT INTO "django_geo_db_location" VALUES(30486,NULL,'Lexington, KY 40588',12294,222,NULL,21,17899,0);
INSERT INTO "django_geo_db_location" VALUES(30487,NULL,'Lexington, KY 40589',12294,222,NULL,21,17900,0);
INSERT INTO "django_geo_db_location" VALUES(30488,NULL,'Lexington, KY 40590',12294,222,NULL,21,17901,0);
INSERT INTO "django_geo_db_location" VALUES(30489,NULL,'Lexington, KY 40591',12294,222,NULL,21,17902,0);
INSERT INTO "django_geo_db_location" VALUES(30490,NULL,'Lexington, KY 40592',12294,222,NULL,21,17903,0);
INSERT INTO "django_geo_db_location" VALUES(30491,NULL,'Lexington, KY 40593',12294,222,NULL,21,17904,0);
INSERT INTO "django_geo_db_location" VALUES(30492,NULL,'Lexington, KY 40594',12294,222,NULL,21,17905,0);
INSERT INTO "django_geo_db_location" VALUES(30493,NULL,'Lexington, KY 40595',12294,222,NULL,21,17906,0);
INSERT INTO "django_geo_db_location" VALUES(30494,NULL,'Lexington, KY 40596',12294,222,NULL,21,17907,0);
INSERT INTO "django_geo_db_location" VALUES(30495,NULL,'Frankfort, KY',12295,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30496,NULL,'Frankfort, KY 40601',12295,222,NULL,21,17908,0);
INSERT INTO "django_geo_db_location" VALUES(30497,NULL,'Frankfort, KY 40602',12295,222,NULL,21,17909,0);
INSERT INTO "django_geo_db_location" VALUES(30498,NULL,'Frankfort, KY 40603',12295,222,NULL,21,17910,0);
INSERT INTO "django_geo_db_location" VALUES(30499,NULL,'Frankfort, KY 40604',12295,222,NULL,21,17911,0);
INSERT INTO "django_geo_db_location" VALUES(30500,NULL,'Frankfort, KY 40618',12295,222,NULL,21,17912,0);
INSERT INTO "django_geo_db_location" VALUES(30501,NULL,'Frankfort, KY 40619',12295,222,NULL,21,17913,0);
INSERT INTO "django_geo_db_location" VALUES(30502,NULL,'Frankfort, KY 40620',12295,222,NULL,21,17914,0);
INSERT INTO "django_geo_db_location" VALUES(30503,NULL,'Frankfort, KY 40621',12295,222,NULL,21,17915,0);
INSERT INTO "django_geo_db_location" VALUES(30504,NULL,'Frankfort, KY 40622',12295,222,NULL,21,17916,0);
INSERT INTO "django_geo_db_location" VALUES(30505,NULL,'Middlesborough, KY',12296,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30506,NULL,'Middlesborough, KY 40695',12296,222,NULL,21,17917,0);
INSERT INTO "django_geo_db_location" VALUES(30507,NULL,'Corbin, KY',12297,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30508,NULL,'Corbin, KY 40701',12297,222,NULL,21,17918,0);
INSERT INTO "django_geo_db_location" VALUES(30509,NULL,'Corbin, KY 40702',12297,222,NULL,21,17919,0);
INSERT INTO "django_geo_db_location" VALUES(30510,NULL,'Bush, KY',12298,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30511,NULL,'Bush, KY 40724',12298,222,NULL,21,17920,0);
INSERT INTO "django_geo_db_location" VALUES(30512,NULL,'East Bernstadt, KY',12299,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30513,NULL,'East Bernstadt, KY 40729',12299,222,NULL,21,17921,0);
INSERT INTO "django_geo_db_location" VALUES(30514,NULL,'Emlyn, KY',12300,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30515,NULL,'Emlyn, KY 40730',12300,222,NULL,21,17922,0);
INSERT INTO "django_geo_db_location" VALUES(30516,NULL,'Gray, KY',12301,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30517,NULL,'Gray, KY 40734',12301,222,NULL,21,17923,0);
INSERT INTO "django_geo_db_location" VALUES(30518,NULL,'Keavy, KY',12302,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30519,NULL,'Keavy, KY 40737',12302,222,NULL,21,17924,0);
INSERT INTO "django_geo_db_location" VALUES(30520,NULL,'Lily, KY',12303,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30521,NULL,'Lily, KY 40740',12303,222,NULL,21,17925,0);
INSERT INTO "django_geo_db_location" VALUES(30522,NULL,'London, KY',12304,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30523,NULL,'London, KY 40741',12304,222,NULL,21,17926,0);
INSERT INTO "django_geo_db_location" VALUES(30524,NULL,'London, KY 40742',12304,222,NULL,21,17927,0);
INSERT INTO "django_geo_db_location" VALUES(30525,NULL,'London, KY 40743',12304,222,NULL,21,17928,0);
INSERT INTO "django_geo_db_location" VALUES(30526,NULL,'London, KY 40744',12304,222,NULL,21,17929,0);
INSERT INTO "django_geo_db_location" VALUES(30527,NULL,'London, KY 40745',12304,222,NULL,21,17930,0);
INSERT INTO "django_geo_db_location" VALUES(30528,NULL,'London, KY 40746',12304,222,NULL,21,17931,0);
INSERT INTO "django_geo_db_location" VALUES(30529,NULL,'London, KY 40747',12304,222,NULL,21,17932,0);
INSERT INTO "django_geo_db_location" VALUES(30530,NULL,'London, KY 40748',12304,222,NULL,21,17933,0);
INSERT INTO "django_geo_db_location" VALUES(30531,NULL,'Marydell, KY',12305,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30532,NULL,'Marydell, KY 40751',12305,222,NULL,21,17934,0);
INSERT INTO "django_geo_db_location" VALUES(30533,NULL,'Nevisdale, KY',12306,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30534,NULL,'Nevisdale, KY 40754',12306,222,NULL,21,17935,0);
INSERT INTO "django_geo_db_location" VALUES(30535,NULL,'Pittsburg, KY',12307,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30536,NULL,'Pittsburg, KY 40755',12307,222,NULL,21,17936,0);
INSERT INTO "django_geo_db_location" VALUES(30537,NULL,'Rockholds, KY',12308,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30538,NULL,'Rockholds, KY 40759',12308,222,NULL,21,17937,0);
INSERT INTO "django_geo_db_location" VALUES(30539,NULL,'Siler, KY',12309,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30540,NULL,'Siler, KY 40763',12309,222,NULL,21,17938,0);
INSERT INTO "django_geo_db_location" VALUES(30541,NULL,'Williamsburg, KY',12310,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30542,NULL,'Williamsburg, KY 40769',12310,222,NULL,21,17939,0);
INSERT INTO "django_geo_db_location" VALUES(30543,NULL,'Woodbine, KY',12311,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30544,NULL,'Woodbine, KY 40771',12311,222,NULL,21,17940,0);
INSERT INTO "django_geo_db_location" VALUES(30545,NULL,'Ages Brookside, KY',12312,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30546,NULL,'Ages Brookside, KY 40801',12312,222,NULL,21,17941,0);
INSERT INTO "django_geo_db_location" VALUES(30547,NULL,'Asher, KY',12313,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30548,NULL,'Asher, KY 40803',12313,222,NULL,21,17942,0);
INSERT INTO "django_geo_db_location" VALUES(30549,NULL,'Baxter, KY',12314,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30550,NULL,'Baxter, KY 40806',12314,222,NULL,21,17943,0);
INSERT INTO "django_geo_db_location" VALUES(30551,NULL,'Benham, KY',12315,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30552,NULL,'Benham, KY 40807',12315,222,NULL,21,17944,0);
INSERT INTO "django_geo_db_location" VALUES(30553,NULL,'Big Laurel, KY',12316,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30554,NULL,'Big Laurel, KY 40808',12316,222,NULL,21,17945,0);
INSERT INTO "django_geo_db_location" VALUES(30555,NULL,'Bledsoe, KY',12317,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30556,NULL,'Bledsoe, KY 40810',12317,222,NULL,21,17946,0);
INSERT INTO "django_geo_db_location" VALUES(30557,NULL,'Calvin, KY',12318,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30558,NULL,'Calvin, KY 40813',12318,222,NULL,21,17947,0);
INSERT INTO "django_geo_db_location" VALUES(30559,NULL,'Cawood, KY',12319,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30560,NULL,'Cawood, KY 40815',12319,222,NULL,21,17948,0);
INSERT INTO "django_geo_db_location" VALUES(30561,NULL,'Chappell, KY',12320,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30562,NULL,'Chappell, KY 40816',12320,222,NULL,21,17949,0);
INSERT INTO "django_geo_db_location" VALUES(30563,NULL,'Coalgood, KY',12321,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30564,NULL,'Coalgood, KY 40818',12321,222,NULL,21,17950,0);
INSERT INTO "django_geo_db_location" VALUES(30565,NULL,'Coldiron, KY',12322,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30566,NULL,'Coldiron, KY 40819',12322,222,NULL,21,17951,0);
INSERT INTO "django_geo_db_location" VALUES(30567,NULL,'Cranks, KY',12323,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30568,NULL,'Cranks, KY 40820',12323,222,NULL,21,17952,0);
INSERT INTO "django_geo_db_location" VALUES(30569,NULL,'Cumberland, KY',12324,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30570,NULL,'Cumberland, KY 40823',12324,222,NULL,21,17953,0);
INSERT INTO "django_geo_db_location" VALUES(30571,NULL,'Dayhoit, KY',12325,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30572,NULL,'Dayhoit, KY 40824',12325,222,NULL,21,17954,0);
INSERT INTO "django_geo_db_location" VALUES(30573,NULL,'Eolia, KY',12326,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30574,NULL,'Eolia, KY 40826',12326,222,NULL,21,17955,0);
INSERT INTO "django_geo_db_location" VALUES(30575,NULL,'Essie, KY',12327,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30576,NULL,'Essie, KY 40827',12327,222,NULL,21,17956,0);
INSERT INTO "django_geo_db_location" VALUES(30577,NULL,'Evarts, KY',12328,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30578,NULL,'Evarts, KY 40828',12328,222,NULL,21,17957,0);
INSERT INTO "django_geo_db_location" VALUES(30579,NULL,'Grays Knob, KY',12329,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30580,NULL,'Grays Knob, KY 40829',12329,222,NULL,21,17958,0);
INSERT INTO "django_geo_db_location" VALUES(30581,NULL,'Gulston, KY',12330,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30582,NULL,'Gulston, KY 40830',12330,222,NULL,21,17959,0);
INSERT INTO "django_geo_db_location" VALUES(30583,NULL,'Harlan, KY',12331,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30584,NULL,'Harlan, KY 40831',12331,222,NULL,21,17960,0);
INSERT INTO "django_geo_db_location" VALUES(30585,NULL,'Helton, KY',12332,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30586,NULL,'Helton, KY 40840',12332,222,NULL,21,17961,0);
INSERT INTO "django_geo_db_location" VALUES(30587,NULL,'Holmes Mill, KY',12333,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30588,NULL,'Holmes Mill, KY 40843',12333,222,NULL,21,17962,0);
INSERT INTO "django_geo_db_location" VALUES(30589,NULL,'Hoskinston, KY',12334,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30590,NULL,'Hoskinston, KY 40844',12334,222,NULL,21,17963,0);
INSERT INTO "django_geo_db_location" VALUES(30591,NULL,'Hulen, KY',12335,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30592,NULL,'Hulen, KY 40845',12335,222,NULL,21,17964,0);
INSERT INTO "django_geo_db_location" VALUES(30593,NULL,'Kenvir, KY',12336,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30594,NULL,'Kenvir, KY 40847',12336,222,NULL,21,17965,0);
INSERT INTO "django_geo_db_location" VALUES(30595,NULL,'Lejunior, KY',12337,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30596,NULL,'Lejunior, KY 40849',12337,222,NULL,21,17966,0);
INSERT INTO "django_geo_db_location" VALUES(30597,NULL,'Loyall, KY',12338,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30598,NULL,'Loyall, KY 40854',12338,222,NULL,21,17967,0);
INSERT INTO "django_geo_db_location" VALUES(30599,NULL,'Lynch, KY',12339,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30600,NULL,'Lynch, KY 40855',12339,222,NULL,21,17968,0);
INSERT INTO "django_geo_db_location" VALUES(30601,NULL,'Miracle, KY',12340,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30602,NULL,'Miracle, KY 40856',12340,222,NULL,21,17969,0);
INSERT INTO "django_geo_db_location" VALUES(30603,NULL,'Mozelle, KY',12341,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30604,NULL,'Mozelle, KY 40858',12341,222,NULL,21,17970,0);
INSERT INTO "django_geo_db_location" VALUES(30605,NULL,'Partridge, KY',12342,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30606,NULL,'Partridge, KY 40862',12342,222,NULL,21,17971,0);
INSERT INTO "django_geo_db_location" VALUES(30607,NULL,'Pathfork, KY',12343,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30608,NULL,'Pathfork, KY 40863',12343,222,NULL,21,17972,0);
INSERT INTO "django_geo_db_location" VALUES(30609,NULL,'Putney, KY',12344,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30610,NULL,'Putney, KY 40865',12344,222,NULL,21,17973,0);
INSERT INTO "django_geo_db_location" VALUES(30611,NULL,'Smith, KY',12345,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30612,NULL,'Smith, KY 40867',12345,222,NULL,21,17974,0);
INSERT INTO "django_geo_db_location" VALUES(30613,NULL,'Stinnett, KY',12346,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30614,NULL,'Stinnett, KY 40868',12346,222,NULL,21,17975,0);
INSERT INTO "django_geo_db_location" VALUES(30615,NULL,'Totz, KY',12347,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30616,NULL,'Totz, KY 40870',12347,222,NULL,21,17976,0);
INSERT INTO "django_geo_db_location" VALUES(30617,NULL,'Wallins Creek, KY',12348,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30618,NULL,'Wallins Creek, KY 40873',12348,222,NULL,21,17977,0);
INSERT INTO "django_geo_db_location" VALUES(30619,NULL,'Warbranch, KY',12349,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30620,NULL,'Warbranch, KY 40874',12349,222,NULL,21,17978,0);
INSERT INTO "django_geo_db_location" VALUES(30621,NULL,'Arjay, KY',12350,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30622,NULL,'Arjay, KY 40902',12350,222,NULL,21,17979,0);
INSERT INTO "django_geo_db_location" VALUES(30623,NULL,'Artemus, KY',12351,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30624,NULL,'Artemus, KY 40903',12351,222,NULL,21,17980,0);
INSERT INTO "django_geo_db_location" VALUES(30625,NULL,'Barbourville, KY',12352,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30626,NULL,'Barbourville, KY 40906',12352,222,NULL,21,17981,0);
INSERT INTO "django_geo_db_location" VALUES(30627,NULL,'Beverly, KY',12353,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30628,NULL,'Beverly, KY 40913',12353,222,NULL,21,17982,0);
INSERT INTO "django_geo_db_location" VALUES(30629,NULL,'Big Creek, KY',12354,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30630,NULL,'Big Creek, KY 40914',12354,222,NULL,21,17983,0);
INSERT INTO "django_geo_db_location" VALUES(30631,NULL,'Bimble, KY',12355,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30632,NULL,'Bimble, KY 40915',12355,222,NULL,21,17984,0);
INSERT INTO "django_geo_db_location" VALUES(30633,NULL,'Bryants Store, KY',12356,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30634,NULL,'Bryants Store, KY 40921',12356,222,NULL,21,17985,0);
INSERT INTO "django_geo_db_location" VALUES(30635,NULL,'Cannon, KY',12357,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30636,NULL,'Cannon, KY 40923',12357,222,NULL,21,17986,0);
INSERT INTO "django_geo_db_location" VALUES(30637,NULL,'Closplint, KY',12358,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30638,NULL,'Closplint, KY 40927',12358,222,NULL,21,17987,0);
INSERT INTO "django_geo_db_location" VALUES(30639,NULL,'Dewitt, KY',12359,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30640,NULL,'Dewitt, KY 40930',12359,222,NULL,21,17988,0);
INSERT INTO "django_geo_db_location" VALUES(30641,NULL,'Eriline, KY',12360,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30642,NULL,'Eriline, KY 40931',12360,222,NULL,21,17989,0);
INSERT INTO "django_geo_db_location" VALUES(30643,NULL,'Fall Rock, KY',12361,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30644,NULL,'Fall Rock, KY 40932',12361,222,NULL,21,17990,0);
INSERT INTO "django_geo_db_location" VALUES(30645,NULL,'Flat Lick, KY',12362,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30646,NULL,'Flat Lick, KY 40935',12362,222,NULL,21,17991,0);
INSERT INTO "django_geo_db_location" VALUES(30647,NULL,'Fourmile, KY',12363,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30648,NULL,'Fourmile, KY 40939',12363,222,NULL,21,17992,0);
INSERT INTO "django_geo_db_location" VALUES(30649,NULL,'Frakes, KY',12364,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30650,NULL,'Frakes, KY 40940',12364,222,NULL,21,17993,0);
INSERT INTO "django_geo_db_location" VALUES(30651,NULL,'Garrard, KY',12365,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30652,NULL,'Garrard, KY 40941',12365,222,NULL,21,17994,0);
INSERT INTO "django_geo_db_location" VALUES(30653,NULL,'Girdler, KY',12366,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30654,NULL,'Girdler, KY 40943',12366,222,NULL,21,17995,0);
INSERT INTO "django_geo_db_location" VALUES(30655,NULL,'Goose Rock, KY',12367,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30656,NULL,'Goose Rock, KY 40944',12367,222,NULL,21,17996,0);
INSERT INTO "django_geo_db_location" VALUES(30657,NULL,'Green Road, KY',12368,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30658,NULL,'Green Road, KY 40946',12368,222,NULL,21,17997,0);
INSERT INTO "django_geo_db_location" VALUES(30659,NULL,'Heidrick, KY',12369,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30660,NULL,'Heidrick, KY 40949',12369,222,NULL,21,17998,0);
INSERT INTO "django_geo_db_location" VALUES(30661,NULL,'Hima, KY',12370,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30662,NULL,'Hima, KY 40951',12370,222,NULL,21,17999,0);
INSERT INTO "django_geo_db_location" VALUES(30663,NULL,'Hinkle, KY',12371,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30664,NULL,'Hinkle, KY 40953',12371,222,NULL,21,18000,0);
INSERT INTO "django_geo_db_location" VALUES(30665,NULL,'Ingram, KY',12372,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30666,NULL,'Ingram, KY 40955',12372,222,NULL,21,18001,0);
INSERT INTO "django_geo_db_location" VALUES(30667,NULL,'Kettle Island, KY',12373,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30668,NULL,'Kettle Island, KY 40958',12373,222,NULL,21,18002,0);
INSERT INTO "django_geo_db_location" VALUES(30669,NULL,'Manchester, KY',12374,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30670,NULL,'Manchester, KY 40962',12374,222,NULL,21,18003,0);
INSERT INTO "django_geo_db_location" VALUES(30671,NULL,'Mary Alice, KY',12375,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30672,NULL,'Mary Alice, KY 40964',12375,222,NULL,21,18004,0);
INSERT INTO "django_geo_db_location" VALUES(30673,NULL,'Middlesboro, KY',12376,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30674,NULL,'Middlesboro, KY 40965',12376,222,NULL,21,18005,0);
INSERT INTO "django_geo_db_location" VALUES(30675,NULL,'Oneida, KY',12377,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30676,NULL,'Oneida, KY 40972',12377,222,NULL,21,18006,0);
INSERT INTO "django_geo_db_location" VALUES(30677,NULL,'Pineville, KY',12378,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30678,NULL,'Pineville, KY 40977',12378,222,NULL,21,18007,0);
INSERT INTO "django_geo_db_location" VALUES(30679,NULL,'Roark, KY',12379,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30680,NULL,'Roark, KY 40979',12379,222,NULL,21,18008,0);
INSERT INTO "django_geo_db_location" VALUES(30681,NULL,'Saul, KY',12380,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30682,NULL,'Saul, KY 40981',12380,222,NULL,21,18009,0);
INSERT INTO "django_geo_db_location" VALUES(30683,NULL,'Scalf, KY',12381,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30684,NULL,'Scalf, KY 40982',12381,222,NULL,21,18010,0);
INSERT INTO "django_geo_db_location" VALUES(30685,NULL,'Sextons Creek, KY',12382,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30686,NULL,'Sextons Creek, KY 40983',12382,222,NULL,21,18011,0);
INSERT INTO "django_geo_db_location" VALUES(30687,NULL,'Stoney Fork, KY',12383,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30688,NULL,'Stoney Fork, KY 40988',12383,222,NULL,21,18012,0);
INSERT INTO "django_geo_db_location" VALUES(30689,NULL,'Trosper, KY',12384,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30690,NULL,'Trosper, KY 40995',12384,222,NULL,21,18013,0);
INSERT INTO "django_geo_db_location" VALUES(30691,NULL,'Walker, KY',12385,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30692,NULL,'Walker, KY 40997',12385,222,NULL,21,18014,0);
INSERT INTO "django_geo_db_location" VALUES(30693,NULL,'Woollum, KY',12386,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30694,NULL,'Woollum, KY 40999',12386,222,NULL,21,18015,0);
INSERT INTO "django_geo_db_location" VALUES(30695,NULL,'Fort Mitchell, KY',12387,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30696,NULL,'Fort Mitchell, KY 41000',12387,222,NULL,21,18016,0);
INSERT INTO "django_geo_db_location" VALUES(30697,NULL,'Alexandria, KY',12388,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30698,NULL,'Alexandria, KY 41001',12388,222,NULL,21,18017,0);
INSERT INTO "django_geo_db_location" VALUES(30699,NULL,'Augusta, KY',12389,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30700,NULL,'Augusta, KY 41002',12389,222,NULL,21,18018,0);
INSERT INTO "django_geo_db_location" VALUES(30701,NULL,'Berry, KY',12390,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30702,NULL,'Berry, KY 41003',12390,222,NULL,21,18019,0);
INSERT INTO "django_geo_db_location" VALUES(30703,NULL,'Brooksville, KY',12391,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30704,NULL,'Brooksville, KY 41004',12391,222,NULL,21,18020,0);
INSERT INTO "django_geo_db_location" VALUES(30705,NULL,'Burlington, KY',12392,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30706,NULL,'Burlington, KY 41005',12392,222,NULL,21,18021,0);
INSERT INTO "django_geo_db_location" VALUES(30707,NULL,'Butler, KY',12393,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30708,NULL,'Butler, KY 41006',12393,222,NULL,21,18022,0);
INSERT INTO "django_geo_db_location" VALUES(30709,NULL,'California, KY',12394,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30710,NULL,'California, KY 41007',12394,222,NULL,21,18023,0);
INSERT INTO "django_geo_db_location" VALUES(30711,NULL,'Carrollton, KY',12395,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30712,NULL,'Carrollton, KY 41008',12395,222,NULL,21,18024,0);
INSERT INTO "django_geo_db_location" VALUES(30713,NULL,'Corinth, KY',12396,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30714,NULL,'Corinth, KY 41010',12396,222,NULL,21,18025,0);
INSERT INTO "django_geo_db_location" VALUES(30715,NULL,'Covington, KY',12397,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30716,NULL,'Covington, KY 41011',12397,222,NULL,21,18026,0);
INSERT INTO "django_geo_db_location" VALUES(30717,NULL,'Covington, KY 41012',12397,222,NULL,21,18027,0);
INSERT INTO "django_geo_db_location" VALUES(30718,NULL,'Covington, KY 41014',12397,222,NULL,21,18028,0);
INSERT INTO "django_geo_db_location" VALUES(30719,NULL,'Latonia, KY',12398,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30720,NULL,'Latonia, KY 41015',12398,222,NULL,21,18029,0);
INSERT INTO "django_geo_db_location" VALUES(30721,NULL,'Covington, KY 41016',12397,222,NULL,21,18030,0);
INSERT INTO "django_geo_db_location" VALUES(30722,NULL,'Ft Mitchell, KY',12399,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30723,NULL,'Ft Mitchell, KY 41017',12399,222,NULL,21,18031,0);
INSERT INTO "django_geo_db_location" VALUES(30724,NULL,'Erlanger, KY',12400,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30725,NULL,'Erlanger, KY 41018',12400,222,NULL,21,18032,0);
INSERT INTO "django_geo_db_location" VALUES(30726,NULL,'Covington, KY 41019',12397,222,NULL,21,18033,0);
INSERT INTO "django_geo_db_location" VALUES(30727,NULL,'Florence, KY',12401,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30728,NULL,'Florence, KY 41022',12401,222,NULL,21,18034,0);
INSERT INTO "django_geo_db_location" VALUES(30729,NULL,'Crittenden, KY',12402,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30730,NULL,'Crittenden, KY 41030',12402,222,NULL,21,18035,0);
INSERT INTO "django_geo_db_location" VALUES(30731,NULL,'Cynthiana, KY',12403,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30732,NULL,'Cynthiana, KY 41031',12403,222,NULL,21,18036,0);
INSERT INTO "django_geo_db_location" VALUES(30733,NULL,'De Mossville, KY',12404,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30734,NULL,'De Mossville, KY 41033',12404,222,NULL,21,18037,0);
INSERT INTO "django_geo_db_location" VALUES(30735,NULL,'Dover, KY',12405,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30736,NULL,'Dover, KY 41034',12405,222,NULL,21,18038,0);
INSERT INTO "django_geo_db_location" VALUES(30737,NULL,'Dry Ridge, KY',12406,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30738,NULL,'Dry Ridge, KY 41035',12406,222,NULL,21,18039,0);
INSERT INTO "django_geo_db_location" VALUES(30739,NULL,'Elizaville, KY',12407,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30740,NULL,'Elizaville, KY 41037',12407,222,NULL,21,18040,0);
INSERT INTO "django_geo_db_location" VALUES(30741,NULL,'Ewing, KY',12408,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30742,NULL,'Ewing, KY 41039',12408,222,NULL,21,18041,0);
INSERT INTO "django_geo_db_location" VALUES(30743,NULL,'Falmouth, KY',12409,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30744,NULL,'Falmouth, KY 41040',12409,222,NULL,21,18042,0);
INSERT INTO "django_geo_db_location" VALUES(30745,NULL,'Flemingsburg, KY',12410,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30746,NULL,'Flemingsburg, KY 41041',12410,222,NULL,21,18043,0);
INSERT INTO "django_geo_db_location" VALUES(30747,NULL,'Florence, KY 41042',12401,222,NULL,21,18044,0);
INSERT INTO "django_geo_db_location" VALUES(30748,NULL,'Foster, KY',12411,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30749,NULL,'Foster, KY 41043',12411,222,NULL,21,18045,0);
INSERT INTO "django_geo_db_location" VALUES(30750,NULL,'Germantown, KY',12412,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30751,NULL,'Germantown, KY 41044',12412,222,NULL,21,18046,0);
INSERT INTO "django_geo_db_location" VALUES(30752,NULL,'Ghent, KY',12413,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30753,NULL,'Ghent, KY 41045',12413,222,NULL,21,18047,0);
INSERT INTO "django_geo_db_location" VALUES(30754,NULL,'Glencoe, KY',12414,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30755,NULL,'Glencoe, KY 41046',12414,222,NULL,21,18048,0);
INSERT INTO "django_geo_db_location" VALUES(30756,NULL,'Hebron, KY',12415,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30757,NULL,'Hebron, KY 41048',12415,222,NULL,21,18049,0);
INSERT INTO "django_geo_db_location" VALUES(30758,NULL,'Hillsboro, KY',12416,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30759,NULL,'Hillsboro, KY 41049',12416,222,NULL,21,18050,0);
INSERT INTO "django_geo_db_location" VALUES(30760,NULL,'Independence, KY',12417,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30761,NULL,'Independence, KY 41051',12417,222,NULL,21,18051,0);
INSERT INTO "django_geo_db_location" VALUES(30762,NULL,'Jonesville, KY',12418,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30763,NULL,'Jonesville, KY 41052',12418,222,NULL,21,18052,0);
INSERT INTO "django_geo_db_location" VALUES(30764,NULL,'Kenton, KY',12419,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30765,NULL,'Kenton, KY 41053',12419,222,NULL,21,18053,0);
INSERT INTO "django_geo_db_location" VALUES(30766,NULL,'Mason, KY',12420,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30767,NULL,'Mason, KY 41054',12420,222,NULL,21,18054,0);
INSERT INTO "django_geo_db_location" VALUES(30768,NULL,'Mayslick, KY',12421,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30769,NULL,'Mayslick, KY 41055',12421,222,NULL,21,18055,0);
INSERT INTO "django_geo_db_location" VALUES(30770,NULL,'Maysville, KY',12422,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30771,NULL,'Maysville, KY 41056',12422,222,NULL,21,18056,0);
INSERT INTO "django_geo_db_location" VALUES(30772,NULL,'Melbourne, KY',12423,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30773,NULL,'Melbourne, KY 41059',12423,222,NULL,21,18057,0);
INSERT INTO "django_geo_db_location" VALUES(30774,NULL,'Milford, KY',12424,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30775,NULL,'Milford, KY 41061',12424,222,NULL,21,18058,0);
INSERT INTO "django_geo_db_location" VALUES(30776,NULL,'Minerva, KY',12425,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30777,NULL,'Minerva, KY 41062',12425,222,NULL,21,18059,0);
INSERT INTO "django_geo_db_location" VALUES(30778,NULL,'Morning View, KY',12426,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30779,NULL,'Morning View, KY 41063',12426,222,NULL,21,18060,0);
INSERT INTO "django_geo_db_location" VALUES(30780,NULL,'Mount Olivet, KY',12427,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30781,NULL,'Mount Olivet, KY 41064',12427,222,NULL,21,18061,0);
INSERT INTO "django_geo_db_location" VALUES(30782,NULL,'Muses Mills, KY',12428,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30783,NULL,'Muses Mills, KY 41065',12428,222,NULL,21,18062,0);
INSERT INTO "django_geo_db_location" VALUES(30784,NULL,'Newport, KY',12429,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30785,NULL,'Newport, KY 41071',12429,222,NULL,21,18063,0);
INSERT INTO "django_geo_db_location" VALUES(30786,NULL,'Newport, KY 41072',12429,222,NULL,21,18064,0);
INSERT INTO "django_geo_db_location" VALUES(30787,NULL,'Bellevue, KY',12430,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30788,NULL,'Bellevue, KY 41073',12430,222,NULL,21,18065,0);
INSERT INTO "django_geo_db_location" VALUES(30789,NULL,'Dayton, KY',12431,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30790,NULL,'Dayton, KY 41074',12431,222,NULL,21,18066,0);
INSERT INTO "django_geo_db_location" VALUES(30791,NULL,'Fort Thomas, KY',12432,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30792,NULL,'Fort Thomas, KY 41075',12432,222,NULL,21,18067,0);
INSERT INTO "django_geo_db_location" VALUES(30793,NULL,'Newport, KY 41076',12429,222,NULL,21,18068,0);
INSERT INTO "django_geo_db_location" VALUES(30794,NULL,'Petersburg, KY',12433,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30795,NULL,'Petersburg, KY 41080',12433,222,NULL,21,18069,0);
INSERT INTO "django_geo_db_location" VALUES(30796,NULL,'Plummers Landing, KY',12434,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30797,NULL,'Plummers Landing, KY 41081',12434,222,NULL,21,18070,0);
INSERT INTO "django_geo_db_location" VALUES(30798,NULL,'Sanders, KY',12435,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30799,NULL,'Sanders, KY 41083',12435,222,NULL,21,18071,0);
INSERT INTO "django_geo_db_location" VALUES(30800,NULL,'Silver Grove, KY',12436,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30801,NULL,'Silver Grove, KY 41085',12436,222,NULL,21,18072,0);
INSERT INTO "django_geo_db_location" VALUES(30802,NULL,'Sparta, KY',12437,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30803,NULL,'Sparta, KY 41086',12437,222,NULL,21,18073,0);
INSERT INTO "django_geo_db_location" VALUES(30804,NULL,'Union, KY',12438,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30805,NULL,'Union, KY 41091',12438,222,NULL,21,18074,0);
INSERT INTO "django_geo_db_location" VALUES(30806,NULL,'Verona, KY',12439,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30807,NULL,'Verona, KY 41092',12439,222,NULL,21,18075,0);
INSERT INTO "django_geo_db_location" VALUES(30808,NULL,'Wallingford, KY',12440,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30809,NULL,'Wallingford, KY 41093',12440,222,NULL,21,18076,0);
INSERT INTO "django_geo_db_location" VALUES(30810,NULL,'Walton, KY',12441,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30811,NULL,'Walton, KY 41094',12441,222,NULL,21,18077,0);
INSERT INTO "django_geo_db_location" VALUES(30812,NULL,'Warsaw, KY',12442,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30813,NULL,'Warsaw, KY 41095',12442,222,NULL,21,18078,0);
INSERT INTO "django_geo_db_location" VALUES(30814,NULL,'Washington, KY',12443,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30815,NULL,'Washington, KY 41096',12443,222,NULL,21,18079,0);
INSERT INTO "django_geo_db_location" VALUES(30816,NULL,'Williamstown, KY',12444,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30817,NULL,'Williamstown, KY 41097',12444,222,NULL,21,18080,0);
INSERT INTO "django_geo_db_location" VALUES(30818,NULL,'Worthville, KY',12445,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30819,NULL,'Worthville, KY 41098',12445,222,NULL,21,18081,0);
INSERT INTO "django_geo_db_location" VALUES(30820,NULL,'Newport, KY 41099',12429,222,NULL,21,18082,0);
INSERT INTO "django_geo_db_location" VALUES(30821,NULL,'Ashland, KY',12446,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30822,NULL,'Ashland, KY 41101',12446,222,NULL,21,18083,0);
INSERT INTO "django_geo_db_location" VALUES(30823,NULL,'Ashland, KY 41102',12446,222,NULL,21,18084,0);
INSERT INTO "django_geo_db_location" VALUES(30824,NULL,'Ashland, KY 41105',12446,222,NULL,21,18085,0);
INSERT INTO "django_geo_db_location" VALUES(30825,NULL,'Ashland, KY 41114',12446,222,NULL,21,18086,0);
INSERT INTO "django_geo_db_location" VALUES(30826,NULL,'Argillite, KY',12447,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30827,NULL,'Argillite, KY 41121',12447,222,NULL,21,18087,0);
INSERT INTO "django_geo_db_location" VALUES(30828,NULL,'Blaine, KY',12448,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30829,NULL,'Blaine, KY 41124',12448,222,NULL,21,18088,0);
INSERT INTO "django_geo_db_location" VALUES(30830,NULL,'Camp Dix, KY',12449,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30831,NULL,'Camp Dix, KY 41127',12449,222,NULL,21,18089,0);
INSERT INTO "django_geo_db_location" VALUES(30832,NULL,'Carter, KY',12450,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30833,NULL,'Carter, KY 41128',12450,222,NULL,21,18090,0);
INSERT INTO "django_geo_db_location" VALUES(30834,NULL,'Catlettsburg, KY',12451,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30835,NULL,'Catlettsburg, KY 41129',12451,222,NULL,21,18091,0);
INSERT INTO "django_geo_db_location" VALUES(30836,NULL,'Denton, KY',12452,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30837,NULL,'Denton, KY 41132',12452,222,NULL,21,18092,0);
INSERT INTO "django_geo_db_location" VALUES(30838,NULL,'Emerson, KY',12453,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30839,NULL,'Emerson, KY 41135',12453,222,NULL,21,18093,0);
INSERT INTO "django_geo_db_location" VALUES(30840,NULL,'Firebrick, KY',12454,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30841,NULL,'Firebrick, KY 41137',12454,222,NULL,21,18094,0);
INSERT INTO "django_geo_db_location" VALUES(30842,NULL,'Flatwoods, KY',12455,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30843,NULL,'Flatwoods, KY 41139',12455,222,NULL,21,18095,0);
INSERT INTO "django_geo_db_location" VALUES(30844,NULL,'Garrison, KY',12456,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30845,NULL,'Garrison, KY 41141',12456,222,NULL,21,18096,0);
INSERT INTO "django_geo_db_location" VALUES(30846,NULL,'Grahn, KY',12457,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30847,NULL,'Grahn, KY 41142',12457,222,NULL,21,18097,0);
INSERT INTO "django_geo_db_location" VALUES(30848,NULL,'Grayson, KY',12458,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30849,NULL,'Grayson, KY 41143',12458,222,NULL,21,18098,0);
INSERT INTO "django_geo_db_location" VALUES(30850,NULL,'Greenup, KY',12459,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30851,NULL,'Greenup, KY 41144',12459,222,NULL,21,18099,0);
INSERT INTO "django_geo_db_location" VALUES(30852,NULL,'Hitchins, KY',12460,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30853,NULL,'Hitchins, KY 41146',12460,222,NULL,21,18100,0);
INSERT INTO "django_geo_db_location" VALUES(30854,NULL,'Isonville, KY',12461,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30855,NULL,'Isonville, KY 41149',12461,222,NULL,21,18101,0);
INSERT INTO "django_geo_db_location" VALUES(30856,NULL,'Jacobs, KY',12462,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30857,NULL,'Jacobs, KY 41150',12462,222,NULL,21,18102,0);
INSERT INTO "django_geo_db_location" VALUES(30858,NULL,'Lloyd, KY',12463,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30859,NULL,'Lloyd, KY 41156',12463,222,NULL,21,18103,0);
INSERT INTO "django_geo_db_location" VALUES(30860,NULL,'Martha, KY',12464,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30861,NULL,'Martha, KY 41159',12464,222,NULL,21,18104,0);
INSERT INTO "django_geo_db_location" VALUES(30862,NULL,'Mazie, KY',12465,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30863,NULL,'Mazie, KY 41160',12465,222,NULL,21,18105,0);
INSERT INTO "django_geo_db_location" VALUES(30864,NULL,'Grayson, KY 41163',12458,222,NULL,21,18106,0);
INSERT INTO "django_geo_db_location" VALUES(30865,NULL,'Olive Hill, KY',12466,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30866,NULL,'Olive Hill, KY 41164',12466,222,NULL,21,18107,0);
INSERT INTO "django_geo_db_location" VALUES(30867,NULL,'Quincy, KY',12467,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30868,NULL,'Quincy, KY 41166',12467,222,NULL,21,18108,0);
INSERT INTO "django_geo_db_location" VALUES(30869,NULL,'Rush, KY',12468,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30870,NULL,'Rush, KY 41168',12468,222,NULL,21,18109,0);
INSERT INTO "django_geo_db_location" VALUES(30871,NULL,'Russell, KY',12469,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30872,NULL,'Russell, KY 41169',12469,222,NULL,21,18110,0);
INSERT INTO "django_geo_db_location" VALUES(30873,NULL,'Saint Paul, KY',12470,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30874,NULL,'Saint Paul, KY 41170',12470,222,NULL,21,18111,0);
INSERT INTO "django_geo_db_location" VALUES(30875,NULL,'Sandy Hook, KY',12471,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30876,NULL,'Sandy Hook, KY 41171',12471,222,NULL,21,18112,0);
INSERT INTO "django_geo_db_location" VALUES(30877,NULL,'Soldier, KY',12472,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30878,NULL,'Soldier, KY 41173',12472,222,NULL,21,18113,0);
INSERT INTO "django_geo_db_location" VALUES(30879,NULL,'South Portsmouth, KY',12473,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30880,NULL,'South Portsmouth, KY 41174',12473,222,NULL,21,18114,0);
INSERT INTO "django_geo_db_location" VALUES(30881,NULL,'South Shore, KY',12474,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30882,NULL,'South Shore, KY 41175',12474,222,NULL,21,18115,0);
INSERT INTO "django_geo_db_location" VALUES(30883,NULL,'Vanceburg, KY',12475,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30884,NULL,'Vanceburg, KY 41179',12475,222,NULL,21,18116,0);
INSERT INTO "django_geo_db_location" VALUES(30885,NULL,'Webbville, KY',12476,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30886,NULL,'Webbville, KY 41180',12476,222,NULL,21,18117,0);
INSERT INTO "django_geo_db_location" VALUES(30887,NULL,'Willard, KY',12477,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30888,NULL,'Willard, KY 41181',12477,222,NULL,21,18118,0);
INSERT INTO "django_geo_db_location" VALUES(30889,NULL,'Worthington, KY',12478,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30890,NULL,'Worthington, KY 41183',12478,222,NULL,21,18119,0);
INSERT INTO "django_geo_db_location" VALUES(30891,NULL,'Tollesboro, KY',12479,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30892,NULL,'Tollesboro, KY 41189',12479,222,NULL,21,18120,0);
INSERT INTO "django_geo_db_location" VALUES(30893,NULL,'Adams, KY',12480,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30894,NULL,'Adams, KY 41201',12480,222,NULL,21,18121,0);
INSERT INTO "django_geo_db_location" VALUES(30895,NULL,'Beauty, KY',12481,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30896,NULL,'Beauty, KY 41203',12481,222,NULL,21,18122,0);
INSERT INTO "django_geo_db_location" VALUES(30897,NULL,'Boons Camp, KY',12482,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30898,NULL,'Boons Camp, KY 41204',12482,222,NULL,21,18123,0);
INSERT INTO "django_geo_db_location" VALUES(30899,NULL,'Debord, KY',12483,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30900,NULL,'Debord, KY 41214',12483,222,NULL,21,18124,0);
INSERT INTO "django_geo_db_location" VALUES(30901,NULL,'Denver, KY',12484,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30902,NULL,'Denver, KY 41215',12484,222,NULL,21,18125,0);
INSERT INTO "django_geo_db_location" VALUES(30903,NULL,'East Point, KY',12485,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30904,NULL,'East Point, KY 41216',12485,222,NULL,21,18126,0);
INSERT INTO "django_geo_db_location" VALUES(30905,NULL,'Flatgap, KY',12486,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30906,NULL,'Flatgap, KY 41219',12486,222,NULL,21,18127,0);
INSERT INTO "django_geo_db_location" VALUES(30907,NULL,'Hagerhill, KY',12487,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30908,NULL,'Hagerhill, KY 41222',12487,222,NULL,21,18128,0);
INSERT INTO "django_geo_db_location" VALUES(30909,NULL,'Inez, KY',12488,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30910,NULL,'Inez, KY 41224',12488,222,NULL,21,18129,0);
INSERT INTO "django_geo_db_location" VALUES(30911,NULL,'Keaton, KY',12489,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30912,NULL,'Keaton, KY 41226',12489,222,NULL,21,18130,0);
INSERT INTO "django_geo_db_location" VALUES(30913,NULL,'Leander, KY',12490,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30914,NULL,'Leander, KY 41228',12490,222,NULL,21,18131,0);
INSERT INTO "django_geo_db_location" VALUES(30915,NULL,'Louisa, KY',12491,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30916,NULL,'Louisa, KY 41230',12491,222,NULL,21,18132,0);
INSERT INTO "django_geo_db_location" VALUES(30917,NULL,'Lovely, KY',12492,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30918,NULL,'Lovely, KY 41231',12492,222,NULL,21,18133,0);
INSERT INTO "django_geo_db_location" VALUES(30919,NULL,'Lowmansville, KY',12493,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30920,NULL,'Lowmansville, KY 41232',12493,222,NULL,21,18134,0);
INSERT INTO "django_geo_db_location" VALUES(30921,NULL,'Meally, KY',12494,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30922,NULL,'Meally, KY 41234',12494,222,NULL,21,18135,0);
INSERT INTO "django_geo_db_location" VALUES(30923,NULL,'Oil Springs, KY',12495,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30924,NULL,'Oil Springs, KY 41238',12495,222,NULL,21,18136,0);
INSERT INTO "django_geo_db_location" VALUES(30925,NULL,'Paintsville, KY',12496,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30926,NULL,'Paintsville, KY 41240',12496,222,NULL,21,18137,0);
INSERT INTO "django_geo_db_location" VALUES(30927,NULL,'Pilgrim, KY',12497,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30928,NULL,'Pilgrim, KY 41250',12497,222,NULL,21,18138,0);
INSERT INTO "django_geo_db_location" VALUES(30929,NULL,'River, KY',12498,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30930,NULL,'River, KY 41254',12498,222,NULL,21,18139,0);
INSERT INTO "django_geo_db_location" VALUES(30931,NULL,'Sitka, KY',12499,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30932,NULL,'Sitka, KY 41255',12499,222,NULL,21,18140,0);
INSERT INTO "django_geo_db_location" VALUES(30933,NULL,'Staffordsville, KY',12500,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30934,NULL,'Staffordsville, KY 41256',12500,222,NULL,21,18141,0);
INSERT INTO "django_geo_db_location" VALUES(30935,NULL,'Stambaugh, KY',12501,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30936,NULL,'Stambaugh, KY 41257',12501,222,NULL,21,18142,0);
INSERT INTO "django_geo_db_location" VALUES(30937,NULL,'Thelma, KY',12502,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30938,NULL,'Thelma, KY 41260',12502,222,NULL,21,18143,0);
INSERT INTO "django_geo_db_location" VALUES(30939,NULL,'Tomahawk, KY',12503,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30940,NULL,'Tomahawk, KY 41262',12503,222,NULL,21,18144,0);
INSERT INTO "django_geo_db_location" VALUES(30941,NULL,'Tutor Key, KY',12504,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30942,NULL,'Tutor Key, KY 41263',12504,222,NULL,21,18145,0);
INSERT INTO "django_geo_db_location" VALUES(30943,NULL,'Ulysses, KY',12505,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30944,NULL,'Ulysses, KY 41264',12505,222,NULL,21,18146,0);
INSERT INTO "django_geo_db_location" VALUES(30945,NULL,'Van Lear, KY',12506,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30946,NULL,'Van Lear, KY 41265',12506,222,NULL,21,18147,0);
INSERT INTO "django_geo_db_location" VALUES(30947,NULL,'Warfield, KY',12507,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30948,NULL,'Warfield, KY 41267',12507,222,NULL,21,18148,0);
INSERT INTO "django_geo_db_location" VALUES(30949,NULL,'West Van Lear, KY',12508,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30950,NULL,'West Van Lear, KY 41268',12508,222,NULL,21,18149,0);
INSERT INTO "django_geo_db_location" VALUES(30951,NULL,'Williamsport, KY',12509,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30952,NULL,'Williamsport, KY 41271',12509,222,NULL,21,18150,0);
INSERT INTO "django_geo_db_location" VALUES(30953,NULL,'Wittensville, KY',12510,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30954,NULL,'Wittensville, KY 41274',12510,222,NULL,21,18151,0);
INSERT INTO "django_geo_db_location" VALUES(30955,NULL,'Campton, KY',12511,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30956,NULL,'Campton, KY 41301',12511,222,NULL,21,18152,0);
INSERT INTO "django_geo_db_location" VALUES(30957,NULL,'Athol, KY',12512,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30958,NULL,'Athol, KY 41307',12512,222,NULL,21,18153,0);
INSERT INTO "django_geo_db_location" VALUES(30959,NULL,'Bays, KY',12513,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30960,NULL,'Bays, KY 41310',12513,222,NULL,21,18154,0);
INSERT INTO "django_geo_db_location" VALUES(30961,NULL,'Beattyville, KY',12514,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30962,NULL,'Beattyville, KY 41311',12514,222,NULL,21,18155,0);
INSERT INTO "django_geo_db_location" VALUES(30963,NULL,'Bethany, KY',12515,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30964,NULL,'Bethany, KY 41313',12515,222,NULL,21,18156,0);
INSERT INTO "django_geo_db_location" VALUES(30965,NULL,'Booneville, KY',12516,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30966,NULL,'Booneville, KY 41314',12516,222,NULL,21,18157,0);
INSERT INTO "django_geo_db_location" VALUES(30967,NULL,'Clayhole, KY',12517,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30968,NULL,'Clayhole, KY 41317',12517,222,NULL,21,18158,0);
INSERT INTO "django_geo_db_location" VALUES(30969,NULL,'Hazel Green, KY',12518,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30970,NULL,'Hazel Green, KY 41332',12518,222,NULL,21,18159,0);
INSERT INTO "django_geo_db_location" VALUES(30971,NULL,'Heidelberg, KY',12519,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30972,NULL,'Heidelberg, KY 41333',12519,222,NULL,21,18160,0);
INSERT INTO "django_geo_db_location" VALUES(30973,NULL,'Island City, KY',12520,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30974,NULL,'Island City, KY 41338',12520,222,NULL,21,18161,0);
INSERT INTO "django_geo_db_location" VALUES(30975,NULL,'Jackson, KY',12521,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30976,NULL,'Jackson, KY 41339',12521,222,NULL,21,18162,0);
INSERT INTO "django_geo_db_location" VALUES(30977,NULL,'Lee City, KY',12522,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30978,NULL,'Lee City, KY 41342',12522,222,NULL,21,18163,0);
INSERT INTO "django_geo_db_location" VALUES(30979,NULL,'Lerose, KY',12523,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30980,NULL,'Lerose, KY 41344',12523,222,NULL,21,18164,0);
INSERT INTO "django_geo_db_location" VALUES(30981,NULL,'Lone, KY',12524,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30982,NULL,'Lone, KY 41347',12524,222,NULL,21,18165,0);
INSERT INTO "django_geo_db_location" VALUES(30983,NULL,'Lost Creek, KY',12525,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30984,NULL,'Lost Creek, KY 41348',12525,222,NULL,21,18166,0);
INSERT INTO "django_geo_db_location" VALUES(30985,NULL,'Mistletoe, KY',12526,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30986,NULL,'Mistletoe, KY 41351',12526,222,NULL,21,18167,0);
INSERT INTO "django_geo_db_location" VALUES(30987,NULL,'Mize, KY',12527,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30988,NULL,'Mize, KY 41352',12527,222,NULL,21,18168,0);
INSERT INTO "django_geo_db_location" VALUES(30989,NULL,'Pine Ridge, KY',12528,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30990,NULL,'Pine Ridge, KY 41360',12528,222,NULL,21,18169,0);
INSERT INTO "django_geo_db_location" VALUES(30991,NULL,'Primrose, KY',12529,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30992,NULL,'Primrose, KY 41362',12529,222,NULL,21,18170,0);
INSERT INTO "django_geo_db_location" VALUES(30993,NULL,'Ricetown, KY',12530,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30994,NULL,'Ricetown, KY 41364',12530,222,NULL,21,18171,0);
INSERT INTO "django_geo_db_location" VALUES(30995,NULL,'Rogers, KY',12531,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30996,NULL,'Rogers, KY 41365',12531,222,NULL,21,18172,0);
INSERT INTO "django_geo_db_location" VALUES(30997,NULL,'Rousseau, KY',12532,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(30998,NULL,'Rousseau, KY 41366',12532,222,NULL,21,18173,0);
INSERT INTO "django_geo_db_location" VALUES(30999,NULL,'Rowdy, KY',12533,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31000,NULL,'Rowdy, KY 41367',12533,222,NULL,21,18174,0);
INSERT INTO "django_geo_db_location" VALUES(31001,NULL,'Saint Helens, KY',12534,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31002,NULL,'Saint Helens, KY 41368',12534,222,NULL,21,18175,0);
INSERT INTO "django_geo_db_location" VALUES(31003,NULL,'Talbert, KY',12535,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31004,NULL,'Talbert, KY 41377',12535,222,NULL,21,18176,0);
INSERT INTO "django_geo_db_location" VALUES(31005,NULL,'Vancleve, KY',12536,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31006,NULL,'Vancleve, KY 41385',12536,222,NULL,21,18177,0);
INSERT INTO "django_geo_db_location" VALUES(31007,NULL,'Vincent, KY',12537,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31008,NULL,'Vincent, KY 41386',12537,222,NULL,21,18178,0);
INSERT INTO "django_geo_db_location" VALUES(31009,NULL,'Whick, KY',12538,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31010,NULL,'Whick, KY 41390',12538,222,NULL,21,18179,0);
INSERT INTO "django_geo_db_location" VALUES(31011,NULL,'Zoe, KY',12539,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31012,NULL,'Zoe, KY 41397',12539,222,NULL,21,18180,0);
INSERT INTO "django_geo_db_location" VALUES(31013,NULL,'Cannel City, KY',12540,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31014,NULL,'Cannel City, KY 41408',12540,222,NULL,21,18181,0);
INSERT INTO "django_geo_db_location" VALUES(31015,NULL,'Cisco, KY',12541,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31016,NULL,'Cisco, KY 41410',12541,222,NULL,21,18182,0);
INSERT INTO "django_geo_db_location" VALUES(31017,NULL,'Crockett, KY',12542,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31018,NULL,'Crockett, KY 41413',12542,222,NULL,21,18183,0);
INSERT INTO "django_geo_db_location" VALUES(31019,NULL,'Edna, KY',12543,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31020,NULL,'Edna, KY 41419',12543,222,NULL,21,18184,0);
INSERT INTO "django_geo_db_location" VALUES(31021,NULL,'Elkfork, KY',12544,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31022,NULL,'Elkfork, KY 41421',12544,222,NULL,21,18185,0);
INSERT INTO "django_geo_db_location" VALUES(31023,NULL,'Elsie, KY',12545,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31024,NULL,'Elsie, KY 41422',12545,222,NULL,21,18186,0);
INSERT INTO "django_geo_db_location" VALUES(31025,NULL,'Ezel, KY',12546,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31026,NULL,'Ezel, KY 41425',12546,222,NULL,21,18187,0);
INSERT INTO "django_geo_db_location" VALUES(31027,NULL,'Falcon, KY',12547,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31028,NULL,'Falcon, KY 41426',12547,222,NULL,21,18188,0);
INSERT INTO "django_geo_db_location" VALUES(31029,NULL,'Gapville, KY',12548,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31030,NULL,'Gapville, KY 41433',12548,222,NULL,21,18189,0);
INSERT INTO "django_geo_db_location" VALUES(31031,NULL,'Ivyton, KY',12549,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31032,NULL,'Ivyton, KY 41444',12549,222,NULL,21,18190,0);
INSERT INTO "django_geo_db_location" VALUES(31033,NULL,'Malone, KY',12550,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31034,NULL,'Malone, KY 41451',12550,222,NULL,21,18191,0);
INSERT INTO "django_geo_db_location" VALUES(31035,NULL,'Ophir, KY',12551,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31036,NULL,'Ophir, KY 41459',12551,222,NULL,21,18192,0);
INSERT INTO "django_geo_db_location" VALUES(31037,NULL,'Salyersville, KY',12552,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31038,NULL,'Salyersville, KY 41463',12552,222,NULL,21,18193,0);
INSERT INTO "django_geo_db_location" VALUES(31039,NULL,'Royalton, KY',12553,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31040,NULL,'Royalton, KY 41464',12553,222,NULL,21,18194,0);
INSERT INTO "django_geo_db_location" VALUES(31041,NULL,'Salyersville, KY 41465',12552,222,NULL,21,18195,0);
INSERT INTO "django_geo_db_location" VALUES(31042,NULL,'West Liberty, KY',12554,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31043,NULL,'West Liberty, KY 41472',12554,222,NULL,21,18196,0);
INSERT INTO "django_geo_db_location" VALUES(31044,NULL,'Wrigley, KY',12555,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31045,NULL,'Wrigley, KY 41477',12555,222,NULL,21,18197,0);
INSERT INTO "django_geo_db_location" VALUES(31046,NULL,'Pikeville, KY',12556,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31047,NULL,'Pikeville, KY 41501',12556,222,NULL,21,18198,0);
INSERT INTO "django_geo_db_location" VALUES(31048,NULL,'Pikeville, KY 41502',12556,222,NULL,21,18199,0);
INSERT INTO "django_geo_db_location" VALUES(31049,NULL,'South Williamson, KY',12557,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31050,NULL,'South Williamson, KY 41503',12557,222,NULL,21,18200,0);
INSERT INTO "django_geo_db_location" VALUES(31051,NULL,'Ashcamp, KY',12558,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31052,NULL,'Ashcamp, KY 41512',12558,222,NULL,21,18201,0);
INSERT INTO "django_geo_db_location" VALUES(31053,NULL,'Belcher, KY',12559,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31054,NULL,'Belcher, KY 41513',12559,222,NULL,21,18202,0);
INSERT INTO "django_geo_db_location" VALUES(31055,NULL,'Belfry, KY',12560,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31056,NULL,'Belfry, KY 41514',12560,222,NULL,21,18203,0);
INSERT INTO "django_geo_db_location" VALUES(31057,NULL,'Burdine, KY',12561,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31058,NULL,'Burdine, KY 41517',12561,222,NULL,21,18204,0);
INSERT INTO "django_geo_db_location" VALUES(31059,NULL,'Canada, KY',12562,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31060,NULL,'Canada, KY 41519',12562,222,NULL,21,18205,0);
INSERT INTO "django_geo_db_location" VALUES(31061,NULL,'Dorton, KY',12563,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31062,NULL,'Dorton, KY 41520',12563,222,NULL,21,18206,0);
INSERT INTO "django_geo_db_location" VALUES(31063,NULL,'Elkhorn City, KY',12564,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31064,NULL,'Elkhorn City, KY 41522',12564,222,NULL,21,18207,0);
INSERT INTO "django_geo_db_location" VALUES(31065,NULL,'Fedscreek, KY',12565,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31066,NULL,'Fedscreek, KY 41524',12565,222,NULL,21,18208,0);
INSERT INTO "django_geo_db_location" VALUES(31067,NULL,'Fords Branch, KY',12566,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31068,NULL,'Fords Branch, KY 41526',12566,222,NULL,21,18209,0);
INSERT INTO "django_geo_db_location" VALUES(31069,NULL,'Forest Hills, KY',12567,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31070,NULL,'Forest Hills, KY 41527',12567,222,NULL,21,18210,0);
INSERT INTO "django_geo_db_location" VALUES(31071,NULL,'Freeburn, KY',12568,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31072,NULL,'Freeburn, KY 41528',12568,222,NULL,21,18211,0);
INSERT INTO "django_geo_db_location" VALUES(31073,NULL,'Hardy, KY',12569,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31074,NULL,'Hardy, KY 41531',12569,222,NULL,21,18212,0);
INSERT INTO "django_geo_db_location" VALUES(31075,NULL,'Hellier, KY',12570,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31076,NULL,'Hellier, KY 41534',12570,222,NULL,21,18213,0);
INSERT INTO "django_geo_db_location" VALUES(31077,NULL,'Huddy, KY',12571,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31078,NULL,'Huddy, KY 41535',12571,222,NULL,21,18214,0);
INSERT INTO "django_geo_db_location" VALUES(31079,NULL,'Jenkins, KY',12572,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31080,NULL,'Jenkins, KY 41537',12572,222,NULL,21,18215,0);
INSERT INTO "django_geo_db_location" VALUES(31081,NULL,'Jonancy, KY',12573,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31082,NULL,'Jonancy, KY 41538',12573,222,NULL,21,18216,0);
INSERT INTO "django_geo_db_location" VALUES(31083,NULL,'Kimper, KY',12574,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31084,NULL,'Kimper, KY 41539',12574,222,NULL,21,18217,0);
INSERT INTO "django_geo_db_location" VALUES(31085,NULL,'Lick Creek, KY',12575,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31086,NULL,'Lick Creek, KY 41540',12575,222,NULL,21,18218,0);
INSERT INTO "django_geo_db_location" VALUES(31087,NULL,'Lookout, KY',12576,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31088,NULL,'Lookout, KY 41542',12576,222,NULL,21,18219,0);
INSERT INTO "django_geo_db_location" VALUES(31089,NULL,'McAndrews, KY',12577,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31090,NULL,'McAndrews, KY 41543',12577,222,NULL,21,18220,0);
INSERT INTO "django_geo_db_location" VALUES(31091,NULL,'McCarr, KY',12578,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31092,NULL,'McCarr, KY 41544',12578,222,NULL,21,18221,0);
INSERT INTO "django_geo_db_location" VALUES(31093,NULL,'McVeigh, KY',12579,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31094,NULL,'McVeigh, KY 41546',12579,222,NULL,21,18222,0);
INSERT INTO "django_geo_db_location" VALUES(31095,NULL,'Majestic, KY',12580,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31096,NULL,'Majestic, KY 41547',12580,222,NULL,21,18223,0);
INSERT INTO "django_geo_db_location" VALUES(31097,NULL,'Mouthcard, KY',12581,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31098,NULL,'Mouthcard, KY 41548',12581,222,NULL,21,18224,0);
INSERT INTO "django_geo_db_location" VALUES(31099,NULL,'Myra, KY',12582,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31100,NULL,'Myra, KY 41549',12582,222,NULL,21,18225,0);
INSERT INTO "django_geo_db_location" VALUES(31101,NULL,'Phelps, KY',12583,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31102,NULL,'Phelps, KY 41553',12583,222,NULL,21,18226,0);
INSERT INTO "django_geo_db_location" VALUES(31103,NULL,'Phyllis, KY',12584,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31104,NULL,'Phyllis, KY 41554',12584,222,NULL,21,18227,0);
INSERT INTO "django_geo_db_location" VALUES(31105,NULL,'Pinsonfork, KY',12585,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31106,NULL,'Pinsonfork, KY 41555',12585,222,NULL,21,18228,0);
INSERT INTO "django_geo_db_location" VALUES(31107,NULL,'Raccoon, KY',12586,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31108,NULL,'Raccoon, KY 41557',12586,222,NULL,21,18229,0);
INSERT INTO "django_geo_db_location" VALUES(31109,NULL,'Ransom, KY',12587,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31110,NULL,'Ransom, KY 41558',12587,222,NULL,21,18230,0);
INSERT INTO "django_geo_db_location" VALUES(31111,NULL,'Regina, KY',12588,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31112,NULL,'Regina, KY 41559',12588,222,NULL,21,18231,0);
INSERT INTO "django_geo_db_location" VALUES(31113,NULL,'Robinson Creek, KY',12589,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31114,NULL,'Robinson Creek, KY 41560',12589,222,NULL,21,18232,0);
INSERT INTO "django_geo_db_location" VALUES(31115,NULL,'Rockhouse, KY',12590,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31116,NULL,'Rockhouse, KY 41561',12590,222,NULL,21,18233,0);
INSERT INTO "django_geo_db_location" VALUES(31117,NULL,'Shelbiana, KY',12591,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31118,NULL,'Shelbiana, KY 41562',12591,222,NULL,21,18234,0);
INSERT INTO "django_geo_db_location" VALUES(31119,NULL,'Shelby Gap, KY',12592,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31120,NULL,'Shelby Gap, KY 41563',12592,222,NULL,21,18235,0);
INSERT INTO "django_geo_db_location" VALUES(31121,NULL,'Sidney, KY',12593,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31122,NULL,'Sidney, KY 41564',12593,222,NULL,21,18236,0);
INSERT INTO "django_geo_db_location" VALUES(31123,NULL,'Steele, KY',12594,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31124,NULL,'Steele, KY 41566',12594,222,NULL,21,18237,0);
INSERT INTO "django_geo_db_location" VALUES(31125,NULL,'Stone, KY',12595,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31126,NULL,'Stone, KY 41567',12595,222,NULL,21,18238,0);
INSERT INTO "django_geo_db_location" VALUES(31127,NULL,'Stopover, KY',12596,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31128,NULL,'Stopover, KY 41568',12596,222,NULL,21,18239,0);
INSERT INTO "django_geo_db_location" VALUES(31129,NULL,'Toler, KY',12597,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31130,NULL,'Toler, KY 41569',12597,222,NULL,21,18240,0);
INSERT INTO "django_geo_db_location" VALUES(31131,NULL,'Varney, KY',12598,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31132,NULL,'Varney, KY 41571',12598,222,NULL,21,18241,0);
INSERT INTO "django_geo_db_location" VALUES(31133,NULL,'Virgie, KY',12599,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31134,NULL,'Virgie, KY 41572',12599,222,NULL,21,18242,0);
INSERT INTO "django_geo_db_location" VALUES(31135,NULL,'Allen, KY',12600,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31136,NULL,'Allen, KY 41601',12600,222,NULL,21,18243,0);
INSERT INTO "django_geo_db_location" VALUES(31137,NULL,'Auxier, KY',12601,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31138,NULL,'Auxier, KY 41602',12601,222,NULL,21,18244,0);
INSERT INTO "django_geo_db_location" VALUES(31139,NULL,'Banner, KY',12602,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31140,NULL,'Banner, KY 41603',12602,222,NULL,21,18245,0);
INSERT INTO "django_geo_db_location" VALUES(31141,NULL,'Beaver, KY',12603,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31142,NULL,'Beaver, KY 41604',12603,222,NULL,21,18246,0);
INSERT INTO "django_geo_db_location" VALUES(31143,NULL,'Betsy Layne, KY',12604,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31144,NULL,'Betsy Layne, KY 41605',12604,222,NULL,21,18247,0);
INSERT INTO "django_geo_db_location" VALUES(31145,NULL,'Bevinsville, KY',12605,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31146,NULL,'Bevinsville, KY 41606',12605,222,NULL,21,18248,0);
INSERT INTO "django_geo_db_location" VALUES(31147,NULL,'Blue River, KY',12606,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31148,NULL,'Blue River, KY 41607',12606,222,NULL,21,18249,0);
INSERT INTO "django_geo_db_location" VALUES(31149,NULL,'Bypro, KY',12607,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31150,NULL,'Bypro, KY 41612',12607,222,NULL,21,18250,0);
INSERT INTO "django_geo_db_location" VALUES(31151,NULL,'Dana, KY',12608,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31152,NULL,'Dana, KY 41615',12608,222,NULL,21,18251,0);
INSERT INTO "django_geo_db_location" VALUES(31153,NULL,'David, KY',12609,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31154,NULL,'David, KY 41616',12609,222,NULL,21,18252,0);
INSERT INTO "django_geo_db_location" VALUES(31155,NULL,'Drift, KY',12610,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31156,NULL,'Drift, KY 41619',12610,222,NULL,21,18253,0);
INSERT INTO "django_geo_db_location" VALUES(31157,NULL,'Dwale, KY',12611,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31158,NULL,'Dwale, KY 41621',12611,222,NULL,21,18254,0);
INSERT INTO "django_geo_db_location" VALUES(31159,NULL,'Eastern, KY',12612,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31160,NULL,'Eastern, KY 41622',12612,222,NULL,21,18255,0);
INSERT INTO "django_geo_db_location" VALUES(31161,NULL,'Garrett, KY',12613,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31162,NULL,'Garrett, KY 41630',12613,222,NULL,21,18256,0);
INSERT INTO "django_geo_db_location" VALUES(31163,NULL,'Grethel, KY',12614,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31164,NULL,'Grethel, KY 41631',12614,222,NULL,21,18257,0);
INSERT INTO "django_geo_db_location" VALUES(31165,NULL,'Gunlock, KY',12615,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31166,NULL,'Gunlock, KY 41632',12615,222,NULL,21,18258,0);
INSERT INTO "django_geo_db_location" VALUES(31167,NULL,'Harold, KY',12616,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31168,NULL,'Harold, KY 41635',12616,222,NULL,21,18259,0);
INSERT INTO "django_geo_db_location" VALUES(31169,NULL,'Hi Hat, KY',12617,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31170,NULL,'Hi Hat, KY 41636',12617,222,NULL,21,18260,0);
INSERT INTO "django_geo_db_location" VALUES(31171,NULL,'Hueysville, KY',12618,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31172,NULL,'Hueysville, KY 41640',12618,222,NULL,21,18261,0);
INSERT INTO "django_geo_db_location" VALUES(31173,NULL,'Ivel, KY',12619,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31174,NULL,'Ivel, KY 41642',12619,222,NULL,21,18262,0);
INSERT INTO "django_geo_db_location" VALUES(31175,NULL,'Lackey, KY',12620,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31176,NULL,'Lackey, KY 41643',12620,222,NULL,21,18263,0);
INSERT INTO "django_geo_db_location" VALUES(31177,NULL,'Langley, KY',12621,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31178,NULL,'Langley, KY 41645',12621,222,NULL,21,18264,0);
INSERT INTO "django_geo_db_location" VALUES(31179,NULL,'McDowell, KY',12622,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31180,NULL,'McDowell, KY 41647',12622,222,NULL,21,18265,0);
INSERT INTO "django_geo_db_location" VALUES(31181,NULL,'Martin, KY',12623,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31182,NULL,'Martin, KY 41649',12623,222,NULL,21,18266,0);
INSERT INTO "django_geo_db_location" VALUES(31183,NULL,'Melvin, KY',12624,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31184,NULL,'Melvin, KY 41650',12624,222,NULL,21,18267,0);
INSERT INTO "django_geo_db_location" VALUES(31185,NULL,'Minnie, KY',12625,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31186,NULL,'Minnie, KY 41651',12625,222,NULL,21,18268,0);
INSERT INTO "django_geo_db_location" VALUES(31187,NULL,'Prestonsburg, KY',12626,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31188,NULL,'Prestonsburg, KY 41653',12626,222,NULL,21,18269,0);
INSERT INTO "django_geo_db_location" VALUES(31189,NULL,'Printer, KY',12627,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31190,NULL,'Printer, KY 41655',12627,222,NULL,21,18270,0);
INSERT INTO "django_geo_db_location" VALUES(31191,NULL,'Stanville, KY',12628,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31192,NULL,'Stanville, KY 41659',12628,222,NULL,21,18271,0);
INSERT INTO "django_geo_db_location" VALUES(31193,NULL,'Teaberry, KY',12629,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31194,NULL,'Teaberry, KY 41660',12629,222,NULL,21,18272,0);
INSERT INTO "django_geo_db_location" VALUES(31195,NULL,'Tram, KY',12630,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31196,NULL,'Tram, KY 41663',12630,222,NULL,21,18273,0);
INSERT INTO "django_geo_db_location" VALUES(31197,NULL,'Wayland, KY',12631,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31198,NULL,'Wayland, KY 41666',12631,222,NULL,21,18274,0);
INSERT INTO "django_geo_db_location" VALUES(31199,NULL,'Weeksbury, KY',12632,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31200,NULL,'Weeksbury, KY 41667',12632,222,NULL,21,18275,0);
INSERT INTO "django_geo_db_location" VALUES(31201,NULL,'West Prestonsburg, KY',12633,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31202,NULL,'West Prestonsburg, KY 41668',12633,222,NULL,21,18276,0);
INSERT INTO "django_geo_db_location" VALUES(31203,NULL,'Wheelwright, KY',12634,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31204,NULL,'Wheelwright, KY 41669',12634,222,NULL,21,18277,0);
INSERT INTO "django_geo_db_location" VALUES(31205,NULL,'Hazard, KY',12635,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31206,NULL,'Hazard, KY 41701',12635,222,NULL,21,18278,0);
INSERT INTO "django_geo_db_location" VALUES(31207,NULL,'Hazard, KY 41702',12635,222,NULL,21,18279,0);
INSERT INTO "django_geo_db_location" VALUES(31208,NULL,'Fort Thomas, KY 41705',12432,222,NULL,21,18280,0);
INSERT INTO "django_geo_db_location" VALUES(31209,NULL,'Ary, KY',12636,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31210,NULL,'Ary, KY 41712',12636,222,NULL,21,18281,0);
INSERT INTO "django_geo_db_location" VALUES(31211,NULL,'Avawam, KY',12637,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31212,NULL,'Avawam, KY 41713',12637,222,NULL,21,18282,0);
INSERT INTO "django_geo_db_location" VALUES(31213,NULL,'Bear Branch, KY',12638,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31214,NULL,'Bear Branch, KY 41714',12638,222,NULL,21,18283,0);
INSERT INTO "django_geo_db_location" VALUES(31215,NULL,'Bonnyman, KY',12639,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31216,NULL,'Bonnyman, KY 41719',12639,222,NULL,21,18284,0);
INSERT INTO "django_geo_db_location" VALUES(31217,NULL,'Buckhorn, KY',12640,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31218,NULL,'Buckhorn, KY 41721',12640,222,NULL,21,18285,0);
INSERT INTO "django_geo_db_location" VALUES(31219,NULL,'Bulan, KY',12641,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31220,NULL,'Bulan, KY 41722',12641,222,NULL,21,18286,0);
INSERT INTO "django_geo_db_location" VALUES(31221,NULL,'Busy, KY',12642,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31222,NULL,'Busy, KY 41723',12642,222,NULL,21,18287,0);
INSERT INTO "django_geo_db_location" VALUES(31223,NULL,'Carrie, KY',12643,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31224,NULL,'Carrie, KY 41725',12643,222,NULL,21,18288,0);
INSERT INTO "django_geo_db_location" VALUES(31225,NULL,'Chavies, KY',12644,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31226,NULL,'Chavies, KY 41727',12644,222,NULL,21,18289,0);
INSERT INTO "django_geo_db_location" VALUES(31227,NULL,'Combs, KY',12645,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31228,NULL,'Combs, KY 41729',12645,222,NULL,21,18290,0);
INSERT INTO "django_geo_db_location" VALUES(31229,NULL,'Confluence, KY',12646,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31230,NULL,'Confluence, KY 41730',12646,222,NULL,21,18291,0);
INSERT INTO "django_geo_db_location" VALUES(31231,NULL,'Cornettsville, KY',12647,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31232,NULL,'Cornettsville, KY 41731',12647,222,NULL,21,18292,0);
INSERT INTO "django_geo_db_location" VALUES(31233,NULL,'Delphia, KY',12648,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31234,NULL,'Delphia, KY 41735',12648,222,NULL,21,18293,0);
INSERT INTO "django_geo_db_location" VALUES(31235,NULL,'Dice, KY',12649,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31236,NULL,'Dice, KY 41736',12649,222,NULL,21,18294,0);
INSERT INTO "django_geo_db_location" VALUES(31237,NULL,'Dwarf, KY',12650,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31238,NULL,'Dwarf, KY 41739',12650,222,NULL,21,18295,0);
INSERT INTO "django_geo_db_location" VALUES(31239,NULL,'Emmalena, KY',12651,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31240,NULL,'Emmalena, KY 41740',12651,222,NULL,21,18296,0);
INSERT INTO "django_geo_db_location" VALUES(31241,NULL,'Fisty, KY',12652,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31242,NULL,'Fisty, KY 41743',12652,222,NULL,21,18297,0);
INSERT INTO "django_geo_db_location" VALUES(31243,NULL,'Gays Creek, KY',12653,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31244,NULL,'Gays Creek, KY 41745',12653,222,NULL,21,18298,0);
INSERT INTO "django_geo_db_location" VALUES(31245,NULL,'Happy, KY',12654,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31246,NULL,'Happy, KY 41746',12654,222,NULL,21,18299,0);
INSERT INTO "django_geo_db_location" VALUES(31247,NULL,'Hardburly, KY',12655,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31248,NULL,'Hardburly, KY 41747',12655,222,NULL,21,18300,0);
INSERT INTO "django_geo_db_location" VALUES(31249,NULL,'Hyden, KY',12656,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31250,NULL,'Hyden, KY 41749',12656,222,NULL,21,18301,0);
INSERT INTO "django_geo_db_location" VALUES(31251,NULL,'Jeff, KY',12657,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31252,NULL,'Jeff, KY 41751',12657,222,NULL,21,18302,0);
INSERT INTO "django_geo_db_location" VALUES(31253,NULL,'Krypton, KY',12658,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31254,NULL,'Krypton, KY 41754',12658,222,NULL,21,18303,0);
INSERT INTO "django_geo_db_location" VALUES(31255,NULL,'Sassafras, KY',12659,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31256,NULL,'Sassafras, KY 41759',12659,222,NULL,21,18304,0);
INSERT INTO "django_geo_db_location" VALUES(31257,NULL,'Scuddy, KY',12660,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31258,NULL,'Scuddy, KY 41760',12660,222,NULL,21,18305,0);
INSERT INTO "django_geo_db_location" VALUES(31259,NULL,'Sizerock, KY',12661,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31260,NULL,'Sizerock, KY 41762',12661,222,NULL,21,18306,0);
INSERT INTO "django_geo_db_location" VALUES(31261,NULL,'Slemp, KY',12662,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31262,NULL,'Slemp, KY 41763',12662,222,NULL,21,18307,0);
INSERT INTO "django_geo_db_location" VALUES(31263,NULL,'Smilax, KY',12663,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31264,NULL,'Smilax, KY 41764',12663,222,NULL,21,18308,0);
INSERT INTO "django_geo_db_location" VALUES(31265,NULL,'Thousandsticks, KY',12664,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31266,NULL,'Thousandsticks, KY 41766',12664,222,NULL,21,18309,0);
INSERT INTO "django_geo_db_location" VALUES(31267,NULL,'Vest, KY',12665,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31268,NULL,'Vest, KY 41772',12665,222,NULL,21,18310,0);
INSERT INTO "django_geo_db_location" VALUES(31269,NULL,'Vicco, KY',12666,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31270,NULL,'Vicco, KY 41773',12666,222,NULL,21,18311,0);
INSERT INTO "django_geo_db_location" VALUES(31271,NULL,'Viper, KY',12667,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31272,NULL,'Viper, KY 41774',12667,222,NULL,21,18312,0);
INSERT INTO "django_geo_db_location" VALUES(31273,NULL,'Wendover, KY',12668,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31274,NULL,'Wendover, KY 41775',12668,222,NULL,21,18313,0);
INSERT INTO "django_geo_db_location" VALUES(31275,NULL,'Wooton, KY',12669,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31276,NULL,'Wooton, KY 41776',12669,222,NULL,21,18314,0);
INSERT INTO "django_geo_db_location" VALUES(31277,NULL,'Yeaddiss, KY',12670,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31278,NULL,'Yeaddiss, KY 41777',12670,222,NULL,21,18315,0);
INSERT INTO "django_geo_db_location" VALUES(31279,NULL,'Yerkes, KY',12671,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31280,NULL,'Yerkes, KY 41778',12671,222,NULL,21,18316,0);
INSERT INTO "django_geo_db_location" VALUES(31281,NULL,'Blackey, KY',12672,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31282,NULL,'Blackey, KY 41804',12672,222,NULL,21,18317,0);
INSERT INTO "django_geo_db_location" VALUES(31283,NULL,'Cromona, KY',12673,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31284,NULL,'Cromona, KY 41810',12673,222,NULL,21,18318,0);
INSERT INTO "django_geo_db_location" VALUES(31285,NULL,'Deane, KY',12674,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31286,NULL,'Deane, KY 41812',12674,222,NULL,21,18319,0);
INSERT INTO "django_geo_db_location" VALUES(31287,NULL,'Ermine, KY',12675,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31288,NULL,'Ermine, KY 41815',12675,222,NULL,21,18320,0);
INSERT INTO "django_geo_db_location" VALUES(31289,NULL,'Garner, KY',12676,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31290,NULL,'Garner, KY 41817',12676,222,NULL,21,18321,0);
INSERT INTO "django_geo_db_location" VALUES(31291,NULL,'Gordon, KY',12677,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31292,NULL,'Gordon, KY 41819',12677,222,NULL,21,18322,0);
INSERT INTO "django_geo_db_location" VALUES(31293,NULL,'Hallie, KY',12678,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31294,NULL,'Hallie, KY 41821',12678,222,NULL,21,18323,0);
INSERT INTO "django_geo_db_location" VALUES(31295,NULL,'Hindman, KY',12679,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31296,NULL,'Hindman, KY 41822',12679,222,NULL,21,18324,0);
INSERT INTO "django_geo_db_location" VALUES(31297,NULL,'Isom, KY',12680,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31298,NULL,'Isom, KY 41824',12680,222,NULL,21,18325,0);
INSERT INTO "django_geo_db_location" VALUES(31299,NULL,'Jackhorn, KY',12681,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31300,NULL,'Jackhorn, KY 41825',12681,222,NULL,21,18326,0);
INSERT INTO "django_geo_db_location" VALUES(31301,NULL,'Jeremiah, KY',12682,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31302,NULL,'Jeremiah, KY 41826',12682,222,NULL,21,18327,0);
INSERT INTO "django_geo_db_location" VALUES(31303,NULL,'Kite, KY',12683,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31304,NULL,'Kite, KY 41828',12683,222,NULL,21,18328,0);
INSERT INTO "django_geo_db_location" VALUES(31305,NULL,'Leburn, KY',12684,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31306,NULL,'Leburn, KY 41831',12684,222,NULL,21,18329,0);
INSERT INTO "django_geo_db_location" VALUES(31307,NULL,'Letcher, KY',12685,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31308,NULL,'Letcher, KY 41832',12685,222,NULL,21,18330,0);
INSERT INTO "django_geo_db_location" VALUES(31309,NULL,'Linefork, KY',12686,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31310,NULL,'Linefork, KY 41833',12686,222,NULL,21,18331,0);
INSERT INTO "django_geo_db_location" VALUES(31311,NULL,'Littcarr, KY',12687,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31312,NULL,'Littcarr, KY 41834',12687,222,NULL,21,18332,0);
INSERT INTO "django_geo_db_location" VALUES(31313,NULL,'McRoberts, KY',12688,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31314,NULL,'McRoberts, KY 41835',12688,222,NULL,21,18333,0);
INSERT INTO "django_geo_db_location" VALUES(31315,NULL,'Mallie, KY',12689,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31316,NULL,'Mallie, KY 41836',12689,222,NULL,21,18334,0);
INSERT INTO "django_geo_db_location" VALUES(31317,NULL,'Mayking, KY',12690,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31318,NULL,'Mayking, KY 41837',12690,222,NULL,21,18335,0);
INSERT INTO "django_geo_db_location" VALUES(31319,NULL,'Millstone, KY',12691,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31320,NULL,'Millstone, KY 41838',12691,222,NULL,21,18336,0);
INSERT INTO "django_geo_db_location" VALUES(31321,NULL,'Mousie, KY',12692,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31322,NULL,'Mousie, KY 41839',12692,222,NULL,21,18337,0);
INSERT INTO "django_geo_db_location" VALUES(31323,NULL,'Neon, KY',12693,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31324,NULL,'Neon, KY 41840',12693,222,NULL,21,18338,0);
INSERT INTO "django_geo_db_location" VALUES(31325,NULL,'Pine Top, KY',12694,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31326,NULL,'Pine Top, KY 41843',12694,222,NULL,21,18339,0);
INSERT INTO "django_geo_db_location" VALUES(31327,NULL,'Pippa Passes, KY',12695,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31328,NULL,'Pippa Passes, KY 41844',12695,222,NULL,21,18340,0);
INSERT INTO "django_geo_db_location" VALUES(31329,NULL,'Premium, KY',12696,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31330,NULL,'Premium, KY 41845',12696,222,NULL,21,18341,0);
INSERT INTO "django_geo_db_location" VALUES(31331,NULL,'Redfox, KY',12697,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31332,NULL,'Redfox, KY 41847',12697,222,NULL,21,18342,0);
INSERT INTO "django_geo_db_location" VALUES(31333,NULL,'Roxana, KY',12698,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31334,NULL,'Roxana, KY 41848',12698,222,NULL,21,18343,0);
INSERT INTO "django_geo_db_location" VALUES(31335,NULL,'Seco, KY',12699,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31336,NULL,'Seco, KY 41849',12699,222,NULL,21,18344,0);
INSERT INTO "django_geo_db_location" VALUES(31337,NULL,'Thornton, KY',12700,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31338,NULL,'Thornton, KY 41855',12700,222,NULL,21,18345,0);
INSERT INTO "django_geo_db_location" VALUES(31339,NULL,'Whitesburg, KY',12701,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31340,NULL,'Whitesburg, KY 41858',12701,222,NULL,21,18346,0);
INSERT INTO "django_geo_db_location" VALUES(31341,NULL,'Dema, KY',12702,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31342,NULL,'Dema, KY 41859',12702,222,NULL,21,18347,0);
INSERT INTO "django_geo_db_location" VALUES(31343,NULL,'Raven, KY',12703,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31344,NULL,'Raven, KY 41861',12703,222,NULL,21,18348,0);
INSERT INTO "django_geo_db_location" VALUES(31345,NULL,'Topmost, KY',12704,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31346,NULL,'Topmost, KY 41862',12704,222,NULL,21,18349,0);
INSERT INTO "django_geo_db_location" VALUES(31347,NULL,'Paducah, KY',12705,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31348,NULL,'Paducah, KY 42001',12705,222,NULL,21,18350,0);
INSERT INTO "django_geo_db_location" VALUES(31349,NULL,'Paducah, KY 42002',12705,222,NULL,21,18351,0);
INSERT INTO "django_geo_db_location" VALUES(31350,NULL,'Paducah, KY 42003',12705,222,NULL,21,18352,0);
INSERT INTO "django_geo_db_location" VALUES(31351,NULL,'Fredonia, KY',12706,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31352,NULL,'Fredonia, KY 42011',12706,222,NULL,21,18353,0);
INSERT INTO "django_geo_db_location" VALUES(31353,NULL,'Almo, KY',12707,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31354,NULL,'Almo, KY 42020',12707,222,NULL,21,18354,0);
INSERT INTO "django_geo_db_location" VALUES(31355,NULL,'Arlington, KY',12708,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31356,NULL,'Arlington, KY 42021',12708,222,NULL,21,18355,0);
INSERT INTO "django_geo_db_location" VALUES(31357,NULL,'Bandana, KY',12709,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31358,NULL,'Bandana, KY 42022',12709,222,NULL,21,18356,0);
INSERT INTO "django_geo_db_location" VALUES(31359,NULL,'Bardwell, KY',12710,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31360,NULL,'Bardwell, KY 42023',12710,222,NULL,21,18357,0);
INSERT INTO "django_geo_db_location" VALUES(31361,NULL,'Barlow, KY',12711,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31362,NULL,'Barlow, KY 42024',12711,222,NULL,21,18358,0);
INSERT INTO "django_geo_db_location" VALUES(31363,NULL,'Benton, KY',12712,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31364,NULL,'Benton, KY 42025',12712,222,NULL,21,18359,0);
INSERT INTO "django_geo_db_location" VALUES(31365,NULL,'Boaz, KY',12713,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31366,NULL,'Boaz, KY 42027',12713,222,NULL,21,18360,0);
INSERT INTO "django_geo_db_location" VALUES(31367,NULL,'Burna, KY',12714,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31368,NULL,'Burna, KY 42028',12714,222,NULL,21,18361,0);
INSERT INTO "django_geo_db_location" VALUES(31369,NULL,'Calvert City, KY',12715,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31370,NULL,'Calvert City, KY 42029',12715,222,NULL,21,18362,0);
INSERT INTO "django_geo_db_location" VALUES(31371,NULL,'Clinton, KY',12716,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31372,NULL,'Clinton, KY 42031',12716,222,NULL,21,18363,0);
INSERT INTO "django_geo_db_location" VALUES(31373,NULL,'Columbus, KY',12717,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31374,NULL,'Columbus, KY 42032',12717,222,NULL,21,18364,0);
INSERT INTO "django_geo_db_location" VALUES(31375,NULL,'Crayne, KY',12718,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31376,NULL,'Crayne, KY 42033',12718,222,NULL,21,18365,0);
INSERT INTO "django_geo_db_location" VALUES(31377,NULL,'Cunningham, KY',12719,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31378,NULL,'Cunningham, KY 42035',12719,222,NULL,21,18366,0);
INSERT INTO "django_geo_db_location" VALUES(31379,NULL,'Dexter, KY',12720,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31380,NULL,'Dexter, KY 42036',12720,222,NULL,21,18367,0);
INSERT INTO "django_geo_db_location" VALUES(31381,NULL,'Dycusburg, KY',12721,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31382,NULL,'Dycusburg, KY 42037',12721,222,NULL,21,18368,0);
INSERT INTO "django_geo_db_location" VALUES(31383,NULL,'Eddyville, KY',12722,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31384,NULL,'Eddyville, KY 42038',12722,222,NULL,21,18369,0);
INSERT INTO "django_geo_db_location" VALUES(31385,NULL,'Fancy Farm, KY',12723,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31386,NULL,'Fancy Farm, KY 42039',12723,222,NULL,21,18370,0);
INSERT INTO "django_geo_db_location" VALUES(31387,NULL,'Farmington, KY',12724,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31388,NULL,'Farmington, KY 42040',12724,222,NULL,21,18371,0);
INSERT INTO "django_geo_db_location" VALUES(31389,NULL,'Fulton, KY',12725,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31390,NULL,'Fulton, KY 42041',12725,222,NULL,21,18372,0);
INSERT INTO "django_geo_db_location" VALUES(31391,NULL,'Gilbertsville, KY',12726,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31392,NULL,'Gilbertsville, KY 42044',12726,222,NULL,21,18373,0);
INSERT INTO "django_geo_db_location" VALUES(31393,NULL,'Grand Rivers, KY',12727,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31394,NULL,'Grand Rivers, KY 42045',12727,222,NULL,21,18374,0);
INSERT INTO "django_geo_db_location" VALUES(31395,NULL,'Hamlin, KY',12728,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31396,NULL,'Hamlin, KY 42046',12728,222,NULL,21,18375,0);
INSERT INTO "django_geo_db_location" VALUES(31397,NULL,'Hampton, KY',12729,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31398,NULL,'Hampton, KY 42047',12729,222,NULL,21,18376,0);
INSERT INTO "django_geo_db_location" VALUES(31399,NULL,'Hardin, KY',12730,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31400,NULL,'Hardin, KY 42048',12730,222,NULL,21,18377,0);
INSERT INTO "django_geo_db_location" VALUES(31401,NULL,'Hazel, KY',12731,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31402,NULL,'Hazel, KY 42049',12731,222,NULL,21,18378,0);
INSERT INTO "django_geo_db_location" VALUES(31403,NULL,'Hickman, KY',12732,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31404,NULL,'Hickman, KY 42050',12732,222,NULL,21,18379,0);
INSERT INTO "django_geo_db_location" VALUES(31405,NULL,'Hickory, KY',12733,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31406,NULL,'Hickory, KY 42051',12733,222,NULL,21,18380,0);
INSERT INTO "django_geo_db_location" VALUES(31407,NULL,'Kevil, KY',12734,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31408,NULL,'Kevil, KY 42053',12734,222,NULL,21,18381,0);
INSERT INTO "django_geo_db_location" VALUES(31409,NULL,'Kirksey, KY',12735,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31410,NULL,'Kirksey, KY 42054',12735,222,NULL,21,18382,0);
INSERT INTO "django_geo_db_location" VALUES(31411,NULL,'Kuttawa, KY',12736,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31412,NULL,'Kuttawa, KY 42055',12736,222,NULL,21,18383,0);
INSERT INTO "django_geo_db_location" VALUES(31413,NULL,'La Center, KY',12737,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31414,NULL,'La Center, KY 42056',12737,222,NULL,21,18384,0);
INSERT INTO "django_geo_db_location" VALUES(31415,NULL,'Ledbetter, KY',12738,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31416,NULL,'Ledbetter, KY 42058',12738,222,NULL,21,18385,0);
INSERT INTO "django_geo_db_location" VALUES(31417,NULL,'Lovelaceville, KY',12739,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31418,NULL,'Lovelaceville, KY 42060',12739,222,NULL,21,18386,0);
INSERT INTO "django_geo_db_location" VALUES(31419,NULL,'Lowes, KY',12740,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31420,NULL,'Lowes, KY 42061',12740,222,NULL,21,18387,0);
INSERT INTO "django_geo_db_location" VALUES(31421,NULL,'Lynnville, KY',12741,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31422,NULL,'Lynnville, KY 42063',12741,222,NULL,21,18388,0);
INSERT INTO "django_geo_db_location" VALUES(31423,NULL,'Marion, KY',12742,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31424,NULL,'Marion, KY 42064',12742,222,NULL,21,18389,0);
INSERT INTO "django_geo_db_location" VALUES(31425,NULL,'Mayfield, KY',12743,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31426,NULL,'Mayfield, KY 42066',12743,222,NULL,21,18390,0);
INSERT INTO "django_geo_db_location" VALUES(31427,NULL,'Melber, KY',12744,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31428,NULL,'Melber, KY 42069',12744,222,NULL,21,18391,0);
INSERT INTO "django_geo_db_location" VALUES(31429,NULL,'Milburn, KY',12745,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31430,NULL,'Milburn, KY 42070',12745,222,NULL,21,18392,0);
INSERT INTO "django_geo_db_location" VALUES(31431,NULL,'Murray, KY',12746,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31432,NULL,'Murray, KY 42071',12746,222,NULL,21,18393,0);
INSERT INTO "django_geo_db_location" VALUES(31433,NULL,'New Concord, KY',12747,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31434,NULL,'New Concord, KY 42076',12747,222,NULL,21,18394,0);
INSERT INTO "django_geo_db_location" VALUES(31435,NULL,'Salem, KY',12748,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31436,NULL,'Salem, KY 42078',12748,222,NULL,21,18395,0);
INSERT INTO "django_geo_db_location" VALUES(31437,NULL,'Sedalia, KY',12749,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31438,NULL,'Sedalia, KY 42079',12749,222,NULL,21,18396,0);
INSERT INTO "django_geo_db_location" VALUES(31439,NULL,'Smithland, KY',12750,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31440,NULL,'Smithland, KY 42081',12750,222,NULL,21,18397,0);
INSERT INTO "django_geo_db_location" VALUES(31441,NULL,'Symsonia, KY',12751,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31442,NULL,'Symsonia, KY 42082',12751,222,NULL,21,18398,0);
INSERT INTO "django_geo_db_location" VALUES(31443,NULL,'Tiline, KY',12752,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31444,NULL,'Tiline, KY 42083',12752,222,NULL,21,18399,0);
INSERT INTO "django_geo_db_location" VALUES(31445,NULL,'Tolu, KY',12753,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31446,NULL,'Tolu, KY 42084',12753,222,NULL,21,18400,0);
INSERT INTO "django_geo_db_location" VALUES(31447,NULL,'Water Valley, KY',12754,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31448,NULL,'Water Valley, KY 42085',12754,222,NULL,21,18401,0);
INSERT INTO "django_geo_db_location" VALUES(31449,NULL,'West Paducah, KY',12755,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31450,NULL,'West Paducah, KY 42086',12755,222,NULL,21,18402,0);
INSERT INTO "django_geo_db_location" VALUES(31451,NULL,'Wickliffe, KY',12756,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31452,NULL,'Wickliffe, KY 42087',12756,222,NULL,21,18403,0);
INSERT INTO "django_geo_db_location" VALUES(31453,NULL,'Wingo, KY',12757,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31454,NULL,'Wingo, KY 42088',12757,222,NULL,21,18404,0);
INSERT INTO "django_geo_db_location" VALUES(31455,NULL,'Bowling Green, KY',12758,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31456,NULL,'Bowling Green, KY 42101',12758,222,NULL,21,18405,0);
INSERT INTO "django_geo_db_location" VALUES(31457,NULL,'Bowling Green, KY 42102',12758,222,NULL,21,18406,0);
INSERT INTO "django_geo_db_location" VALUES(31458,NULL,'Bowling Green, KY 42103',12758,222,NULL,21,18407,0);
INSERT INTO "django_geo_db_location" VALUES(31459,NULL,'Bowling Green, KY 42104',12758,222,NULL,21,18408,0);
INSERT INTO "django_geo_db_location" VALUES(31460,NULL,'Bowling Green, KY 42109',12758,222,NULL,21,18409,0);
INSERT INTO "django_geo_db_location" VALUES(31461,NULL,'Adolphus, KY',12759,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31462,NULL,'Adolphus, KY 42120',12759,222,NULL,21,18410,0);
INSERT INTO "django_geo_db_location" VALUES(31463,NULL,'Alvaton, KY',12760,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31464,NULL,'Alvaton, KY 42122',12760,222,NULL,21,18411,0);
INSERT INTO "django_geo_db_location" VALUES(31465,NULL,'Austin, KY',12761,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31466,NULL,'Austin, KY 42123',12761,222,NULL,21,18412,0);
INSERT INTO "django_geo_db_location" VALUES(31467,NULL,'Beaumont, KY',12762,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31468,NULL,'Beaumont, KY 42124',12762,222,NULL,21,18413,0);
INSERT INTO "django_geo_db_location" VALUES(31469,NULL,'Cave City, KY',12763,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31470,NULL,'Cave City, KY 42127',12763,222,NULL,21,18414,0);
INSERT INTO "django_geo_db_location" VALUES(31471,NULL,'Drake, KY',12764,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31472,NULL,'Drake, KY 42128',12764,222,NULL,21,18415,0);
INSERT INTO "django_geo_db_location" VALUES(31473,NULL,'Edmonton, KY',12765,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31474,NULL,'Edmonton, KY 42129',12765,222,NULL,21,18416,0);
INSERT INTO "django_geo_db_location" VALUES(31475,NULL,'Eighty Eight, KY',12766,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31476,NULL,'Eighty Eight, KY 42130',12766,222,NULL,21,18417,0);
INSERT INTO "django_geo_db_location" VALUES(31477,NULL,'Etoile, KY',12767,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31478,NULL,'Etoile, KY 42131',12767,222,NULL,21,18418,0);
INSERT INTO "django_geo_db_location" VALUES(31479,NULL,'Fountain Run, KY',12768,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31480,NULL,'Fountain Run, KY 42133',12768,222,NULL,21,18419,0);
INSERT INTO "django_geo_db_location" VALUES(31481,NULL,'Franklin, KY',12769,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31482,NULL,'Franklin, KY 42134',12769,222,NULL,21,18420,0);
INSERT INTO "django_geo_db_location" VALUES(31483,NULL,'Franklin, KY 42135',12769,222,NULL,21,18421,0);
INSERT INTO "django_geo_db_location" VALUES(31484,NULL,'Gamaliel, KY',12770,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31485,NULL,'Gamaliel, KY 42140',12770,222,NULL,21,18422,0);
INSERT INTO "django_geo_db_location" VALUES(31486,NULL,'Glasgow, KY',12771,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31487,NULL,'Glasgow, KY 42141',12771,222,NULL,21,18423,0);
INSERT INTO "django_geo_db_location" VALUES(31488,NULL,'Glasgow, KY 42142',12771,222,NULL,21,18424,0);
INSERT INTO "django_geo_db_location" VALUES(31489,NULL,'Halfway, KY',12772,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31490,NULL,'Halfway, KY 42150',12772,222,NULL,21,18425,0);
INSERT INTO "django_geo_db_location" VALUES(31491,NULL,'Hestand, KY',12773,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31492,NULL,'Hestand, KY 42151',12773,222,NULL,21,18426,0);
INSERT INTO "django_geo_db_location" VALUES(31493,NULL,'Hiseville, KY',12774,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31494,NULL,'Hiseville, KY 42152',12774,222,NULL,21,18427,0);
INSERT INTO "django_geo_db_location" VALUES(31495,NULL,'Holland, KY',12775,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31496,NULL,'Holland, KY 42153',12775,222,NULL,21,18428,0);
INSERT INTO "django_geo_db_location" VALUES(31497,NULL,'Knob Lick, KY',12776,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31498,NULL,'Knob Lick, KY 42154',12776,222,NULL,21,18429,0);
INSERT INTO "django_geo_db_location" VALUES(31499,NULL,'Lucas, KY',12777,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31500,NULL,'Lucas, KY 42156',12777,222,NULL,21,18430,0);
INSERT INTO "django_geo_db_location" VALUES(31501,NULL,'Mount Hermon, KY',12778,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31502,NULL,'Mount Hermon, KY 42157',12778,222,NULL,21,18431,0);
INSERT INTO "django_geo_db_location" VALUES(31503,NULL,'Oakland, KY',12779,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31504,NULL,'Oakland, KY 42159',12779,222,NULL,21,18432,0);
INSERT INTO "django_geo_db_location" VALUES(31505,NULL,'Park City, KY',12780,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31506,NULL,'Park City, KY 42160',12780,222,NULL,21,18433,0);
INSERT INTO "django_geo_db_location" VALUES(31507,NULL,'Rocky Hill, KY',12781,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31508,NULL,'Rocky Hill, KY 42163',12781,222,NULL,21,18434,0);
INSERT INTO "django_geo_db_location" VALUES(31509,NULL,'Scottsville, KY',12782,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31510,NULL,'Scottsville, KY 42164',12782,222,NULL,21,18435,0);
INSERT INTO "django_geo_db_location" VALUES(31511,NULL,'Summer Shade, KY',12783,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31512,NULL,'Summer Shade, KY 42166',12783,222,NULL,21,18436,0);
INSERT INTO "django_geo_db_location" VALUES(31513,NULL,'Tompkinsville, KY',12784,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31514,NULL,'Tompkinsville, KY 42167',12784,222,NULL,21,18437,0);
INSERT INTO "django_geo_db_location" VALUES(31515,NULL,'Woodburn, KY',12785,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31516,NULL,'Woodburn, KY 42170',12785,222,NULL,21,18438,0);
INSERT INTO "django_geo_db_location" VALUES(31517,NULL,'Smiths Grove, KY',12786,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31518,NULL,'Smiths Grove, KY 42171',12786,222,NULL,21,18439,0);
INSERT INTO "django_geo_db_location" VALUES(31519,NULL,'Aberdeen, KY',12787,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31520,NULL,'Aberdeen, KY 42201',12787,222,NULL,21,18440,0);
INSERT INTO "django_geo_db_location" VALUES(31521,NULL,'Adairville, KY',12788,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31522,NULL,'Adairville, KY 42202',12788,222,NULL,21,18441,0);
INSERT INTO "django_geo_db_location" VALUES(31523,NULL,'Allegre, KY',12789,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31524,NULL,'Allegre, KY 42203',12789,222,NULL,21,18442,0);
INSERT INTO "django_geo_db_location" VALUES(31525,NULL,'Allensville, KY',12790,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31526,NULL,'Allensville, KY 42204',12790,222,NULL,21,18443,0);
INSERT INTO "django_geo_db_location" VALUES(31527,NULL,'Auburn, KY',12791,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31528,NULL,'Auburn, KY 42206',12791,222,NULL,21,18444,0);
INSERT INTO "django_geo_db_location" VALUES(31529,NULL,'Bee Spring, KY',12792,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31530,NULL,'Bee Spring, KY 42207',12792,222,NULL,21,18445,0);
INSERT INTO "django_geo_db_location" VALUES(31531,NULL,'Brooklyn, KY',12793,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31532,NULL,'Brooklyn, KY 42209',12793,222,NULL,21,18446,0);
INSERT INTO "django_geo_db_location" VALUES(31533,NULL,'Brownsville, KY',12794,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31534,NULL,'Brownsville, KY 42210',12794,222,NULL,21,18447,0);
INSERT INTO "django_geo_db_location" VALUES(31535,NULL,'Cadiz, KY',12795,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31536,NULL,'Cadiz, KY 42211',12795,222,NULL,21,18448,0);
INSERT INTO "django_geo_db_location" VALUES(31537,NULL,'Center, KY',12796,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31538,NULL,'Center, KY 42214',12796,222,NULL,21,18449,0);
INSERT INTO "django_geo_db_location" VALUES(31539,NULL,'Cerulean, KY',12797,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31540,NULL,'Cerulean, KY 42215',12797,222,NULL,21,18450,0);
INSERT INTO "django_geo_db_location" VALUES(31541,NULL,'Clifty, KY',12798,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31542,NULL,'Clifty, KY 42216',12798,222,NULL,21,18451,0);
INSERT INTO "django_geo_db_location" VALUES(31543,NULL,'Crofton, KY',12799,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31544,NULL,'Crofton, KY 42217',12799,222,NULL,21,18452,0);
INSERT INTO "django_geo_db_location" VALUES(31545,NULL,'Dunbar, KY',12800,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31546,NULL,'Dunbar, KY 42219',12800,222,NULL,21,18453,0);
INSERT INTO "django_geo_db_location" VALUES(31547,NULL,'Elkton, KY',12801,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31548,NULL,'Elkton, KY 42220',12801,222,NULL,21,18454,0);
INSERT INTO "django_geo_db_location" VALUES(31549,NULL,'Fairview, KY',12802,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31550,NULL,'Fairview, KY 42221',12802,222,NULL,21,18455,0);
INSERT INTO "django_geo_db_location" VALUES(31551,NULL,'Fort Campbell, KY',12803,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31552,NULL,'Fort Campbell, KY 42223',12803,222,NULL,21,18456,0);
INSERT INTO "django_geo_db_location" VALUES(31553,NULL,'Gracey, KY',12804,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31554,NULL,'Gracey, KY 42232',12804,222,NULL,21,18457,0);
INSERT INTO "django_geo_db_location" VALUES(31555,NULL,'Guthrie, KY',12805,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31556,NULL,'Guthrie, KY 42234',12805,222,NULL,21,18458,0);
INSERT INTO "django_geo_db_location" VALUES(31557,NULL,'Hadley, KY',12806,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31558,NULL,'Hadley, KY 42235',12806,222,NULL,21,18459,0);
INSERT INTO "django_geo_db_location" VALUES(31559,NULL,'Herndon, KY',12807,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31560,NULL,'Herndon, KY 42236',12807,222,NULL,21,18460,0);
INSERT INTO "django_geo_db_location" VALUES(31561,NULL,'Hopkinsville, KY',12808,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31562,NULL,'Hopkinsville, KY 42240',12808,222,NULL,21,18461,0);
INSERT INTO "django_geo_db_location" VALUES(31563,NULL,'Hopkinsville, KY 42241',12808,222,NULL,21,18462,0);
INSERT INTO "django_geo_db_location" VALUES(31564,NULL,'Huntsville, KY',12809,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31565,NULL,'Huntsville, KY 42251',12809,222,NULL,21,18463,0);
INSERT INTO "django_geo_db_location" VALUES(31566,NULL,'Jetson, KY',12810,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31567,NULL,'Jetson, KY 42252',12810,222,NULL,21,18464,0);
INSERT INTO "django_geo_db_location" VALUES(31568,NULL,'Science Hill, KY',12811,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31569,NULL,'Science Hill, KY 42253',12811,222,NULL,21,18465,0);
INSERT INTO "django_geo_db_location" VALUES(31570,NULL,'La Fayette, KY',12812,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31571,NULL,'La Fayette, KY 42254',12812,222,NULL,21,18466,0);
INSERT INTO "django_geo_db_location" VALUES(31572,NULL,'Lewisburg, KY',12813,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31573,NULL,'Lewisburg, KY 42256',12813,222,NULL,21,18467,0);
INSERT INTO "django_geo_db_location" VALUES(31574,NULL,'Lindseyville, KY',12814,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31575,NULL,'Lindseyville, KY 42257',12814,222,NULL,21,18468,0);
INSERT INTO "django_geo_db_location" VALUES(31576,NULL,'Mammoth Cave, KY',12815,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31577,NULL,'Mammoth Cave, KY 42259',12815,222,NULL,21,18469,0);
INSERT INTO "django_geo_db_location" VALUES(31578,NULL,'Morgantown, KY',12816,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31579,NULL,'Morgantown, KY 42261',12816,222,NULL,21,18470,0);
INSERT INTO "django_geo_db_location" VALUES(31580,NULL,'Oak Grove, KY',12817,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31581,NULL,'Oak Grove, KY 42262',12817,222,NULL,21,18471,0);
INSERT INTO "django_geo_db_location" VALUES(31582,NULL,'Olmstead, KY',12818,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31583,NULL,'Olmstead, KY 42265',12818,222,NULL,21,18472,0);
INSERT INTO "django_geo_db_location" VALUES(31584,NULL,'Pembroke, KY',12819,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31585,NULL,'Pembroke, KY 42266',12819,222,NULL,21,18473,0);
INSERT INTO "django_geo_db_location" VALUES(31586,NULL,'Provo, KY',12820,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31587,NULL,'Provo, KY 42267',12820,222,NULL,21,18474,0);
INSERT INTO "django_geo_db_location" VALUES(31588,NULL,'Richardsville, KY',12821,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31589,NULL,'Richardsville, KY 42270',12821,222,NULL,21,18475,0);
INSERT INTO "django_geo_db_location" VALUES(31590,NULL,'Rochester, KY',12822,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31591,NULL,'Rochester, KY 42273',12822,222,NULL,21,18476,0);
INSERT INTO "django_geo_db_location" VALUES(31592,NULL,'Rockfield, KY',12823,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31593,NULL,'Rockfield, KY 42274',12823,222,NULL,21,18477,0);
INSERT INTO "django_geo_db_location" VALUES(31594,NULL,'Roundhill, KY',12824,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31595,NULL,'Roundhill, KY 42275',12824,222,NULL,21,18478,0);
INSERT INTO "django_geo_db_location" VALUES(31596,NULL,'Russellville, KY',12825,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31597,NULL,'Russellville, KY 42276',12825,222,NULL,21,18479,0);
INSERT INTO "django_geo_db_location" VALUES(31598,NULL,'Sharon Grove, KY',12826,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31599,NULL,'Sharon Grove, KY 42280',12826,222,NULL,21,18480,0);
INSERT INTO "django_geo_db_location" VALUES(31600,NULL,'South Union, KY',12827,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31601,NULL,'South Union, KY 42283',12827,222,NULL,21,18481,0);
INSERT INTO "django_geo_db_location" VALUES(31602,NULL,'Sweeden, KY',12828,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31603,NULL,'Sweeden, KY 42285',12828,222,NULL,21,18482,0);
INSERT INTO "django_geo_db_location" VALUES(31604,NULL,'Trenton, KY',12829,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31605,NULL,'Trenton, KY 42286',12829,222,NULL,21,18483,0);
INSERT INTO "django_geo_db_location" VALUES(31606,NULL,'Welchs Creek, KY',12830,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31607,NULL,'Welchs Creek, KY 42287',12830,222,NULL,21,18484,0);
INSERT INTO "django_geo_db_location" VALUES(31608,NULL,'Woodbury, KY',12831,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31609,NULL,'Woodbury, KY 42288',12831,222,NULL,21,18485,0);
INSERT INTO "django_geo_db_location" VALUES(31610,NULL,'Owensboro, KY',12832,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31611,NULL,'Owensboro, KY 42301',12832,222,NULL,21,18486,0);
INSERT INTO "django_geo_db_location" VALUES(31612,NULL,'Owensboro, KY 42302',12832,222,NULL,21,18487,0);
INSERT INTO "django_geo_db_location" VALUES(31613,NULL,'Owensboro, KY 42303',12832,222,NULL,21,18488,0);
INSERT INTO "django_geo_db_location" VALUES(31614,NULL,'Owensboro, KY 42304',12832,222,NULL,21,18489,0);
INSERT INTO "django_geo_db_location" VALUES(31615,NULL,'Beaver Dam, KY',12833,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31616,NULL,'Beaver Dam, KY 42320',12833,222,NULL,21,18490,0);
INSERT INTO "django_geo_db_location" VALUES(31617,NULL,'Beech Creek, KY',12834,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31618,NULL,'Beech Creek, KY 42321',12834,222,NULL,21,18491,0);
INSERT INTO "django_geo_db_location" VALUES(31619,NULL,'Beech Grove, KY',12835,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31620,NULL,'Beech Grove, KY 42322',12835,222,NULL,21,18492,0);
INSERT INTO "django_geo_db_location" VALUES(31621,NULL,'Beechmont, KY',12836,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31622,NULL,'Beechmont, KY 42323',12836,222,NULL,21,18493,0);
INSERT INTO "django_geo_db_location" VALUES(31623,NULL,'Belton, KY',12837,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31624,NULL,'Belton, KY 42324',12837,222,NULL,21,18494,0);
INSERT INTO "django_geo_db_location" VALUES(31625,NULL,'Bremen, KY',12838,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31626,NULL,'Bremen, KY 42325',12838,222,NULL,21,18495,0);
INSERT INTO "django_geo_db_location" VALUES(31627,NULL,'Browder, KY',12839,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31628,NULL,'Browder, KY 42326',12839,222,NULL,21,18496,0);
INSERT INTO "django_geo_db_location" VALUES(31629,NULL,'Calhoun, KY',12840,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31630,NULL,'Calhoun, KY 42327',12840,222,NULL,21,18497,0);
INSERT INTO "django_geo_db_location" VALUES(31631,NULL,'Centertown, KY',12841,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31632,NULL,'Centertown, KY 42328',12841,222,NULL,21,18498,0);
INSERT INTO "django_geo_db_location" VALUES(31633,NULL,'Central City, KY',12842,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31634,NULL,'Central City, KY 42330',12842,222,NULL,21,18499,0);
INSERT INTO "django_geo_db_location" VALUES(31635,NULL,'Cleaton, KY',12843,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31636,NULL,'Cleaton, KY 42332',12843,222,NULL,21,18500,0);
INSERT INTO "django_geo_db_location" VALUES(31637,NULL,'Cromwell, KY',12844,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31638,NULL,'Cromwell, KY 42333',12844,222,NULL,21,18501,0);
INSERT INTO "django_geo_db_location" VALUES(31639,NULL,'Curdsville, KY',12845,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31640,NULL,'Curdsville, KY 42334',12845,222,NULL,21,18502,0);
INSERT INTO "django_geo_db_location" VALUES(31641,NULL,'Drakesboro, KY',12846,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31642,NULL,'Drakesboro, KY 42337',12846,222,NULL,21,18503,0);
INSERT INTO "django_geo_db_location" VALUES(31643,NULL,'Dundee, KY',12847,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31644,NULL,'Dundee, KY 42338',12847,222,NULL,21,18504,0);
INSERT INTO "django_geo_db_location" VALUES(31645,NULL,'Dunmor, KY',12848,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31646,NULL,'Dunmor, KY 42339',12848,222,NULL,21,18505,0);
INSERT INTO "django_geo_db_location" VALUES(31647,NULL,'Fordsville, KY',12849,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31648,NULL,'Fordsville, KY 42343',12849,222,NULL,21,18506,0);
INSERT INTO "django_geo_db_location" VALUES(31649,NULL,'Graham, KY',12850,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31650,NULL,'Graham, KY 42344',12850,222,NULL,21,18507,0);
INSERT INTO "django_geo_db_location" VALUES(31651,NULL,'Greenville, KY',12851,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31652,NULL,'Greenville, KY 42345',12851,222,NULL,21,18508,0);
INSERT INTO "django_geo_db_location" VALUES(31653,NULL,'Hartford, KY',12852,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31654,NULL,'Hartford, KY 42347',12852,222,NULL,21,18509,0);
INSERT INTO "django_geo_db_location" VALUES(31655,NULL,'Hawesville, KY',12853,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31656,NULL,'Hawesville, KY 42348',12853,222,NULL,21,18510,0);
INSERT INTO "django_geo_db_location" VALUES(31657,NULL,'Horse Branch, KY',12854,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31658,NULL,'Horse Branch, KY 42349',12854,222,NULL,21,18511,0);
INSERT INTO "django_geo_db_location" VALUES(31659,NULL,'Island, KY',12855,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31660,NULL,'Island, KY 42350',12855,222,NULL,21,18512,0);
INSERT INTO "django_geo_db_location" VALUES(31661,NULL,'Lewisport, KY',12856,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31662,NULL,'Lewisport, KY 42351',12856,222,NULL,21,18513,0);
INSERT INTO "django_geo_db_location" VALUES(31663,NULL,'Livermore, KY',12857,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31664,NULL,'Livermore, KY 42352',12857,222,NULL,21,18514,0);
INSERT INTO "django_geo_db_location" VALUES(31665,NULL,'McHenry, KY',12858,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31666,NULL,'McHenry, KY 42354',12858,222,NULL,21,18515,0);
INSERT INTO "django_geo_db_location" VALUES(31667,NULL,'Maceo, KY',12859,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31668,NULL,'Maceo, KY 42355',12859,222,NULL,21,18516,0);
INSERT INTO "django_geo_db_location" VALUES(31669,NULL,'Maple Mount, KY',12860,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31670,NULL,'Maple Mount, KY 42356',12860,222,NULL,21,18517,0);
INSERT INTO "django_geo_db_location" VALUES(31671,NULL,'Olaton, KY',12861,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31672,NULL,'Olaton, KY 42361',12861,222,NULL,21,18518,0);
INSERT INTO "django_geo_db_location" VALUES(31673,NULL,'Pellville, KY',12862,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31674,NULL,'Pellville, KY 42364',12862,222,NULL,21,18519,0);
INSERT INTO "django_geo_db_location" VALUES(31675,NULL,'Penrod, KY',12863,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31676,NULL,'Penrod, KY 42365',12863,222,NULL,21,18520,0);
INSERT INTO "django_geo_db_location" VALUES(31677,NULL,'Philpot, KY',12864,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31678,NULL,'Philpot, KY 42366',12864,222,NULL,21,18521,0);
INSERT INTO "django_geo_db_location" VALUES(31679,NULL,'Powderly, KY',12865,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31680,NULL,'Powderly, KY 42367',12865,222,NULL,21,18522,0);
INSERT INTO "django_geo_db_location" VALUES(31681,NULL,'Reynolds Station, KY',12866,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31682,NULL,'Reynolds Station, KY 42368',12866,222,NULL,21,18523,0);
INSERT INTO "django_geo_db_location" VALUES(31683,NULL,'Rockport, KY',12867,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31684,NULL,'Rockport, KY 42369',12867,222,NULL,21,18524,0);
INSERT INTO "django_geo_db_location" VALUES(31685,NULL,'Rosine, KY',12868,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31686,NULL,'Rosine, KY 42370',12868,222,NULL,21,18525,0);
INSERT INTO "django_geo_db_location" VALUES(31687,NULL,'Rumsey, KY',12869,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31688,NULL,'Rumsey, KY 42371',12869,222,NULL,21,18526,0);
INSERT INTO "django_geo_db_location" VALUES(31689,NULL,'Sacramento, KY',12870,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31690,NULL,'Sacramento, KY 42372',12870,222,NULL,21,18527,0);
INSERT INTO "django_geo_db_location" VALUES(31691,NULL,'South Carrollton, KY',12871,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31692,NULL,'South Carrollton, KY 42374',12871,222,NULL,21,18528,0);
INSERT INTO "django_geo_db_location" VALUES(31693,NULL,'Stanley, KY',12872,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31694,NULL,'Stanley, KY 42375',12872,222,NULL,21,18529,0);
INSERT INTO "django_geo_db_location" VALUES(31695,NULL,'Utica, KY',12873,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31696,NULL,'Utica, KY 42376',12873,222,NULL,21,18530,0);
INSERT INTO "django_geo_db_location" VALUES(31697,NULL,'West Louisville, KY',12874,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31698,NULL,'West Louisville, KY 42377',12874,222,NULL,21,18531,0);
INSERT INTO "django_geo_db_location" VALUES(31699,NULL,'Whitesville, KY',12875,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31700,NULL,'Whitesville, KY 42378',12875,222,NULL,21,18532,0);
INSERT INTO "django_geo_db_location" VALUES(31701,NULL,'Morganfield, KY',12876,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31702,NULL,'Morganfield, KY 42400',12876,222,NULL,21,18533,0);
INSERT INTO "django_geo_db_location" VALUES(31703,NULL,'Baskett, KY',12877,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31704,NULL,'Baskett, KY 42402',12877,222,NULL,21,18534,0);
INSERT INTO "django_geo_db_location" VALUES(31705,NULL,'Blackford, KY',12878,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31706,NULL,'Blackford, KY 42403',12878,222,NULL,21,18535,0);
INSERT INTO "django_geo_db_location" VALUES(31707,NULL,'Clay, KY',12879,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31708,NULL,'Clay, KY 42404',12879,222,NULL,21,18536,0);
INSERT INTO "django_geo_db_location" VALUES(31709,NULL,'Corydon, KY',12880,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31710,NULL,'Corydon, KY 42406',12880,222,NULL,21,18537,0);
INSERT INTO "django_geo_db_location" VALUES(31711,NULL,'Dawson Springs, KY',12881,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31712,NULL,'Dawson Springs, KY 42408',12881,222,NULL,21,18538,0);
INSERT INTO "django_geo_db_location" VALUES(31713,NULL,'Dixon, KY',12882,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31714,NULL,'Dixon, KY 42409',12882,222,NULL,21,18539,0);
INSERT INTO "django_geo_db_location" VALUES(31715,NULL,'Earlington, KY',12883,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31716,NULL,'Earlington, KY 42410',12883,222,NULL,21,18540,0);
INSERT INTO "django_geo_db_location" VALUES(31717,NULL,'Fredonia, KY 42411',12706,222,NULL,21,18541,0);
INSERT INTO "django_geo_db_location" VALUES(31718,NULL,'Hanson, KY',12884,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31719,NULL,'Hanson, KY 42413',12884,222,NULL,21,18542,0);
INSERT INTO "django_geo_db_location" VALUES(31720,NULL,'Henderson, KY',12885,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31721,NULL,'Henderson, KY 42419',12885,222,NULL,21,18543,0);
INSERT INTO "django_geo_db_location" VALUES(31722,NULL,'Henderson, KY 42420',12885,222,NULL,21,18544,0);
INSERT INTO "django_geo_db_location" VALUES(31723,NULL,'Madisonville, KY',12886,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31724,NULL,'Madisonville, KY 42431',12886,222,NULL,21,18545,0);
INSERT INTO "django_geo_db_location" VALUES(31725,NULL,'Manitou, KY',12887,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31726,NULL,'Manitou, KY 42436',12887,222,NULL,21,18546,0);
INSERT INTO "django_geo_db_location" VALUES(31727,NULL,'Morganfield, KY 42437',12876,222,NULL,21,18547,0);
INSERT INTO "django_geo_db_location" VALUES(31728,NULL,'Mortons Gap, KY',12888,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31729,NULL,'Mortons Gap, KY 42440',12888,222,NULL,21,18548,0);
INSERT INTO "django_geo_db_location" VALUES(31730,NULL,'Nebo, KY',12889,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31731,NULL,'Nebo, KY 42441',12889,222,NULL,21,18549,0);
INSERT INTO "django_geo_db_location" VALUES(31732,NULL,'Nortonville, KY',12890,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31733,NULL,'Nortonville, KY 42442',12890,222,NULL,21,18550,0);
INSERT INTO "django_geo_db_location" VALUES(31734,NULL,'Poole, KY',12891,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31735,NULL,'Poole, KY 42444',12891,222,NULL,21,18551,0);
INSERT INTO "django_geo_db_location" VALUES(31736,NULL,'Princeton, KY',12892,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31737,NULL,'Princeton, KY 42445',12892,222,NULL,21,18552,0);
INSERT INTO "django_geo_db_location" VALUES(31738,NULL,'Providence, KY',12893,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31739,NULL,'Providence, KY 42450',12893,222,NULL,21,18553,0);
INSERT INTO "django_geo_db_location" VALUES(31740,NULL,'Reed, KY',12894,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31741,NULL,'Reed, KY 42451',12894,222,NULL,21,18554,0);
INSERT INTO "django_geo_db_location" VALUES(31742,NULL,'Robards, KY',12895,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31743,NULL,'Robards, KY 42452',12895,222,NULL,21,18555,0);
INSERT INTO "django_geo_db_location" VALUES(31744,NULL,'Saint Charles, KY',12896,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31745,NULL,'Saint Charles, KY 42453',12896,222,NULL,21,18556,0);
INSERT INTO "django_geo_db_location" VALUES(31746,NULL,'Sebree, KY',12897,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31747,NULL,'Sebree, KY 42455',12897,222,NULL,21,18557,0);
INSERT INTO "django_geo_db_location" VALUES(31748,NULL,'Slaughters, KY',12898,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31749,NULL,'Slaughters, KY 42456',12898,222,NULL,21,18558,0);
INSERT INTO "django_geo_db_location" VALUES(31750,NULL,'Smith Mills, KY',12899,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31751,NULL,'Smith Mills, KY 42457',12899,222,NULL,21,18559,0);
INSERT INTO "django_geo_db_location" VALUES(31752,NULL,'Spottsville, KY',12900,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31753,NULL,'Spottsville, KY 42458',12900,222,NULL,21,18560,0);
INSERT INTO "django_geo_db_location" VALUES(31754,NULL,'Sturgis, KY',12901,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31755,NULL,'Sturgis, KY 42459',12901,222,NULL,21,18561,0);
INSERT INTO "django_geo_db_location" VALUES(31756,NULL,'Sullivan, KY',12902,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31757,NULL,'Sullivan, KY 42460',12902,222,NULL,21,18562,0);
INSERT INTO "django_geo_db_location" VALUES(31758,NULL,'Uniontown, KY',12903,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31759,NULL,'Uniontown, KY 42461',12903,222,NULL,21,18563,0);
INSERT INTO "django_geo_db_location" VALUES(31760,NULL,'Waverly, KY',12904,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31761,NULL,'Waverly, KY 42462',12904,222,NULL,21,18564,0);
INSERT INTO "django_geo_db_location" VALUES(31762,NULL,'Wheatcroft, KY',12905,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31763,NULL,'Wheatcroft, KY 42463',12905,222,NULL,21,18565,0);
INSERT INTO "django_geo_db_location" VALUES(31764,NULL,'White Plains, KY',12906,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31765,NULL,'White Plains, KY 42464',12906,222,NULL,21,18566,0);
INSERT INTO "django_geo_db_location" VALUES(31766,NULL,'Somerset, KY',12907,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31767,NULL,'Somerset, KY 42501',12907,222,NULL,21,18567,0);
INSERT INTO "django_geo_db_location" VALUES(31768,NULL,'Somerset, KY 42502',12907,222,NULL,21,18568,0);
INSERT INTO "django_geo_db_location" VALUES(31769,NULL,'Somerset, KY 42503',12907,222,NULL,21,18569,0);
INSERT INTO "django_geo_db_location" VALUES(31770,NULL,'Bethelridge, KY',12908,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31771,NULL,'Bethelridge, KY 42516',12908,222,NULL,21,18570,0);
INSERT INTO "django_geo_db_location" VALUES(31772,NULL,'Bronston, KY',12909,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31773,NULL,'Bronston, KY 42518',12909,222,NULL,21,18571,0);
INSERT INTO "django_geo_db_location" VALUES(31774,NULL,'Burnside, KY',12910,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31775,NULL,'Burnside, KY 42519',12910,222,NULL,21,18572,0);
INSERT INTO "django_geo_db_location" VALUES(31776,NULL,'Dunnville, KY',12911,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31777,NULL,'Dunnville, KY 42528',12911,222,NULL,21,18573,0);
INSERT INTO "django_geo_db_location" VALUES(31778,NULL,'Ferguson, KY',12912,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31779,NULL,'Ferguson, KY 42533',12912,222,NULL,21,18574,0);
INSERT INTO "django_geo_db_location" VALUES(31780,NULL,'Liberty, KY',12913,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31781,NULL,'Liberty, KY 42539',12913,222,NULL,21,18575,0);
INSERT INTO "django_geo_db_location" VALUES(31782,NULL,'Middleburg, KY',12914,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31783,NULL,'Middleburg, KY 42541',12914,222,NULL,21,18576,0);
INSERT INTO "django_geo_db_location" VALUES(31784,NULL,'Nancy, KY',12915,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31785,NULL,'Nancy, KY 42544',12915,222,NULL,21,18577,0);
INSERT INTO "django_geo_db_location" VALUES(31786,NULL,'Science Hill, KY 42553',12811,222,NULL,21,18578,0);
INSERT INTO "django_geo_db_location" VALUES(31787,NULL,'Tateville, KY',12916,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31788,NULL,'Tateville, KY 42558',12916,222,NULL,21,18579,0);
INSERT INTO "django_geo_db_location" VALUES(31789,NULL,'West Somerset, KY',12917,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31790,NULL,'West Somerset, KY 42564',12917,222,NULL,21,18580,0);
INSERT INTO "django_geo_db_location" VALUES(31791,NULL,'Windsor, KY',12918,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31792,NULL,'Windsor, KY 42565',12918,222,NULL,21,18581,0);
INSERT INTO "django_geo_db_location" VALUES(31793,NULL,'Yosemite, KY',12919,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31794,NULL,'Yosemite, KY 42566',12919,222,NULL,21,18582,0);
INSERT INTO "django_geo_db_location" VALUES(31795,NULL,'Eubank, KY',12920,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31796,NULL,'Eubank, KY 42567',12920,222,NULL,21,18583,0);
INSERT INTO "django_geo_db_location" VALUES(31797,NULL,'Albany, KY',12921,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31798,NULL,'Albany, KY 42602',12921,222,NULL,21,18584,0);
INSERT INTO "django_geo_db_location" VALUES(31799,NULL,'Alpha, KY',12922,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31800,NULL,'Alpha, KY 42603',12922,222,NULL,21,18585,0);
INSERT INTO "django_geo_db_location" VALUES(31801,NULL,'Jamestown, KY',12923,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31802,NULL,'Jamestown, KY 42629',12923,222,NULL,21,18586,0);
INSERT INTO "django_geo_db_location" VALUES(31803,NULL,'Marshes Siding, KY',12924,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31804,NULL,'Marshes Siding, KY 42631',12924,222,NULL,21,18587,0);
INSERT INTO "django_geo_db_location" VALUES(31805,NULL,'Mill Springs, KY',12925,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31806,NULL,'Mill Springs, KY 42632',12925,222,NULL,21,18588,0);
INSERT INTO "django_geo_db_location" VALUES(31807,NULL,'Monticello, KY',12926,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31808,NULL,'Monticello, KY 42633',12926,222,NULL,21,18589,0);
INSERT INTO "django_geo_db_location" VALUES(31809,NULL,'Parkers Lake, KY',12927,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31810,NULL,'Parkers Lake, KY 42634',12927,222,NULL,21,18590,0);
INSERT INTO "django_geo_db_location" VALUES(31811,NULL,'Pine Knot, KY',12928,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31812,NULL,'Pine Knot, KY 42635',12928,222,NULL,21,18591,0);
INSERT INTO "django_geo_db_location" VALUES(31813,NULL,'Monticello, KY 42637',12926,222,NULL,21,18592,0);
INSERT INTO "django_geo_db_location" VALUES(31814,NULL,'Revelo, KY',12929,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31815,NULL,'Revelo, KY 42638',12929,222,NULL,21,18593,0);
INSERT INTO "django_geo_db_location" VALUES(31816,NULL,'Russell Springs, KY',12930,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31817,NULL,'Russell Springs, KY 42642',12930,222,NULL,21,18594,0);
INSERT INTO "django_geo_db_location" VALUES(31818,NULL,'Stearns, KY',12931,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31819,NULL,'Stearns, KY 42647',12931,222,NULL,21,18595,0);
INSERT INTO "django_geo_db_location" VALUES(31820,NULL,'Strunk, KY',12932,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31821,NULL,'Strunk, KY 42649',12932,222,NULL,21,18596,0);
INSERT INTO "django_geo_db_location" VALUES(31822,NULL,'Whitley City, KY',12933,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31823,NULL,'Whitley City, KY 42653',12933,222,NULL,21,18597,0);
INSERT INTO "django_geo_db_location" VALUES(31824,NULL,'Elizabethtown, KY',12934,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31825,NULL,'Elizabethtown, KY 42701',12934,222,NULL,21,18598,0);
INSERT INTO "django_geo_db_location" VALUES(31826,NULL,'Elizabethtown, KY 42702',12934,222,NULL,21,18599,0);
INSERT INTO "django_geo_db_location" VALUES(31827,NULL,'Bakerton, KY',12935,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31828,NULL,'Bakerton, KY 42711',12935,222,NULL,21,18600,0);
INSERT INTO "django_geo_db_location" VALUES(31829,NULL,'Big Clifty, KY',12936,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31830,NULL,'Big Clifty, KY 42712',12936,222,NULL,21,18601,0);
INSERT INTO "django_geo_db_location" VALUES(31831,NULL,'Bonnieville, KY',12937,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31832,NULL,'Bonnieville, KY 42713',12937,222,NULL,21,18602,0);
INSERT INTO "django_geo_db_location" VALUES(31833,NULL,'Breeding, KY',12938,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31834,NULL,'Breeding, KY 42715',12938,222,NULL,21,18603,0);
INSERT INTO "django_geo_db_location" VALUES(31835,NULL,'Buffalo, KY',12939,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31836,NULL,'Buffalo, KY 42716',12939,222,NULL,21,18604,0);
INSERT INTO "django_geo_db_location" VALUES(31837,NULL,'Burkesville, KY',12940,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31838,NULL,'Burkesville, KY 42717',12940,222,NULL,21,18605,0);
INSERT INTO "django_geo_db_location" VALUES(31839,NULL,'Campbellsville, KY',12941,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31840,NULL,'Campbellsville, KY 42718',12941,222,NULL,21,18606,0);
INSERT INTO "django_geo_db_location" VALUES(31841,NULL,'Campbellsville, KY 42719',12941,222,NULL,21,18607,0);
INSERT INTO "django_geo_db_location" VALUES(31842,NULL,'Cane Valley, KY',12942,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31843,NULL,'Cane Valley, KY 42720',12942,222,NULL,21,18608,0);
INSERT INTO "django_geo_db_location" VALUES(31844,NULL,'Caneyville, KY',12943,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31845,NULL,'Caneyville, KY 42721',12943,222,NULL,21,18609,0);
INSERT INTO "django_geo_db_location" VALUES(31846,NULL,'Canmer, KY',12944,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31847,NULL,'Canmer, KY 42722',12944,222,NULL,21,18610,0);
INSERT INTO "django_geo_db_location" VALUES(31848,NULL,'Cecilia, KY',12945,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31849,NULL,'Cecilia, KY 42724',12945,222,NULL,21,18611,0);
INSERT INTO "django_geo_db_location" VALUES(31850,NULL,'Clarkson, KY',12946,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31851,NULL,'Clarkson, KY 42726',12946,222,NULL,21,18612,0);
INSERT INTO "django_geo_db_location" VALUES(31852,NULL,'Columbia, KY',12947,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31853,NULL,'Columbia, KY 42728',12947,222,NULL,21,18613,0);
INSERT INTO "django_geo_db_location" VALUES(31854,NULL,'Cub Run, KY',12948,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31855,NULL,'Cub Run, KY 42729',12948,222,NULL,21,18614,0);
INSERT INTO "django_geo_db_location" VALUES(31856,NULL,'Dubre, KY',12949,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31857,NULL,'Dubre, KY 42731',12949,222,NULL,21,18615,0);
INSERT INTO "django_geo_db_location" VALUES(31858,NULL,'Eastview, KY',12950,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31859,NULL,'Eastview, KY 42732',12950,222,NULL,21,18616,0);
INSERT INTO "django_geo_db_location" VALUES(31860,NULL,'Elk Horn, KY',12951,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31861,NULL,'Elk Horn, KY 42733',12951,222,NULL,21,18617,0);
INSERT INTO "django_geo_db_location" VALUES(31862,NULL,'Fairplay, KY',12952,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31863,NULL,'Fairplay, KY 42735',12952,222,NULL,21,18618,0);
INSERT INTO "django_geo_db_location" VALUES(31864,NULL,'Glendale, KY',12953,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31865,NULL,'Glendale, KY 42740',12953,222,NULL,21,18619,0);
INSERT INTO "django_geo_db_location" VALUES(31866,NULL,'Glens Fork, KY',12954,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31867,NULL,'Glens Fork, KY 42741',12954,222,NULL,21,18620,0);
INSERT INTO "django_geo_db_location" VALUES(31868,NULL,'Gradyville, KY',12955,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31869,NULL,'Gradyville, KY 42742',12955,222,NULL,21,18621,0);
INSERT INTO "django_geo_db_location" VALUES(31870,NULL,'Greensburg, KY',12956,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31871,NULL,'Greensburg, KY 42743',12956,222,NULL,21,18622,0);
INSERT INTO "django_geo_db_location" VALUES(31872,NULL,'Hardyville, KY',12957,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31873,NULL,'Hardyville, KY 42746',12957,222,NULL,21,18623,0);
INSERT INTO "django_geo_db_location" VALUES(31874,NULL,'Hodgenville, KY',12958,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31875,NULL,'Hodgenville, KY 42748',12958,222,NULL,21,18624,0);
INSERT INTO "django_geo_db_location" VALUES(31876,NULL,'Horse Cave, KY',12959,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31877,NULL,'Horse Cave, KY 42749',12959,222,NULL,21,18625,0);
INSERT INTO "django_geo_db_location" VALUES(31878,NULL,'Knifley, KY',12960,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31879,NULL,'Knifley, KY 42753',12960,222,NULL,21,18626,0);
INSERT INTO "django_geo_db_location" VALUES(31880,NULL,'Leitchfield, KY',12961,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31881,NULL,'Leitchfield, KY 42754',12961,222,NULL,21,18627,0);
INSERT INTO "django_geo_db_location" VALUES(31882,NULL,'Leitchfield, KY 42755',12961,222,NULL,21,18628,0);
INSERT INTO "django_geo_db_location" VALUES(31883,NULL,'Magnolia, KY',12962,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31884,NULL,'Magnolia, KY 42757',12962,222,NULL,21,18629,0);
INSERT INTO "django_geo_db_location" VALUES(31885,NULL,'Mannsville, KY',12963,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31886,NULL,'Mannsville, KY 42758',12963,222,NULL,21,18630,0);
INSERT INTO "django_geo_db_location" VALUES(31887,NULL,'Marrowbone, KY',12964,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31888,NULL,'Marrowbone, KY 42759',12964,222,NULL,21,18631,0);
INSERT INTO "django_geo_db_location" VALUES(31889,NULL,'Milltown, KY',12965,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31890,NULL,'Milltown, KY 42761',12965,222,NULL,21,18632,0);
INSERT INTO "django_geo_db_location" VALUES(31891,NULL,'Millwood, KY',12966,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31892,NULL,'Millwood, KY 42762',12966,222,NULL,21,18633,0);
INSERT INTO "django_geo_db_location" VALUES(31893,NULL,'Mount Sherman, KY',12967,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31894,NULL,'Mount Sherman, KY 42764',12967,222,NULL,21,18634,0);
INSERT INTO "django_geo_db_location" VALUES(31895,NULL,'Munfordville, KY',12968,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31896,NULL,'Munfordville, KY 42765',12968,222,NULL,21,18635,0);
INSERT INTO "django_geo_db_location" VALUES(31897,NULL,'Sonora, KY',12969,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31898,NULL,'Sonora, KY 42776',12969,222,NULL,21,18636,0);
INSERT INTO "django_geo_db_location" VALUES(31899,NULL,'Summersville, KY',12970,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31900,NULL,'Summersville, KY 42782',12970,222,NULL,21,18637,0);
INSERT INTO "django_geo_db_location" VALUES(31901,NULL,'Summit, KY',12971,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31902,NULL,'Summit, KY 42783',12971,222,NULL,21,18638,0);
INSERT INTO "django_geo_db_location" VALUES(31903,NULL,'Upton, KY',12972,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31904,NULL,'Upton, KY 42784',12972,222,NULL,21,18639,0);
INSERT INTO "django_geo_db_location" VALUES(31905,NULL,'Waterview, KY',12973,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31906,NULL,'Waterview, KY 42786',12973,222,NULL,21,18640,0);
INSERT INTO "django_geo_db_location" VALUES(31907,NULL,'White Mills, KY',12974,222,NULL,21,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31908,NULL,'White Mills, KY 42788',12974,222,NULL,21,18641,0);
INSERT INTO "django_geo_db_location" VALUES(31909,NULL,'Alexandria, OH',12975,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31910,NULL,'Alexandria, OH 43001',12975,222,NULL,35,18642,0);
INSERT INTO "django_geo_db_location" VALUES(31911,NULL,'Amlin, OH',12976,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31912,NULL,'Amlin, OH 43002',12976,222,NULL,35,18643,0);
INSERT INTO "django_geo_db_location" VALUES(31913,NULL,'Ashley, OH',12977,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31914,NULL,'Ashley, OH 43003',12977,222,NULL,35,18644,0);
INSERT INTO "django_geo_db_location" VALUES(31915,NULL,'Blacklick, OH',12978,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31916,NULL,'Blacklick, OH 43004',12978,222,NULL,35,18645,0);
INSERT INTO "django_geo_db_location" VALUES(31917,NULL,'Bladensburg, OH',12979,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31918,NULL,'Bladensburg, OH 43005',12979,222,NULL,35,18646,0);
INSERT INTO "django_geo_db_location" VALUES(31919,NULL,'Brinkhaven, OH',12980,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31920,NULL,'Brinkhaven, OH 43006',12980,222,NULL,35,18647,0);
INSERT INTO "django_geo_db_location" VALUES(31921,NULL,'Broadway, OH',12981,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31922,NULL,'Broadway, OH 43007',12981,222,NULL,35,18648,0);
INSERT INTO "django_geo_db_location" VALUES(31923,NULL,'Buckeye Lake, OH',12982,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31924,NULL,'Buckeye Lake, OH 43008',12982,222,NULL,35,18649,0);
INSERT INTO "django_geo_db_location" VALUES(31925,NULL,'Cable, OH',12983,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31926,NULL,'Cable, OH 43009',12983,222,NULL,35,18650,0);
INSERT INTO "django_geo_db_location" VALUES(31927,NULL,'Catawba, OH',12984,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31928,NULL,'Catawba, OH 43010',12984,222,NULL,35,18651,0);
INSERT INTO "django_geo_db_location" VALUES(31929,NULL,'Centerburg, OH',12985,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31930,NULL,'Centerburg, OH 43011',12985,222,NULL,35,18652,0);
INSERT INTO "django_geo_db_location" VALUES(31931,NULL,'Croton, OH',12986,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31932,NULL,'Croton, OH 43013',12986,222,NULL,35,18653,0);
INSERT INTO "django_geo_db_location" VALUES(31933,NULL,'Danville, OH',12987,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31934,NULL,'Danville, OH 43014',12987,222,NULL,35,18654,0);
INSERT INTO "django_geo_db_location" VALUES(31935,NULL,'Delaware, OH',12988,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31936,NULL,'Delaware, OH 43015',12988,222,NULL,35,18655,0);
INSERT INTO "django_geo_db_location" VALUES(31937,NULL,'Dublin, OH',12989,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31938,NULL,'Dublin, OH 43016',12989,222,NULL,35,18656,0);
INSERT INTO "django_geo_db_location" VALUES(31939,NULL,'Dublin, OH 43017',12989,222,NULL,35,18657,0);
INSERT INTO "django_geo_db_location" VALUES(31940,NULL,'Etna, OH',12990,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31941,NULL,'Etna, OH 43018',12990,222,NULL,35,18658,0);
INSERT INTO "django_geo_db_location" VALUES(31942,NULL,'Fredericktown, OH',12991,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31943,NULL,'Fredericktown, OH 43019',12991,222,NULL,35,18659,0);
INSERT INTO "django_geo_db_location" VALUES(31944,NULL,'Galena, OH',12992,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31945,NULL,'Galena, OH 43021',12992,222,NULL,35,18660,0);
INSERT INTO "django_geo_db_location" VALUES(31946,NULL,'Gambier, OH',12993,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31947,NULL,'Gambier, OH 43022',12993,222,NULL,35,18661,0);
INSERT INTO "django_geo_db_location" VALUES(31948,NULL,'Granville, OH',12994,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31949,NULL,'Granville, OH 43023',12994,222,NULL,35,18662,0);
INSERT INTO "django_geo_db_location" VALUES(31950,NULL,'Hebron, OH',12995,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31951,NULL,'Hebron, OH 43025',12995,222,NULL,35,18663,0);
INSERT INTO "django_geo_db_location" VALUES(31952,NULL,'Hilliard, OH',12996,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31953,NULL,'Hilliard, OH 43026',12996,222,NULL,35,18664,0);
INSERT INTO "django_geo_db_location" VALUES(31954,NULL,'Homer, OH',12997,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31955,NULL,'Homer, OH 43027',12997,222,NULL,35,18665,0);
INSERT INTO "django_geo_db_location" VALUES(31956,NULL,'Howard, OH',12998,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31957,NULL,'Howard, OH 43028',12998,222,NULL,35,18666,0);
INSERT INTO "django_geo_db_location" VALUES(31958,NULL,'Irwin, OH',12999,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31959,NULL,'Irwin, OH 43029',12999,222,NULL,35,18667,0);
INSERT INTO "django_geo_db_location" VALUES(31960,NULL,'Jacksontown, OH',13000,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31961,NULL,'Jacksontown, OH 43030',13000,222,NULL,35,18668,0);
INSERT INTO "django_geo_db_location" VALUES(31962,NULL,'Johnstown, OH',13001,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31963,NULL,'Johnstown, OH 43031',13001,222,NULL,35,18669,0);
INSERT INTO "django_geo_db_location" VALUES(31964,NULL,'Kilbourne, OH',13002,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31965,NULL,'Kilbourne, OH 43032',13002,222,NULL,35,18670,0);
INSERT INTO "django_geo_db_location" VALUES(31966,NULL,'Kirkersville, OH',13003,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31967,NULL,'Kirkersville, OH 43033',13003,222,NULL,35,18671,0);
INSERT INTO "django_geo_db_location" VALUES(31968,NULL,'Lewis Center, OH',13004,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31969,NULL,'Lewis Center, OH 43035',13004,222,NULL,35,18672,0);
INSERT INTO "django_geo_db_location" VALUES(31970,NULL,'Magnetic Springs, OH',13005,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31971,NULL,'Magnetic Springs, OH 43036',13005,222,NULL,35,18673,0);
INSERT INTO "django_geo_db_location" VALUES(31972,NULL,'Martinsburg, OH',13006,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31973,NULL,'Martinsburg, OH 43037',13006,222,NULL,35,18674,0);
INSERT INTO "django_geo_db_location" VALUES(31974,NULL,'Marysville, OH',13007,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31975,NULL,'Marysville, OH 43040',13007,222,NULL,35,18675,0);
INSERT INTO "django_geo_db_location" VALUES(31976,NULL,'Marysville, OH 43041',13007,222,NULL,35,18676,0);
INSERT INTO "django_geo_db_location" VALUES(31977,NULL,'Mechanicsburg, OH',13008,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31978,NULL,'Mechanicsburg, OH 43044',13008,222,NULL,35,18677,0);
INSERT INTO "django_geo_db_location" VALUES(31979,NULL,'Milford Center, OH',13009,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31980,NULL,'Milford Center, OH 43045',13009,222,NULL,35,18678,0);
INSERT INTO "django_geo_db_location" VALUES(31981,NULL,'Millersport, OH',13010,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31982,NULL,'Millersport, OH 43046',13010,222,NULL,35,18679,0);
INSERT INTO "django_geo_db_location" VALUES(31983,NULL,'Mingo, OH',13011,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31984,NULL,'Mingo, OH 43047',13011,222,NULL,35,18680,0);
INSERT INTO "django_geo_db_location" VALUES(31985,NULL,'Mount Liberty, OH',13012,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31986,NULL,'Mount Liberty, OH 43048',13012,222,NULL,35,18681,0);
INSERT INTO "django_geo_db_location" VALUES(31987,NULL,'Mount Vernon, OH',13013,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31988,NULL,'Mount Vernon, OH 43050',13013,222,NULL,35,18682,0);
INSERT INTO "django_geo_db_location" VALUES(31989,NULL,'New Albany, OH',13014,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31990,NULL,'New Albany, OH 43054',13014,222,NULL,35,18683,0);
INSERT INTO "django_geo_db_location" VALUES(31991,NULL,'Newark, OH',13015,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31992,NULL,'Newark, OH 43055',13015,222,NULL,35,18684,0);
INSERT INTO "django_geo_db_location" VALUES(31993,NULL,'Heath, OH',13016,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31994,NULL,'Heath, OH 43056',13016,222,NULL,35,18685,0);
INSERT INTO "django_geo_db_location" VALUES(31995,NULL,'Newark, OH 43058',13015,222,NULL,35,18686,0);
INSERT INTO "django_geo_db_location" VALUES(31996,NULL,'North Lewisburg, OH',13017,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31997,NULL,'North Lewisburg, OH 43060',13017,222,NULL,35,18687,0);
INSERT INTO "django_geo_db_location" VALUES(31998,NULL,'Ostrander, OH',13018,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(31999,NULL,'Ostrander, OH 43061',13018,222,NULL,35,18688,0);
INSERT INTO "django_geo_db_location" VALUES(32000,NULL,'Pataskala, OH',13019,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32001,NULL,'Pataskala, OH 43062',13019,222,NULL,35,18689,0);
INSERT INTO "django_geo_db_location" VALUES(32002,NULL,'Plain City, OH',13020,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32003,NULL,'Plain City, OH 43064',13020,222,NULL,35,18690,0);
INSERT INTO "django_geo_db_location" VALUES(32004,NULL,'Powell, OH',13021,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32005,NULL,'Powell, OH 43065',13021,222,NULL,35,18691,0);
INSERT INTO "django_geo_db_location" VALUES(32006,NULL,'Radnor, OH',13022,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32007,NULL,'Radnor, OH 43066',13022,222,NULL,35,18692,0);
INSERT INTO "django_geo_db_location" VALUES(32008,NULL,'Raymond, OH',13023,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32009,NULL,'Raymond, OH 43067',13023,222,NULL,35,18693,0);
INSERT INTO "django_geo_db_location" VALUES(32010,NULL,'Reynoldsburg, OH',13024,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32011,NULL,'Reynoldsburg, OH 43068',13024,222,NULL,35,18694,0);
INSERT INTO "django_geo_db_location" VALUES(32012,NULL,'Rosewood, OH',13025,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32013,NULL,'Rosewood, OH 43070',13025,222,NULL,35,18695,0);
INSERT INTO "django_geo_db_location" VALUES(32014,NULL,'Saint Louisville, OH',13026,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32015,NULL,'Saint Louisville, OH 43071',13026,222,NULL,35,18696,0);
INSERT INTO "django_geo_db_location" VALUES(32016,NULL,'Saint Paris, OH',13027,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32017,NULL,'Saint Paris, OH 43072',13027,222,NULL,35,18697,0);
INSERT INTO "django_geo_db_location" VALUES(32018,NULL,'Summit Station, OH',13028,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32019,NULL,'Summit Station, OH 43073',13028,222,NULL,35,18698,0);
INSERT INTO "django_geo_db_location" VALUES(32020,NULL,'Sunbury, OH',13029,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32021,NULL,'Sunbury, OH 43074',13029,222,NULL,35,18699,0);
INSERT INTO "django_geo_db_location" VALUES(32022,NULL,'Thornville, OH',13030,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32023,NULL,'Thornville, OH 43076',13030,222,NULL,35,18700,0);
INSERT INTO "django_geo_db_location" VALUES(32024,NULL,'Unionville Center, OH',13031,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32025,NULL,'Unionville Center, OH 43077',13031,222,NULL,35,18701,0);
INSERT INTO "django_geo_db_location" VALUES(32026,NULL,'Urbana, OH',13032,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32027,NULL,'Urbana, OH 43078',13032,222,NULL,35,18702,0);
INSERT INTO "django_geo_db_location" VALUES(32028,NULL,'Utica, OH',13033,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32029,NULL,'Utica, OH 43080',13033,222,NULL,35,18703,0);
INSERT INTO "django_geo_db_location" VALUES(32030,NULL,'Westerville, OH',13034,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32031,NULL,'Westerville, OH 43081',13034,222,NULL,35,18704,0);
INSERT INTO "django_geo_db_location" VALUES(32032,NULL,'Westerville, OH 43082',13034,222,NULL,35,18705,0);
INSERT INTO "django_geo_db_location" VALUES(32033,NULL,'Westville, OH',13035,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32034,NULL,'Westville, OH 43083',13035,222,NULL,35,18706,0);
INSERT INTO "django_geo_db_location" VALUES(32035,NULL,'Woodstock, OH',13036,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32036,NULL,'Woodstock, OH 43084',13036,222,NULL,35,18707,0);
INSERT INTO "django_geo_db_location" VALUES(32037,NULL,'Columbus, OH',13037,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32038,NULL,'Columbus, OH 43085',13037,222,NULL,35,18708,0);
INSERT INTO "django_geo_db_location" VALUES(32039,NULL,'Westerville, OH 43086',13034,222,NULL,35,18709,0);
INSERT INTO "django_geo_db_location" VALUES(32040,NULL,'Newark, OH 43093',13015,222,NULL,35,18710,0);
INSERT INTO "django_geo_db_location" VALUES(32041,NULL,'Hebron, OH 43098',12995,222,NULL,35,18711,0);
INSERT INTO "django_geo_db_location" VALUES(32042,NULL,'Adelphi, OH',13038,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32043,NULL,'Adelphi, OH 43101',13038,222,NULL,35,18712,0);
INSERT INTO "django_geo_db_location" VALUES(32044,NULL,'Amanda, OH',13039,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32045,NULL,'Amanda, OH 43102',13039,222,NULL,35,18713,0);
INSERT INTO "django_geo_db_location" VALUES(32046,NULL,'Ashville, OH',13040,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32047,NULL,'Ashville, OH 43103',13040,222,NULL,35,18714,0);
INSERT INTO "django_geo_db_location" VALUES(32048,NULL,'Baltimore, OH',13041,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32049,NULL,'Baltimore, OH 43105',13041,222,NULL,35,18715,0);
INSERT INTO "django_geo_db_location" VALUES(32050,NULL,'Bloomingburg, OH',13042,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32051,NULL,'Bloomingburg, OH 43106',13042,222,NULL,35,18716,0);
INSERT INTO "django_geo_db_location" VALUES(32052,NULL,'Bremen, OH',13043,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32053,NULL,'Bremen, OH 43107',13043,222,NULL,35,18717,0);
INSERT INTO "django_geo_db_location" VALUES(32054,NULL,'Brice, OH',13044,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32055,NULL,'Brice, OH 43109',13044,222,NULL,35,18718,0);
INSERT INTO "django_geo_db_location" VALUES(32056,NULL,'Canal Winchester, OH',13045,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32057,NULL,'Canal Winchester, OH 43110',13045,222,NULL,35,18719,0);
INSERT INTO "django_geo_db_location" VALUES(32058,NULL,'Carbon Hill, OH',13046,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32059,NULL,'Carbon Hill, OH 43111',13046,222,NULL,35,18720,0);
INSERT INTO "django_geo_db_location" VALUES(32060,NULL,'Carroll, OH',13047,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32061,NULL,'Carroll, OH 43112',13047,222,NULL,35,18721,0);
INSERT INTO "django_geo_db_location" VALUES(32062,NULL,'Circleville, OH',13048,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32063,NULL,'Circleville, OH 43113',13048,222,NULL,35,18722,0);
INSERT INTO "django_geo_db_location" VALUES(32064,NULL,'Clarksburg, OH',13049,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32065,NULL,'Clarksburg, OH 43115',13049,222,NULL,35,18723,0);
INSERT INTO "django_geo_db_location" VALUES(32066,NULL,'Commercial Point, OH',13050,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32067,NULL,'Commercial Point, OH 43116',13050,222,NULL,35,18724,0);
INSERT INTO "django_geo_db_location" VALUES(32068,NULL,'Derby, OH',13051,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32069,NULL,'Derby, OH 43117',13051,222,NULL,35,18725,0);
INSERT INTO "django_geo_db_location" VALUES(32070,NULL,'Galloway, OH',13052,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32071,NULL,'Galloway, OH 43119',13052,222,NULL,35,18726,0);
INSERT INTO "django_geo_db_location" VALUES(32072,NULL,'Grove City, OH',13053,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32073,NULL,'Grove City, OH 43123',13053,222,NULL,35,18727,0);
INSERT INTO "django_geo_db_location" VALUES(32074,NULL,'Groveport, OH',13054,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32075,NULL,'Groveport, OH 43125',13054,222,NULL,35,18728,0);
INSERT INTO "django_geo_db_location" VALUES(32076,NULL,'Harrisburg, OH',13055,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32077,NULL,'Harrisburg, OH 43126',13055,222,NULL,35,18729,0);
INSERT INTO "django_geo_db_location" VALUES(32078,NULL,'Haydenville, OH',13056,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32079,NULL,'Haydenville, OH 43127',13056,222,NULL,35,18730,0);
INSERT INTO "django_geo_db_location" VALUES(32080,NULL,'Jeffersonville, OH',13057,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32081,NULL,'Jeffersonville, OH 43128',13057,222,NULL,35,18731,0);
INSERT INTO "django_geo_db_location" VALUES(32082,NULL,'Lancaster, OH',13058,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32083,NULL,'Lancaster, OH 43130',13058,222,NULL,35,18732,0);
INSERT INTO "django_geo_db_location" VALUES(32084,NULL,'Laurelville, OH',13059,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32085,NULL,'Laurelville, OH 43135',13059,222,NULL,35,18733,0);
INSERT INTO "django_geo_db_location" VALUES(32086,NULL,'Lithopolis, OH',13060,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32087,NULL,'Lithopolis, OH 43136',13060,222,NULL,35,18734,0);
INSERT INTO "django_geo_db_location" VALUES(32088,NULL,'Lockbourne, OH',13061,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32089,NULL,'Lockbourne, OH 43137',13061,222,NULL,35,18735,0);
INSERT INTO "django_geo_db_location" VALUES(32090,NULL,'Logan, OH',13062,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32091,NULL,'Logan, OH 43138',13062,222,NULL,35,18736,0);
INSERT INTO "django_geo_db_location" VALUES(32092,NULL,'London, OH',13063,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32093,NULL,'London, OH 43140',13063,222,NULL,35,18737,0);
INSERT INTO "django_geo_db_location" VALUES(32094,NULL,'Milledgeville, OH',13064,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32095,NULL,'Milledgeville, OH 43142',13064,222,NULL,35,18738,0);
INSERT INTO "django_geo_db_location" VALUES(32096,NULL,'Mount Sterling, OH',13065,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32097,NULL,'Mount Sterling, OH 43143',13065,222,NULL,35,18739,0);
INSERT INTO "django_geo_db_location" VALUES(32098,NULL,'Murray City, OH',13066,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32099,NULL,'Murray City, OH 43144',13066,222,NULL,35,18740,0);
INSERT INTO "django_geo_db_location" VALUES(32100,NULL,'New Holland, OH',13067,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32101,NULL,'New Holland, OH 43145',13067,222,NULL,35,18741,0);
INSERT INTO "django_geo_db_location" VALUES(32102,NULL,'Orient, OH',13068,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32103,NULL,'Orient, OH 43146',13068,222,NULL,35,18742,0);
INSERT INTO "django_geo_db_location" VALUES(32104,NULL,'Pickerington, OH',13069,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32105,NULL,'Pickerington, OH 43147',13069,222,NULL,35,18743,0);
INSERT INTO "django_geo_db_location" VALUES(32106,NULL,'Pleasantville, OH',13070,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32107,NULL,'Pleasantville, OH 43148',13070,222,NULL,35,18744,0);
INSERT INTO "django_geo_db_location" VALUES(32108,NULL,'Rockbridge, OH',13071,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32109,NULL,'Rockbridge, OH 43149',13071,222,NULL,35,18745,0);
INSERT INTO "django_geo_db_location" VALUES(32110,NULL,'Rushville, OH',13072,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32111,NULL,'Rushville, OH 43150',13072,222,NULL,35,18746,0);
INSERT INTO "django_geo_db_location" VALUES(32112,NULL,'Sedalia, OH',13073,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32113,NULL,'Sedalia, OH 43151',13073,222,NULL,35,18747,0);
INSERT INTO "django_geo_db_location" VALUES(32114,NULL,'South Bloomingville, OH',13074,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32115,NULL,'South Bloomingville, OH 43152',13074,222,NULL,35,18748,0);
INSERT INTO "django_geo_db_location" VALUES(32116,NULL,'South Solon, OH',13075,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32117,NULL,'South Solon, OH 43153',13075,222,NULL,35,18749,0);
INSERT INTO "django_geo_db_location" VALUES(32118,NULL,'Stoutsville, OH',13076,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32119,NULL,'Stoutsville, OH 43154',13076,222,NULL,35,18750,0);
INSERT INTO "django_geo_db_location" VALUES(32120,NULL,'Sugar Grove, OH',13077,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32121,NULL,'Sugar Grove, OH 43155',13077,222,NULL,35,18751,0);
INSERT INTO "django_geo_db_location" VALUES(32122,NULL,'Tarlton, OH',13078,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32123,NULL,'Tarlton, OH 43156',13078,222,NULL,35,18752,0);
INSERT INTO "django_geo_db_location" VALUES(32124,NULL,'Thurston, OH',13079,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32125,NULL,'Thurston, OH 43157',13079,222,NULL,35,18753,0);
INSERT INTO "django_geo_db_location" VALUES(32126,NULL,'Union Furnace, OH',13080,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32127,NULL,'Union Furnace, OH 43158',13080,222,NULL,35,18754,0);
INSERT INTO "django_geo_db_location" VALUES(32128,NULL,'Washington Court House, OH',13081,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32129,NULL,'Washington Court House, OH 43160',13081,222,NULL,35,18755,0);
INSERT INTO "django_geo_db_location" VALUES(32130,NULL,'West Jefferson, OH',13082,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32131,NULL,'West Jefferson, OH 43162',13082,222,NULL,35,18756,0);
INSERT INTO "django_geo_db_location" VALUES(32132,NULL,'West Rushville, OH',13083,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32133,NULL,'West Rushville, OH 43163',13083,222,NULL,35,18757,0);
INSERT INTO "django_geo_db_location" VALUES(32134,NULL,'Williamsport, OH',13084,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32135,NULL,'Williamsport, OH 43164',13084,222,NULL,35,18758,0);
INSERT INTO "django_geo_db_location" VALUES(32136,NULL,'Pickerington, OH 43187',13069,222,NULL,35,18759,0);
INSERT INTO "django_geo_db_location" VALUES(32137,NULL,'Groveport, OH 43199',13054,222,NULL,35,18760,0);
INSERT INTO "django_geo_db_location" VALUES(32138,NULL,'Columbus, OH 43201',13037,222,NULL,35,18761,0);
INSERT INTO "django_geo_db_location" VALUES(32139,NULL,'Columbus, OH 43202',13037,222,NULL,35,18762,0);
INSERT INTO "django_geo_db_location" VALUES(32140,NULL,'Columbus, OH 43203',13037,222,NULL,35,18763,0);
INSERT INTO "django_geo_db_location" VALUES(32141,NULL,'Columbus, OH 43204',13037,222,NULL,35,18764,0);
INSERT INTO "django_geo_db_location" VALUES(32142,NULL,'Columbus, OH 43205',13037,222,NULL,35,18765,0);
INSERT INTO "django_geo_db_location" VALUES(32143,NULL,'Columbus, OH 43206',13037,222,NULL,35,18766,0);
INSERT INTO "django_geo_db_location" VALUES(32144,NULL,'Columbus, OH 43207',13037,222,NULL,35,18767,0);
INSERT INTO "django_geo_db_location" VALUES(32145,NULL,'Columbus, OH 43209',13037,222,NULL,35,18768,0);
INSERT INTO "django_geo_db_location" VALUES(32146,NULL,'Columbus, OH 43210',13037,222,NULL,35,18769,0);
INSERT INTO "django_geo_db_location" VALUES(32147,NULL,'Columbus, OH 43211',13037,222,NULL,35,18770,0);
INSERT INTO "django_geo_db_location" VALUES(32148,NULL,'Columbus, OH 43212',13037,222,NULL,35,18771,0);
INSERT INTO "django_geo_db_location" VALUES(32149,NULL,'Columbus, OH 43213',13037,222,NULL,35,18772,0);
INSERT INTO "django_geo_db_location" VALUES(32150,NULL,'Columbus, OH 43214',13037,222,NULL,35,18773,0);
INSERT INTO "django_geo_db_location" VALUES(32151,NULL,'Columbus, OH 43215',13037,222,NULL,35,18774,0);
INSERT INTO "django_geo_db_location" VALUES(32152,NULL,'Columbus, OH 43216',13037,222,NULL,35,18775,0);
INSERT INTO "django_geo_db_location" VALUES(32153,NULL,'Columbus, OH 43217',13037,222,NULL,35,18776,0);
INSERT INTO "django_geo_db_location" VALUES(32154,NULL,'Columbus, OH 43218',13037,222,NULL,35,18777,0);
INSERT INTO "django_geo_db_location" VALUES(32155,NULL,'Columbus, OH 43219',13037,222,NULL,35,18778,0);
INSERT INTO "django_geo_db_location" VALUES(32156,NULL,'Columbus, OH 43220',13037,222,NULL,35,18779,0);
INSERT INTO "django_geo_db_location" VALUES(32157,NULL,'Columbus, OH 43221',13037,222,NULL,35,18780,0);
INSERT INTO "django_geo_db_location" VALUES(32158,NULL,'Columbus, OH 43222',13037,222,NULL,35,18781,0);
INSERT INTO "django_geo_db_location" VALUES(32159,NULL,'Columbus, OH 43223',13037,222,NULL,35,18782,0);
INSERT INTO "django_geo_db_location" VALUES(32160,NULL,'Columbus, OH 43224',13037,222,NULL,35,18783,0);
INSERT INTO "django_geo_db_location" VALUES(32161,NULL,'Columbus, OH 43226',13037,222,NULL,35,18784,0);
INSERT INTO "django_geo_db_location" VALUES(32162,NULL,'Columbus, OH 43227',13037,222,NULL,35,18785,0);
INSERT INTO "django_geo_db_location" VALUES(32163,NULL,'Columbus, OH 43228',13037,222,NULL,35,18786,0);
INSERT INTO "django_geo_db_location" VALUES(32164,NULL,'Columbus, OH 43229',13037,222,NULL,35,18787,0);
INSERT INTO "django_geo_db_location" VALUES(32165,NULL,'Columbus, OH 43230',13037,222,NULL,35,18788,0);
INSERT INTO "django_geo_db_location" VALUES(32166,NULL,'Columbus, OH 43231',13037,222,NULL,35,18789,0);
INSERT INTO "django_geo_db_location" VALUES(32167,NULL,'Columbus, OH 43232',13037,222,NULL,35,18790,0);
INSERT INTO "django_geo_db_location" VALUES(32168,NULL,'Columbus, OH 43234',13037,222,NULL,35,18791,0);
INSERT INTO "django_geo_db_location" VALUES(32169,NULL,'Columbus, OH 43235',13037,222,NULL,35,18792,0);
INSERT INTO "django_geo_db_location" VALUES(32170,NULL,'Columbus, OH 43236',13037,222,NULL,35,18793,0);
INSERT INTO "django_geo_db_location" VALUES(32171,NULL,'Columbus, OH 43240',13037,222,NULL,35,18794,0);
INSERT INTO "django_geo_db_location" VALUES(32172,NULL,'Columbus, OH 43251',13037,222,NULL,35,18795,0);
INSERT INTO "django_geo_db_location" VALUES(32173,NULL,'Columbus, OH 43260',13037,222,NULL,35,18796,0);
INSERT INTO "django_geo_db_location" VALUES(32174,NULL,'Columbus, OH 43265',13037,222,NULL,35,18797,0);
INSERT INTO "django_geo_db_location" VALUES(32175,NULL,'Columbus, OH 43266',13037,222,NULL,35,18798,0);
INSERT INTO "django_geo_db_location" VALUES(32176,NULL,'Columbus, OH 43268',13037,222,NULL,35,18799,0);
INSERT INTO "django_geo_db_location" VALUES(32177,NULL,'Columbus, OH 43270',13037,222,NULL,35,18800,0);
INSERT INTO "django_geo_db_location" VALUES(32178,NULL,'Columbus, OH 43271',13037,222,NULL,35,18801,0);
INSERT INTO "django_geo_db_location" VALUES(32179,NULL,'Columbus, OH 43272',13037,222,NULL,35,18802,0);
INSERT INTO "django_geo_db_location" VALUES(32180,NULL,'Columbus, OH 43279',13037,222,NULL,35,18803,0);
INSERT INTO "django_geo_db_location" VALUES(32181,NULL,'Columbus, OH 43284',13037,222,NULL,35,18804,0);
INSERT INTO "django_geo_db_location" VALUES(32182,NULL,'Columbus, OH 43287',13037,222,NULL,35,18805,0);
INSERT INTO "django_geo_db_location" VALUES(32183,NULL,'Columbus, OH 43291',13037,222,NULL,35,18806,0);
INSERT INTO "django_geo_db_location" VALUES(32184,NULL,'Columbus, OH 43299',13037,222,NULL,35,18807,0);
INSERT INTO "django_geo_db_location" VALUES(32185,NULL,'Marion, OH',13085,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32186,NULL,'Marion, OH 43301',13085,222,NULL,35,18808,0);
INSERT INTO "django_geo_db_location" VALUES(32187,NULL,'Marion, OH 43302',13085,222,NULL,35,18809,0);
INSERT INTO "django_geo_db_location" VALUES(32188,NULL,'Marion, OH 43306',13085,222,NULL,35,18810,0);
INSERT INTO "django_geo_db_location" VALUES(32189,NULL,'Marion, OH 43307',13085,222,NULL,35,18811,0);
INSERT INTO "django_geo_db_location" VALUES(32190,NULL,'Belle Center, OH',13086,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32191,NULL,'Belle Center, OH 43310',13086,222,NULL,35,18812,0);
INSERT INTO "django_geo_db_location" VALUES(32192,NULL,'Bellefontaine, OH',13087,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32193,NULL,'Bellefontaine, OH 43311',13087,222,NULL,35,18813,0);
INSERT INTO "django_geo_db_location" VALUES(32194,NULL,'Caledonia, OH',13088,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32195,NULL,'Caledonia, OH 43314',13088,222,NULL,35,18814,0);
INSERT INTO "django_geo_db_location" VALUES(32196,NULL,'Cardington, OH',13089,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32197,NULL,'Cardington, OH 43315',13089,222,NULL,35,18815,0);
INSERT INTO "django_geo_db_location" VALUES(32198,NULL,'Carey, OH',13090,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32199,NULL,'Carey, OH 43316',13090,222,NULL,35,18816,0);
INSERT INTO "django_geo_db_location" VALUES(32200,NULL,'Chesterville, OH',13091,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32201,NULL,'Chesterville, OH 43317',13091,222,NULL,35,18817,0);
INSERT INTO "django_geo_db_location" VALUES(32202,NULL,'De Graff, OH',13092,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32203,NULL,'De Graff, OH 43318',13092,222,NULL,35,18818,0);
INSERT INTO "django_geo_db_location" VALUES(32204,NULL,'East Liberty, OH',13093,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32205,NULL,'East Liberty, OH 43319',13093,222,NULL,35,18819,0);
INSERT INTO "django_geo_db_location" VALUES(32206,NULL,'Edison, OH',13094,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32207,NULL,'Edison, OH 43320',13094,222,NULL,35,18820,0);
INSERT INTO "django_geo_db_location" VALUES(32208,NULL,'Fulton, OH',13095,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32209,NULL,'Fulton, OH 43321',13095,222,NULL,35,18821,0);
INSERT INTO "django_geo_db_location" VALUES(32210,NULL,'Green Camp, OH',13096,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32211,NULL,'Green Camp, OH 43322',13096,222,NULL,35,18822,0);
INSERT INTO "django_geo_db_location" VALUES(32212,NULL,'Harpster, OH',13097,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32213,NULL,'Harpster, OH 43323',13097,222,NULL,35,18823,0);
INSERT INTO "django_geo_db_location" VALUES(32214,NULL,'Huntsville, OH',13098,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32215,NULL,'Huntsville, OH 43324',13098,222,NULL,35,18824,0);
INSERT INTO "django_geo_db_location" VALUES(32216,NULL,'Iberia, OH',13099,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32217,NULL,'Iberia, OH 43325',13099,222,NULL,35,18825,0);
INSERT INTO "django_geo_db_location" VALUES(32218,NULL,'Kenton, OH',13100,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32219,NULL,'Kenton, OH 43326',13100,222,NULL,35,18826,0);
INSERT INTO "django_geo_db_location" VALUES(32220,NULL,'Kirby, OH',13101,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32221,NULL,'Kirby, OH 43330',13101,222,NULL,35,18827,0);
INSERT INTO "django_geo_db_location" VALUES(32222,NULL,'Lakeview, OH',13102,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32223,NULL,'Lakeview, OH 43331',13102,222,NULL,35,18828,0);
INSERT INTO "django_geo_db_location" VALUES(32224,NULL,'La Rue, OH',13103,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32225,NULL,'La Rue, OH 43332',13103,222,NULL,35,18829,0);
INSERT INTO "django_geo_db_location" VALUES(32226,NULL,'Lewistown, OH',13104,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32227,NULL,'Lewistown, OH 43333',13104,222,NULL,35,18830,0);
INSERT INTO "django_geo_db_location" VALUES(32228,NULL,'Marengo, OH',13105,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32229,NULL,'Marengo, OH 43334',13105,222,NULL,35,18831,0);
INSERT INTO "django_geo_db_location" VALUES(32230,NULL,'Martel, OH',13106,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32231,NULL,'Martel, OH 43335',13106,222,NULL,35,18832,0);
INSERT INTO "django_geo_db_location" VALUES(32232,NULL,'Middleburg, OH',13107,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32233,NULL,'Middleburg, OH 43336',13107,222,NULL,35,18833,0);
INSERT INTO "django_geo_db_location" VALUES(32234,NULL,'Morral, OH',13108,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32235,NULL,'Morral, OH 43337',13108,222,NULL,35,18834,0);
INSERT INTO "django_geo_db_location" VALUES(32236,NULL,'Mount Gilead, OH',13109,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32237,NULL,'Mount Gilead, OH 43338',13109,222,NULL,35,18835,0);
INSERT INTO "django_geo_db_location" VALUES(32238,NULL,'Mount Victory, OH',13110,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32239,NULL,'Mount Victory, OH 43340',13110,222,NULL,35,18836,0);
INSERT INTO "django_geo_db_location" VALUES(32240,NULL,'New Bloomington, OH',13111,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32241,NULL,'New Bloomington, OH 43341',13111,222,NULL,35,18837,0);
INSERT INTO "django_geo_db_location" VALUES(32242,NULL,'Prospect, OH',13112,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32243,NULL,'Prospect, OH 43342',13112,222,NULL,35,18838,0);
INSERT INTO "django_geo_db_location" VALUES(32244,NULL,'Quincy, OH',13113,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32245,NULL,'Quincy, OH 43343',13113,222,NULL,35,18839,0);
INSERT INTO "django_geo_db_location" VALUES(32246,NULL,'Richwood, OH',13114,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32247,NULL,'Richwood, OH 43344',13114,222,NULL,35,18840,0);
INSERT INTO "django_geo_db_location" VALUES(32248,NULL,'Ridgeway, OH',13115,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32249,NULL,'Ridgeway, OH 43345',13115,222,NULL,35,18841,0);
INSERT INTO "django_geo_db_location" VALUES(32250,NULL,'Roundhead, OH',13116,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32251,NULL,'Roundhead, OH 43346',13116,222,NULL,35,18842,0);
INSERT INTO "django_geo_db_location" VALUES(32252,NULL,'Rushsylvania, OH',13117,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32253,NULL,'Rushsylvania, OH 43347',13117,222,NULL,35,18843,0);
INSERT INTO "django_geo_db_location" VALUES(32254,NULL,'Russells Point, OH',13118,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32255,NULL,'Russells Point, OH 43348',13118,222,NULL,35,18844,0);
INSERT INTO "django_geo_db_location" VALUES(32256,NULL,'Shauck, OH',13119,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32257,NULL,'Shauck, OH 43349',13119,222,NULL,35,18845,0);
INSERT INTO "django_geo_db_location" VALUES(32258,NULL,'Sparta, OH',13120,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32259,NULL,'Sparta, OH 43350',13120,222,NULL,35,18846,0);
INSERT INTO "django_geo_db_location" VALUES(32260,NULL,'Upper Sandusky, OH',13121,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32261,NULL,'Upper Sandusky, OH 43351',13121,222,NULL,35,18847,0);
INSERT INTO "django_geo_db_location" VALUES(32262,NULL,'Ridgeville, OH',13122,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32263,NULL,'Ridgeville, OH 43355',13122,222,NULL,35,18848,0);
INSERT INTO "django_geo_db_location" VALUES(32264,NULL,'Waldo, OH',13123,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32265,NULL,'Waldo, OH 43356',13123,222,NULL,35,18849,0);
INSERT INTO "django_geo_db_location" VALUES(32266,NULL,'West Liberty, OH',13124,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32267,NULL,'West Liberty, OH 43357',13124,222,NULL,35,18850,0);
INSERT INTO "django_geo_db_location" VALUES(32268,NULL,'West Mansfield, OH',13125,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32269,NULL,'West Mansfield, OH 43358',13125,222,NULL,35,18851,0);
INSERT INTO "django_geo_db_location" VALUES(32270,NULL,'Wharton, OH',13126,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32271,NULL,'Wharton, OH 43359',13126,222,NULL,35,18852,0);
INSERT INTO "django_geo_db_location" VALUES(32272,NULL,'Zanesfield, OH',13127,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32273,NULL,'Zanesfield, OH 43360',13127,222,NULL,35,18853,0);
INSERT INTO "django_geo_db_location" VALUES(32274,NULL,'Stokes, OH',13128,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32275,NULL,'Stokes, OH 43381',13128,222,NULL,35,18854,0);
INSERT INTO "django_geo_db_location" VALUES(32276,NULL,'Danbury, OH',13129,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32277,NULL,'Danbury, OH 43400',13129,222,NULL,35,18855,0);
INSERT INTO "django_geo_db_location" VALUES(32278,NULL,'Bowling Green, OH',13130,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32279,NULL,'Bowling Green, OH 43402',13130,222,NULL,35,18856,0);
INSERT INTO "django_geo_db_location" VALUES(32280,NULL,'Bowling Green, OH 43403',13130,222,NULL,35,18857,0);
INSERT INTO "django_geo_db_location" VALUES(32281,NULL,'Bradner, OH',13131,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32282,NULL,'Bradner, OH 43406',13131,222,NULL,35,18858,0);
INSERT INTO "django_geo_db_location" VALUES(32283,NULL,'Burgoon, OH',13132,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32284,NULL,'Burgoon, OH 43407',13132,222,NULL,35,18859,0);
INSERT INTO "django_geo_db_location" VALUES(32285,NULL,'Clay Center, OH',13133,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32286,NULL,'Clay Center, OH 43408',13133,222,NULL,35,18860,0);
INSERT INTO "django_geo_db_location" VALUES(32287,NULL,'Clyde, OH',13134,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32288,NULL,'Clyde, OH 43410',13134,222,NULL,35,18861,0);
INSERT INTO "django_geo_db_location" VALUES(32289,NULL,'Curtice, OH',13135,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32290,NULL,'Curtice, OH 43412',13135,222,NULL,35,18862,0);
INSERT INTO "django_geo_db_location" VALUES(32291,NULL,'Cygnet, OH',13136,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32292,NULL,'Cygnet, OH 43413',13136,222,NULL,35,18863,0);
INSERT INTO "django_geo_db_location" VALUES(32293,NULL,'Dunbridge, OH',13137,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32294,NULL,'Dunbridge, OH 43414',13137,222,NULL,35,18864,0);
INSERT INTO "django_geo_db_location" VALUES(32295,NULL,'Elmore, OH',13138,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32296,NULL,'Elmore, OH 43416',13138,222,NULL,35,18865,0);
INSERT INTO "django_geo_db_location" VALUES(32297,NULL,'Fremont, OH',13139,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32298,NULL,'Fremont, OH 43420',13139,222,NULL,35,18866,0);
INSERT INTO "django_geo_db_location" VALUES(32299,NULL,'Genoa, OH',13140,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32300,NULL,'Genoa, OH 43430',13140,222,NULL,35,18867,0);
INSERT INTO "django_geo_db_location" VALUES(32301,NULL,'Gibsonburg, OH',13141,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32302,NULL,'Gibsonburg, OH 43431',13141,222,NULL,35,18868,0);
INSERT INTO "django_geo_db_location" VALUES(32303,NULL,'Graytown, OH',13142,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32304,NULL,'Graytown, OH 43432',13142,222,NULL,35,18869,0);
INSERT INTO "django_geo_db_location" VALUES(32305,NULL,'Gypsum, OH',13143,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32306,NULL,'Gypsum, OH 43433',13143,222,NULL,35,18870,0);
INSERT INTO "django_geo_db_location" VALUES(32307,NULL,'Harbor View, OH',13144,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32308,NULL,'Harbor View, OH 43434',13144,222,NULL,35,18871,0);
INSERT INTO "django_geo_db_location" VALUES(32309,NULL,'Helena, OH',13145,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32310,NULL,'Helena, OH 43435',13145,222,NULL,35,18872,0);
INSERT INTO "django_geo_db_location" VALUES(32311,NULL,'Isle Saint George, OH',13146,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32312,NULL,'Isle Saint George, OH 43436',13146,222,NULL,35,18873,0);
INSERT INTO "django_geo_db_location" VALUES(32313,NULL,'Jerry City, OH',13147,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32314,NULL,'Jerry City, OH 43437',13147,222,NULL,35,18874,0);
INSERT INTO "django_geo_db_location" VALUES(32315,NULL,'Kelleys Island, OH',13148,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32316,NULL,'Kelleys Island, OH 43438',13148,222,NULL,35,18875,0);
INSERT INTO "django_geo_db_location" VALUES(32317,NULL,'Lacarne, OH',13149,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32318,NULL,'Lacarne, OH 43439',13149,222,NULL,35,18876,0);
INSERT INTO "django_geo_db_location" VALUES(32319,NULL,'Lakeside Marblehead, OH',13150,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32320,NULL,'Lakeside Marblehead, OH 43440',13150,222,NULL,35,18877,0);
INSERT INTO "django_geo_db_location" VALUES(32321,NULL,'Lemoyne, OH',13151,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32322,NULL,'Lemoyne, OH 43441',13151,222,NULL,35,18878,0);
INSERT INTO "django_geo_db_location" VALUES(32323,NULL,'Lindsey, OH',13152,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32324,NULL,'Lindsey, OH 43442',13152,222,NULL,35,18879,0);
INSERT INTO "django_geo_db_location" VALUES(32325,NULL,'Luckey, OH',13153,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32326,NULL,'Luckey, OH 43443',13153,222,NULL,35,18880,0);
INSERT INTO "django_geo_db_location" VALUES(32327,NULL,'Martin, OH',13154,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32328,NULL,'Martin, OH 43445',13154,222,NULL,35,18881,0);
INSERT INTO "django_geo_db_location" VALUES(32329,NULL,'Middle Bass, OH',13155,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32330,NULL,'Middle Bass, OH 43446',13155,222,NULL,35,18882,0);
INSERT INTO "django_geo_db_location" VALUES(32331,NULL,'Millbury, OH',13156,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32332,NULL,'Millbury, OH 43447',13156,222,NULL,35,18883,0);
INSERT INTO "django_geo_db_location" VALUES(32333,NULL,'Oak Harbor, OH',13157,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32334,NULL,'Oak Harbor, OH 43449',13157,222,NULL,35,18884,0);
INSERT INTO "django_geo_db_location" VALUES(32335,NULL,'Pemberville, OH',13158,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32336,NULL,'Pemberville, OH 43450',13158,222,NULL,35,18885,0);
INSERT INTO "django_geo_db_location" VALUES(32337,NULL,'Portage, OH',13159,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32338,NULL,'Portage, OH 43451',13159,222,NULL,35,18886,0);
INSERT INTO "django_geo_db_location" VALUES(32339,NULL,'Port Clinton, OH',13160,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32340,NULL,'Port Clinton, OH 43452',13160,222,NULL,35,18887,0);
INSERT INTO "django_geo_db_location" VALUES(32341,NULL,'Put In Bay, OH',13161,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32342,NULL,'Put In Bay, OH 43456',13161,222,NULL,35,18888,0);
INSERT INTO "django_geo_db_location" VALUES(32343,NULL,'Risingsun, OH',13162,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32344,NULL,'Risingsun, OH 43457',13162,222,NULL,35,18889,0);
INSERT INTO "django_geo_db_location" VALUES(32345,NULL,'Rocky Ridge, OH',13163,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32346,NULL,'Rocky Ridge, OH 43458',13163,222,NULL,35,18890,0);
INSERT INTO "django_geo_db_location" VALUES(32347,NULL,'Rossford, OH',13164,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32348,NULL,'Rossford, OH 43460',13164,222,NULL,35,18891,0);
INSERT INTO "django_geo_db_location" VALUES(32349,NULL,'Rudolph, OH',13165,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32350,NULL,'Rudolph, OH 43462',13165,222,NULL,35,18892,0);
INSERT INTO "django_geo_db_location" VALUES(32351,NULL,'Stony Ridge, OH',13166,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32352,NULL,'Stony Ridge, OH 43463',13166,222,NULL,35,18893,0);
INSERT INTO "django_geo_db_location" VALUES(32353,NULL,'Vickery, OH',13167,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32354,NULL,'Vickery, OH 43464',13167,222,NULL,35,18894,0);
INSERT INTO "django_geo_db_location" VALUES(32355,NULL,'Walbridge, OH',13168,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32356,NULL,'Walbridge, OH 43465',13168,222,NULL,35,18895,0);
INSERT INTO "django_geo_db_location" VALUES(32357,NULL,'Wayne, OH',13169,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32358,NULL,'Wayne, OH 43466',13169,222,NULL,35,18896,0);
INSERT INTO "django_geo_db_location" VALUES(32359,NULL,'West Millgrove, OH',13170,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32360,NULL,'West Millgrove, OH 43467',13170,222,NULL,35,18897,0);
INSERT INTO "django_geo_db_location" VALUES(32361,NULL,'Williston, OH',13171,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32362,NULL,'Williston, OH 43468',13171,222,NULL,35,18898,0);
INSERT INTO "django_geo_db_location" VALUES(32363,NULL,'Woodville, OH',13172,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32364,NULL,'Woodville, OH 43469',13172,222,NULL,35,18899,0);
INSERT INTO "django_geo_db_location" VALUES(32365,NULL,'Alvordton, OH',13173,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32366,NULL,'Alvordton, OH 43501',13173,222,NULL,35,18900,0);
INSERT INTO "django_geo_db_location" VALUES(32367,NULL,'Archbold, OH',13174,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32368,NULL,'Archbold, OH 43502',13174,222,NULL,35,18901,0);
INSERT INTO "django_geo_db_location" VALUES(32369,NULL,'Berkey, OH',13175,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32370,NULL,'Berkey, OH 43504',13175,222,NULL,35,18902,0);
INSERT INTO "django_geo_db_location" VALUES(32371,NULL,'Blakeslee, OH',13176,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32372,NULL,'Blakeslee, OH 43505',13176,222,NULL,35,18903,0);
INSERT INTO "django_geo_db_location" VALUES(32373,NULL,'Bryan, OH',13177,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32374,NULL,'Bryan, OH 43506',13177,222,NULL,35,18904,0);
INSERT INTO "django_geo_db_location" VALUES(32375,NULL,'Colton, OH',13178,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32376,NULL,'Colton, OH 43510',13178,222,NULL,35,18905,0);
INSERT INTO "django_geo_db_location" VALUES(32377,NULL,'Custar, OH',13179,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32378,NULL,'Custar, OH 43511',13179,222,NULL,35,18906,0);
INSERT INTO "django_geo_db_location" VALUES(32379,NULL,'Defiance, OH',13180,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32380,NULL,'Defiance, OH 43512',13180,222,NULL,35,18907,0);
INSERT INTO "django_geo_db_location" VALUES(32381,NULL,'Delta, OH',13181,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32382,NULL,'Delta, OH 43515',13181,222,NULL,35,18908,0);
INSERT INTO "django_geo_db_location" VALUES(32383,NULL,'Deshler, OH',13182,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32384,NULL,'Deshler, OH 43516',13182,222,NULL,35,18909,0);
INSERT INTO "django_geo_db_location" VALUES(32385,NULL,'Edgerton, OH',13183,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32386,NULL,'Edgerton, OH 43517',13183,222,NULL,35,18910,0);
INSERT INTO "django_geo_db_location" VALUES(32387,NULL,'Edon, OH',13184,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32388,NULL,'Edon, OH 43518',13184,222,NULL,35,18911,0);
INSERT INTO "django_geo_db_location" VALUES(32389,NULL,'Evansport, OH',13185,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32390,NULL,'Evansport, OH 43519',13185,222,NULL,35,18912,0);
INSERT INTO "django_geo_db_location" VALUES(32391,NULL,'Farmer, OH',13186,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32392,NULL,'Farmer, OH 43520',13186,222,NULL,35,18913,0);
INSERT INTO "django_geo_db_location" VALUES(32393,NULL,'Fayette, OH',13187,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32394,NULL,'Fayette, OH 43521',13187,222,NULL,35,18914,0);
INSERT INTO "django_geo_db_location" VALUES(32395,NULL,'Grand Rapids, OH',13188,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32396,NULL,'Grand Rapids, OH 43522',13188,222,NULL,35,18915,0);
INSERT INTO "django_geo_db_location" VALUES(32397,NULL,'Grelton, OH',13189,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32398,NULL,'Grelton, OH 43523',13189,222,NULL,35,18916,0);
INSERT INTO "django_geo_db_location" VALUES(32399,NULL,'Hamler, OH',13190,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32400,NULL,'Hamler, OH 43524',13190,222,NULL,35,18917,0);
INSERT INTO "django_geo_db_location" VALUES(32401,NULL,'Haskins, OH',13191,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32402,NULL,'Haskins, OH 43525',13191,222,NULL,35,18918,0);
INSERT INTO "django_geo_db_location" VALUES(32403,NULL,'Hicksville, OH',13192,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32404,NULL,'Hicksville, OH 43526',13192,222,NULL,35,18919,0);
INSERT INTO "django_geo_db_location" VALUES(32405,NULL,'Holgate, OH',13193,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32406,NULL,'Holgate, OH 43527',13193,222,NULL,35,18920,0);
INSERT INTO "django_geo_db_location" VALUES(32407,NULL,'Holland, OH',13194,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32408,NULL,'Holland, OH 43528',13194,222,NULL,35,18921,0);
INSERT INTO "django_geo_db_location" VALUES(32409,NULL,'Hoytville, OH',13195,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32410,NULL,'Hoytville, OH 43529',13195,222,NULL,35,18922,0);
INSERT INTO "django_geo_db_location" VALUES(32411,NULL,'Jewell, OH',13196,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32412,NULL,'Jewell, OH 43530',13196,222,NULL,35,18923,0);
INSERT INTO "django_geo_db_location" VALUES(32413,NULL,'Kunkle, OH',13197,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32414,NULL,'Kunkle, OH 43531',13197,222,NULL,35,18924,0);
INSERT INTO "django_geo_db_location" VALUES(32415,NULL,'Liberty Center, OH',13198,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32416,NULL,'Liberty Center, OH 43532',13198,222,NULL,35,18925,0);
INSERT INTO "django_geo_db_location" VALUES(32417,NULL,'Lyons, OH',13199,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32418,NULL,'Lyons, OH 43533',13199,222,NULL,35,18926,0);
INSERT INTO "django_geo_db_location" VALUES(32419,NULL,'McClure, OH',13200,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32420,NULL,'McClure, OH 43534',13200,222,NULL,35,18927,0);
INSERT INTO "django_geo_db_location" VALUES(32421,NULL,'Malinta, OH',13201,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32422,NULL,'Malinta, OH 43535',13201,222,NULL,35,18928,0);
INSERT INTO "django_geo_db_location" VALUES(32423,NULL,'Mark Center, OH',13202,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32424,NULL,'Mark Center, OH 43536',13202,222,NULL,35,18929,0);
INSERT INTO "django_geo_db_location" VALUES(32425,NULL,'Maumee, OH',13203,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32426,NULL,'Maumee, OH 43537',13203,222,NULL,35,18930,0);
INSERT INTO "django_geo_db_location" VALUES(32427,NULL,'Monclova, OH',13204,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32428,NULL,'Monclova, OH 43538',13204,222,NULL,35,18931,0);
INSERT INTO "django_geo_db_location" VALUES(32429,NULL,'Metamora, OH',13205,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32430,NULL,'Metamora, OH 43540',13205,222,NULL,35,18932,0);
INSERT INTO "django_geo_db_location" VALUES(32431,NULL,'Milton Center, OH',13206,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32432,NULL,'Milton Center, OH 43541',13206,222,NULL,35,18933,0);
INSERT INTO "django_geo_db_location" VALUES(32433,NULL,'Monclova, OH 43542',13204,222,NULL,35,18934,0);
INSERT INTO "django_geo_db_location" VALUES(32434,NULL,'Montpelier, OH',13207,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32435,NULL,'Montpelier, OH 43543',13207,222,NULL,35,18935,0);
INSERT INTO "django_geo_db_location" VALUES(32436,NULL,'Napoleon, OH',13208,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32437,NULL,'Napoleon, OH 43545',13208,222,NULL,35,18936,0);
INSERT INTO "django_geo_db_location" VALUES(32438,NULL,'Neapolis, OH',13209,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32439,NULL,'Neapolis, OH 43547',13209,222,NULL,35,18937,0);
INSERT INTO "django_geo_db_location" VALUES(32440,NULL,'New Bavaria, OH',13210,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32441,NULL,'New Bavaria, OH 43548',13210,222,NULL,35,18938,0);
INSERT INTO "django_geo_db_location" VALUES(32442,NULL,'Ney, OH',13211,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32443,NULL,'Ney, OH 43549',13211,222,NULL,35,18939,0);
INSERT INTO "django_geo_db_location" VALUES(32444,NULL,'Okolona, OH',13212,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32445,NULL,'Okolona, OH 43550',13212,222,NULL,35,18940,0);
INSERT INTO "django_geo_db_location" VALUES(32446,NULL,'Perrysburg, OH',13213,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32447,NULL,'Perrysburg, OH 43551',13213,222,NULL,35,18941,0);
INSERT INTO "django_geo_db_location" VALUES(32448,NULL,'Perrysburg, OH 43552',13213,222,NULL,35,18942,0);
INSERT INTO "django_geo_db_location" VALUES(32449,NULL,'Pettisville, OH',13214,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32450,NULL,'Pettisville, OH 43553',13214,222,NULL,35,18943,0);
INSERT INTO "django_geo_db_location" VALUES(32451,NULL,'Pioneer, OH',13215,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32452,NULL,'Pioneer, OH 43554',13215,222,NULL,35,18944,0);
INSERT INTO "django_geo_db_location" VALUES(32453,NULL,'Ridgeville Corners, OH',13216,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32454,NULL,'Ridgeville Corners, OH 43555',13216,222,NULL,35,18945,0);
INSERT INTO "django_geo_db_location" VALUES(32455,NULL,'Sherwood, OH',13217,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32456,NULL,'Sherwood, OH 43556',13217,222,NULL,35,18946,0);
INSERT INTO "django_geo_db_location" VALUES(32457,NULL,'Stryker, OH',13218,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32458,NULL,'Stryker, OH 43557',13218,222,NULL,35,18947,0);
INSERT INTO "django_geo_db_location" VALUES(32459,NULL,'Swanton, OH',13219,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32460,NULL,'Swanton, OH 43558',13219,222,NULL,35,18948,0);
INSERT INTO "django_geo_db_location" VALUES(32461,NULL,'Sylvania, OH',13220,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32462,NULL,'Sylvania, OH 43560',13220,222,NULL,35,18949,0);
INSERT INTO "django_geo_db_location" VALUES(32463,NULL,'Tontogany, OH',13221,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32464,NULL,'Tontogany, OH 43565',13221,222,NULL,35,18950,0);
INSERT INTO "django_geo_db_location" VALUES(32465,NULL,'Waterville, OH',13222,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32466,NULL,'Waterville, OH 43566',13222,222,NULL,35,18951,0);
INSERT INTO "django_geo_db_location" VALUES(32467,NULL,'Wauseon, OH',13223,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32468,NULL,'Wauseon, OH 43567',13223,222,NULL,35,18952,0);
INSERT INTO "django_geo_db_location" VALUES(32469,NULL,'Weston, OH',13224,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32470,NULL,'Weston, OH 43569',13224,222,NULL,35,18953,0);
INSERT INTO "django_geo_db_location" VALUES(32471,NULL,'West Unity, OH',13225,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32472,NULL,'West Unity, OH 43570',13225,222,NULL,35,18954,0);
INSERT INTO "django_geo_db_location" VALUES(32473,NULL,'Whitehouse, OH',13226,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32474,NULL,'Whitehouse, OH 43571',13226,222,NULL,35,18955,0);
INSERT INTO "django_geo_db_location" VALUES(32475,NULL,'Tiffin, OH',13227,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32476,NULL,'Tiffin, OH 43579',13227,222,NULL,35,18956,0);
INSERT INTO "django_geo_db_location" VALUES(32477,NULL,'Toledo, OH',13228,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32478,NULL,'Toledo, OH 43601',13228,222,NULL,35,18957,0);
INSERT INTO "django_geo_db_location" VALUES(32479,NULL,'Toledo, OH 43602',13228,222,NULL,35,18958,0);
INSERT INTO "django_geo_db_location" VALUES(32480,NULL,'Toledo, OH 43603',13228,222,NULL,35,18959,0);
INSERT INTO "django_geo_db_location" VALUES(32481,NULL,'Toledo, OH 43604',13228,222,NULL,35,18960,0);
INSERT INTO "django_geo_db_location" VALUES(32482,NULL,'Toledo, OH 43605',13228,222,NULL,35,18961,0);
INSERT INTO "django_geo_db_location" VALUES(32483,NULL,'Toledo, OH 43606',13228,222,NULL,35,18962,0);
INSERT INTO "django_geo_db_location" VALUES(32484,NULL,'Toledo, OH 43607',13228,222,NULL,35,18963,0);
INSERT INTO "django_geo_db_location" VALUES(32485,NULL,'Toledo, OH 43608',13228,222,NULL,35,18964,0);
INSERT INTO "django_geo_db_location" VALUES(32486,NULL,'Toledo, OH 43609',13228,222,NULL,35,18965,0);
INSERT INTO "django_geo_db_location" VALUES(32487,NULL,'Toledo, OH 43610',13228,222,NULL,35,18966,0);
INSERT INTO "django_geo_db_location" VALUES(32488,NULL,'Toledo, OH 43611',13228,222,NULL,35,18967,0);
INSERT INTO "django_geo_db_location" VALUES(32489,NULL,'Toledo, OH 43612',13228,222,NULL,35,18968,0);
INSERT INTO "django_geo_db_location" VALUES(32490,NULL,'Toledo, OH 43613',13228,222,NULL,35,18969,0);
INSERT INTO "django_geo_db_location" VALUES(32491,NULL,'Toledo, OH 43614',13228,222,NULL,35,18970,0);
INSERT INTO "django_geo_db_location" VALUES(32492,NULL,'Toledo, OH 43615',13228,222,NULL,35,18971,0);
INSERT INTO "django_geo_db_location" VALUES(32493,NULL,'Oregon, OH',13229,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32494,NULL,'Oregon, OH 43616',13229,222,NULL,35,18972,0);
INSERT INTO "django_geo_db_location" VALUES(32495,NULL,'Toledo, OH 43617',13228,222,NULL,35,18973,0);
INSERT INTO "django_geo_db_location" VALUES(32496,NULL,'Oregon, OH 43618',13229,222,NULL,35,18974,0);
INSERT INTO "django_geo_db_location" VALUES(32497,NULL,'Northwood, OH',13230,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32498,NULL,'Northwood, OH 43619',13230,222,NULL,35,18975,0);
INSERT INTO "django_geo_db_location" VALUES(32499,NULL,'Toledo, OH 43620',13228,222,NULL,35,18976,0);
INSERT INTO "django_geo_db_location" VALUES(32500,NULL,'Toledo, OH 43623',13228,222,NULL,35,18977,0);
INSERT INTO "django_geo_db_location" VALUES(32501,NULL,'Toledo, OH 43624',13228,222,NULL,35,18978,0);
INSERT INTO "django_geo_db_location" VALUES(32502,NULL,'Howard, OH 43628',12998,222,NULL,35,18979,0);
INSERT INTO "django_geo_db_location" VALUES(32503,NULL,'Toledo, OH 43635',13228,222,NULL,35,18980,0);
INSERT INTO "django_geo_db_location" VALUES(32504,NULL,'Toledo, OH 43652',13228,222,NULL,35,18981,0);
INSERT INTO "django_geo_db_location" VALUES(32505,NULL,'Toledo, OH 43653',13228,222,NULL,35,18982,0);
INSERT INTO "django_geo_db_location" VALUES(32506,NULL,'Toledo, OH 43654',13228,222,NULL,35,18983,0);
INSERT INTO "django_geo_db_location" VALUES(32507,NULL,'Toledo, OH 43655',13228,222,NULL,35,18984,0);
INSERT INTO "django_geo_db_location" VALUES(32508,NULL,'Toledo, OH 43656',13228,222,NULL,35,18985,0);
INSERT INTO "django_geo_db_location" VALUES(32509,NULL,'Toledo, OH 43657',13228,222,NULL,35,18986,0);
INSERT INTO "django_geo_db_location" VALUES(32510,NULL,'Toledo, OH 43659',13228,222,NULL,35,18987,0);
INSERT INTO "django_geo_db_location" VALUES(32511,NULL,'Toledo, OH 43660',13228,222,NULL,35,18988,0);
INSERT INTO "django_geo_db_location" VALUES(32512,NULL,'Toledo, OH 43661',13228,222,NULL,35,18989,0);
INSERT INTO "django_geo_db_location" VALUES(32513,NULL,'Toledo, OH 43666',13228,222,NULL,35,18990,0);
INSERT INTO "django_geo_db_location" VALUES(32514,NULL,'Toledo, OH 43667',13228,222,NULL,35,18991,0);
INSERT INTO "django_geo_db_location" VALUES(32515,NULL,'Toledo, OH 43681',13228,222,NULL,35,18992,0);
INSERT INTO "django_geo_db_location" VALUES(32516,NULL,'Toledo, OH 43682',13228,222,NULL,35,18993,0);
INSERT INTO "django_geo_db_location" VALUES(32517,NULL,'Toledo, OH 43697',13228,222,NULL,35,18994,0);
INSERT INTO "django_geo_db_location" VALUES(32518,NULL,'Toledo, OH 43699',13228,222,NULL,35,18995,0);
INSERT INTO "django_geo_db_location" VALUES(32519,NULL,'Zanesville, OH',13231,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32520,NULL,'Zanesville, OH 43701',13231,222,NULL,35,18996,0);
INSERT INTO "django_geo_db_location" VALUES(32521,NULL,'Zanesville, OH 43702',13231,222,NULL,35,18997,0);
INSERT INTO "django_geo_db_location" VALUES(32522,NULL,'Columbus, OH 43704',13037,222,NULL,35,18998,0);
INSERT INTO "django_geo_db_location" VALUES(32523,NULL,'Wayne, OH 43708',13169,222,NULL,35,18999,0);
INSERT INTO "django_geo_db_location" VALUES(32524,NULL,'Ava, OH',13232,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32525,NULL,'Ava, OH 43711',13232,222,NULL,35,19000,0);
INSERT INTO "django_geo_db_location" VALUES(32526,NULL,'Barnesville, OH',13233,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32527,NULL,'Barnesville, OH 43713',13233,222,NULL,35,19001,0);
INSERT INTO "django_geo_db_location" VALUES(32528,NULL,'Beallsville, OH',13234,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32529,NULL,'Beallsville, OH 43716',13234,222,NULL,35,19002,0);
INSERT INTO "django_geo_db_location" VALUES(32530,NULL,'Belle Valley, OH',13235,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32531,NULL,'Belle Valley, OH 43717',13235,222,NULL,35,19003,0);
INSERT INTO "django_geo_db_location" VALUES(32532,NULL,'Belmont, OH',13236,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32533,NULL,'Belmont, OH 43718',13236,222,NULL,35,19004,0);
INSERT INTO "django_geo_db_location" VALUES(32534,NULL,'Bethesda, OH',13237,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32535,NULL,'Bethesda, OH 43719',13237,222,NULL,35,19005,0);
INSERT INTO "django_geo_db_location" VALUES(32536,NULL,'Blue Rock, OH',13238,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32537,NULL,'Blue Rock, OH 43720',13238,222,NULL,35,19006,0);
INSERT INTO "django_geo_db_location" VALUES(32538,NULL,'Brownsville, OH',13239,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32539,NULL,'Brownsville, OH 43721',13239,222,NULL,35,19007,0);
INSERT INTO "django_geo_db_location" VALUES(32540,NULL,'Buffalo, OH',13240,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32541,NULL,'Buffalo, OH 43722',13240,222,NULL,35,19008,0);
INSERT INTO "django_geo_db_location" VALUES(32542,NULL,'Byesville, OH',13241,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32543,NULL,'Byesville, OH 43723',13241,222,NULL,35,19009,0);
INSERT INTO "django_geo_db_location" VALUES(32544,NULL,'Caldwell, OH',13242,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32545,NULL,'Caldwell, OH 43724',13242,222,NULL,35,19010,0);
INSERT INTO "django_geo_db_location" VALUES(32546,NULL,'Cambridge, OH',13243,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32547,NULL,'Cambridge, OH 43725',13243,222,NULL,35,19011,0);
INSERT INTO "django_geo_db_location" VALUES(32548,NULL,'Chandlersville, OH',13244,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32549,NULL,'Chandlersville, OH 43727',13244,222,NULL,35,19012,0);
INSERT INTO "django_geo_db_location" VALUES(32550,NULL,'Chesterhill, OH',13245,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32551,NULL,'Chesterhill, OH 43728',13245,222,NULL,35,19013,0);
INSERT INTO "django_geo_db_location" VALUES(32552,NULL,'Corning, OH',13246,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32553,NULL,'Corning, OH 43730',13246,222,NULL,35,19014,0);
INSERT INTO "django_geo_db_location" VALUES(32554,NULL,'Crooksville, OH',13247,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32555,NULL,'Crooksville, OH 43731',13247,222,NULL,35,19015,0);
INSERT INTO "django_geo_db_location" VALUES(32556,NULL,'Cumberland, OH',13248,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32557,NULL,'Cumberland, OH 43732',13248,222,NULL,35,19016,0);
INSERT INTO "django_geo_db_location" VALUES(32558,NULL,'Derwent, OH',13249,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32559,NULL,'Derwent, OH 43733',13249,222,NULL,35,19017,0);
INSERT INTO "django_geo_db_location" VALUES(32560,NULL,'Duncan Falls, OH',13250,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32561,NULL,'Duncan Falls, OH 43734',13250,222,NULL,35,19018,0);
INSERT INTO "django_geo_db_location" VALUES(32562,NULL,'East Fultonham, OH',13251,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32563,NULL,'East Fultonham, OH 43735',13251,222,NULL,35,19019,0);
INSERT INTO "django_geo_db_location" VALUES(32564,NULL,'Fairview, OH',13252,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32565,NULL,'Fairview, OH 43736',13252,222,NULL,35,19020,0);
INSERT INTO "django_geo_db_location" VALUES(32566,NULL,'Fultonham, OH',13253,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32567,NULL,'Fultonham, OH 43738',13253,222,NULL,35,19021,0);
INSERT INTO "django_geo_db_location" VALUES(32568,NULL,'Glenford, OH',13254,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32569,NULL,'Glenford, OH 43739',13254,222,NULL,35,19022,0);
INSERT INTO "django_geo_db_location" VALUES(32570,NULL,'Gratiot, OH',13255,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32571,NULL,'Gratiot, OH 43740',13255,222,NULL,35,19023,0);
INSERT INTO "django_geo_db_location" VALUES(32572,NULL,'Wayne, OH 43741',13169,222,NULL,35,19024,0);
INSERT INTO "django_geo_db_location" VALUES(32573,NULL,'Hopewell, OH',13256,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32574,NULL,'Hopewell, OH 43746',13256,222,NULL,35,19025,0);
INSERT INTO "django_geo_db_location" VALUES(32575,NULL,'Jerusalem, OH',13257,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32576,NULL,'Jerusalem, OH 43747',13257,222,NULL,35,19026,0);
INSERT INTO "django_geo_db_location" VALUES(32577,NULL,'Junction City, OH',13258,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32578,NULL,'Junction City, OH 43748',13258,222,NULL,35,19027,0);
INSERT INTO "django_geo_db_location" VALUES(32579,NULL,'Kimbolton, OH',13259,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32580,NULL,'Kimbolton, OH 43749',13259,222,NULL,35,19028,0);
INSERT INTO "django_geo_db_location" VALUES(32581,NULL,'Kipling, OH',13260,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32582,NULL,'Kipling, OH 43750',13260,222,NULL,35,19029,0);
INSERT INTO "django_geo_db_location" VALUES(32583,NULL,'Laings, OH',13261,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32584,NULL,'Laings, OH 43752',13261,222,NULL,35,19030,0);
INSERT INTO "django_geo_db_location" VALUES(32585,NULL,'Lewisville, OH',13262,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32586,NULL,'Lewisville, OH 43754',13262,222,NULL,35,19031,0);
INSERT INTO "django_geo_db_location" VALUES(32587,NULL,'Lore City, OH',13263,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32588,NULL,'Lore City, OH 43755',13263,222,NULL,35,19032,0);
INSERT INTO "django_geo_db_location" VALUES(32589,NULL,'McConnelsville, OH',13264,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32590,NULL,'McConnelsville, OH 43756',13264,222,NULL,35,19033,0);
INSERT INTO "django_geo_db_location" VALUES(32591,NULL,'Malaga, OH',13265,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32592,NULL,'Malaga, OH 43757',13265,222,NULL,35,19034,0);
INSERT INTO "django_geo_db_location" VALUES(32593,NULL,'Malta, OH',13266,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32594,NULL,'Malta, OH 43758',13266,222,NULL,35,19035,0);
INSERT INTO "django_geo_db_location" VALUES(32595,NULL,'Morristown, OH',13267,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32596,NULL,'Morristown, OH 43759',13267,222,NULL,35,19036,0);
INSERT INTO "django_geo_db_location" VALUES(32597,NULL,'Mount Perry, OH',13268,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32598,NULL,'Mount Perry, OH 43760',13268,222,NULL,35,19037,0);
INSERT INTO "django_geo_db_location" VALUES(32599,NULL,'Moxahala, OH',13269,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32600,NULL,'Moxahala, OH 43761',13269,222,NULL,35,19038,0);
INSERT INTO "django_geo_db_location" VALUES(32601,NULL,'New Concord, OH',13270,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32602,NULL,'New Concord, OH 43762',13270,222,NULL,35,19039,0);
INSERT INTO "django_geo_db_location" VALUES(32603,NULL,'New Lexington, OH',13271,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32604,NULL,'New Lexington, OH 43764',13271,222,NULL,35,19040,0);
INSERT INTO "django_geo_db_location" VALUES(32605,NULL,'New Straitsville, OH',13272,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32606,NULL,'New Straitsville, OH 43766',13272,222,NULL,35,19041,0);
INSERT INTO "django_geo_db_location" VALUES(32607,NULL,'Norwich, OH',13273,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32608,NULL,'Norwich, OH 43767',13273,222,NULL,35,19042,0);
INSERT INTO "django_geo_db_location" VALUES(32609,NULL,'Old Washington, OH',13274,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32610,NULL,'Old Washington, OH 43768',13274,222,NULL,35,19043,0);
INSERT INTO "django_geo_db_location" VALUES(32611,NULL,'Philo, OH',13275,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32612,NULL,'Philo, OH 43771',13275,222,NULL,35,19044,0);
INSERT INTO "django_geo_db_location" VALUES(32613,NULL,'Pleasant City, OH',13276,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32614,NULL,'Pleasant City, OH 43772',13276,222,NULL,35,19045,0);
INSERT INTO "django_geo_db_location" VALUES(32615,NULL,'Quaker City, OH',13277,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32616,NULL,'Quaker City, OH 43773',13277,222,NULL,35,19046,0);
INSERT INTO "django_geo_db_location" VALUES(32617,NULL,'Roseville, OH',13278,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32618,NULL,'Roseville, OH 43777',13278,222,NULL,35,19047,0);
INSERT INTO "django_geo_db_location" VALUES(32619,NULL,'Salesville, OH',13279,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32620,NULL,'Salesville, OH 43778',13279,222,NULL,35,19048,0);
INSERT INTO "django_geo_db_location" VALUES(32621,NULL,'Sarahsville, OH',13280,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32622,NULL,'Sarahsville, OH 43779',13280,222,NULL,35,19049,0);
INSERT INTO "django_geo_db_location" VALUES(32623,NULL,'Senecaville, OH',13281,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32624,NULL,'Senecaville, OH 43780',13281,222,NULL,35,19050,0);
INSERT INTO "django_geo_db_location" VALUES(32625,NULL,'Shawnee, OH',13282,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32626,NULL,'Shawnee, OH 43782',13282,222,NULL,35,19051,0);
INSERT INTO "django_geo_db_location" VALUES(32627,NULL,'Somerset, OH',13283,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32628,NULL,'Somerset, OH 43783',13283,222,NULL,35,19052,0);
INSERT INTO "django_geo_db_location" VALUES(32629,NULL,'Stafford, OH',13284,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32630,NULL,'Stafford, OH 43786',13284,222,NULL,35,19053,0);
INSERT INTO "django_geo_db_location" VALUES(32631,NULL,'Stockport, OH',13285,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32632,NULL,'Stockport, OH 43787',13285,222,NULL,35,19054,0);
INSERT INTO "django_geo_db_location" VALUES(32633,NULL,'Summerfield, OH',13286,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32634,NULL,'Summerfield, OH 43788',13286,222,NULL,35,19055,0);
INSERT INTO "django_geo_db_location" VALUES(32635,NULL,'Sycamore Valley, OH',13287,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32636,NULL,'Sycamore Valley, OH 43789',13287,222,NULL,35,19056,0);
INSERT INTO "django_geo_db_location" VALUES(32637,NULL,'White Cottage, OH',13288,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32638,NULL,'White Cottage, OH 43791',13288,222,NULL,35,19057,0);
INSERT INTO "django_geo_db_location" VALUES(32639,NULL,'Woodsfield, OH',13289,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32640,NULL,'Woodsfield, OH 43793',13289,222,NULL,35,19058,0);
INSERT INTO "django_geo_db_location" VALUES(32641,NULL,'Center, OH',13290,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32642,NULL,'Center, OH 43799',13290,222,NULL,35,19059,0);
INSERT INTO "django_geo_db_location" VALUES(32643,NULL,'Adamsville, OH',13291,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32644,NULL,'Adamsville, OH 43802',13291,222,NULL,35,19060,0);
INSERT INTO "django_geo_db_location" VALUES(32645,NULL,'Bakersville, OH',13292,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32646,NULL,'Bakersville, OH 43803',13292,222,NULL,35,19061,0);
INSERT INTO "django_geo_db_location" VALUES(32647,NULL,'Baltic, OH',13293,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32648,NULL,'Baltic, OH 43804',13293,222,NULL,35,19062,0);
INSERT INTO "django_geo_db_location" VALUES(32649,NULL,'Blissfield, OH',13294,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32650,NULL,'Blissfield, OH 43805',13294,222,NULL,35,19063,0);
INSERT INTO "django_geo_db_location" VALUES(32651,NULL,'Conesville, OH',13295,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32652,NULL,'Conesville, OH 43811',13295,222,NULL,35,19064,0);
INSERT INTO "django_geo_db_location" VALUES(32653,NULL,'Coshocton, OH',13296,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32654,NULL,'Coshocton, OH 43812',13296,222,NULL,35,19065,0);
INSERT INTO "django_geo_db_location" VALUES(32655,NULL,'Dresden, OH',13297,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32656,NULL,'Dresden, OH 43821',13297,222,NULL,35,19066,0);
INSERT INTO "django_geo_db_location" VALUES(32657,NULL,'Frazeysburg, OH',13298,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32658,NULL,'Frazeysburg, OH 43822',13298,222,NULL,35,19067,0);
INSERT INTO "django_geo_db_location" VALUES(32659,NULL,'Fresno, OH',13299,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32660,NULL,'Fresno, OH 43824',13299,222,NULL,35,19068,0);
INSERT INTO "django_geo_db_location" VALUES(32661,NULL,'Keene, OH',13300,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32662,NULL,'Keene, OH 43828',13300,222,NULL,35,19069,0);
INSERT INTO "django_geo_db_location" VALUES(32663,NULL,'Nashport, OH',13301,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32664,NULL,'Nashport, OH 43830',13301,222,NULL,35,19070,0);
INSERT INTO "django_geo_db_location" VALUES(32665,NULL,'Newcomerstown, OH',13302,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32666,NULL,'Newcomerstown, OH 43832',13302,222,NULL,35,19071,0);
INSERT INTO "django_geo_db_location" VALUES(32667,NULL,'Plainfield, OH',13303,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32668,NULL,'Plainfield, OH 43836',13303,222,NULL,35,19072,0);
INSERT INTO "django_geo_db_location" VALUES(32669,NULL,'Port Washington, OH',13304,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32670,NULL,'Port Washington, OH 43837',13304,222,NULL,35,19073,0);
INSERT INTO "django_geo_db_location" VALUES(32671,NULL,'Stone Creek, OH',13305,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32672,NULL,'Stone Creek, OH 43840',13305,222,NULL,35,19074,0);
INSERT INTO "django_geo_db_location" VALUES(32673,NULL,'Trinway, OH',13306,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32674,NULL,'Trinway, OH 43842',13306,222,NULL,35,19075,0);
INSERT INTO "django_geo_db_location" VALUES(32675,NULL,'Walhonding, OH',13307,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32676,NULL,'Walhonding, OH 43843',13307,222,NULL,35,19076,0);
INSERT INTO "django_geo_db_location" VALUES(32677,NULL,'Warsaw, OH',13308,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32678,NULL,'Warsaw, OH 43844',13308,222,NULL,35,19077,0);
INSERT INTO "django_geo_db_location" VALUES(32679,NULL,'West Lafayette, OH',13309,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32680,NULL,'West Lafayette, OH 43845',13309,222,NULL,35,19078,0);
INSERT INTO "django_geo_db_location" VALUES(32681,NULL,'Adena, OH',13310,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32682,NULL,'Adena, OH 43901',13310,222,NULL,35,19079,0);
INSERT INTO "django_geo_db_location" VALUES(32683,NULL,'Alledonia, OH',13311,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32684,NULL,'Alledonia, OH 43902',13311,222,NULL,35,19080,0);
INSERT INTO "django_geo_db_location" VALUES(32685,NULL,'Amsterdam, OH',13312,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32686,NULL,'Amsterdam, OH 43903',13312,222,NULL,35,19081,0);
INSERT INTO "django_geo_db_location" VALUES(32687,NULL,'Barton, OH',13313,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32688,NULL,'Barton, OH 43905',13313,222,NULL,35,19082,0);
INSERT INTO "django_geo_db_location" VALUES(32689,NULL,'Bellaire, OH',13314,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32690,NULL,'Bellaire, OH 43906',13314,222,NULL,35,19083,0);
INSERT INTO "django_geo_db_location" VALUES(32691,NULL,'Cadiz, OH',13315,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32692,NULL,'Cadiz, OH 43907',13315,222,NULL,35,19084,0);
INSERT INTO "django_geo_db_location" VALUES(32693,NULL,'Bergholz, OH',13316,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32694,NULL,'Bergholz, OH 43908',13316,222,NULL,35,19085,0);
INSERT INTO "django_geo_db_location" VALUES(32695,NULL,'Blaine, OH',13317,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32696,NULL,'Blaine, OH 43909',13317,222,NULL,35,19086,0);
INSERT INTO "django_geo_db_location" VALUES(32697,NULL,'Bloomingdale, OH',13318,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32698,NULL,'Bloomingdale, OH 43910',13318,222,NULL,35,19087,0);
INSERT INTO "django_geo_db_location" VALUES(32699,NULL,'Bridgeport, OH',13319,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32700,NULL,'Bridgeport, OH 43912',13319,222,NULL,35,19088,0);
INSERT INTO "django_geo_db_location" VALUES(32701,NULL,'Brilliant, OH',13320,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32702,NULL,'Brilliant, OH 43913',13320,222,NULL,35,19089,0);
INSERT INTO "django_geo_db_location" VALUES(32703,NULL,'Cameron, OH',13321,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32704,NULL,'Cameron, OH 43914',13321,222,NULL,35,19090,0);
INSERT INTO "django_geo_db_location" VALUES(32705,NULL,'Clarington, OH',13322,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32706,NULL,'Clarington, OH 43915',13322,222,NULL,35,19091,0);
INSERT INTO "django_geo_db_location" VALUES(32707,NULL,'Colerain, OH',13323,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32708,NULL,'Colerain, OH 43916',13323,222,NULL,35,19092,0);
INSERT INTO "django_geo_db_location" VALUES(32709,NULL,'Dillonvale, OH',13324,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32710,NULL,'Dillonvale, OH 43917',13324,222,NULL,35,19093,0);
INSERT INTO "django_geo_db_location" VALUES(32711,NULL,'East Liverpool, OH',13325,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32712,NULL,'East Liverpool, OH 43920',13325,222,NULL,35,19094,0);
INSERT INTO "django_geo_db_location" VALUES(32713,NULL,'Noble, OH',13326,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32714,NULL,'Noble, OH 43924',13326,222,NULL,35,19095,0);
INSERT INTO "django_geo_db_location" VALUES(32715,NULL,'East Springfield, OH',13327,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32716,NULL,'East Springfield, OH 43925',13327,222,NULL,35,19096,0);
INSERT INTO "django_geo_db_location" VALUES(32717,NULL,'Empire, OH',13328,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32718,NULL,'Empire, OH 43926',13328,222,NULL,35,19097,0);
INSERT INTO "django_geo_db_location" VALUES(32719,NULL,'Fairpoint, OH',13329,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32720,NULL,'Fairpoint, OH 43927',13329,222,NULL,35,19098,0);
INSERT INTO "django_geo_db_location" VALUES(32721,NULL,'Glencoe, OH',13330,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32722,NULL,'Glencoe, OH 43928',13330,222,NULL,35,19099,0);
INSERT INTO "django_geo_db_location" VALUES(32723,NULL,'Hammondsville, OH',13331,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32724,NULL,'Hammondsville, OH 43930',13331,222,NULL,35,19100,0);
INSERT INTO "django_geo_db_location" VALUES(32725,NULL,'Hannibal, OH',13332,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32726,NULL,'Hannibal, OH 43931',13332,222,NULL,35,19101,0);
INSERT INTO "django_geo_db_location" VALUES(32727,NULL,'Irondale, OH',13333,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32728,NULL,'Irondale, OH 43932',13333,222,NULL,35,19102,0);
INSERT INTO "django_geo_db_location" VALUES(32729,NULL,'Jacobsburg, OH',13334,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32730,NULL,'Jacobsburg, OH 43933',13334,222,NULL,35,19103,0);
INSERT INTO "django_geo_db_location" VALUES(32731,NULL,'Lansing, OH',13335,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32732,NULL,'Lansing, OH 43934',13335,222,NULL,35,19104,0);
INSERT INTO "django_geo_db_location" VALUES(32733,NULL,'Martins Ferry, OH',13336,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32734,NULL,'Martins Ferry, OH 43935',13336,222,NULL,35,19105,0);
INSERT INTO "django_geo_db_location" VALUES(32735,NULL,'Maynard, OH',13337,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32736,NULL,'Maynard, OH 43937',13337,222,NULL,35,19106,0);
INSERT INTO "django_geo_db_location" VALUES(32737,NULL,'Mingo Junction, OH',13338,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32738,NULL,'Mingo Junction, OH 43938',13338,222,NULL,35,19107,0);
INSERT INTO "django_geo_db_location" VALUES(32739,NULL,'Mount Pleasant, OH',13339,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32740,NULL,'Mount Pleasant, OH 43939',13339,222,NULL,35,19108,0);
INSERT INTO "django_geo_db_location" VALUES(32741,NULL,'Neffs, OH',13340,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32742,NULL,'Neffs, OH 43940',13340,222,NULL,35,19109,0);
INSERT INTO "django_geo_db_location" VALUES(32743,NULL,'Piney Fork, OH',13341,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32744,NULL,'Piney Fork, OH 43941',13341,222,NULL,35,19110,0);
INSERT INTO "django_geo_db_location" VALUES(32745,NULL,'Powhatan Point, OH',13342,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32746,NULL,'Powhatan Point, OH 43942',13342,222,NULL,35,19111,0);
INSERT INTO "django_geo_db_location" VALUES(32747,NULL,'Rayland, OH',13343,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32748,NULL,'Rayland, OH 43943',13343,222,NULL,35,19112,0);
INSERT INTO "django_geo_db_location" VALUES(32749,NULL,'Richmond, OH',13344,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32750,NULL,'Richmond, OH 43944',13344,222,NULL,35,19113,0);
INSERT INTO "django_geo_db_location" VALUES(32751,NULL,'Salineville, OH',13345,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32752,NULL,'Salineville, OH 43945',13345,222,NULL,35,19114,0);
INSERT INTO "django_geo_db_location" VALUES(32753,NULL,'Sardis, OH',13346,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32754,NULL,'Sardis, OH 43946',13346,222,NULL,35,19115,0);
INSERT INTO "django_geo_db_location" VALUES(32755,NULL,'Shadyside, OH',13347,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32756,NULL,'Shadyside, OH 43947',13347,222,NULL,35,19116,0);
INSERT INTO "django_geo_db_location" VALUES(32757,NULL,'Smithfield, OH',13348,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32758,NULL,'Smithfield, OH 43948',13348,222,NULL,35,19117,0);
INSERT INTO "django_geo_db_location" VALUES(32759,NULL,'Saint Clairsville, OH',13349,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32760,NULL,'Saint Clairsville, OH 43950',13349,222,NULL,35,19118,0);
INSERT INTO "django_geo_db_location" VALUES(32761,NULL,'Lafferty, OH',13350,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32762,NULL,'Lafferty, OH 43951',13350,222,NULL,35,19119,0);
INSERT INTO "django_geo_db_location" VALUES(32763,NULL,'Steubenville, OH',13351,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32764,NULL,'Steubenville, OH 43952',13351,222,NULL,35,19120,0);
INSERT INTO "django_geo_db_location" VALUES(32765,NULL,'Steubenville, OH 43953',13351,222,NULL,35,19121,0);
INSERT INTO "django_geo_db_location" VALUES(32766,NULL,'Richland, OH',13352,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32767,NULL,'Richland, OH 43960',13352,222,NULL,35,19122,0);
INSERT INTO "django_geo_db_location" VALUES(32768,NULL,'Stratton, OH',13353,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32769,NULL,'Stratton, OH 43961',13353,222,NULL,35,19123,0);
INSERT INTO "django_geo_db_location" VALUES(32770,NULL,'Summitville, OH',13354,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32771,NULL,'Summitville, OH 43962',13354,222,NULL,35,19124,0);
INSERT INTO "django_geo_db_location" VALUES(32772,NULL,'Tiltonsville, OH',13355,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32773,NULL,'Tiltonsville, OH 43963',13355,222,NULL,35,19125,0);
INSERT INTO "django_geo_db_location" VALUES(32774,NULL,'Toronto, OH',13356,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32775,NULL,'Toronto, OH 43964',13356,222,NULL,35,19126,0);
INSERT INTO "django_geo_db_location" VALUES(32776,NULL,'Unionport, OH',13357,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32777,NULL,'Unionport, OH 43966',13357,222,NULL,35,19127,0);
INSERT INTO "django_geo_db_location" VALUES(32778,NULL,'Warnock, OH',13358,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32779,NULL,'Warnock, OH 43967',13358,222,NULL,35,19128,0);
INSERT INTO "django_geo_db_location" VALUES(32780,NULL,'Wellsville, OH',13359,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32781,NULL,'Wellsville, OH 43968',13359,222,NULL,35,19129,0);
INSERT INTO "django_geo_db_location" VALUES(32782,NULL,'Wolf Run, OH',13360,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32783,NULL,'Wolf Run, OH 43970',13360,222,NULL,35,19130,0);
INSERT INTO "django_geo_db_location" VALUES(32784,NULL,'Yorkville, OH',13361,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32785,NULL,'Yorkville, OH 43971',13361,222,NULL,35,19131,0);
INSERT INTO "django_geo_db_location" VALUES(32786,NULL,'Bannock, OH',13362,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32787,NULL,'Bannock, OH 43972',13362,222,NULL,35,19132,0);
INSERT INTO "django_geo_db_location" VALUES(32788,NULL,'Freeport, OH',13363,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32789,NULL,'Freeport, OH 43973',13363,222,NULL,35,19133,0);
INSERT INTO "django_geo_db_location" VALUES(32790,NULL,'Harrisville, OH',13364,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32791,NULL,'Harrisville, OH 43974',13364,222,NULL,35,19134,0);
INSERT INTO "django_geo_db_location" VALUES(32792,NULL,'Hopedale, OH',13365,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32793,NULL,'Hopedale, OH 43976',13365,222,NULL,35,19135,0);
INSERT INTO "django_geo_db_location" VALUES(32794,NULL,'Flushing, OH',13366,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32795,NULL,'Flushing, OH 43977',13366,222,NULL,35,19136,0);
INSERT INTO "django_geo_db_location" VALUES(32796,NULL,'New Athens, OH',13367,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32797,NULL,'New Athens, OH 43981',13367,222,NULL,35,19137,0);
INSERT INTO "django_geo_db_location" VALUES(32798,NULL,'Piedmont, OH',13368,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32799,NULL,'Piedmont, OH 43983',13368,222,NULL,35,19138,0);
INSERT INTO "django_geo_db_location" VALUES(32800,NULL,'New Rumley, OH',13369,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32801,NULL,'New Rumley, OH 43984',13369,222,NULL,35,19139,0);
INSERT INTO "django_geo_db_location" VALUES(32802,NULL,'Holloway, OH',13370,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32803,NULL,'Holloway, OH 43985',13370,222,NULL,35,19140,0);
INSERT INTO "django_geo_db_location" VALUES(32804,NULL,'Jewett, OH',13371,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32805,NULL,'Jewett, OH 43986',13371,222,NULL,35,19141,0);
INSERT INTO "django_geo_db_location" VALUES(32806,NULL,'Scio, OH',13372,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32807,NULL,'Scio, OH 43988',13372,222,NULL,35,19142,0);
INSERT INTO "django_geo_db_location" VALUES(32808,NULL,'Short Creek, OH',13373,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32809,NULL,'Short Creek, OH 43989',13373,222,NULL,35,19143,0);
INSERT INTO "django_geo_db_location" VALUES(32810,NULL,'Amherst, OH',13374,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32811,NULL,'Amherst, OH 44001',13374,222,NULL,35,19144,0);
INSERT INTO "django_geo_db_location" VALUES(32812,NULL,'Andover, OH',13375,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32813,NULL,'Andover, OH 44003',13375,222,NULL,35,19145,0);
INSERT INTO "django_geo_db_location" VALUES(32814,NULL,'Ashtabula, OH',13376,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32815,NULL,'Ashtabula, OH 44004',13376,222,NULL,35,19146,0);
INSERT INTO "django_geo_db_location" VALUES(32816,NULL,'Ashtabula, OH 44005',13376,222,NULL,35,19147,0);
INSERT INTO "django_geo_db_location" VALUES(32817,NULL,'Austinburg, OH',13377,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32818,NULL,'Austinburg, OH 44010',13377,222,NULL,35,19148,0);
INSERT INTO "django_geo_db_location" VALUES(32819,NULL,'Avon, OH',13378,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32820,NULL,'Avon, OH 44011',13378,222,NULL,35,19149,0);
INSERT INTO "django_geo_db_location" VALUES(32821,NULL,'Avon Lake, OH',13379,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32822,NULL,'Avon Lake, OH 44012',13379,222,NULL,35,19150,0);
INSERT INTO "django_geo_db_location" VALUES(32823,NULL,'Berea, OH',13380,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32824,NULL,'Berea, OH 44017',13380,222,NULL,35,19151,0);
INSERT INTO "django_geo_db_location" VALUES(32825,NULL,'Burton, OH',13381,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32826,NULL,'Burton, OH 44021',13381,222,NULL,35,19152,0);
INSERT INTO "django_geo_db_location" VALUES(32827,NULL,'Chagrin Falls, OH',13382,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32828,NULL,'Chagrin Falls, OH 44022',13382,222,NULL,35,19153,0);
INSERT INTO "django_geo_db_location" VALUES(32829,NULL,'Chagrin Falls, OH 44023',13382,222,NULL,35,19154,0);
INSERT INTO "django_geo_db_location" VALUES(32830,NULL,'Chardon, OH',13383,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32831,NULL,'Chardon, OH 44024',13383,222,NULL,35,19155,0);
INSERT INTO "django_geo_db_location" VALUES(32832,NULL,'Chesterland, OH',13384,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32833,NULL,'Chesterland, OH 44026',13384,222,NULL,35,19156,0);
INSERT INTO "django_geo_db_location" VALUES(32834,NULL,'Columbia Station, OH',13385,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32835,NULL,'Columbia Station, OH 44028',13385,222,NULL,35,19157,0);
INSERT INTO "django_geo_db_location" VALUES(32836,NULL,'Conneaut, OH',13386,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32837,NULL,'Conneaut, OH 44030',13386,222,NULL,35,19158,0);
INSERT INTO "django_geo_db_location" VALUES(32838,NULL,'Dorset, OH',13387,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32839,NULL,'Dorset, OH 44032',13387,222,NULL,35,19159,0);
INSERT INTO "django_geo_db_location" VALUES(32840,NULL,'East Claridon, OH',13388,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32841,NULL,'East Claridon, OH 44033',13388,222,NULL,35,19160,0);
INSERT INTO "django_geo_db_location" VALUES(32842,NULL,'Elyria, OH',13389,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32843,NULL,'Elyria, OH 44035',13389,222,NULL,35,19161,0);
INSERT INTO "django_geo_db_location" VALUES(32844,NULL,'Elyria, OH 44036',13389,222,NULL,35,19162,0);
INSERT INTO "django_geo_db_location" VALUES(32845,NULL,'North Ridgeville, OH',13390,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32846,NULL,'North Ridgeville, OH 44039',13390,222,NULL,35,19163,0);
INSERT INTO "django_geo_db_location" VALUES(32847,NULL,'Gates Mills, OH',13391,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32848,NULL,'Gates Mills, OH 44040',13391,222,NULL,35,19164,0);
INSERT INTO "django_geo_db_location" VALUES(32849,NULL,'Geneva, OH',13392,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32850,NULL,'Geneva, OH 44041',13392,222,NULL,35,19165,0);
INSERT INTO "django_geo_db_location" VALUES(32851,NULL,'Grafton, OH',13393,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32852,NULL,'Grafton, OH 44044',13393,222,NULL,35,19166,0);
INSERT INTO "django_geo_db_location" VALUES(32853,NULL,'Grand River, OH',13394,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32854,NULL,'Grand River, OH 44045',13394,222,NULL,35,19167,0);
INSERT INTO "django_geo_db_location" VALUES(32855,NULL,'Huntsburg, OH',13395,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32856,NULL,'Huntsburg, OH 44046',13395,222,NULL,35,19168,0);
INSERT INTO "django_geo_db_location" VALUES(32857,NULL,'Jefferson, OH',13396,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32858,NULL,'Jefferson, OH 44047',13396,222,NULL,35,19169,0);
INSERT INTO "django_geo_db_location" VALUES(32859,NULL,'Kingsville, OH',13397,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32860,NULL,'Kingsville, OH 44048',13397,222,NULL,35,19170,0);
INSERT INTO "django_geo_db_location" VALUES(32861,NULL,'Kipton, OH',13398,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32862,NULL,'Kipton, OH 44049',13398,222,NULL,35,19171,0);
INSERT INTO "django_geo_db_location" VALUES(32863,NULL,'Lagrange, OH',13399,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32864,NULL,'Lagrange, OH 44050',13399,222,NULL,35,19172,0);
INSERT INTO "django_geo_db_location" VALUES(32865,NULL,'Lorain, OH',13400,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32866,NULL,'Lorain, OH 44052',13400,222,NULL,35,19173,0);
INSERT INTO "django_geo_db_location" VALUES(32867,NULL,'Lorain, OH 44053',13400,222,NULL,35,19174,0);
INSERT INTO "django_geo_db_location" VALUES(32868,NULL,'Sheffield Lake, OH',13401,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32869,NULL,'Sheffield Lake, OH 44054',13401,222,NULL,35,19175,0);
INSERT INTO "django_geo_db_location" VALUES(32870,NULL,'Lorain, OH 44055',13400,222,NULL,35,19176,0);
INSERT INTO "django_geo_db_location" VALUES(32871,NULL,'Macedonia, OH',13402,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32872,NULL,'Macedonia, OH 44056',13402,222,NULL,35,19177,0);
INSERT INTO "django_geo_db_location" VALUES(32873,NULL,'Madison, OH',13403,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32874,NULL,'Madison, OH 44057',13403,222,NULL,35,19178,0);
INSERT INTO "django_geo_db_location" VALUES(32875,NULL,'Mentor, OH',13404,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32876,NULL,'Mentor, OH 44060',13404,222,NULL,35,19179,0);
INSERT INTO "django_geo_db_location" VALUES(32877,NULL,'Mentor, OH 44061',13404,222,NULL,35,19180,0);
INSERT INTO "django_geo_db_location" VALUES(32878,NULL,'Middlefield, OH',13405,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32879,NULL,'Middlefield, OH 44062',13405,222,NULL,35,19181,0);
INSERT INTO "django_geo_db_location" VALUES(32880,NULL,'Montville, OH',13406,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32881,NULL,'Montville, OH 44064',13406,222,NULL,35,19182,0);
INSERT INTO "django_geo_db_location" VALUES(32882,NULL,'Newbury, OH',13407,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32883,NULL,'Newbury, OH 44065',13407,222,NULL,35,19183,0);
INSERT INTO "django_geo_db_location" VALUES(32884,NULL,'Northfield, OH',13408,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32885,NULL,'Northfield, OH 44067',13408,222,NULL,35,19184,0);
INSERT INTO "django_geo_db_location" VALUES(32886,NULL,'North Kingsville, OH',13409,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32887,NULL,'North Kingsville, OH 44068',13409,222,NULL,35,19185,0);
INSERT INTO "django_geo_db_location" VALUES(32888,NULL,'North Olmsted, OH',13410,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32889,NULL,'North Olmsted, OH 44070',13410,222,NULL,35,19186,0);
INSERT INTO "django_geo_db_location" VALUES(32890,NULL,'Novelty, OH',13411,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32891,NULL,'Novelty, OH 44072',13411,222,NULL,35,19187,0);
INSERT INTO "django_geo_db_location" VALUES(32892,NULL,'Novelty, OH 44073',13411,222,NULL,35,19188,0);
INSERT INTO "django_geo_db_location" VALUES(32893,NULL,'Oberlin, OH',13412,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32894,NULL,'Oberlin, OH 44074',13412,222,NULL,35,19189,0);
INSERT INTO "django_geo_db_location" VALUES(32895,NULL,'Orwell, OH',13413,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32896,NULL,'Orwell, OH 44076',13413,222,NULL,35,19190,0);
INSERT INTO "django_geo_db_location" VALUES(32897,NULL,'Painesville, OH',13414,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32898,NULL,'Painesville, OH 44077',13414,222,NULL,35,19191,0);
INSERT INTO "django_geo_db_location" VALUES(32899,NULL,'Parkman, OH',13415,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32900,NULL,'Parkman, OH 44080',13415,222,NULL,35,19192,0);
INSERT INTO "django_geo_db_location" VALUES(32901,NULL,'Perry, OH',13416,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32902,NULL,'Perry, OH 44081',13416,222,NULL,35,19193,0);
INSERT INTO "django_geo_db_location" VALUES(32903,NULL,'Pierpont, OH',13417,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32904,NULL,'Pierpont, OH 44082',13417,222,NULL,35,19194,0);
INSERT INTO "django_geo_db_location" VALUES(32905,NULL,'Rock Creek, OH',13418,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32906,NULL,'Rock Creek, OH 44084',13418,222,NULL,35,19195,0);
INSERT INTO "django_geo_db_location" VALUES(32907,NULL,'Rome, OH',13419,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32908,NULL,'Rome, OH 44085',13419,222,NULL,35,19196,0);
INSERT INTO "django_geo_db_location" VALUES(32909,NULL,'Thompson, OH',13420,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32910,NULL,'Thompson, OH 44086',13420,222,NULL,35,19197,0);
INSERT INTO "django_geo_db_location" VALUES(32911,NULL,'Twinsburg, OH',13421,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32912,NULL,'Twinsburg, OH 44087',13421,222,NULL,35,19198,0);
INSERT INTO "django_geo_db_location" VALUES(32913,NULL,'Unionville, OH',13422,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32914,NULL,'Unionville, OH 44088',13422,222,NULL,35,19199,0);
INSERT INTO "django_geo_db_location" VALUES(32915,NULL,'Vermilion, OH',13423,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32916,NULL,'Vermilion, OH 44089',13423,222,NULL,35,19200,0);
INSERT INTO "django_geo_db_location" VALUES(32917,NULL,'Wellington, OH',13424,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32918,NULL,'Wellington, OH 44090',13424,222,NULL,35,19201,0);
INSERT INTO "django_geo_db_location" VALUES(32919,NULL,'Wickliffe, OH',13425,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32920,NULL,'Wickliffe, OH 44092',13425,222,NULL,35,19202,0);
INSERT INTO "django_geo_db_location" VALUES(32921,NULL,'Williamsfield, OH',13426,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32922,NULL,'Williamsfield, OH 44093',13426,222,NULL,35,19203,0);
INSERT INTO "django_geo_db_location" VALUES(32923,NULL,'Willoughby, OH',13427,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32924,NULL,'Willoughby, OH 44094',13427,222,NULL,35,19204,0);
INSERT INTO "django_geo_db_location" VALUES(32925,NULL,'Eastlake, OH',13428,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32926,NULL,'Eastlake, OH 44095',13428,222,NULL,35,19205,0);
INSERT INTO "django_geo_db_location" VALUES(32927,NULL,'Willoughby, OH 44096',13427,222,NULL,35,19206,0);
INSERT INTO "django_geo_db_location" VALUES(32928,NULL,'Eastlake, OH 44097',13428,222,NULL,35,19207,0);
INSERT INTO "django_geo_db_location" VALUES(32929,NULL,'Windsor, OH',13429,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32930,NULL,'Windsor, OH 44099',13429,222,NULL,35,19208,0);
INSERT INTO "django_geo_db_location" VALUES(32931,NULL,'Cleveland, OH',13430,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32932,NULL,'Cleveland, OH 44101',13430,222,NULL,35,19209,0);
INSERT INTO "django_geo_db_location" VALUES(32933,NULL,'Cleveland, OH 44102',13430,222,NULL,35,19210,0);
INSERT INTO "django_geo_db_location" VALUES(32934,NULL,'Cleveland, OH 44103',13430,222,NULL,35,19211,0);
INSERT INTO "django_geo_db_location" VALUES(32935,NULL,'Cleveland, OH 44104',13430,222,NULL,35,19212,0);
INSERT INTO "django_geo_db_location" VALUES(32936,NULL,'Cleveland, OH 44105',13430,222,NULL,35,19213,0);
INSERT INTO "django_geo_db_location" VALUES(32937,NULL,'Cleveland, OH 44106',13430,222,NULL,35,19214,0);
INSERT INTO "django_geo_db_location" VALUES(32938,NULL,'Lakewood, OH',13431,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32939,NULL,'Lakewood, OH 44107',13431,222,NULL,35,19215,0);
INSERT INTO "django_geo_db_location" VALUES(32940,NULL,'Cleveland, OH 44108',13430,222,NULL,35,19216,0);
INSERT INTO "django_geo_db_location" VALUES(32941,NULL,'Cleveland, OH 44109',13430,222,NULL,35,19217,0);
INSERT INTO "django_geo_db_location" VALUES(32942,NULL,'Cleveland, OH 44110',13430,222,NULL,35,19218,0);
INSERT INTO "django_geo_db_location" VALUES(32943,NULL,'Cleveland, OH 44111',13430,222,NULL,35,19219,0);
INSERT INTO "django_geo_db_location" VALUES(32944,NULL,'Cleveland, OH 44112',13430,222,NULL,35,19220,0);
INSERT INTO "django_geo_db_location" VALUES(32945,NULL,'Cleveland, OH 44113',13430,222,NULL,35,19221,0);
INSERT INTO "django_geo_db_location" VALUES(32946,NULL,'Cleveland, OH 44114',13430,222,NULL,35,19222,0);
INSERT INTO "django_geo_db_location" VALUES(32947,NULL,'Cleveland, OH 44115',13430,222,NULL,35,19223,0);
INSERT INTO "django_geo_db_location" VALUES(32948,NULL,'Rocky River, OH',13432,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32949,NULL,'Rocky River, OH 44116',13432,222,NULL,35,19224,0);
INSERT INTO "django_geo_db_location" VALUES(32950,NULL,'Euclid, OH',13433,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32951,NULL,'Euclid, OH 44117',13433,222,NULL,35,19225,0);
INSERT INTO "django_geo_db_location" VALUES(32952,NULL,'Cleveland, OH 44118',13430,222,NULL,35,19226,0);
INSERT INTO "django_geo_db_location" VALUES(32953,NULL,'Cleveland, OH 44119',13430,222,NULL,35,19227,0);
INSERT INTO "django_geo_db_location" VALUES(32954,NULL,'Cleveland, OH 44120',13430,222,NULL,35,19228,0);
INSERT INTO "django_geo_db_location" VALUES(32955,NULL,'Cleveland, OH 44121',13430,222,NULL,35,19229,0);
INSERT INTO "django_geo_db_location" VALUES(32956,NULL,'Beachwood, OH',13434,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32957,NULL,'Beachwood, OH 44122',13434,222,NULL,35,19230,0);
INSERT INTO "django_geo_db_location" VALUES(32958,NULL,'Euclid, OH 44123',13433,222,NULL,35,19231,0);
INSERT INTO "django_geo_db_location" VALUES(32959,NULL,'Cleveland, OH 44124',13430,222,NULL,35,19232,0);
INSERT INTO "django_geo_db_location" VALUES(32960,NULL,'Cleveland, OH 44125',13430,222,NULL,35,19233,0);
INSERT INTO "django_geo_db_location" VALUES(32961,NULL,'Cleveland, OH 44126',13430,222,NULL,35,19234,0);
INSERT INTO "django_geo_db_location" VALUES(32962,NULL,'Cleveland, OH 44127',13430,222,NULL,35,19235,0);
INSERT INTO "django_geo_db_location" VALUES(32963,NULL,'Cleveland, OH 44128',13430,222,NULL,35,19236,0);
INSERT INTO "django_geo_db_location" VALUES(32964,NULL,'Cleveland, OH 44129',13430,222,NULL,35,19237,0);
INSERT INTO "django_geo_db_location" VALUES(32965,NULL,'Cleveland, OH 44130',13430,222,NULL,35,19238,0);
INSERT INTO "django_geo_db_location" VALUES(32966,NULL,'Independence, OH',13435,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32967,NULL,'Independence, OH 44131',13435,222,NULL,35,19239,0);
INSERT INTO "django_geo_db_location" VALUES(32968,NULL,'Euclid, OH 44132',13433,222,NULL,35,19240,0);
INSERT INTO "django_geo_db_location" VALUES(32969,NULL,'North Royalton, OH',13436,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32970,NULL,'North Royalton, OH 44133',13436,222,NULL,35,19241,0);
INSERT INTO "django_geo_db_location" VALUES(32971,NULL,'Cleveland, OH 44134',13430,222,NULL,35,19242,0);
INSERT INTO "django_geo_db_location" VALUES(32972,NULL,'Cleveland, OH 44135',13430,222,NULL,35,19243,0);
INSERT INTO "django_geo_db_location" VALUES(32973,NULL,'Strongsville, OH',13437,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32974,NULL,'Strongsville, OH 44136',13437,222,NULL,35,19244,0);
INSERT INTO "django_geo_db_location" VALUES(32975,NULL,'Maple Heights, OH',13438,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32976,NULL,'Maple Heights, OH 44137',13438,222,NULL,35,19245,0);
INSERT INTO "django_geo_db_location" VALUES(32977,NULL,'Olmsted Falls, OH',13439,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32978,NULL,'Olmsted Falls, OH 44138',13439,222,NULL,35,19246,0);
INSERT INTO "django_geo_db_location" VALUES(32979,NULL,'Solon, OH',13440,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32980,NULL,'Solon, OH 44139',13440,222,NULL,35,19247,0);
INSERT INTO "django_geo_db_location" VALUES(32981,NULL,'Bay Village, OH',13441,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32982,NULL,'Bay Village, OH 44140',13441,222,NULL,35,19248,0);
INSERT INTO "django_geo_db_location" VALUES(32983,NULL,'Brecksville, OH',13442,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32984,NULL,'Brecksville, OH 44141',13442,222,NULL,35,19249,0);
INSERT INTO "django_geo_db_location" VALUES(32985,NULL,'Brookpark, OH',13443,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32986,NULL,'Brookpark, OH 44142',13443,222,NULL,35,19250,0);
INSERT INTO "django_geo_db_location" VALUES(32987,NULL,'Cleveland, OH 44143',13430,222,NULL,35,19251,0);
INSERT INTO "django_geo_db_location" VALUES(32988,NULL,'Cleveland, OH 44144',13430,222,NULL,35,19252,0);
INSERT INTO "django_geo_db_location" VALUES(32989,NULL,'Westlake, OH',13444,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32990,NULL,'Westlake, OH 44145',13444,222,NULL,35,19253,0);
INSERT INTO "django_geo_db_location" VALUES(32991,NULL,'Bedford, OH',13445,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32992,NULL,'Bedford, OH 44146',13445,222,NULL,35,19254,0);
INSERT INTO "django_geo_db_location" VALUES(32993,NULL,'Broadview Heights, OH',13446,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32994,NULL,'Broadview Heights, OH 44147',13446,222,NULL,35,19255,0);
INSERT INTO "django_geo_db_location" VALUES(32995,NULL,'Brunswick, OH',13447,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32996,NULL,'Brunswick, OH 44149',13447,222,NULL,35,19256,0);
INSERT INTO "django_geo_db_location" VALUES(32997,NULL,'Dalton, OH',13448,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(32998,NULL,'Dalton, OH 44168',13448,222,NULL,35,19257,0);
INSERT INTO "django_geo_db_location" VALUES(32999,NULL,'Cleveland, OH 44177',13430,222,NULL,35,19258,0);
INSERT INTO "django_geo_db_location" VALUES(33000,NULL,'Cleveland, OH 44178',13430,222,NULL,35,19259,0);
INSERT INTO "django_geo_db_location" VALUES(33001,NULL,'Cleveland, OH 44179',13430,222,NULL,35,19260,0);
INSERT INTO "django_geo_db_location" VALUES(33002,NULL,'Cleveland, OH 44181',13430,222,NULL,35,19261,0);
INSERT INTO "django_geo_db_location" VALUES(33003,NULL,'Cleveland, OH 44184',13430,222,NULL,35,19262,0);
INSERT INTO "django_geo_db_location" VALUES(33004,NULL,'Cleveland, OH 44185',13430,222,NULL,35,19263,0);
INSERT INTO "django_geo_db_location" VALUES(33005,NULL,'Cleveland, OH 44186',13430,222,NULL,35,19264,0);
INSERT INTO "django_geo_db_location" VALUES(33006,NULL,'Cleveland, OH 44188',13430,222,NULL,35,19265,0);
INSERT INTO "django_geo_db_location" VALUES(33007,NULL,'Cleveland, OH 44189',13430,222,NULL,35,19266,0);
INSERT INTO "django_geo_db_location" VALUES(33008,NULL,'Cleveland, OH 44190',13430,222,NULL,35,19267,0);
INSERT INTO "django_geo_db_location" VALUES(33009,NULL,'Cleveland, OH 44191',13430,222,NULL,35,19268,0);
INSERT INTO "django_geo_db_location" VALUES(33010,NULL,'Cleveland, OH 44192',13430,222,NULL,35,19269,0);
INSERT INTO "django_geo_db_location" VALUES(33011,NULL,'Cleveland, OH 44193',13430,222,NULL,35,19270,0);
INSERT INTO "django_geo_db_location" VALUES(33012,NULL,'Cleveland, OH 44194',13430,222,NULL,35,19271,0);
INSERT INTO "django_geo_db_location" VALUES(33013,NULL,'Cleveland, OH 44195',13430,222,NULL,35,19272,0);
INSERT INTO "django_geo_db_location" VALUES(33014,NULL,'Cleveland, OH 44197',13430,222,NULL,35,19273,0);
INSERT INTO "django_geo_db_location" VALUES(33015,NULL,'Cleveland, OH 44198',13430,222,NULL,35,19274,0);
INSERT INTO "django_geo_db_location" VALUES(33016,NULL,'Cleveland, OH 44199',13430,222,NULL,35,19275,0);
INSERT INTO "django_geo_db_location" VALUES(33017,NULL,'Atwater, OH',13449,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33018,NULL,'Atwater, OH 44201',13449,222,NULL,35,19276,0);
INSERT INTO "django_geo_db_location" VALUES(33019,NULL,'Aurora, OH',13450,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33020,NULL,'Aurora, OH 44202',13450,222,NULL,35,19277,0);
INSERT INTO "django_geo_db_location" VALUES(33021,NULL,'Barberton, OH',13451,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33022,NULL,'Barberton, OH 44203',13451,222,NULL,35,19278,0);
INSERT INTO "django_geo_db_location" VALUES(33023,NULL,'Bath, OH',13452,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33024,NULL,'Bath, OH 44210',13452,222,NULL,35,19279,0);
INSERT INTO "django_geo_db_location" VALUES(33025,NULL,'Brady Lake, OH',13453,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33026,NULL,'Brady Lake, OH 44211',13453,222,NULL,35,19280,0);
INSERT INTO "django_geo_db_location" VALUES(33027,NULL,'Brunswick, OH 44212',13447,222,NULL,35,19281,0);
INSERT INTO "django_geo_db_location" VALUES(33028,NULL,'Burbank, OH',13454,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33029,NULL,'Burbank, OH 44214',13454,222,NULL,35,19282,0);
INSERT INTO "django_geo_db_location" VALUES(33030,NULL,'Chippewa Lake, OH',13455,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33031,NULL,'Chippewa Lake, OH 44215',13455,222,NULL,35,19283,0);
INSERT INTO "django_geo_db_location" VALUES(33032,NULL,'Clinton, OH',13456,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33033,NULL,'Clinton, OH 44216',13456,222,NULL,35,19284,0);
INSERT INTO "django_geo_db_location" VALUES(33034,NULL,'Creston, OH',13457,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33035,NULL,'Creston, OH 44217',13457,222,NULL,35,19285,0);
INSERT INTO "django_geo_db_location" VALUES(33036,NULL,'Cuyahoga Falls, OH',13458,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33037,NULL,'Cuyahoga Falls, OH 44221',13458,222,NULL,35,19286,0);
INSERT INTO "django_geo_db_location" VALUES(33038,NULL,'Cuyahoga Falls, OH 44222',13458,222,NULL,35,19287,0);
INSERT INTO "django_geo_db_location" VALUES(33039,NULL,'Cuyahoga Falls, OH 44223',13458,222,NULL,35,19288,0);
INSERT INTO "django_geo_db_location" VALUES(33040,NULL,'Stow, OH',13459,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33041,NULL,'Stow, OH 44224',13459,222,NULL,35,19289,0);
INSERT INTO "django_geo_db_location" VALUES(33042,NULL,'Doylestown, OH',13460,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33043,NULL,'Doylestown, OH 44230',13460,222,NULL,35,19290,0);
INSERT INTO "django_geo_db_location" VALUES(33044,NULL,'Garrettsville, OH',13461,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33045,NULL,'Garrettsville, OH 44231',13461,222,NULL,35,19291,0);
INSERT INTO "django_geo_db_location" VALUES(33046,NULL,'Green, OH',13462,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33047,NULL,'Green, OH 44232',13462,222,NULL,35,19292,0);
INSERT INTO "django_geo_db_location" VALUES(33048,NULL,'Hinckley, OH',13463,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33049,NULL,'Hinckley, OH 44233',13463,222,NULL,35,19293,0);
INSERT INTO "django_geo_db_location" VALUES(33050,NULL,'Hiram, OH',13464,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33051,NULL,'Hiram, OH 44234',13464,222,NULL,35,19294,0);
INSERT INTO "django_geo_db_location" VALUES(33052,NULL,'Homerville, OH',13465,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33053,NULL,'Homerville, OH 44235',13465,222,NULL,35,19295,0);
INSERT INTO "django_geo_db_location" VALUES(33054,NULL,'Hudson, OH',13466,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33055,NULL,'Hudson, OH 44236',13466,222,NULL,35,19296,0);
INSERT INTO "django_geo_db_location" VALUES(33056,NULL,'Hudson, OH 44237',13466,222,NULL,35,19297,0);
INSERT INTO "django_geo_db_location" VALUES(33057,NULL,'Hudson, OH 44238',13466,222,NULL,35,19298,0);
INSERT INTO "django_geo_db_location" VALUES(33058,NULL,'Kent, OH',13467,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33059,NULL,'Kent, OH 44240',13467,222,NULL,35,19299,0);
INSERT INTO "django_geo_db_location" VALUES(33060,NULL,'Streetsboro, OH',13468,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33061,NULL,'Streetsboro, OH 44241',13468,222,NULL,35,19300,0);
INSERT INTO "django_geo_db_location" VALUES(33062,NULL,'Kent, OH 44242',13467,222,NULL,35,19301,0);
INSERT INTO "django_geo_db_location" VALUES(33063,NULL,'Kent, OH 44243',13467,222,NULL,35,19302,0);
INSERT INTO "django_geo_db_location" VALUES(33064,NULL,'Lakemore, OH',13469,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33065,NULL,'Lakemore, OH 44250',13469,222,NULL,35,19303,0);
INSERT INTO "django_geo_db_location" VALUES(33066,NULL,'Westfield Center, OH',13470,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33067,NULL,'Westfield Center, OH 44251',13470,222,NULL,35,19304,0);
INSERT INTO "django_geo_db_location" VALUES(33068,NULL,'Litchfield, OH',13471,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33069,NULL,'Litchfield, OH 44253',13471,222,NULL,35,19305,0);
INSERT INTO "django_geo_db_location" VALUES(33070,NULL,'Lodi, OH',13472,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33071,NULL,'Lodi, OH 44254',13472,222,NULL,35,19306,0);
INSERT INTO "django_geo_db_location" VALUES(33072,NULL,'Mantua, OH',13473,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33073,NULL,'Mantua, OH 44255',13473,222,NULL,35,19307,0);
INSERT INTO "django_geo_db_location" VALUES(33074,NULL,'Medina, OH',13474,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33075,NULL,'Medina, OH 44256',13474,222,NULL,35,19308,0);
INSERT INTO "django_geo_db_location" VALUES(33076,NULL,'Medina, OH 44258',13474,222,NULL,35,19309,0);
INSERT INTO "django_geo_db_location" VALUES(33077,NULL,'Mogadore, OH',13475,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33078,NULL,'Mogadore, OH 44260',13475,222,NULL,35,19310,0);
INSERT INTO "django_geo_db_location" VALUES(33079,NULL,'Munroe Falls, OH',13476,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33080,NULL,'Munroe Falls, OH 44262',13476,222,NULL,35,19311,0);
INSERT INTO "django_geo_db_location" VALUES(33081,NULL,'Peninsula, OH',13477,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33082,NULL,'Peninsula, OH 44264',13477,222,NULL,35,19312,0);
INSERT INTO "django_geo_db_location" VALUES(33083,NULL,'Randolph, OH',13478,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33084,NULL,'Randolph, OH 44265',13478,222,NULL,35,19313,0);
INSERT INTO "django_geo_db_location" VALUES(33085,NULL,'Ravenna, OH',13479,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33086,NULL,'Ravenna, OH 44266',13479,222,NULL,35,19314,0);
INSERT INTO "django_geo_db_location" VALUES(33087,NULL,'Rittman, OH',13480,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33088,NULL,'Rittman, OH 44270',13480,222,NULL,35,19315,0);
INSERT INTO "django_geo_db_location" VALUES(33089,NULL,'Rootstown, OH',13481,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33090,NULL,'Rootstown, OH 44272',13481,222,NULL,35,19316,0);
INSERT INTO "django_geo_db_location" VALUES(33091,NULL,'Seville, OH',13482,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33092,NULL,'Seville, OH 44273',13482,222,NULL,35,19317,0);
INSERT INTO "django_geo_db_location" VALUES(33093,NULL,'Sharon Center, OH',13483,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33094,NULL,'Sharon Center, OH 44274',13483,222,NULL,35,19318,0);
INSERT INTO "django_geo_db_location" VALUES(33095,NULL,'Spencer, OH',13484,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33096,NULL,'Spencer, OH 44275',13484,222,NULL,35,19319,0);
INSERT INTO "django_geo_db_location" VALUES(33097,NULL,'Sterling, OH',13485,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33098,NULL,'Sterling, OH 44276',13485,222,NULL,35,19320,0);
INSERT INTO "django_geo_db_location" VALUES(33099,NULL,'Tallmadge, OH',13486,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33100,NULL,'Tallmadge, OH 44278',13486,222,NULL,35,19321,0);
INSERT INTO "django_geo_db_location" VALUES(33101,NULL,'Valley City, OH',13487,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33102,NULL,'Valley City, OH 44280',13487,222,NULL,35,19322,0);
INSERT INTO "django_geo_db_location" VALUES(33103,NULL,'Wadsworth, OH',13488,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33104,NULL,'Wadsworth, OH 44281',13488,222,NULL,35,19323,0);
INSERT INTO "django_geo_db_location" VALUES(33105,NULL,'Wadsworth, OH 44282',13488,222,NULL,35,19324,0);
INSERT INTO "django_geo_db_location" VALUES(33106,NULL,'Wayland, OH',13489,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33107,NULL,'Wayland, OH 44285',13489,222,NULL,35,19325,0);
INSERT INTO "django_geo_db_location" VALUES(33108,NULL,'Richfield, OH',13490,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33109,NULL,'Richfield, OH 44286',13490,222,NULL,35,19326,0);
INSERT INTO "django_geo_db_location" VALUES(33110,NULL,'West Salem, OH',13491,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33111,NULL,'West Salem, OH 44287',13491,222,NULL,35,19327,0);
INSERT INTO "django_geo_db_location" VALUES(33112,NULL,'Windham, OH',13492,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33113,NULL,'Windham, OH 44288',13492,222,NULL,35,19328,0);
INSERT INTO "django_geo_db_location" VALUES(33114,NULL,'Akron, OH',13493,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33115,NULL,'Akron, OH 44301',13493,222,NULL,35,19329,0);
INSERT INTO "django_geo_db_location" VALUES(33116,NULL,'Akron, OH 44302',13493,222,NULL,35,19330,0);
INSERT INTO "django_geo_db_location" VALUES(33117,NULL,'Akron, OH 44303',13493,222,NULL,35,19331,0);
INSERT INTO "django_geo_db_location" VALUES(33118,NULL,'Akron, OH 44304',13493,222,NULL,35,19332,0);
INSERT INTO "django_geo_db_location" VALUES(33119,NULL,'Akron, OH 44305',13493,222,NULL,35,19333,0);
INSERT INTO "django_geo_db_location" VALUES(33120,NULL,'Akron, OH 44306',13493,222,NULL,35,19334,0);
INSERT INTO "django_geo_db_location" VALUES(33121,NULL,'Akron, OH 44307',13493,222,NULL,35,19335,0);
INSERT INTO "django_geo_db_location" VALUES(33122,NULL,'Akron, OH 44308',13493,222,NULL,35,19336,0);
INSERT INTO "django_geo_db_location" VALUES(33123,NULL,'Akron, OH 44309',13493,222,NULL,35,19337,0);
INSERT INTO "django_geo_db_location" VALUES(33124,NULL,'Akron, OH 44310',13493,222,NULL,35,19338,0);
INSERT INTO "django_geo_db_location" VALUES(33125,NULL,'Akron, OH 44311',13493,222,NULL,35,19339,0);
INSERT INTO "django_geo_db_location" VALUES(33126,NULL,'Akron, OH 44312',13493,222,NULL,35,19340,0);
INSERT INTO "django_geo_db_location" VALUES(33127,NULL,'Akron, OH 44313',13493,222,NULL,35,19341,0);
INSERT INTO "django_geo_db_location" VALUES(33128,NULL,'Akron, OH 44314',13493,222,NULL,35,19342,0);
INSERT INTO "django_geo_db_location" VALUES(33129,NULL,'Akron, OH 44315',13493,222,NULL,35,19343,0);
INSERT INTO "django_geo_db_location" VALUES(33130,NULL,'Akron, OH 44316',13493,222,NULL,35,19344,0);
INSERT INTO "django_geo_db_location" VALUES(33131,NULL,'Akron, OH 44317',13493,222,NULL,35,19345,0);
INSERT INTO "django_geo_db_location" VALUES(33132,NULL,'Akron, OH 44319',13493,222,NULL,35,19346,0);
INSERT INTO "django_geo_db_location" VALUES(33133,NULL,'Akron, OH 44320',13493,222,NULL,35,19347,0);
INSERT INTO "django_geo_db_location" VALUES(33134,NULL,'Akron, OH 44321',13493,222,NULL,35,19348,0);
INSERT INTO "django_geo_db_location" VALUES(33135,NULL,'Akron, OH 44322',13493,222,NULL,35,19349,0);
INSERT INTO "django_geo_db_location" VALUES(33136,NULL,'Akron, OH 44325',13493,222,NULL,35,19350,0);
INSERT INTO "django_geo_db_location" VALUES(33137,NULL,'Akron, OH 44326',13493,222,NULL,35,19351,0);
INSERT INTO "django_geo_db_location" VALUES(33138,NULL,'Akron, OH 44328',13493,222,NULL,35,19352,0);
INSERT INTO "django_geo_db_location" VALUES(33139,NULL,'Paint, OH',13494,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33140,NULL,'Paint, OH 44331',13494,222,NULL,35,19353,0);
INSERT INTO "django_geo_db_location" VALUES(33141,NULL,'Akron, OH 44333',13493,222,NULL,35,19354,0);
INSERT INTO "django_geo_db_location" VALUES(33142,NULL,'Akron, OH 44334',13493,222,NULL,35,19355,0);
INSERT INTO "django_geo_db_location" VALUES(33143,NULL,'Akron, OH 44372',13493,222,NULL,35,19356,0);
INSERT INTO "django_geo_db_location" VALUES(33144,NULL,'Akron, OH 44393',13493,222,NULL,35,19357,0);
INSERT INTO "django_geo_db_location" VALUES(33145,NULL,'Akron, OH 44396',13493,222,NULL,35,19358,0);
INSERT INTO "django_geo_db_location" VALUES(33146,NULL,'Akron, OH 44397',13493,222,NULL,35,19359,0);
INSERT INTO "django_geo_db_location" VALUES(33147,NULL,'Akron, OH 44398',13493,222,NULL,35,19360,0);
INSERT INTO "django_geo_db_location" VALUES(33148,NULL,'Akron, OH 44399',13493,222,NULL,35,19361,0);
INSERT INTO "django_geo_db_location" VALUES(33149,NULL,'Berlin Center, OH',13495,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33150,NULL,'Berlin Center, OH 44401',13495,222,NULL,35,19362,0);
INSERT INTO "django_geo_db_location" VALUES(33151,NULL,'Bristolville, OH',13496,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33152,NULL,'Bristolville, OH 44402',13496,222,NULL,35,19363,0);
INSERT INTO "django_geo_db_location" VALUES(33153,NULL,'Brookfield, OH',13497,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33154,NULL,'Brookfield, OH 44403',13497,222,NULL,35,19364,0);
INSERT INTO "django_geo_db_location" VALUES(33155,NULL,'Burghill, OH',13498,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33156,NULL,'Burghill, OH 44404',13498,222,NULL,35,19365,0);
INSERT INTO "django_geo_db_location" VALUES(33157,NULL,'Campbell, OH',13499,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33158,NULL,'Campbell, OH 44405',13499,222,NULL,35,19366,0);
INSERT INTO "django_geo_db_location" VALUES(33159,NULL,'Canfield, OH',13500,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33160,NULL,'Canfield, OH 44406',13500,222,NULL,35,19367,0);
INSERT INTO "django_geo_db_location" VALUES(33161,NULL,'Columbiana, OH',13501,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33162,NULL,'Columbiana, OH 44408',13501,222,NULL,35,19368,0);
INSERT INTO "django_geo_db_location" VALUES(33163,NULL,'Cortland, OH',13502,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33164,NULL,'Cortland, OH 44410',13502,222,NULL,35,19369,0);
INSERT INTO "django_geo_db_location" VALUES(33165,NULL,'Deerfield, OH',13503,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33166,NULL,'Deerfield, OH 44411',13503,222,NULL,35,19370,0);
INSERT INTO "django_geo_db_location" VALUES(33167,NULL,'Diamond, OH',13504,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33168,NULL,'Diamond, OH 44412',13504,222,NULL,35,19371,0);
INSERT INTO "django_geo_db_location" VALUES(33169,NULL,'East Palestine, OH',13505,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33170,NULL,'East Palestine, OH 44413',13505,222,NULL,35,19372,0);
INSERT INTO "django_geo_db_location" VALUES(33171,NULL,'Elkton, OH',13506,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33172,NULL,'Elkton, OH 44415',13506,222,NULL,35,19373,0);
INSERT INTO "django_geo_db_location" VALUES(33173,NULL,'Ellsworth, OH',13507,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33174,NULL,'Ellsworth, OH 44416',13507,222,NULL,35,19374,0);
INSERT INTO "django_geo_db_location" VALUES(33175,NULL,'Farmdale, OH',13508,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33176,NULL,'Farmdale, OH 44417',13508,222,NULL,35,19375,0);
INSERT INTO "django_geo_db_location" VALUES(33177,NULL,'Fowler, OH',13509,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33178,NULL,'Fowler, OH 44418',13509,222,NULL,35,19376,0);
INSERT INTO "django_geo_db_location" VALUES(33179,NULL,'Girard, OH',13510,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33180,NULL,'Girard, OH 44420',13510,222,NULL,35,19377,0);
INSERT INTO "django_geo_db_location" VALUES(33181,NULL,'Greenford, OH',13511,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33182,NULL,'Greenford, OH 44422',13511,222,NULL,35,19378,0);
INSERT INTO "django_geo_db_location" VALUES(33183,NULL,'Hanoverton, OH',13512,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33184,NULL,'Hanoverton, OH 44423',13512,222,NULL,35,19379,0);
INSERT INTO "django_geo_db_location" VALUES(33185,NULL,'Hartford, OH',13513,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33186,NULL,'Hartford, OH 44424',13513,222,NULL,35,19380,0);
INSERT INTO "django_geo_db_location" VALUES(33187,NULL,'Hubbard, OH',13514,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33188,NULL,'Hubbard, OH 44425',13514,222,NULL,35,19381,0);
INSERT INTO "django_geo_db_location" VALUES(33189,NULL,'Kensington, OH',13515,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33190,NULL,'Kensington, OH 44427',13515,222,NULL,35,19382,0);
INSERT INTO "django_geo_db_location" VALUES(33191,NULL,'Kinsman, OH',13516,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33192,NULL,'Kinsman, OH 44428',13516,222,NULL,35,19383,0);
INSERT INTO "django_geo_db_location" VALUES(33193,NULL,'Lake Milton, OH',13517,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33194,NULL,'Lake Milton, OH 44429',13517,222,NULL,35,19384,0);
INSERT INTO "django_geo_db_location" VALUES(33195,NULL,'Leavittsburg, OH',13518,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33196,NULL,'Leavittsburg, OH 44430',13518,222,NULL,35,19385,0);
INSERT INTO "django_geo_db_location" VALUES(33197,NULL,'Leetonia, OH',13519,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33198,NULL,'Leetonia, OH 44431',13519,222,NULL,35,19386,0);
INSERT INTO "django_geo_db_location" VALUES(33199,NULL,'Lisbon, OH',13520,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33200,NULL,'Lisbon, OH 44432',13520,222,NULL,35,19387,0);
INSERT INTO "django_geo_db_location" VALUES(33201,NULL,'Lowellville, OH',13521,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33202,NULL,'Lowellville, OH 44436',13521,222,NULL,35,19388,0);
INSERT INTO "django_geo_db_location" VALUES(33203,NULL,'McDonald, OH',13522,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33204,NULL,'McDonald, OH 44437',13522,222,NULL,35,19389,0);
INSERT INTO "django_geo_db_location" VALUES(33205,NULL,'Masury, OH',13523,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33206,NULL,'Masury, OH 44438',13523,222,NULL,35,19390,0);
INSERT INTO "django_geo_db_location" VALUES(33207,NULL,'Mesopotamia, OH',13524,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33208,NULL,'Mesopotamia, OH 44439',13524,222,NULL,35,19391,0);
INSERT INTO "django_geo_db_location" VALUES(33209,NULL,'Mineral Ridge, OH',13525,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33210,NULL,'Mineral Ridge, OH 44440',13525,222,NULL,35,19392,0);
INSERT INTO "django_geo_db_location" VALUES(33211,NULL,'Negley, OH',13526,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33212,NULL,'Negley, OH 44441',13526,222,NULL,35,19393,0);
INSERT INTO "django_geo_db_location" VALUES(33213,NULL,'New Middletown, OH',13527,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33214,NULL,'New Middletown, OH 44442',13527,222,NULL,35,19394,0);
INSERT INTO "django_geo_db_location" VALUES(33215,NULL,'New Springfield, OH',13528,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33216,NULL,'New Springfield, OH 44443',13528,222,NULL,35,19395,0);
INSERT INTO "django_geo_db_location" VALUES(33217,NULL,'Newton Falls, OH',13529,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33218,NULL,'Newton Falls, OH 44444',13529,222,NULL,35,19396,0);
INSERT INTO "django_geo_db_location" VALUES(33219,NULL,'New Waterford, OH',13530,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33220,NULL,'New Waterford, OH 44445',13530,222,NULL,35,19397,0);
INSERT INTO "django_geo_db_location" VALUES(33221,NULL,'Niles, OH',13531,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33222,NULL,'Niles, OH 44446',13531,222,NULL,35,19398,0);
INSERT INTO "django_geo_db_location" VALUES(33223,NULL,'North Benton, OH',13532,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33224,NULL,'North Benton, OH 44449',13532,222,NULL,35,19399,0);
INSERT INTO "django_geo_db_location" VALUES(33225,NULL,'North Bloomfield, OH',13533,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33226,NULL,'North Bloomfield, OH 44450',13533,222,NULL,35,19400,0);
INSERT INTO "django_geo_db_location" VALUES(33227,NULL,'North Jackson, OH',13534,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33228,NULL,'North Jackson, OH 44451',13534,222,NULL,35,19401,0);
INSERT INTO "django_geo_db_location" VALUES(33229,NULL,'North Lima, OH',13535,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33230,NULL,'North Lima, OH 44452',13535,222,NULL,35,19402,0);
INSERT INTO "django_geo_db_location" VALUES(33231,NULL,'Orangeville, OH',13536,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33232,NULL,'Orangeville, OH 44453',13536,222,NULL,35,19403,0);
INSERT INTO "django_geo_db_location" VALUES(33233,NULL,'Petersburg, OH',13537,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33234,NULL,'Petersburg, OH 44454',13537,222,NULL,35,19404,0);
INSERT INTO "django_geo_db_location" VALUES(33235,NULL,'Rogers, OH',13538,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33236,NULL,'Rogers, OH 44455',13538,222,NULL,35,19405,0);
INSERT INTO "django_geo_db_location" VALUES(33237,NULL,'Salem, OH',13539,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33238,NULL,'Salem, OH 44460',13539,222,NULL,35,19406,0);
INSERT INTO "django_geo_db_location" VALUES(33239,NULL,'Southington, OH',13540,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33240,NULL,'Southington, OH 44470',13540,222,NULL,35,19407,0);
INSERT INTO "django_geo_db_location" VALUES(33241,NULL,'Struthers, OH',13541,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33242,NULL,'Struthers, OH 44471',13541,222,NULL,35,19408,0);
INSERT INTO "django_geo_db_location" VALUES(33243,NULL,'Vienna, OH',13542,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33244,NULL,'Vienna, OH 44473',13542,222,NULL,35,19409,0);
INSERT INTO "django_geo_db_location" VALUES(33245,NULL,'Warren, OH',13543,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33246,NULL,'Warren, OH 44481',13543,222,NULL,35,19410,0);
INSERT INTO "django_geo_db_location" VALUES(33247,NULL,'Warren, OH 44482',13543,222,NULL,35,19411,0);
INSERT INTO "django_geo_db_location" VALUES(33248,NULL,'Warren, OH 44483',13543,222,NULL,35,19412,0);
INSERT INTO "django_geo_db_location" VALUES(33249,NULL,'Warren, OH 44484',13543,222,NULL,35,19413,0);
INSERT INTO "django_geo_db_location" VALUES(33250,NULL,'Warren, OH 44485',13543,222,NULL,35,19414,0);
INSERT INTO "django_geo_db_location" VALUES(33251,NULL,'Warren, OH 44486',13543,222,NULL,35,19415,0);
INSERT INTO "django_geo_db_location" VALUES(33252,NULL,'Warren, OH 44487',13543,222,NULL,35,19416,0);
INSERT INTO "django_geo_db_location" VALUES(33253,NULL,'Warren, OH 44488',13543,222,NULL,35,19417,0);
INSERT INTO "django_geo_db_location" VALUES(33254,NULL,'Washingtonville, OH',13544,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33255,NULL,'Washingtonville, OH 44490',13544,222,NULL,35,19418,0);
INSERT INTO "django_geo_db_location" VALUES(33256,NULL,'West Farmington, OH',13545,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33257,NULL,'West Farmington, OH 44491',13545,222,NULL,35,19419,0);
INSERT INTO "django_geo_db_location" VALUES(33258,NULL,'West Point, OH',13546,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33259,NULL,'West Point, OH 44492',13546,222,NULL,35,19420,0);
INSERT INTO "django_geo_db_location" VALUES(33260,NULL,'Winona, OH',13547,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33261,NULL,'Winona, OH 44493',13547,222,NULL,35,19421,0);
INSERT INTO "django_geo_db_location" VALUES(33262,NULL,'Youngstown, OH',13548,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33263,NULL,'Youngstown, OH 44501',13548,222,NULL,35,19422,0);
INSERT INTO "django_geo_db_location" VALUES(33264,NULL,'Youngstown, OH 44502',13548,222,NULL,35,19423,0);
INSERT INTO "django_geo_db_location" VALUES(33265,NULL,'Youngstown, OH 44503',13548,222,NULL,35,19424,0);
INSERT INTO "django_geo_db_location" VALUES(33266,NULL,'Youngstown, OH 44504',13548,222,NULL,35,19425,0);
INSERT INTO "django_geo_db_location" VALUES(33267,NULL,'Youngstown, OH 44505',13548,222,NULL,35,19426,0);
INSERT INTO "django_geo_db_location" VALUES(33268,NULL,'Youngstown, OH 44506',13548,222,NULL,35,19427,0);
INSERT INTO "django_geo_db_location" VALUES(33269,NULL,'Youngstown, OH 44507',13548,222,NULL,35,19428,0);
INSERT INTO "django_geo_db_location" VALUES(33270,NULL,'Youngstown, OH 44509',13548,222,NULL,35,19429,0);
INSERT INTO "django_geo_db_location" VALUES(33271,NULL,'Youngstown, OH 44510',13548,222,NULL,35,19430,0);
INSERT INTO "django_geo_db_location" VALUES(33272,NULL,'Youngstown, OH 44511',13548,222,NULL,35,19431,0);
INSERT INTO "django_geo_db_location" VALUES(33273,NULL,'Youngstown, OH 44512',13548,222,NULL,35,19432,0);
INSERT INTO "django_geo_db_location" VALUES(33274,NULL,'Youngstown, OH 44513',13548,222,NULL,35,19433,0);
INSERT INTO "django_geo_db_location" VALUES(33275,NULL,'Youngstown, OH 44514',13548,222,NULL,35,19434,0);
INSERT INTO "django_geo_db_location" VALUES(33276,NULL,'Youngstown, OH 44515',13548,222,NULL,35,19435,0);
INSERT INTO "django_geo_db_location" VALUES(33277,NULL,'Youngstown, OH 44555',13548,222,NULL,35,19436,0);
INSERT INTO "django_geo_db_location" VALUES(33278,NULL,'Youngstown, OH 44598',13548,222,NULL,35,19437,0);
INSERT INTO "django_geo_db_location" VALUES(33279,NULL,'Youngstown, OH 44599',13548,222,NULL,35,19438,0);
INSERT INTO "django_geo_db_location" VALUES(33280,NULL,'Alliance, OH',13549,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33281,NULL,'Alliance, OH 44601',13549,222,NULL,35,19439,0);
INSERT INTO "django_geo_db_location" VALUES(33282,NULL,'Apple Creek, OH',13550,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33283,NULL,'Apple Creek, OH 44606',13550,222,NULL,35,19440,0);
INSERT INTO "django_geo_db_location" VALUES(33284,NULL,'Augusta, OH',13551,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33285,NULL,'Augusta, OH 44607',13551,222,NULL,35,19441,0);
INSERT INTO "django_geo_db_location" VALUES(33286,NULL,'Beach City, OH',13552,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33287,NULL,'Beach City, OH 44608',13552,222,NULL,35,19442,0);
INSERT INTO "django_geo_db_location" VALUES(33288,NULL,'Beloit, OH',13553,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33289,NULL,'Beloit, OH 44609',13553,222,NULL,35,19443,0);
INSERT INTO "django_geo_db_location" VALUES(33290,NULL,'Berlin, OH',13554,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33291,NULL,'Berlin, OH 44610',13554,222,NULL,35,19444,0);
INSERT INTO "django_geo_db_location" VALUES(33292,NULL,'Big Prairie, OH',13555,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33293,NULL,'Big Prairie, OH 44611',13555,222,NULL,35,19445,0);
INSERT INTO "django_geo_db_location" VALUES(33294,NULL,'Bolivar, OH',13556,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33295,NULL,'Bolivar, OH 44612',13556,222,NULL,35,19446,0);
INSERT INTO "django_geo_db_location" VALUES(33296,NULL,'Brewster, OH',13557,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33297,NULL,'Brewster, OH 44613',13557,222,NULL,35,19447,0);
INSERT INTO "django_geo_db_location" VALUES(33298,NULL,'Canal Fulton, OH',13558,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33299,NULL,'Canal Fulton, OH 44614',13558,222,NULL,35,19448,0);
INSERT INTO "django_geo_db_location" VALUES(33300,NULL,'Carrollton, OH',13559,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33301,NULL,'Carrollton, OH 44615',13559,222,NULL,35,19449,0);
INSERT INTO "django_geo_db_location" VALUES(33302,NULL,'Charm, OH',13560,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33303,NULL,'Charm, OH 44617',13560,222,NULL,35,19450,0);
INSERT INTO "django_geo_db_location" VALUES(33304,NULL,'Dalton, OH 44618',13448,222,NULL,35,19451,0);
INSERT INTO "django_geo_db_location" VALUES(33305,NULL,'Damascus, OH',13561,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33306,NULL,'Damascus, OH 44619',13561,222,NULL,35,19452,0);
INSERT INTO "django_geo_db_location" VALUES(33307,NULL,'Dellroy, OH',13562,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33308,NULL,'Dellroy, OH 44620',13562,222,NULL,35,19453,0);
INSERT INTO "django_geo_db_location" VALUES(33309,NULL,'Dennison, OH',13563,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33310,NULL,'Dennison, OH 44621',13563,222,NULL,35,19454,0);
INSERT INTO "django_geo_db_location" VALUES(33311,NULL,'Dover, OH',13564,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33312,NULL,'Dover, OH 44622',13564,222,NULL,35,19455,0);
INSERT INTO "django_geo_db_location" VALUES(33313,NULL,'Dundee, OH',13565,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33314,NULL,'Dundee, OH 44624',13565,222,NULL,35,19456,0);
INSERT INTO "django_geo_db_location" VALUES(33315,NULL,'East Rochester, OH',13566,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33316,NULL,'East Rochester, OH 44625',13566,222,NULL,35,19457,0);
INSERT INTO "django_geo_db_location" VALUES(33317,NULL,'East Sparta, OH',13567,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33318,NULL,'East Sparta, OH 44626',13567,222,NULL,35,19458,0);
INSERT INTO "django_geo_db_location" VALUES(33319,NULL,'Fredericksburg, OH',13568,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33320,NULL,'Fredericksburg, OH 44627',13568,222,NULL,35,19459,0);
INSERT INTO "django_geo_db_location" VALUES(33321,NULL,'Glenmont, OH',13569,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33322,NULL,'Glenmont, OH 44628',13569,222,NULL,35,19460,0);
INSERT INTO "django_geo_db_location" VALUES(33323,NULL,'Gnadenhutten, OH',13570,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33324,NULL,'Gnadenhutten, OH 44629',13570,222,NULL,35,19461,0);
INSERT INTO "django_geo_db_location" VALUES(33325,NULL,'Greentown, OH',13571,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33326,NULL,'Greentown, OH 44630',13571,222,NULL,35,19462,0);
INSERT INTO "django_geo_db_location" VALUES(33327,NULL,'Harlem Springs, OH',13572,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33328,NULL,'Harlem Springs, OH 44631',13572,222,NULL,35,19463,0);
INSERT INTO "django_geo_db_location" VALUES(33329,NULL,'Hartville, OH',13573,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33330,NULL,'Hartville, OH 44632',13573,222,NULL,35,19464,0);
INSERT INTO "django_geo_db_location" VALUES(33331,NULL,'Holmesville, OH',13574,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33332,NULL,'Holmesville, OH 44633',13574,222,NULL,35,19465,0);
INSERT INTO "django_geo_db_location" VALUES(33333,NULL,'Homeworth, OH',13575,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33334,NULL,'Homeworth, OH 44634',13575,222,NULL,35,19466,0);
INSERT INTO "django_geo_db_location" VALUES(33335,NULL,'Kidron, OH',13576,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33336,NULL,'Kidron, OH 44636',13576,222,NULL,35,19467,0);
INSERT INTO "django_geo_db_location" VALUES(33337,NULL,'Killbuck, OH',13577,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33338,NULL,'Killbuck, OH 44637',13577,222,NULL,35,19468,0);
INSERT INTO "django_geo_db_location" VALUES(33339,NULL,'Lakeville, OH',13578,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33340,NULL,'Lakeville, OH 44638',13578,222,NULL,35,19469,0);
INSERT INTO "django_geo_db_location" VALUES(33341,NULL,'Leesville, OH',13579,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33342,NULL,'Leesville, OH 44639',13579,222,NULL,35,19470,0);
INSERT INTO "django_geo_db_location" VALUES(33343,NULL,'Limaville, OH',13580,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33344,NULL,'Limaville, OH 44640',13580,222,NULL,35,19471,0);
INSERT INTO "django_geo_db_location" VALUES(33345,NULL,'Louisville, OH',13581,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33346,NULL,'Louisville, OH 44641',13581,222,NULL,35,19472,0);
INSERT INTO "django_geo_db_location" VALUES(33347,NULL,'Magnolia, OH',13582,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33348,NULL,'Magnolia, OH 44643',13582,222,NULL,35,19473,0);
INSERT INTO "django_geo_db_location" VALUES(33349,NULL,'Malvern, OH',13583,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33350,NULL,'Malvern, OH 44644',13583,222,NULL,35,19474,0);
INSERT INTO "django_geo_db_location" VALUES(33351,NULL,'Marshallville, OH',13584,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33352,NULL,'Marshallville, OH 44645',13584,222,NULL,35,19475,0);
INSERT INTO "django_geo_db_location" VALUES(33353,NULL,'Massillon, OH',13585,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33354,NULL,'Massillon, OH 44646',13585,222,NULL,35,19476,0);
INSERT INTO "django_geo_db_location" VALUES(33355,NULL,'Massillon, OH 44647',13585,222,NULL,35,19477,0);
INSERT INTO "django_geo_db_location" VALUES(33356,NULL,'Massillon, OH 44648',13585,222,NULL,35,19478,0);
INSERT INTO "django_geo_db_location" VALUES(33357,NULL,'Maximo, OH',13586,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33358,NULL,'Maximo, OH 44650',13586,222,NULL,35,19479,0);
INSERT INTO "django_geo_db_location" VALUES(33359,NULL,'Mechanicstown, OH',13587,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33360,NULL,'Mechanicstown, OH 44651',13587,222,NULL,35,19480,0);
INSERT INTO "django_geo_db_location" VALUES(33361,NULL,'Middlebranch, OH',13588,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33362,NULL,'Middlebranch, OH 44652',13588,222,NULL,35,19481,0);
INSERT INTO "django_geo_db_location" VALUES(33363,NULL,'Midvale, OH',13589,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33364,NULL,'Midvale, OH 44653',13589,222,NULL,35,19482,0);
INSERT INTO "django_geo_db_location" VALUES(33365,NULL,'Millersburg, OH',13590,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33366,NULL,'Millersburg, OH 44654',13590,222,NULL,35,19483,0);
INSERT INTO "django_geo_db_location" VALUES(33367,NULL,'Mineral City, OH',13591,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33368,NULL,'Mineral City, OH 44656',13591,222,NULL,35,19484,0);
INSERT INTO "django_geo_db_location" VALUES(33369,NULL,'Minerva, OH',13592,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33370,NULL,'Minerva, OH 44657',13592,222,NULL,35,19485,0);
INSERT INTO "django_geo_db_location" VALUES(33371,NULL,'Mount Eaton, OH',13593,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33372,NULL,'Mount Eaton, OH 44659',13593,222,NULL,35,19486,0);
INSERT INTO "django_geo_db_location" VALUES(33373,NULL,'Mount Hope, OH',13594,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33374,NULL,'Mount Hope, OH 44660',13594,222,NULL,35,19487,0);
INSERT INTO "django_geo_db_location" VALUES(33375,NULL,'Nashville, OH',13595,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33376,NULL,'Nashville, OH 44661',13595,222,NULL,35,19488,0);
INSERT INTO "django_geo_db_location" VALUES(33377,NULL,'Navarre, OH',13596,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33378,NULL,'Navarre, OH 44662',13596,222,NULL,35,19489,0);
INSERT INTO "django_geo_db_location" VALUES(33379,NULL,'New Philadelphia, OH',13597,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33380,NULL,'New Philadelphia, OH 44663',13597,222,NULL,35,19490,0);
INSERT INTO "django_geo_db_location" VALUES(33381,NULL,'North Georgetown, OH',13598,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33382,NULL,'North Georgetown, OH 44665',13598,222,NULL,35,19491,0);
INSERT INTO "django_geo_db_location" VALUES(33383,NULL,'North Lawrence, OH',13599,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33384,NULL,'North Lawrence, OH 44666',13599,222,NULL,35,19492,0);
INSERT INTO "django_geo_db_location" VALUES(33385,NULL,'Orrville, OH',13600,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33386,NULL,'Orrville, OH 44667',13600,222,NULL,35,19493,0);
INSERT INTO "django_geo_db_location" VALUES(33387,NULL,'Paris, OH',13601,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33388,NULL,'Paris, OH 44669',13601,222,NULL,35,19494,0);
INSERT INTO "django_geo_db_location" VALUES(33389,NULL,'Robertsville, OH',13602,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33390,NULL,'Robertsville, OH 44670',13602,222,NULL,35,19495,0);
INSERT INTO "django_geo_db_location" VALUES(33391,NULL,'Sandyville, OH',13603,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33392,NULL,'Sandyville, OH 44671',13603,222,NULL,35,19496,0);
INSERT INTO "django_geo_db_location" VALUES(33393,NULL,'Sebring, OH',13604,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33394,NULL,'Sebring, OH 44672',13604,222,NULL,35,19497,0);
INSERT INTO "django_geo_db_location" VALUES(33395,NULL,'Sherrodsville, OH',13605,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33396,NULL,'Sherrodsville, OH 44675',13605,222,NULL,35,19498,0);
INSERT INTO "django_geo_db_location" VALUES(33397,NULL,'Shreve, OH',13606,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33398,NULL,'Shreve, OH 44676',13606,222,NULL,35,19499,0);
INSERT INTO "django_geo_db_location" VALUES(33399,NULL,'Smithville, OH',13607,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33400,NULL,'Smithville, OH 44677',13607,222,NULL,35,19500,0);
INSERT INTO "django_geo_db_location" VALUES(33401,NULL,'Somerdale, OH',13608,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33402,NULL,'Somerdale, OH 44678',13608,222,NULL,35,19501,0);
INSERT INTO "django_geo_db_location" VALUES(33403,NULL,'Stillwater, OH',13609,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33404,NULL,'Stillwater, OH 44679',13609,222,NULL,35,19502,0);
INSERT INTO "django_geo_db_location" VALUES(33405,NULL,'Strasburg, OH',13610,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33406,NULL,'Strasburg, OH 44680',13610,222,NULL,35,19503,0);
INSERT INTO "django_geo_db_location" VALUES(33407,NULL,'Sugarcreek, OH',13611,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33408,NULL,'Sugarcreek, OH 44681',13611,222,NULL,35,19504,0);
INSERT INTO "django_geo_db_location" VALUES(33409,NULL,'Tuscarawas, OH',13612,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33410,NULL,'Tuscarawas, OH 44682',13612,222,NULL,35,19505,0);
INSERT INTO "django_geo_db_location" VALUES(33411,NULL,'Uhrichsville, OH',13613,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33412,NULL,'Uhrichsville, OH 44683',13613,222,NULL,35,19506,0);
INSERT INTO "django_geo_db_location" VALUES(33413,NULL,'Walnut Creek, OH',13614,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33414,NULL,'Walnut Creek, OH 44684',13614,222,NULL,35,19507,0);
INSERT INTO "django_geo_db_location" VALUES(33415,NULL,'Uniontown, OH',13615,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33416,NULL,'Uniontown, OH 44685',13615,222,NULL,35,19508,0);
INSERT INTO "django_geo_db_location" VALUES(33417,NULL,'Walnut Creek, OH 44687',13614,222,NULL,35,19509,0);
INSERT INTO "django_geo_db_location" VALUES(33418,NULL,'Waynesburg, OH',13616,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33419,NULL,'Waynesburg, OH 44688',13616,222,NULL,35,19510,0);
INSERT INTO "django_geo_db_location" VALUES(33420,NULL,'Wilmot, OH',13617,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33421,NULL,'Wilmot, OH 44689',13617,222,NULL,35,19511,0);
INSERT INTO "django_geo_db_location" VALUES(33422,NULL,'Winesburg, OH',13618,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33423,NULL,'Winesburg, OH 44690',13618,222,NULL,35,19512,0);
INSERT INTO "django_geo_db_location" VALUES(33424,NULL,'Wooster, OH',13619,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33425,NULL,'Wooster, OH 44691',13619,222,NULL,35,19513,0);
INSERT INTO "django_geo_db_location" VALUES(33426,NULL,'Tuscarawas, OH 44692',13612,222,NULL,35,19514,0);
INSERT INTO "django_geo_db_location" VALUES(33427,NULL,'Deersville, OH',13620,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33428,NULL,'Deersville, OH 44693',13620,222,NULL,35,19515,0);
INSERT INTO "django_geo_db_location" VALUES(33429,NULL,'Bowerston, OH',13621,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33430,NULL,'Bowerston, OH 44695',13621,222,NULL,35,19516,0);
INSERT INTO "django_geo_db_location" VALUES(33431,NULL,'Zoar, OH',13622,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33432,NULL,'Zoar, OH 44697',13622,222,NULL,35,19517,0);
INSERT INTO "django_geo_db_location" VALUES(33433,NULL,'Tippecanoe, OH',13623,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33434,NULL,'Tippecanoe, OH 44699',13623,222,NULL,35,19518,0);
INSERT INTO "django_geo_db_location" VALUES(33435,NULL,'Canton, OH',13624,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33436,NULL,'Canton, OH 44701',13624,222,NULL,35,19519,0);
INSERT INTO "django_geo_db_location" VALUES(33437,NULL,'Canton, OH 44702',13624,222,NULL,35,19520,0);
INSERT INTO "django_geo_db_location" VALUES(33438,NULL,'Canton, OH 44703',13624,222,NULL,35,19521,0);
INSERT INTO "django_geo_db_location" VALUES(33439,NULL,'Canton, OH 44704',13624,222,NULL,35,19522,0);
INSERT INTO "django_geo_db_location" VALUES(33440,NULL,'Canton, OH 44705',13624,222,NULL,35,19523,0);
INSERT INTO "django_geo_db_location" VALUES(33441,NULL,'Canton, OH 44706',13624,222,NULL,35,19524,0);
INSERT INTO "django_geo_db_location" VALUES(33442,NULL,'Canton, OH 44707',13624,222,NULL,35,19525,0);
INSERT INTO "django_geo_db_location" VALUES(33443,NULL,'Canton, OH 44708',13624,222,NULL,35,19526,0);
INSERT INTO "django_geo_db_location" VALUES(33444,NULL,'Canton, OH 44709',13624,222,NULL,35,19527,0);
INSERT INTO "django_geo_db_location" VALUES(33445,NULL,'Canton, OH 44710',13624,222,NULL,35,19528,0);
INSERT INTO "django_geo_db_location" VALUES(33446,NULL,'Canton, OH 44711',13624,222,NULL,35,19529,0);
INSERT INTO "django_geo_db_location" VALUES(33447,NULL,'Canton, OH 44712',13624,222,NULL,35,19530,0);
INSERT INTO "django_geo_db_location" VALUES(33448,NULL,'Canton, OH 44714',13624,222,NULL,35,19531,0);
INSERT INTO "django_geo_db_location" VALUES(33449,NULL,'Canton, OH 44718',13624,222,NULL,35,19532,0);
INSERT INTO "django_geo_db_location" VALUES(33450,NULL,'Canton, OH 44720',13624,222,NULL,35,19533,0);
INSERT INTO "django_geo_db_location" VALUES(33451,NULL,'Canton, OH 44721',13624,222,NULL,35,19534,0);
INSERT INTO "django_geo_db_location" VALUES(33452,NULL,'Canton, OH 44730',13624,222,NULL,35,19535,0);
INSERT INTO "django_geo_db_location" VALUES(33453,NULL,'Canton, OH 44735',13624,222,NULL,35,19536,0);
INSERT INTO "django_geo_db_location" VALUES(33454,NULL,'Canton, OH 44750',13624,222,NULL,35,19537,0);
INSERT INTO "django_geo_db_location" VALUES(33455,NULL,'Canton, OH 44760',13624,222,NULL,35,19538,0);
INSERT INTO "django_geo_db_location" VALUES(33456,NULL,'Canton, OH 44767',13624,222,NULL,35,19539,0);
INSERT INTO "django_geo_db_location" VALUES(33457,NULL,'Canton, OH 44798',13624,222,NULL,35,19540,0);
INSERT INTO "django_geo_db_location" VALUES(33458,NULL,'Canton, OH 44799',13624,222,NULL,35,19541,0);
INSERT INTO "django_geo_db_location" VALUES(33459,NULL,'Adrian, OH',13625,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33460,NULL,'Adrian, OH 44801',13625,222,NULL,35,19542,0);
INSERT INTO "django_geo_db_location" VALUES(33461,NULL,'Alvada, OH',13626,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33462,NULL,'Alvada, OH 44802',13626,222,NULL,35,19543,0);
INSERT INTO "django_geo_db_location" VALUES(33463,NULL,'Amsden, OH',13627,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33464,NULL,'Amsden, OH 44803',13627,222,NULL,35,19544,0);
INSERT INTO "django_geo_db_location" VALUES(33465,NULL,'Arcadia, OH',13628,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33466,NULL,'Arcadia, OH 44804',13628,222,NULL,35,19545,0);
INSERT INTO "django_geo_db_location" VALUES(33467,NULL,'Ashland, OH',13629,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33468,NULL,'Ashland, OH 44805',13629,222,NULL,35,19546,0);
INSERT INTO "django_geo_db_location" VALUES(33469,NULL,'Attica, OH',13630,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33470,NULL,'Attica, OH 44807',13630,222,NULL,35,19547,0);
INSERT INTO "django_geo_db_location" VALUES(33471,NULL,'Bascom, OH',13631,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33472,NULL,'Bascom, OH 44809',13631,222,NULL,35,19548,0);
INSERT INTO "django_geo_db_location" VALUES(33473,NULL,'Bellevue, OH',13632,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33474,NULL,'Bellevue, OH 44811',13632,222,NULL,35,19549,0);
INSERT INTO "django_geo_db_location" VALUES(33475,NULL,'Bellville, OH',13633,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33476,NULL,'Bellville, OH 44813',13633,222,NULL,35,19550,0);
INSERT INTO "django_geo_db_location" VALUES(33477,NULL,'Berlin Heights, OH',13634,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33478,NULL,'Berlin Heights, OH 44814',13634,222,NULL,35,19551,0);
INSERT INTO "django_geo_db_location" VALUES(33479,NULL,'Bettsville, OH',13635,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33480,NULL,'Bettsville, OH 44815',13635,222,NULL,35,19552,0);
INSERT INTO "django_geo_db_location" VALUES(33481,NULL,'Birmingham, OH',13636,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33482,NULL,'Birmingham, OH 44816',13636,222,NULL,35,19553,0);
INSERT INTO "django_geo_db_location" VALUES(33483,NULL,'Bloomdale, OH',13637,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33484,NULL,'Bloomdale, OH 44817',13637,222,NULL,35,19554,0);
INSERT INTO "django_geo_db_location" VALUES(33485,NULL,'Bloomville, OH',13638,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33486,NULL,'Bloomville, OH 44818',13638,222,NULL,35,19555,0);
INSERT INTO "django_geo_db_location" VALUES(33487,NULL,'Bucyrus, OH',13639,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33488,NULL,'Bucyrus, OH 44820',13639,222,NULL,35,19556,0);
INSERT INTO "django_geo_db_location" VALUES(33489,NULL,'Butler, OH',13640,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33490,NULL,'Butler, OH 44822',13640,222,NULL,35,19557,0);
INSERT INTO "django_geo_db_location" VALUES(33491,NULL,'Castalia, OH',13641,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33492,NULL,'Castalia, OH 44824',13641,222,NULL,35,19558,0);
INSERT INTO "django_geo_db_location" VALUES(33493,NULL,'Chatfield, OH',13642,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33494,NULL,'Chatfield, OH 44825',13642,222,NULL,35,19559,0);
INSERT INTO "django_geo_db_location" VALUES(33495,NULL,'Collins, OH',13643,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33496,NULL,'Collins, OH 44826',13643,222,NULL,35,19560,0);
INSERT INTO "django_geo_db_location" VALUES(33497,NULL,'Crestline, OH',13644,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33498,NULL,'Crestline, OH 44827',13644,222,NULL,35,19561,0);
INSERT INTO "django_geo_db_location" VALUES(33499,NULL,'Flat Rock, OH',13645,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33500,NULL,'Flat Rock, OH 44828',13645,222,NULL,35,19562,0);
INSERT INTO "django_geo_db_location" VALUES(33501,NULL,'Fostoria, OH',13646,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33502,NULL,'Fostoria, OH 44830',13646,222,NULL,35,19563,0);
INSERT INTO "django_geo_db_location" VALUES(33503,NULL,'Galion, OH',13647,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33504,NULL,'Galion, OH 44833',13647,222,NULL,35,19564,0);
INSERT INTO "django_geo_db_location" VALUES(33505,NULL,'Green Springs, OH',13648,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33506,NULL,'Green Springs, OH 44836',13648,222,NULL,35,19565,0);
INSERT INTO "django_geo_db_location" VALUES(33507,NULL,'Greenwich, OH',13649,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33508,NULL,'Greenwich, OH 44837',13649,222,NULL,35,19566,0);
INSERT INTO "django_geo_db_location" VALUES(33509,NULL,'Hayesville, OH',13650,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33510,NULL,'Hayesville, OH 44838',13650,222,NULL,35,19567,0);
INSERT INTO "django_geo_db_location" VALUES(33511,NULL,'Huron, OH',13651,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33512,NULL,'Huron, OH 44839',13651,222,NULL,35,19568,0);
INSERT INTO "django_geo_db_location" VALUES(33513,NULL,'Jeromesville, OH',13652,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33514,NULL,'Jeromesville, OH 44840',13652,222,NULL,35,19569,0);
INSERT INTO "django_geo_db_location" VALUES(33515,NULL,'Kansas, OH',13653,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33516,NULL,'Kansas, OH 44841',13653,222,NULL,35,19570,0);
INSERT INTO "django_geo_db_location" VALUES(33517,NULL,'Loudonville, OH',13654,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33518,NULL,'Loudonville, OH 44842',13654,222,NULL,35,19571,0);
INSERT INTO "django_geo_db_location" VALUES(33519,NULL,'Lucas, OH',13655,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33520,NULL,'Lucas, OH 44843',13655,222,NULL,35,19572,0);
INSERT INTO "django_geo_db_location" VALUES(33521,NULL,'McCutchenville, OH',13656,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33522,NULL,'McCutchenville, OH 44844',13656,222,NULL,35,19573,0);
INSERT INTO "django_geo_db_location" VALUES(33523,NULL,'Melmore, OH',13657,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33524,NULL,'Melmore, OH 44845',13657,222,NULL,35,19574,0);
INSERT INTO "django_geo_db_location" VALUES(33525,NULL,'Milan, OH',13658,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33526,NULL,'Milan, OH 44846',13658,222,NULL,35,19575,0);
INSERT INTO "django_geo_db_location" VALUES(33527,NULL,'Monroeville, OH',13659,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33528,NULL,'Monroeville, OH 44847',13659,222,NULL,35,19576,0);
INSERT INTO "django_geo_db_location" VALUES(33529,NULL,'Nankin, OH',13660,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33530,NULL,'Nankin, OH 44848',13660,222,NULL,35,19577,0);
INSERT INTO "django_geo_db_location" VALUES(33531,NULL,'Nevada, OH',13661,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33532,NULL,'Nevada, OH 44849',13661,222,NULL,35,19578,0);
INSERT INTO "django_geo_db_location" VALUES(33533,NULL,'New Haven, OH',13662,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33534,NULL,'New Haven, OH 44850',13662,222,NULL,35,19579,0);
INSERT INTO "django_geo_db_location" VALUES(33535,NULL,'New London, OH',13663,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33536,NULL,'New London, OH 44851',13663,222,NULL,35,19580,0);
INSERT INTO "django_geo_db_location" VALUES(33537,NULL,'New Riegel, OH',13664,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33538,NULL,'New Riegel, OH 44853',13664,222,NULL,35,19581,0);
INSERT INTO "django_geo_db_location" VALUES(33539,NULL,'New Washington, OH',13665,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33540,NULL,'New Washington, OH 44854',13665,222,NULL,35,19582,0);
INSERT INTO "django_geo_db_location" VALUES(33541,NULL,'North Fairfield, OH',13666,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33542,NULL,'North Fairfield, OH 44855',13666,222,NULL,35,19583,0);
INSERT INTO "django_geo_db_location" VALUES(33543,NULL,'North Robinson, OH',13667,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33544,NULL,'North Robinson, OH 44856',13667,222,NULL,35,19584,0);
INSERT INTO "django_geo_db_location" VALUES(33545,NULL,'Norwalk, OH',13668,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33546,NULL,'Norwalk, OH 44857',13668,222,NULL,35,19585,0);
INSERT INTO "django_geo_db_location" VALUES(33547,NULL,'Norwalk, OH 44858',13668,222,NULL,35,19586,0);
INSERT INTO "django_geo_db_location" VALUES(33548,NULL,'Nova, OH',13669,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33549,NULL,'Nova, OH 44859',13669,222,NULL,35,19587,0);
INSERT INTO "django_geo_db_location" VALUES(33550,NULL,'Oceola, OH',13670,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33551,NULL,'Oceola, OH 44860',13670,222,NULL,35,19588,0);
INSERT INTO "django_geo_db_location" VALUES(33552,NULL,'Old Fort, OH',13671,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33553,NULL,'Old Fort, OH 44861',13671,222,NULL,35,19589,0);
INSERT INTO "django_geo_db_location" VALUES(33554,NULL,'Ontario, OH',13672,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33555,NULL,'Ontario, OH 44862',13672,222,NULL,35,19590,0);
INSERT INTO "django_geo_db_location" VALUES(33556,NULL,'Perrysville, OH',13673,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33557,NULL,'Perrysville, OH 44864',13673,222,NULL,35,19591,0);
INSERT INTO "django_geo_db_location" VALUES(33558,NULL,'Plymouth, OH',13674,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33559,NULL,'Plymouth, OH 44865',13674,222,NULL,35,19592,0);
INSERT INTO "django_geo_db_location" VALUES(33560,NULL,'Polk, OH',13675,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33561,NULL,'Polk, OH 44866',13675,222,NULL,35,19593,0);
INSERT INTO "django_geo_db_location" VALUES(33562,NULL,'Republic, OH',13676,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33563,NULL,'Republic, OH 44867',13676,222,NULL,35,19594,0);
INSERT INTO "django_geo_db_location" VALUES(33564,NULL,'Sandusky, OH',13677,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33565,NULL,'Sandusky, OH 44870',13677,222,NULL,35,19595,0);
INSERT INTO "django_geo_db_location" VALUES(33566,NULL,'Sandusky, OH 44871',13677,222,NULL,35,19596,0);
INSERT INTO "django_geo_db_location" VALUES(33567,NULL,'Savannah, OH',13678,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33568,NULL,'Savannah, OH 44874',13678,222,NULL,35,19597,0);
INSERT INTO "django_geo_db_location" VALUES(33569,NULL,'Shelby, OH',13679,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33570,NULL,'Shelby, OH 44875',13679,222,NULL,35,19598,0);
INSERT INTO "django_geo_db_location" VALUES(33571,NULL,'Shiloh, OH',13680,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33572,NULL,'Shiloh, OH 44878',13680,222,NULL,35,19599,0);
INSERT INTO "django_geo_db_location" VALUES(33573,NULL,'Sullivan, OH',13681,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33574,NULL,'Sullivan, OH 44880',13681,222,NULL,35,19600,0);
INSERT INTO "django_geo_db_location" VALUES(33575,NULL,'Sulphur Springs, OH',13682,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33576,NULL,'Sulphur Springs, OH 44881',13682,222,NULL,35,19601,0);
INSERT INTO "django_geo_db_location" VALUES(33577,NULL,'Sycamore, OH',13683,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33578,NULL,'Sycamore, OH 44882',13683,222,NULL,35,19602,0);
INSERT INTO "django_geo_db_location" VALUES(33579,NULL,'Tiffin, OH 44883',13227,222,NULL,35,19603,0);
INSERT INTO "django_geo_db_location" VALUES(33580,NULL,'Tiro, OH',13684,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33581,NULL,'Tiro, OH 44887',13684,222,NULL,35,19604,0);
INSERT INTO "django_geo_db_location" VALUES(33582,NULL,'Willard, OH',13685,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33583,NULL,'Willard, OH 44888',13685,222,NULL,35,19605,0);
INSERT INTO "django_geo_db_location" VALUES(33584,NULL,'Wakeman, OH',13686,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33585,NULL,'Wakeman, OH 44889',13686,222,NULL,35,19606,0);
INSERT INTO "django_geo_db_location" VALUES(33586,NULL,'Willard, OH 44890',13685,222,NULL,35,19607,0);
INSERT INTO "django_geo_db_location" VALUES(33587,NULL,'Mansfield, OH',13687,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33588,NULL,'Mansfield, OH 44901',13687,222,NULL,35,19608,0);
INSERT INTO "django_geo_db_location" VALUES(33589,NULL,'Mansfield, OH 44902',13687,222,NULL,35,19609,0);
INSERT INTO "django_geo_db_location" VALUES(33590,NULL,'Mansfield, OH 44903',13687,222,NULL,35,19610,0);
INSERT INTO "django_geo_db_location" VALUES(33591,NULL,'Mansfield, OH 44904',13687,222,NULL,35,19611,0);
INSERT INTO "django_geo_db_location" VALUES(33592,NULL,'Mansfield, OH 44905',13687,222,NULL,35,19612,0);
INSERT INTO "django_geo_db_location" VALUES(33593,NULL,'Mansfield, OH 44906',13687,222,NULL,35,19613,0);
INSERT INTO "django_geo_db_location" VALUES(33594,NULL,'Mansfield, OH 44907',13687,222,NULL,35,19614,0);
INSERT INTO "django_geo_db_location" VALUES(33595,NULL,'Mansfield, OH 44999',13687,222,NULL,35,19615,0);
INSERT INTO "django_geo_db_location" VALUES(33596,NULL,'North Bend, OH',13688,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33597,NULL,'North Bend, OH 45000',13688,222,NULL,35,19616,0);
INSERT INTO "django_geo_db_location" VALUES(33598,NULL,'Addyston, OH',13689,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33599,NULL,'Addyston, OH 45001',13689,222,NULL,35,19617,0);
INSERT INTO "django_geo_db_location" VALUES(33600,NULL,'Cleves, OH',13690,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33601,NULL,'Cleves, OH 45002',13690,222,NULL,35,19618,0);
INSERT INTO "django_geo_db_location" VALUES(33602,NULL,'College Corner, OH',13691,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33603,NULL,'College Corner, OH 45003',13691,222,NULL,35,19619,0);
INSERT INTO "django_geo_db_location" VALUES(33604,NULL,'Collinsville, OH',13692,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33605,NULL,'Collinsville, OH 45004',13692,222,NULL,35,19620,0);
INSERT INTO "django_geo_db_location" VALUES(33606,NULL,'Franklin, OH',13693,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33607,NULL,'Franklin, OH 45005',13693,222,NULL,35,19621,0);
INSERT INTO "django_geo_db_location" VALUES(33608,NULL,'Catawba, OH 45010',12984,222,NULL,35,19622,0);
INSERT INTO "django_geo_db_location" VALUES(33609,NULL,'Hamilton, OH',13694,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33610,NULL,'Hamilton, OH 45011',13694,222,NULL,35,19623,0);
INSERT INTO "django_geo_db_location" VALUES(33611,NULL,'Hamilton, OH 45012',13694,222,NULL,35,19624,0);
INSERT INTO "django_geo_db_location" VALUES(33612,NULL,'Hamilton, OH 45013',13694,222,NULL,35,19625,0);
INSERT INTO "django_geo_db_location" VALUES(33613,NULL,'Fairfield, OH',13695,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33614,NULL,'Fairfield, OH 45014',13695,222,NULL,35,19626,0);
INSERT INTO "django_geo_db_location" VALUES(33615,NULL,'Hamilton, OH 45015',13694,222,NULL,35,19627,0);
INSERT INTO "django_geo_db_location" VALUES(33616,NULL,'Fairfield, OH 45018',13695,222,NULL,35,19628,0);
INSERT INTO "django_geo_db_location" VALUES(33617,NULL,'Hamilton, OH 45020',13694,222,NULL,35,19629,0);
INSERT INTO "django_geo_db_location" VALUES(33618,NULL,'Hamilton, OH 45023',13694,222,NULL,35,19630,0);
INSERT INTO "django_geo_db_location" VALUES(33619,NULL,'Hamilton, OH 45025',13694,222,NULL,35,19631,0);
INSERT INTO "django_geo_db_location" VALUES(33620,NULL,'Hamilton, OH 45026',13694,222,NULL,35,19632,0);
INSERT INTO "django_geo_db_location" VALUES(33621,NULL,'Harrison, OH',13696,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33622,NULL,'Harrison, OH 45030',13696,222,NULL,35,19633,0);
INSERT INTO "django_geo_db_location" VALUES(33623,NULL,'Harveysburg, OH',13697,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33624,NULL,'Harveysburg, OH 45032',13697,222,NULL,35,19634,0);
INSERT INTO "django_geo_db_location" VALUES(33625,NULL,'Hooven, OH',13698,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33626,NULL,'Hooven, OH 45033',13698,222,NULL,35,19635,0);
INSERT INTO "django_geo_db_location" VALUES(33627,NULL,'Kings Mills, OH',13699,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33628,NULL,'Kings Mills, OH 45034',13699,222,NULL,35,19636,0);
INSERT INTO "django_geo_db_location" VALUES(33629,NULL,'Lebanon, OH',13700,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33630,NULL,'Lebanon, OH 45036',13700,222,NULL,35,19637,0);
INSERT INTO "django_geo_db_location" VALUES(33631,NULL,'Maineville, OH',13701,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33632,NULL,'Maineville, OH 45039',13701,222,NULL,35,19638,0);
INSERT INTO "django_geo_db_location" VALUES(33633,NULL,'Mason, OH',13702,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33634,NULL,'Mason, OH 45040',13702,222,NULL,35,19639,0);
INSERT INTO "django_geo_db_location" VALUES(33635,NULL,'Miamitown, OH',13703,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33636,NULL,'Miamitown, OH 45041',13703,222,NULL,35,19640,0);
INSERT INTO "django_geo_db_location" VALUES(33637,NULL,'Middletown, OH',13704,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33638,NULL,'Middletown, OH 45042',13704,222,NULL,35,19641,0);
INSERT INTO "django_geo_db_location" VALUES(33639,NULL,'Middletown, OH 45043',13704,222,NULL,35,19642,0);
INSERT INTO "django_geo_db_location" VALUES(33640,NULL,'Middletown, OH 45044',13704,222,NULL,35,19643,0);
INSERT INTO "django_geo_db_location" VALUES(33641,NULL,'Monroe, OH',13705,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33642,NULL,'Monroe, OH 45050',13705,222,NULL,35,19644,0);
INSERT INTO "django_geo_db_location" VALUES(33643,NULL,'Mount Saint Joseph, OH',13706,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33644,NULL,'Mount Saint Joseph, OH 45051',13706,222,NULL,35,19645,0);
INSERT INTO "django_geo_db_location" VALUES(33645,NULL,'North Bend, OH 45052',13688,222,NULL,35,19646,0);
INSERT INTO "django_geo_db_location" VALUES(33646,NULL,'Okeana, OH',13707,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33647,NULL,'Okeana, OH 45053',13707,222,NULL,35,19647,0);
INSERT INTO "django_geo_db_location" VALUES(33648,NULL,'Oregonia, OH',13708,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33649,NULL,'Oregonia, OH 45054',13708,222,NULL,35,19648,0);
INSERT INTO "django_geo_db_location" VALUES(33650,NULL,'Overpeck, OH',13709,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33651,NULL,'Overpeck, OH 45055',13709,222,NULL,35,19649,0);
INSERT INTO "django_geo_db_location" VALUES(33652,NULL,'Oxford, OH',13710,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33653,NULL,'Oxford, OH 45056',13710,222,NULL,35,19650,0);
INSERT INTO "django_geo_db_location" VALUES(33654,NULL,'Ross, OH',13711,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33655,NULL,'Ross, OH 45061',13711,222,NULL,35,19651,0);
INSERT INTO "django_geo_db_location" VALUES(33656,NULL,'Seven Mile, OH',13712,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33657,NULL,'Seven Mile, OH 45062',13712,222,NULL,35,19652,0);
INSERT INTO "django_geo_db_location" VALUES(33658,NULL,'Shandon, OH',13713,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33659,NULL,'Shandon, OH 45063',13713,222,NULL,35,19653,0);
INSERT INTO "django_geo_db_location" VALUES(33660,NULL,'Somerville, OH',13714,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33661,NULL,'Somerville, OH 45064',13714,222,NULL,35,19654,0);
INSERT INTO "django_geo_db_location" VALUES(33662,NULL,'South Lebanon, OH',13715,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33663,NULL,'South Lebanon, OH 45065',13715,222,NULL,35,19655,0);
INSERT INTO "django_geo_db_location" VALUES(33664,NULL,'Springboro, OH',13716,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33665,NULL,'Springboro, OH 45066',13716,222,NULL,35,19656,0);
INSERT INTO "django_geo_db_location" VALUES(33666,NULL,'Trenton, OH',13717,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33667,NULL,'Trenton, OH 45067',13717,222,NULL,35,19657,0);
INSERT INTO "django_geo_db_location" VALUES(33668,NULL,'Waynesville, OH',13718,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33669,NULL,'Waynesville, OH 45068',13718,222,NULL,35,19658,0);
INSERT INTO "django_geo_db_location" VALUES(33670,NULL,'West Chester, OH',13719,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33671,NULL,'West Chester, OH 45069',13719,222,NULL,35,19659,0);
INSERT INTO "django_geo_db_location" VALUES(33672,NULL,'West Elkton, OH',13720,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33673,NULL,'West Elkton, OH 45070',13720,222,NULL,35,19660,0);
INSERT INTO "django_geo_db_location" VALUES(33674,NULL,'West Chester, OH 45071',13719,222,NULL,35,19661,0);
INSERT INTO "django_geo_db_location" VALUES(33675,NULL,'Monroe, OH 45073',13705,222,NULL,35,19662,0);
INSERT INTO "django_geo_db_location" VALUES(33676,NULL,'Monroe, OH 45099',13705,222,NULL,35,19663,0);
INSERT INTO "django_geo_db_location" VALUES(33677,NULL,'Aberdeen, OH',13721,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33678,NULL,'Aberdeen, OH 45101',13721,222,NULL,35,19664,0);
INSERT INTO "django_geo_db_location" VALUES(33679,NULL,'Amelia, OH',13722,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33680,NULL,'Amelia, OH 45102',13722,222,NULL,35,19665,0);
INSERT INTO "django_geo_db_location" VALUES(33681,NULL,'Batavia, OH',13723,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33682,NULL,'Batavia, OH 45103',13723,222,NULL,35,19666,0);
INSERT INTO "django_geo_db_location" VALUES(33683,NULL,'Bentonville, OH',13724,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33684,NULL,'Bentonville, OH 45105',13724,222,NULL,35,19667,0);
INSERT INTO "django_geo_db_location" VALUES(33685,NULL,'Bethel, OH',13725,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33686,NULL,'Bethel, OH 45106',13725,222,NULL,35,19668,0);
INSERT INTO "django_geo_db_location" VALUES(33687,NULL,'Blanchester, OH',13726,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33688,NULL,'Blanchester, OH 45107',13726,222,NULL,35,19669,0);
INSERT INTO "django_geo_db_location" VALUES(33689,NULL,'Buford, OH',13727,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33690,NULL,'Buford, OH 45110',13727,222,NULL,35,19670,0);
INSERT INTO "django_geo_db_location" VALUES(33691,NULL,'Camp Dennison, OH',13728,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33692,NULL,'Camp Dennison, OH 45111',13728,222,NULL,35,19671,0);
INSERT INTO "django_geo_db_location" VALUES(33693,NULL,'Chilo, OH',13729,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33694,NULL,'Chilo, OH 45112',13729,222,NULL,35,19672,0);
INSERT INTO "django_geo_db_location" VALUES(33695,NULL,'Clarksville, OH',13730,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33696,NULL,'Clarksville, OH 45113',13730,222,NULL,35,19673,0);
INSERT INTO "django_geo_db_location" VALUES(33697,NULL,'Cuba, OH',13731,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33698,NULL,'Cuba, OH 45114',13731,222,NULL,35,19674,0);
INSERT INTO "django_geo_db_location" VALUES(33699,NULL,'Decatur, OH',13732,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33700,NULL,'Decatur, OH 45115',13732,222,NULL,35,19675,0);
INSERT INTO "django_geo_db_location" VALUES(33701,NULL,'Fayetteville, OH',13733,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33702,NULL,'Fayetteville, OH 45118',13733,222,NULL,35,19676,0);
INSERT INTO "django_geo_db_location" VALUES(33703,NULL,'Feesburg, OH',13734,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33704,NULL,'Feesburg, OH 45119',13734,222,NULL,35,19677,0);
INSERT INTO "django_geo_db_location" VALUES(33705,NULL,'Felicity, OH',13735,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33706,NULL,'Felicity, OH 45120',13735,222,NULL,35,19678,0);
INSERT INTO "django_geo_db_location" VALUES(33707,NULL,'Georgetown, OH',13736,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33708,NULL,'Georgetown, OH 45121',13736,222,NULL,35,19679,0);
INSERT INTO "django_geo_db_location" VALUES(33709,NULL,'Goshen, OH',13737,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33710,NULL,'Goshen, OH 45122',13737,222,NULL,35,19680,0);
INSERT INTO "django_geo_db_location" VALUES(33711,NULL,'Greenfield, OH',13738,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33712,NULL,'Greenfield, OH 45123',13738,222,NULL,35,19681,0);
INSERT INTO "django_geo_db_location" VALUES(33713,NULL,'Union, OH',13739,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33714,NULL,'Union, OH 45125',13739,222,NULL,35,19682,0);
INSERT INTO "django_geo_db_location" VALUES(33715,NULL,'Columbia, OH',13740,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33716,NULL,'Columbia, OH 45127',13740,222,NULL,35,19683,0);
INSERT INTO "django_geo_db_location" VALUES(33717,NULL,'Hamersville, OH',13741,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33718,NULL,'Hamersville, OH 45130',13741,222,NULL,35,19684,0);
INSERT INTO "django_geo_db_location" VALUES(33719,NULL,'Higginsport, OH',13742,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33720,NULL,'Higginsport, OH 45131',13742,222,NULL,35,19685,0);
INSERT INTO "django_geo_db_location" VALUES(33721,NULL,'Highland, OH',13743,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33722,NULL,'Highland, OH 45132',13743,222,NULL,35,19686,0);
INSERT INTO "django_geo_db_location" VALUES(33723,NULL,'Hillsboro, OH',13744,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33724,NULL,'Hillsboro, OH 45133',13744,222,NULL,35,19687,0);
INSERT INTO "django_geo_db_location" VALUES(33725,NULL,'Leesburg, OH',13745,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33726,NULL,'Leesburg, OH 45135',13745,222,NULL,35,19688,0);
INSERT INTO "django_geo_db_location" VALUES(33727,NULL,'Lees Creek, OH',13746,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33728,NULL,'Lees Creek, OH 45138',13746,222,NULL,35,19689,0);
INSERT INTO "django_geo_db_location" VALUES(33729,NULL,'Loveland, OH',13747,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33730,NULL,'Loveland, OH 45140',13747,222,NULL,35,19690,0);
INSERT INTO "django_geo_db_location" VALUES(33731,NULL,'Lynchburg, OH',13748,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33732,NULL,'Lynchburg, OH 45142',13748,222,NULL,35,19691,0);
INSERT INTO "django_geo_db_location" VALUES(33733,NULL,'Manchester, OH',13749,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33734,NULL,'Manchester, OH 45144',13749,222,NULL,35,19692,0);
INSERT INTO "django_geo_db_location" VALUES(33735,NULL,'Marathon, OH',13750,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33736,NULL,'Marathon, OH 45145',13750,222,NULL,35,19693,0);
INSERT INTO "django_geo_db_location" VALUES(33737,NULL,'Martinsville, OH',13751,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33738,NULL,'Martinsville, OH 45146',13751,222,NULL,35,19694,0);
INSERT INTO "django_geo_db_location" VALUES(33739,NULL,'Miamiville, OH',13752,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33740,NULL,'Miamiville, OH 45147',13752,222,NULL,35,19695,0);
INSERT INTO "django_geo_db_location" VALUES(33741,NULL,'Midland, OH',13753,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33742,NULL,'Midland, OH 45148',13753,222,NULL,35,19696,0);
INSERT INTO "django_geo_db_location" VALUES(33743,NULL,'Milford, OH',13754,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33744,NULL,'Milford, OH 45150',13754,222,NULL,35,19697,0);
INSERT INTO "django_geo_db_location" VALUES(33745,NULL,'Morrow, OH',13755,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33746,NULL,'Morrow, OH 45152',13755,222,NULL,35,19698,0);
INSERT INTO "django_geo_db_location" VALUES(33747,NULL,'Moscow, OH',13756,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33748,NULL,'Moscow, OH 45153',13756,222,NULL,35,19699,0);
INSERT INTO "django_geo_db_location" VALUES(33749,NULL,'Mount Orab, OH',13757,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33750,NULL,'Mount Orab, OH 45154',13757,222,NULL,35,19700,0);
INSERT INTO "django_geo_db_location" VALUES(33751,NULL,'Mowrystown, OH',13758,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33752,NULL,'Mowrystown, OH 45155',13758,222,NULL,35,19701,0);
INSERT INTO "django_geo_db_location" VALUES(33753,NULL,'Neville, OH',13759,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33754,NULL,'Neville, OH 45156',13759,222,NULL,35,19702,0);
INSERT INTO "django_geo_db_location" VALUES(33755,NULL,'New Richmond, OH',13760,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33756,NULL,'New Richmond, OH 45157',13760,222,NULL,35,19703,0);
INSERT INTO "django_geo_db_location" VALUES(33757,NULL,'Newtonsville, OH',13761,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33758,NULL,'Newtonsville, OH 45158',13761,222,NULL,35,19704,0);
INSERT INTO "django_geo_db_location" VALUES(33759,NULL,'New Vienna, OH',13762,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33760,NULL,'New Vienna, OH 45159',13762,222,NULL,35,19705,0);
INSERT INTO "django_geo_db_location" VALUES(33761,NULL,'Owensville, OH',13763,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33762,NULL,'Owensville, OH 45160',13763,222,NULL,35,19706,0);
INSERT INTO "django_geo_db_location" VALUES(33763,NULL,'Pleasant Plain, OH',13764,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33764,NULL,'Pleasant Plain, OH 45162',13764,222,NULL,35,19707,0);
INSERT INTO "django_geo_db_location" VALUES(33765,NULL,'Port William, OH',13765,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33766,NULL,'Port William, OH 45164',13765,222,NULL,35,19708,0);
INSERT INTO "django_geo_db_location" VALUES(33767,NULL,'Greenfield, OH 45165',13738,222,NULL,35,19709,0);
INSERT INTO "django_geo_db_location" VALUES(33768,NULL,'Reesville, OH',13766,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33769,NULL,'Reesville, OH 45166',13766,222,NULL,35,19710,0);
INSERT INTO "django_geo_db_location" VALUES(33770,NULL,'Ripley, OH',13767,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33771,NULL,'Ripley, OH 45167',13767,222,NULL,35,19711,0);
INSERT INTO "django_geo_db_location" VALUES(33772,NULL,'Russellville, OH',13768,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33773,NULL,'Russellville, OH 45168',13768,222,NULL,35,19712,0);
INSERT INTO "django_geo_db_location" VALUES(33774,NULL,'Sabina, OH',13769,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33775,NULL,'Sabina, OH 45169',13769,222,NULL,35,19713,0);
INSERT INTO "django_geo_db_location" VALUES(33776,NULL,'Sardinia, OH',13770,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33777,NULL,'Sardinia, OH 45171',13770,222,NULL,35,19714,0);
INSERT INTO "django_geo_db_location" VALUES(33778,NULL,'Sinking Spring, OH',13771,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33779,NULL,'Sinking Spring, OH 45172',13771,222,NULL,35,19715,0);
INSERT INTO "django_geo_db_location" VALUES(33780,NULL,'Terrace Park, OH',13772,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33781,NULL,'Terrace Park, OH 45174',13772,222,NULL,35,19716,0);
INSERT INTO "django_geo_db_location" VALUES(33782,NULL,'Williamsburg, OH',13773,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33783,NULL,'Williamsburg, OH 45176',13773,222,NULL,35,19717,0);
INSERT INTO "django_geo_db_location" VALUES(33784,NULL,'Wilmington, OH',13774,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33785,NULL,'Wilmington, OH 45177',13774,222,NULL,35,19718,0);
INSERT INTO "django_geo_db_location" VALUES(33786,NULL,'Cincinnati, OH',13775,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33787,NULL,'Cincinnati, OH 45201',13775,222,NULL,35,19719,0);
INSERT INTO "django_geo_db_location" VALUES(33788,NULL,'Cincinnati, OH 45202',13775,222,NULL,35,19720,0);
INSERT INTO "django_geo_db_location" VALUES(33789,NULL,'Cincinnati, OH 45203',13775,222,NULL,35,19721,0);
INSERT INTO "django_geo_db_location" VALUES(33790,NULL,'Cincinnati, OH 45204',13775,222,NULL,35,19722,0);
INSERT INTO "django_geo_db_location" VALUES(33791,NULL,'Cincinnati, OH 45205',13775,222,NULL,35,19723,0);
INSERT INTO "django_geo_db_location" VALUES(33792,NULL,'Cincinnati, OH 45206',13775,222,NULL,35,19724,0);
INSERT INTO "django_geo_db_location" VALUES(33793,NULL,'Cincinnati, OH 45207',13775,222,NULL,35,19725,0);
INSERT INTO "django_geo_db_location" VALUES(33794,NULL,'Cincinnati, OH 45208',13775,222,NULL,35,19726,0);
INSERT INTO "django_geo_db_location" VALUES(33795,NULL,'Cincinnati, OH 45209',13775,222,NULL,35,19727,0);
INSERT INTO "django_geo_db_location" VALUES(33796,NULL,'Cincinnati, OH 45210',13775,222,NULL,35,19728,0);
INSERT INTO "django_geo_db_location" VALUES(33797,NULL,'Cincinnati, OH 45211',13775,222,NULL,35,19729,0);
INSERT INTO "django_geo_db_location" VALUES(33798,NULL,'Cincinnati, OH 45212',13775,222,NULL,35,19730,0);
INSERT INTO "django_geo_db_location" VALUES(33799,NULL,'Cincinnati, OH 45213',13775,222,NULL,35,19731,0);
INSERT INTO "django_geo_db_location" VALUES(33800,NULL,'Cincinnati, OH 45214',13775,222,NULL,35,19732,0);
INSERT INTO "django_geo_db_location" VALUES(33801,NULL,'Cincinnati, OH 45215',13775,222,NULL,35,19733,0);
INSERT INTO "django_geo_db_location" VALUES(33802,NULL,'Cincinnati, OH 45216',13775,222,NULL,35,19734,0);
INSERT INTO "django_geo_db_location" VALUES(33803,NULL,'Cincinnati, OH 45217',13775,222,NULL,35,19735,0);
INSERT INTO "django_geo_db_location" VALUES(33804,NULL,'Cincinnati, OH 45218',13775,222,NULL,35,19736,0);
INSERT INTO "django_geo_db_location" VALUES(33805,NULL,'Cincinnati, OH 45219',13775,222,NULL,35,19737,0);
INSERT INTO "django_geo_db_location" VALUES(33806,NULL,'Cincinnati, OH 45220',13775,222,NULL,35,19738,0);
INSERT INTO "django_geo_db_location" VALUES(33807,NULL,'Cincinnati, OH 45221',13775,222,NULL,35,19739,0);
INSERT INTO "django_geo_db_location" VALUES(33808,NULL,'Cincinnati, OH 45222',13775,222,NULL,35,19740,0);
INSERT INTO "django_geo_db_location" VALUES(33809,NULL,'Cincinnati, OH 45223',13775,222,NULL,35,19741,0);
INSERT INTO "django_geo_db_location" VALUES(33810,NULL,'Cincinnati, OH 45224',13775,222,NULL,35,19742,0);
INSERT INTO "django_geo_db_location" VALUES(33811,NULL,'Cincinnati, OH 45225',13775,222,NULL,35,19743,0);
INSERT INTO "django_geo_db_location" VALUES(33812,NULL,'Cincinnati, OH 45226',13775,222,NULL,35,19744,0);
INSERT INTO "django_geo_db_location" VALUES(33813,NULL,'Cincinnati, OH 45227',13775,222,NULL,35,19745,0);
INSERT INTO "django_geo_db_location" VALUES(33814,NULL,'Cincinnati, OH 45228',13775,222,NULL,35,19746,0);
INSERT INTO "django_geo_db_location" VALUES(33815,NULL,'Cincinnati, OH 45229',13775,222,NULL,35,19747,0);
INSERT INTO "django_geo_db_location" VALUES(33816,NULL,'Cincinnati, OH 45230',13775,222,NULL,35,19748,0);
INSERT INTO "django_geo_db_location" VALUES(33817,NULL,'Cincinnati, OH 45231',13775,222,NULL,35,19749,0);
INSERT INTO "django_geo_db_location" VALUES(33818,NULL,'Cincinnati, OH 45232',13775,222,NULL,35,19750,0);
INSERT INTO "django_geo_db_location" VALUES(33819,NULL,'Cincinnati, OH 45233',13775,222,NULL,35,19751,0);
INSERT INTO "django_geo_db_location" VALUES(33820,NULL,'Cincinnati, OH 45234',13775,222,NULL,35,19752,0);
INSERT INTO "django_geo_db_location" VALUES(33821,NULL,'Cincinnati, OH 45235',13775,222,NULL,35,19753,0);
INSERT INTO "django_geo_db_location" VALUES(33822,NULL,'Cincinnati, OH 45236',13775,222,NULL,35,19754,0);
INSERT INTO "django_geo_db_location" VALUES(33823,NULL,'Cincinnati, OH 45237',13775,222,NULL,35,19755,0);
INSERT INTO "django_geo_db_location" VALUES(33824,NULL,'Cincinnati, OH 45238',13775,222,NULL,35,19756,0);
INSERT INTO "django_geo_db_location" VALUES(33825,NULL,'Cincinnati, OH 45239',13775,222,NULL,35,19757,0);
INSERT INTO "django_geo_db_location" VALUES(33826,NULL,'Cincinnati, OH 45240',13775,222,NULL,35,19758,0);
INSERT INTO "django_geo_db_location" VALUES(33827,NULL,'Cincinnati, OH 45241',13775,222,NULL,35,19759,0);
INSERT INTO "django_geo_db_location" VALUES(33828,NULL,'Cincinnati, OH 45242',13775,222,NULL,35,19760,0);
INSERT INTO "django_geo_db_location" VALUES(33829,NULL,'Cincinnati, OH 45243',13775,222,NULL,35,19761,0);
INSERT INTO "django_geo_db_location" VALUES(33830,NULL,'Cincinnati, OH 45244',13775,222,NULL,35,19762,0);
INSERT INTO "django_geo_db_location" VALUES(33831,NULL,'Cincinnati, OH 45245',13775,222,NULL,35,19763,0);
INSERT INTO "django_geo_db_location" VALUES(33832,NULL,'Cincinnati, OH 45246',13775,222,NULL,35,19764,0);
INSERT INTO "django_geo_db_location" VALUES(33833,NULL,'Cincinnati, OH 45247',13775,222,NULL,35,19765,0);
INSERT INTO "django_geo_db_location" VALUES(33834,NULL,'Cincinnati, OH 45248',13775,222,NULL,35,19766,0);
INSERT INTO "django_geo_db_location" VALUES(33835,NULL,'Cincinnati, OH 45249',13775,222,NULL,35,19767,0);
INSERT INTO "django_geo_db_location" VALUES(33836,NULL,'Cincinnati, OH 45250',13775,222,NULL,35,19768,0);
INSERT INTO "django_geo_db_location" VALUES(33837,NULL,'Cincinnati, OH 45251',13775,222,NULL,35,19769,0);
INSERT INTO "django_geo_db_location" VALUES(33838,NULL,'Cincinnati, OH 45252',13775,222,NULL,35,19770,0);
INSERT INTO "django_geo_db_location" VALUES(33839,NULL,'Cincinnati, OH 45253',13775,222,NULL,35,19771,0);
INSERT INTO "django_geo_db_location" VALUES(33840,NULL,'Cincinnati, OH 45254',13775,222,NULL,35,19772,0);
INSERT INTO "django_geo_db_location" VALUES(33841,NULL,'Cincinnati, OH 45255',13775,222,NULL,35,19773,0);
INSERT INTO "django_geo_db_location" VALUES(33842,NULL,'Cincinnati, OH 45258',13775,222,NULL,35,19774,0);
INSERT INTO "django_geo_db_location" VALUES(33843,NULL,'Cincinnati, OH 45262',13775,222,NULL,35,19775,0);
INSERT INTO "django_geo_db_location" VALUES(33844,NULL,'Cincinnati, OH 45263',13775,222,NULL,35,19776,0);
INSERT INTO "django_geo_db_location" VALUES(33845,NULL,'Cincinnati, OH 45264',13775,222,NULL,35,19777,0);
INSERT INTO "django_geo_db_location" VALUES(33846,NULL,'Cincinnati, OH 45267',13775,222,NULL,35,19778,0);
INSERT INTO "django_geo_db_location" VALUES(33847,NULL,'Cincinnati, OH 45268',13775,222,NULL,35,19779,0);
INSERT INTO "django_geo_db_location" VALUES(33848,NULL,'Cincinnati, OH 45269',13775,222,NULL,35,19780,0);
INSERT INTO "django_geo_db_location" VALUES(33849,NULL,'Cincinnati, OH 45270',13775,222,NULL,35,19781,0);
INSERT INTO "django_geo_db_location" VALUES(33850,NULL,'Cincinnati, OH 45271',13775,222,NULL,35,19782,0);
INSERT INTO "django_geo_db_location" VALUES(33851,NULL,'Cincinnati, OH 45273',13775,222,NULL,35,19783,0);
INSERT INTO "django_geo_db_location" VALUES(33852,NULL,'Cincinnati, OH 45274',13775,222,NULL,35,19784,0);
INSERT INTO "django_geo_db_location" VALUES(33853,NULL,'Cincinnati, OH 45275',13775,222,NULL,35,19785,0);
INSERT INTO "django_geo_db_location" VALUES(33854,NULL,'Cincinnati, OH 45277',13775,222,NULL,35,19786,0);
INSERT INTO "django_geo_db_location" VALUES(33855,NULL,'Cincinnati, OH 45296',13775,222,NULL,35,19787,0);
INSERT INTO "django_geo_db_location" VALUES(33856,NULL,'Cincinnati, OH 45298',13775,222,NULL,35,19788,0);
INSERT INTO "django_geo_db_location" VALUES(33857,NULL,'Cincinnati, OH 45299',13775,222,NULL,35,19789,0);
INSERT INTO "django_geo_db_location" VALUES(33858,NULL,'Alpha, OH',13776,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33859,NULL,'Alpha, OH 45301',13776,222,NULL,35,19790,0);
INSERT INTO "django_geo_db_location" VALUES(33860,NULL,'Anna, OH',13777,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33861,NULL,'Anna, OH 45302',13777,222,NULL,35,19791,0);
INSERT INTO "django_geo_db_location" VALUES(33862,NULL,'Ansonia, OH',13778,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33863,NULL,'Ansonia, OH 45303',13778,222,NULL,35,19792,0);
INSERT INTO "django_geo_db_location" VALUES(33864,NULL,'Arcanum, OH',13779,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33865,NULL,'Arcanum, OH 45304',13779,222,NULL,35,19793,0);
INSERT INTO "django_geo_db_location" VALUES(33866,NULL,'Bellbrook, OH',13780,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33867,NULL,'Bellbrook, OH 45305',13780,222,NULL,35,19794,0);
INSERT INTO "django_geo_db_location" VALUES(33868,NULL,'Botkins, OH',13781,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33869,NULL,'Botkins, OH 45306',13781,222,NULL,35,19795,0);
INSERT INTO "django_geo_db_location" VALUES(33870,NULL,'Bowersville, OH',13782,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33871,NULL,'Bowersville, OH 45307',13782,222,NULL,35,19796,0);
INSERT INTO "django_geo_db_location" VALUES(33872,NULL,'Bradford, OH',13783,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33873,NULL,'Bradford, OH 45308',13783,222,NULL,35,19797,0);
INSERT INTO "django_geo_db_location" VALUES(33874,NULL,'Brookville, OH',13784,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33875,NULL,'Brookville, OH 45309',13784,222,NULL,35,19798,0);
INSERT INTO "django_geo_db_location" VALUES(33876,NULL,'Burkettsville, OH',13785,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33877,NULL,'Burkettsville, OH 45310',13785,222,NULL,35,19799,0);
INSERT INTO "django_geo_db_location" VALUES(33878,NULL,'Camden, OH',13786,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33879,NULL,'Camden, OH 45311',13786,222,NULL,35,19800,0);
INSERT INTO "django_geo_db_location" VALUES(33880,NULL,'Casstown, OH',13787,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33881,NULL,'Casstown, OH 45312',13787,222,NULL,35,19801,0);
INSERT INTO "django_geo_db_location" VALUES(33882,NULL,'Cedarville, OH',13788,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33883,NULL,'Cedarville, OH 45314',13788,222,NULL,35,19802,0);
INSERT INTO "django_geo_db_location" VALUES(33884,NULL,'Clayton, OH',13789,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33885,NULL,'Clayton, OH 45315',13789,222,NULL,35,19803,0);
INSERT INTO "django_geo_db_location" VALUES(33886,NULL,'Clifton, OH',13790,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33887,NULL,'Clifton, OH 45316',13790,222,NULL,35,19804,0);
INSERT INTO "django_geo_db_location" VALUES(33888,NULL,'Conover, OH',13791,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33889,NULL,'Conover, OH 45317',13791,222,NULL,35,19805,0);
INSERT INTO "django_geo_db_location" VALUES(33890,NULL,'Covington, OH',13792,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33891,NULL,'Covington, OH 45318',13792,222,NULL,35,19806,0);
INSERT INTO "django_geo_db_location" VALUES(33892,NULL,'Donnelsville, OH',13793,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33893,NULL,'Donnelsville, OH 45319',13793,222,NULL,35,19807,0);
INSERT INTO "django_geo_db_location" VALUES(33894,NULL,'Eaton, OH',13794,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33895,NULL,'Eaton, OH 45320',13794,222,NULL,35,19808,0);
INSERT INTO "django_geo_db_location" VALUES(33896,NULL,'Eldorado, OH',13795,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33897,NULL,'Eldorado, OH 45321',13795,222,NULL,35,19809,0);
INSERT INTO "django_geo_db_location" VALUES(33898,NULL,'Englewood, OH',13796,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33899,NULL,'Englewood, OH 45322',13796,222,NULL,35,19810,0);
INSERT INTO "django_geo_db_location" VALUES(33900,NULL,'Enon, OH',13797,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33901,NULL,'Enon, OH 45323',13797,222,NULL,35,19811,0);
INSERT INTO "django_geo_db_location" VALUES(33902,NULL,'Fairborn, OH',13798,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33903,NULL,'Fairborn, OH 45324',13798,222,NULL,35,19812,0);
INSERT INTO "django_geo_db_location" VALUES(33904,NULL,'Farmersville, OH',13799,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33905,NULL,'Farmersville, OH 45325',13799,222,NULL,35,19813,0);
INSERT INTO "django_geo_db_location" VALUES(33906,NULL,'Fletcher, OH',13800,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33907,NULL,'Fletcher, OH 45326',13800,222,NULL,35,19814,0);
INSERT INTO "django_geo_db_location" VALUES(33908,NULL,'Germantown, OH',13801,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33909,NULL,'Germantown, OH 45327',13801,222,NULL,35,19815,0);
INSERT INTO "django_geo_db_location" VALUES(33910,NULL,'Gettysburg, OH',13802,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33911,NULL,'Gettysburg, OH 45328',13802,222,NULL,35,19816,0);
INSERT INTO "django_geo_db_location" VALUES(33912,NULL,'Gordon, OH',13803,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33913,NULL,'Gordon, OH 45329',13803,222,NULL,35,19817,0);
INSERT INTO "django_geo_db_location" VALUES(33914,NULL,'Gratis, OH',13804,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33915,NULL,'Gratis, OH 45330',13804,222,NULL,35,19818,0);
INSERT INTO "django_geo_db_location" VALUES(33916,NULL,'Greenville, OH',13805,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33917,NULL,'Greenville, OH 45331',13805,222,NULL,35,19819,0);
INSERT INTO "django_geo_db_location" VALUES(33918,NULL,'Hollansburg, OH',13806,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33919,NULL,'Hollansburg, OH 45332',13806,222,NULL,35,19820,0);
INSERT INTO "django_geo_db_location" VALUES(33920,NULL,'Houston, OH',13807,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33921,NULL,'Houston, OH 45333',13807,222,NULL,35,19821,0);
INSERT INTO "django_geo_db_location" VALUES(33922,NULL,'Jackson Center, OH',13808,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33923,NULL,'Jackson Center, OH 45334',13808,222,NULL,35,19822,0);
INSERT INTO "django_geo_db_location" VALUES(33924,NULL,'Jamestown, OH',13809,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33925,NULL,'Jamestown, OH 45335',13809,222,NULL,35,19823,0);
INSERT INTO "django_geo_db_location" VALUES(33926,NULL,'Kettlersville, OH',13810,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33927,NULL,'Kettlersville, OH 45336',13810,222,NULL,35,19824,0);
INSERT INTO "django_geo_db_location" VALUES(33928,NULL,'Laura, OH',13811,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33929,NULL,'Laura, OH 45337',13811,222,NULL,35,19825,0);
INSERT INTO "django_geo_db_location" VALUES(33930,NULL,'Lewisburg, OH',13812,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33931,NULL,'Lewisburg, OH 45338',13812,222,NULL,35,19826,0);
INSERT INTO "django_geo_db_location" VALUES(33932,NULL,'Ludlow Falls, OH',13813,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33933,NULL,'Ludlow Falls, OH 45339',13813,222,NULL,35,19827,0);
INSERT INTO "django_geo_db_location" VALUES(33934,NULL,'Maplewood, OH',13814,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33935,NULL,'Maplewood, OH 45340',13814,222,NULL,35,19828,0);
INSERT INTO "django_geo_db_location" VALUES(33936,NULL,'Medway, OH',13815,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33937,NULL,'Medway, OH 45341',13815,222,NULL,35,19829,0);
INSERT INTO "django_geo_db_location" VALUES(33938,NULL,'Miamisburg, OH',13816,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33939,NULL,'Miamisburg, OH 45342',13816,222,NULL,35,19830,0);
INSERT INTO "django_geo_db_location" VALUES(33940,NULL,'Miamisburg, OH 45343',13816,222,NULL,35,19831,0);
INSERT INTO "django_geo_db_location" VALUES(33941,NULL,'New Carlisle, OH',13817,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33942,NULL,'New Carlisle, OH 45344',13817,222,NULL,35,19832,0);
INSERT INTO "django_geo_db_location" VALUES(33943,NULL,'New Lebanon, OH',13818,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33944,NULL,'New Lebanon, OH 45345',13818,222,NULL,35,19833,0);
INSERT INTO "django_geo_db_location" VALUES(33945,NULL,'New Madison, OH',13819,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33946,NULL,'New Madison, OH 45346',13819,222,NULL,35,19834,0);
INSERT INTO "django_geo_db_location" VALUES(33947,NULL,'New Paris, OH',13820,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33948,NULL,'New Paris, OH 45347',13820,222,NULL,35,19835,0);
INSERT INTO "django_geo_db_location" VALUES(33949,NULL,'New Weston, OH',13821,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33950,NULL,'New Weston, OH 45348',13821,222,NULL,35,19836,0);
INSERT INTO "django_geo_db_location" VALUES(33951,NULL,'North Hampton, OH',13822,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33952,NULL,'North Hampton, OH 45349',13822,222,NULL,35,19837,0);
INSERT INTO "django_geo_db_location" VALUES(33953,NULL,'North Star, OH',13823,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33954,NULL,'North Star, OH 45350',13823,222,NULL,35,19838,0);
INSERT INTO "django_geo_db_location" VALUES(33955,NULL,'Osgood, OH',13824,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33956,NULL,'Osgood, OH 45351',13824,222,NULL,35,19839,0);
INSERT INTO "django_geo_db_location" VALUES(33957,NULL,'Palestine, OH',13825,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33958,NULL,'Palestine, OH 45352',13825,222,NULL,35,19840,0);
INSERT INTO "django_geo_db_location" VALUES(33959,NULL,'Pemberton, OH',13826,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33960,NULL,'Pemberton, OH 45353',13826,222,NULL,35,19841,0);
INSERT INTO "django_geo_db_location" VALUES(33961,NULL,'Phillipsburg, OH',13827,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33962,NULL,'Phillipsburg, OH 45354',13827,222,NULL,35,19842,0);
INSERT INTO "django_geo_db_location" VALUES(33963,NULL,'Piqua, OH',13828,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33964,NULL,'Piqua, OH 45356',13828,222,NULL,35,19843,0);
INSERT INTO "django_geo_db_location" VALUES(33965,NULL,'Pitsburg, OH',13829,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33966,NULL,'Pitsburg, OH 45358',13829,222,NULL,35,19844,0);
INSERT INTO "django_geo_db_location" VALUES(33967,NULL,'Pleasant Hill, OH',13830,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33968,NULL,'Pleasant Hill, OH 45359',13830,222,NULL,35,19845,0);
INSERT INTO "django_geo_db_location" VALUES(33969,NULL,'Port Jefferson, OH',13831,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33970,NULL,'Port Jefferson, OH 45360',13831,222,NULL,35,19846,0);
INSERT INTO "django_geo_db_location" VALUES(33971,NULL,'Potsdam, OH',13832,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33972,NULL,'Potsdam, OH 45361',13832,222,NULL,35,19847,0);
INSERT INTO "django_geo_db_location" VALUES(33973,NULL,'Rossburg, OH',13833,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33974,NULL,'Rossburg, OH 45362',13833,222,NULL,35,19848,0);
INSERT INTO "django_geo_db_location" VALUES(33975,NULL,'Russia, OH',13834,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33976,NULL,'Russia, OH 45363',13834,222,NULL,35,19849,0);
INSERT INTO "django_geo_db_location" VALUES(33977,NULL,'Sidney, OH',13835,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33978,NULL,'Sidney, OH 45365',13835,222,NULL,35,19850,0);
INSERT INTO "django_geo_db_location" VALUES(33979,NULL,'Sidney, OH 45367',13835,222,NULL,35,19851,0);
INSERT INTO "django_geo_db_location" VALUES(33980,NULL,'South Charleston, OH',13836,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33981,NULL,'South Charleston, OH 45368',13836,222,NULL,35,19852,0);
INSERT INTO "django_geo_db_location" VALUES(33982,NULL,'South Vienna, OH',13837,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33983,NULL,'South Vienna, OH 45369',13837,222,NULL,35,19853,0);
INSERT INTO "django_geo_db_location" VALUES(33984,NULL,'Spring Valley, OH',13838,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33985,NULL,'Spring Valley, OH 45370',13838,222,NULL,35,19854,0);
INSERT INTO "django_geo_db_location" VALUES(33986,NULL,'Tipp City, OH',13839,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33987,NULL,'Tipp City, OH 45371',13839,222,NULL,35,19855,0);
INSERT INTO "django_geo_db_location" VALUES(33988,NULL,'Tremont City, OH',13840,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33989,NULL,'Tremont City, OH 45372',13840,222,NULL,35,19856,0);
INSERT INTO "django_geo_db_location" VALUES(33990,NULL,'Troy, OH',13841,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33991,NULL,'Troy, OH 45373',13841,222,NULL,35,19857,0);
INSERT INTO "django_geo_db_location" VALUES(33992,NULL,'Troy, OH 45374',13841,222,NULL,35,19858,0);
INSERT INTO "django_geo_db_location" VALUES(33993,NULL,'Vandalia, OH',13842,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33994,NULL,'Vandalia, OH 45377',13842,222,NULL,35,19859,0);
INSERT INTO "django_geo_db_location" VALUES(33995,NULL,'Verona, OH',13843,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33996,NULL,'Verona, OH 45378',13843,222,NULL,35,19860,0);
INSERT INTO "django_geo_db_location" VALUES(33997,NULL,'Versailles, OH',13844,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(33998,NULL,'Versailles, OH 45380',13844,222,NULL,35,19861,0);
INSERT INTO "django_geo_db_location" VALUES(33999,NULL,'West Alexandria, OH',13845,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34000,NULL,'West Alexandria, OH 45381',13845,222,NULL,35,19862,0);
INSERT INTO "django_geo_db_location" VALUES(34001,NULL,'West Manchester, OH',13846,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34002,NULL,'West Manchester, OH 45382',13846,222,NULL,35,19863,0);
INSERT INTO "django_geo_db_location" VALUES(34003,NULL,'West Milton, OH',13847,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34004,NULL,'West Milton, OH 45383',13847,222,NULL,35,19864,0);
INSERT INTO "django_geo_db_location" VALUES(34005,NULL,'Wilberforce, OH',13848,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34006,NULL,'Wilberforce, OH 45384',13848,222,NULL,35,19865,0);
INSERT INTO "django_geo_db_location" VALUES(34007,NULL,'Xenia, OH',13849,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34008,NULL,'Xenia, OH 45385',13849,222,NULL,35,19866,0);
INSERT INTO "django_geo_db_location" VALUES(34009,NULL,'Yellow Springs, OH',13850,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34010,NULL,'Yellow Springs, OH 45387',13850,222,NULL,35,19867,0);
INSERT INTO "django_geo_db_location" VALUES(34011,NULL,'Yorkshire, OH',13851,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34012,NULL,'Yorkshire, OH 45388',13851,222,NULL,35,19868,0);
INSERT INTO "django_geo_db_location" VALUES(34013,NULL,'Christiansburg, OH',13852,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34014,NULL,'Christiansburg, OH 45389',13852,222,NULL,35,19869,0);
INSERT INTO "django_geo_db_location" VALUES(34015,NULL,'Union City, OH',13853,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34016,NULL,'Union City, OH 45390',13853,222,NULL,35,19870,0);
INSERT INTO "django_geo_db_location" VALUES(34017,NULL,'Dayton, OH',13854,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34018,NULL,'Dayton, OH 45401',13854,222,NULL,35,19871,0);
INSERT INTO "django_geo_db_location" VALUES(34019,NULL,'Dayton, OH 45402',13854,222,NULL,35,19872,0);
INSERT INTO "django_geo_db_location" VALUES(34020,NULL,'Dayton, OH 45403',13854,222,NULL,35,19873,0);
INSERT INTO "django_geo_db_location" VALUES(34021,NULL,'Dayton, OH 45404',13854,222,NULL,35,19874,0);
INSERT INTO "django_geo_db_location" VALUES(34022,NULL,'Dayton, OH 45405',13854,222,NULL,35,19875,0);
INSERT INTO "django_geo_db_location" VALUES(34023,NULL,'Dayton, OH 45406',13854,222,NULL,35,19876,0);
INSERT INTO "django_geo_db_location" VALUES(34024,NULL,'Dayton, OH 45407',13854,222,NULL,35,19877,0);
INSERT INTO "django_geo_db_location" VALUES(34025,NULL,'Dayton, OH 45408',13854,222,NULL,35,19878,0);
INSERT INTO "django_geo_db_location" VALUES(34026,NULL,'Dayton, OH 45409',13854,222,NULL,35,19879,0);
INSERT INTO "django_geo_db_location" VALUES(34027,NULL,'Dayton, OH 45410',13854,222,NULL,35,19880,0);
INSERT INTO "django_geo_db_location" VALUES(34028,NULL,'Dayton, OH 45412',13854,222,NULL,35,19881,0);
INSERT INTO "django_geo_db_location" VALUES(34029,NULL,'Dayton, OH 45413',13854,222,NULL,35,19882,0);
INSERT INTO "django_geo_db_location" VALUES(34030,NULL,'Dayton, OH 45414',13854,222,NULL,35,19883,0);
INSERT INTO "django_geo_db_location" VALUES(34031,NULL,'Dayton, OH 45415',13854,222,NULL,35,19884,0);
INSERT INTO "django_geo_db_location" VALUES(34032,NULL,'Dayton, OH 45416',13854,222,NULL,35,19885,0);
INSERT INTO "django_geo_db_location" VALUES(34033,NULL,'Dayton, OH 45417',13854,222,NULL,35,19886,0);
INSERT INTO "django_geo_db_location" VALUES(34034,NULL,'Dayton, OH 45418',13854,222,NULL,35,19887,0);
INSERT INTO "django_geo_db_location" VALUES(34035,NULL,'Dayton, OH 45419',13854,222,NULL,35,19888,0);
INSERT INTO "django_geo_db_location" VALUES(34036,NULL,'Dayton, OH 45420',13854,222,NULL,35,19889,0);
INSERT INTO "django_geo_db_location" VALUES(34037,NULL,'Dayton, OH 45422',13854,222,NULL,35,19890,0);
INSERT INTO "django_geo_db_location" VALUES(34038,NULL,'Dayton, OH 45423',13854,222,NULL,35,19891,0);
INSERT INTO "django_geo_db_location" VALUES(34039,NULL,'Dayton, OH 45424',13854,222,NULL,35,19892,0);
INSERT INTO "django_geo_db_location" VALUES(34040,NULL,'Dayton, OH 45426',13854,222,NULL,35,19893,0);
INSERT INTO "django_geo_db_location" VALUES(34041,NULL,'Dayton, OH 45427',13854,222,NULL,35,19894,0);
INSERT INTO "django_geo_db_location" VALUES(34042,NULL,'Dayton, OH 45428',13854,222,NULL,35,19895,0);
INSERT INTO "django_geo_db_location" VALUES(34043,NULL,'Dayton, OH 45429',13854,222,NULL,35,19896,0);
INSERT INTO "django_geo_db_location" VALUES(34044,NULL,'Dayton, OH 45430',13854,222,NULL,35,19897,0);
INSERT INTO "django_geo_db_location" VALUES(34045,NULL,'Dayton, OH 45431',13854,222,NULL,35,19898,0);
INSERT INTO "django_geo_db_location" VALUES(34046,NULL,'Dayton, OH 45432',13854,222,NULL,35,19899,0);
INSERT INTO "django_geo_db_location" VALUES(34047,NULL,'Dayton, OH 45433',13854,222,NULL,35,19900,0);
INSERT INTO "django_geo_db_location" VALUES(34048,NULL,'Dayton, OH 45434',13854,222,NULL,35,19901,0);
INSERT INTO "django_geo_db_location" VALUES(34049,NULL,'Dayton, OH 45435',13854,222,NULL,35,19902,0);
INSERT INTO "django_geo_db_location" VALUES(34050,NULL,'Dayton, OH 45437',13854,222,NULL,35,19903,0);
INSERT INTO "django_geo_db_location" VALUES(34051,NULL,'Dayton, OH 45439',13854,222,NULL,35,19904,0);
INSERT INTO "django_geo_db_location" VALUES(34052,NULL,'Dayton, OH 45440',13854,222,NULL,35,19905,0);
INSERT INTO "django_geo_db_location" VALUES(34053,NULL,'Dayton, OH 45441',13854,222,NULL,35,19906,0);
INSERT INTO "django_geo_db_location" VALUES(34054,NULL,'Dayton, OH 45448',13854,222,NULL,35,19907,0);
INSERT INTO "django_geo_db_location" VALUES(34055,NULL,'Dayton, OH 45449',13854,222,NULL,35,19908,0);
INSERT INTO "django_geo_db_location" VALUES(34056,NULL,'Dayton, OH 45454',13854,222,NULL,35,19909,0);
INSERT INTO "django_geo_db_location" VALUES(34057,NULL,'Dayton, OH 45458',13854,222,NULL,35,19910,0);
INSERT INTO "django_geo_db_location" VALUES(34058,NULL,'Dayton, OH 45459',13854,222,NULL,35,19911,0);
INSERT INTO "django_geo_db_location" VALUES(34059,NULL,'Dayton, OH 45463',13854,222,NULL,35,19912,0);
INSERT INTO "django_geo_db_location" VALUES(34060,NULL,'Dayton, OH 45469',13854,222,NULL,35,19913,0);
INSERT INTO "django_geo_db_location" VALUES(34061,NULL,'Dayton, OH 45470',13854,222,NULL,35,19914,0);
INSERT INTO "django_geo_db_location" VALUES(34062,NULL,'Dayton, OH 45475',13854,222,NULL,35,19915,0);
INSERT INTO "django_geo_db_location" VALUES(34063,NULL,'Dayton, OH 45479',13854,222,NULL,35,19916,0);
INSERT INTO "django_geo_db_location" VALUES(34064,NULL,'Dayton, OH 45481',13854,222,NULL,35,19917,0);
INSERT INTO "django_geo_db_location" VALUES(34065,NULL,'Dayton, OH 45482',13854,222,NULL,35,19918,0);
INSERT INTO "django_geo_db_location" VALUES(34066,NULL,'Dayton, OH 45490',13854,222,NULL,35,19919,0);
INSERT INTO "django_geo_db_location" VALUES(34067,NULL,'Springfield, OH',13855,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34068,NULL,'Springfield, OH 45501',13855,222,NULL,35,19920,0);
INSERT INTO "django_geo_db_location" VALUES(34069,NULL,'Springfield, OH 45502',13855,222,NULL,35,19921,0);
INSERT INTO "django_geo_db_location" VALUES(34070,NULL,'Springfield, OH 45503',13855,222,NULL,35,19922,0);
INSERT INTO "django_geo_db_location" VALUES(34071,NULL,'Springfield, OH 45504',13855,222,NULL,35,19923,0);
INSERT INTO "django_geo_db_location" VALUES(34072,NULL,'Springfield, OH 45505',13855,222,NULL,35,19924,0);
INSERT INTO "django_geo_db_location" VALUES(34073,NULL,'Springfield, OH 45506',13855,222,NULL,35,19925,0);
INSERT INTO "django_geo_db_location" VALUES(34074,NULL,'West Union, OH',13856,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34075,NULL,'West Union, OH 45553',13856,222,NULL,35,19926,0);
INSERT INTO "django_geo_db_location" VALUES(34076,NULL,'Chillicothe, OH',13857,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34077,NULL,'Chillicothe, OH 45601',13857,222,NULL,35,19927,0);
INSERT INTO "django_geo_db_location" VALUES(34078,NULL,'Bainbridge, OH',13858,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34079,NULL,'Bainbridge, OH 45612',13858,222,NULL,35,19928,0);
INSERT INTO "django_geo_db_location" VALUES(34080,NULL,'Beaver, OH',13859,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34081,NULL,'Beaver, OH 45613',13859,222,NULL,35,19929,0);
INSERT INTO "django_geo_db_location" VALUES(34082,NULL,'Bidwell, OH',13860,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34083,NULL,'Bidwell, OH 45614',13860,222,NULL,35,19930,0);
INSERT INTO "django_geo_db_location" VALUES(34084,NULL,'Blue Creek, OH',13861,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34085,NULL,'Blue Creek, OH 45616',13861,222,NULL,35,19931,0);
INSERT INTO "django_geo_db_location" VALUES(34086,NULL,'Bourneville, OH',13862,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34087,NULL,'Bourneville, OH 45617',13862,222,NULL,35,19932,0);
INSERT INTO "django_geo_db_location" VALUES(34088,NULL,'Cherry Fork, OH',13863,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34089,NULL,'Cherry Fork, OH 45618',13863,222,NULL,35,19933,0);
INSERT INTO "django_geo_db_location" VALUES(34090,NULL,'Chesapeake, OH',13864,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34091,NULL,'Chesapeake, OH 45619',13864,222,NULL,35,19934,0);
INSERT INTO "django_geo_db_location" VALUES(34092,NULL,'Cheshire, OH',13865,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34093,NULL,'Cheshire, OH 45620',13865,222,NULL,35,19935,0);
INSERT INTO "django_geo_db_location" VALUES(34094,NULL,'Coalton, OH',13866,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34095,NULL,'Coalton, OH 45621',13866,222,NULL,35,19936,0);
INSERT INTO "django_geo_db_location" VALUES(34096,NULL,'Creola, OH',13867,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34097,NULL,'Creola, OH 45622',13867,222,NULL,35,19937,0);
INSERT INTO "django_geo_db_location" VALUES(34098,NULL,'Crown City, OH',13868,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34099,NULL,'Crown City, OH 45623',13868,222,NULL,35,19938,0);
INSERT INTO "django_geo_db_location" VALUES(34100,NULL,'Cynthiana, OH',13869,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34101,NULL,'Cynthiana, OH 45624',13869,222,NULL,35,19939,0);
INSERT INTO "django_geo_db_location" VALUES(34102,NULL,'Frankfort, OH',13870,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34103,NULL,'Frankfort, OH 45628',13870,222,NULL,35,19940,0);
INSERT INTO "django_geo_db_location" VALUES(34104,NULL,'Franklin Furnace, OH',13871,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34105,NULL,'Franklin Furnace, OH 45629',13871,222,NULL,35,19941,0);
INSERT INTO "django_geo_db_location" VALUES(34106,NULL,'Friendship, OH',13872,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34107,NULL,'Friendship, OH 45630',13872,222,NULL,35,19942,0);
INSERT INTO "django_geo_db_location" VALUES(34108,NULL,'Gallipolis, OH',13873,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34109,NULL,'Gallipolis, OH 45631',13873,222,NULL,35,19943,0);
INSERT INTO "django_geo_db_location" VALUES(34110,NULL,'Hallsville, OH',13874,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34111,NULL,'Hallsville, OH 45633',13874,222,NULL,35,19944,0);
INSERT INTO "django_geo_db_location" VALUES(34112,NULL,'Hamden, OH',13875,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34113,NULL,'Hamden, OH 45634',13875,222,NULL,35,19945,0);
INSERT INTO "django_geo_db_location" VALUES(34114,NULL,'Haverhill, OH',13876,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34115,NULL,'Haverhill, OH 45636',13876,222,NULL,35,19946,0);
INSERT INTO "django_geo_db_location" VALUES(34116,NULL,'Ironton, OH',13877,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34117,NULL,'Ironton, OH 45638',13877,222,NULL,35,19947,0);
INSERT INTO "django_geo_db_location" VALUES(34118,NULL,'Jackson, OH',13878,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34119,NULL,'Jackson, OH 45640',13878,222,NULL,35,19948,0);
INSERT INTO "django_geo_db_location" VALUES(34120,NULL,'Morgan, OH',13879,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34121,NULL,'Morgan, OH 45641',13879,222,NULL,35,19949,0);
INSERT INTO "django_geo_db_location" VALUES(34122,NULL,'Jasper, OH',13880,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34123,NULL,'Jasper, OH 45642',13880,222,NULL,35,19950,0);
INSERT INTO "django_geo_db_location" VALUES(34124,NULL,'Kerr, OH',13881,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34125,NULL,'Kerr, OH 45643',13881,222,NULL,35,19951,0);
INSERT INTO "django_geo_db_location" VALUES(34126,NULL,'Kingston, OH',13882,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34127,NULL,'Kingston, OH 45644',13882,222,NULL,35,19952,0);
INSERT INTO "django_geo_db_location" VALUES(34128,NULL,'Kitts Hill, OH',13883,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34129,NULL,'Kitts Hill, OH 45645',13883,222,NULL,35,19953,0);
INSERT INTO "django_geo_db_location" VALUES(34130,NULL,'Latham, OH',13884,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34131,NULL,'Latham, OH 45646',13884,222,NULL,35,19954,0);
INSERT INTO "django_geo_db_location" VALUES(34132,NULL,'Londonderry, OH',13885,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34133,NULL,'Londonderry, OH 45647',13885,222,NULL,35,19955,0);
INSERT INTO "django_geo_db_location" VALUES(34134,NULL,'Lucasville, OH',13886,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34135,NULL,'Lucasville, OH 45648',13886,222,NULL,35,19956,0);
INSERT INTO "django_geo_db_location" VALUES(34136,NULL,'Lynx, OH',13887,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34137,NULL,'Lynx, OH 45650',13887,222,NULL,35,19957,0);
INSERT INTO "django_geo_db_location" VALUES(34138,NULL,'McArthur, OH',13888,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34139,NULL,'McArthur, OH 45651',13888,222,NULL,35,19958,0);
INSERT INTO "django_geo_db_location" VALUES(34140,NULL,'McDermott, OH',13889,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34141,NULL,'McDermott, OH 45652',13889,222,NULL,35,19959,0);
INSERT INTO "django_geo_db_location" VALUES(34142,NULL,'Minford, OH',13890,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34143,NULL,'Minford, OH 45653',13890,222,NULL,35,19960,0);
INSERT INTO "django_geo_db_location" VALUES(34144,NULL,'New Plymouth, OH',13891,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34145,NULL,'New Plymouth, OH 45654',13891,222,NULL,35,19961,0);
INSERT INTO "django_geo_db_location" VALUES(34146,NULL,'Oak Hill, OH',13892,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34147,NULL,'Oak Hill, OH 45656',13892,222,NULL,35,19962,0);
INSERT INTO "django_geo_db_location" VALUES(34148,NULL,'Otway, OH',13893,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34149,NULL,'Otway, OH 45657',13893,222,NULL,35,19963,0);
INSERT INTO "django_geo_db_location" VALUES(34150,NULL,'Patriot, OH',13894,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34151,NULL,'Patriot, OH 45658',13894,222,NULL,35,19964,0);
INSERT INTO "django_geo_db_location" VALUES(34152,NULL,'Pedro, OH',13895,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34153,NULL,'Pedro, OH 45659',13895,222,NULL,35,19965,0);
INSERT INTO "django_geo_db_location" VALUES(34154,NULL,'Peebles, OH',13896,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34155,NULL,'Peebles, OH 45660',13896,222,NULL,35,19966,0);
INSERT INTO "django_geo_db_location" VALUES(34156,NULL,'Piketon, OH',13897,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34157,NULL,'Piketon, OH 45661',13897,222,NULL,35,19967,0);
INSERT INTO "django_geo_db_location" VALUES(34158,NULL,'Portsmouth, OH',13898,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34159,NULL,'Portsmouth, OH 45662',13898,222,NULL,35,19968,0);
INSERT INTO "django_geo_db_location" VALUES(34160,NULL,'West Portsmouth, OH',13899,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34161,NULL,'West Portsmouth, OH 45663',13899,222,NULL,35,19969,0);
INSERT INTO "django_geo_db_location" VALUES(34162,NULL,'Proctorville, OH',13900,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34163,NULL,'Proctorville, OH 45669',13900,222,NULL,35,19970,0);
INSERT INTO "django_geo_db_location" VALUES(34164,NULL,'Wilkesville, OH',13901,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34165,NULL,'Wilkesville, OH 45670',13901,222,NULL,35,19971,0);
INSERT INTO "django_geo_db_location" VALUES(34166,NULL,'Rarden, OH',13902,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34167,NULL,'Rarden, OH 45671',13902,222,NULL,35,19972,0);
INSERT INTO "django_geo_db_location" VALUES(34168,NULL,'Ray, OH',13903,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34169,NULL,'Ray, OH 45672',13903,222,NULL,35,19973,0);
INSERT INTO "django_geo_db_location" VALUES(34170,NULL,'Richmond Dale, OH',13904,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34171,NULL,'Richmond Dale, OH 45673',13904,222,NULL,35,19974,0);
INSERT INTO "django_geo_db_location" VALUES(34172,NULL,'Rio Grande, OH',13905,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34173,NULL,'Rio Grande, OH 45674',13905,222,NULL,35,19975,0);
INSERT INTO "django_geo_db_location" VALUES(34174,NULL,'Rock Camp, OH',13906,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34175,NULL,'Rock Camp, OH 45675',13906,222,NULL,35,19976,0);
INSERT INTO "django_geo_db_location" VALUES(34176,NULL,'Scioto Furnace, OH',13907,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34177,NULL,'Scioto Furnace, OH 45677',13907,222,NULL,35,19977,0);
INSERT INTO "django_geo_db_location" VALUES(34178,NULL,'Scottown, OH',13908,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34179,NULL,'Scottown, OH 45678',13908,222,NULL,35,19978,0);
INSERT INTO "django_geo_db_location" VALUES(34180,NULL,'Seaman, OH',13909,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34181,NULL,'Seaman, OH 45679',13909,222,NULL,35,19979,0);
INSERT INTO "django_geo_db_location" VALUES(34182,NULL,'South Point, OH',13910,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34183,NULL,'South Point, OH 45680',13910,222,NULL,35,19980,0);
INSERT INTO "django_geo_db_location" VALUES(34184,NULL,'South Salem, OH',13911,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34185,NULL,'South Salem, OH 45681',13911,222,NULL,35,19981,0);
INSERT INTO "django_geo_db_location" VALUES(34186,NULL,'South Webster, OH',13912,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34187,NULL,'South Webster, OH 45682',13912,222,NULL,35,19982,0);
INSERT INTO "django_geo_db_location" VALUES(34188,NULL,'Stockdale, OH',13913,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34189,NULL,'Stockdale, OH 45683',13913,222,NULL,35,19983,0);
INSERT INTO "django_geo_db_location" VALUES(34190,NULL,'Stout, OH',13914,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34191,NULL,'Stout, OH 45684',13914,222,NULL,35,19984,0);
INSERT INTO "django_geo_db_location" VALUES(34192,NULL,'Thurman, OH',13915,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34193,NULL,'Thurman, OH 45685',13915,222,NULL,35,19985,0);
INSERT INTO "django_geo_db_location" VALUES(34194,NULL,'Vinton, OH',13916,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34195,NULL,'Vinton, OH 45686',13916,222,NULL,35,19986,0);
INSERT INTO "django_geo_db_location" VALUES(34196,NULL,'Wakefield, OH',13917,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34197,NULL,'Wakefield, OH 45687',13917,222,NULL,35,19987,0);
INSERT INTO "django_geo_db_location" VALUES(34198,NULL,'Waterloo, OH',13918,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34199,NULL,'Waterloo, OH 45688',13918,222,NULL,35,19988,0);
INSERT INTO "django_geo_db_location" VALUES(34200,NULL,'Waverly, OH',13919,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34201,NULL,'Waverly, OH 45690',13919,222,NULL,35,19989,0);
INSERT INTO "django_geo_db_location" VALUES(34202,NULL,'Wellston, OH',13920,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34203,NULL,'Wellston, OH 45692',13920,222,NULL,35,19990,0);
INSERT INTO "django_geo_db_location" VALUES(34204,NULL,'West Union, OH 45693',13856,222,NULL,35,19991,0);
INSERT INTO "django_geo_db_location" VALUES(34205,NULL,'Wheelersburg, OH',13921,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34206,NULL,'Wheelersburg, OH 45694',13921,222,NULL,35,19992,0);
INSERT INTO "django_geo_db_location" VALUES(34207,NULL,'Wilkesville, OH 45695',13901,222,NULL,35,19993,0);
INSERT INTO "django_geo_db_location" VALUES(34208,NULL,'Willow Wood, OH',13922,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34209,NULL,'Willow Wood, OH 45696',13922,222,NULL,35,19994,0);
INSERT INTO "django_geo_db_location" VALUES(34210,NULL,'Winchester, OH',13923,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34211,NULL,'Winchester, OH 45697',13923,222,NULL,35,19995,0);
INSERT INTO "django_geo_db_location" VALUES(34212,NULL,'Zaleski, OH',13924,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34213,NULL,'Zaleski, OH 45698',13924,222,NULL,35,19996,0);
INSERT INTO "django_geo_db_location" VALUES(34214,NULL,'Lucasville, OH 45699',13886,222,NULL,35,19997,0);
INSERT INTO "django_geo_db_location" VALUES(34215,NULL,'Athens, OH',13925,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34216,NULL,'Athens, OH 45701',13925,222,NULL,35,19998,0);
INSERT INTO "django_geo_db_location" VALUES(34217,NULL,'Albany, OH',13926,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34218,NULL,'Albany, OH 45710',13926,222,NULL,35,19999,0);
INSERT INTO "django_geo_db_location" VALUES(34219,NULL,'Amesville, OH',13927,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34220,NULL,'Amesville, OH 45711',13927,222,NULL,35,20000,0);
INSERT INTO "django_geo_db_location" VALUES(34221,NULL,'Barlow, OH',13928,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34222,NULL,'Barlow, OH 45712',13928,222,NULL,35,20001,0);
INSERT INTO "django_geo_db_location" VALUES(34223,NULL,'Bartlett, OH',13929,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34224,NULL,'Bartlett, OH 45713',13929,222,NULL,35,20002,0);
INSERT INTO "django_geo_db_location" VALUES(34225,NULL,'Belpre, OH',13930,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34226,NULL,'Belpre, OH 45714',13930,222,NULL,35,20003,0);
INSERT INTO "django_geo_db_location" VALUES(34227,NULL,'Beverly, OH',13931,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34228,NULL,'Beverly, OH 45715',13931,222,NULL,35,20004,0);
INSERT INTO "django_geo_db_location" VALUES(34229,NULL,'Buchtel, OH',13932,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34230,NULL,'Buchtel, OH 45716',13932,222,NULL,35,20005,0);
INSERT INTO "django_geo_db_location" VALUES(34231,NULL,'Carbondale, OH',13933,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34232,NULL,'Carbondale, OH 45717',13933,222,NULL,35,20006,0);
INSERT INTO "django_geo_db_location" VALUES(34233,NULL,'Chauncey, OH',13934,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34234,NULL,'Chauncey, OH 45719',13934,222,NULL,35,20007,0);
INSERT INTO "django_geo_db_location" VALUES(34235,NULL,'Chester, OH',13935,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34236,NULL,'Chester, OH 45720',13935,222,NULL,35,20008,0);
INSERT INTO "django_geo_db_location" VALUES(34237,NULL,'Coal Run, OH',13936,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34238,NULL,'Coal Run, OH 45721',13936,222,NULL,35,20009,0);
INSERT INTO "django_geo_db_location" VALUES(34239,NULL,'Coolville, OH',13937,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34240,NULL,'Coolville, OH 45723',13937,222,NULL,35,20010,0);
INSERT INTO "django_geo_db_location" VALUES(34241,NULL,'Cutler, OH',13938,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34242,NULL,'Cutler, OH 45724',13938,222,NULL,35,20011,0);
INSERT INTO "django_geo_db_location" VALUES(34243,NULL,'Dexter City, OH',13939,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34244,NULL,'Dexter City, OH 45727',13939,222,NULL,35,20012,0);
INSERT INTO "django_geo_db_location" VALUES(34245,NULL,'Fleming, OH',13940,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34246,NULL,'Fleming, OH 45729',13940,222,NULL,35,20013,0);
INSERT INTO "django_geo_db_location" VALUES(34247,NULL,'Glouster, OH',13941,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34248,NULL,'Glouster, OH 45732',13941,222,NULL,35,20014,0);
INSERT INTO "django_geo_db_location" VALUES(34249,NULL,'Graysville, OH',13942,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34250,NULL,'Graysville, OH 45734',13942,222,NULL,35,20015,0);
INSERT INTO "django_geo_db_location" VALUES(34251,NULL,'Guysville, OH',13943,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34252,NULL,'Guysville, OH 45735',13943,222,NULL,35,20016,0);
INSERT INTO "django_geo_db_location" VALUES(34253,NULL,'Hockingport, OH',13944,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34254,NULL,'Hockingport, OH 45739',13944,222,NULL,35,20017,0);
INSERT INTO "django_geo_db_location" VALUES(34255,NULL,'Jacksonville, OH',13945,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34256,NULL,'Jacksonville, OH 45740',13945,222,NULL,35,20018,0);
INSERT INTO "django_geo_db_location" VALUES(34257,NULL,'Langsville, OH',13946,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34258,NULL,'Langsville, OH 45741',13946,222,NULL,35,20019,0);
INSERT INTO "django_geo_db_location" VALUES(34259,NULL,'Little Hocking, OH',13947,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34260,NULL,'Little Hocking, OH 45742',13947,222,NULL,35,20020,0);
INSERT INTO "django_geo_db_location" VALUES(34261,NULL,'Long Bottom, OH',13948,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34262,NULL,'Long Bottom, OH 45743',13948,222,NULL,35,20021,0);
INSERT INTO "django_geo_db_location" VALUES(34263,NULL,'Lowell, OH',13949,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34264,NULL,'Lowell, OH 45744',13949,222,NULL,35,20022,0);
INSERT INTO "django_geo_db_location" VALUES(34265,NULL,'Lower Salem, OH',13950,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34266,NULL,'Lower Salem, OH 45745',13950,222,NULL,35,20023,0);
INSERT INTO "django_geo_db_location" VALUES(34267,NULL,'Macksburg, OH',13951,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34268,NULL,'Macksburg, OH 45746',13951,222,NULL,35,20024,0);
INSERT INTO "django_geo_db_location" VALUES(34269,NULL,'Marietta, OH',13952,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34270,NULL,'Marietta, OH 45750',13952,222,NULL,35,20025,0);
INSERT INTO "django_geo_db_location" VALUES(34271,NULL,'Dexter City, OH 45757',13939,222,NULL,35,20026,0);
INSERT INTO "django_geo_db_location" VALUES(34272,NULL,'Middleport, OH',13953,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34273,NULL,'Middleport, OH 45760',13953,222,NULL,35,20027,0);
INSERT INTO "django_geo_db_location" VALUES(34274,NULL,'Millfield, OH',13954,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34275,NULL,'Millfield, OH 45761',13954,222,NULL,35,20028,0);
INSERT INTO "django_geo_db_location" VALUES(34276,NULL,'Nelsonville, OH',13955,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34277,NULL,'Nelsonville, OH 45764',13955,222,NULL,35,20029,0);
INSERT INTO "django_geo_db_location" VALUES(34278,NULL,'New Marshfield, OH',13956,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34279,NULL,'New Marshfield, OH 45766',13956,222,NULL,35,20030,0);
INSERT INTO "django_geo_db_location" VALUES(34280,NULL,'New Matamoras, OH',13957,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34281,NULL,'New Matamoras, OH 45767',13957,222,NULL,35,20031,0);
INSERT INTO "django_geo_db_location" VALUES(34282,NULL,'Newport, OH',13958,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34283,NULL,'Newport, OH 45768',13958,222,NULL,35,20032,0);
INSERT INTO "django_geo_db_location" VALUES(34284,NULL,'Pomeroy, OH',13959,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34285,NULL,'Pomeroy, OH 45769',13959,222,NULL,35,20033,0);
INSERT INTO "django_geo_db_location" VALUES(34286,NULL,'Portland, OH',13960,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34287,NULL,'Portland, OH 45770',13960,222,NULL,35,20034,0);
INSERT INTO "django_geo_db_location" VALUES(34288,NULL,'Racine, OH',13961,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34289,NULL,'Racine, OH 45771',13961,222,NULL,35,20035,0);
INSERT INTO "django_geo_db_location" VALUES(34290,NULL,'Reedsville, OH',13962,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34291,NULL,'Reedsville, OH 45772',13962,222,NULL,35,20036,0);
INSERT INTO "django_geo_db_location" VALUES(34292,NULL,'Reno, OH',13963,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34293,NULL,'Reno, OH 45773',13963,222,NULL,35,20037,0);
INSERT INTO "django_geo_db_location" VALUES(34294,NULL,'Rutland, OH',13964,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34295,NULL,'Rutland, OH 45775',13964,222,NULL,35,20038,0);
INSERT INTO "django_geo_db_location" VALUES(34296,NULL,'Shade, OH',13965,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34297,NULL,'Shade, OH 45776',13965,222,NULL,35,20039,0);
INSERT INTO "django_geo_db_location" VALUES(34298,NULL,'Sharpsburg, OH',13966,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34299,NULL,'Sharpsburg, OH 45777',13966,222,NULL,35,20040,0);
INSERT INTO "django_geo_db_location" VALUES(34300,NULL,'Stewart, OH',13967,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34301,NULL,'Stewart, OH 45778',13967,222,NULL,35,20041,0);
INSERT INTO "django_geo_db_location" VALUES(34302,NULL,'Syracuse, OH',13968,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34303,NULL,'Syracuse, OH 45779',13968,222,NULL,35,20042,0);
INSERT INTO "django_geo_db_location" VALUES(34304,NULL,'The Plains, OH',13969,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34305,NULL,'The Plains, OH 45780',13969,222,NULL,35,20043,0);
INSERT INTO "django_geo_db_location" VALUES(34306,NULL,'Torch, OH',13970,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34307,NULL,'Torch, OH 45781',13970,222,NULL,35,20044,0);
INSERT INTO "django_geo_db_location" VALUES(34308,NULL,'Trimble, OH',13971,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34309,NULL,'Trimble, OH 45782',13971,222,NULL,35,20045,0);
INSERT INTO "django_geo_db_location" VALUES(34310,NULL,'Tuppers Plains, OH',13972,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34311,NULL,'Tuppers Plains, OH 45783',13972,222,NULL,35,20046,0);
INSERT INTO "django_geo_db_location" VALUES(34312,NULL,'Vincent, OH',13973,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34313,NULL,'Vincent, OH 45784',13973,222,NULL,35,20047,0);
INSERT INTO "django_geo_db_location" VALUES(34314,NULL,'Waterford, OH',13974,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34315,NULL,'Waterford, OH 45786',13974,222,NULL,35,20048,0);
INSERT INTO "django_geo_db_location" VALUES(34316,NULL,'Watertown, OH',13975,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34317,NULL,'Watertown, OH 45787',13975,222,NULL,35,20049,0);
INSERT INTO "django_geo_db_location" VALUES(34318,NULL,'Whipple, OH',13976,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34319,NULL,'Whipple, OH 45788',13976,222,NULL,35,20050,0);
INSERT INTO "django_geo_db_location" VALUES(34320,NULL,'Wingett Run, OH',13977,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34321,NULL,'Wingett Run, OH 45789',13977,222,NULL,35,20051,0);
INSERT INTO "django_geo_db_location" VALUES(34322,NULL,'Lima, OH',13978,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34323,NULL,'Lima, OH 45801',13978,222,NULL,35,20052,0);
INSERT INTO "django_geo_db_location" VALUES(34324,NULL,'Lima, OH 45802',13978,222,NULL,35,20053,0);
INSERT INTO "django_geo_db_location" VALUES(34325,NULL,'Lima, OH 45804',13978,222,NULL,35,20054,0);
INSERT INTO "django_geo_db_location" VALUES(34326,NULL,'Lima, OH 45805',13978,222,NULL,35,20055,0);
INSERT INTO "django_geo_db_location" VALUES(34327,NULL,'Lima, OH 45806',13978,222,NULL,35,20056,0);
INSERT INTO "django_geo_db_location" VALUES(34328,NULL,'Lima, OH 45807',13978,222,NULL,35,20057,0);
INSERT INTO "django_geo_db_location" VALUES(34329,NULL,'Beaverdam, OH',13979,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34330,NULL,'Beaverdam, OH 45808',13979,222,NULL,35,20058,0);
INSERT INTO "django_geo_db_location" VALUES(34331,NULL,'Gomer, OH',13980,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34332,NULL,'Gomer, OH 45809',13980,222,NULL,35,20059,0);
INSERT INTO "django_geo_db_location" VALUES(34333,NULL,'Ada, OH',13981,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34334,NULL,'Ada, OH 45810',13981,222,NULL,35,20060,0);
INSERT INTO "django_geo_db_location" VALUES(34335,NULL,'Alger, OH',13982,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34336,NULL,'Alger, OH 45812',13982,222,NULL,35,20061,0);
INSERT INTO "django_geo_db_location" VALUES(34337,NULL,'Antwerp, OH',13983,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34338,NULL,'Antwerp, OH 45813',13983,222,NULL,35,20062,0);
INSERT INTO "django_geo_db_location" VALUES(34339,NULL,'Arlington, OH',13984,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34340,NULL,'Arlington, OH 45814',13984,222,NULL,35,20063,0);
INSERT INTO "django_geo_db_location" VALUES(34341,NULL,'Belmore, OH',13985,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34342,NULL,'Belmore, OH 45815',13985,222,NULL,35,20064,0);
INSERT INTO "django_geo_db_location" VALUES(34343,NULL,'Benton Ridge, OH',13986,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34344,NULL,'Benton Ridge, OH 45816',13986,222,NULL,35,20065,0);
INSERT INTO "django_geo_db_location" VALUES(34345,NULL,'Bluffton, OH',13987,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34346,NULL,'Bluffton, OH 45817',13987,222,NULL,35,20066,0);
INSERT INTO "django_geo_db_location" VALUES(34347,NULL,'Buckland, OH',13988,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34348,NULL,'Buckland, OH 45819',13988,222,NULL,35,20067,0);
INSERT INTO "django_geo_db_location" VALUES(34349,NULL,'Cairo, OH',13989,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34350,NULL,'Cairo, OH 45820',13989,222,NULL,35,20068,0);
INSERT INTO "django_geo_db_location" VALUES(34351,NULL,'Cecil, OH',13990,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34352,NULL,'Cecil, OH 45821',13990,222,NULL,35,20069,0);
INSERT INTO "django_geo_db_location" VALUES(34353,NULL,'Celina, OH',13991,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34354,NULL,'Celina, OH 45822',13991,222,NULL,35,20070,0);
INSERT INTO "django_geo_db_location" VALUES(34355,NULL,'Chickasaw, OH',13992,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34356,NULL,'Chickasaw, OH 45826',13992,222,NULL,35,20071,0);
INSERT INTO "django_geo_db_location" VALUES(34357,NULL,'Cloverdale, OH',13993,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34358,NULL,'Cloverdale, OH 45827',13993,222,NULL,35,20072,0);
INSERT INTO "django_geo_db_location" VALUES(34359,NULL,'Coldwater, OH',13994,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34360,NULL,'Coldwater, OH 45828',13994,222,NULL,35,20073,0);
INSERT INTO "django_geo_db_location" VALUES(34361,NULL,'Crane, OH',13995,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34362,NULL,'Crane, OH 45829',13995,222,NULL,35,20074,0);
INSERT INTO "django_geo_db_location" VALUES(34363,NULL,'Columbus Grove, OH',13996,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34364,NULL,'Columbus Grove, OH 45830',13996,222,NULL,35,20075,0);
INSERT INTO "django_geo_db_location" VALUES(34365,NULL,'Continental, OH',13997,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34366,NULL,'Continental, OH 45831',13997,222,NULL,35,20076,0);
INSERT INTO "django_geo_db_location" VALUES(34367,NULL,'Convoy, OH',13998,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34368,NULL,'Convoy, OH 45832',13998,222,NULL,35,20077,0);
INSERT INTO "django_geo_db_location" VALUES(34369,NULL,'Delphos, OH',13999,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34370,NULL,'Delphos, OH 45833',13999,222,NULL,35,20078,0);
INSERT INTO "django_geo_db_location" VALUES(34371,NULL,'Dola, OH',14000,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34372,NULL,'Dola, OH 45835',14000,222,NULL,35,20079,0);
INSERT INTO "django_geo_db_location" VALUES(34373,NULL,'Dunkirk, OH',14001,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34374,NULL,'Dunkirk, OH 45836',14001,222,NULL,35,20080,0);
INSERT INTO "django_geo_db_location" VALUES(34375,NULL,'Dupont, OH',14002,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34376,NULL,'Dupont, OH 45837',14002,222,NULL,35,20081,0);
INSERT INTO "django_geo_db_location" VALUES(34377,NULL,'Elgin, OH',14003,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34378,NULL,'Elgin, OH 45838',14003,222,NULL,35,20082,0);
INSERT INTO "django_geo_db_location" VALUES(34379,NULL,'Findlay, OH',14004,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34380,NULL,'Findlay, OH 45839',14004,222,NULL,35,20083,0);
INSERT INTO "django_geo_db_location" VALUES(34381,NULL,'Findlay, OH 45840',14004,222,NULL,35,20084,0);
INSERT INTO "django_geo_db_location" VALUES(34382,NULL,'Jenera, OH',14005,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34383,NULL,'Jenera, OH 45841',14005,222,NULL,35,20085,0);
INSERT INTO "django_geo_db_location" VALUES(34384,NULL,'Forest, OH',14006,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34385,NULL,'Forest, OH 45843',14006,222,NULL,35,20086,0);
INSERT INTO "django_geo_db_location" VALUES(34386,NULL,'Fort Jennings, OH',14007,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34387,NULL,'Fort Jennings, OH 45844',14007,222,NULL,35,20087,0);
INSERT INTO "django_geo_db_location" VALUES(34388,NULL,'Fort Loramie, OH',14008,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34389,NULL,'Fort Loramie, OH 45845',14008,222,NULL,35,20088,0);
INSERT INTO "django_geo_db_location" VALUES(34390,NULL,'Fort Recovery, OH',14009,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34391,NULL,'Fort Recovery, OH 45846',14009,222,NULL,35,20089,0);
INSERT INTO "django_geo_db_location" VALUES(34392,NULL,'Glandorf, OH',14010,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34393,NULL,'Glandorf, OH 45848',14010,222,NULL,35,20090,0);
INSERT INTO "django_geo_db_location" VALUES(34394,NULL,'Grover Hill, OH',14011,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34395,NULL,'Grover Hill, OH 45849',14011,222,NULL,35,20091,0);
INSERT INTO "django_geo_db_location" VALUES(34396,NULL,'Harrod, OH',14012,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34397,NULL,'Harrod, OH 45850',14012,222,NULL,35,20092,0);
INSERT INTO "django_geo_db_location" VALUES(34398,NULL,'Haviland, OH',14013,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34399,NULL,'Haviland, OH 45851',14013,222,NULL,35,20093,0);
INSERT INTO "django_geo_db_location" VALUES(34400,NULL,'Kalida, OH',14014,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34401,NULL,'Kalida, OH 45853',14014,222,NULL,35,20094,0);
INSERT INTO "django_geo_db_location" VALUES(34402,NULL,'Lafayette, OH',14015,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34403,NULL,'Lafayette, OH 45854',14015,222,NULL,35,20095,0);
INSERT INTO "django_geo_db_location" VALUES(34404,NULL,'Latty, OH',14016,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34405,NULL,'Latty, OH 45855',14016,222,NULL,35,20096,0);
INSERT INTO "django_geo_db_location" VALUES(34406,NULL,'Leipsic, OH',14017,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34407,NULL,'Leipsic, OH 45856',14017,222,NULL,35,20097,0);
INSERT INTO "django_geo_db_location" VALUES(34408,NULL,'McComb, OH',14018,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34409,NULL,'McComb, OH 45858',14018,222,NULL,35,20098,0);
INSERT INTO "django_geo_db_location" VALUES(34410,NULL,'McGuffey, OH',14019,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34411,NULL,'McGuffey, OH 45859',14019,222,NULL,35,20099,0);
INSERT INTO "django_geo_db_location" VALUES(34412,NULL,'Maria Stein, OH',14020,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34413,NULL,'Maria Stein, OH 45860',14020,222,NULL,35,20100,0);
INSERT INTO "django_geo_db_location" VALUES(34414,NULL,'Melrose, OH',14021,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34415,NULL,'Melrose, OH 45861',14021,222,NULL,35,20101,0);
INSERT INTO "django_geo_db_location" VALUES(34416,NULL,'Mendon, OH',14022,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34417,NULL,'Mendon, OH 45862',14022,222,NULL,35,20102,0);
INSERT INTO "django_geo_db_location" VALUES(34418,NULL,'Middle Point, OH',14023,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34419,NULL,'Middle Point, OH 45863',14023,222,NULL,35,20103,0);
INSERT INTO "django_geo_db_location" VALUES(34420,NULL,'Miller City, OH',14024,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34421,NULL,'Miller City, OH 45864',14024,222,NULL,35,20104,0);
INSERT INTO "django_geo_db_location" VALUES(34422,NULL,'Minster, OH',14025,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34423,NULL,'Minster, OH 45865',14025,222,NULL,35,20105,0);
INSERT INTO "django_geo_db_location" VALUES(34424,NULL,'Montezuma, OH',14026,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34425,NULL,'Montezuma, OH 45866',14026,222,NULL,35,20106,0);
INSERT INTO "django_geo_db_location" VALUES(34426,NULL,'Mount Blanchard, OH',14027,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34427,NULL,'Mount Blanchard, OH 45867',14027,222,NULL,35,20107,0);
INSERT INTO "django_geo_db_location" VALUES(34428,NULL,'Mount Cory, OH',14028,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34429,NULL,'Mount Cory, OH 45868',14028,222,NULL,35,20108,0);
INSERT INTO "django_geo_db_location" VALUES(34430,NULL,'New Bremen, OH',14029,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34431,NULL,'New Bremen, OH 45869',14029,222,NULL,35,20109,0);
INSERT INTO "django_geo_db_location" VALUES(34432,NULL,'New Hampshire, OH',14030,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34433,NULL,'New Hampshire, OH 45870',14030,222,NULL,35,20110,0);
INSERT INTO "django_geo_db_location" VALUES(34434,NULL,'New Knoxville, OH',14031,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34435,NULL,'New Knoxville, OH 45871',14031,222,NULL,35,20111,0);
INSERT INTO "django_geo_db_location" VALUES(34436,NULL,'North Baltimore, OH',14032,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34437,NULL,'North Baltimore, OH 45872',14032,222,NULL,35,20112,0);
INSERT INTO "django_geo_db_location" VALUES(34438,NULL,'Oakwood, OH',14033,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34439,NULL,'Oakwood, OH 45873',14033,222,NULL,35,20113,0);
INSERT INTO "django_geo_db_location" VALUES(34440,NULL,'Ohio City, OH',14034,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34441,NULL,'Ohio City, OH 45874',14034,222,NULL,35,20114,0);
INSERT INTO "django_geo_db_location" VALUES(34442,NULL,'Ottawa, OH',14035,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34443,NULL,'Ottawa, OH 45875',14035,222,NULL,35,20115,0);
INSERT INTO "django_geo_db_location" VALUES(34444,NULL,'Ottoville, OH',14036,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34445,NULL,'Ottoville, OH 45876',14036,222,NULL,35,20116,0);
INSERT INTO "django_geo_db_location" VALUES(34446,NULL,'Pandora, OH',14037,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34447,NULL,'Pandora, OH 45877',14037,222,NULL,35,20117,0);
INSERT INTO "django_geo_db_location" VALUES(34448,NULL,'Paulding, OH',14038,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34449,NULL,'Paulding, OH 45879',14038,222,NULL,35,20118,0);
INSERT INTO "django_geo_db_location" VALUES(34450,NULL,'Payne, OH',14039,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34451,NULL,'Payne, OH 45880',14039,222,NULL,35,20119,0);
INSERT INTO "django_geo_db_location" VALUES(34452,NULL,'Rawson, OH',14040,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34453,NULL,'Rawson, OH 45881',14040,222,NULL,35,20120,0);
INSERT INTO "django_geo_db_location" VALUES(34454,NULL,'Rockford, OH',14041,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34455,NULL,'Rockford, OH 45882',14041,222,NULL,35,20121,0);
INSERT INTO "django_geo_db_location" VALUES(34456,NULL,'Saint Henry, OH',14042,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34457,NULL,'Saint Henry, OH 45883',14042,222,NULL,35,20122,0);
INSERT INTO "django_geo_db_location" VALUES(34458,NULL,'Saint Johns, OH',14043,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34459,NULL,'Saint Johns, OH 45884',14043,222,NULL,35,20123,0);
INSERT INTO "django_geo_db_location" VALUES(34460,NULL,'Saint Marys, OH',14044,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34461,NULL,'Saint Marys, OH 45885',14044,222,NULL,35,20124,0);
INSERT INTO "django_geo_db_location" VALUES(34462,NULL,'Scott, OH',14045,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34463,NULL,'Scott, OH 45886',14045,222,NULL,35,20125,0);
INSERT INTO "django_geo_db_location" VALUES(34464,NULL,'Spencerville, OH',14046,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34465,NULL,'Spencerville, OH 45887',14046,222,NULL,35,20126,0);
INSERT INTO "django_geo_db_location" VALUES(34466,NULL,'Uniopolis, OH',14047,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34467,NULL,'Uniopolis, OH 45888',14047,222,NULL,35,20127,0);
INSERT INTO "django_geo_db_location" VALUES(34468,NULL,'Van Buren, OH',14048,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34469,NULL,'Van Buren, OH 45889',14048,222,NULL,35,20128,0);
INSERT INTO "django_geo_db_location" VALUES(34470,NULL,'Vanlue, OH',14049,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34471,NULL,'Vanlue, OH 45890',14049,222,NULL,35,20129,0);
INSERT INTO "django_geo_db_location" VALUES(34472,NULL,'Van Wert, OH',14050,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34473,NULL,'Van Wert, OH 45891',14050,222,NULL,35,20130,0);
INSERT INTO "django_geo_db_location" VALUES(34474,NULL,'Vaughnsville, OH',14051,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34475,NULL,'Vaughnsville, OH 45893',14051,222,NULL,35,20131,0);
INSERT INTO "django_geo_db_location" VALUES(34476,NULL,'Venedocia, OH',14052,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34477,NULL,'Venedocia, OH 45894',14052,222,NULL,35,20132,0);
INSERT INTO "django_geo_db_location" VALUES(34478,NULL,'Wapakoneta, OH',14053,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34479,NULL,'Wapakoneta, OH 45895',14053,222,NULL,35,20133,0);
INSERT INTO "django_geo_db_location" VALUES(34480,NULL,'Waynesfield, OH',14054,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34481,NULL,'Waynesfield, OH 45896',14054,222,NULL,35,20134,0);
INSERT INTO "django_geo_db_location" VALUES(34482,NULL,'Williamstown, OH',14055,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34483,NULL,'Williamstown, OH 45897',14055,222,NULL,35,20135,0);
INSERT INTO "django_geo_db_location" VALUES(34484,NULL,'Willshire, OH',14056,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34485,NULL,'Willshire, OH 45898',14056,222,NULL,35,20136,0);
INSERT INTO "django_geo_db_location" VALUES(34486,NULL,'Wren, OH',14057,222,NULL,35,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34487,NULL,'Wren, OH 45899',14057,222,NULL,35,20137,0);
INSERT INTO "django_geo_db_location" VALUES(34488,NULL,'Cincinnati, OH 45944',13775,222,NULL,35,20138,0);
INSERT INTO "django_geo_db_location" VALUES(34489,NULL,'Cincinnati, OH 45999',13775,222,NULL,35,20139,0);
INSERT INTO "django_geo_db_location" VALUES(34490,NULL,'Alexandria, IN',14058,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34491,NULL,'Alexandria, IN 46001',14058,222,NULL,18,20140,0);
INSERT INTO "django_geo_db_location" VALUES(34492,NULL,'Anderson, IN',14059,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34493,NULL,'Anderson, IN 46011',14059,222,NULL,18,20141,0);
INSERT INTO "django_geo_db_location" VALUES(34494,NULL,'Anderson, IN 46012',14059,222,NULL,18,20142,0);
INSERT INTO "django_geo_db_location" VALUES(34495,NULL,'Anderson, IN 46013',14059,222,NULL,18,20143,0);
INSERT INTO "django_geo_db_location" VALUES(34496,NULL,'Anderson, IN 46014',14059,222,NULL,18,20144,0);
INSERT INTO "django_geo_db_location" VALUES(34497,NULL,'Anderson, IN 46015',14059,222,NULL,18,20145,0);
INSERT INTO "django_geo_db_location" VALUES(34498,NULL,'Anderson, IN 46016',14059,222,NULL,18,20146,0);
INSERT INTO "django_geo_db_location" VALUES(34499,NULL,'Anderson, IN 46017',14059,222,NULL,18,20147,0);
INSERT INTO "django_geo_db_location" VALUES(34500,NULL,'Anderson, IN 46018',14059,222,NULL,18,20148,0);
INSERT INTO "django_geo_db_location" VALUES(34501,NULL,'Arcadia, IN',14060,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34502,NULL,'Arcadia, IN 46030',14060,222,NULL,18,20149,0);
INSERT INTO "django_geo_db_location" VALUES(34503,NULL,'Atlanta, IN',14061,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34504,NULL,'Atlanta, IN 46031',14061,222,NULL,18,20150,0);
INSERT INTO "django_geo_db_location" VALUES(34505,NULL,'Carmel, IN',14062,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34506,NULL,'Carmel, IN 46032',14062,222,NULL,18,20151,0);
INSERT INTO "django_geo_db_location" VALUES(34507,NULL,'Carmel, IN 46033',14062,222,NULL,18,20152,0);
INSERT INTO "django_geo_db_location" VALUES(34508,NULL,'Cicero, IN',14063,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34509,NULL,'Cicero, IN 46034',14063,222,NULL,18,20153,0);
INSERT INTO "django_geo_db_location" VALUES(34510,NULL,'Colfax, IN',14064,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34511,NULL,'Colfax, IN 46035',14064,222,NULL,18,20154,0);
INSERT INTO "django_geo_db_location" VALUES(34512,NULL,'Elwood, IN',14065,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34513,NULL,'Elwood, IN 46036',14065,222,NULL,18,20155,0);
INSERT INTO "django_geo_db_location" VALUES(34514,NULL,'Fishers, IN',14066,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34515,NULL,'Fishers, IN 46038',14066,222,NULL,18,20156,0);
INSERT INTO "django_geo_db_location" VALUES(34516,NULL,'Forest, IN',14067,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34517,NULL,'Forest, IN 46039',14067,222,NULL,18,20157,0);
INSERT INTO "django_geo_db_location" VALUES(34518,NULL,'Fortville, IN',14068,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34519,NULL,'Fortville, IN 46040',14068,222,NULL,18,20158,0);
INSERT INTO "django_geo_db_location" VALUES(34520,NULL,'Frankfort, IN',14069,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34521,NULL,'Frankfort, IN 46041',14069,222,NULL,18,20159,0);
INSERT INTO "django_geo_db_location" VALUES(34522,NULL,'Frankton, IN',14070,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34523,NULL,'Frankton, IN 46044',14070,222,NULL,18,20160,0);
INSERT INTO "django_geo_db_location" VALUES(34524,NULL,'Goldsmith, IN',14071,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34525,NULL,'Goldsmith, IN 46045',14071,222,NULL,18,20161,0);
INSERT INTO "django_geo_db_location" VALUES(34526,NULL,'Hillisburg, IN',14072,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34527,NULL,'Hillisburg, IN 46046',14072,222,NULL,18,20162,0);
INSERT INTO "django_geo_db_location" VALUES(34528,NULL,'Hobbs, IN',14073,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34529,NULL,'Hobbs, IN 46047',14073,222,NULL,18,20163,0);
INSERT INTO "django_geo_db_location" VALUES(34530,NULL,'Ingalls, IN',14074,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34531,NULL,'Ingalls, IN 46048',14074,222,NULL,18,20164,0);
INSERT INTO "django_geo_db_location" VALUES(34532,NULL,'Kempton, IN',14075,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34533,NULL,'Kempton, IN 46049',14075,222,NULL,18,20165,0);
INSERT INTO "django_geo_db_location" VALUES(34534,NULL,'Kirklin, IN',14076,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34535,NULL,'Kirklin, IN 46050',14076,222,NULL,18,20166,0);
INSERT INTO "django_geo_db_location" VALUES(34536,NULL,'Lapel, IN',14077,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34537,NULL,'Lapel, IN 46051',14077,222,NULL,18,20167,0);
INSERT INTO "django_geo_db_location" VALUES(34538,NULL,'Lebanon, IN',14078,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34539,NULL,'Lebanon, IN 46052',14078,222,NULL,18,20168,0);
INSERT INTO "django_geo_db_location" VALUES(34540,NULL,'McCordsville, IN',14079,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34541,NULL,'McCordsville, IN 46055',14079,222,NULL,18,20169,0);
INSERT INTO "django_geo_db_location" VALUES(34542,NULL,'Markleville, IN',14080,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34543,NULL,'Markleville, IN 46056',14080,222,NULL,18,20170,0);
INSERT INTO "django_geo_db_location" VALUES(34544,NULL,'Michigantown, IN',14081,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34545,NULL,'Michigantown, IN 46057',14081,222,NULL,18,20171,0);
INSERT INTO "django_geo_db_location" VALUES(34546,NULL,'Mulberry, IN',14082,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34547,NULL,'Mulberry, IN 46058',14082,222,NULL,18,20172,0);
INSERT INTO "django_geo_db_location" VALUES(34548,NULL,'Noblesville, IN',14083,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34549,NULL,'Noblesville, IN 46060',14083,222,NULL,18,20173,0);
INSERT INTO "django_geo_db_location" VALUES(34550,NULL,'Noblesville, IN 46061',14083,222,NULL,18,20174,0);
INSERT INTO "django_geo_db_location" VALUES(34551,NULL,'Orestes, IN',14084,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34552,NULL,'Orestes, IN 46063',14084,222,NULL,18,20175,0);
INSERT INTO "django_geo_db_location" VALUES(34553,NULL,'Pendleton, IN',14085,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34554,NULL,'Pendleton, IN 46064',14085,222,NULL,18,20176,0);
INSERT INTO "django_geo_db_location" VALUES(34555,NULL,'Rossville, IN',14086,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34556,NULL,'Rossville, IN 46065',14086,222,NULL,18,20177,0);
INSERT INTO "django_geo_db_location" VALUES(34557,NULL,'Sedalia, IN',14087,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34558,NULL,'Sedalia, IN 46067',14087,222,NULL,18,20178,0);
INSERT INTO "django_geo_db_location" VALUES(34559,NULL,'Sharpsville, IN',14088,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34560,NULL,'Sharpsville, IN 46068',14088,222,NULL,18,20179,0);
INSERT INTO "django_geo_db_location" VALUES(34561,NULL,'Sheridan, IN',14089,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34562,NULL,'Sheridan, IN 46069',14089,222,NULL,18,20180,0);
INSERT INTO "django_geo_db_location" VALUES(34563,NULL,'Summitville, IN',14090,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34564,NULL,'Summitville, IN 46070',14090,222,NULL,18,20181,0);
INSERT INTO "django_geo_db_location" VALUES(34565,NULL,'Thorntown, IN',14091,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34566,NULL,'Thorntown, IN 46071',14091,222,NULL,18,20182,0);
INSERT INTO "django_geo_db_location" VALUES(34567,NULL,'Tipton, IN',14092,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34568,NULL,'Tipton, IN 46072',14092,222,NULL,18,20183,0);
INSERT INTO "django_geo_db_location" VALUES(34569,NULL,'Westfield, IN',14093,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34570,NULL,'Westfield, IN 46074',14093,222,NULL,18,20184,0);
INSERT INTO "django_geo_db_location" VALUES(34571,NULL,'Whitestown, IN',14094,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34572,NULL,'Whitestown, IN 46075',14094,222,NULL,18,20185,0);
INSERT INTO "django_geo_db_location" VALUES(34573,NULL,'Windfall, IN',14095,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34574,NULL,'Windfall, IN 46076',14095,222,NULL,18,20186,0);
INSERT INTO "django_geo_db_location" VALUES(34575,NULL,'Zionsville, IN',14096,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34576,NULL,'Zionsville, IN 46077',14096,222,NULL,18,20187,0);
INSERT INTO "django_geo_db_location" VALUES(34577,NULL,'Carmel, IN 46082',14062,222,NULL,18,20188,0);
INSERT INTO "django_geo_db_location" VALUES(34578,NULL,'Advance, IN',14097,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34579,NULL,'Advance, IN 46102',14097,222,NULL,18,20189,0);
INSERT INTO "django_geo_db_location" VALUES(34580,NULL,'Amo, IN',14098,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34581,NULL,'Amo, IN 46103',14098,222,NULL,18,20190,0);
INSERT INTO "django_geo_db_location" VALUES(34582,NULL,'Arlington, IN',14099,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34583,NULL,'Arlington, IN 46104',14099,222,NULL,18,20191,0);
INSERT INTO "django_geo_db_location" VALUES(34584,NULL,'Bainbridge, IN',14100,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34585,NULL,'Bainbridge, IN 46105',14100,222,NULL,18,20192,0);
INSERT INTO "django_geo_db_location" VALUES(34586,NULL,'Bargersville, IN',14101,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34587,NULL,'Bargersville, IN 46106',14101,222,NULL,18,20193,0);
INSERT INTO "django_geo_db_location" VALUES(34588,NULL,'Beech Grove, IN',14102,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34589,NULL,'Beech Grove, IN 46107',14102,222,NULL,18,20194,0);
INSERT INTO "django_geo_db_location" VALUES(34590,NULL,'Boggstown, IN',14103,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34591,NULL,'Boggstown, IN 46110',14103,222,NULL,18,20195,0);
INSERT INTO "django_geo_db_location" VALUES(34592,NULL,'Brooklyn, IN',14104,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34593,NULL,'Brooklyn, IN 46111',14104,222,NULL,18,20196,0);
INSERT INTO "django_geo_db_location" VALUES(34594,NULL,'Brownsburg, IN',14105,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34595,NULL,'Brownsburg, IN 46112',14105,222,NULL,18,20197,0);
INSERT INTO "django_geo_db_location" VALUES(34596,NULL,'Camby, IN',14106,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34597,NULL,'Camby, IN 46113',14106,222,NULL,18,20198,0);
INSERT INTO "django_geo_db_location" VALUES(34598,NULL,'Cartersburg, IN',14107,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34599,NULL,'Cartersburg, IN 46114',14107,222,NULL,18,20199,0);
INSERT INTO "django_geo_db_location" VALUES(34600,NULL,'Carthage, IN',14108,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34601,NULL,'Carthage, IN 46115',14108,222,NULL,18,20200,0);
INSERT INTO "django_geo_db_location" VALUES(34602,NULL,'Charlottesville, IN',14109,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34603,NULL,'Charlottesville, IN 46117',14109,222,NULL,18,20201,0);
INSERT INTO "django_geo_db_location" VALUES(34604,NULL,'Clayton, IN',14110,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34605,NULL,'Clayton, IN 46118',14110,222,NULL,18,20202,0);
INSERT INTO "django_geo_db_location" VALUES(34606,NULL,'Cloverdale, IN',14111,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34607,NULL,'Cloverdale, IN 46120',14111,222,NULL,18,20203,0);
INSERT INTO "django_geo_db_location" VALUES(34608,NULL,'Coatesville, IN',14112,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34609,NULL,'Coatesville, IN 46121',14112,222,NULL,18,20204,0);
INSERT INTO "django_geo_db_location" VALUES(34610,NULL,'Danville, IN',14113,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34611,NULL,'Danville, IN 46122',14113,222,NULL,18,20205,0);
INSERT INTO "django_geo_db_location" VALUES(34612,NULL,'Avon, IN',14114,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34613,NULL,'Avon, IN 46123',14114,222,NULL,18,20206,0);
INSERT INTO "django_geo_db_location" VALUES(34614,NULL,'Edinburgh, IN',14115,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34615,NULL,'Edinburgh, IN 46124',14115,222,NULL,18,20207,0);
INSERT INTO "django_geo_db_location" VALUES(34616,NULL,'Eminence, IN',14116,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34617,NULL,'Eminence, IN 46125',14116,222,NULL,18,20208,0);
INSERT INTO "django_geo_db_location" VALUES(34618,NULL,'Fairland, IN',14117,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34619,NULL,'Fairland, IN 46126',14117,222,NULL,18,20209,0);
INSERT INTO "django_geo_db_location" VALUES(34620,NULL,'Falmouth, IN',14118,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34621,NULL,'Falmouth, IN 46127',14118,222,NULL,18,20210,0);
INSERT INTO "django_geo_db_location" VALUES(34622,NULL,'Fillmore, IN',14119,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34623,NULL,'Fillmore, IN 46128',14119,222,NULL,18,20211,0);
INSERT INTO "django_geo_db_location" VALUES(34624,NULL,'Finly, IN',14120,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34625,NULL,'Finly, IN 46129',14120,222,NULL,18,20212,0);
INSERT INTO "django_geo_db_location" VALUES(34626,NULL,'Fountaintown, IN',14121,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34627,NULL,'Fountaintown, IN 46130',14121,222,NULL,18,20213,0);
INSERT INTO "django_geo_db_location" VALUES(34628,NULL,'Franklin, IN',14122,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34629,NULL,'Franklin, IN 46131',14122,222,NULL,18,20214,0);
INSERT INTO "django_geo_db_location" VALUES(34630,NULL,'Glenwood, IN',14123,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34631,NULL,'Glenwood, IN 46133',14123,222,NULL,18,20215,0);
INSERT INTO "django_geo_db_location" VALUES(34632,NULL,'Greencastle, IN',14124,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34633,NULL,'Greencastle, IN 46135',14124,222,NULL,18,20216,0);
INSERT INTO "django_geo_db_location" VALUES(34634,NULL,'Greenfield, IN',14125,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34635,NULL,'Greenfield, IN 46140',14125,222,NULL,18,20217,0);
INSERT INTO "django_geo_db_location" VALUES(34636,NULL,'Greenwood, IN',14126,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34637,NULL,'Greenwood, IN 46142',14126,222,NULL,18,20218,0);
INSERT INTO "django_geo_db_location" VALUES(34638,NULL,'Greenwood, IN 46143',14126,222,NULL,18,20219,0);
INSERT INTO "django_geo_db_location" VALUES(34639,NULL,'Gwynneville, IN',14127,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34640,NULL,'Gwynneville, IN 46144',14127,222,NULL,18,20220,0);
INSERT INTO "django_geo_db_location" VALUES(34641,NULL,'Greenwood, IN 46145',14126,222,NULL,18,20221,0);
INSERT INTO "django_geo_db_location" VALUES(34642,NULL,'Homer, IN',14128,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34643,NULL,'Homer, IN 46146',14128,222,NULL,18,20222,0);
INSERT INTO "django_geo_db_location" VALUES(34644,NULL,'Jamestown, IN',14129,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34645,NULL,'Jamestown, IN 46147',14129,222,NULL,18,20223,0);
INSERT INTO "django_geo_db_location" VALUES(34646,NULL,'Knightstown, IN',14130,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34647,NULL,'Knightstown, IN 46148',14130,222,NULL,18,20224,0);
INSERT INTO "django_geo_db_location" VALUES(34648,NULL,'Lizton, IN',14131,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34649,NULL,'Lizton, IN 46149',14131,222,NULL,18,20225,0);
INSERT INTO "django_geo_db_location" VALUES(34650,NULL,'Manilla, IN',14132,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34651,NULL,'Manilla, IN 46150',14132,222,NULL,18,20226,0);
INSERT INTO "django_geo_db_location" VALUES(34652,NULL,'Martinsville, IN',14133,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34653,NULL,'Martinsville, IN 46151',14133,222,NULL,18,20227,0);
INSERT INTO "django_geo_db_location" VALUES(34654,NULL,'Maxwell, IN',14134,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34655,NULL,'Maxwell, IN 46154',14134,222,NULL,18,20228,0);
INSERT INTO "django_geo_db_location" VALUES(34656,NULL,'Mays, IN',14135,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34657,NULL,'Mays, IN 46155',14135,222,NULL,18,20229,0);
INSERT INTO "django_geo_db_location" VALUES(34658,NULL,'Milroy, IN',14136,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34659,NULL,'Milroy, IN 46156',14136,222,NULL,18,20230,0);
INSERT INTO "django_geo_db_location" VALUES(34660,NULL,'Monrovia, IN',14137,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34661,NULL,'Monrovia, IN 46157',14137,222,NULL,18,20231,0);
INSERT INTO "django_geo_db_location" VALUES(34662,NULL,'Mooresville, IN',14138,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34663,NULL,'Mooresville, IN 46158',14138,222,NULL,18,20232,0);
INSERT INTO "django_geo_db_location" VALUES(34664,NULL,'Morgantown, IN',14139,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34665,NULL,'Morgantown, IN 46160',14139,222,NULL,18,20233,0);
INSERT INTO "django_geo_db_location" VALUES(34666,NULL,'Morristown, IN',14140,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34667,NULL,'Morristown, IN 46161',14140,222,NULL,18,20234,0);
INSERT INTO "django_geo_db_location" VALUES(34668,NULL,'Needham, IN',14141,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34669,NULL,'Needham, IN 46162',14141,222,NULL,18,20235,0);
INSERT INTO "django_geo_db_location" VALUES(34670,NULL,'New Palestine, IN',14142,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34671,NULL,'New Palestine, IN 46163',14142,222,NULL,18,20236,0);
INSERT INTO "django_geo_db_location" VALUES(34672,NULL,'Nineveh, IN',14143,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34673,NULL,'Nineveh, IN 46164',14143,222,NULL,18,20237,0);
INSERT INTO "django_geo_db_location" VALUES(34674,NULL,'North Salem, IN',14144,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34675,NULL,'North Salem, IN 46165',14144,222,NULL,18,20238,0);
INSERT INTO "django_geo_db_location" VALUES(34676,NULL,'Paragon, IN',14145,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34677,NULL,'Paragon, IN 46166',14145,222,NULL,18,20239,0);
INSERT INTO "django_geo_db_location" VALUES(34678,NULL,'Pittsboro, IN',14146,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34679,NULL,'Pittsboro, IN 46167',14146,222,NULL,18,20240,0);
INSERT INTO "django_geo_db_location" VALUES(34680,NULL,'Plainfield, IN',14147,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34681,NULL,'Plainfield, IN 46168',14147,222,NULL,18,20241,0);
INSERT INTO "django_geo_db_location" VALUES(34682,NULL,'Putnamville, IN',14148,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34683,NULL,'Putnamville, IN 46170',14148,222,NULL,18,20242,0);
INSERT INTO "django_geo_db_location" VALUES(34684,NULL,'Reelsville, IN',14149,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34685,NULL,'Reelsville, IN 46171',14149,222,NULL,18,20243,0);
INSERT INTO "django_geo_db_location" VALUES(34686,NULL,'Roachdale, IN',14150,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34687,NULL,'Roachdale, IN 46172',14150,222,NULL,18,20244,0);
INSERT INTO "django_geo_db_location" VALUES(34688,NULL,'Rushville, IN',14151,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34689,NULL,'Rushville, IN 46173',14151,222,NULL,18,20245,0);
INSERT INTO "django_geo_db_location" VALUES(34690,NULL,'Russellville, IN',14152,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34691,NULL,'Russellville, IN 46175',14152,222,NULL,18,20246,0);
INSERT INTO "django_geo_db_location" VALUES(34692,NULL,'Shelbyville, IN',14153,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34693,NULL,'Shelbyville, IN 46176',14153,222,NULL,18,20247,0);
INSERT INTO "django_geo_db_location" VALUES(34694,NULL,'Stilesville, IN',14154,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34695,NULL,'Stilesville, IN 46180',14154,222,NULL,18,20248,0);
INSERT INTO "django_geo_db_location" VALUES(34696,NULL,'Trafalgar, IN',14155,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34697,NULL,'Trafalgar, IN 46181',14155,222,NULL,18,20249,0);
INSERT INTO "django_geo_db_location" VALUES(34698,NULL,'Waldron, IN',14156,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34699,NULL,'Waldron, IN 46182',14156,222,NULL,18,20250,0);
INSERT INTO "django_geo_db_location" VALUES(34700,NULL,'West Newton, IN',14157,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34701,NULL,'West Newton, IN 46183',14157,222,NULL,18,20251,0);
INSERT INTO "django_geo_db_location" VALUES(34702,NULL,'Whiteland, IN',14158,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34703,NULL,'Whiteland, IN 46184',14158,222,NULL,18,20252,0);
INSERT INTO "django_geo_db_location" VALUES(34704,NULL,'Wilkinson, IN',14159,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34705,NULL,'Wilkinson, IN 46186',14159,222,NULL,18,20253,0);
INSERT INTO "django_geo_db_location" VALUES(34706,NULL,'Indianapolis, IN',14160,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34707,NULL,'Indianapolis, IN 46201',14160,222,NULL,18,20254,0);
INSERT INTO "django_geo_db_location" VALUES(34708,NULL,'Indianapolis, IN 46202',14160,222,NULL,18,20255,0);
INSERT INTO "django_geo_db_location" VALUES(34709,NULL,'Indianapolis, IN 46203',14160,222,NULL,18,20256,0);
INSERT INTO "django_geo_db_location" VALUES(34710,NULL,'Indianapolis, IN 46204',14160,222,NULL,18,20257,0);
INSERT INTO "django_geo_db_location" VALUES(34711,NULL,'Indianapolis, IN 46205',14160,222,NULL,18,20258,0);
INSERT INTO "django_geo_db_location" VALUES(34712,NULL,'Indianapolis, IN 46206',14160,222,NULL,18,20259,0);
INSERT INTO "django_geo_db_location" VALUES(34713,NULL,'Indianapolis, IN 46207',14160,222,NULL,18,20260,0);
INSERT INTO "django_geo_db_location" VALUES(34714,NULL,'Indianapolis, IN 46208',14160,222,NULL,18,20261,0);
INSERT INTO "django_geo_db_location" VALUES(34715,NULL,'Indianapolis, IN 46209',14160,222,NULL,18,20262,0);
INSERT INTO "django_geo_db_location" VALUES(34716,NULL,'Indianapolis, IN 46211',14160,222,NULL,18,20263,0);
INSERT INTO "django_geo_db_location" VALUES(34717,NULL,'Indianapolis, IN 46214',14160,222,NULL,18,20264,0);
INSERT INTO "django_geo_db_location" VALUES(34718,NULL,'Indianapolis, IN 46216',14160,222,NULL,18,20265,0);
INSERT INTO "django_geo_db_location" VALUES(34719,NULL,'Indianapolis, IN 46217',14160,222,NULL,18,20266,0);
INSERT INTO "django_geo_db_location" VALUES(34720,NULL,'Indianapolis, IN 46218',14160,222,NULL,18,20267,0);
INSERT INTO "django_geo_db_location" VALUES(34721,NULL,'Indianapolis, IN 46219',14160,222,NULL,18,20268,0);
INSERT INTO "django_geo_db_location" VALUES(34722,NULL,'Indianapolis, IN 46220',14160,222,NULL,18,20269,0);
INSERT INTO "django_geo_db_location" VALUES(34723,NULL,'Indianapolis, IN 46221',14160,222,NULL,18,20270,0);
INSERT INTO "django_geo_db_location" VALUES(34724,NULL,'Indianapolis, IN 46222',14160,222,NULL,18,20271,0);
INSERT INTO "django_geo_db_location" VALUES(34725,NULL,'Indianapolis, IN 46223',14160,222,NULL,18,20272,0);
INSERT INTO "django_geo_db_location" VALUES(34726,NULL,'Indianapolis, IN 46224',14160,222,NULL,18,20273,0);
INSERT INTO "django_geo_db_location" VALUES(34727,NULL,'Indianapolis, IN 46225',14160,222,NULL,18,20274,0);
INSERT INTO "django_geo_db_location" VALUES(34728,NULL,'Indianapolis, IN 46226',14160,222,NULL,18,20275,0);
INSERT INTO "django_geo_db_location" VALUES(34729,NULL,'Indianapolis, IN 46227',14160,222,NULL,18,20276,0);
INSERT INTO "django_geo_db_location" VALUES(34730,NULL,'Indianapolis, IN 46228',14160,222,NULL,18,20277,0);
INSERT INTO "django_geo_db_location" VALUES(34731,NULL,'Indianapolis, IN 46229',14160,222,NULL,18,20278,0);
INSERT INTO "django_geo_db_location" VALUES(34732,NULL,'Indianapolis, IN 46230',14160,222,NULL,18,20279,0);
INSERT INTO "django_geo_db_location" VALUES(34733,NULL,'Indianapolis, IN 46231',14160,222,NULL,18,20280,0);
INSERT INTO "django_geo_db_location" VALUES(34734,NULL,'Indianapolis, IN 46234',14160,222,NULL,18,20281,0);
INSERT INTO "django_geo_db_location" VALUES(34735,NULL,'Indianapolis, IN 46235',14160,222,NULL,18,20282,0);
INSERT INTO "django_geo_db_location" VALUES(34736,NULL,'Indianapolis, IN 46236',14160,222,NULL,18,20283,0);
INSERT INTO "django_geo_db_location" VALUES(34737,NULL,'Indianapolis, IN 46237',14160,222,NULL,18,20284,0);
INSERT INTO "django_geo_db_location" VALUES(34738,NULL,'Indianapolis, IN 46239',14160,222,NULL,18,20285,0);
INSERT INTO "django_geo_db_location" VALUES(34739,NULL,'Indianapolis, IN 46240',14160,222,NULL,18,20286,0);
INSERT INTO "django_geo_db_location" VALUES(34740,NULL,'Indianapolis, IN 46241',14160,222,NULL,18,20287,0);
INSERT INTO "django_geo_db_location" VALUES(34741,NULL,'Indianapolis, IN 46242',14160,222,NULL,18,20288,0);
INSERT INTO "django_geo_db_location" VALUES(34742,NULL,'Washington, IN',14161,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34743,NULL,'Washington, IN 46243',14161,222,NULL,18,20289,0);
INSERT INTO "django_geo_db_location" VALUES(34744,NULL,'Indianapolis, IN 46244',14160,222,NULL,18,20290,0);
INSERT INTO "django_geo_db_location" VALUES(34745,NULL,'Indianapolis, IN 46247',14160,222,NULL,18,20291,0);
INSERT INTO "django_geo_db_location" VALUES(34746,NULL,'Indianapolis, IN 46249',14160,222,NULL,18,20292,0);
INSERT INTO "django_geo_db_location" VALUES(34747,NULL,'Indianapolis, IN 46250',14160,222,NULL,18,20293,0);
INSERT INTO "django_geo_db_location" VALUES(34748,NULL,'Indianapolis, IN 46251',14160,222,NULL,18,20294,0);
INSERT INTO "django_geo_db_location" VALUES(34749,NULL,'Indianapolis, IN 46253',14160,222,NULL,18,20295,0);
INSERT INTO "django_geo_db_location" VALUES(34750,NULL,'Indianapolis, IN 46254',14160,222,NULL,18,20296,0);
INSERT INTO "django_geo_db_location" VALUES(34751,NULL,'Indianapolis, IN 46255',14160,222,NULL,18,20297,0);
INSERT INTO "django_geo_db_location" VALUES(34752,NULL,'Indianapolis, IN 46256',14160,222,NULL,18,20298,0);
INSERT INTO "django_geo_db_location" VALUES(34753,NULL,'Indianapolis, IN 46259',14160,222,NULL,18,20299,0);
INSERT INTO "django_geo_db_location" VALUES(34754,NULL,'Indianapolis, IN 46260',14160,222,NULL,18,20300,0);
INSERT INTO "django_geo_db_location" VALUES(34755,NULL,'Indianapolis, IN 46266',14160,222,NULL,18,20301,0);
INSERT INTO "django_geo_db_location" VALUES(34756,NULL,'Indianapolis, IN 46268',14160,222,NULL,18,20302,0);
INSERT INTO "django_geo_db_location" VALUES(34757,NULL,'Indianapolis, IN 46274',14160,222,NULL,18,20303,0);
INSERT INTO "django_geo_db_location" VALUES(34758,NULL,'Indianapolis, IN 46275',14160,222,NULL,18,20304,0);
INSERT INTO "django_geo_db_location" VALUES(34759,NULL,'Indianapolis, IN 46277',14160,222,NULL,18,20305,0);
INSERT INTO "django_geo_db_location" VALUES(34760,NULL,'Indianapolis, IN 46278',14160,222,NULL,18,20306,0);
INSERT INTO "django_geo_db_location" VALUES(34761,NULL,'Indianapolis, IN 46280',14160,222,NULL,18,20307,0);
INSERT INTO "django_geo_db_location" VALUES(34762,NULL,'Indianapolis, IN 46282',14160,222,NULL,18,20308,0);
INSERT INTO "django_geo_db_location" VALUES(34763,NULL,'Indianapolis, IN 46283',14160,222,NULL,18,20309,0);
INSERT INTO "django_geo_db_location" VALUES(34764,NULL,'Indianapolis, IN 46285',14160,222,NULL,18,20310,0);
INSERT INTO "django_geo_db_location" VALUES(34765,NULL,'Indianapolis, IN 46290',14160,222,NULL,18,20311,0);
INSERT INTO "django_geo_db_location" VALUES(34766,NULL,'Indianapolis, IN 46291',14160,222,NULL,18,20312,0);
INSERT INTO "django_geo_db_location" VALUES(34767,NULL,'Indianapolis, IN 46295',14160,222,NULL,18,20313,0);
INSERT INTO "django_geo_db_location" VALUES(34768,NULL,'Indianapolis, IN 46298',14160,222,NULL,18,20314,0);
INSERT INTO "django_geo_db_location" VALUES(34769,NULL,'Beverly Shores, IN',14162,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34770,NULL,'Beverly Shores, IN 46301',14162,222,NULL,18,20315,0);
INSERT INTO "django_geo_db_location" VALUES(34771,NULL,'Boone Grove, IN',14163,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34772,NULL,'Boone Grove, IN 46302',14163,222,NULL,18,20316,0);
INSERT INTO "django_geo_db_location" VALUES(34773,NULL,'Cedar Lake, IN',14164,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34774,NULL,'Cedar Lake, IN 46303',14164,222,NULL,18,20317,0);
INSERT INTO "django_geo_db_location" VALUES(34775,NULL,'Chesterton, IN',14165,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34776,NULL,'Chesterton, IN 46304',14165,222,NULL,18,20318,0);
INSERT INTO "django_geo_db_location" VALUES(34777,NULL,'Granger, IN',14166,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34778,NULL,'Granger, IN 46305',14166,222,NULL,18,20319,0);
INSERT INTO "django_geo_db_location" VALUES(34779,NULL,'Crown Point, IN',14167,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34780,NULL,'Crown Point, IN 46307',14167,222,NULL,18,20320,0);
INSERT INTO "django_geo_db_location" VALUES(34781,NULL,'Crown Point, IN 46308',14167,222,NULL,18,20321,0);
INSERT INTO "django_geo_db_location" VALUES(34782,NULL,'Demotte, IN',14168,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34783,NULL,'Demotte, IN 46310',14168,222,NULL,18,20322,0);
INSERT INTO "django_geo_db_location" VALUES(34784,NULL,'Dyer, IN',14169,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34785,NULL,'Dyer, IN 46311',14169,222,NULL,18,20323,0);
INSERT INTO "django_geo_db_location" VALUES(34786,NULL,'East Chicago, IN',14170,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34787,NULL,'East Chicago, IN 46312',14170,222,NULL,18,20324,0);
INSERT INTO "django_geo_db_location" VALUES(34788,NULL,'Griffith, IN',14171,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34789,NULL,'Griffith, IN 46319',14171,222,NULL,18,20325,0);
INSERT INTO "django_geo_db_location" VALUES(34790,NULL,'Hammond, IN',14172,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34791,NULL,'Hammond, IN 46320',14172,222,NULL,18,20326,0);
INSERT INTO "django_geo_db_location" VALUES(34792,NULL,'Munster, IN',14173,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34793,NULL,'Munster, IN 46321',14173,222,NULL,18,20327,0);
INSERT INTO "django_geo_db_location" VALUES(34794,NULL,'Highland, IN',14174,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34795,NULL,'Highland, IN 46322',14174,222,NULL,18,20328,0);
INSERT INTO "django_geo_db_location" VALUES(34796,NULL,'Hammond, IN 46323',14172,222,NULL,18,20329,0);
INSERT INTO "django_geo_db_location" VALUES(34797,NULL,'Hammond, IN 46324',14172,222,NULL,18,20330,0);
INSERT INTO "django_geo_db_location" VALUES(34798,NULL,'Hammond, IN 46325',14172,222,NULL,18,20331,0);
INSERT INTO "django_geo_db_location" VALUES(34799,NULL,'Hammond, IN 46327',14172,222,NULL,18,20332,0);
INSERT INTO "django_geo_db_location" VALUES(34800,NULL,'Washington, IN 46332',14161,222,NULL,18,20333,0);
INSERT INTO "django_geo_db_location" VALUES(34801,NULL,'Hanna, IN',14175,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34802,NULL,'Hanna, IN 46340',14175,222,NULL,18,20334,0);
INSERT INTO "django_geo_db_location" VALUES(34803,NULL,'Hebron, IN',14176,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34804,NULL,'Hebron, IN 46341',14176,222,NULL,18,20335,0);
INSERT INTO "django_geo_db_location" VALUES(34805,NULL,'Hobart, IN',14177,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34806,NULL,'Hobart, IN 46342',14177,222,NULL,18,20336,0);
INSERT INTO "django_geo_db_location" VALUES(34807,NULL,'Kingsbury, IN',14178,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34808,NULL,'Kingsbury, IN 46345',14178,222,NULL,18,20337,0);
INSERT INTO "django_geo_db_location" VALUES(34809,NULL,'Kingsford Heights, IN',14179,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34810,NULL,'Kingsford Heights, IN 46346',14179,222,NULL,18,20338,0);
INSERT INTO "django_geo_db_location" VALUES(34811,NULL,'Kouts, IN',14180,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34812,NULL,'Kouts, IN 46347',14180,222,NULL,18,20339,0);
INSERT INTO "django_geo_db_location" VALUES(34813,NULL,'La Crosse, IN',14181,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34814,NULL,'La Crosse, IN 46348',14181,222,NULL,18,20340,0);
INSERT INTO "django_geo_db_location" VALUES(34815,NULL,'Lake Village, IN',14182,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34816,NULL,'Lake Village, IN 46349',14182,222,NULL,18,20341,0);
INSERT INTO "django_geo_db_location" VALUES(34817,NULL,'La Porte, IN',14183,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34818,NULL,'La Porte, IN 46350',14183,222,NULL,18,20342,0);
INSERT INTO "django_geo_db_location" VALUES(34819,NULL,'La Porte, IN 46352',14183,222,NULL,18,20343,0);
INSERT INTO "django_geo_db_location" VALUES(34820,NULL,'Leroy, IN',14184,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34821,NULL,'Leroy, IN 46355',14184,222,NULL,18,20344,0);
INSERT INTO "django_geo_db_location" VALUES(34822,NULL,'Lowell, IN',14185,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34823,NULL,'Lowell, IN 46356',14185,222,NULL,18,20345,0);
INSERT INTO "django_geo_db_location" VALUES(34824,NULL,'Michigan City, IN',14186,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34825,NULL,'Michigan City, IN 46360',14186,222,NULL,18,20346,0);
INSERT INTO "django_geo_db_location" VALUES(34826,NULL,'Michigan City, IN 46361',14186,222,NULL,18,20347,0);
INSERT INTO "django_geo_db_location" VALUES(34827,NULL,'Mill Creek, IN',14187,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34828,NULL,'Mill Creek, IN 46365',14187,222,NULL,18,20348,0);
INSERT INTO "django_geo_db_location" VALUES(34829,NULL,'North Judson, IN',14188,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34830,NULL,'North Judson, IN 46366',14188,222,NULL,18,20349,0);
INSERT INTO "django_geo_db_location" VALUES(34831,NULL,'Portage, IN',14189,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34832,NULL,'Portage, IN 46368',14189,222,NULL,18,20350,0);
INSERT INTO "django_geo_db_location" VALUES(34833,NULL,'Russiaville, IN',14190,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34834,NULL,'Russiaville, IN 46369',14190,222,NULL,18,20351,0);
INSERT INTO "django_geo_db_location" VALUES(34835,NULL,'Rolling Prairie, IN',14191,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34836,NULL,'Rolling Prairie, IN 46371',14191,222,NULL,18,20352,0);
INSERT INTO "django_geo_db_location" VALUES(34837,NULL,'Roselawn, IN',14192,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34838,NULL,'Roselawn, IN 46372',14192,222,NULL,18,20353,0);
INSERT INTO "django_geo_db_location" VALUES(34839,NULL,'Saint John, IN',14193,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34840,NULL,'Saint John, IN 46373',14193,222,NULL,18,20354,0);
INSERT INTO "django_geo_db_location" VALUES(34841,NULL,'San Pierre, IN',14194,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34842,NULL,'San Pierre, IN 46374',14194,222,NULL,18,20355,0);
INSERT INTO "django_geo_db_location" VALUES(34843,NULL,'Schererville, IN',14195,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34844,NULL,'Schererville, IN 46375',14195,222,NULL,18,20356,0);
INSERT INTO "django_geo_db_location" VALUES(34845,NULL,'Schneider, IN',14196,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34846,NULL,'Schneider, IN 46376',14196,222,NULL,18,20357,0);
INSERT INTO "django_geo_db_location" VALUES(34847,NULL,'Shelby, IN',14197,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34848,NULL,'Shelby, IN 46377',14197,222,NULL,18,20358,0);
INSERT INTO "django_geo_db_location" VALUES(34849,NULL,'Sumava Resorts, IN',14198,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34850,NULL,'Sumava Resorts, IN 46379',14198,222,NULL,18,20359,0);
INSERT INTO "django_geo_db_location" VALUES(34851,NULL,'Tefft, IN',14199,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34852,NULL,'Tefft, IN 46380',14199,222,NULL,18,20360,0);
INSERT INTO "django_geo_db_location" VALUES(34853,NULL,'Thayer, IN',14200,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34854,NULL,'Thayer, IN 46381',14200,222,NULL,18,20361,0);
INSERT INTO "django_geo_db_location" VALUES(34855,NULL,'Union Mills, IN',14201,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34856,NULL,'Union Mills, IN 46382',14201,222,NULL,18,20362,0);
INSERT INTO "django_geo_db_location" VALUES(34857,NULL,'Valparaiso, IN',14202,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34858,NULL,'Valparaiso, IN 46383',14202,222,NULL,18,20363,0);
INSERT INTO "django_geo_db_location" VALUES(34859,NULL,'Valparaiso, IN 46384',14202,222,NULL,18,20364,0);
INSERT INTO "django_geo_db_location" VALUES(34860,NULL,'Valparaiso, IN 46385',14202,222,NULL,18,20365,0);
INSERT INTO "django_geo_db_location" VALUES(34861,NULL,'Porter, IN',14203,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34862,NULL,'Porter, IN 46386',14203,222,NULL,18,20366,0);
INSERT INTO "django_geo_db_location" VALUES(34863,NULL,'Wanatah, IN',14204,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34864,NULL,'Wanatah, IN 46390',14204,222,NULL,18,20367,0);
INSERT INTO "django_geo_db_location" VALUES(34865,NULL,'Westville, IN',14205,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34866,NULL,'Westville, IN 46391',14205,222,NULL,18,20368,0);
INSERT INTO "django_geo_db_location" VALUES(34867,NULL,'Wheatfield, IN',14206,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34868,NULL,'Wheatfield, IN 46392',14206,222,NULL,18,20369,0);
INSERT INTO "django_geo_db_location" VALUES(34869,NULL,'Wheeler, IN',14207,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34870,NULL,'Wheeler, IN 46393',14207,222,NULL,18,20370,0);
INSERT INTO "django_geo_db_location" VALUES(34871,NULL,'Whiting, IN',14208,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34872,NULL,'Whiting, IN 46394',14208,222,NULL,18,20371,0);
INSERT INTO "django_geo_db_location" VALUES(34873,NULL,'Gary, IN',14209,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34874,NULL,'Gary, IN 46401',14209,222,NULL,18,20372,0);
INSERT INTO "django_geo_db_location" VALUES(34875,NULL,'Gary, IN 46402',14209,222,NULL,18,20373,0);
INSERT INTO "django_geo_db_location" VALUES(34876,NULL,'Gary, IN 46403',14209,222,NULL,18,20374,0);
INSERT INTO "django_geo_db_location" VALUES(34877,NULL,'Gary, IN 46404',14209,222,NULL,18,20375,0);
INSERT INTO "django_geo_db_location" VALUES(34878,NULL,'Lake Station, IN',14210,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34879,NULL,'Lake Station, IN 46405',14210,222,NULL,18,20376,0);
INSERT INTO "django_geo_db_location" VALUES(34880,NULL,'Gary, IN 46406',14209,222,NULL,18,20377,0);
INSERT INTO "django_geo_db_location" VALUES(34881,NULL,'Gary, IN 46407',14209,222,NULL,18,20378,0);
INSERT INTO "django_geo_db_location" VALUES(34882,NULL,'Gary, IN 46408',14209,222,NULL,18,20379,0);
INSERT INTO "django_geo_db_location" VALUES(34883,NULL,'Gary, IN 46409',14209,222,NULL,18,20380,0);
INSERT INTO "django_geo_db_location" VALUES(34884,NULL,'Merrillville, IN',14211,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34885,NULL,'Merrillville, IN 46410',14211,222,NULL,18,20381,0);
INSERT INTO "django_geo_db_location" VALUES(34886,NULL,'Merrillville, IN 46411',14211,222,NULL,18,20382,0);
INSERT INTO "django_geo_db_location" VALUES(34887,NULL,'Burlington, IN',14212,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34888,NULL,'Burlington, IN 46415',14212,222,NULL,18,20383,0);
INSERT INTO "django_geo_db_location" VALUES(34889,NULL,'Argos, IN',14213,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34890,NULL,'Argos, IN 46501',14213,222,NULL,18,20384,0);
INSERT INTO "django_geo_db_location" VALUES(34891,NULL,'Atwood, IN',14214,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34892,NULL,'Atwood, IN 46502',14214,222,NULL,18,20385,0);
INSERT INTO "django_geo_db_location" VALUES(34893,NULL,'Bourbon, IN',14215,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34894,NULL,'Bourbon, IN 46504',14215,222,NULL,18,20386,0);
INSERT INTO "django_geo_db_location" VALUES(34895,NULL,'Bremen, IN',14216,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34896,NULL,'Bremen, IN 46506',14216,222,NULL,18,20387,0);
INSERT INTO "django_geo_db_location" VALUES(34897,NULL,'Bristol, IN',14217,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34898,NULL,'Bristol, IN 46507',14217,222,NULL,18,20388,0);
INSERT INTO "django_geo_db_location" VALUES(34899,NULL,'Burket, IN',14218,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34900,NULL,'Burket, IN 46508',14218,222,NULL,18,20389,0);
INSERT INTO "django_geo_db_location" VALUES(34901,NULL,'Claypool, IN',14219,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34902,NULL,'Claypool, IN 46510',14219,222,NULL,18,20390,0);
INSERT INTO "django_geo_db_location" VALUES(34903,NULL,'Culver, IN',14220,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34904,NULL,'Culver, IN 46511',14220,222,NULL,18,20391,0);
INSERT INTO "django_geo_db_location" VALUES(34905,NULL,'Donaldson, IN',14221,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34906,NULL,'Donaldson, IN 46513',14221,222,NULL,18,20392,0);
INSERT INTO "django_geo_db_location" VALUES(34907,NULL,'Elkhart, IN',14222,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34908,NULL,'Elkhart, IN 46514',14222,222,NULL,18,20393,0);
INSERT INTO "django_geo_db_location" VALUES(34909,NULL,'Elkhart, IN 46515',14222,222,NULL,18,20394,0);
INSERT INTO "django_geo_db_location" VALUES(34910,NULL,'Elkhart, IN 46516',14222,222,NULL,18,20395,0);
INSERT INTO "django_geo_db_location" VALUES(34911,NULL,'Elkhart, IN 46517',14222,222,NULL,18,20396,0);
INSERT INTO "django_geo_db_location" VALUES(34912,NULL,'Madison, IN',14223,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34913,NULL,'Madison, IN 46518',14223,222,NULL,18,20397,0);
INSERT INTO "django_geo_db_location" VALUES(34914,NULL,'Etna Green, IN',14224,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34915,NULL,'Etna Green, IN 46524',14224,222,NULL,18,20398,0);
INSERT INTO "django_geo_db_location" VALUES(34916,NULL,'Goshen, IN',14225,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34917,NULL,'Goshen, IN 46526',14225,222,NULL,18,20399,0);
INSERT INTO "django_geo_db_location" VALUES(34918,NULL,'Goshen, IN 46527',14225,222,NULL,18,20400,0);
INSERT INTO "django_geo_db_location" VALUES(34919,NULL,'Goshen, IN 46528',14225,222,NULL,18,20401,0);
INSERT INTO "django_geo_db_location" VALUES(34920,NULL,'Granger, IN 46530',14166,222,NULL,18,20402,0);
INSERT INTO "django_geo_db_location" VALUES(34921,NULL,'Grovertown, IN',14226,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34922,NULL,'Grovertown, IN 46531',14226,222,NULL,18,20403,0);
INSERT INTO "django_geo_db_location" VALUES(34923,NULL,'Hamlet, IN',14227,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34924,NULL,'Hamlet, IN 46532',14227,222,NULL,18,20404,0);
INSERT INTO "django_geo_db_location" VALUES(34925,NULL,'Knox, IN',14228,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34926,NULL,'Knox, IN 46534',14228,222,NULL,18,20405,0);
INSERT INTO "django_geo_db_location" VALUES(34927,NULL,'Granger, IN 46535',14166,222,NULL,18,20406,0);
INSERT INTO "django_geo_db_location" VALUES(34928,NULL,'Lakeville, IN',14229,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34929,NULL,'Lakeville, IN 46536',14229,222,NULL,18,20407,0);
INSERT INTO "django_geo_db_location" VALUES(34930,NULL,'Lapaz, IN',14230,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34931,NULL,'Lapaz, IN 46537',14230,222,NULL,18,20408,0);
INSERT INTO "django_geo_db_location" VALUES(34932,NULL,'Leesburg, IN',14231,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34933,NULL,'Leesburg, IN 46538',14231,222,NULL,18,20409,0);
INSERT INTO "django_geo_db_location" VALUES(34934,NULL,'Mentone, IN',14232,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34935,NULL,'Mentone, IN 46539',14232,222,NULL,18,20410,0);
INSERT INTO "django_geo_db_location" VALUES(34936,NULL,'Middlebury, IN',14233,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34937,NULL,'Middlebury, IN 46540',14233,222,NULL,18,20411,0);
INSERT INTO "django_geo_db_location" VALUES(34938,NULL,'Milford, IN',14234,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34939,NULL,'Milford, IN 46542',14234,222,NULL,18,20412,0);
INSERT INTO "django_geo_db_location" VALUES(34940,NULL,'Millersburg, IN',14235,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34941,NULL,'Millersburg, IN 46543',14235,222,NULL,18,20413,0);
INSERT INTO "django_geo_db_location" VALUES(34942,NULL,'Mishawaka, IN',14236,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34943,NULL,'Mishawaka, IN 46544',14236,222,NULL,18,20414,0);
INSERT INTO "django_geo_db_location" VALUES(34944,NULL,'Mishawaka, IN 46545',14236,222,NULL,18,20415,0);
INSERT INTO "django_geo_db_location" VALUES(34945,NULL,'Mishawaka, IN 46546',14236,222,NULL,18,20416,0);
INSERT INTO "django_geo_db_location" VALUES(34946,NULL,'Nappanee, IN',14237,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34947,NULL,'Nappanee, IN 46550',14237,222,NULL,18,20417,0);
INSERT INTO "django_geo_db_location" VALUES(34948,NULL,'New Carlisle, IN',14238,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34949,NULL,'New Carlisle, IN 46552',14238,222,NULL,18,20418,0);
INSERT INTO "django_geo_db_location" VALUES(34950,NULL,'New Paris, IN',14239,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34951,NULL,'New Paris, IN 46553',14239,222,NULL,18,20419,0);
INSERT INTO "django_geo_db_location" VALUES(34952,NULL,'North Liberty, IN',14240,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34953,NULL,'North Liberty, IN 46554',14240,222,NULL,18,20420,0);
INSERT INTO "django_geo_db_location" VALUES(34954,NULL,'North Webster, IN',14241,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34955,NULL,'North Webster, IN 46555',14241,222,NULL,18,20421,0);
INSERT INTO "django_geo_db_location" VALUES(34956,NULL,'Notre Dame, IN',14242,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34957,NULL,'Notre Dame, IN 46556',14242,222,NULL,18,20422,0);
INSERT INTO "django_geo_db_location" VALUES(34958,NULL,'Osceola, IN',14243,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34959,NULL,'Osceola, IN 46561',14243,222,NULL,18,20423,0);
INSERT INTO "django_geo_db_location" VALUES(34960,NULL,'Pierceton, IN',14244,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34961,NULL,'Pierceton, IN 46562',14244,222,NULL,18,20424,0);
INSERT INTO "django_geo_db_location" VALUES(34962,NULL,'Plymouth, IN',14245,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34963,NULL,'Plymouth, IN 46563',14245,222,NULL,18,20425,0);
INSERT INTO "django_geo_db_location" VALUES(34964,NULL,'Shipshewana, IN',14246,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34965,NULL,'Shipshewana, IN 46565',14246,222,NULL,18,20426,0);
INSERT INTO "django_geo_db_location" VALUES(34966,NULL,'Sidney, IN',14247,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34967,NULL,'Sidney, IN 46566',14247,222,NULL,18,20427,0);
INSERT INTO "django_geo_db_location" VALUES(34968,NULL,'Syracuse, IN',14248,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34969,NULL,'Syracuse, IN 46567',14248,222,NULL,18,20428,0);
INSERT INTO "django_geo_db_location" VALUES(34970,NULL,'Tippecanoe, IN',14249,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34971,NULL,'Tippecanoe, IN 46570',14249,222,NULL,18,20429,0);
INSERT INTO "django_geo_db_location" VALUES(34972,NULL,'Topeka, IN',14250,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34973,NULL,'Topeka, IN 46571',14250,222,NULL,18,20430,0);
INSERT INTO "django_geo_db_location" VALUES(34974,NULL,'Tyner, IN',14251,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34975,NULL,'Tyner, IN 46572',14251,222,NULL,18,20431,0);
INSERT INTO "django_geo_db_location" VALUES(34976,NULL,'Wakarusa, IN',14252,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34977,NULL,'Wakarusa, IN 46573',14252,222,NULL,18,20432,0);
INSERT INTO "django_geo_db_location" VALUES(34978,NULL,'Walkerton, IN',14253,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34979,NULL,'Walkerton, IN 46574',14253,222,NULL,18,20433,0);
INSERT INTO "django_geo_db_location" VALUES(34980,NULL,'Warsaw, IN',14254,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34981,NULL,'Warsaw, IN 46580',14254,222,NULL,18,20434,0);
INSERT INTO "django_geo_db_location" VALUES(34982,NULL,'Warsaw, IN 46581',14254,222,NULL,18,20435,0);
INSERT INTO "django_geo_db_location" VALUES(34983,NULL,'Warsaw, IN 46582',14254,222,NULL,18,20436,0);
INSERT INTO "django_geo_db_location" VALUES(34984,NULL,'Winona Lake, IN',14255,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34985,NULL,'Winona Lake, IN 46590',14255,222,NULL,18,20437,0);
INSERT INTO "django_geo_db_location" VALUES(34986,NULL,'Wyatt, IN',14256,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34987,NULL,'Wyatt, IN 46595',14256,222,NULL,18,20438,0);
INSERT INTO "django_geo_db_location" VALUES(34988,NULL,'South Bend, IN',14257,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(34989,NULL,'South Bend, IN 46601',14257,222,NULL,18,20439,0);
INSERT INTO "django_geo_db_location" VALUES(34990,NULL,'South Bend, IN 46604',14257,222,NULL,18,20440,0);
INSERT INTO "django_geo_db_location" VALUES(34991,NULL,'South Bend, IN 46612',14257,222,NULL,18,20441,0);
INSERT INTO "django_geo_db_location" VALUES(34992,NULL,'South Bend, IN 46613',14257,222,NULL,18,20442,0);
INSERT INTO "django_geo_db_location" VALUES(34993,NULL,'South Bend, IN 46614',14257,222,NULL,18,20443,0);
INSERT INTO "django_geo_db_location" VALUES(34994,NULL,'South Bend, IN 46615',14257,222,NULL,18,20444,0);
INSERT INTO "django_geo_db_location" VALUES(34995,NULL,'South Bend, IN 46616',14257,222,NULL,18,20445,0);
INSERT INTO "django_geo_db_location" VALUES(34996,NULL,'South Bend, IN 46617',14257,222,NULL,18,20446,0);
INSERT INTO "django_geo_db_location" VALUES(34997,NULL,'South Bend, IN 46619',14257,222,NULL,18,20447,0);
INSERT INTO "django_geo_db_location" VALUES(34998,NULL,'South Bend, IN 46620',14257,222,NULL,18,20448,0);
INSERT INTO "django_geo_db_location" VALUES(34999,NULL,'South Bend, IN 46624',14257,222,NULL,18,20449,0);
INSERT INTO "django_geo_db_location" VALUES(35000,NULL,'South Bend, IN 46626',14257,222,NULL,18,20450,0);
INSERT INTO "django_geo_db_location" VALUES(35001,NULL,'South Bend, IN 46628',14257,222,NULL,18,20451,0);
INSERT INTO "django_geo_db_location" VALUES(35002,NULL,'South Bend, IN 46629',14257,222,NULL,18,20452,0);
INSERT INTO "django_geo_db_location" VALUES(35003,NULL,'South Bend, IN 46634',14257,222,NULL,18,20453,0);
INSERT INTO "django_geo_db_location" VALUES(35004,NULL,'South Bend, IN 46635',14257,222,NULL,18,20454,0);
INSERT INTO "django_geo_db_location" VALUES(35005,NULL,'South Bend, IN 46637',14257,222,NULL,18,20455,0);
INSERT INTO "django_geo_db_location" VALUES(35006,NULL,'South Bend, IN 46660',14257,222,NULL,18,20456,0);
INSERT INTO "django_geo_db_location" VALUES(35007,NULL,'Topeka, IN 46671',14250,222,NULL,18,20457,0);
INSERT INTO "django_geo_db_location" VALUES(35008,NULL,'South Bend, IN 46680',14257,222,NULL,18,20458,0);
INSERT INTO "django_geo_db_location" VALUES(35009,NULL,'Noble, IN',14258,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35010,NULL,'Noble, IN 46692',14258,222,NULL,18,20459,0);
INSERT INTO "django_geo_db_location" VALUES(35011,NULL,'Franklin, IN 46696',14122,222,NULL,18,20460,0);
INSERT INTO "django_geo_db_location" VALUES(35012,NULL,'South Bend, IN 46699',14257,222,NULL,18,20461,0);
INSERT INTO "django_geo_db_location" VALUES(35013,NULL,'Albion, IN',14259,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35014,NULL,'Albion, IN 46701',14259,222,NULL,18,20462,0);
INSERT INTO "django_geo_db_location" VALUES(35015,NULL,'Andrews, IN',14260,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35016,NULL,'Andrews, IN 46702',14260,222,NULL,18,20463,0);
INSERT INTO "django_geo_db_location" VALUES(35017,NULL,'Angola, IN',14261,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35018,NULL,'Angola, IN 46703',14261,222,NULL,18,20464,0);
INSERT INTO "django_geo_db_location" VALUES(35019,NULL,'Arcola, IN',14262,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35020,NULL,'Arcola, IN 46704',14262,222,NULL,18,20465,0);
INSERT INTO "django_geo_db_location" VALUES(35021,NULL,'Ashley, IN',14263,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35022,NULL,'Ashley, IN 46705',14263,222,NULL,18,20466,0);
INSERT INTO "django_geo_db_location" VALUES(35023,NULL,'Auburn, IN',14264,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35024,NULL,'Auburn, IN 46706',14264,222,NULL,18,20467,0);
INSERT INTO "django_geo_db_location" VALUES(35025,NULL,'Avilla, IN',14265,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35026,NULL,'Avilla, IN 46710',14265,222,NULL,18,20468,0);
INSERT INTO "django_geo_db_location" VALUES(35027,NULL,'Berne, IN',14266,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35028,NULL,'Berne, IN 46711',14266,222,NULL,18,20469,0);
INSERT INTO "django_geo_db_location" VALUES(35029,NULL,'Bippus, IN',14267,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35030,NULL,'Bippus, IN 46713',14267,222,NULL,18,20470,0);
INSERT INTO "django_geo_db_location" VALUES(35031,NULL,'Bluffton, IN',14268,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35032,NULL,'Bluffton, IN 46714',14268,222,NULL,18,20471,0);
INSERT INTO "django_geo_db_location" VALUES(35033,NULL,'Brimfield, IN',14269,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35034,NULL,'Brimfield, IN 46720',14269,222,NULL,18,20472,0);
INSERT INTO "django_geo_db_location" VALUES(35035,NULL,'Butler, IN',14270,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35036,NULL,'Butler, IN 46721',14270,222,NULL,18,20473,0);
INSERT INTO "django_geo_db_location" VALUES(35037,NULL,'Churubusco, IN',14271,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35038,NULL,'Churubusco, IN 46723',14271,222,NULL,18,20474,0);
INSERT INTO "django_geo_db_location" VALUES(35039,NULL,'Columbia City, IN',14272,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35040,NULL,'Columbia City, IN 46725',14272,222,NULL,18,20475,0);
INSERT INTO "django_geo_db_location" VALUES(35041,NULL,'Corunna, IN',14273,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35042,NULL,'Corunna, IN 46730',14273,222,NULL,18,20476,0);
INSERT INTO "django_geo_db_location" VALUES(35043,NULL,'Craigville, IN',14274,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35044,NULL,'Craigville, IN 46731',14274,222,NULL,18,20477,0);
INSERT INTO "django_geo_db_location" VALUES(35045,NULL,'Cromwell, IN',14275,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35046,NULL,'Cromwell, IN 46732',14275,222,NULL,18,20478,0);
INSERT INTO "django_geo_db_location" VALUES(35047,NULL,'Decatur, IN',14276,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35048,NULL,'Decatur, IN 46733',14276,222,NULL,18,20479,0);
INSERT INTO "django_geo_db_location" VALUES(35049,NULL,'Fremont, IN',14277,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35050,NULL,'Fremont, IN 46737',14277,222,NULL,18,20480,0);
INSERT INTO "django_geo_db_location" VALUES(35051,NULL,'Garrett, IN',14278,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35052,NULL,'Garrett, IN 46738',14278,222,NULL,18,20481,0);
INSERT INTO "django_geo_db_location" VALUES(35053,NULL,'Geneva, IN',14279,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35054,NULL,'Geneva, IN 46740',14279,222,NULL,18,20482,0);
INSERT INTO "django_geo_db_location" VALUES(35055,NULL,'Grabill, IN',14280,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35056,NULL,'Grabill, IN 46741',14280,222,NULL,18,20483,0);
INSERT INTO "django_geo_db_location" VALUES(35057,NULL,'Hamilton, IN',14281,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35058,NULL,'Hamilton, IN 46742',14281,222,NULL,18,20484,0);
INSERT INTO "django_geo_db_location" VALUES(35059,NULL,'Harlan, IN',14282,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35060,NULL,'Harlan, IN 46743',14282,222,NULL,18,20485,0);
INSERT INTO "django_geo_db_location" VALUES(35061,NULL,'Hoagland, IN',14283,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35062,NULL,'Hoagland, IN 46745',14283,222,NULL,18,20486,0);
INSERT INTO "django_geo_db_location" VALUES(35063,NULL,'Howe, IN',14284,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35064,NULL,'Howe, IN 46746',14284,222,NULL,18,20487,0);
INSERT INTO "django_geo_db_location" VALUES(35065,NULL,'Hudson, IN',14285,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35066,NULL,'Hudson, IN 46747',14285,222,NULL,18,20488,0);
INSERT INTO "django_geo_db_location" VALUES(35067,NULL,'Huntertown, IN',14286,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35068,NULL,'Huntertown, IN 46748',14286,222,NULL,18,20489,0);
INSERT INTO "django_geo_db_location" VALUES(35069,NULL,'Huntington, IN',14287,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35070,NULL,'Huntington, IN 46750',14287,222,NULL,18,20490,0);
INSERT INTO "django_geo_db_location" VALUES(35071,NULL,'Kendallville, IN',14288,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35072,NULL,'Kendallville, IN 46755',14288,222,NULL,18,20491,0);
INSERT INTO "django_geo_db_location" VALUES(35073,NULL,'Keystone, IN',14289,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35074,NULL,'Keystone, IN 46759',14289,222,NULL,18,20492,0);
INSERT INTO "django_geo_db_location" VALUES(35075,NULL,'Kimmell, IN',14290,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35076,NULL,'Kimmell, IN 46760',14290,222,NULL,18,20493,0);
INSERT INTO "django_geo_db_location" VALUES(35077,NULL,'Lagrange, IN',14291,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35078,NULL,'Lagrange, IN 46761',14291,222,NULL,18,20494,0);
INSERT INTO "django_geo_db_location" VALUES(35079,NULL,'Laotto, IN',14292,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35080,NULL,'Laotto, IN 46763',14292,222,NULL,18,20495,0);
INSERT INTO "django_geo_db_location" VALUES(35081,NULL,'Larwill, IN',14293,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35082,NULL,'Larwill, IN 46764',14293,222,NULL,18,20496,0);
INSERT INTO "django_geo_db_location" VALUES(35083,NULL,'Leo, IN',14294,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35084,NULL,'Leo, IN 46765',14294,222,NULL,18,20497,0);
INSERT INTO "django_geo_db_location" VALUES(35085,NULL,'Liberty Center, IN',14295,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35086,NULL,'Liberty Center, IN 46766',14295,222,NULL,18,20498,0);
INSERT INTO "django_geo_db_location" VALUES(35087,NULL,'Ligonier, IN',14296,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35088,NULL,'Ligonier, IN 46767',14296,222,NULL,18,20499,0);
INSERT INTO "django_geo_db_location" VALUES(35089,NULL,'Plainfield, IN 46768',14147,222,NULL,18,20500,0);
INSERT INTO "django_geo_db_location" VALUES(35090,NULL,'Linn Grove, IN',14297,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35091,NULL,'Linn Grove, IN 46769',14297,222,NULL,18,20501,0);
INSERT INTO "django_geo_db_location" VALUES(35092,NULL,'Markle, IN',14298,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35093,NULL,'Markle, IN 46770',14298,222,NULL,18,20502,0);
INSERT INTO "django_geo_db_location" VALUES(35094,NULL,'Mongo, IN',14299,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35095,NULL,'Mongo, IN 46771',14299,222,NULL,18,20503,0);
INSERT INTO "django_geo_db_location" VALUES(35096,NULL,'Monroe, IN',14300,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35097,NULL,'Monroe, IN 46772',14300,222,NULL,18,20504,0);
INSERT INTO "django_geo_db_location" VALUES(35098,NULL,'Monroeville, IN',14301,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35099,NULL,'Monroeville, IN 46773',14301,222,NULL,18,20505,0);
INSERT INTO "django_geo_db_location" VALUES(35100,NULL,'New Haven, IN',14302,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35101,NULL,'New Haven, IN 46774',14302,222,NULL,18,20506,0);
INSERT INTO "django_geo_db_location" VALUES(35102,NULL,'Orland, IN',14303,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35103,NULL,'Orland, IN 46776',14303,222,NULL,18,20507,0);
INSERT INTO "django_geo_db_location" VALUES(35104,NULL,'Ossian, IN',14304,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35105,NULL,'Ossian, IN 46777',14304,222,NULL,18,20508,0);
INSERT INTO "django_geo_db_location" VALUES(35106,NULL,'Petroleum, IN',14305,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35107,NULL,'Petroleum, IN 46778',14305,222,NULL,18,20509,0);
INSERT INTO "django_geo_db_location" VALUES(35108,NULL,'Pleasant Lake, IN',14306,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35109,NULL,'Pleasant Lake, IN 46779',14306,222,NULL,18,20510,0);
INSERT INTO "django_geo_db_location" VALUES(35110,NULL,'Pleasant Mills, IN',14307,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35111,NULL,'Pleasant Mills, IN 46780',14307,222,NULL,18,20511,0);
INSERT INTO "django_geo_db_location" VALUES(35112,NULL,'Poneto, IN',14308,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35113,NULL,'Poneto, IN 46781',14308,222,NULL,18,20512,0);
INSERT INTO "django_geo_db_location" VALUES(35114,NULL,'Preble, IN',14309,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35115,NULL,'Preble, IN 46782',14309,222,NULL,18,20513,0);
INSERT INTO "django_geo_db_location" VALUES(35116,NULL,'Roanoke, IN',14310,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35117,NULL,'Roanoke, IN 46783',14310,222,NULL,18,20514,0);
INSERT INTO "django_geo_db_location" VALUES(35118,NULL,'Rome City, IN',14311,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35119,NULL,'Rome City, IN 46784',14311,222,NULL,18,20515,0);
INSERT INTO "django_geo_db_location" VALUES(35120,NULL,'Saint Joe, IN',14312,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35121,NULL,'Saint Joe, IN 46785',14312,222,NULL,18,20516,0);
INSERT INTO "django_geo_db_location" VALUES(35122,NULL,'South Milford, IN',14313,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35123,NULL,'South Milford, IN 46786',14313,222,NULL,18,20517,0);
INSERT INTO "django_geo_db_location" VALUES(35124,NULL,'South Whitley, IN',14314,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35125,NULL,'South Whitley, IN 46787',14314,222,NULL,18,20518,0);
INSERT INTO "django_geo_db_location" VALUES(35126,NULL,'Spencerville, IN',14315,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35127,NULL,'Spencerville, IN 46788',14315,222,NULL,18,20519,0);
INSERT INTO "django_geo_db_location" VALUES(35128,NULL,'Stroh, IN',14316,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35129,NULL,'Stroh, IN 46789',14316,222,NULL,18,20520,0);
INSERT INTO "django_geo_db_location" VALUES(35130,NULL,'Uniondale, IN',14317,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35131,NULL,'Uniondale, IN 46791',14317,222,NULL,18,20521,0);
INSERT INTO "django_geo_db_location" VALUES(35132,NULL,'Warren, IN',14318,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35133,NULL,'Warren, IN 46792',14318,222,NULL,18,20522,0);
INSERT INTO "django_geo_db_location" VALUES(35134,NULL,'Waterloo, IN',14319,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35135,NULL,'Waterloo, IN 46793',14319,222,NULL,18,20523,0);
INSERT INTO "django_geo_db_location" VALUES(35136,NULL,'Wawaka, IN',14320,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35137,NULL,'Wawaka, IN 46794',14320,222,NULL,18,20524,0);
INSERT INTO "django_geo_db_location" VALUES(35138,NULL,'Wolcottville, IN',14321,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35139,NULL,'Wolcottville, IN 46795',14321,222,NULL,18,20525,0);
INSERT INTO "django_geo_db_location" VALUES(35140,NULL,'Wolflake, IN',14322,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35141,NULL,'Wolflake, IN 46796',14322,222,NULL,18,20526,0);
INSERT INTO "django_geo_db_location" VALUES(35142,NULL,'Woodburn, IN',14323,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35143,NULL,'Woodburn, IN 46797',14323,222,NULL,18,20527,0);
INSERT INTO "django_geo_db_location" VALUES(35144,NULL,'Yoder, IN',14324,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35145,NULL,'Yoder, IN 46798',14324,222,NULL,18,20528,0);
INSERT INTO "django_geo_db_location" VALUES(35146,NULL,'Zanesville, IN',14325,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35147,NULL,'Zanesville, IN 46799',14325,222,NULL,18,20529,0);
INSERT INTO "django_geo_db_location" VALUES(35148,NULL,'Fort Wayne, IN',14326,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35149,NULL,'Fort Wayne, IN 46801',14326,222,NULL,18,20530,0);
INSERT INTO "django_geo_db_location" VALUES(35150,NULL,'Fort Wayne, IN 46802',14326,222,NULL,18,20531,0);
INSERT INTO "django_geo_db_location" VALUES(35151,NULL,'Fort Wayne, IN 46803',14326,222,NULL,18,20532,0);
INSERT INTO "django_geo_db_location" VALUES(35152,NULL,'Fort Wayne, IN 46804',14326,222,NULL,18,20533,0);
INSERT INTO "django_geo_db_location" VALUES(35153,NULL,'Fort Wayne, IN 46805',14326,222,NULL,18,20534,0);
INSERT INTO "django_geo_db_location" VALUES(35154,NULL,'Fort Wayne, IN 46806',14326,222,NULL,18,20535,0);
INSERT INTO "django_geo_db_location" VALUES(35155,NULL,'Fort Wayne, IN 46807',14326,222,NULL,18,20536,0);
INSERT INTO "django_geo_db_location" VALUES(35156,NULL,'Fort Wayne, IN 46808',14326,222,NULL,18,20537,0);
INSERT INTO "django_geo_db_location" VALUES(35157,NULL,'Fort Wayne, IN 46809',14326,222,NULL,18,20538,0);
INSERT INTO "django_geo_db_location" VALUES(35158,NULL,'Fort Wayne, IN 46814',14326,222,NULL,18,20539,0);
INSERT INTO "django_geo_db_location" VALUES(35159,NULL,'Fort Wayne, IN 46815',14326,222,NULL,18,20540,0);
INSERT INTO "django_geo_db_location" VALUES(35160,NULL,'Fort Wayne, IN 46816',14326,222,NULL,18,20541,0);
INSERT INTO "django_geo_db_location" VALUES(35161,NULL,'Fort Wayne, IN 46818',14326,222,NULL,18,20542,0);
INSERT INTO "django_geo_db_location" VALUES(35162,NULL,'Fort Wayne, IN 46819',14326,222,NULL,18,20543,0);
INSERT INTO "django_geo_db_location" VALUES(35163,NULL,'Fort Wayne, IN 46825',14326,222,NULL,18,20544,0);
INSERT INTO "django_geo_db_location" VALUES(35164,NULL,'Fort Wayne, IN 46835',14326,222,NULL,18,20545,0);
INSERT INTO "django_geo_db_location" VALUES(35165,NULL,'Fort Wayne, IN 46845',14326,222,NULL,18,20546,0);
INSERT INTO "django_geo_db_location" VALUES(35166,NULL,'Huntertown, IN 46848',14286,222,NULL,18,20547,0);
INSERT INTO "django_geo_db_location" VALUES(35167,NULL,'Fort Wayne, IN 46850',14326,222,NULL,18,20548,0);
INSERT INTO "django_geo_db_location" VALUES(35168,NULL,'Fort Wayne, IN 46851',14326,222,NULL,18,20549,0);
INSERT INTO "django_geo_db_location" VALUES(35169,NULL,'Fort Wayne, IN 46852',14326,222,NULL,18,20550,0);
INSERT INTO "django_geo_db_location" VALUES(35170,NULL,'Fort Wayne, IN 46853',14326,222,NULL,18,20551,0);
INSERT INTO "django_geo_db_location" VALUES(35171,NULL,'Fort Wayne, IN 46854',14326,222,NULL,18,20552,0);
INSERT INTO "django_geo_db_location" VALUES(35172,NULL,'Fort Wayne, IN 46855',14326,222,NULL,18,20553,0);
INSERT INTO "django_geo_db_location" VALUES(35173,NULL,'Fort Wayne, IN 46856',14326,222,NULL,18,20554,0);
INSERT INTO "django_geo_db_location" VALUES(35174,NULL,'Fort Wayne, IN 46857',14326,222,NULL,18,20555,0);
INSERT INTO "django_geo_db_location" VALUES(35175,NULL,'Fort Wayne, IN 46858',14326,222,NULL,18,20556,0);
INSERT INTO "django_geo_db_location" VALUES(35176,NULL,'Fort Wayne, IN 46859',14326,222,NULL,18,20557,0);
INSERT INTO "django_geo_db_location" VALUES(35177,NULL,'Fort Wayne, IN 46860',14326,222,NULL,18,20558,0);
INSERT INTO "django_geo_db_location" VALUES(35178,NULL,'Fort Wayne, IN 46861',14326,222,NULL,18,20559,0);
INSERT INTO "django_geo_db_location" VALUES(35179,NULL,'Fort Wayne, IN 46862',14326,222,NULL,18,20560,0);
INSERT INTO "django_geo_db_location" VALUES(35180,NULL,'Fort Wayne, IN 46863',14326,222,NULL,18,20561,0);
INSERT INTO "django_geo_db_location" VALUES(35181,NULL,'Fort Wayne, IN 46864',14326,222,NULL,18,20562,0);
INSERT INTO "django_geo_db_location" VALUES(35182,NULL,'Fort Wayne, IN 46865',14326,222,NULL,18,20563,0);
INSERT INTO "django_geo_db_location" VALUES(35183,NULL,'Fort Wayne, IN 46866',14326,222,NULL,18,20564,0);
INSERT INTO "django_geo_db_location" VALUES(35184,NULL,'Fort Wayne, IN 46867',14326,222,NULL,18,20565,0);
INSERT INTO "django_geo_db_location" VALUES(35185,NULL,'Fort Wayne, IN 46868',14326,222,NULL,18,20566,0);
INSERT INTO "django_geo_db_location" VALUES(35186,NULL,'Fort Wayne, IN 46869',14326,222,NULL,18,20567,0);
INSERT INTO "django_geo_db_location" VALUES(35187,NULL,'Fort Wayne, IN 46885',14326,222,NULL,18,20568,0);
INSERT INTO "django_geo_db_location" VALUES(35188,NULL,'Fort Wayne, IN 46891',14326,222,NULL,18,20569,0);
INSERT INTO "django_geo_db_location" VALUES(35189,NULL,'Fort Wayne, IN 46895',14326,222,NULL,18,20570,0);
INSERT INTO "django_geo_db_location" VALUES(35190,NULL,'Fort Wayne, IN 46896',14326,222,NULL,18,20571,0);
INSERT INTO "django_geo_db_location" VALUES(35191,NULL,'Fort Wayne, IN 46897',14326,222,NULL,18,20572,0);
INSERT INTO "django_geo_db_location" VALUES(35192,NULL,'Fort Wayne, IN 46898',14326,222,NULL,18,20573,0);
INSERT INTO "django_geo_db_location" VALUES(35193,NULL,'Fort Wayne, IN 46899',14326,222,NULL,18,20574,0);
INSERT INTO "django_geo_db_location" VALUES(35194,NULL,'Kokomo, IN',14327,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35195,NULL,'Kokomo, IN 46901',14327,222,NULL,18,20575,0);
INSERT INTO "django_geo_db_location" VALUES(35196,NULL,'Kokomo, IN 46902',14327,222,NULL,18,20576,0);
INSERT INTO "django_geo_db_location" VALUES(35197,NULL,'Kokomo, IN 46903',14327,222,NULL,18,20577,0);
INSERT INTO "django_geo_db_location" VALUES(35198,NULL,'Kokomo, IN 46904',14327,222,NULL,18,20578,0);
INSERT INTO "django_geo_db_location" VALUES(35199,NULL,'Akron, IN',14328,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35200,NULL,'Akron, IN 46910',14328,222,NULL,18,20579,0);
INSERT INTO "django_geo_db_location" VALUES(35201,NULL,'Amboy, IN',14329,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35202,NULL,'Amboy, IN 46911',14329,222,NULL,18,20580,0);
INSERT INTO "django_geo_db_location" VALUES(35203,NULL,'Athens, IN',14330,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35204,NULL,'Athens, IN 46912',14330,222,NULL,18,20581,0);
INSERT INTO "django_geo_db_location" VALUES(35205,NULL,'Bringhurst, IN',14331,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35206,NULL,'Bringhurst, IN 46913',14331,222,NULL,18,20582,0);
INSERT INTO "django_geo_db_location" VALUES(35207,NULL,'Bunker Hill, IN',14332,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35208,NULL,'Bunker Hill, IN 46914',14332,222,NULL,18,20583,0);
INSERT INTO "django_geo_db_location" VALUES(35209,NULL,'Burlington, IN 46915',14212,222,NULL,18,20584,0);
INSERT INTO "django_geo_db_location" VALUES(35210,NULL,'Burrows, IN',14333,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35211,NULL,'Burrows, IN 46916',14333,222,NULL,18,20585,0);
INSERT INTO "django_geo_db_location" VALUES(35212,NULL,'Camden, IN',14334,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35213,NULL,'Camden, IN 46917',14334,222,NULL,18,20586,0);
INSERT INTO "django_geo_db_location" VALUES(35214,NULL,'Converse, IN',14335,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35215,NULL,'Converse, IN 46919',14335,222,NULL,18,20587,0);
INSERT INTO "django_geo_db_location" VALUES(35216,NULL,'Cutler, IN',14336,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35217,NULL,'Cutler, IN 46920',14336,222,NULL,18,20588,0);
INSERT INTO "django_geo_db_location" VALUES(35218,NULL,'Deedsville, IN',14337,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35219,NULL,'Deedsville, IN 46921',14337,222,NULL,18,20589,0);
INSERT INTO "django_geo_db_location" VALUES(35220,NULL,'Delong, IN',14338,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35221,NULL,'Delong, IN 46922',14338,222,NULL,18,20590,0);
INSERT INTO "django_geo_db_location" VALUES(35222,NULL,'Delphi, IN',14339,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35223,NULL,'Delphi, IN 46923',14339,222,NULL,18,20591,0);
INSERT INTO "django_geo_db_location" VALUES(35224,NULL,'Denver, IN',14340,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35225,NULL,'Denver, IN 46926',14340,222,NULL,18,20592,0);
INSERT INTO "django_geo_db_location" VALUES(35226,NULL,'Fairmount, IN',14341,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35227,NULL,'Fairmount, IN 46928',14341,222,NULL,18,20593,0);
INSERT INTO "django_geo_db_location" VALUES(35228,NULL,'Flora, IN',14342,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35229,NULL,'Flora, IN 46929',14342,222,NULL,18,20594,0);
INSERT INTO "django_geo_db_location" VALUES(35230,NULL,'Fowlerton, IN',14343,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35231,NULL,'Fowlerton, IN 46930',14343,222,NULL,18,20595,0);
INSERT INTO "django_geo_db_location" VALUES(35232,NULL,'Fulton, IN',14344,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35233,NULL,'Fulton, IN 46931',14344,222,NULL,18,20596,0);
INSERT INTO "django_geo_db_location" VALUES(35234,NULL,'Galveston, IN',14345,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35235,NULL,'Galveston, IN 46932',14345,222,NULL,18,20597,0);
INSERT INTO "django_geo_db_location" VALUES(35236,NULL,'Gas City, IN',14346,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35237,NULL,'Gas City, IN 46933',14346,222,NULL,18,20598,0);
INSERT INTO "django_geo_db_location" VALUES(35238,NULL,'Grass Creek, IN',14347,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35239,NULL,'Grass Creek, IN 46935',14347,222,NULL,18,20599,0);
INSERT INTO "django_geo_db_location" VALUES(35240,NULL,'Greentown, IN',14348,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35241,NULL,'Greentown, IN 46936',14348,222,NULL,18,20600,0);
INSERT INTO "django_geo_db_location" VALUES(35242,NULL,'Hemlock, IN',14349,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35243,NULL,'Hemlock, IN 46937',14349,222,NULL,18,20601,0);
INSERT INTO "django_geo_db_location" VALUES(35244,NULL,'Jonesboro, IN',14350,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35245,NULL,'Jonesboro, IN 46938',14350,222,NULL,18,20602,0);
INSERT INTO "django_geo_db_location" VALUES(35246,NULL,'Kewanna, IN',14351,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35247,NULL,'Kewanna, IN 46939',14351,222,NULL,18,20603,0);
INSERT INTO "django_geo_db_location" VALUES(35248,NULL,'La Fontaine, IN',14352,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35249,NULL,'La Fontaine, IN 46940',14352,222,NULL,18,20604,0);
INSERT INTO "django_geo_db_location" VALUES(35250,NULL,'Lagro, IN',14353,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35251,NULL,'Lagro, IN 46941',14353,222,NULL,18,20605,0);
INSERT INTO "django_geo_db_location" VALUES(35252,NULL,'Lake Cicott, IN',14354,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35253,NULL,'Lake Cicott, IN 46942',14354,222,NULL,18,20606,0);
INSERT INTO "django_geo_db_location" VALUES(35254,NULL,'Laketon, IN',14355,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35255,NULL,'Laketon, IN 46943',14355,222,NULL,18,20607,0);
INSERT INTO "django_geo_db_location" VALUES(35256,NULL,'Leiters Ford, IN',14356,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35257,NULL,'Leiters Ford, IN 46945',14356,222,NULL,18,20608,0);
INSERT INTO "django_geo_db_location" VALUES(35258,NULL,'Liberty Mills, IN',14357,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35259,NULL,'Liberty Mills, IN 46946',14357,222,NULL,18,20609,0);
INSERT INTO "django_geo_db_location" VALUES(35260,NULL,'Logansport, IN',14358,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35261,NULL,'Logansport, IN 46947',14358,222,NULL,18,20610,0);
INSERT INTO "django_geo_db_location" VALUES(35262,NULL,'Lucerne, IN',14359,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35263,NULL,'Lucerne, IN 46950',14359,222,NULL,18,20611,0);
INSERT INTO "django_geo_db_location" VALUES(35264,NULL,'Macy, IN',14360,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35265,NULL,'Macy, IN 46951',14360,222,NULL,18,20612,0);
INSERT INTO "django_geo_db_location" VALUES(35266,NULL,'Marion, IN',14361,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35267,NULL,'Marion, IN 46952',14361,222,NULL,18,20613,0);
INSERT INTO "django_geo_db_location" VALUES(35268,NULL,'Marion, IN 46953',14361,222,NULL,18,20614,0);
INSERT INTO "django_geo_db_location" VALUES(35269,NULL,'Matthews, IN',14362,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35270,NULL,'Matthews, IN 46957',14362,222,NULL,18,20615,0);
INSERT INTO "django_geo_db_location" VALUES(35271,NULL,'Mexico, IN',14363,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35272,NULL,'Mexico, IN 46958',14363,222,NULL,18,20616,0);
INSERT INTO "django_geo_db_location" VALUES(35273,NULL,'Miami, IN',14364,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35274,NULL,'Miami, IN 46959',14364,222,NULL,18,20617,0);
INSERT INTO "django_geo_db_location" VALUES(35275,NULL,'Monterey, IN',14365,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35276,NULL,'Monterey, IN 46960',14365,222,NULL,18,20618,0);
INSERT INTO "django_geo_db_location" VALUES(35277,NULL,'New Waverly, IN',14366,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35278,NULL,'New Waverly, IN 46961',14366,222,NULL,18,20619,0);
INSERT INTO "django_geo_db_location" VALUES(35279,NULL,'North Manchester, IN',14367,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35280,NULL,'North Manchester, IN 46962',14367,222,NULL,18,20620,0);
INSERT INTO "django_geo_db_location" VALUES(35281,NULL,'Oakford, IN',14368,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35282,NULL,'Oakford, IN 46965',14368,222,NULL,18,20621,0);
INSERT INTO "django_geo_db_location" VALUES(35283,NULL,'Harrison, IN',14369,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35284,NULL,'Harrison, IN 46966',14369,222,NULL,18,20622,0);
INSERT INTO "django_geo_db_location" VALUES(35285,NULL,'Onward, IN',14370,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35286,NULL,'Onward, IN 46967',14370,222,NULL,18,20623,0);
INSERT INTO "django_geo_db_location" VALUES(35287,NULL,'Ora, IN',14371,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35288,NULL,'Ora, IN 46968',14371,222,NULL,18,20624,0);
INSERT INTO "django_geo_db_location" VALUES(35289,NULL,'Peru, IN',14372,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35290,NULL,'Peru, IN 46970',14372,222,NULL,18,20625,0);
INSERT INTO "django_geo_db_location" VALUES(35291,NULL,'Grissom AFB, IN',14373,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35292,NULL,'Grissom AFB, IN 46971',14373,222,NULL,18,20626,0);
INSERT INTO "django_geo_db_location" VALUES(35293,NULL,'Roann, IN',14374,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35294,NULL,'Roann, IN 46974',14374,222,NULL,18,20627,0);
INSERT INTO "django_geo_db_location" VALUES(35295,NULL,'Rochester, IN',14375,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35296,NULL,'Rochester, IN 46975',14375,222,NULL,18,20628,0);
INSERT INTO "django_geo_db_location" VALUES(35297,NULL,'Rockfield, IN',14376,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35298,NULL,'Rockfield, IN 46977',14376,222,NULL,18,20629,0);
INSERT INTO "django_geo_db_location" VALUES(35299,NULL,'Royal Center, IN',14377,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35300,NULL,'Royal Center, IN 46978',14377,222,NULL,18,20630,0);
INSERT INTO "django_geo_db_location" VALUES(35301,NULL,'Russiaville, IN 46979',14190,222,NULL,18,20631,0);
INSERT INTO "django_geo_db_location" VALUES(35302,NULL,'Servia, IN',14378,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35303,NULL,'Servia, IN 46980',14378,222,NULL,18,20632,0);
INSERT INTO "django_geo_db_location" VALUES(35304,NULL,'Silver Lake, IN',14379,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35305,NULL,'Silver Lake, IN 46982',14379,222,NULL,18,20633,0);
INSERT INTO "django_geo_db_location" VALUES(35306,NULL,'Somerset, IN',14380,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35307,NULL,'Somerset, IN 46984',14380,222,NULL,18,20634,0);
INSERT INTO "django_geo_db_location" VALUES(35308,NULL,'Star City, IN',14381,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35309,NULL,'Star City, IN 46985',14381,222,NULL,18,20635,0);
INSERT INTO "django_geo_db_location" VALUES(35310,NULL,'Swayzee, IN',14382,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35311,NULL,'Swayzee, IN 46986',14382,222,NULL,18,20636,0);
INSERT INTO "django_geo_db_location" VALUES(35312,NULL,'Sweetser, IN',14383,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35313,NULL,'Sweetser, IN 46987',14383,222,NULL,18,20637,0);
INSERT INTO "django_geo_db_location" VALUES(35314,NULL,'Twelve Mile, IN',14384,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35315,NULL,'Twelve Mile, IN 46988',14384,222,NULL,18,20638,0);
INSERT INTO "django_geo_db_location" VALUES(35316,NULL,'Upland, IN',14385,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35317,NULL,'Upland, IN 46989',14385,222,NULL,18,20639,0);
INSERT INTO "django_geo_db_location" VALUES(35318,NULL,'Urbana, IN',14386,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35319,NULL,'Urbana, IN 46990',14386,222,NULL,18,20640,0);
INSERT INTO "django_geo_db_location" VALUES(35320,NULL,'Van Buren, IN',14387,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35321,NULL,'Van Buren, IN 46991',14387,222,NULL,18,20641,0);
INSERT INTO "django_geo_db_location" VALUES(35322,NULL,'Wabash, IN',14388,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35323,NULL,'Wabash, IN 46992',14388,222,NULL,18,20642,0);
INSERT INTO "django_geo_db_location" VALUES(35324,NULL,'Walton, IN',14389,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35325,NULL,'Walton, IN 46994',14389,222,NULL,18,20643,0);
INSERT INTO "django_geo_db_location" VALUES(35326,NULL,'West Middleton, IN',14390,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35327,NULL,'West Middleton, IN 46995',14390,222,NULL,18,20644,0);
INSERT INTO "django_geo_db_location" VALUES(35328,NULL,'Winamac, IN',14391,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35329,NULL,'Winamac, IN 46996',14391,222,NULL,18,20645,0);
INSERT INTO "django_geo_db_location" VALUES(35330,NULL,'Young America, IN',14392,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35331,NULL,'Young America, IN 46998',14392,222,NULL,18,20646,0);
INSERT INTO "django_geo_db_location" VALUES(35332,NULL,'Aurora, IN',14393,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35333,NULL,'Aurora, IN 47001',14393,222,NULL,18,20647,0);
INSERT INTO "django_geo_db_location" VALUES(35334,NULL,'West College Corner, IN',14394,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35335,NULL,'West College Corner, IN 47003',14394,222,NULL,18,20648,0);
INSERT INTO "django_geo_db_location" VALUES(35336,NULL,'Batesville, IN',14395,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35337,NULL,'Batesville, IN 47006',14395,222,NULL,18,20649,0);
INSERT INTO "django_geo_db_location" VALUES(35338,NULL,'Bath, IN',14396,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35339,NULL,'Bath, IN 47010',14396,222,NULL,18,20650,0);
INSERT INTO "django_geo_db_location" VALUES(35340,NULL,'Bennington, IN',14397,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35341,NULL,'Bennington, IN 47011',14397,222,NULL,18,20651,0);
INSERT INTO "django_geo_db_location" VALUES(35342,NULL,'Brookville, IN',14398,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35343,NULL,'Brookville, IN 47012',14398,222,NULL,18,20652,0);
INSERT INTO "django_geo_db_location" VALUES(35344,NULL,'Cedar Grove, IN',14399,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35345,NULL,'Cedar Grove, IN 47016',14399,222,NULL,18,20653,0);
INSERT INTO "django_geo_db_location" VALUES(35346,NULL,'Cross Plains, IN',14400,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35347,NULL,'Cross Plains, IN 47017',14400,222,NULL,18,20654,0);
INSERT INTO "django_geo_db_location" VALUES(35348,NULL,'Dillsboro, IN',14401,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35349,NULL,'Dillsboro, IN 47018',14401,222,NULL,18,20655,0);
INSERT INTO "django_geo_db_location" VALUES(35350,NULL,'East Enterprise, IN',14402,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35351,NULL,'East Enterprise, IN 47019',14402,222,NULL,18,20656,0);
INSERT INTO "django_geo_db_location" VALUES(35352,NULL,'Florence, IN',14403,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35353,NULL,'Florence, IN 47020',14403,222,NULL,18,20657,0);
INSERT INTO "django_geo_db_location" VALUES(35354,NULL,'Friendship, IN',14404,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35355,NULL,'Friendship, IN 47021',14404,222,NULL,18,20658,0);
INSERT INTO "django_geo_db_location" VALUES(35356,NULL,'Guilford, IN',14405,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35357,NULL,'Guilford, IN 47022',14405,222,NULL,18,20659,0);
INSERT INTO "django_geo_db_location" VALUES(35358,NULL,'Holton, IN',14406,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35359,NULL,'Holton, IN 47023',14406,222,NULL,18,20660,0);
INSERT INTO "django_geo_db_location" VALUES(35360,NULL,'Laurel, IN',14407,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35361,NULL,'Laurel, IN 47024',14407,222,NULL,18,20661,0);
INSERT INTO "django_geo_db_location" VALUES(35362,NULL,'Lawrenceburg, IN',14408,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35363,NULL,'Lawrenceburg, IN 47025',14408,222,NULL,18,20662,0);
INSERT INTO "django_geo_db_location" VALUES(35364,NULL,'Metamora, IN',14409,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35365,NULL,'Metamora, IN 47030',14409,222,NULL,18,20663,0);
INSERT INTO "django_geo_db_location" VALUES(35366,NULL,'Milan, IN',14410,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35367,NULL,'Milan, IN 47031',14410,222,NULL,18,20664,0);
INSERT INTO "django_geo_db_location" VALUES(35368,NULL,'Moores Hill, IN',14411,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35369,NULL,'Moores Hill, IN 47032',14411,222,NULL,18,20665,0);
INSERT INTO "django_geo_db_location" VALUES(35370,NULL,'Morris, IN',14412,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35371,NULL,'Morris, IN 47033',14412,222,NULL,18,20666,0);
INSERT INTO "django_geo_db_location" VALUES(35372,NULL,'Napoleon, IN',14413,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35373,NULL,'Napoleon, IN 47034',14413,222,NULL,18,20667,0);
INSERT INTO "django_geo_db_location" VALUES(35374,NULL,'New Trenton, IN',14414,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35375,NULL,'New Trenton, IN 47035',14414,222,NULL,18,20668,0);
INSERT INTO "django_geo_db_location" VALUES(35376,NULL,'Oldenburg, IN',14415,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35377,NULL,'Oldenburg, IN 47036',14415,222,NULL,18,20669,0);
INSERT INTO "django_geo_db_location" VALUES(35378,NULL,'Osgood, IN',14416,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35379,NULL,'Osgood, IN 47037',14416,222,NULL,18,20670,0);
INSERT INTO "django_geo_db_location" VALUES(35380,NULL,'Patriot, IN',14417,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35381,NULL,'Patriot, IN 47038',14417,222,NULL,18,20671,0);
INSERT INTO "django_geo_db_location" VALUES(35382,NULL,'Pierceville, IN',14418,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35383,NULL,'Pierceville, IN 47039',14418,222,NULL,18,20672,0);
INSERT INTO "django_geo_db_location" VALUES(35384,NULL,'Rising Sun, IN',14419,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35385,NULL,'Rising Sun, IN 47040',14419,222,NULL,18,20673,0);
INSERT INTO "django_geo_db_location" VALUES(35386,NULL,'Sunman, IN',14420,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35387,NULL,'Sunman, IN 47041',14420,222,NULL,18,20674,0);
INSERT INTO "django_geo_db_location" VALUES(35388,NULL,'Versailles, IN',14421,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35389,NULL,'Versailles, IN 47042',14421,222,NULL,18,20675,0);
INSERT INTO "django_geo_db_location" VALUES(35390,NULL,'Vevay, IN',14422,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35391,NULL,'Vevay, IN 47043',14422,222,NULL,18,20676,0);
INSERT INTO "django_geo_db_location" VALUES(35392,NULL,'Jefferson, IN',14423,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35393,NULL,'Jefferson, IN 47045',14423,222,NULL,18,20677,0);
INSERT INTO "django_geo_db_location" VALUES(35394,NULL,'Bloomington, IN',14424,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35395,NULL,'Bloomington, IN 47048',14424,222,NULL,18,20678,0);
INSERT INTO "django_geo_db_location" VALUES(35396,NULL,'West Harrison, IN',14425,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35397,NULL,'West Harrison, IN 47060',14425,222,NULL,18,20679,0);
INSERT INTO "django_geo_db_location" VALUES(35398,NULL,'Lovett, IN',14426,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35399,NULL,'Lovett, IN 47070',14426,222,NULL,18,20680,0);
INSERT INTO "django_geo_db_location" VALUES(35400,NULL,'Jefferson, IN 47093',14423,222,NULL,18,20681,0);
INSERT INTO "django_geo_db_location" VALUES(35401,NULL,'Austin, IN',14427,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35402,NULL,'Austin, IN 47102',14427,222,NULL,18,20682,0);
INSERT INTO "django_geo_db_location" VALUES(35403,NULL,'Bethlehem, IN',14428,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35404,NULL,'Bethlehem, IN 47104',14428,222,NULL,18,20683,0);
INSERT INTO "django_geo_db_location" VALUES(35405,NULL,'Borden, IN',14429,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35406,NULL,'Borden, IN 47106',14429,222,NULL,18,20684,0);
INSERT INTO "django_geo_db_location" VALUES(35407,NULL,'Bradford, IN',14430,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35408,NULL,'Bradford, IN 47107',14430,222,NULL,18,20685,0);
INSERT INTO "django_geo_db_location" VALUES(35409,NULL,'Campbellsburg, IN',14431,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35410,NULL,'Campbellsburg, IN 47108',14431,222,NULL,18,20686,0);
INSERT INTO "django_geo_db_location" VALUES(35411,NULL,'Central, IN',14432,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35412,NULL,'Central, IN 47110',14432,222,NULL,18,20687,0);
INSERT INTO "django_geo_db_location" VALUES(35413,NULL,'Charlestown, IN',14433,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35414,NULL,'Charlestown, IN 47111',14433,222,NULL,18,20688,0);
INSERT INTO "django_geo_db_location" VALUES(35415,NULL,'Corydon, IN',14434,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35416,NULL,'Corydon, IN 47112',14434,222,NULL,18,20689,0);
INSERT INTO "django_geo_db_location" VALUES(35417,NULL,'Crandall, IN',14435,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35418,NULL,'Crandall, IN 47114',14435,222,NULL,18,20690,0);
INSERT INTO "django_geo_db_location" VALUES(35419,NULL,'Depauw, IN',14436,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35420,NULL,'Depauw, IN 47115',14436,222,NULL,18,20691,0);
INSERT INTO "django_geo_db_location" VALUES(35421,NULL,'Eckerty, IN',14437,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35422,NULL,'Eckerty, IN 47116',14437,222,NULL,18,20692,0);
INSERT INTO "django_geo_db_location" VALUES(35423,NULL,'Elizabeth, IN',14438,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35424,NULL,'Elizabeth, IN 47117',14438,222,NULL,18,20693,0);
INSERT INTO "django_geo_db_location" VALUES(35425,NULL,'English, IN',14439,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35426,NULL,'English, IN 47118',14439,222,NULL,18,20694,0);
INSERT INTO "django_geo_db_location" VALUES(35427,NULL,'Floyds Knobs, IN',14440,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35428,NULL,'Floyds Knobs, IN 47119',14440,222,NULL,18,20695,0);
INSERT INTO "django_geo_db_location" VALUES(35429,NULL,'Fredericksburg, IN',14441,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35430,NULL,'Fredericksburg, IN 47120',14441,222,NULL,18,20696,0);
INSERT INTO "django_geo_db_location" VALUES(35431,NULL,'Georgetown, IN',14442,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35432,NULL,'Georgetown, IN 47122',14442,222,NULL,18,20697,0);
INSERT INTO "django_geo_db_location" VALUES(35433,NULL,'Grantsburg, IN',14443,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35434,NULL,'Grantsburg, IN 47123',14443,222,NULL,18,20698,0);
INSERT INTO "django_geo_db_location" VALUES(35435,NULL,'Greenville, IN',14444,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35436,NULL,'Greenville, IN 47124',14444,222,NULL,18,20699,0);
INSERT INTO "django_geo_db_location" VALUES(35437,NULL,'Hardinsburg, IN',14445,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35438,NULL,'Hardinsburg, IN 47125',14445,222,NULL,18,20700,0);
INSERT INTO "django_geo_db_location" VALUES(35439,NULL,'Henryville, IN',14446,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35440,NULL,'Henryville, IN 47126',14446,222,NULL,18,20701,0);
INSERT INTO "django_geo_db_location" VALUES(35441,NULL,'Madison, IN 47128',14223,222,NULL,18,20702,0);
INSERT INTO "django_geo_db_location" VALUES(35442,NULL,'Clarksville, IN',14447,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35443,NULL,'Clarksville, IN 47129',14447,222,NULL,18,20703,0);
INSERT INTO "django_geo_db_location" VALUES(35444,NULL,'Jeffersonville, IN',14448,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35445,NULL,'Jeffersonville, IN 47130',14448,222,NULL,18,20704,0);
INSERT INTO "django_geo_db_location" VALUES(35446,NULL,'Jeffersonville, IN 47131',14448,222,NULL,18,20705,0);
INSERT INTO "django_geo_db_location" VALUES(35447,NULL,'Jeffersonville, IN 47132',14448,222,NULL,18,20706,0);
INSERT INTO "django_geo_db_location" VALUES(35448,NULL,'Jeffersonville, IN 47133',14448,222,NULL,18,20707,0);
INSERT INTO "django_geo_db_location" VALUES(35449,NULL,'Jeffersonville, IN 47134',14448,222,NULL,18,20708,0);
INSERT INTO "django_geo_db_location" VALUES(35450,NULL,'Laconia, IN',14449,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35451,NULL,'Laconia, IN 47135',14449,222,NULL,18,20709,0);
INSERT INTO "django_geo_db_location" VALUES(35452,NULL,'Lanesville, IN',14450,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35453,NULL,'Lanesville, IN 47136',14450,222,NULL,18,20710,0);
INSERT INTO "django_geo_db_location" VALUES(35454,NULL,'Leavenworth, IN',14451,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35455,NULL,'Leavenworth, IN 47137',14451,222,NULL,18,20711,0);
INSERT INTO "django_geo_db_location" VALUES(35456,NULL,'Lexington, IN',14452,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35457,NULL,'Lexington, IN 47138',14452,222,NULL,18,20712,0);
INSERT INTO "django_geo_db_location" VALUES(35458,NULL,'Little York, IN',14453,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35459,NULL,'Little York, IN 47139',14453,222,NULL,18,20713,0);
INSERT INTO "django_geo_db_location" VALUES(35460,NULL,'Marengo, IN',14454,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35461,NULL,'Marengo, IN 47140',14454,222,NULL,18,20714,0);
INSERT INTO "django_geo_db_location" VALUES(35462,NULL,'Marysville, IN',14455,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35463,NULL,'Marysville, IN 47141',14455,222,NULL,18,20715,0);
INSERT INTO "django_geo_db_location" VALUES(35464,NULL,'Mauckport, IN',14456,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35465,NULL,'Mauckport, IN 47142',14456,222,NULL,18,20716,0);
INSERT INTO "django_geo_db_location" VALUES(35466,NULL,'Memphis, IN',14457,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35467,NULL,'Memphis, IN 47143',14457,222,NULL,18,20717,0);
INSERT INTO "django_geo_db_location" VALUES(35468,NULL,'Jeffersonville, IN 47144',14448,222,NULL,18,20718,0);
INSERT INTO "django_geo_db_location" VALUES(35469,NULL,'Milltown, IN',14458,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35470,NULL,'Milltown, IN 47145',14458,222,NULL,18,20719,0);
INSERT INTO "django_geo_db_location" VALUES(35471,NULL,'Mount Saint Francis, IN',14459,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35472,NULL,'Mount Saint Francis, IN 47146',14459,222,NULL,18,20720,0);
INSERT INTO "django_geo_db_location" VALUES(35473,NULL,'Nabb, IN',14460,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35474,NULL,'Nabb, IN 47147',14460,222,NULL,18,20721,0);
INSERT INTO "django_geo_db_location" VALUES(35475,NULL,'New Albany, IN',14461,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35476,NULL,'New Albany, IN 47150',14461,222,NULL,18,20722,0);
INSERT INTO "django_geo_db_location" VALUES(35477,NULL,'New Albany, IN 47151',14461,222,NULL,18,20723,0);
INSERT INTO "django_geo_db_location" VALUES(35478,NULL,'New Middletown, IN',14462,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35479,NULL,'New Middletown, IN 47160',14462,222,NULL,18,20724,0);
INSERT INTO "django_geo_db_location" VALUES(35480,NULL,'New Salisbury, IN',14463,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35481,NULL,'New Salisbury, IN 47161',14463,222,NULL,18,20725,0);
INSERT INTO "django_geo_db_location" VALUES(35482,NULL,'New Washington, IN',14464,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35483,NULL,'New Washington, IN 47162',14464,222,NULL,18,20726,0);
INSERT INTO "django_geo_db_location" VALUES(35484,NULL,'Otisco, IN',14465,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35485,NULL,'Otisco, IN 47163',14465,222,NULL,18,20727,0);
INSERT INTO "django_geo_db_location" VALUES(35486,NULL,'Palmyra, IN',14466,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35487,NULL,'Palmyra, IN 47164',14466,222,NULL,18,20728,0);
INSERT INTO "django_geo_db_location" VALUES(35488,NULL,'Pekin, IN',14467,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35489,NULL,'Pekin, IN 47165',14467,222,NULL,18,20729,0);
INSERT INTO "django_geo_db_location" VALUES(35490,NULL,'Ramsey, IN',14468,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35491,NULL,'Ramsey, IN 47166',14468,222,NULL,18,20730,0);
INSERT INTO "django_geo_db_location" VALUES(35492,NULL,'Salem, IN',14469,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35493,NULL,'Salem, IN 47167',14469,222,NULL,18,20731,0);
INSERT INTO "django_geo_db_location" VALUES(35494,NULL,'Washington, IN 47169',14161,222,NULL,18,20732,0);
INSERT INTO "django_geo_db_location" VALUES(35495,NULL,'Scottsburg, IN',14470,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35496,NULL,'Scottsburg, IN 47170',14470,222,NULL,18,20733,0);
INSERT INTO "django_geo_db_location" VALUES(35497,NULL,'Sellersburg, IN',14471,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35498,NULL,'Sellersburg, IN 47172',14471,222,NULL,18,20734,0);
INSERT INTO "django_geo_db_location" VALUES(35499,NULL,'Sulphur, IN',14472,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35500,NULL,'Sulphur, IN 47174',14472,222,NULL,18,20735,0);
INSERT INTO "django_geo_db_location" VALUES(35501,NULL,'Taswell, IN',14473,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35502,NULL,'Taswell, IN 47175',14473,222,NULL,18,20736,0);
INSERT INTO "django_geo_db_location" VALUES(35503,NULL,'Underwood, IN',14474,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35504,NULL,'Underwood, IN 47177',14474,222,NULL,18,20737,0);
INSERT INTO "django_geo_db_location" VALUES(35505,NULL,'Jeffersonville, IN 47190',14448,222,NULL,18,20738,0);
INSERT INTO "django_geo_db_location" VALUES(35506,NULL,'Jeffersonville, IN 47199',14448,222,NULL,18,20739,0);
INSERT INTO "django_geo_db_location" VALUES(35507,NULL,'Columbus, IN',14475,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35508,NULL,'Columbus, IN 47201',14475,222,NULL,18,20740,0);
INSERT INTO "django_geo_db_location" VALUES(35509,NULL,'Columbus, IN 47202',14475,222,NULL,18,20741,0);
INSERT INTO "django_geo_db_location" VALUES(35510,NULL,'Columbus, IN 47203',14475,222,NULL,18,20742,0);
INSERT INTO "django_geo_db_location" VALUES(35511,NULL,'Brownstown, IN',14476,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35512,NULL,'Brownstown, IN 47220',14476,222,NULL,18,20743,0);
INSERT INTO "django_geo_db_location" VALUES(35513,NULL,'Butlerville, IN',14477,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35514,NULL,'Butlerville, IN 47223',14477,222,NULL,18,20744,0);
INSERT INTO "django_geo_db_location" VALUES(35515,NULL,'Canaan, IN',14478,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35516,NULL,'Canaan, IN 47224',14478,222,NULL,18,20745,0);
INSERT INTO "django_geo_db_location" VALUES(35517,NULL,'Clarksburg, IN',14479,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35518,NULL,'Clarksburg, IN 47225',14479,222,NULL,18,20746,0);
INSERT INTO "django_geo_db_location" VALUES(35519,NULL,'Clifford, IN',14480,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35520,NULL,'Clifford, IN 47226',14480,222,NULL,18,20747,0);
INSERT INTO "django_geo_db_location" VALUES(35521,NULL,'Commiskey, IN',14481,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35522,NULL,'Commiskey, IN 47227',14481,222,NULL,18,20748,0);
INSERT INTO "django_geo_db_location" VALUES(35523,NULL,'Cortland, IN',14482,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35524,NULL,'Cortland, IN 47228',14482,222,NULL,18,20749,0);
INSERT INTO "django_geo_db_location" VALUES(35525,NULL,'Crothersville, IN',14483,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35526,NULL,'Crothersville, IN 47229',14483,222,NULL,18,20750,0);
INSERT INTO "django_geo_db_location" VALUES(35527,NULL,'Deputy, IN',14484,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35528,NULL,'Deputy, IN 47230',14484,222,NULL,18,20751,0);
INSERT INTO "django_geo_db_location" VALUES(35529,NULL,'Dupont, IN',14485,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35530,NULL,'Dupont, IN 47231',14485,222,NULL,18,20752,0);
INSERT INTO "django_geo_db_location" VALUES(35531,NULL,'Elizabethtown, IN',14486,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35532,NULL,'Elizabethtown, IN 47232',14486,222,NULL,18,20753,0);
INSERT INTO "django_geo_db_location" VALUES(35533,NULL,'Flat Rock, IN',14487,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35534,NULL,'Flat Rock, IN 47234',14487,222,NULL,18,20754,0);
INSERT INTO "django_geo_db_location" VALUES(35535,NULL,'Freetown, IN',14488,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35536,NULL,'Freetown, IN 47235',14488,222,NULL,18,20755,0);
INSERT INTO "django_geo_db_location" VALUES(35537,NULL,'Grammer, IN',14489,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35538,NULL,'Grammer, IN 47236',14489,222,NULL,18,20756,0);
INSERT INTO "django_geo_db_location" VALUES(35539,NULL,'Greensburg, IN',14490,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35540,NULL,'Greensburg, IN 47240',14490,222,NULL,18,20757,0);
INSERT INTO "django_geo_db_location" VALUES(35541,NULL,'Bedford, IN',14491,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35542,NULL,'Bedford, IN 47241',14491,222,NULL,18,20758,0);
INSERT INTO "django_geo_db_location" VALUES(35543,NULL,'Hanover, IN',14492,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35544,NULL,'Hanover, IN 47243',14492,222,NULL,18,20759,0);
INSERT INTO "django_geo_db_location" VALUES(35545,NULL,'Hartsville, IN',14493,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35546,NULL,'Hartsville, IN 47244',14493,222,NULL,18,20760,0);
INSERT INTO "django_geo_db_location" VALUES(35547,NULL,'Hayden, IN',14494,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35548,NULL,'Hayden, IN 47245',14494,222,NULL,18,20761,0);
INSERT INTO "django_geo_db_location" VALUES(35549,NULL,'Hope, IN',14495,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35550,NULL,'Hope, IN 47246',14495,222,NULL,18,20762,0);
INSERT INTO "django_geo_db_location" VALUES(35551,NULL,'Jonesville, IN',14496,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35552,NULL,'Jonesville, IN 47247',14496,222,NULL,18,20763,0);
INSERT INTO "django_geo_db_location" VALUES(35553,NULL,'Kurtz, IN',14497,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35554,NULL,'Kurtz, IN 47249',14497,222,NULL,18,20764,0);
INSERT INTO "django_geo_db_location" VALUES(35555,NULL,'Madison, IN 47250',14223,222,NULL,18,20765,0);
INSERT INTO "django_geo_db_location" VALUES(35556,NULL,'North Vernon, IN',14498,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35557,NULL,'North Vernon, IN 47256',14498,222,NULL,18,20766,0);
INSERT INTO "django_geo_db_location" VALUES(35558,NULL,'North Vernon, IN 47257',14498,222,NULL,18,20767,0);
INSERT INTO "django_geo_db_location" VALUES(35559,NULL,'Medora, IN',14499,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35560,NULL,'Medora, IN 47260',14499,222,NULL,18,20768,0);
INSERT INTO "django_geo_db_location" VALUES(35561,NULL,'Millhousen, IN',14500,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35562,NULL,'Millhousen, IN 47261',14500,222,NULL,18,20769,0);
INSERT INTO "django_geo_db_location" VALUES(35563,NULL,'Nebraska, IN',14501,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35564,NULL,'Nebraska, IN 47262',14501,222,NULL,18,20770,0);
INSERT INTO "django_geo_db_location" VALUES(35565,NULL,'New Point, IN',14502,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35566,NULL,'New Point, IN 47263',14502,222,NULL,18,20771,0);
INSERT INTO "django_geo_db_location" VALUES(35567,NULL,'Norman, IN',14503,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35568,NULL,'Norman, IN 47264',14503,222,NULL,18,20772,0);
INSERT INTO "django_geo_db_location" VALUES(35569,NULL,'North Vernon, IN 47265',14498,222,NULL,18,20773,0);
INSERT INTO "django_geo_db_location" VALUES(35570,NULL,'Paris Crossing, IN',14504,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35571,NULL,'Paris Crossing, IN 47270',14504,222,NULL,18,20774,0);
INSERT INTO "django_geo_db_location" VALUES(35572,NULL,'Saint Paul, IN',14505,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35573,NULL,'Saint Paul, IN 47272',14505,222,NULL,18,20775,0);
INSERT INTO "django_geo_db_location" VALUES(35574,NULL,'Scipio, IN',14506,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35575,NULL,'Scipio, IN 47273',14506,222,NULL,18,20776,0);
INSERT INTO "django_geo_db_location" VALUES(35576,NULL,'Seymour, IN',14507,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35577,NULL,'Seymour, IN 47274',14507,222,NULL,18,20777,0);
INSERT INTO "django_geo_db_location" VALUES(35578,NULL,'Taylorsville, IN',14508,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35579,NULL,'Taylorsville, IN 47280',14508,222,NULL,18,20778,0);
INSERT INTO "django_geo_db_location" VALUES(35580,NULL,'Vallonia, IN',14509,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35581,NULL,'Vallonia, IN 47281',14509,222,NULL,18,20779,0);
INSERT INTO "django_geo_db_location" VALUES(35582,NULL,'Vernon, IN',14510,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35583,NULL,'Vernon, IN 47282',14510,222,NULL,18,20780,0);
INSERT INTO "django_geo_db_location" VALUES(35584,NULL,'Westport, IN',14511,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35585,NULL,'Westport, IN 47283',14511,222,NULL,18,20781,0);
INSERT INTO "django_geo_db_location" VALUES(35586,NULL,'Cayuga, IN',14512,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35587,NULL,'Cayuga, IN 47288',14512,222,NULL,18,20782,0);
INSERT INTO "django_geo_db_location" VALUES(35588,NULL,'Muncie, IN',14513,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35589,NULL,'Muncie, IN 47302',14513,222,NULL,18,20783,0);
INSERT INTO "django_geo_db_location" VALUES(35590,NULL,'Muncie, IN 47303',14513,222,NULL,18,20784,0);
INSERT INTO "django_geo_db_location" VALUES(35591,NULL,'Muncie, IN 47304',14513,222,NULL,18,20785,0);
INSERT INTO "django_geo_db_location" VALUES(35592,NULL,'Muncie, IN 47305',14513,222,NULL,18,20786,0);
INSERT INTO "django_geo_db_location" VALUES(35593,NULL,'Muncie, IN 47306',14513,222,NULL,18,20787,0);
INSERT INTO "django_geo_db_location" VALUES(35594,NULL,'Muncie, IN 47307',14513,222,NULL,18,20788,0);
INSERT INTO "django_geo_db_location" VALUES(35595,NULL,'Muncie, IN 47308',14513,222,NULL,18,20789,0);
INSERT INTO "django_geo_db_location" VALUES(35596,NULL,'Kennard, IN',14514,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35597,NULL,'Kennard, IN 47317',14514,222,NULL,18,20790,0);
INSERT INTO "django_geo_db_location" VALUES(35598,NULL,'Albany, IN',14515,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35599,NULL,'Albany, IN 47320',14515,222,NULL,18,20791,0);
INSERT INTO "django_geo_db_location" VALUES(35600,NULL,'Bentonville, IN',14516,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35601,NULL,'Bentonville, IN 47322',14516,222,NULL,18,20792,0);
INSERT INTO "django_geo_db_location" VALUES(35602,NULL,'Boston, IN',14517,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35603,NULL,'Boston, IN 47324',14517,222,NULL,18,20793,0);
INSERT INTO "django_geo_db_location" VALUES(35604,NULL,'Brownsville, IN',14518,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35605,NULL,'Brownsville, IN 47325',14518,222,NULL,18,20794,0);
INSERT INTO "django_geo_db_location" VALUES(35606,NULL,'Bryant, IN',14519,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35607,NULL,'Bryant, IN 47326',14519,222,NULL,18,20795,0);
INSERT INTO "django_geo_db_location" VALUES(35608,NULL,'Cambridge City, IN',14520,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35609,NULL,'Cambridge City, IN 47327',14520,222,NULL,18,20796,0);
INSERT INTO "django_geo_db_location" VALUES(35610,NULL,'Centerville, IN',14521,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35611,NULL,'Centerville, IN 47330',14521,222,NULL,18,20797,0);
INSERT INTO "django_geo_db_location" VALUES(35612,NULL,'Connersville, IN',14522,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35613,NULL,'Connersville, IN 47331',14522,222,NULL,18,20798,0);
INSERT INTO "django_geo_db_location" VALUES(35614,NULL,'Daleville, IN',14523,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35615,NULL,'Daleville, IN 47334',14523,222,NULL,18,20799,0);
INSERT INTO "django_geo_db_location" VALUES(35616,NULL,'Dublin, IN',14524,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35617,NULL,'Dublin, IN 47335',14524,222,NULL,18,20800,0);
INSERT INTO "django_geo_db_location" VALUES(35618,NULL,'Dunkirk, IN',14525,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35619,NULL,'Dunkirk, IN 47336',14525,222,NULL,18,20801,0);
INSERT INTO "django_geo_db_location" VALUES(35620,NULL,'Dunreith, IN',14526,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35621,NULL,'Dunreith, IN 47337',14526,222,NULL,18,20802,0);
INSERT INTO "django_geo_db_location" VALUES(35622,NULL,'Eaton, IN',14527,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35623,NULL,'Eaton, IN 47338',14527,222,NULL,18,20803,0);
INSERT INTO "django_geo_db_location" VALUES(35624,NULL,'Economy, IN',14528,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35625,NULL,'Economy, IN 47339',14528,222,NULL,18,20804,0);
INSERT INTO "django_geo_db_location" VALUES(35626,NULL,'Farmland, IN',14529,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35627,NULL,'Farmland, IN 47340',14529,222,NULL,18,20805,0);
INSERT INTO "django_geo_db_location" VALUES(35628,NULL,'Fountain City, IN',14530,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35629,NULL,'Fountain City, IN 47341',14530,222,NULL,18,20806,0);
INSERT INTO "django_geo_db_location" VALUES(35630,NULL,'Gaston, IN',14531,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35631,NULL,'Gaston, IN 47342',14531,222,NULL,18,20807,0);
INSERT INTO "django_geo_db_location" VALUES(35632,NULL,'Greensboro, IN',14532,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35633,NULL,'Greensboro, IN 47344',14532,222,NULL,18,20808,0);
INSERT INTO "django_geo_db_location" VALUES(35634,NULL,'Greens Fork, IN',14533,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35635,NULL,'Greens Fork, IN 47345',14533,222,NULL,18,20809,0);
INSERT INTO "django_geo_db_location" VALUES(35636,NULL,'Hagerstown, IN',14534,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35637,NULL,'Hagerstown, IN 47346',14534,222,NULL,18,20810,0);
INSERT INTO "django_geo_db_location" VALUES(35638,NULL,'Hartford City, IN',14535,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35639,NULL,'Hartford City, IN 47348',14535,222,NULL,18,20811,0);
INSERT INTO "django_geo_db_location" VALUES(35640,NULL,'Kennard, IN 47351',14514,222,NULL,18,20812,0);
INSERT INTO "django_geo_db_location" VALUES(35641,NULL,'Lewisville, IN',14536,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35642,NULL,'Lewisville, IN 47352',14536,222,NULL,18,20813,0);
INSERT INTO "django_geo_db_location" VALUES(35643,NULL,'Liberty, IN',14537,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35644,NULL,'Liberty, IN 47353',14537,222,NULL,18,20814,0);
INSERT INTO "django_geo_db_location" VALUES(35645,NULL,'Losantville, IN',14538,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35646,NULL,'Losantville, IN 47354',14538,222,NULL,18,20815,0);
INSERT INTO "django_geo_db_location" VALUES(35647,NULL,'Lynn, IN',14539,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35648,NULL,'Lynn, IN 47355',14539,222,NULL,18,20816,0);
INSERT INTO "django_geo_db_location" VALUES(35649,NULL,'Middletown, IN',14540,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35650,NULL,'Middletown, IN 47356',14540,222,NULL,18,20817,0);
INSERT INTO "django_geo_db_location" VALUES(35651,NULL,'Milton, IN',14541,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35652,NULL,'Milton, IN 47357',14541,222,NULL,18,20818,0);
INSERT INTO "django_geo_db_location" VALUES(35653,NULL,'Modoc, IN',14542,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35654,NULL,'Modoc, IN 47358',14542,222,NULL,18,20819,0);
INSERT INTO "django_geo_db_location" VALUES(35655,NULL,'Montpelier, IN',14543,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35656,NULL,'Montpelier, IN 47359',14543,222,NULL,18,20820,0);
INSERT INTO "django_geo_db_location" VALUES(35657,NULL,'Mooreland, IN',14544,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35658,NULL,'Mooreland, IN 47360',14544,222,NULL,18,20821,0);
INSERT INTO "django_geo_db_location" VALUES(35659,NULL,'Mount Summit, IN',14545,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35660,NULL,'Mount Summit, IN 47361',14545,222,NULL,18,20822,0);
INSERT INTO "django_geo_db_location" VALUES(35661,NULL,'New Castle, IN',14546,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35662,NULL,'New Castle, IN 47362',14546,222,NULL,18,20823,0);
INSERT INTO "django_geo_db_location" VALUES(35663,NULL,'New Lisbon, IN',14547,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35664,NULL,'New Lisbon, IN 47366',14547,222,NULL,18,20824,0);
INSERT INTO "django_geo_db_location" VALUES(35665,NULL,'Oakville, IN',14548,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35666,NULL,'Oakville, IN 47367',14548,222,NULL,18,20825,0);
INSERT INTO "django_geo_db_location" VALUES(35667,NULL,'Parker City, IN',14549,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35668,NULL,'Parker City, IN 47368',14549,222,NULL,18,20826,0);
INSERT INTO "django_geo_db_location" VALUES(35669,NULL,'Pennville, IN',14550,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35670,NULL,'Pennville, IN 47369',14550,222,NULL,18,20827,0);
INSERT INTO "django_geo_db_location" VALUES(35671,NULL,'Pershing, IN',14551,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35672,NULL,'Pershing, IN 47370',14551,222,NULL,18,20828,0);
INSERT INTO "django_geo_db_location" VALUES(35673,NULL,'Portland, IN',14552,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35674,NULL,'Portland, IN 47371',14552,222,NULL,18,20829,0);
INSERT INTO "django_geo_db_location" VALUES(35675,NULL,'Redkey, IN',14553,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35676,NULL,'Redkey, IN 47373',14553,222,NULL,18,20830,0);
INSERT INTO "django_geo_db_location" VALUES(35677,NULL,'Richmond, IN',14554,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35678,NULL,'Richmond, IN 47374',14554,222,NULL,18,20831,0);
INSERT INTO "django_geo_db_location" VALUES(35679,NULL,'Richmond, IN 47375',14554,222,NULL,18,20832,0);
INSERT INTO "django_geo_db_location" VALUES(35680,NULL,'Ridgeville, IN',14555,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35681,NULL,'Ridgeville, IN 47380',14555,222,NULL,18,20833,0);
INSERT INTO "django_geo_db_location" VALUES(35682,NULL,'Salamonia, IN',14556,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35683,NULL,'Salamonia, IN 47381',14556,222,NULL,18,20834,0);
INSERT INTO "django_geo_db_location" VALUES(35684,NULL,'Saratoga, IN',14557,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35685,NULL,'Saratoga, IN 47382',14557,222,NULL,18,20835,0);
INSERT INTO "django_geo_db_location" VALUES(35686,NULL,'Selma, IN',14558,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35687,NULL,'Selma, IN 47383',14558,222,NULL,18,20836,0);
INSERT INTO "django_geo_db_location" VALUES(35688,NULL,'Shirley, IN',14559,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35689,NULL,'Shirley, IN 47384',14559,222,NULL,18,20837,0);
INSERT INTO "django_geo_db_location" VALUES(35690,NULL,'Spiceland, IN',14560,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35691,NULL,'Spiceland, IN 47385',14560,222,NULL,18,20838,0);
INSERT INTO "django_geo_db_location" VALUES(35692,NULL,'Springport, IN',14561,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35693,NULL,'Springport, IN 47386',14561,222,NULL,18,20839,0);
INSERT INTO "django_geo_db_location" VALUES(35694,NULL,'Straughn, IN',14562,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35695,NULL,'Straughn, IN 47387',14562,222,NULL,18,20840,0);
INSERT INTO "django_geo_db_location" VALUES(35696,NULL,'Sulphur Springs, IN',14563,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35697,NULL,'Sulphur Springs, IN 47388',14563,222,NULL,18,20841,0);
INSERT INTO "django_geo_db_location" VALUES(35698,NULL,'Union City, IN',14564,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35699,NULL,'Union City, IN 47390',14564,222,NULL,18,20842,0);
INSERT INTO "django_geo_db_location" VALUES(35700,NULL,'Webster, IN',14565,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35701,NULL,'Webster, IN 47392',14565,222,NULL,18,20843,0);
INSERT INTO "django_geo_db_location" VALUES(35702,NULL,'Williamsburg, IN',14566,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35703,NULL,'Williamsburg, IN 47393',14566,222,NULL,18,20844,0);
INSERT INTO "django_geo_db_location" VALUES(35704,NULL,'Winchester, IN',14567,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35705,NULL,'Winchester, IN 47394',14567,222,NULL,18,20845,0);
INSERT INTO "django_geo_db_location" VALUES(35706,NULL,'Lynn, IN 47395',14539,222,NULL,18,20846,0);
INSERT INTO "django_geo_db_location" VALUES(35707,NULL,'Yorktown, IN',14568,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35708,NULL,'Yorktown, IN 47396',14568,222,NULL,18,20847,0);
INSERT INTO "django_geo_db_location" VALUES(35709,NULL,'Hartford City, IN 47398',14535,222,NULL,18,20848,0);
INSERT INTO "django_geo_db_location" VALUES(35710,NULL,'Bloomington, IN 47401',14424,222,NULL,18,20849,0);
INSERT INTO "django_geo_db_location" VALUES(35711,NULL,'Bloomington, IN 47402',14424,222,NULL,18,20850,0);
INSERT INTO "django_geo_db_location" VALUES(35712,NULL,'Bloomington, IN 47403',14424,222,NULL,18,20851,0);
INSERT INTO "django_geo_db_location" VALUES(35713,NULL,'Bloomington, IN 47404',14424,222,NULL,18,20852,0);
INSERT INTO "django_geo_db_location" VALUES(35714,NULL,'Bloomington, IN 47405',14424,222,NULL,18,20853,0);
INSERT INTO "django_geo_db_location" VALUES(35715,NULL,'Bloomington, IN 47406',14424,222,NULL,18,20854,0);
INSERT INTO "django_geo_db_location" VALUES(35716,NULL,'Bloomington, IN 47407',14424,222,NULL,18,20855,0);
INSERT INTO "django_geo_db_location" VALUES(35717,NULL,'Bloomington, IN 47408',14424,222,NULL,18,20856,0);
INSERT INTO "django_geo_db_location" VALUES(35718,NULL,'Evansville, IN',14569,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35719,NULL,'Evansville, IN 47412',14569,222,NULL,18,20857,0);
INSERT INTO "django_geo_db_location" VALUES(35720,NULL,'Avoca, IN',14570,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35721,NULL,'Avoca, IN 47420',14570,222,NULL,18,20858,0);
INSERT INTO "django_geo_db_location" VALUES(35722,NULL,'Bedford, IN 47421',14491,222,NULL,18,20859,0);
INSERT INTO "django_geo_db_location" VALUES(35723,NULL,'Bloomfield, IN',14571,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35724,NULL,'Bloomfield, IN 47424',14571,222,NULL,18,20860,0);
INSERT INTO "django_geo_db_location" VALUES(35725,NULL,'Clear Creek, IN',14572,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35726,NULL,'Clear Creek, IN 47426',14572,222,NULL,18,20861,0);
INSERT INTO "django_geo_db_location" VALUES(35727,NULL,'Coal City, IN',14573,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35728,NULL,'Coal City, IN 47427',14573,222,NULL,18,20862,0);
INSERT INTO "django_geo_db_location" VALUES(35729,NULL,'Ellettsville, IN',14574,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35730,NULL,'Ellettsville, IN 47429',14574,222,NULL,18,20863,0);
INSERT INTO "django_geo_db_location" VALUES(35731,NULL,'Fort Ritner, IN',14575,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35732,NULL,'Fort Ritner, IN 47430',14575,222,NULL,18,20864,0);
INSERT INTO "django_geo_db_location" VALUES(35733,NULL,'Freedom, IN',14576,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35734,NULL,'Freedom, IN 47431',14576,222,NULL,18,20865,0);
INSERT INTO "django_geo_db_location" VALUES(35735,NULL,'French Lick, IN',14577,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35736,NULL,'French Lick, IN 47432',14577,222,NULL,18,20866,0);
INSERT INTO "django_geo_db_location" VALUES(35737,NULL,'Gosport, IN',14578,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35738,NULL,'Gosport, IN 47433',14578,222,NULL,18,20867,0);
INSERT INTO "django_geo_db_location" VALUES(35739,NULL,'Harrodsburg, IN',14579,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35740,NULL,'Harrodsburg, IN 47434',14579,222,NULL,18,20868,0);
INSERT INTO "django_geo_db_location" VALUES(35741,NULL,'Helmsburg, IN',14580,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35742,NULL,'Helmsburg, IN 47435',14580,222,NULL,18,20869,0);
INSERT INTO "django_geo_db_location" VALUES(35743,NULL,'Heltonville, IN',14581,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35744,NULL,'Heltonville, IN 47436',14581,222,NULL,18,20870,0);
INSERT INTO "django_geo_db_location" VALUES(35745,NULL,'Huron, IN',14582,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35746,NULL,'Huron, IN 47437',14582,222,NULL,18,20871,0);
INSERT INTO "django_geo_db_location" VALUES(35747,NULL,'Jasonville, IN',14583,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35748,NULL,'Jasonville, IN 47438',14583,222,NULL,18,20872,0);
INSERT INTO "django_geo_db_location" VALUES(35749,NULL,'Koleen, IN',14584,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35750,NULL,'Koleen, IN 47439',14584,222,NULL,18,20873,0);
INSERT INTO "django_geo_db_location" VALUES(35751,NULL,'Linton, IN',14585,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35752,NULL,'Linton, IN 47441',14585,222,NULL,18,20874,0);
INSERT INTO "django_geo_db_location" VALUES(35753,NULL,'Lyons, IN',14586,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35754,NULL,'Lyons, IN 47443',14586,222,NULL,18,20875,0);
INSERT INTO "django_geo_db_location" VALUES(35755,NULL,'Midland, IN',14587,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35756,NULL,'Midland, IN 47445',14587,222,NULL,18,20876,0);
INSERT INTO "django_geo_db_location" VALUES(35757,NULL,'Mitchell, IN',14588,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35758,NULL,'Mitchell, IN 47446',14588,222,NULL,18,20877,0);
INSERT INTO "django_geo_db_location" VALUES(35759,NULL,'Nashville, IN',14589,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35760,NULL,'Nashville, IN 47448',14589,222,NULL,18,20878,0);
INSERT INTO "django_geo_db_location" VALUES(35761,NULL,'Newberry, IN',14590,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35762,NULL,'Newberry, IN 47449',14590,222,NULL,18,20879,0);
INSERT INTO "django_geo_db_location" VALUES(35763,NULL,'Oolitic, IN',14591,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35764,NULL,'Oolitic, IN 47451',14591,222,NULL,18,20880,0);
INSERT INTO "django_geo_db_location" VALUES(35765,NULL,'Orleans, IN',14592,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35766,NULL,'Orleans, IN 47452',14592,222,NULL,18,20881,0);
INSERT INTO "django_geo_db_location" VALUES(35767,NULL,'Owensburg, IN',14593,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35768,NULL,'Owensburg, IN 47453',14593,222,NULL,18,20882,0);
INSERT INTO "django_geo_db_location" VALUES(35769,NULL,'Paoli, IN',14594,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35770,NULL,'Paoli, IN 47454',14594,222,NULL,18,20883,0);
INSERT INTO "django_geo_db_location" VALUES(35771,NULL,'Patricksburg, IN',14595,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35772,NULL,'Patricksburg, IN 47455',14595,222,NULL,18,20884,0);
INSERT INTO "django_geo_db_location" VALUES(35773,NULL,'Quincy, IN',14596,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35774,NULL,'Quincy, IN 47456',14596,222,NULL,18,20885,0);
INSERT INTO "django_geo_db_location" VALUES(35775,NULL,'Scotland, IN',14597,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35776,NULL,'Scotland, IN 47457',14597,222,NULL,18,20886,0);
INSERT INTO "django_geo_db_location" VALUES(35777,NULL,'Smithville, IN',14598,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35778,NULL,'Smithville, IN 47458',14598,222,NULL,18,20887,0);
INSERT INTO "django_geo_db_location" VALUES(35779,NULL,'Solsberry, IN',14599,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35780,NULL,'Solsberry, IN 47459',14599,222,NULL,18,20888,0);
INSERT INTO "django_geo_db_location" VALUES(35781,NULL,'Spencer, IN',14600,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35782,NULL,'Spencer, IN 47460',14600,222,NULL,18,20889,0);
INSERT INTO "django_geo_db_location" VALUES(35783,NULL,'Springville, IN',14601,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35784,NULL,'Springville, IN 47462',14601,222,NULL,18,20890,0);
INSERT INTO "django_geo_db_location" VALUES(35785,NULL,'Stanford, IN',14602,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35786,NULL,'Stanford, IN 47463',14602,222,NULL,18,20891,0);
INSERT INTO "django_geo_db_location" VALUES(35787,NULL,'Stinesville, IN',14603,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35788,NULL,'Stinesville, IN 47464',14603,222,NULL,18,20892,0);
INSERT INTO "django_geo_db_location" VALUES(35789,NULL,'Switz City, IN',14604,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35790,NULL,'Switz City, IN 47465',14604,222,NULL,18,20893,0);
INSERT INTO "django_geo_db_location" VALUES(35791,NULL,'Tunnelton, IN',14605,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35792,NULL,'Tunnelton, IN 47467',14605,222,NULL,18,20894,0);
INSERT INTO "django_geo_db_location" VALUES(35793,NULL,'Unionville, IN',14606,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35794,NULL,'Unionville, IN 47468',14606,222,NULL,18,20895,0);
INSERT INTO "django_geo_db_location" VALUES(35795,NULL,'West Baden Springs, IN',14607,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35796,NULL,'West Baden Springs, IN 47469',14607,222,NULL,18,20896,0);
INSERT INTO "django_geo_db_location" VALUES(35797,NULL,'Williams, IN',14608,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35798,NULL,'Williams, IN 47470',14608,222,NULL,18,20897,0);
INSERT INTO "django_geo_db_location" VALUES(35799,NULL,'Worthington, IN',14609,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35800,NULL,'Worthington, IN 47471',14609,222,NULL,18,20898,0);
INSERT INTO "django_geo_db_location" VALUES(35801,NULL,'Lewis, IN',14610,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35802,NULL,'Lewis, IN 47485',14610,222,NULL,18,20899,0);
INSERT INTO "django_geo_db_location" VALUES(35803,NULL,'Hamblen, IN',14611,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35804,NULL,'Hamblen, IN 47488',14611,222,NULL,18,20900,0);
INSERT INTO "django_geo_db_location" VALUES(35805,NULL,'Bloomington, IN 47490',14424,222,NULL,18,20901,0);
INSERT INTO "django_geo_db_location" VALUES(35806,NULL,'Washington, IN 47501',14161,222,NULL,18,20902,0);
INSERT INTO "django_geo_db_location" VALUES(35807,NULL,'Bicknell, IN',14612,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35808,NULL,'Bicknell, IN 47512',14612,222,NULL,18,20903,0);
INSERT INTO "django_geo_db_location" VALUES(35809,NULL,'Birdseye, IN',14613,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35810,NULL,'Birdseye, IN 47513',14613,222,NULL,18,20904,0);
INSERT INTO "django_geo_db_location" VALUES(35811,NULL,'Branchville, IN',14614,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35812,NULL,'Branchville, IN 47514',14614,222,NULL,18,20905,0);
INSERT INTO "django_geo_db_location" VALUES(35813,NULL,'Bristow, IN',14615,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35814,NULL,'Bristow, IN 47515',14615,222,NULL,18,20906,0);
INSERT INTO "django_geo_db_location" VALUES(35815,NULL,'Bruceville, IN',14616,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35816,NULL,'Bruceville, IN 47516',14616,222,NULL,18,20907,0);
INSERT INTO "django_geo_db_location" VALUES(35817,NULL,'Cannelburg, IN',14617,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35818,NULL,'Cannelburg, IN 47519',14617,222,NULL,18,20908,0);
INSERT INTO "django_geo_db_location" VALUES(35819,NULL,'Cannelton, IN',14618,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35820,NULL,'Cannelton, IN 47520',14618,222,NULL,18,20909,0);
INSERT INTO "django_geo_db_location" VALUES(35821,NULL,'Celestine, IN',14619,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35822,NULL,'Celestine, IN 47521',14619,222,NULL,18,20910,0);
INSERT INTO "django_geo_db_location" VALUES(35823,NULL,'Crane, IN',14620,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35824,NULL,'Crane, IN 47522',14620,222,NULL,18,20911,0);
INSERT INTO "django_geo_db_location" VALUES(35825,NULL,'Dale, IN',14621,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35826,NULL,'Dale, IN 47523',14621,222,NULL,18,20912,0);
INSERT INTO "django_geo_db_location" VALUES(35827,NULL,'Decker, IN',14622,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35828,NULL,'Decker, IN 47524',14622,222,NULL,18,20913,0);
INSERT INTO "django_geo_db_location" VALUES(35829,NULL,'Derby, IN',14623,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35830,NULL,'Derby, IN 47525',14623,222,NULL,18,20914,0);
INSERT INTO "django_geo_db_location" VALUES(35831,NULL,'Dubois, IN',14624,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35832,NULL,'Dubois, IN 47527',14624,222,NULL,18,20915,0);
INSERT INTO "django_geo_db_location" VALUES(35833,NULL,'Edwardsport, IN',14625,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35834,NULL,'Edwardsport, IN 47528',14625,222,NULL,18,20916,0);
INSERT INTO "django_geo_db_location" VALUES(35835,NULL,'Elnora, IN',14626,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35836,NULL,'Elnora, IN 47529',14626,222,NULL,18,20917,0);
INSERT INTO "django_geo_db_location" VALUES(35837,NULL,'Evanston, IN',14627,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35838,NULL,'Evanston, IN 47531',14627,222,NULL,18,20918,0);
INSERT INTO "django_geo_db_location" VALUES(35839,NULL,'Ferdinand, IN',14628,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35840,NULL,'Ferdinand, IN 47532',14628,222,NULL,18,20919,0);
INSERT INTO "django_geo_db_location" VALUES(35841,NULL,'Freelandville, IN',14629,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35842,NULL,'Freelandville, IN 47535',14629,222,NULL,18,20920,0);
INSERT INTO "django_geo_db_location" VALUES(35843,NULL,'Fulda, IN',14630,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35844,NULL,'Fulda, IN 47536',14630,222,NULL,18,20921,0);
INSERT INTO "django_geo_db_location" VALUES(35845,NULL,'Gentryville, IN',14631,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35846,NULL,'Gentryville, IN 47537',14631,222,NULL,18,20922,0);
INSERT INTO "django_geo_db_location" VALUES(35847,NULL,'Holland, IN',14632,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35848,NULL,'Holland, IN 47541',14632,222,NULL,18,20923,0);
INSERT INTO "django_geo_db_location" VALUES(35849,NULL,'Huntingburg, IN',14633,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35850,NULL,'Huntingburg, IN 47542',14633,222,NULL,18,20924,0);
INSERT INTO "django_geo_db_location" VALUES(35851,NULL,'Ireland, IN',14634,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35852,NULL,'Ireland, IN 47545',14634,222,NULL,18,20925,0);
INSERT INTO "django_geo_db_location" VALUES(35853,NULL,'Jasper, IN',14635,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35854,NULL,'Jasper, IN 47546',14635,222,NULL,18,20926,0);
INSERT INTO "django_geo_db_location" VALUES(35855,NULL,'Jasper, IN 47547',14635,222,NULL,18,20927,0);
INSERT INTO "django_geo_db_location" VALUES(35856,NULL,'Jasper, IN 47549',14635,222,NULL,18,20928,0);
INSERT INTO "django_geo_db_location" VALUES(35857,NULL,'Lamar, IN',14636,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35858,NULL,'Lamar, IN 47550',14636,222,NULL,18,20929,0);
INSERT INTO "django_geo_db_location" VALUES(35859,NULL,'Leopold, IN',14637,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35860,NULL,'Leopold, IN 47551',14637,222,NULL,18,20930,0);
INSERT INTO "django_geo_db_location" VALUES(35861,NULL,'Lincoln City, IN',14638,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35862,NULL,'Lincoln City, IN 47552',14638,222,NULL,18,20931,0);
INSERT INTO "django_geo_db_location" VALUES(35863,NULL,'Loogootee, IN',14639,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35864,NULL,'Loogootee, IN 47553',14639,222,NULL,18,20932,0);
INSERT INTO "django_geo_db_location" VALUES(35865,NULL,'Mariah Hill, IN',14640,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35866,NULL,'Mariah Hill, IN 47556',14640,222,NULL,18,20933,0);
INSERT INTO "django_geo_db_location" VALUES(35867,NULL,'Monroe City, IN',14641,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35868,NULL,'Monroe City, IN 47557',14641,222,NULL,18,20934,0);
INSERT INTO "django_geo_db_location" VALUES(35869,NULL,'Montgomery, IN',14642,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35870,NULL,'Montgomery, IN 47558',14642,222,NULL,18,20935,0);
INSERT INTO "django_geo_db_location" VALUES(35871,NULL,'Oaktown, IN',14643,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35872,NULL,'Oaktown, IN 47561',14643,222,NULL,18,20936,0);
INSERT INTO "django_geo_db_location" VALUES(35873,NULL,'Odon, IN',14644,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35874,NULL,'Odon, IN 47562',14644,222,NULL,18,20937,0);
INSERT INTO "django_geo_db_location" VALUES(35875,NULL,'Otwell, IN',14645,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35876,NULL,'Otwell, IN 47564',14645,222,NULL,18,20938,0);
INSERT INTO "django_geo_db_location" VALUES(35877,NULL,'Petersburg, IN',14646,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35878,NULL,'Petersburg, IN 47567',14646,222,NULL,18,20939,0);
INSERT INTO "django_geo_db_location" VALUES(35879,NULL,'Plainville, IN',14647,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35880,NULL,'Plainville, IN 47568',14647,222,NULL,18,20940,0);
INSERT INTO "django_geo_db_location" VALUES(35881,NULL,'Ragsdale, IN',14648,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35882,NULL,'Ragsdale, IN 47573',14648,222,NULL,18,20941,0);
INSERT INTO "django_geo_db_location" VALUES(35883,NULL,'Rome, IN',14649,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35884,NULL,'Rome, IN 47574',14649,222,NULL,18,20942,0);
INSERT INTO "django_geo_db_location" VALUES(35885,NULL,'Saint Anthony, IN',14650,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35886,NULL,'Saint Anthony, IN 47575',14650,222,NULL,18,20943,0);
INSERT INTO "django_geo_db_location" VALUES(35887,NULL,'Saint Croix, IN',14651,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35888,NULL,'Saint Croix, IN 47576',14651,222,NULL,18,20944,0);
INSERT INTO "django_geo_db_location" VALUES(35889,NULL,'Saint Meinrad, IN',14652,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35890,NULL,'Saint Meinrad, IN 47577',14652,222,NULL,18,20945,0);
INSERT INTO "django_geo_db_location" VALUES(35891,NULL,'Sandborn, IN',14653,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35892,NULL,'Sandborn, IN 47578',14653,222,NULL,18,20946,0);
INSERT INTO "django_geo_db_location" VALUES(35893,NULL,'Santa Claus, IN',14654,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35894,NULL,'Santa Claus, IN 47579',14654,222,NULL,18,20947,0);
INSERT INTO "django_geo_db_location" VALUES(35895,NULL,'Schnellville, IN',14655,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35896,NULL,'Schnellville, IN 47580',14655,222,NULL,18,20948,0);
INSERT INTO "django_geo_db_location" VALUES(35897,NULL,'Shoals, IN',14656,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35898,NULL,'Shoals, IN 47581',14656,222,NULL,18,20949,0);
INSERT INTO "django_geo_db_location" VALUES(35899,NULL,'Spurgeon, IN',14657,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35900,NULL,'Spurgeon, IN 47584',14657,222,NULL,18,20950,0);
INSERT INTO "django_geo_db_location" VALUES(35901,NULL,'Stendal, IN',14658,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35902,NULL,'Stendal, IN 47585',14658,222,NULL,18,20951,0);
INSERT INTO "django_geo_db_location" VALUES(35903,NULL,'Tell City, IN',14659,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35904,NULL,'Tell City, IN 47586',14659,222,NULL,18,20952,0);
INSERT INTO "django_geo_db_location" VALUES(35905,NULL,'Troy, IN',14660,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35906,NULL,'Troy, IN 47588',14660,222,NULL,18,20953,0);
INSERT INTO "django_geo_db_location" VALUES(35907,NULL,'Velpen, IN',14661,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35908,NULL,'Velpen, IN 47590',14661,222,NULL,18,20954,0);
INSERT INTO "django_geo_db_location" VALUES(35909,NULL,'Vincennes, IN',14662,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35910,NULL,'Vincennes, IN 47591',14662,222,NULL,18,20955,0);
INSERT INTO "django_geo_db_location" VALUES(35911,NULL,'Westphalia, IN',14663,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35912,NULL,'Westphalia, IN 47596',14663,222,NULL,18,20956,0);
INSERT INTO "django_geo_db_location" VALUES(35913,NULL,'Wheatland, IN',14664,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35914,NULL,'Wheatland, IN 47597',14664,222,NULL,18,20957,0);
INSERT INTO "django_geo_db_location" VALUES(35915,NULL,'Winslow, IN',14665,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35916,NULL,'Winslow, IN 47598',14665,222,NULL,18,20958,0);
INSERT INTO "django_geo_db_location" VALUES(35917,NULL,'Boonville, IN',14666,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35918,NULL,'Boonville, IN 47601',14666,222,NULL,18,20959,0);
INSERT INTO "django_geo_db_location" VALUES(35919,NULL,'Chandler, IN',14667,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35920,NULL,'Chandler, IN 47610',14667,222,NULL,18,20960,0);
INSERT INTO "django_geo_db_location" VALUES(35921,NULL,'Chrisney, IN',14668,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35922,NULL,'Chrisney, IN 47611',14668,222,NULL,18,20961,0);
INSERT INTO "django_geo_db_location" VALUES(35923,NULL,'Cynthiana, IN',14669,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35924,NULL,'Cynthiana, IN 47612',14669,222,NULL,18,20962,0);
INSERT INTO "django_geo_db_location" VALUES(35925,NULL,'Elberfeld, IN',14670,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35926,NULL,'Elberfeld, IN 47613',14670,222,NULL,18,20963,0);
INSERT INTO "django_geo_db_location" VALUES(35927,NULL,'Folsomville, IN',14671,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35928,NULL,'Folsomville, IN 47614',14671,222,NULL,18,20964,0);
INSERT INTO "django_geo_db_location" VALUES(35929,NULL,'Grandview, IN',14672,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35930,NULL,'Grandview, IN 47615',14672,222,NULL,18,20965,0);
INSERT INTO "django_geo_db_location" VALUES(35931,NULL,'Griffin, IN',14673,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35932,NULL,'Griffin, IN 47616',14673,222,NULL,18,20966,0);
INSERT INTO "django_geo_db_location" VALUES(35933,NULL,'Hatfield, IN',14674,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35934,NULL,'Hatfield, IN 47617',14674,222,NULL,18,20967,0);
INSERT INTO "django_geo_db_location" VALUES(35935,NULL,'Inglefield, IN',14675,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35936,NULL,'Inglefield, IN 47618',14675,222,NULL,18,20968,0);
INSERT INTO "django_geo_db_location" VALUES(35937,NULL,'Lynnville, IN',14676,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35938,NULL,'Lynnville, IN 47619',14676,222,NULL,18,20969,0);
INSERT INTO "django_geo_db_location" VALUES(35939,NULL,'Mount Vernon, IN',14677,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35940,NULL,'Mount Vernon, IN 47620',14677,222,NULL,18,20970,0);
INSERT INTO "django_geo_db_location" VALUES(35941,NULL,'North Vernon, IN 47625',14498,222,NULL,18,20971,0);
INSERT INTO "django_geo_db_location" VALUES(35942,NULL,'Newburgh, IN',14678,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35943,NULL,'Newburgh, IN 47629',14678,222,NULL,18,20972,0);
INSERT INTO "django_geo_db_location" VALUES(35944,NULL,'Newburgh, IN 47630',14678,222,NULL,18,20973,0);
INSERT INTO "django_geo_db_location" VALUES(35945,NULL,'New Harmony, IN',14679,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35946,NULL,'New Harmony, IN 47631',14679,222,NULL,18,20974,0);
INSERT INTO "django_geo_db_location" VALUES(35947,NULL,'Poseyville, IN',14680,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35948,NULL,'Poseyville, IN 47633',14680,222,NULL,18,20975,0);
INSERT INTO "django_geo_db_location" VALUES(35949,NULL,'Richland, IN',14681,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35950,NULL,'Richland, IN 47634',14681,222,NULL,18,20976,0);
INSERT INTO "django_geo_db_location" VALUES(35951,NULL,'Rockport, IN',14682,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35952,NULL,'Rockport, IN 47635',14682,222,NULL,18,20977,0);
INSERT INTO "django_geo_db_location" VALUES(35953,NULL,'Tennyson, IN',14683,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35954,NULL,'Tennyson, IN 47637',14683,222,NULL,18,20978,0);
INSERT INTO "django_geo_db_location" VALUES(35955,NULL,'Wadesville, IN',14684,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35956,NULL,'Wadesville, IN 47638',14684,222,NULL,18,20979,0);
INSERT INTO "django_geo_db_location" VALUES(35957,NULL,'Haubstadt, IN',14685,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35958,NULL,'Haubstadt, IN 47639',14685,222,NULL,18,20980,0);
INSERT INTO "django_geo_db_location" VALUES(35959,NULL,'Hazleton, IN',14686,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35960,NULL,'Hazleton, IN 47640',14686,222,NULL,18,20981,0);
INSERT INTO "django_geo_db_location" VALUES(35961,NULL,'Buckskin, IN',14687,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35962,NULL,'Buckskin, IN 47647',14687,222,NULL,18,20982,0);
INSERT INTO "django_geo_db_location" VALUES(35963,NULL,'Fort Branch, IN',14688,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35964,NULL,'Fort Branch, IN 47648',14688,222,NULL,18,20983,0);
INSERT INTO "django_geo_db_location" VALUES(35965,NULL,'Francisco, IN',14689,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35966,NULL,'Francisco, IN 47649',14689,222,NULL,18,20984,0);
INSERT INTO "django_geo_db_location" VALUES(35967,NULL,'Mackey, IN',14690,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35968,NULL,'Mackey, IN 47654',14690,222,NULL,18,20985,0);
INSERT INTO "django_geo_db_location" VALUES(35969,NULL,'Oakland City, IN',14691,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35970,NULL,'Oakland City, IN 47660',14691,222,NULL,18,20986,0);
INSERT INTO "django_geo_db_location" VALUES(35971,NULL,'Owensville, IN',14692,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35972,NULL,'Owensville, IN 47665',14692,222,NULL,18,20987,0);
INSERT INTO "django_geo_db_location" VALUES(35973,NULL,'Patoka, IN',14693,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35974,NULL,'Patoka, IN 47666',14693,222,NULL,18,20988,0);
INSERT INTO "django_geo_db_location" VALUES(35975,NULL,'Owensville, IN 47667',14692,222,NULL,18,20989,0);
INSERT INTO "django_geo_db_location" VALUES(35976,NULL,'Princeton, IN',14694,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35977,NULL,'Princeton, IN 47670',14694,222,NULL,18,20990,0);
INSERT INTO "django_geo_db_location" VALUES(35978,NULL,'Oxford, IN',14695,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35979,NULL,'Oxford, IN 47671',14695,222,NULL,18,20991,0);
INSERT INTO "django_geo_db_location" VALUES(35980,NULL,'Cynthiana, IN 47672',14669,222,NULL,18,20992,0);
INSERT INTO "django_geo_db_location" VALUES(35981,NULL,'Somerville, IN',14696,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35982,NULL,'Somerville, IN 47683',14696,222,NULL,18,20993,0);
INSERT INTO "django_geo_db_location" VALUES(35983,NULL,'Evansville, IN 47701',14569,222,NULL,18,20994,0);
INSERT INTO "django_geo_db_location" VALUES(35984,NULL,'Evansville, IN 47702',14569,222,NULL,18,20995,0);
INSERT INTO "django_geo_db_location" VALUES(35985,NULL,'Evansville, IN 47703',14569,222,NULL,18,20996,0);
INSERT INTO "django_geo_db_location" VALUES(35986,NULL,'Evansville, IN 47704',14569,222,NULL,18,20997,0);
INSERT INTO "django_geo_db_location" VALUES(35987,NULL,'Evansville, IN 47705',14569,222,NULL,18,20998,0);
INSERT INTO "django_geo_db_location" VALUES(35988,NULL,'Evansville, IN 47706',14569,222,NULL,18,20999,0);
INSERT INTO "django_geo_db_location" VALUES(35989,NULL,'Evansville, IN 47708',14569,222,NULL,18,21000,0);
INSERT INTO "django_geo_db_location" VALUES(35990,NULL,'Evansville, IN 47710',14569,222,NULL,18,21001,0);
INSERT INTO "django_geo_db_location" VALUES(35991,NULL,'Evansville, IN 47711',14569,222,NULL,18,21002,0);
INSERT INTO "django_geo_db_location" VALUES(35992,NULL,'Evansville, IN 47712',14569,222,NULL,18,21003,0);
INSERT INTO "django_geo_db_location" VALUES(35993,NULL,'Evansville, IN 47713',14569,222,NULL,18,21004,0);
INSERT INTO "django_geo_db_location" VALUES(35994,NULL,'Evansville, IN 47714',14569,222,NULL,18,21005,0);
INSERT INTO "django_geo_db_location" VALUES(35995,NULL,'Evansville, IN 47715',14569,222,NULL,18,21006,0);
INSERT INTO "django_geo_db_location" VALUES(35996,NULL,'Evansville, IN 47716',14569,222,NULL,18,21007,0);
INSERT INTO "django_geo_db_location" VALUES(35997,NULL,'Jackson, IN',14697,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(35998,NULL,'Jackson, IN 47718',14697,222,NULL,18,21008,0);
INSERT INTO "django_geo_db_location" VALUES(35999,NULL,'Evansville, IN 47719',14569,222,NULL,18,21009,0);
INSERT INTO "django_geo_db_location" VALUES(36000,NULL,'Evansville, IN 47720',14569,222,NULL,18,21010,0);
INSERT INTO "django_geo_db_location" VALUES(36001,NULL,'Evansville, IN 47721',14569,222,NULL,18,21011,0);
INSERT INTO "django_geo_db_location" VALUES(36002,NULL,'Evansville, IN 47722',14569,222,NULL,18,21012,0);
INSERT INTO "django_geo_db_location" VALUES(36003,NULL,'Evansville, IN 47724',14569,222,NULL,18,21013,0);
INSERT INTO "django_geo_db_location" VALUES(36004,NULL,'Evansville, IN 47725',14569,222,NULL,18,21014,0);
INSERT INTO "django_geo_db_location" VALUES(36005,NULL,'Evansville, IN 47727',14569,222,NULL,18,21015,0);
INSERT INTO "django_geo_db_location" VALUES(36006,NULL,'Evansville, IN 47728',14569,222,NULL,18,21016,0);
INSERT INTO "django_geo_db_location" VALUES(36007,NULL,'Scott, IN',14698,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36008,NULL,'Scott, IN 47729',14698,222,NULL,18,21017,0);
INSERT INTO "django_geo_db_location" VALUES(36009,NULL,'Evansville, IN 47730',14569,222,NULL,18,21018,0);
INSERT INTO "django_geo_db_location" VALUES(36010,NULL,'Evansville, IN 47731',14569,222,NULL,18,21019,0);
INSERT INTO "django_geo_db_location" VALUES(36011,NULL,'Evansville, IN 47732',14569,222,NULL,18,21020,0);
INSERT INTO "django_geo_db_location" VALUES(36012,NULL,'Evansville, IN 47733',14569,222,NULL,18,21021,0);
INSERT INTO "django_geo_db_location" VALUES(36013,NULL,'Evansville, IN 47734',14569,222,NULL,18,21022,0);
INSERT INTO "django_geo_db_location" VALUES(36014,NULL,'Evansville, IN 47735',14569,222,NULL,18,21023,0);
INSERT INTO "django_geo_db_location" VALUES(36015,NULL,'Evansville, IN 47736',14569,222,NULL,18,21024,0);
INSERT INTO "django_geo_db_location" VALUES(36016,NULL,'Evansville, IN 47737',14569,222,NULL,18,21025,0);
INSERT INTO "django_geo_db_location" VALUES(36017,NULL,'Evansville, IN 47739',14569,222,NULL,18,21026,0);
INSERT INTO "django_geo_db_location" VALUES(36018,NULL,'Evansville, IN 47740',14569,222,NULL,18,21027,0);
INSERT INTO "django_geo_db_location" VALUES(36019,NULL,'Evansville, IN 47741',14569,222,NULL,18,21028,0);
INSERT INTO "django_geo_db_location" VALUES(36020,NULL,'Evansville, IN 47744',14569,222,NULL,18,21029,0);
INSERT INTO "django_geo_db_location" VALUES(36021,NULL,'Evansville, IN 47747',14569,222,NULL,18,21030,0);
INSERT INTO "django_geo_db_location" VALUES(36022,NULL,'Evansville, IN 47750',14569,222,NULL,18,21031,0);
INSERT INTO "django_geo_db_location" VALUES(36023,NULL,'New Market, IN',14699,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36024,NULL,'New Market, IN 47765',14699,222,NULL,18,21032,0);
INSERT INTO "django_geo_db_location" VALUES(36025,NULL,'Terre Haute, IN',14700,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36026,NULL,'Terre Haute, IN 47801',14700,222,NULL,18,21033,0);
INSERT INTO "django_geo_db_location" VALUES(36027,NULL,'Terre Haute, IN 47802',14700,222,NULL,18,21034,0);
INSERT INTO "django_geo_db_location" VALUES(36028,NULL,'Terre Haute, IN 47803',14700,222,NULL,18,21035,0);
INSERT INTO "django_geo_db_location" VALUES(36029,NULL,'Terre Haute, IN 47804',14700,222,NULL,18,21036,0);
INSERT INTO "django_geo_db_location" VALUES(36030,NULL,'Terre Haute, IN 47805',14700,222,NULL,18,21037,0);
INSERT INTO "django_geo_db_location" VALUES(36031,NULL,'Terre Haute, IN 47807',14700,222,NULL,18,21038,0);
INSERT INTO "django_geo_db_location" VALUES(36032,NULL,'Terre Haute, IN 47808',14700,222,NULL,18,21039,0);
INSERT INTO "django_geo_db_location" VALUES(36033,NULL,'Terre Haute, IN 47809',14700,222,NULL,18,21040,0);
INSERT INTO "django_geo_db_location" VALUES(36034,NULL,'Terre Haute, IN 47811',14700,222,NULL,18,21041,0);
INSERT INTO "django_geo_db_location" VALUES(36035,NULL,'Terre Haute, IN 47812',14700,222,NULL,18,21042,0);
INSERT INTO "django_geo_db_location" VALUES(36036,NULL,'Terre Haute, IN 47813',14700,222,NULL,18,21043,0);
INSERT INTO "django_geo_db_location" VALUES(36037,NULL,'Terre Haute, IN 47814',14700,222,NULL,18,21044,0);
INSERT INTO "django_geo_db_location" VALUES(36038,NULL,'Bellmore, IN',14701,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36039,NULL,'Bellmore, IN 47830',14701,222,NULL,18,21045,0);
INSERT INTO "django_geo_db_location" VALUES(36040,NULL,'Blanford, IN',14702,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36041,NULL,'Blanford, IN 47831',14702,222,NULL,18,21046,0);
INSERT INTO "django_geo_db_location" VALUES(36042,NULL,'Bloomingdale, IN',14703,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36043,NULL,'Bloomingdale, IN 47832',14703,222,NULL,18,21047,0);
INSERT INTO "django_geo_db_location" VALUES(36044,NULL,'Bowling Green, IN',14704,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36045,NULL,'Bowling Green, IN 47833',14704,222,NULL,18,21048,0);
INSERT INTO "django_geo_db_location" VALUES(36046,NULL,'Brazil, IN',14705,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36047,NULL,'Brazil, IN 47834',14705,222,NULL,18,21049,0);
INSERT INTO "django_geo_db_location" VALUES(36048,NULL,'Bridgeton, IN',14706,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36049,NULL,'Bridgeton, IN 47836',14706,222,NULL,18,21050,0);
INSERT INTO "django_geo_db_location" VALUES(36050,NULL,'Carbon, IN',14707,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36051,NULL,'Carbon, IN 47837',14707,222,NULL,18,21051,0);
INSERT INTO "django_geo_db_location" VALUES(36052,NULL,'Carlisle, IN',14708,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36053,NULL,'Carlisle, IN 47838',14708,222,NULL,18,21052,0);
INSERT INTO "django_geo_db_location" VALUES(36054,NULL,'Centerpoint, IN',14709,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36055,NULL,'Centerpoint, IN 47840',14709,222,NULL,18,21053,0);
INSERT INTO "django_geo_db_location" VALUES(36056,NULL,'Clay City, IN',14710,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36057,NULL,'Clay City, IN 47841',14710,222,NULL,18,21054,0);
INSERT INTO "django_geo_db_location" VALUES(36058,NULL,'Clinton, IN',14711,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36059,NULL,'Clinton, IN 47842',14711,222,NULL,18,21055,0);
INSERT INTO "django_geo_db_location" VALUES(36060,NULL,'Coalmont, IN',14712,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36061,NULL,'Coalmont, IN 47845',14712,222,NULL,18,21056,0);
INSERT INTO "django_geo_db_location" VALUES(36062,NULL,'Cory, IN',14713,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36063,NULL,'Cory, IN 47846',14713,222,NULL,18,21057,0);
INSERT INTO "django_geo_db_location" VALUES(36064,NULL,'Dana, IN',14714,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36065,NULL,'Dana, IN 47847',14714,222,NULL,18,21058,0);
INSERT INTO "django_geo_db_location" VALUES(36066,NULL,'Dugger, IN',14715,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36067,NULL,'Dugger, IN 47848',14715,222,NULL,18,21059,0);
INSERT INTO "django_geo_db_location" VALUES(36068,NULL,'Fairbanks, IN',14716,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36069,NULL,'Fairbanks, IN 47849',14716,222,NULL,18,21060,0);
INSERT INTO "django_geo_db_location" VALUES(36070,NULL,'Farmersburg, IN',14717,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36071,NULL,'Farmersburg, IN 47850',14717,222,NULL,18,21061,0);
INSERT INTO "django_geo_db_location" VALUES(36072,NULL,'Fontanet, IN',14718,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36073,NULL,'Fontanet, IN 47851',14718,222,NULL,18,21062,0);
INSERT INTO "django_geo_db_location" VALUES(36074,NULL,'Graysville, IN',14719,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36075,NULL,'Graysville, IN 47852',14719,222,NULL,18,21063,0);
INSERT INTO "django_geo_db_location" VALUES(36076,NULL,'Harmony, IN',14720,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36077,NULL,'Harmony, IN 47853',14720,222,NULL,18,21064,0);
INSERT INTO "django_geo_db_location" VALUES(36078,NULL,'Hillsdale, IN',14721,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36079,NULL,'Hillsdale, IN 47854',14721,222,NULL,18,21065,0);
INSERT INTO "django_geo_db_location" VALUES(36080,NULL,'Hymera, IN',14722,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36081,NULL,'Hymera, IN 47855',14722,222,NULL,18,21066,0);
INSERT INTO "django_geo_db_location" VALUES(36082,NULL,'Judson, IN',14723,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36083,NULL,'Judson, IN 47856',14723,222,NULL,18,21067,0);
INSERT INTO "django_geo_db_location" VALUES(36084,NULL,'Knightsville, IN',14724,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36085,NULL,'Knightsville, IN 47857',14724,222,NULL,18,21068,0);
INSERT INTO "django_geo_db_location" VALUES(36086,NULL,'Lewis, IN 47858',14610,222,NULL,18,21069,0);
INSERT INTO "django_geo_db_location" VALUES(36087,NULL,'Marshall, IN',14725,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36088,NULL,'Marshall, IN 47859',14725,222,NULL,18,21070,0);
INSERT INTO "django_geo_db_location" VALUES(36089,NULL,'Mecca, IN',14726,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36090,NULL,'Mecca, IN 47860',14726,222,NULL,18,21071,0);
INSERT INTO "django_geo_db_location" VALUES(36091,NULL,'Merom, IN',14727,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36092,NULL,'Merom, IN 47861',14727,222,NULL,18,21072,0);
INSERT INTO "django_geo_db_location" VALUES(36093,NULL,'Montezuma, IN',14728,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36094,NULL,'Montezuma, IN 47862',14728,222,NULL,18,21073,0);
INSERT INTO "django_geo_db_location" VALUES(36095,NULL,'New Goshen, IN',14729,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36096,NULL,'New Goshen, IN 47863',14729,222,NULL,18,21074,0);
INSERT INTO "django_geo_db_location" VALUES(36097,NULL,'New Lebanon, IN',14730,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36098,NULL,'New Lebanon, IN 47864',14730,222,NULL,18,21075,0);
INSERT INTO "django_geo_db_location" VALUES(36099,NULL,'Paxton, IN',14731,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36100,NULL,'Paxton, IN 47865',14731,222,NULL,18,21076,0);
INSERT INTO "django_geo_db_location" VALUES(36101,NULL,'Pimento, IN',14732,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36102,NULL,'Pimento, IN 47866',14732,222,NULL,18,21077,0);
INSERT INTO "django_geo_db_location" VALUES(36103,NULL,'Poland, IN',14733,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36104,NULL,'Poland, IN 47868',14733,222,NULL,18,21078,0);
INSERT INTO "django_geo_db_location" VALUES(36105,NULL,'Prairie Creek, IN',14734,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36106,NULL,'Prairie Creek, IN 47869',14734,222,NULL,18,21079,0);
INSERT INTO "django_geo_db_location" VALUES(36107,NULL,'Prairieton, IN',14735,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36108,NULL,'Prairieton, IN 47870',14735,222,NULL,18,21080,0);
INSERT INTO "django_geo_db_location" VALUES(36109,NULL,'Riley, IN',14736,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36110,NULL,'Riley, IN 47871',14736,222,NULL,18,21081,0);
INSERT INTO "django_geo_db_location" VALUES(36111,NULL,'Rockville, IN',14737,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36112,NULL,'Rockville, IN 47872',14737,222,NULL,18,21082,0);
INSERT INTO "django_geo_db_location" VALUES(36113,NULL,'Rosedale, IN',14738,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36114,NULL,'Rosedale, IN 47874',14738,222,NULL,18,21083,0);
INSERT INTO "django_geo_db_location" VALUES(36115,NULL,'Saint Bernice, IN',14739,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36116,NULL,'Saint Bernice, IN 47875',14739,222,NULL,18,21084,0);
INSERT INTO "django_geo_db_location" VALUES(36117,NULL,'Saint Mary Of The Woods, IN',14740,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36118,NULL,'Saint Mary Of The Woods, IN 47876',14740,222,NULL,18,21085,0);
INSERT INTO "django_geo_db_location" VALUES(36119,NULL,'Seelyville, IN',14741,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36120,NULL,'Seelyville, IN 47878',14741,222,NULL,18,21086,0);
INSERT INTO "django_geo_db_location" VALUES(36121,NULL,'Shelburn, IN',14742,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36122,NULL,'Shelburn, IN 47879',14742,222,NULL,18,21087,0);
INSERT INTO "django_geo_db_location" VALUES(36123,NULL,'Shepardsville, IN',14743,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36124,NULL,'Shepardsville, IN 47880',14743,222,NULL,18,21088,0);
INSERT INTO "django_geo_db_location" VALUES(36125,NULL,'Staunton, IN',14744,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36126,NULL,'Staunton, IN 47881',14744,222,NULL,18,21089,0);
INSERT INTO "django_geo_db_location" VALUES(36127,NULL,'Sullivan, IN',14745,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36128,NULL,'Sullivan, IN 47882',14745,222,NULL,18,21090,0);
INSERT INTO "django_geo_db_location" VALUES(36129,NULL,'Universal, IN',14746,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36130,NULL,'Universal, IN 47884',14746,222,NULL,18,21091,0);
INSERT INTO "django_geo_db_location" VALUES(36131,NULL,'West Terre Haute, IN',14747,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36132,NULL,'West Terre Haute, IN 47885',14747,222,NULL,18,21092,0);
INSERT INTO "django_geo_db_location" VALUES(36133,NULL,'Helt, IN',14748,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36134,NULL,'Helt, IN 47895',14748,222,NULL,18,21093,0);
INSERT INTO "django_geo_db_location" VALUES(36135,NULL,'Lafayette, IN',14749,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36136,NULL,'Lafayette, IN 47901',14749,222,NULL,18,21094,0);
INSERT INTO "django_geo_db_location" VALUES(36137,NULL,'Lafayette, IN 47902',14749,222,NULL,18,21095,0);
INSERT INTO "django_geo_db_location" VALUES(36138,NULL,'Lafayette, IN 47903',14749,222,NULL,18,21096,0);
INSERT INTO "django_geo_db_location" VALUES(36139,NULL,'Lafayette, IN 47904',14749,222,NULL,18,21097,0);
INSERT INTO "django_geo_db_location" VALUES(36140,NULL,'Lafayette, IN 47905',14749,222,NULL,18,21098,0);
INSERT INTO "django_geo_db_location" VALUES(36141,NULL,'West Lafayette, IN',14750,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36142,NULL,'West Lafayette, IN 47906',14750,222,NULL,18,21099,0);
INSERT INTO "django_geo_db_location" VALUES(36143,NULL,'West Lafayette, IN 47907',14750,222,NULL,18,21100,0);
INSERT INTO "django_geo_db_location" VALUES(36144,NULL,'Lafayette, IN 47909',14749,222,NULL,18,21101,0);
INSERT INTO "django_geo_db_location" VALUES(36145,NULL,'Alamo, IN',14751,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36146,NULL,'Alamo, IN 47916',14751,222,NULL,18,21102,0);
INSERT INTO "django_geo_db_location" VALUES(36147,NULL,'Ambia, IN',14752,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36148,NULL,'Ambia, IN 47917',14752,222,NULL,18,21103,0);
INSERT INTO "django_geo_db_location" VALUES(36149,NULL,'Attica, IN',14753,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36150,NULL,'Attica, IN 47918',14753,222,NULL,18,21104,0);
INSERT INTO "django_geo_db_location" VALUES(36151,NULL,'Battle Ground, IN',14754,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36152,NULL,'Battle Ground, IN 47920',14754,222,NULL,18,21105,0);
INSERT INTO "django_geo_db_location" VALUES(36153,NULL,'Boswell, IN',14755,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36154,NULL,'Boswell, IN 47921',14755,222,NULL,18,21106,0);
INSERT INTO "django_geo_db_location" VALUES(36155,NULL,'Brook, IN',14756,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36156,NULL,'Brook, IN 47922',14756,222,NULL,18,21107,0);
INSERT INTO "django_geo_db_location" VALUES(36157,NULL,'Brookston, IN',14757,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36158,NULL,'Brookston, IN 47923',14757,222,NULL,18,21108,0);
INSERT INTO "django_geo_db_location" VALUES(36159,NULL,'Buck Creek, IN',14758,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36160,NULL,'Buck Creek, IN 47924',14758,222,NULL,18,21109,0);
INSERT INTO "django_geo_db_location" VALUES(36161,NULL,'Buffalo, IN',14759,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36162,NULL,'Buffalo, IN 47925',14759,222,NULL,18,21110,0);
INSERT INTO "django_geo_db_location" VALUES(36163,NULL,'Burnettsville, IN',14760,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36164,NULL,'Burnettsville, IN 47926',14760,222,NULL,18,21111,0);
INSERT INTO "django_geo_db_location" VALUES(36165,NULL,'Cayuga, IN 47928',14512,222,NULL,18,21112,0);
INSERT INTO "django_geo_db_location" VALUES(36166,NULL,'Chalmers, IN',14761,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36167,NULL,'Chalmers, IN 47929',14761,222,NULL,18,21113,0);
INSERT INTO "django_geo_db_location" VALUES(36168,NULL,'Clarks Hill, IN',14762,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36169,NULL,'Clarks Hill, IN 47930',14762,222,NULL,18,21114,0);
INSERT INTO "django_geo_db_location" VALUES(36170,NULL,'Covington, IN',14763,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36171,NULL,'Covington, IN 47932',14763,222,NULL,18,21115,0);
INSERT INTO "django_geo_db_location" VALUES(36172,NULL,'Crawfordsville, IN',14764,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36173,NULL,'Crawfordsville, IN 47933',14764,222,NULL,18,21116,0);
INSERT INTO "django_geo_db_location" VALUES(36174,NULL,'Crawfordsville, IN 47934',14764,222,NULL,18,21117,0);
INSERT INTO "django_geo_db_location" VALUES(36175,NULL,'Crawfordsville, IN 47935',14764,222,NULL,18,21118,0);
INSERT INTO "django_geo_db_location" VALUES(36176,NULL,'Crawfordsville, IN 47936',14764,222,NULL,18,21119,0);
INSERT INTO "django_geo_db_location" VALUES(36177,NULL,'Crawfordsville, IN 47937',14764,222,NULL,18,21120,0);
INSERT INTO "django_geo_db_location" VALUES(36178,NULL,'Crawfordsville, IN 47938',14764,222,NULL,18,21121,0);
INSERT INTO "django_geo_db_location" VALUES(36179,NULL,'Crawfordsville, IN 47939',14764,222,NULL,18,21122,0);
INSERT INTO "django_geo_db_location" VALUES(36180,NULL,'Darlington, IN',14765,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36181,NULL,'Darlington, IN 47940',14765,222,NULL,18,21123,0);
INSERT INTO "django_geo_db_location" VALUES(36182,NULL,'Dayton, IN',14766,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36183,NULL,'Dayton, IN 47941',14766,222,NULL,18,21124,0);
INSERT INTO "django_geo_db_location" VALUES(36184,NULL,'Earl Park, IN',14767,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36185,NULL,'Earl Park, IN 47942',14767,222,NULL,18,21125,0);
INSERT INTO "django_geo_db_location" VALUES(36186,NULL,'Fair Oaks, IN',14768,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36187,NULL,'Fair Oaks, IN 47943',14768,222,NULL,18,21126,0);
INSERT INTO "django_geo_db_location" VALUES(36188,NULL,'Fowler, IN',14769,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36189,NULL,'Fowler, IN 47944',14769,222,NULL,18,21127,0);
INSERT INTO "django_geo_db_location" VALUES(36190,NULL,'Francesville, IN',14770,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36191,NULL,'Francesville, IN 47946',14770,222,NULL,18,21128,0);
INSERT INTO "django_geo_db_location" VALUES(36192,NULL,'Goodland, IN',14771,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36193,NULL,'Goodland, IN 47948',14771,222,NULL,18,21129,0);
INSERT INTO "django_geo_db_location" VALUES(36194,NULL,'Hillsboro, IN',14772,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36195,NULL,'Hillsboro, IN 47949',14772,222,NULL,18,21130,0);
INSERT INTO "django_geo_db_location" VALUES(36196,NULL,'Idaville, IN',14773,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36197,NULL,'Idaville, IN 47950',14773,222,NULL,18,21131,0);
INSERT INTO "django_geo_db_location" VALUES(36198,NULL,'Kentland, IN',14774,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36199,NULL,'Kentland, IN 47951',14774,222,NULL,18,21132,0);
INSERT INTO "django_geo_db_location" VALUES(36200,NULL,'Kingman, IN',14775,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36201,NULL,'Kingman, IN 47952',14775,222,NULL,18,21133,0);
INSERT INTO "django_geo_db_location" VALUES(36202,NULL,'Ladoga, IN',14776,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36203,NULL,'Ladoga, IN 47954',14776,222,NULL,18,21134,0);
INSERT INTO "django_geo_db_location" VALUES(36204,NULL,'Linden, IN',14777,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36205,NULL,'Linden, IN 47955',14777,222,NULL,18,21135,0);
INSERT INTO "django_geo_db_location" VALUES(36206,NULL,'Medaryville, IN',14778,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36207,NULL,'Medaryville, IN 47957',14778,222,NULL,18,21136,0);
INSERT INTO "django_geo_db_location" VALUES(36208,NULL,'Mellott, IN',14779,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36209,NULL,'Mellott, IN 47958',14779,222,NULL,18,21137,0);
INSERT INTO "django_geo_db_location" VALUES(36210,NULL,'Monon, IN',14780,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36211,NULL,'Monon, IN 47959',14780,222,NULL,18,21138,0);
INSERT INTO "django_geo_db_location" VALUES(36212,NULL,'Monticello, IN',14781,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36213,NULL,'Monticello, IN 47960',14781,222,NULL,18,21139,0);
INSERT INTO "django_geo_db_location" VALUES(36214,NULL,'Montmorenci, IN',14782,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36215,NULL,'Montmorenci, IN 47962',14782,222,NULL,18,21140,0);
INSERT INTO "django_geo_db_location" VALUES(36216,NULL,'Morocco, IN',14783,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36217,NULL,'Morocco, IN 47963',14783,222,NULL,18,21141,0);
INSERT INTO "django_geo_db_location" VALUES(36218,NULL,'Mount Ayr, IN',14784,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36219,NULL,'Mount Ayr, IN 47964',14784,222,NULL,18,21142,0);
INSERT INTO "django_geo_db_location" VALUES(36220,NULL,'New Market, IN 47965',14699,222,NULL,18,21143,0);
INSERT INTO "django_geo_db_location" VALUES(36221,NULL,'Newport, IN',14785,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36222,NULL,'Newport, IN 47966',14785,222,NULL,18,21144,0);
INSERT INTO "django_geo_db_location" VALUES(36223,NULL,'New Richmond, IN',14786,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36224,NULL,'New Richmond, IN 47967',14786,222,NULL,18,21145,0);
INSERT INTO "django_geo_db_location" VALUES(36225,NULL,'New Ross, IN',14787,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36226,NULL,'New Ross, IN 47968',14787,222,NULL,18,21146,0);
INSERT INTO "django_geo_db_location" VALUES(36227,NULL,'Newtown, IN',14788,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36228,NULL,'Newtown, IN 47969',14788,222,NULL,18,21147,0);
INSERT INTO "django_geo_db_location" VALUES(36229,NULL,'Otterbein, IN',14789,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36230,NULL,'Otterbein, IN 47970',14789,222,NULL,18,21148,0);
INSERT INTO "django_geo_db_location" VALUES(36231,NULL,'Oxford, IN 47971',14695,222,NULL,18,21149,0);
INSERT INTO "django_geo_db_location" VALUES(36232,NULL,'Perrysville, IN',14790,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36233,NULL,'Perrysville, IN 47974',14790,222,NULL,18,21150,0);
INSERT INTO "django_geo_db_location" VALUES(36234,NULL,'Pine Village, IN',14791,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36235,NULL,'Pine Village, IN 47975',14791,222,NULL,18,21151,0);
INSERT INTO "django_geo_db_location" VALUES(36236,NULL,'Earl Park, IN 47976',14767,222,NULL,18,21152,0);
INSERT INTO "django_geo_db_location" VALUES(36237,NULL,'Remington, IN',14792,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36238,NULL,'Remington, IN 47977',14792,222,NULL,18,21153,0);
INSERT INTO "django_geo_db_location" VALUES(36239,NULL,'Rensselaer, IN',14793,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36240,NULL,'Rensselaer, IN 47978',14793,222,NULL,18,21154,0);
INSERT INTO "django_geo_db_location" VALUES(36241,NULL,'Reynolds, IN',14794,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36242,NULL,'Reynolds, IN 47980',14794,222,NULL,18,21155,0);
INSERT INTO "django_geo_db_location" VALUES(36243,NULL,'Romney, IN',14795,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36244,NULL,'Romney, IN 47981',14795,222,NULL,18,21156,0);
INSERT INTO "django_geo_db_location" VALUES(36245,NULL,'State Line, IN',14796,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36246,NULL,'State Line, IN 47982',14796,222,NULL,18,21157,0);
INSERT INTO "django_geo_db_location" VALUES(36247,NULL,'Stockwell, IN',14797,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36248,NULL,'Stockwell, IN 47983',14797,222,NULL,18,21158,0);
INSERT INTO "django_geo_db_location" VALUES(36249,NULL,'Talbot, IN',14798,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36250,NULL,'Talbot, IN 47984',14798,222,NULL,18,21159,0);
INSERT INTO "django_geo_db_location" VALUES(36251,NULL,'Templeton, IN',14799,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36252,NULL,'Templeton, IN 47986',14799,222,NULL,18,21160,0);
INSERT INTO "django_geo_db_location" VALUES(36253,NULL,'Veedersburg, IN',14800,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36254,NULL,'Veedersburg, IN 47987',14800,222,NULL,18,21161,0);
INSERT INTO "django_geo_db_location" VALUES(36255,NULL,'Wallace, IN',14801,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36256,NULL,'Wallace, IN 47988',14801,222,NULL,18,21162,0);
INSERT INTO "django_geo_db_location" VALUES(36257,NULL,'Waveland, IN',14802,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36258,NULL,'Waveland, IN 47989',14802,222,NULL,18,21163,0);
INSERT INTO "django_geo_db_location" VALUES(36259,NULL,'Waynetown, IN',14803,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36260,NULL,'Waynetown, IN 47990',14803,222,NULL,18,21164,0);
INSERT INTO "django_geo_db_location" VALUES(36261,NULL,'West Lebanon, IN',14804,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36262,NULL,'West Lebanon, IN 47991',14804,222,NULL,18,21165,0);
INSERT INTO "django_geo_db_location" VALUES(36263,NULL,'Westpoint, IN',14805,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36264,NULL,'Westpoint, IN 47992',14805,222,NULL,18,21166,0);
INSERT INTO "django_geo_db_location" VALUES(36265,NULL,'Williamsport, IN',14806,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36266,NULL,'Williamsport, IN 47993',14806,222,NULL,18,21167,0);
INSERT INTO "django_geo_db_location" VALUES(36267,NULL,'Wingate, IN',14807,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36268,NULL,'Wingate, IN 47994',14807,222,NULL,18,21168,0);
INSERT INTO "django_geo_db_location" VALUES(36269,NULL,'Wolcott, IN',14808,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36270,NULL,'Wolcott, IN 47995',14808,222,NULL,18,21169,0);
INSERT INTO "django_geo_db_location" VALUES(36271,NULL,'West Lafayette, IN 47996',14750,222,NULL,18,21170,0);
INSERT INTO "django_geo_db_location" VALUES(36272,NULL,'Yeoman, IN',14809,222,NULL,18,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36273,NULL,'Yeoman, IN 47997',14809,222,NULL,18,21171,0);
INSERT INTO "django_geo_db_location" VALUES(36274,NULL,'Algonac, MI',14810,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36275,NULL,'Algonac, MI 48001',14810,222,NULL,40,21172,0);
INSERT INTO "django_geo_db_location" VALUES(36276,NULL,'Allenton, MI',14811,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36277,NULL,'Allenton, MI 48002',14811,222,NULL,40,21173,0);
INSERT INTO "django_geo_db_location" VALUES(36278,NULL,'Almont, MI',14812,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36279,NULL,'Almont, MI 48003',14812,222,NULL,40,21174,0);
INSERT INTO "django_geo_db_location" VALUES(36280,NULL,'Anchorville, MI',14813,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36281,NULL,'Anchorville, MI 48004',14813,222,NULL,40,21175,0);
INSERT INTO "django_geo_db_location" VALUES(36282,NULL,'Armada, MI',14814,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36283,NULL,'Armada, MI 48005',14814,222,NULL,40,21176,0);
INSERT INTO "django_geo_db_location" VALUES(36284,NULL,'Avoca, MI',14815,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36285,NULL,'Avoca, MI 48006',14815,222,NULL,40,21177,0);
INSERT INTO "django_geo_db_location" VALUES(36286,NULL,'Troy, MI',14816,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36287,NULL,'Troy, MI 48007',14816,222,NULL,40,21178,0);
INSERT INTO "django_geo_db_location" VALUES(36288,NULL,'Birmingham, MI',14817,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36289,NULL,'Birmingham, MI 48009',14817,222,NULL,40,21179,0);
INSERT INTO "django_geo_db_location" VALUES(36290,NULL,'Birmingham, MI 48012',14817,222,NULL,40,21180,0);
INSERT INTO "django_geo_db_location" VALUES(36291,NULL,'Capac, MI',14818,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36292,NULL,'Capac, MI 48014',14818,222,NULL,40,21181,0);
INSERT INTO "django_geo_db_location" VALUES(36293,NULL,'Center Line, MI',14819,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36294,NULL,'Center Line, MI 48015',14819,222,NULL,40,21182,0);
INSERT INTO "django_geo_db_location" VALUES(36295,NULL,'Clawson, MI',14820,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36296,NULL,'Clawson, MI 48017',14820,222,NULL,40,21183,0);
INSERT INTO "django_geo_db_location" VALUES(36297,NULL,'Rose, MI',14821,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36298,NULL,'Rose, MI 48019',14821,222,NULL,40,21184,0);
INSERT INTO "django_geo_db_location" VALUES(36299,NULL,'Eastpointe, MI',14822,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36300,NULL,'Eastpointe, MI 48021',14822,222,NULL,40,21185,0);
INSERT INTO "django_geo_db_location" VALUES(36301,NULL,'Emmett, MI',14823,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36302,NULL,'Emmett, MI 48022',14823,222,NULL,40,21186,0);
INSERT INTO "django_geo_db_location" VALUES(36303,NULL,'Fair Haven, MI',14824,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36304,NULL,'Fair Haven, MI 48023',14824,222,NULL,40,21187,0);
INSERT INTO "django_geo_db_location" VALUES(36305,NULL,'Franklin, MI',14825,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36306,NULL,'Franklin, MI 48025',14825,222,NULL,40,21188,0);
INSERT INTO "django_geo_db_location" VALUES(36307,NULL,'Fraser, MI',14826,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36308,NULL,'Fraser, MI 48026',14826,222,NULL,40,21189,0);
INSERT INTO "django_geo_db_location" VALUES(36309,NULL,'Goodells, MI',14827,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36310,NULL,'Goodells, MI 48027',14827,222,NULL,40,21190,0);
INSERT INTO "django_geo_db_location" VALUES(36311,NULL,'Harsens Island, MI',14828,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36312,NULL,'Harsens Island, MI 48028',14828,222,NULL,40,21191,0);
INSERT INTO "django_geo_db_location" VALUES(36313,NULL,'Hazel Park, MI',14829,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36314,NULL,'Hazel Park, MI 48030',14829,222,NULL,40,21192,0);
INSERT INTO "django_geo_db_location" VALUES(36315,NULL,'Jeddo, MI',14830,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36316,NULL,'Jeddo, MI 48032',14830,222,NULL,40,21193,0);
INSERT INTO "django_geo_db_location" VALUES(36317,NULL,'Southfield, MI',14831,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36318,NULL,'Southfield, MI 48034',14831,222,NULL,40,21194,0);
INSERT INTO "django_geo_db_location" VALUES(36319,NULL,'Clinton Township, MI',14832,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36320,NULL,'Clinton Township, MI 48035',14832,222,NULL,40,21195,0);
INSERT INTO "django_geo_db_location" VALUES(36321,NULL,'Clinton Township, MI 48036',14832,222,NULL,40,21196,0);
INSERT INTO "django_geo_db_location" VALUES(36322,NULL,'Southfield, MI 48037',14831,222,NULL,40,21197,0);
INSERT INTO "django_geo_db_location" VALUES(36323,NULL,'Clinton Township, MI 48038',14832,222,NULL,40,21198,0);
INSERT INTO "django_geo_db_location" VALUES(36324,NULL,'Marine City, MI',14833,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36325,NULL,'Marine City, MI 48039',14833,222,NULL,40,21199,0);
INSERT INTO "django_geo_db_location" VALUES(36326,NULL,'Marysville, MI',14834,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36327,NULL,'Marysville, MI 48040',14834,222,NULL,40,21200,0);
INSERT INTO "django_geo_db_location" VALUES(36328,NULL,'Memphis, MI',14835,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36329,NULL,'Memphis, MI 48041',14835,222,NULL,40,21201,0);
INSERT INTO "django_geo_db_location" VALUES(36330,NULL,'Macomb, MI',14836,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36331,NULL,'Macomb, MI 48042',14836,222,NULL,40,21202,0);
INSERT INTO "django_geo_db_location" VALUES(36332,NULL,'Mount Clemens, MI',14837,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36333,NULL,'Mount Clemens, MI 48043',14837,222,NULL,40,21203,0);
INSERT INTO "django_geo_db_location" VALUES(36334,NULL,'Macomb, MI 48044',14836,222,NULL,40,21204,0);
INSERT INTO "django_geo_db_location" VALUES(36335,NULL,'Harrison Township, MI',14838,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36336,NULL,'Harrison Township, MI 48045',14838,222,NULL,40,21205,0);
INSERT INTO "django_geo_db_location" VALUES(36337,NULL,'Mount Clemens, MI 48046',14837,222,NULL,40,21206,0);
INSERT INTO "django_geo_db_location" VALUES(36338,NULL,'New Baltimore, MI',14839,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36339,NULL,'New Baltimore, MI 48047',14839,222,NULL,40,21207,0);
INSERT INTO "django_geo_db_location" VALUES(36340,NULL,'New Haven, MI',14840,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36341,NULL,'New Haven, MI 48048',14840,222,NULL,40,21208,0);
INSERT INTO "django_geo_db_location" VALUES(36342,NULL,'North Street, MI',14841,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36343,NULL,'North Street, MI 48049',14841,222,NULL,40,21209,0);
INSERT INTO "django_geo_db_location" VALUES(36344,NULL,'New Haven, MI 48050',14840,222,NULL,40,21210,0);
INSERT INTO "django_geo_db_location" VALUES(36345,NULL,'New Baltimore, MI 48051',14839,222,NULL,40,21211,0);
INSERT INTO "django_geo_db_location" VALUES(36346,NULL,'East China, MI',14842,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36347,NULL,'East China, MI 48054',14842,222,NULL,40,21212,0);
INSERT INTO "django_geo_db_location" VALUES(36348,NULL,'Fort Gratiot, MI',14843,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36349,NULL,'Fort Gratiot, MI 48059',14843,222,NULL,40,21213,0);
INSERT INTO "django_geo_db_location" VALUES(36350,NULL,'Port Huron, MI',14844,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36351,NULL,'Port Huron, MI 48060',14844,222,NULL,40,21214,0);
INSERT INTO "django_geo_db_location" VALUES(36352,NULL,'Port Huron, MI 48061',14844,222,NULL,40,21215,0);
INSERT INTO "django_geo_db_location" VALUES(36353,NULL,'Richmond, MI',14845,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36354,NULL,'Richmond, MI 48062',14845,222,NULL,40,21216,0);
INSERT INTO "django_geo_db_location" VALUES(36355,NULL,'Columbus, MI',14846,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36356,NULL,'Columbus, MI 48063',14846,222,NULL,40,21217,0);
INSERT INTO "django_geo_db_location" VALUES(36357,NULL,'Casco, MI',14847,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36358,NULL,'Casco, MI 48064',14847,222,NULL,40,21218,0);
INSERT INTO "django_geo_db_location" VALUES(36359,NULL,'Romeo, MI',14848,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36360,NULL,'Romeo, MI 48065',14848,222,NULL,40,21219,0);
INSERT INTO "django_geo_db_location" VALUES(36361,NULL,'Roseville, MI',14849,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36362,NULL,'Roseville, MI 48066',14849,222,NULL,40,21220,0);
INSERT INTO "django_geo_db_location" VALUES(36363,NULL,'Royal Oak, MI',14850,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36364,NULL,'Royal Oak, MI 48067',14850,222,NULL,40,21221,0);
INSERT INTO "django_geo_db_location" VALUES(36365,NULL,'Royal Oak, MI 48068',14850,222,NULL,40,21222,0);
INSERT INTO "django_geo_db_location" VALUES(36366,NULL,'Pleasant Ridge, MI',14851,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36367,NULL,'Pleasant Ridge, MI 48069',14851,222,NULL,40,21223,0);
INSERT INTO "django_geo_db_location" VALUES(36368,NULL,'Huntington Woods, MI',14852,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36369,NULL,'Huntington Woods, MI 48070',14852,222,NULL,40,21224,0);
INSERT INTO "django_geo_db_location" VALUES(36370,NULL,'Madison Heights, MI',14853,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36371,NULL,'Madison Heights, MI 48071',14853,222,NULL,40,21225,0);
INSERT INTO "django_geo_db_location" VALUES(36372,NULL,'Berkley, MI',14854,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36373,NULL,'Berkley, MI 48072',14854,222,NULL,40,21226,0);
INSERT INTO "django_geo_db_location" VALUES(36374,NULL,'Royal Oak, MI 48073',14850,222,NULL,40,21227,0);
INSERT INTO "django_geo_db_location" VALUES(36375,NULL,'Smiths Creek, MI',14855,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36376,NULL,'Smiths Creek, MI 48074',14855,222,NULL,40,21228,0);
INSERT INTO "django_geo_db_location" VALUES(36377,NULL,'Southfield, MI 48075',14831,222,NULL,40,21229,0);
INSERT INTO "django_geo_db_location" VALUES(36378,NULL,'Southfield, MI 48076',14831,222,NULL,40,21230,0);
INSERT INTO "django_geo_db_location" VALUES(36379,NULL,'Saint Clair, MI',14856,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36380,NULL,'Saint Clair, MI 48079',14856,222,NULL,40,21231,0);
INSERT INTO "django_geo_db_location" VALUES(36381,NULL,'Saint Clair Shores, MI',14857,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36382,NULL,'Saint Clair Shores, MI 48080',14857,222,NULL,40,21232,0);
INSERT INTO "django_geo_db_location" VALUES(36383,NULL,'Saint Clair Shores, MI 48081',14857,222,NULL,40,21233,0);
INSERT INTO "django_geo_db_location" VALUES(36384,NULL,'Saint Clair Shores, MI 48082',14857,222,NULL,40,21234,0);
INSERT INTO "django_geo_db_location" VALUES(36385,NULL,'Troy, MI 48083',14816,222,NULL,40,21235,0);
INSERT INTO "django_geo_db_location" VALUES(36386,NULL,'Troy, MI 48084',14816,222,NULL,40,21236,0);
INSERT INTO "django_geo_db_location" VALUES(36387,NULL,'Troy, MI 48085',14816,222,NULL,40,21237,0);
INSERT INTO "django_geo_db_location" VALUES(36388,NULL,'Southfield, MI 48086',14831,222,NULL,40,21238,0);
INSERT INTO "django_geo_db_location" VALUES(36389,NULL,'Warren, MI',14858,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36390,NULL,'Warren, MI 48088',14858,222,NULL,40,21239,0);
INSERT INTO "django_geo_db_location" VALUES(36391,NULL,'Warren, MI 48089',14858,222,NULL,40,21240,0);
INSERT INTO "django_geo_db_location" VALUES(36392,NULL,'Warren, MI 48090',14858,222,NULL,40,21241,0);
INSERT INTO "django_geo_db_location" VALUES(36393,NULL,'Warren, MI 48091',14858,222,NULL,40,21242,0);
INSERT INTO "django_geo_db_location" VALUES(36394,NULL,'Warren, MI 48092',14858,222,NULL,40,21243,0);
INSERT INTO "django_geo_db_location" VALUES(36395,NULL,'Warren, MI 48093',14858,222,NULL,40,21244,0);
INSERT INTO "django_geo_db_location" VALUES(36396,NULL,'Washington, MI',14859,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36397,NULL,'Washington, MI 48094',14859,222,NULL,40,21245,0);
INSERT INTO "django_geo_db_location" VALUES(36398,NULL,'Washington, MI 48095',14859,222,NULL,40,21246,0);
INSERT INTO "django_geo_db_location" VALUES(36399,NULL,'Ray, MI',14860,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36400,NULL,'Ray, MI 48096',14860,222,NULL,40,21247,0);
INSERT INTO "django_geo_db_location" VALUES(36401,NULL,'Yale, MI',14861,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36402,NULL,'Yale, MI 48097',14861,222,NULL,40,21248,0);
INSERT INTO "django_geo_db_location" VALUES(36403,NULL,'Troy, MI 48098',14816,222,NULL,40,21249,0);
INSERT INTO "django_geo_db_location" VALUES(36404,NULL,'Troy, MI 48099',14816,222,NULL,40,21250,0);
INSERT INTO "django_geo_db_location" VALUES(36405,NULL,'Allen Park, MI',14862,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36406,NULL,'Allen Park, MI 48101',14862,222,NULL,40,21251,0);
INSERT INTO "django_geo_db_location" VALUES(36407,NULL,'Ann Arbor, MI',14863,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36408,NULL,'Ann Arbor, MI 48103',14863,222,NULL,40,21252,0);
INSERT INTO "django_geo_db_location" VALUES(36409,NULL,'Ann Arbor, MI 48104',14863,222,NULL,40,21253,0);
INSERT INTO "django_geo_db_location" VALUES(36410,NULL,'Ann Arbor, MI 48105',14863,222,NULL,40,21254,0);
INSERT INTO "django_geo_db_location" VALUES(36411,NULL,'Ann Arbor, MI 48106',14863,222,NULL,40,21255,0);
INSERT INTO "django_geo_db_location" VALUES(36412,NULL,'Ann Arbor, MI 48107',14863,222,NULL,40,21256,0);
INSERT INTO "django_geo_db_location" VALUES(36413,NULL,'Ann Arbor, MI 48108',14863,222,NULL,40,21257,0);
INSERT INTO "django_geo_db_location" VALUES(36414,NULL,'Ann Arbor, MI 48109',14863,222,NULL,40,21258,0);
INSERT INTO "django_geo_db_location" VALUES(36415,NULL,'Azalia, MI',14864,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36416,NULL,'Azalia, MI 48110',14864,222,NULL,40,21259,0);
INSERT INTO "django_geo_db_location" VALUES(36417,NULL,'Belleville, MI',14865,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36418,NULL,'Belleville, MI 48111',14865,222,NULL,40,21260,0);
INSERT INTO "django_geo_db_location" VALUES(36419,NULL,'Belleville, MI 48112',14865,222,NULL,40,21261,0);
INSERT INTO "django_geo_db_location" VALUES(36420,NULL,'Ann Arbor, MI 48113',14863,222,NULL,40,21262,0);
INSERT INTO "django_geo_db_location" VALUES(36421,NULL,'Brighton, MI',14866,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36422,NULL,'Brighton, MI 48114',14866,222,NULL,40,21263,0);
INSERT INTO "django_geo_db_location" VALUES(36423,NULL,'Bridgewater, MI',14867,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36424,NULL,'Bridgewater, MI 48115',14867,222,NULL,40,21264,0);
INSERT INTO "django_geo_db_location" VALUES(36425,NULL,'Brighton, MI 48116',14866,222,NULL,40,21265,0);
INSERT INTO "django_geo_db_location" VALUES(36426,NULL,'Carleton, MI',14868,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36427,NULL,'Carleton, MI 48117',14868,222,NULL,40,21266,0);
INSERT INTO "django_geo_db_location" VALUES(36428,NULL,'Chelsea, MI',14869,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36429,NULL,'Chelsea, MI 48118',14869,222,NULL,40,21267,0);
INSERT INTO "django_geo_db_location" VALUES(36430,NULL,'Dearborn, MI',14870,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36431,NULL,'Dearborn, MI 48120',14870,222,NULL,40,21268,0);
INSERT INTO "django_geo_db_location" VALUES(36432,NULL,'Dearborn, MI 48121',14870,222,NULL,40,21269,0);
INSERT INTO "django_geo_db_location" VALUES(36433,NULL,'Melvindale, MI',14871,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36434,NULL,'Melvindale, MI 48122',14871,222,NULL,40,21270,0);
INSERT INTO "django_geo_db_location" VALUES(36435,NULL,'Dearborn, MI 48123',14870,222,NULL,40,21271,0);
INSERT INTO "django_geo_db_location" VALUES(36436,NULL,'Dearborn, MI 48124',14870,222,NULL,40,21272,0);
INSERT INTO "django_geo_db_location" VALUES(36437,NULL,'Dearborn Heights, MI',14872,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36438,NULL,'Dearborn Heights, MI 48125',14872,222,NULL,40,21273,0);
INSERT INTO "django_geo_db_location" VALUES(36439,NULL,'Dearborn, MI 48126',14870,222,NULL,40,21274,0);
INSERT INTO "django_geo_db_location" VALUES(36440,NULL,'Dearborn Heights, MI 48127',14872,222,NULL,40,21275,0);
INSERT INTO "django_geo_db_location" VALUES(36441,NULL,'Dearborn, MI 48128',14870,222,NULL,40,21276,0);
INSERT INTO "django_geo_db_location" VALUES(36442,NULL,'Dexter, MI',14873,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36443,NULL,'Dexter, MI 48130',14873,222,NULL,40,21277,0);
INSERT INTO "django_geo_db_location" VALUES(36444,NULL,'Dundee, MI',14874,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36445,NULL,'Dundee, MI 48131',14874,222,NULL,40,21278,0);
INSERT INTO "django_geo_db_location" VALUES(36446,NULL,'Erie, MI',14875,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36447,NULL,'Erie, MI 48133',14875,222,NULL,40,21279,0);
INSERT INTO "django_geo_db_location" VALUES(36448,NULL,'Flat Rock, MI',14876,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36449,NULL,'Flat Rock, MI 48134',14876,222,NULL,40,21280,0);
INSERT INTO "django_geo_db_location" VALUES(36450,NULL,'Garden City, MI',14877,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36451,NULL,'Garden City, MI 48135',14877,222,NULL,40,21281,0);
INSERT INTO "django_geo_db_location" VALUES(36452,NULL,'Garden City, MI 48136',14877,222,NULL,40,21282,0);
INSERT INTO "django_geo_db_location" VALUES(36453,NULL,'Gregory, MI',14878,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36454,NULL,'Gregory, MI 48137',14878,222,NULL,40,21283,0);
INSERT INTO "django_geo_db_location" VALUES(36455,NULL,'Grosse Ile, MI',14879,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36456,NULL,'Grosse Ile, MI 48138',14879,222,NULL,40,21284,0);
INSERT INTO "django_geo_db_location" VALUES(36457,NULL,'Hamburg, MI',14880,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36458,NULL,'Hamburg, MI 48139',14880,222,NULL,40,21285,0);
INSERT INTO "django_geo_db_location" VALUES(36459,NULL,'Ida, MI',14881,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36460,NULL,'Ida, MI 48140',14881,222,NULL,40,21286,0);
INSERT INTO "django_geo_db_location" VALUES(36461,NULL,'Inkster, MI',14882,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36462,NULL,'Inkster, MI 48141',14882,222,NULL,40,21287,0);
INSERT INTO "django_geo_db_location" VALUES(36463,NULL,'Lakeland, MI',14883,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36464,NULL,'Lakeland, MI 48143',14883,222,NULL,40,21288,0);
INSERT INTO "django_geo_db_location" VALUES(36465,NULL,'Lambertville, MI',14884,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36466,NULL,'Lambertville, MI 48144',14884,222,NULL,40,21289,0);
INSERT INTO "django_geo_db_location" VALUES(36467,NULL,'La Salle, MI',14885,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36468,NULL,'La Salle, MI 48145',14885,222,NULL,40,21290,0);
INSERT INTO "django_geo_db_location" VALUES(36469,NULL,'Lincoln Park, MI',14886,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36470,NULL,'Lincoln Park, MI 48146',14886,222,NULL,40,21291,0);
INSERT INTO "django_geo_db_location" VALUES(36471,NULL,'Livonia, MI',14887,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36472,NULL,'Livonia, MI 48150',14887,222,NULL,40,21292,0);
INSERT INTO "django_geo_db_location" VALUES(36473,NULL,'Livonia, MI 48151',14887,222,NULL,40,21293,0);
INSERT INTO "django_geo_db_location" VALUES(36474,NULL,'Livonia, MI 48152',14887,222,NULL,40,21294,0);
INSERT INTO "django_geo_db_location" VALUES(36475,NULL,'Livonia, MI 48153',14887,222,NULL,40,21295,0);
INSERT INTO "django_geo_db_location" VALUES(36476,NULL,'Livonia, MI 48154',14887,222,NULL,40,21296,0);
INSERT INTO "django_geo_db_location" VALUES(36477,NULL,'Luna Pier, MI',14888,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36478,NULL,'Luna Pier, MI 48157',14888,222,NULL,40,21297,0);
INSERT INTO "django_geo_db_location" VALUES(36479,NULL,'Manchester, MI',14889,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36480,NULL,'Manchester, MI 48158',14889,222,NULL,40,21298,0);
INSERT INTO "django_geo_db_location" VALUES(36481,NULL,'Maybee, MI',14890,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36482,NULL,'Maybee, MI 48159',14890,222,NULL,40,21299,0);
INSERT INTO "django_geo_db_location" VALUES(36483,NULL,'Milan, MI',14891,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36484,NULL,'Milan, MI 48160',14891,222,NULL,40,21300,0);
INSERT INTO "django_geo_db_location" VALUES(36485,NULL,'Monroe, MI',14892,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36486,NULL,'Monroe, MI 48161',14892,222,NULL,40,21301,0);
INSERT INTO "django_geo_db_location" VALUES(36487,NULL,'Monroe, MI 48162',14892,222,NULL,40,21302,0);
INSERT INTO "django_geo_db_location" VALUES(36488,NULL,'New Boston, MI',14893,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36489,NULL,'New Boston, MI 48164',14893,222,NULL,40,21303,0);
INSERT INTO "django_geo_db_location" VALUES(36490,NULL,'New Hudson, MI',14894,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36491,NULL,'New Hudson, MI 48165',14894,222,NULL,40,21304,0);
INSERT INTO "django_geo_db_location" VALUES(36492,NULL,'Newport, MI',14895,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36493,NULL,'Newport, MI 48166',14895,222,NULL,40,21305,0);
INSERT INTO "django_geo_db_location" VALUES(36494,NULL,'Northville, MI',14896,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36495,NULL,'Northville, MI 48167',14896,222,NULL,40,21306,0);
INSERT INTO "django_geo_db_location" VALUES(36496,NULL,'South Monroe, MI',14897,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36497,NULL,'South Monroe, MI 48168',14897,222,NULL,40,21307,0);
INSERT INTO "django_geo_db_location" VALUES(36498,NULL,'Pinckney, MI',14898,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36499,NULL,'Pinckney, MI 48169',14898,222,NULL,40,21308,0);
INSERT INTO "django_geo_db_location" VALUES(36500,NULL,'Plymouth, MI',14899,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36501,NULL,'Plymouth, MI 48170',14899,222,NULL,40,21309,0);
INSERT INTO "django_geo_db_location" VALUES(36502,NULL,'Rockwood, MI',14900,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36503,NULL,'Rockwood, MI 48173',14900,222,NULL,40,21310,0);
INSERT INTO "django_geo_db_location" VALUES(36504,NULL,'Romulus, MI',14901,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36505,NULL,'Romulus, MI 48174',14901,222,NULL,40,21311,0);
INSERT INTO "django_geo_db_location" VALUES(36506,NULL,'Salem, MI',14902,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36507,NULL,'Salem, MI 48175',14902,222,NULL,40,21312,0);
INSERT INTO "django_geo_db_location" VALUES(36508,NULL,'Saline, MI',14903,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36509,NULL,'Saline, MI 48176',14903,222,NULL,40,21313,0);
INSERT INTO "django_geo_db_location" VALUES(36510,NULL,'Samaria, MI',14904,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36511,NULL,'Samaria, MI 48177',14904,222,NULL,40,21314,0);
INSERT INTO "django_geo_db_location" VALUES(36512,NULL,'South Lyon, MI',14905,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36513,NULL,'South Lyon, MI 48178',14905,222,NULL,40,21315,0);
INSERT INTO "django_geo_db_location" VALUES(36514,NULL,'South Rockwood, MI',14906,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36515,NULL,'South Rockwood, MI 48179',14906,222,NULL,40,21316,0);
INSERT INTO "django_geo_db_location" VALUES(36516,NULL,'Taylor, MI',14907,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36517,NULL,'Taylor, MI 48180',14907,222,NULL,40,21317,0);
INSERT INTO "django_geo_db_location" VALUES(36518,NULL,'Temperance, MI',14908,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36519,NULL,'Temperance, MI 48182',14908,222,NULL,40,21318,0);
INSERT INTO "django_geo_db_location" VALUES(36520,NULL,'Trenton, MI',14909,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36521,NULL,'Trenton, MI 48183',14909,222,NULL,40,21319,0);
INSERT INTO "django_geo_db_location" VALUES(36522,NULL,'Wayne, MI',14910,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36523,NULL,'Wayne, MI 48184',14910,222,NULL,40,21320,0);
INSERT INTO "django_geo_db_location" VALUES(36524,NULL,'Westland, MI',14911,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36525,NULL,'Westland, MI 48185',14911,222,NULL,40,21321,0);
INSERT INTO "django_geo_db_location" VALUES(36526,NULL,'Westland, MI 48186',14911,222,NULL,40,21322,0);
INSERT INTO "django_geo_db_location" VALUES(36527,NULL,'Canton, MI',14912,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36528,NULL,'Canton, MI 48187',14912,222,NULL,40,21323,0);
INSERT INTO "django_geo_db_location" VALUES(36529,NULL,'Canton, MI 48188',14912,222,NULL,40,21324,0);
INSERT INTO "django_geo_db_location" VALUES(36530,NULL,'Whitmore Lake, MI',14913,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36531,NULL,'Whitmore Lake, MI 48189',14913,222,NULL,40,21325,0);
INSERT INTO "django_geo_db_location" VALUES(36532,NULL,'Whittaker, MI',14914,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36533,NULL,'Whittaker, MI 48190',14914,222,NULL,40,21326,0);
INSERT INTO "django_geo_db_location" VALUES(36534,NULL,'Willis, MI',14915,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36535,NULL,'Willis, MI 48191',14915,222,NULL,40,21327,0);
INSERT INTO "django_geo_db_location" VALUES(36536,NULL,'Wyandotte, MI',14916,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36537,NULL,'Wyandotte, MI 48192',14916,222,NULL,40,21328,0);
INSERT INTO "django_geo_db_location" VALUES(36538,NULL,'Southgate, MI',14917,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36539,NULL,'Southgate, MI 48195',14917,222,NULL,40,21329,0);
INSERT INTO "django_geo_db_location" VALUES(36540,NULL,'Ypsilanti, MI',14918,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36541,NULL,'Ypsilanti, MI 48197',14918,222,NULL,40,21330,0);
INSERT INTO "django_geo_db_location" VALUES(36542,NULL,'Ypsilanti, MI 48198',14918,222,NULL,40,21331,0);
INSERT INTO "django_geo_db_location" VALUES(36543,NULL,'Detroit, MI',14919,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36544,NULL,'Detroit, MI 48201',14919,222,NULL,40,21332,0);
INSERT INTO "django_geo_db_location" VALUES(36545,NULL,'Detroit, MI 48202',14919,222,NULL,40,21333,0);
INSERT INTO "django_geo_db_location" VALUES(36546,NULL,'Highland Park, MI',14920,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36547,NULL,'Highland Park, MI 48203',14920,222,NULL,40,21334,0);
INSERT INTO "django_geo_db_location" VALUES(36548,NULL,'Detroit, MI 48204',14919,222,NULL,40,21335,0);
INSERT INTO "django_geo_db_location" VALUES(36549,NULL,'Detroit, MI 48205',14919,222,NULL,40,21336,0);
INSERT INTO "django_geo_db_location" VALUES(36550,NULL,'Detroit, MI 48206',14919,222,NULL,40,21337,0);
INSERT INTO "django_geo_db_location" VALUES(36551,NULL,'Detroit, MI 48207',14919,222,NULL,40,21338,0);
INSERT INTO "django_geo_db_location" VALUES(36552,NULL,'Detroit, MI 48208',14919,222,NULL,40,21339,0);
INSERT INTO "django_geo_db_location" VALUES(36553,NULL,'Detroit, MI 48209',14919,222,NULL,40,21340,0);
INSERT INTO "django_geo_db_location" VALUES(36554,NULL,'Detroit, MI 48210',14919,222,NULL,40,21341,0);
INSERT INTO "django_geo_db_location" VALUES(36555,NULL,'Detroit, MI 48211',14919,222,NULL,40,21342,0);
INSERT INTO "django_geo_db_location" VALUES(36556,NULL,'Hamtramck, MI',14921,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36557,NULL,'Hamtramck, MI 48212',14921,222,NULL,40,21343,0);
INSERT INTO "django_geo_db_location" VALUES(36558,NULL,'Detroit, MI 48213',14919,222,NULL,40,21344,0);
INSERT INTO "django_geo_db_location" VALUES(36559,NULL,'Detroit, MI 48214',14919,222,NULL,40,21345,0);
INSERT INTO "django_geo_db_location" VALUES(36560,NULL,'Detroit, MI 48215',14919,222,NULL,40,21346,0);
INSERT INTO "django_geo_db_location" VALUES(36561,NULL,'Detroit, MI 48216',14919,222,NULL,40,21347,0);
INSERT INTO "django_geo_db_location" VALUES(36562,NULL,'Detroit, MI 48217',14919,222,NULL,40,21348,0);
INSERT INTO "django_geo_db_location" VALUES(36563,NULL,'River Rouge, MI',14922,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36564,NULL,'River Rouge, MI 48218',14922,222,NULL,40,21349,0);
INSERT INTO "django_geo_db_location" VALUES(36565,NULL,'Detroit, MI 48219',14919,222,NULL,40,21350,0);
INSERT INTO "django_geo_db_location" VALUES(36566,NULL,'Ferndale, MI',14923,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36567,NULL,'Ferndale, MI 48220',14923,222,NULL,40,21351,0);
INSERT INTO "django_geo_db_location" VALUES(36568,NULL,'Detroit, MI 48221',14919,222,NULL,40,21352,0);
INSERT INTO "django_geo_db_location" VALUES(36569,NULL,'Detroit, MI 48222',14919,222,NULL,40,21353,0);
INSERT INTO "django_geo_db_location" VALUES(36570,NULL,'Detroit, MI 48223',14919,222,NULL,40,21354,0);
INSERT INTO "django_geo_db_location" VALUES(36571,NULL,'Detroit, MI 48224',14919,222,NULL,40,21355,0);
INSERT INTO "django_geo_db_location" VALUES(36572,NULL,'Harper Woods, MI',14924,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36573,NULL,'Harper Woods, MI 48225',14924,222,NULL,40,21356,0);
INSERT INTO "django_geo_db_location" VALUES(36574,NULL,'Detroit, MI 48226',14919,222,NULL,40,21357,0);
INSERT INTO "django_geo_db_location" VALUES(36575,NULL,'Detroit, MI 48227',14919,222,NULL,40,21358,0);
INSERT INTO "django_geo_db_location" VALUES(36576,NULL,'Detroit, MI 48228',14919,222,NULL,40,21359,0);
INSERT INTO "django_geo_db_location" VALUES(36577,NULL,'Ecorse, MI',14925,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36578,NULL,'Ecorse, MI 48229',14925,222,NULL,40,21360,0);
INSERT INTO "django_geo_db_location" VALUES(36579,NULL,'Grosse Pointe, MI',14926,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36580,NULL,'Grosse Pointe, MI 48230',14926,222,NULL,40,21361,0);
INSERT INTO "django_geo_db_location" VALUES(36581,NULL,'Detroit, MI 48231',14919,222,NULL,40,21362,0);
INSERT INTO "django_geo_db_location" VALUES(36582,NULL,'Detroit, MI 48232',14919,222,NULL,40,21363,0);
INSERT INTO "django_geo_db_location" VALUES(36583,NULL,'Detroit, MI 48233',14919,222,NULL,40,21364,0);
INSERT INTO "django_geo_db_location" VALUES(36584,NULL,'Detroit, MI 48234',14919,222,NULL,40,21365,0);
INSERT INTO "django_geo_db_location" VALUES(36585,NULL,'Detroit, MI 48235',14919,222,NULL,40,21366,0);
INSERT INTO "django_geo_db_location" VALUES(36586,NULL,'Grosse Pointe, MI 48236',14926,222,NULL,40,21367,0);
INSERT INTO "django_geo_db_location" VALUES(36587,NULL,'Oak Park, MI',14927,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36588,NULL,'Oak Park, MI 48237',14927,222,NULL,40,21368,0);
INSERT INTO "django_geo_db_location" VALUES(36589,NULL,'Detroit, MI 48238',14919,222,NULL,40,21369,0);
INSERT INTO "django_geo_db_location" VALUES(36590,NULL,'Redford, MI',14928,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36591,NULL,'Redford, MI 48239',14928,222,NULL,40,21370,0);
INSERT INTO "django_geo_db_location" VALUES(36592,NULL,'Redford, MI 48240',14928,222,NULL,40,21371,0);
INSERT INTO "django_geo_db_location" VALUES(36593,NULL,'Detroit, MI 48242',14919,222,NULL,40,21372,0);
INSERT INTO "django_geo_db_location" VALUES(36594,NULL,'Detroit, MI 48243',14919,222,NULL,40,21373,0);
INSERT INTO "django_geo_db_location" VALUES(36595,NULL,'Detroit, MI 48244',14919,222,NULL,40,21374,0);
INSERT INTO "django_geo_db_location" VALUES(36596,NULL,'Independence, MI',14929,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36597,NULL,'Independence, MI 48246',14929,222,NULL,40,21375,0);
INSERT INTO "django_geo_db_location" VALUES(36598,NULL,'Detroit, MI 48254',14919,222,NULL,40,21376,0);
INSERT INTO "django_geo_db_location" VALUES(36599,NULL,'Detroit, MI 48255',14919,222,NULL,40,21377,0);
INSERT INTO "django_geo_db_location" VALUES(36600,NULL,'Detroit, MI 48258',14919,222,NULL,40,21378,0);
INSERT INTO "django_geo_db_location" VALUES(36601,NULL,'Detroit, MI 48260',14919,222,NULL,40,21379,0);
INSERT INTO "django_geo_db_location" VALUES(36602,NULL,'Detroit, MI 48264',14919,222,NULL,40,21380,0);
INSERT INTO "django_geo_db_location" VALUES(36603,NULL,'Detroit, MI 48265',14919,222,NULL,40,21381,0);
INSERT INTO "django_geo_db_location" VALUES(36604,NULL,'Detroit, MI 48266',14919,222,NULL,40,21382,0);
INSERT INTO "django_geo_db_location" VALUES(36605,NULL,'Detroit, MI 48267',14919,222,NULL,40,21383,0);
INSERT INTO "django_geo_db_location" VALUES(36606,NULL,'Detroit, MI 48268',14919,222,NULL,40,21384,0);
INSERT INTO "django_geo_db_location" VALUES(36607,NULL,'Detroit, MI 48269',14919,222,NULL,40,21385,0);
INSERT INTO "django_geo_db_location" VALUES(36608,NULL,'Detroit, MI 48272',14919,222,NULL,40,21386,0);
INSERT INTO "django_geo_db_location" VALUES(36609,NULL,'Detroit, MI 48274',14919,222,NULL,40,21387,0);
INSERT INTO "django_geo_db_location" VALUES(36610,NULL,'Detroit, MI 48275',14919,222,NULL,40,21388,0);
INSERT INTO "django_geo_db_location" VALUES(36611,NULL,'Detroit, MI 48277',14919,222,NULL,40,21389,0);
INSERT INTO "django_geo_db_location" VALUES(36612,NULL,'Detroit, MI 48278',14919,222,NULL,40,21390,0);
INSERT INTO "django_geo_db_location" VALUES(36613,NULL,'Detroit, MI 48279',14919,222,NULL,40,21391,0);
INSERT INTO "django_geo_db_location" VALUES(36614,NULL,'Detroit, MI 48288',14919,222,NULL,40,21392,0);
INSERT INTO "django_geo_db_location" VALUES(36615,NULL,'Detroit, MI 48295',14919,222,NULL,40,21393,0);
INSERT INTO "django_geo_db_location" VALUES(36616,NULL,'Detroit, MI 48297',14919,222,NULL,40,21394,0);
INSERT INTO "django_geo_db_location" VALUES(36617,NULL,'Detroit, MI 48299',14919,222,NULL,40,21395,0);
INSERT INTO "django_geo_db_location" VALUES(36618,NULL,'Bloomfield Hills, MI',14930,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36619,NULL,'Bloomfield Hills, MI 48301',14930,222,NULL,40,21396,0);
INSERT INTO "django_geo_db_location" VALUES(36620,NULL,'Bloomfield Hills, MI 48302',14930,222,NULL,40,21397,0);
INSERT INTO "django_geo_db_location" VALUES(36621,NULL,'Bloomfield Hills, MI 48303',14930,222,NULL,40,21398,0);
INSERT INTO "django_geo_db_location" VALUES(36622,NULL,'Bloomfield Hills, MI 48304',14930,222,NULL,40,21399,0);
INSERT INTO "django_geo_db_location" VALUES(36623,NULL,'Clinton, MI',14931,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36624,NULL,'Clinton, MI 48305',14931,222,NULL,40,21400,0);
INSERT INTO "django_geo_db_location" VALUES(36625,NULL,'Rochester, MI',14932,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36626,NULL,'Rochester, MI 48306',14932,222,NULL,40,21401,0);
INSERT INTO "django_geo_db_location" VALUES(36627,NULL,'Rochester, MI 48307',14932,222,NULL,40,21402,0);
INSERT INTO "django_geo_db_location" VALUES(36628,NULL,'Rochester, MI 48308',14932,222,NULL,40,21403,0);
INSERT INTO "django_geo_db_location" VALUES(36629,NULL,'Rochester, MI 48309',14932,222,NULL,40,21404,0);
INSERT INTO "django_geo_db_location" VALUES(36630,NULL,'Sterling Heights, MI',14933,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36631,NULL,'Sterling Heights, MI 48310',14933,222,NULL,40,21405,0);
INSERT INTO "django_geo_db_location" VALUES(36632,NULL,'Sterling Heights, MI 48311',14933,222,NULL,40,21406,0);
INSERT INTO "django_geo_db_location" VALUES(36633,NULL,'Sterling Heights, MI 48312',14933,222,NULL,40,21407,0);
INSERT INTO "django_geo_db_location" VALUES(36634,NULL,'Sterling Heights, MI 48313',14933,222,NULL,40,21408,0);
INSERT INTO "django_geo_db_location" VALUES(36635,NULL,'Sterling Heights, MI 48314',14933,222,NULL,40,21409,0);
INSERT INTO "django_geo_db_location" VALUES(36636,NULL,'Utica, MI',14934,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36637,NULL,'Utica, MI 48315',14934,222,NULL,40,21410,0);
INSERT INTO "django_geo_db_location" VALUES(36638,NULL,'Utica, MI 48316',14934,222,NULL,40,21411,0);
INSERT INTO "django_geo_db_location" VALUES(36639,NULL,'Utica, MI 48317',14934,222,NULL,40,21412,0);
INSERT INTO "django_geo_db_location" VALUES(36640,NULL,'Utica, MI 48318',14934,222,NULL,40,21413,0);
INSERT INTO "django_geo_db_location" VALUES(36641,NULL,'Keego Harbor, MI',14935,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36642,NULL,'Keego Harbor, MI 48320',14935,222,NULL,40,21414,0);
INSERT INTO "django_geo_db_location" VALUES(36643,NULL,'Auburn Hills, MI',14936,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36644,NULL,'Auburn Hills, MI 48321',14936,222,NULL,40,21415,0);
INSERT INTO "django_geo_db_location" VALUES(36645,NULL,'West Bloomfield, MI',14937,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36646,NULL,'West Bloomfield, MI 48322',14937,222,NULL,40,21416,0);
INSERT INTO "django_geo_db_location" VALUES(36647,NULL,'West Bloomfield, MI 48323',14937,222,NULL,40,21417,0);
INSERT INTO "django_geo_db_location" VALUES(36648,NULL,'West Bloomfield, MI 48324',14937,222,NULL,40,21418,0);
INSERT INTO "django_geo_db_location" VALUES(36649,NULL,'West Bloomfield, MI 48325',14937,222,NULL,40,21419,0);
INSERT INTO "django_geo_db_location" VALUES(36650,NULL,'Auburn Hills, MI 48326',14936,222,NULL,40,21420,0);
INSERT INTO "django_geo_db_location" VALUES(36651,NULL,'Waterford, MI',14938,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36652,NULL,'Waterford, MI 48327',14938,222,NULL,40,21421,0);
INSERT INTO "django_geo_db_location" VALUES(36653,NULL,'Waterford, MI 48328',14938,222,NULL,40,21422,0);
INSERT INTO "django_geo_db_location" VALUES(36654,NULL,'Waterford, MI 48329',14938,222,NULL,40,21423,0);
INSERT INTO "django_geo_db_location" VALUES(36655,NULL,'Drayton Plains, MI',14939,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36656,NULL,'Drayton Plains, MI 48330',14939,222,NULL,40,21424,0);
INSERT INTO "django_geo_db_location" VALUES(36657,NULL,'Farmington, MI',14940,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36658,NULL,'Farmington, MI 48331',14940,222,NULL,40,21425,0);
INSERT INTO "django_geo_db_location" VALUES(36659,NULL,'Farmington, MI 48332',14940,222,NULL,40,21426,0);
INSERT INTO "django_geo_db_location" VALUES(36660,NULL,'Farmington, MI 48333',14940,222,NULL,40,21427,0);
INSERT INTO "django_geo_db_location" VALUES(36661,NULL,'Farmington, MI 48334',14940,222,NULL,40,21428,0);
INSERT INTO "django_geo_db_location" VALUES(36662,NULL,'Farmington, MI 48335',14940,222,NULL,40,21429,0);
INSERT INTO "django_geo_db_location" VALUES(36663,NULL,'Farmington, MI 48336',14940,222,NULL,40,21430,0);
INSERT INTO "django_geo_db_location" VALUES(36664,NULL,'Pontiac, MI',14941,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36665,NULL,'Pontiac, MI 48340',14941,222,NULL,40,21431,0);
INSERT INTO "django_geo_db_location" VALUES(36666,NULL,'Pontiac, MI 48341',14941,222,NULL,40,21432,0);
INSERT INTO "django_geo_db_location" VALUES(36667,NULL,'Pontiac, MI 48342',14941,222,NULL,40,21433,0);
INSERT INTO "django_geo_db_location" VALUES(36668,NULL,'Pontiac, MI 48343',14941,222,NULL,40,21434,0);
INSERT INTO "django_geo_db_location" VALUES(36669,NULL,'Clarkston, MI',14942,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36670,NULL,'Clarkston, MI 48346',14942,222,NULL,40,21435,0);
INSERT INTO "django_geo_db_location" VALUES(36671,NULL,'Clarkston, MI 48347',14942,222,NULL,40,21436,0);
INSERT INTO "django_geo_db_location" VALUES(36672,NULL,'Clarkston, MI 48348',14942,222,NULL,40,21437,0);
INSERT INTO "django_geo_db_location" VALUES(36673,NULL,'Davisburg, MI',14943,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36674,NULL,'Davisburg, MI 48350',14943,222,NULL,40,21438,0);
INSERT INTO "django_geo_db_location" VALUES(36675,NULL,'Hartland, MI',14944,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36676,NULL,'Hartland, MI 48353',14944,222,NULL,40,21439,0);
INSERT INTO "django_geo_db_location" VALUES(36677,NULL,'Highland, MI',14945,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36678,NULL,'Highland, MI 48356',14945,222,NULL,40,21440,0);
INSERT INTO "django_geo_db_location" VALUES(36679,NULL,'Highland, MI 48357',14945,222,NULL,40,21441,0);
INSERT INTO "django_geo_db_location" VALUES(36680,NULL,'Lake Orion, MI',14946,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36681,NULL,'Lake Orion, MI 48359',14946,222,NULL,40,21442,0);
INSERT INTO "django_geo_db_location" VALUES(36682,NULL,'Lake Orion, MI 48360',14946,222,NULL,40,21443,0);
INSERT INTO "django_geo_db_location" VALUES(36683,NULL,'Lake Orion, MI 48361',14946,222,NULL,40,21444,0);
INSERT INTO "django_geo_db_location" VALUES(36684,NULL,'Lake Orion, MI 48362',14946,222,NULL,40,21445,0);
INSERT INTO "django_geo_db_location" VALUES(36685,NULL,'Oakland, MI',14947,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36686,NULL,'Oakland, MI 48363',14947,222,NULL,40,21446,0);
INSERT INTO "django_geo_db_location" VALUES(36687,NULL,'Lakeville, MI',14948,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36688,NULL,'Lakeville, MI 48366',14948,222,NULL,40,21447,0);
INSERT INTO "django_geo_db_location" VALUES(36689,NULL,'Leonard, MI',14949,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36690,NULL,'Leonard, MI 48367',14949,222,NULL,40,21448,0);
INSERT INTO "django_geo_db_location" VALUES(36691,NULL,'Oxford, MI',14950,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36692,NULL,'Oxford, MI 48370',14950,222,NULL,40,21449,0);
INSERT INTO "django_geo_db_location" VALUES(36693,NULL,'Oxford, MI 48371',14950,222,NULL,40,21450,0);
INSERT INTO "django_geo_db_location" VALUES(36694,NULL,'Novi, MI',14951,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36695,NULL,'Novi, MI 48374',14951,222,NULL,40,21451,0);
INSERT INTO "django_geo_db_location" VALUES(36696,NULL,'Novi, MI 48375',14951,222,NULL,40,21452,0);
INSERT INTO "django_geo_db_location" VALUES(36697,NULL,'Novi, MI 48376',14951,222,NULL,40,21453,0);
INSERT INTO "django_geo_db_location" VALUES(36698,NULL,'Novi, MI 48377',14951,222,NULL,40,21454,0);
INSERT INTO "django_geo_db_location" VALUES(36699,NULL,'Milford, MI',14952,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36700,NULL,'Milford, MI 48380',14952,222,NULL,40,21455,0);
INSERT INTO "django_geo_db_location" VALUES(36701,NULL,'Milford, MI 48381',14952,222,NULL,40,21456,0);
INSERT INTO "django_geo_db_location" VALUES(36702,NULL,'Commerce Township, MI',14953,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36703,NULL,'Commerce Township, MI 48382',14953,222,NULL,40,21457,0);
INSERT INTO "django_geo_db_location" VALUES(36704,NULL,'White Lake, MI',14954,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36705,NULL,'White Lake, MI 48383',14954,222,NULL,40,21458,0);
INSERT INTO "django_geo_db_location" VALUES(36706,NULL,'White Lake, MI 48386',14954,222,NULL,40,21459,0);
INSERT INTO "django_geo_db_location" VALUES(36707,NULL,'Union Lake, MI',14955,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36708,NULL,'Union Lake, MI 48387',14955,222,NULL,40,21460,0);
INSERT INTO "django_geo_db_location" VALUES(36709,NULL,'Walled Lake, MI',14956,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36710,NULL,'Walled Lake, MI 48390',14956,222,NULL,40,21461,0);
INSERT INTO "django_geo_db_location" VALUES(36711,NULL,'Walled Lake, MI 48391',14956,222,NULL,40,21462,0);
INSERT INTO "django_geo_db_location" VALUES(36712,NULL,'Wixom, MI',14957,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36713,NULL,'Wixom, MI 48393',14957,222,NULL,40,21463,0);
INSERT INTO "django_geo_db_location" VALUES(36714,NULL,'Wixom, MI 48396',14957,222,NULL,40,21464,0);
INSERT INTO "django_geo_db_location" VALUES(36715,NULL,'Warren, MI 48397',14858,222,NULL,40,21465,0);
INSERT INTO "django_geo_db_location" VALUES(36716,NULL,'Clawson, MI 48398',14820,222,NULL,40,21466,0);
INSERT INTO "django_geo_db_location" VALUES(36717,NULL,'Applegate, MI',14958,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36718,NULL,'Applegate, MI 48401',14958,222,NULL,40,21467,0);
INSERT INTO "django_geo_db_location" VALUES(36719,NULL,'Argyle, MI',14959,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36720,NULL,'Argyle, MI 48410',14959,222,NULL,40,21468,0);
INSERT INTO "django_geo_db_location" VALUES(36721,NULL,'Atlas, MI',14960,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36722,NULL,'Atlas, MI 48411',14960,222,NULL,40,21469,0);
INSERT INTO "django_geo_db_location" VALUES(36723,NULL,'Attica, MI',14961,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36724,NULL,'Attica, MI 48412',14961,222,NULL,40,21470,0);
INSERT INTO "django_geo_db_location" VALUES(36725,NULL,'Bad Axe, MI',14962,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36726,NULL,'Bad Axe, MI 48413',14962,222,NULL,40,21471,0);
INSERT INTO "django_geo_db_location" VALUES(36727,NULL,'Bancroft, MI',14963,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36728,NULL,'Bancroft, MI 48414',14963,222,NULL,40,21472,0);
INSERT INTO "django_geo_db_location" VALUES(36729,NULL,'Birch Run, MI',14964,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36730,NULL,'Birch Run, MI 48415',14964,222,NULL,40,21473,0);
INSERT INTO "django_geo_db_location" VALUES(36731,NULL,'Brown City, MI',14965,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36732,NULL,'Brown City, MI 48416',14965,222,NULL,40,21474,0);
INSERT INTO "django_geo_db_location" VALUES(36733,NULL,'Burt, MI',14966,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36734,NULL,'Burt, MI 48417',14966,222,NULL,40,21475,0);
INSERT INTO "django_geo_db_location" VALUES(36735,NULL,'Byron, MI',14967,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36736,NULL,'Byron, MI 48418',14967,222,NULL,40,21476,0);
INSERT INTO "django_geo_db_location" VALUES(36737,NULL,'Carsonville, MI',14968,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36738,NULL,'Carsonville, MI 48419',14968,222,NULL,40,21477,0);
INSERT INTO "django_geo_db_location" VALUES(36739,NULL,'Clio, MI',14969,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36740,NULL,'Clio, MI 48420',14969,222,NULL,40,21478,0);
INSERT INTO "django_geo_db_location" VALUES(36741,NULL,'Columbiaville, MI',14970,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36742,NULL,'Columbiaville, MI 48421',14970,222,NULL,40,21479,0);
INSERT INTO "django_geo_db_location" VALUES(36743,NULL,'Croswell, MI',14971,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36744,NULL,'Croswell, MI 48422',14971,222,NULL,40,21480,0);
INSERT INTO "django_geo_db_location" VALUES(36745,NULL,'Davison, MI',14972,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36746,NULL,'Davison, MI 48423',14972,222,NULL,40,21481,0);
INSERT INTO "django_geo_db_location" VALUES(36747,NULL,'Decker, MI',14973,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36748,NULL,'Decker, MI 48426',14973,222,NULL,40,21482,0);
INSERT INTO "django_geo_db_location" VALUES(36749,NULL,'Deckerville, MI',14974,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36750,NULL,'Deckerville, MI 48427',14974,222,NULL,40,21483,0);
INSERT INTO "django_geo_db_location" VALUES(36751,NULL,'Dryden, MI',14975,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36752,NULL,'Dryden, MI 48428',14975,222,NULL,40,21484,0);
INSERT INTO "django_geo_db_location" VALUES(36753,NULL,'Durand, MI',14976,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36754,NULL,'Durand, MI 48429',14976,222,NULL,40,21485,0);
INSERT INTO "django_geo_db_location" VALUES(36755,NULL,'Fenton, MI',14977,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36756,NULL,'Fenton, MI 48430',14977,222,NULL,40,21486,0);
INSERT INTO "django_geo_db_location" VALUES(36757,NULL,'Filion, MI',14978,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36758,NULL,'Filion, MI 48432',14978,222,NULL,40,21487,0);
INSERT INTO "django_geo_db_location" VALUES(36759,NULL,'Flushing, MI',14979,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36760,NULL,'Flushing, MI 48433',14979,222,NULL,40,21488,0);
INSERT INTO "django_geo_db_location" VALUES(36761,NULL,'Forestville, MI',14980,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36762,NULL,'Forestville, MI 48434',14980,222,NULL,40,21489,0);
INSERT INTO "django_geo_db_location" VALUES(36763,NULL,'Fostoria, MI',14981,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36764,NULL,'Fostoria, MI 48435',14981,222,NULL,40,21490,0);
INSERT INTO "django_geo_db_location" VALUES(36765,NULL,'Gaines, MI',14982,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36766,NULL,'Gaines, MI 48436',14982,222,NULL,40,21491,0);
INSERT INTO "django_geo_db_location" VALUES(36767,NULL,'Genesee, MI',14983,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36768,NULL,'Genesee, MI 48437',14983,222,NULL,40,21492,0);
INSERT INTO "django_geo_db_location" VALUES(36769,NULL,'Goodrich, MI',14984,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36770,NULL,'Goodrich, MI 48438',14984,222,NULL,40,21493,0);
INSERT INTO "django_geo_db_location" VALUES(36771,NULL,'Grand Blanc, MI',14985,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36772,NULL,'Grand Blanc, MI 48439',14985,222,NULL,40,21494,0);
INSERT INTO "django_geo_db_location" VALUES(36773,NULL,'Hadley, MI',14986,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36774,NULL,'Hadley, MI 48440',14986,222,NULL,40,21495,0);
INSERT INTO "django_geo_db_location" VALUES(36775,NULL,'Harbor Beach, MI',14987,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36776,NULL,'Harbor Beach, MI 48441',14987,222,NULL,40,21496,0);
INSERT INTO "django_geo_db_location" VALUES(36777,NULL,'Holly, MI',14988,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36778,NULL,'Holly, MI 48442',14988,222,NULL,40,21497,0);
INSERT INTO "django_geo_db_location" VALUES(36779,NULL,'Imlay City, MI',14989,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36780,NULL,'Imlay City, MI 48444',14989,222,NULL,40,21498,0);
INSERT INTO "django_geo_db_location" VALUES(36781,NULL,'Kinde, MI',14990,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36782,NULL,'Kinde, MI 48445',14990,222,NULL,40,21499,0);
INSERT INTO "django_geo_db_location" VALUES(36783,NULL,'Lapeer, MI',14991,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36784,NULL,'Lapeer, MI 48446',14991,222,NULL,40,21500,0);
INSERT INTO "django_geo_db_location" VALUES(36785,NULL,'Sciota, MI',14992,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36786,NULL,'Sciota, MI 48448',14992,222,NULL,40,21501,0);
INSERT INTO "django_geo_db_location" VALUES(36787,NULL,'Lennon, MI',14993,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36788,NULL,'Lennon, MI 48449',14993,222,NULL,40,21502,0);
INSERT INTO "django_geo_db_location" VALUES(36789,NULL,'Lexington, MI',14994,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36790,NULL,'Lexington, MI 48450',14994,222,NULL,40,21503,0);
INSERT INTO "django_geo_db_location" VALUES(36791,NULL,'Linden, MI',14995,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36792,NULL,'Linden, MI 48451',14995,222,NULL,40,21504,0);
INSERT INTO "django_geo_db_location" VALUES(36793,NULL,'Marlette, MI',14996,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36794,NULL,'Marlette, MI 48453',14996,222,NULL,40,21505,0);
INSERT INTO "django_geo_db_location" VALUES(36795,NULL,'Melvin, MI',14997,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36796,NULL,'Melvin, MI 48454',14997,222,NULL,40,21506,0);
INSERT INTO "django_geo_db_location" VALUES(36797,NULL,'Metamora, MI',14998,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36798,NULL,'Metamora, MI 48455',14998,222,NULL,40,21507,0);
INSERT INTO "django_geo_db_location" VALUES(36799,NULL,'Minden City, MI',14999,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36800,NULL,'Minden City, MI 48456',14999,222,NULL,40,21508,0);
INSERT INTO "django_geo_db_location" VALUES(36801,NULL,'Montrose, MI',15000,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36802,NULL,'Montrose, MI 48457',15000,222,NULL,40,21509,0);
INSERT INTO "django_geo_db_location" VALUES(36803,NULL,'Mount Morris, MI',15001,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36804,NULL,'Mount Morris, MI 48458',15001,222,NULL,40,21510,0);
INSERT INTO "django_geo_db_location" VALUES(36805,NULL,'New Lothrop, MI',15002,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36806,NULL,'New Lothrop, MI 48460',15002,222,NULL,40,21511,0);
INSERT INTO "django_geo_db_location" VALUES(36807,NULL,'North Branch, MI',15003,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36808,NULL,'North Branch, MI 48461',15003,222,NULL,40,21512,0);
INSERT INTO "django_geo_db_location" VALUES(36809,NULL,'Ortonville, MI',15004,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36810,NULL,'Ortonville, MI 48462',15004,222,NULL,40,21513,0);
INSERT INTO "django_geo_db_location" VALUES(36811,NULL,'Otisville, MI',15005,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36812,NULL,'Otisville, MI 48463',15005,222,NULL,40,21514,0);
INSERT INTO "django_geo_db_location" VALUES(36813,NULL,'Otter Lake, MI',15006,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36814,NULL,'Otter Lake, MI 48464',15006,222,NULL,40,21515,0);
INSERT INTO "django_geo_db_location" VALUES(36815,NULL,'Palms, MI',15007,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36816,NULL,'Palms, MI 48465',15007,222,NULL,40,21516,0);
INSERT INTO "django_geo_db_location" VALUES(36817,NULL,'Peck, MI',15008,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36818,NULL,'Peck, MI 48466',15008,222,NULL,40,21517,0);
INSERT INTO "django_geo_db_location" VALUES(36819,NULL,'Port Austin, MI',15009,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36820,NULL,'Port Austin, MI 48467',15009,222,NULL,40,21518,0);
INSERT INTO "django_geo_db_location" VALUES(36821,NULL,'Port Hope, MI',15010,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36822,NULL,'Port Hope, MI 48468',15010,222,NULL,40,21519,0);
INSERT INTO "django_geo_db_location" VALUES(36823,NULL,'Port Sanilac, MI',15011,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36824,NULL,'Port Sanilac, MI 48469',15011,222,NULL,40,21520,0);
INSERT INTO "django_geo_db_location" VALUES(36825,NULL,'Ruth, MI',15012,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36826,NULL,'Ruth, MI 48470',15012,222,NULL,40,21521,0);
INSERT INTO "django_geo_db_location" VALUES(36827,NULL,'Sandusky, MI',15013,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36828,NULL,'Sandusky, MI 48471',15013,222,NULL,40,21522,0);
INSERT INTO "django_geo_db_location" VALUES(36829,NULL,'Snover, MI',15014,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36830,NULL,'Snover, MI 48472',15014,222,NULL,40,21523,0);
INSERT INTO "django_geo_db_location" VALUES(36831,NULL,'Swartz Creek, MI',15015,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36832,NULL,'Swartz Creek, MI 48473',15015,222,NULL,40,21524,0);
INSERT INTO "django_geo_db_location" VALUES(36833,NULL,'Ubly, MI',15016,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36834,NULL,'Ubly, MI 48475',15016,222,NULL,40,21525,0);
INSERT INTO "django_geo_db_location" VALUES(36835,NULL,'Vernon, MI',15017,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36836,NULL,'Vernon, MI 48476',15017,222,NULL,40,21526,0);
INSERT INTO "django_geo_db_location" VALUES(36837,NULL,'Flint, MI',15018,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36838,NULL,'Flint, MI 48501',15018,222,NULL,40,21527,0);
INSERT INTO "django_geo_db_location" VALUES(36839,NULL,'Flint, MI 48502',15018,222,NULL,40,21528,0);
INSERT INTO "django_geo_db_location" VALUES(36840,NULL,'Flint, MI 48503',15018,222,NULL,40,21529,0);
INSERT INTO "django_geo_db_location" VALUES(36841,NULL,'Flint, MI 48504',15018,222,NULL,40,21530,0);
INSERT INTO "django_geo_db_location" VALUES(36842,NULL,'Flint, MI 48505',15018,222,NULL,40,21531,0);
INSERT INTO "django_geo_db_location" VALUES(36843,NULL,'Flint, MI 48506',15018,222,NULL,40,21532,0);
INSERT INTO "django_geo_db_location" VALUES(36844,NULL,'Flint, MI 48507',15018,222,NULL,40,21533,0);
INSERT INTO "django_geo_db_location" VALUES(36845,NULL,'Burton, MI',15019,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36846,NULL,'Burton, MI 48509',15019,222,NULL,40,21534,0);
INSERT INTO "django_geo_db_location" VALUES(36847,NULL,'Burton, MI 48519',15019,222,NULL,40,21535,0);
INSERT INTO "django_geo_db_location" VALUES(36848,NULL,'Burton, MI 48529',15019,222,NULL,40,21536,0);
INSERT INTO "django_geo_db_location" VALUES(36849,NULL,'Flint, MI 48531',15018,222,NULL,40,21537,0);
INSERT INTO "django_geo_db_location" VALUES(36850,NULL,'Flint, MI 48532',15018,222,NULL,40,21538,0);
INSERT INTO "django_geo_db_location" VALUES(36851,NULL,'Flint, MI 48550',15018,222,NULL,40,21539,0);
INSERT INTO "django_geo_db_location" VALUES(36852,NULL,'Flint, MI 48551',15018,222,NULL,40,21540,0);
INSERT INTO "django_geo_db_location" VALUES(36853,NULL,'Flint, MI 48552',15018,222,NULL,40,21541,0);
INSERT INTO "django_geo_db_location" VALUES(36854,NULL,'Flint, MI 48553',15018,222,NULL,40,21542,0);
INSERT INTO "django_geo_db_location" VALUES(36855,NULL,'Flint, MI 48554',15018,222,NULL,40,21543,0);
INSERT INTO "django_geo_db_location" VALUES(36856,NULL,'Flint, MI 48555',15018,222,NULL,40,21544,0);
INSERT INTO "django_geo_db_location" VALUES(36857,NULL,'Flint, MI 48556',15018,222,NULL,40,21545,0);
INSERT INTO "django_geo_db_location" VALUES(36858,NULL,'Flint, MI 48557',15018,222,NULL,40,21546,0);
INSERT INTO "django_geo_db_location" VALUES(36859,NULL,'Flint, MI 48559',15018,222,NULL,40,21547,0);
INSERT INTO "django_geo_db_location" VALUES(36860,NULL,'Markey, MI',15020,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36861,NULL,'Markey, MI 48563',15020,222,NULL,40,21548,0);
INSERT INTO "django_geo_db_location" VALUES(36862,NULL,'Flint, MI 48567',15018,222,NULL,40,21549,0);
INSERT INTO "django_geo_db_location" VALUES(36863,NULL,'Saginaw, MI',15021,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36864,NULL,'Saginaw, MI 48601',15021,222,NULL,40,21550,0);
INSERT INTO "django_geo_db_location" VALUES(36865,NULL,'Saginaw, MI 48602',15021,222,NULL,40,21551,0);
INSERT INTO "django_geo_db_location" VALUES(36866,NULL,'Saginaw, MI 48603',15021,222,NULL,40,21552,0);
INSERT INTO "django_geo_db_location" VALUES(36867,NULL,'Saginaw, MI 48604',15021,222,NULL,40,21553,0);
INSERT INTO "django_geo_db_location" VALUES(36868,NULL,'Saginaw, MI 48605',15021,222,NULL,40,21554,0);
INSERT INTO "django_geo_db_location" VALUES(36869,NULL,'Saginaw, MI 48606',15021,222,NULL,40,21555,0);
INSERT INTO "django_geo_db_location" VALUES(36870,NULL,'Saginaw, MI 48607',15021,222,NULL,40,21556,0);
INSERT INTO "django_geo_db_location" VALUES(36871,NULL,'Saginaw, MI 48608',15021,222,NULL,40,21557,0);
INSERT INTO "django_geo_db_location" VALUES(36872,NULL,'Saginaw, MI 48609',15021,222,NULL,40,21558,0);
INSERT INTO "django_geo_db_location" VALUES(36873,NULL,'Alger, MI',15022,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36874,NULL,'Alger, MI 48610',15022,222,NULL,40,21559,0);
INSERT INTO "django_geo_db_location" VALUES(36875,NULL,'Auburn, MI',15023,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36876,NULL,'Auburn, MI 48611',15023,222,NULL,40,21560,0);
INSERT INTO "django_geo_db_location" VALUES(36877,NULL,'Beaverton, MI',15024,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36878,NULL,'Beaverton, MI 48612',15024,222,NULL,40,21561,0);
INSERT INTO "django_geo_db_location" VALUES(36879,NULL,'Bentley, MI',15025,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36880,NULL,'Bentley, MI 48613',15025,222,NULL,40,21562,0);
INSERT INTO "django_geo_db_location" VALUES(36881,NULL,'Brant, MI',15026,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36882,NULL,'Brant, MI 48614',15026,222,NULL,40,21563,0);
INSERT INTO "django_geo_db_location" VALUES(36883,NULL,'Breckenridge, MI',15027,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36884,NULL,'Breckenridge, MI 48615',15027,222,NULL,40,21564,0);
INSERT INTO "django_geo_db_location" VALUES(36885,NULL,'Chesaning, MI',15028,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36886,NULL,'Chesaning, MI 48616',15028,222,NULL,40,21565,0);
INSERT INTO "django_geo_db_location" VALUES(36887,NULL,'Clare, MI',15029,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36888,NULL,'Clare, MI 48617',15029,222,NULL,40,21566,0);
INSERT INTO "django_geo_db_location" VALUES(36889,NULL,'Coleman, MI',15030,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36890,NULL,'Coleman, MI 48618',15030,222,NULL,40,21567,0);
INSERT INTO "django_geo_db_location" VALUES(36891,NULL,'Comins, MI',15031,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36892,NULL,'Comins, MI 48619',15031,222,NULL,40,21568,0);
INSERT INTO "django_geo_db_location" VALUES(36893,NULL,'Edenville, MI',15032,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36894,NULL,'Edenville, MI 48620',15032,222,NULL,40,21569,0);
INSERT INTO "django_geo_db_location" VALUES(36895,NULL,'Fairview, MI',15033,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36896,NULL,'Fairview, MI 48621',15033,222,NULL,40,21570,0);
INSERT INTO "django_geo_db_location" VALUES(36897,NULL,'Farwell, MI',15034,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36898,NULL,'Farwell, MI 48622',15034,222,NULL,40,21571,0);
INSERT INTO "django_geo_db_location" VALUES(36899,NULL,'Freeland, MI',15035,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36900,NULL,'Freeland, MI 48623',15035,222,NULL,40,21572,0);
INSERT INTO "django_geo_db_location" VALUES(36901,NULL,'Gladwin, MI',15036,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36902,NULL,'Gladwin, MI 48624',15036,222,NULL,40,21573,0);
INSERT INTO "django_geo_db_location" VALUES(36903,NULL,'Harrison, MI',15037,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36904,NULL,'Harrison, MI 48625',15037,222,NULL,40,21574,0);
INSERT INTO "django_geo_db_location" VALUES(36905,NULL,'Hemlock, MI',15038,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36906,NULL,'Hemlock, MI 48626',15038,222,NULL,40,21575,0);
INSERT INTO "django_geo_db_location" VALUES(36907,NULL,'Higgins Lake, MI',15039,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36908,NULL,'Higgins Lake, MI 48627',15039,222,NULL,40,21576,0);
INSERT INTO "django_geo_db_location" VALUES(36909,NULL,'Hope, MI',15040,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36910,NULL,'Hope, MI 48628',15040,222,NULL,40,21577,0);
INSERT INTO "django_geo_db_location" VALUES(36911,NULL,'Houghton Lake, MI',15041,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36912,NULL,'Houghton Lake, MI 48629',15041,222,NULL,40,21578,0);
INSERT INTO "django_geo_db_location" VALUES(36913,NULL,'Houghton Lake Heights, MI',15042,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36914,NULL,'Houghton Lake Heights, MI 48630',15042,222,NULL,40,21579,0);
INSERT INTO "django_geo_db_location" VALUES(36915,NULL,'Kawkawlin, MI',15043,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36916,NULL,'Kawkawlin, MI 48631',15043,222,NULL,40,21580,0);
INSERT INTO "django_geo_db_location" VALUES(36917,NULL,'Lake, MI',15044,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36918,NULL,'Lake, MI 48632',15044,222,NULL,40,21581,0);
INSERT INTO "django_geo_db_location" VALUES(36919,NULL,'Lake George, MI',15045,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36920,NULL,'Lake George, MI 48633',15045,222,NULL,40,21582,0);
INSERT INTO "django_geo_db_location" VALUES(36921,NULL,'Linwood, MI',15046,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36922,NULL,'Linwood, MI 48634',15046,222,NULL,40,21583,0);
INSERT INTO "django_geo_db_location" VALUES(36923,NULL,'Lupton, MI',15047,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36924,NULL,'Lupton, MI 48635',15047,222,NULL,40,21584,0);
INSERT INTO "django_geo_db_location" VALUES(36925,NULL,'Luzerne, MI',15048,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36926,NULL,'Luzerne, MI 48636',15048,222,NULL,40,21585,0);
INSERT INTO "django_geo_db_location" VALUES(36927,NULL,'Merrill, MI',15049,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36928,NULL,'Merrill, MI 48637',15049,222,NULL,40,21586,0);
INSERT INTO "django_geo_db_location" VALUES(36929,NULL,'Midland, MI',15050,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36930,NULL,'Midland, MI 48640',15050,222,NULL,40,21587,0);
INSERT INTO "django_geo_db_location" VALUES(36931,NULL,'Midland, MI 48641',15050,222,NULL,40,21588,0);
INSERT INTO "django_geo_db_location" VALUES(36932,NULL,'Midland, MI 48642',15050,222,NULL,40,21589,0);
INSERT INTO "django_geo_db_location" VALUES(36933,NULL,'Mio, MI',15051,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36934,NULL,'Mio, MI 48647',15051,222,NULL,40,21590,0);
INSERT INTO "django_geo_db_location" VALUES(36935,NULL,'Oakley, MI',15052,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36936,NULL,'Oakley, MI 48649',15052,222,NULL,40,21591,0);
INSERT INTO "django_geo_db_location" VALUES(36937,NULL,'Pinconning, MI',15053,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36938,NULL,'Pinconning, MI 48650',15053,222,NULL,40,21592,0);
INSERT INTO "django_geo_db_location" VALUES(36939,NULL,'Prudenville, MI',15054,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36940,NULL,'Prudenville, MI 48651',15054,222,NULL,40,21593,0);
INSERT INTO "django_geo_db_location" VALUES(36941,NULL,'Rhodes, MI',15055,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36942,NULL,'Rhodes, MI 48652',15055,222,NULL,40,21594,0);
INSERT INTO "django_geo_db_location" VALUES(36943,NULL,'Roscommon, MI',15056,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36944,NULL,'Roscommon, MI 48653',15056,222,NULL,40,21595,0);
INSERT INTO "django_geo_db_location" VALUES(36945,NULL,'Rose City, MI',15057,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36946,NULL,'Rose City, MI 48654',15057,222,NULL,40,21596,0);
INSERT INTO "django_geo_db_location" VALUES(36947,NULL,'Saint Charles, MI',15058,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36948,NULL,'Saint Charles, MI 48655',15058,222,NULL,40,21597,0);
INSERT INTO "django_geo_db_location" VALUES(36949,NULL,'Saint Helen, MI',15059,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36950,NULL,'Saint Helen, MI 48656',15059,222,NULL,40,21598,0);
INSERT INTO "django_geo_db_location" VALUES(36951,NULL,'Sanford, MI',15060,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36952,NULL,'Sanford, MI 48657',15060,222,NULL,40,21599,0);
INSERT INTO "django_geo_db_location" VALUES(36953,NULL,'Standish, MI',15061,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36954,NULL,'Standish, MI 48658',15061,222,NULL,40,21600,0);
INSERT INTO "django_geo_db_location" VALUES(36955,NULL,'Sterling, MI',15062,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36956,NULL,'Sterling, MI 48659',15062,222,NULL,40,21601,0);
INSERT INTO "django_geo_db_location" VALUES(36957,NULL,'West Branch, MI',15063,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36958,NULL,'West Branch, MI 48661',15063,222,NULL,40,21602,0);
INSERT INTO "django_geo_db_location" VALUES(36959,NULL,'Wheeler, MI',15064,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36960,NULL,'Wheeler, MI 48662',15064,222,NULL,40,21603,0);
INSERT INTO "django_geo_db_location" VALUES(36961,NULL,'Saginaw, MI 48663',15021,222,NULL,40,21604,0);
INSERT INTO "django_geo_db_location" VALUES(36962,NULL,'Midland, MI 48667',15050,222,NULL,40,21605,0);
INSERT INTO "django_geo_db_location" VALUES(36963,NULL,'Midland, MI 48670',15050,222,NULL,40,21606,0);
INSERT INTO "django_geo_db_location" VALUES(36964,NULL,'Midland, MI 48674',15050,222,NULL,40,21607,0);
INSERT INTO "django_geo_db_location" VALUES(36965,NULL,'Midland, MI 48686',15050,222,NULL,40,21608,0);
INSERT INTO "django_geo_db_location" VALUES(36966,NULL,'Akron, MI',15065,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36967,NULL,'Akron, MI 48701',15065,222,NULL,40,21609,0);
INSERT INTO "django_geo_db_location" VALUES(36968,NULL,'Au Gres, MI',15066,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36969,NULL,'Au Gres, MI 48703',15066,222,NULL,40,21610,0);
INSERT INTO "django_geo_db_location" VALUES(36970,NULL,'Barton City, MI',15067,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36971,NULL,'Barton City, MI 48705',15067,222,NULL,40,21611,0);
INSERT INTO "django_geo_db_location" VALUES(36972,NULL,'Bay City, MI',15068,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36973,NULL,'Bay City, MI 48706',15068,222,NULL,40,21612,0);
INSERT INTO "django_geo_db_location" VALUES(36974,NULL,'Bay City, MI 48707',15068,222,NULL,40,21613,0);
INSERT INTO "django_geo_db_location" VALUES(36975,NULL,'Bay City, MI 48708',15068,222,NULL,40,21614,0);
INSERT INTO "django_geo_db_location" VALUES(36976,NULL,'University Center, MI',15069,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36977,NULL,'University Center, MI 48710',15069,222,NULL,40,21615,0);
INSERT INTO "django_geo_db_location" VALUES(36978,NULL,'Bay Port, MI',15070,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36979,NULL,'Bay Port, MI 48720',15070,222,NULL,40,21616,0);
INSERT INTO "django_geo_db_location" VALUES(36980,NULL,'Black River, MI',15071,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36981,NULL,'Black River, MI 48721',15071,222,NULL,40,21617,0);
INSERT INTO "django_geo_db_location" VALUES(36982,NULL,'Bridgeport, MI',15072,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36983,NULL,'Bridgeport, MI 48722',15072,222,NULL,40,21618,0);
INSERT INTO "django_geo_db_location" VALUES(36984,NULL,'Caro, MI',15073,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36985,NULL,'Caro, MI 48723',15073,222,NULL,40,21619,0);
INSERT INTO "django_geo_db_location" VALUES(36986,NULL,'Carrollton, MI',15074,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36987,NULL,'Carrollton, MI 48724',15074,222,NULL,40,21620,0);
INSERT INTO "django_geo_db_location" VALUES(36988,NULL,'Caseville, MI',15075,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36989,NULL,'Caseville, MI 48725',15075,222,NULL,40,21621,0);
INSERT INTO "django_geo_db_location" VALUES(36990,NULL,'Cass City, MI',15076,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36991,NULL,'Cass City, MI 48726',15076,222,NULL,40,21622,0);
INSERT INTO "django_geo_db_location" VALUES(36992,NULL,'Clifford, MI',15077,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36993,NULL,'Clifford, MI 48727',15077,222,NULL,40,21623,0);
INSERT INTO "django_geo_db_location" VALUES(36994,NULL,'Curran, MI',15078,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36995,NULL,'Curran, MI 48728',15078,222,NULL,40,21624,0);
INSERT INTO "django_geo_db_location" VALUES(36996,NULL,'Deford, MI',15079,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36997,NULL,'Deford, MI 48729',15079,222,NULL,40,21625,0);
INSERT INTO "django_geo_db_location" VALUES(36998,NULL,'East Tawas, MI',15080,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(36999,NULL,'East Tawas, MI 48730',15080,222,NULL,40,21626,0);
INSERT INTO "django_geo_db_location" VALUES(37000,NULL,'Elkton, MI',15081,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37001,NULL,'Elkton, MI 48731',15081,222,NULL,40,21627,0);
INSERT INTO "django_geo_db_location" VALUES(37002,NULL,'Essexville, MI',15082,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37003,NULL,'Essexville, MI 48732',15082,222,NULL,40,21628,0);
INSERT INTO "django_geo_db_location" VALUES(37004,NULL,'Fairgrove, MI',15083,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37005,NULL,'Fairgrove, MI 48733',15083,222,NULL,40,21629,0);
INSERT INTO "django_geo_db_location" VALUES(37006,NULL,'Frankenmuth, MI',15084,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37007,NULL,'Frankenmuth, MI 48734',15084,222,NULL,40,21630,0);
INSERT INTO "django_geo_db_location" VALUES(37008,NULL,'Gagetown, MI',15085,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37009,NULL,'Gagetown, MI 48735',15085,222,NULL,40,21631,0);
INSERT INTO "django_geo_db_location" VALUES(37010,NULL,'Gilford, MI',15086,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37011,NULL,'Gilford, MI 48736',15086,222,NULL,40,21632,0);
INSERT INTO "django_geo_db_location" VALUES(37012,NULL,'Glennie, MI',15087,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37013,NULL,'Glennie, MI 48737',15087,222,NULL,40,21633,0);
INSERT INTO "django_geo_db_location" VALUES(37014,NULL,'Greenbush, MI',15088,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37015,NULL,'Greenbush, MI 48738',15088,222,NULL,40,21634,0);
INSERT INTO "django_geo_db_location" VALUES(37016,NULL,'Hale, MI',15089,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37017,NULL,'Hale, MI 48739',15089,222,NULL,40,21635,0);
INSERT INTO "django_geo_db_location" VALUES(37018,NULL,'Harrisville, MI',15090,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37019,NULL,'Harrisville, MI 48740',15090,222,NULL,40,21636,0);
INSERT INTO "django_geo_db_location" VALUES(37020,NULL,'Kingston, MI',15091,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37021,NULL,'Kingston, MI 48741',15091,222,NULL,40,21637,0);
INSERT INTO "django_geo_db_location" VALUES(37022,NULL,'Lincoln, MI',15092,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37023,NULL,'Lincoln, MI 48742',15092,222,NULL,40,21638,0);
INSERT INTO "django_geo_db_location" VALUES(37024,NULL,'Long Lake, MI',15093,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37025,NULL,'Long Lake, MI 48743',15093,222,NULL,40,21639,0);
INSERT INTO "django_geo_db_location" VALUES(37026,NULL,'Mayville, MI',15094,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37027,NULL,'Mayville, MI 48744',15094,222,NULL,40,21640,0);
INSERT INTO "django_geo_db_location" VALUES(37028,NULL,'Mikado, MI',15095,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37029,NULL,'Mikado, MI 48745',15095,222,NULL,40,21641,0);
INSERT INTO "django_geo_db_location" VALUES(37030,NULL,'Millington, MI',15096,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37031,NULL,'Millington, MI 48746',15096,222,NULL,40,21642,0);
INSERT INTO "django_geo_db_location" VALUES(37032,NULL,'Munger, MI',15097,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37033,NULL,'Munger, MI 48747',15097,222,NULL,40,21643,0);
INSERT INTO "django_geo_db_location" VALUES(37034,NULL,'National City, MI',15098,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37035,NULL,'National City, MI 48748',15098,222,NULL,40,21644,0);
INSERT INTO "django_geo_db_location" VALUES(37036,NULL,'Omer, MI',15099,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37037,NULL,'Omer, MI 48749',15099,222,NULL,40,21645,0);
INSERT INTO "django_geo_db_location" VALUES(37038,NULL,'Oscoda, MI',15100,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37039,NULL,'Oscoda, MI 48750',15100,222,NULL,40,21646,0);
INSERT INTO "django_geo_db_location" VALUES(37040,NULL,'Owendale, MI',15101,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37041,NULL,'Owendale, MI 48754',15101,222,NULL,40,21647,0);
INSERT INTO "django_geo_db_location" VALUES(37042,NULL,'Pigeon, MI',15102,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37043,NULL,'Pigeon, MI 48755',15102,222,NULL,40,21648,0);
INSERT INTO "django_geo_db_location" VALUES(37044,NULL,'Prescott, MI',15103,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37045,NULL,'Prescott, MI 48756',15103,222,NULL,40,21649,0);
INSERT INTO "django_geo_db_location" VALUES(37046,NULL,'Reese, MI',15104,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37047,NULL,'Reese, MI 48757',15104,222,NULL,40,21650,0);
INSERT INTO "django_geo_db_location" VALUES(37048,NULL,'Richville, MI',15105,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37049,NULL,'Richville, MI 48758',15105,222,NULL,40,21651,0);
INSERT INTO "django_geo_db_location" VALUES(37050,NULL,'Sebewaing, MI',15106,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37051,NULL,'Sebewaing, MI 48759',15106,222,NULL,40,21652,0);
INSERT INTO "django_geo_db_location" VALUES(37052,NULL,'Silverwood, MI',15107,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37053,NULL,'Silverwood, MI 48760',15107,222,NULL,40,21653,0);
INSERT INTO "django_geo_db_location" VALUES(37054,NULL,'South Branch, MI',15108,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37055,NULL,'South Branch, MI 48761',15108,222,NULL,40,21654,0);
INSERT INTO "django_geo_db_location" VALUES(37056,NULL,'Spruce, MI',15109,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37057,NULL,'Spruce, MI 48762',15109,222,NULL,40,21655,0);
INSERT INTO "django_geo_db_location" VALUES(37058,NULL,'Tawas City, MI',15110,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37059,NULL,'Tawas City, MI 48763',15110,222,NULL,40,21656,0);
INSERT INTO "django_geo_db_location" VALUES(37060,NULL,'Tawas City, MI 48764',15110,222,NULL,40,21657,0);
INSERT INTO "django_geo_db_location" VALUES(37061,NULL,'Turner, MI',15111,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37062,NULL,'Turner, MI 48765',15111,222,NULL,40,21658,0);
INSERT INTO "django_geo_db_location" VALUES(37063,NULL,'Twining, MI',15112,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37064,NULL,'Twining, MI 48766',15112,222,NULL,40,21659,0);
INSERT INTO "django_geo_db_location" VALUES(37065,NULL,'Unionville, MI',15113,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37066,NULL,'Unionville, MI 48767',15113,222,NULL,40,21660,0);
INSERT INTO "django_geo_db_location" VALUES(37067,NULL,'Vassar, MI',15114,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37068,NULL,'Vassar, MI 48768',15114,222,NULL,40,21661,0);
INSERT INTO "django_geo_db_location" VALUES(37069,NULL,'Tuscola, MI',15115,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37070,NULL,'Tuscola, MI 48769',15115,222,NULL,40,21662,0);
INSERT INTO "django_geo_db_location" VALUES(37071,NULL,'Whittemore, MI',15116,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37072,NULL,'Whittemore, MI 48770',15116,222,NULL,40,21663,0);
INSERT INTO "django_geo_db_location" VALUES(37073,NULL,'Frankenmuth, MI 48787',15084,222,NULL,40,21664,0);
INSERT INTO "django_geo_db_location" VALUES(37074,NULL,'Alma, MI',15117,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37075,NULL,'Alma, MI 48801',15117,222,NULL,40,21665,0);
INSERT INTO "django_geo_db_location" VALUES(37076,NULL,'Alma, MI 48802',15117,222,NULL,40,21666,0);
INSERT INTO "django_geo_db_location" VALUES(37077,NULL,'Troy, MI 48803',14816,222,NULL,40,21667,0);
INSERT INTO "django_geo_db_location" VALUES(37078,NULL,'Mount Pleasant, MI',15118,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37079,NULL,'Mount Pleasant, MI 48804',15118,222,NULL,40,21668,0);
INSERT INTO "django_geo_db_location" VALUES(37080,NULL,'Okemos, MI',15119,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37081,NULL,'Okemos, MI 48805',15119,222,NULL,40,21669,0);
INSERT INTO "django_geo_db_location" VALUES(37082,NULL,'Ashley, MI',15120,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37083,NULL,'Ashley, MI 48806',15120,222,NULL,40,21670,0);
INSERT INTO "django_geo_db_location" VALUES(37084,NULL,'Bannister, MI',15121,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37085,NULL,'Bannister, MI 48807',15121,222,NULL,40,21671,0);
INSERT INTO "django_geo_db_location" VALUES(37086,NULL,'Bath, MI',15122,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37087,NULL,'Bath, MI 48808',15122,222,NULL,40,21672,0);
INSERT INTO "django_geo_db_location" VALUES(37088,NULL,'Belding, MI',15123,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37089,NULL,'Belding, MI 48809',15123,222,NULL,40,21673,0);
INSERT INTO "django_geo_db_location" VALUES(37090,NULL,'Carson City, MI',15124,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37091,NULL,'Carson City, MI 48811',15124,222,NULL,40,21674,0);
INSERT INTO "django_geo_db_location" VALUES(37092,NULL,'Cedar Lake, MI',15125,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37093,NULL,'Cedar Lake, MI 48812',15125,222,NULL,40,21675,0);
INSERT INTO "django_geo_db_location" VALUES(37094,NULL,'Charlotte, MI',15126,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37095,NULL,'Charlotte, MI 48813',15126,222,NULL,40,21676,0);
INSERT INTO "django_geo_db_location" VALUES(37096,NULL,'Clarksville, MI',15127,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37097,NULL,'Clarksville, MI 48815',15127,222,NULL,40,21677,0);
INSERT INTO "django_geo_db_location" VALUES(37098,NULL,'Cohoctah, MI',15128,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37099,NULL,'Cohoctah, MI 48816',15128,222,NULL,40,21678,0);
INSERT INTO "django_geo_db_location" VALUES(37100,NULL,'Corunna, MI',15129,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37101,NULL,'Corunna, MI 48817',15129,222,NULL,40,21679,0);
INSERT INTO "django_geo_db_location" VALUES(37102,NULL,'Crystal, MI',15130,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37103,NULL,'Crystal, MI 48818',15130,222,NULL,40,21680,0);
INSERT INTO "django_geo_db_location" VALUES(37104,NULL,'Dansville, MI',15131,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37105,NULL,'Dansville, MI 48819',15131,222,NULL,40,21681,0);
INSERT INTO "django_geo_db_location" VALUES(37106,NULL,'Dewitt, MI',15132,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37107,NULL,'Dewitt, MI 48820',15132,222,NULL,40,21682,0);
INSERT INTO "django_geo_db_location" VALUES(37108,NULL,'Dimondale, MI',15133,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37109,NULL,'Dimondale, MI 48821',15133,222,NULL,40,21683,0);
INSERT INTO "django_geo_db_location" VALUES(37110,NULL,'Eagle, MI',15134,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37111,NULL,'Eagle, MI 48822',15134,222,NULL,40,21684,0);
INSERT INTO "django_geo_db_location" VALUES(37112,NULL,'East Lansing, MI',15135,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37113,NULL,'East Lansing, MI 48823',15135,222,NULL,40,21685,0);
INSERT INTO "django_geo_db_location" VALUES(37114,NULL,'East Lansing, MI 48824',15135,222,NULL,40,21686,0);
INSERT INTO "django_geo_db_location" VALUES(37115,NULL,'East Lansing, MI 48825',15135,222,NULL,40,21687,0);
INSERT INTO "django_geo_db_location" VALUES(37116,NULL,'East Lansing, MI 48826',15135,222,NULL,40,21688,0);
INSERT INTO "django_geo_db_location" VALUES(37117,NULL,'Eaton Rapids, MI',15136,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37118,NULL,'Eaton Rapids, MI 48827',15136,222,NULL,40,21689,0);
INSERT INTO "django_geo_db_location" VALUES(37119,NULL,'Edmore, MI',15137,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37120,NULL,'Edmore, MI 48829',15137,222,NULL,40,21690,0);
INSERT INTO "django_geo_db_location" VALUES(37121,NULL,'Elm Hall, MI',15138,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37122,NULL,'Elm Hall, MI 48830',15138,222,NULL,40,21691,0);
INSERT INTO "django_geo_db_location" VALUES(37123,NULL,'Elsie, MI',15139,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37124,NULL,'Elsie, MI 48831',15139,222,NULL,40,21692,0);
INSERT INTO "django_geo_db_location" VALUES(37125,NULL,'Elwell, MI',15140,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37126,NULL,'Elwell, MI 48832',15140,222,NULL,40,21693,0);
INSERT INTO "django_geo_db_location" VALUES(37127,NULL,'Eureka, MI',15141,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37128,NULL,'Eureka, MI 48833',15141,222,NULL,40,21694,0);
INSERT INTO "django_geo_db_location" VALUES(37129,NULL,'Fenwick, MI',15142,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37130,NULL,'Fenwick, MI 48834',15142,222,NULL,40,21695,0);
INSERT INTO "django_geo_db_location" VALUES(37131,NULL,'Fowler, MI',15143,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37132,NULL,'Fowler, MI 48835',15143,222,NULL,40,21696,0);
INSERT INTO "django_geo_db_location" VALUES(37133,NULL,'Fowlerville, MI',15144,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37134,NULL,'Fowlerville, MI 48836',15144,222,NULL,40,21697,0);
INSERT INTO "django_geo_db_location" VALUES(37135,NULL,'Grand Ledge, MI',15145,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37136,NULL,'Grand Ledge, MI 48837',15145,222,NULL,40,21698,0);
INSERT INTO "django_geo_db_location" VALUES(37137,NULL,'Greenville, MI',15146,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37138,NULL,'Greenville, MI 48838',15146,222,NULL,40,21699,0);
INSERT INTO "django_geo_db_location" VALUES(37139,NULL,'Haslett, MI',15147,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37140,NULL,'Haslett, MI 48840',15147,222,NULL,40,21700,0);
INSERT INTO "django_geo_db_location" VALUES(37141,NULL,'Henderson, MI',15148,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37142,NULL,'Henderson, MI 48841',15148,222,NULL,40,21701,0);
INSERT INTO "django_geo_db_location" VALUES(37143,NULL,'Holt, MI',15149,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37144,NULL,'Holt, MI 48842',15149,222,NULL,40,21702,0);
INSERT INTO "django_geo_db_location" VALUES(37145,NULL,'Howell, MI',15150,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37146,NULL,'Howell, MI 48843',15150,222,NULL,40,21703,0);
INSERT INTO "django_geo_db_location" VALUES(37147,NULL,'Howell, MI 48844',15150,222,NULL,40,21704,0);
INSERT INTO "django_geo_db_location" VALUES(37148,NULL,'Hubbardston, MI',15151,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37149,NULL,'Hubbardston, MI 48845',15151,222,NULL,40,21705,0);
INSERT INTO "django_geo_db_location" VALUES(37150,NULL,'Ionia, MI',15152,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37151,NULL,'Ionia, MI 48846',15152,222,NULL,40,21706,0);
INSERT INTO "django_geo_db_location" VALUES(37152,NULL,'Ithaca, MI',15153,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37153,NULL,'Ithaca, MI 48847',15153,222,NULL,40,21707,0);
INSERT INTO "django_geo_db_location" VALUES(37154,NULL,'Laingsburg, MI',15154,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37155,NULL,'Laingsburg, MI 48848',15154,222,NULL,40,21708,0);
INSERT INTO "django_geo_db_location" VALUES(37156,NULL,'Lake Odessa, MI',15155,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37157,NULL,'Lake Odessa, MI 48849',15155,222,NULL,40,21709,0);
INSERT INTO "django_geo_db_location" VALUES(37158,NULL,'Lakeview, MI',15156,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37159,NULL,'Lakeview, MI 48850',15156,222,NULL,40,21710,0);
INSERT INTO "django_geo_db_location" VALUES(37160,NULL,'Lyons, MI',15157,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37161,NULL,'Lyons, MI 48851',15157,222,NULL,40,21711,0);
INSERT INTO "django_geo_db_location" VALUES(37162,NULL,'Mcbrides, MI',15158,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37163,NULL,'Mcbrides, MI 48852',15158,222,NULL,40,21712,0);
INSERT INTO "django_geo_db_location" VALUES(37164,NULL,'Maple Rapids, MI',15159,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37165,NULL,'Maple Rapids, MI 48853',15159,222,NULL,40,21713,0);
INSERT INTO "django_geo_db_location" VALUES(37166,NULL,'Mason, MI',15160,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37167,NULL,'Mason, MI 48854',15160,222,NULL,40,21714,0);
INSERT INTO "django_geo_db_location" VALUES(37168,NULL,'Howell, MI 48855',15150,222,NULL,40,21715,0);
INSERT INTO "django_geo_db_location" VALUES(37169,NULL,'Middleton, MI',15161,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37170,NULL,'Middleton, MI 48856',15161,222,NULL,40,21716,0);
INSERT INTO "django_geo_db_location" VALUES(37171,NULL,'Morrice, MI',15162,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37172,NULL,'Morrice, MI 48857',15162,222,NULL,40,21717,0);
INSERT INTO "django_geo_db_location" VALUES(37173,NULL,'Mount Pleasant, MI 48858',15118,222,NULL,40,21718,0);
INSERT INTO "django_geo_db_location" VALUES(37174,NULL,'Mount Pleasant, MI 48859',15118,222,NULL,40,21719,0);
INSERT INTO "django_geo_db_location" VALUES(37175,NULL,'Muir, MI',15163,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37176,NULL,'Muir, MI 48860',15163,222,NULL,40,21720,0);
INSERT INTO "django_geo_db_location" VALUES(37177,NULL,'Mulliken, MI',15164,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37178,NULL,'Mulliken, MI 48861',15164,222,NULL,40,21721,0);
INSERT INTO "django_geo_db_location" VALUES(37179,NULL,'North Star, MI',15165,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37180,NULL,'North Star, MI 48862',15165,222,NULL,40,21722,0);
INSERT INTO "django_geo_db_location" VALUES(37181,NULL,'Oak Grove, MI',15166,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37182,NULL,'Oak Grove, MI 48863',15166,222,NULL,40,21723,0);
INSERT INTO "django_geo_db_location" VALUES(37183,NULL,'Okemos, MI 48864',15119,222,NULL,40,21724,0);
INSERT INTO "django_geo_db_location" VALUES(37184,NULL,'Orleans, MI',15167,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37185,NULL,'Orleans, MI 48865',15167,222,NULL,40,21725,0);
INSERT INTO "django_geo_db_location" VALUES(37186,NULL,'Ovid, MI',15168,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37187,NULL,'Ovid, MI 48866',15168,222,NULL,40,21726,0);
INSERT INTO "django_geo_db_location" VALUES(37188,NULL,'Owosso, MI',15169,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37189,NULL,'Owosso, MI 48867',15169,222,NULL,40,21727,0);
INSERT INTO "django_geo_db_location" VALUES(37190,NULL,'Palo, MI',15170,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37191,NULL,'Palo, MI 48870',15170,222,NULL,40,21728,0);
INSERT INTO "django_geo_db_location" VALUES(37192,NULL,'Perrinton, MI',15171,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37193,NULL,'Perrinton, MI 48871',15171,222,NULL,40,21729,0);
INSERT INTO "django_geo_db_location" VALUES(37194,NULL,'Perry, MI',15172,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37195,NULL,'Perry, MI 48872',15172,222,NULL,40,21730,0);
INSERT INTO "django_geo_db_location" VALUES(37196,NULL,'Pewamo, MI',15173,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37197,NULL,'Pewamo, MI 48873',15173,222,NULL,40,21731,0);
INSERT INTO "django_geo_db_location" VALUES(37198,NULL,'Pompeii, MI',15174,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37199,NULL,'Pompeii, MI 48874',15174,222,NULL,40,21732,0);
INSERT INTO "django_geo_db_location" VALUES(37200,NULL,'Portland, MI',15175,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37201,NULL,'Portland, MI 48875',15175,222,NULL,40,21733,0);
INSERT INTO "django_geo_db_location" VALUES(37202,NULL,'Potterville, MI',15176,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37203,NULL,'Potterville, MI 48876',15176,222,NULL,40,21734,0);
INSERT INTO "django_geo_db_location" VALUES(37204,NULL,'Riverdale, MI',15177,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37205,NULL,'Riverdale, MI 48877',15177,222,NULL,40,21735,0);
INSERT INTO "django_geo_db_location" VALUES(37206,NULL,'Rosebush, MI',15178,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37207,NULL,'Rosebush, MI 48878',15178,222,NULL,40,21736,0);
INSERT INTO "django_geo_db_location" VALUES(37208,NULL,'Saint Johns, MI',15179,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37209,NULL,'Saint Johns, MI 48879',15179,222,NULL,40,21737,0);
INSERT INTO "django_geo_db_location" VALUES(37210,NULL,'Saint Louis, MI',15180,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37211,NULL,'Saint Louis, MI 48880',15180,222,NULL,40,21738,0);
INSERT INTO "django_geo_db_location" VALUES(37212,NULL,'Saranac, MI',15181,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37213,NULL,'Saranac, MI 48881',15181,222,NULL,40,21739,0);
INSERT INTO "django_geo_db_location" VALUES(37214,NULL,'Shaftsburg, MI',15182,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37215,NULL,'Shaftsburg, MI 48882',15182,222,NULL,40,21740,0);
INSERT INTO "django_geo_db_location" VALUES(37216,NULL,'Shepherd, MI',15183,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37217,NULL,'Shepherd, MI 48883',15183,222,NULL,40,21741,0);
INSERT INTO "django_geo_db_location" VALUES(37218,NULL,'Sheridan, MI',15184,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37219,NULL,'Sheridan, MI 48884',15184,222,NULL,40,21742,0);
INSERT INTO "django_geo_db_location" VALUES(37220,NULL,'Sidney, MI',15185,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37221,NULL,'Sidney, MI 48885',15185,222,NULL,40,21743,0);
INSERT INTO "django_geo_db_location" VALUES(37222,NULL,'Six Lakes, MI',15186,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37223,NULL,'Six Lakes, MI 48886',15186,222,NULL,40,21744,0);
INSERT INTO "django_geo_db_location" VALUES(37224,NULL,'Smyrna, MI',15187,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37225,NULL,'Smyrna, MI 48887',15187,222,NULL,40,21745,0);
INSERT INTO "django_geo_db_location" VALUES(37226,NULL,'Stanton, MI',15188,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37227,NULL,'Stanton, MI 48888',15188,222,NULL,40,21746,0);
INSERT INTO "django_geo_db_location" VALUES(37228,NULL,'Sumner, MI',15189,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37229,NULL,'Sumner, MI 48889',15189,222,NULL,40,21747,0);
INSERT INTO "django_geo_db_location" VALUES(37230,NULL,'Sunfield, MI',15190,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37231,NULL,'Sunfield, MI 48890',15190,222,NULL,40,21748,0);
INSERT INTO "django_geo_db_location" VALUES(37232,NULL,'Vestaburg, MI',15191,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37233,NULL,'Vestaburg, MI 48891',15191,222,NULL,40,21749,0);
INSERT INTO "django_geo_db_location" VALUES(37234,NULL,'Webberville, MI',15192,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37235,NULL,'Webberville, MI 48892',15192,222,NULL,40,21750,0);
INSERT INTO "django_geo_db_location" VALUES(37236,NULL,'Weidman, MI',15193,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37237,NULL,'Weidman, MI 48893',15193,222,NULL,40,21751,0);
INSERT INTO "django_geo_db_location" VALUES(37238,NULL,'Westphalia, MI',15194,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37239,NULL,'Westphalia, MI 48894',15194,222,NULL,40,21752,0);
INSERT INTO "django_geo_db_location" VALUES(37240,NULL,'Williamston, MI',15195,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37241,NULL,'Williamston, MI 48895',15195,222,NULL,40,21753,0);
INSERT INTO "django_geo_db_location" VALUES(37242,NULL,'Winn, MI',15196,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37243,NULL,'Winn, MI 48896',15196,222,NULL,40,21754,0);
INSERT INTO "django_geo_db_location" VALUES(37244,NULL,'Woodland, MI',15197,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37245,NULL,'Woodland, MI 48897',15197,222,NULL,40,21755,0);
INSERT INTO "django_geo_db_location" VALUES(37246,NULL,'Lansing, MI',15198,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37247,NULL,'Lansing, MI 48901',15198,222,NULL,40,21756,0);
INSERT INTO "django_geo_db_location" VALUES(37248,NULL,'Lansing, MI 48906',15198,222,NULL,40,21757,0);
INSERT INTO "django_geo_db_location" VALUES(37249,NULL,'Lansing, MI 48907',15198,222,NULL,40,21758,0);
INSERT INTO "django_geo_db_location" VALUES(37250,NULL,'Lansing, MI 48908',15198,222,NULL,40,21759,0);
INSERT INTO "django_geo_db_location" VALUES(37251,NULL,'Lansing, MI 48909',15198,222,NULL,40,21760,0);
INSERT INTO "django_geo_db_location" VALUES(37252,NULL,'Lansing, MI 48910',15198,222,NULL,40,21761,0);
INSERT INTO "django_geo_db_location" VALUES(37253,NULL,'Lansing, MI 48911',15198,222,NULL,40,21762,0);
INSERT INTO "django_geo_db_location" VALUES(37254,NULL,'Lansing, MI 48912',15198,222,NULL,40,21763,0);
INSERT INTO "django_geo_db_location" VALUES(37255,NULL,'Lansing, MI 48913',15198,222,NULL,40,21764,0);
INSERT INTO "django_geo_db_location" VALUES(37256,NULL,'Lansing, MI 48915',15198,222,NULL,40,21765,0);
INSERT INTO "django_geo_db_location" VALUES(37257,NULL,'Lansing, MI 48916',15198,222,NULL,40,21766,0);
INSERT INTO "django_geo_db_location" VALUES(37258,NULL,'Lansing, MI 48917',15198,222,NULL,40,21767,0);
INSERT INTO "django_geo_db_location" VALUES(37259,NULL,'Lansing, MI 48918',15198,222,NULL,40,21768,0);
INSERT INTO "django_geo_db_location" VALUES(37260,NULL,'Lansing, MI 48919',15198,222,NULL,40,21769,0);
INSERT INTO "django_geo_db_location" VALUES(37261,NULL,'Lansing, MI 48921',15198,222,NULL,40,21770,0);
INSERT INTO "django_geo_db_location" VALUES(37262,NULL,'Lansing, MI 48922',15198,222,NULL,40,21771,0);
INSERT INTO "django_geo_db_location" VALUES(37263,NULL,'Lansing, MI 48924',15198,222,NULL,40,21772,0);
INSERT INTO "django_geo_db_location" VALUES(37264,NULL,'Lansing, MI 48929',15198,222,NULL,40,21773,0);
INSERT INTO "django_geo_db_location" VALUES(37265,NULL,'Lansing, MI 48930',15198,222,NULL,40,21774,0);
INSERT INTO "django_geo_db_location" VALUES(37266,NULL,'Lansing, MI 48933',15198,222,NULL,40,21775,0);
INSERT INTO "django_geo_db_location" VALUES(37267,NULL,'Lansing, MI 48937',15198,222,NULL,40,21776,0);
INSERT INTO "django_geo_db_location" VALUES(37268,NULL,'Lansing, MI 48950',15198,222,NULL,40,21777,0);
INSERT INTO "django_geo_db_location" VALUES(37269,NULL,'Lansing, MI 48956',15198,222,NULL,40,21778,0);
INSERT INTO "django_geo_db_location" VALUES(37270,NULL,'Lansing, MI 48980',15198,222,NULL,40,21779,0);
INSERT INTO "django_geo_db_location" VALUES(37271,NULL,'Kalamazoo, MI',15199,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37272,NULL,'Kalamazoo, MI 49001',15199,222,NULL,40,21780,0);
INSERT INTO "django_geo_db_location" VALUES(37273,NULL,'Portage, MI',15200,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37274,NULL,'Portage, MI 49002',15200,222,NULL,40,21781,0);
INSERT INTO "django_geo_db_location" VALUES(37275,NULL,'Kalamazoo, MI 49003',15199,222,NULL,40,21782,0);
INSERT INTO "django_geo_db_location" VALUES(37276,NULL,'Kalamazoo, MI 49004',15199,222,NULL,40,21783,0);
INSERT INTO "django_geo_db_location" VALUES(37277,NULL,'Kalamazoo, MI 49005',15199,222,NULL,40,21784,0);
INSERT INTO "django_geo_db_location" VALUES(37278,NULL,'Kalamazoo, MI 49006',15199,222,NULL,40,21785,0);
INSERT INTO "django_geo_db_location" VALUES(37279,NULL,'Kalamazoo, MI 49007',15199,222,NULL,40,21786,0);
INSERT INTO "django_geo_db_location" VALUES(37280,NULL,'Kalamazoo, MI 49008',15199,222,NULL,40,21787,0);
INSERT INTO "django_geo_db_location" VALUES(37281,NULL,'Kalamazoo, MI 49009',15199,222,NULL,40,21788,0);
INSERT INTO "django_geo_db_location" VALUES(37282,NULL,'Allegan, MI',15201,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37283,NULL,'Allegan, MI 49010',15201,222,NULL,40,21789,0);
INSERT INTO "django_geo_db_location" VALUES(37284,NULL,'Athens, MI',15202,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37285,NULL,'Athens, MI 49011',15202,222,NULL,40,21790,0);
INSERT INTO "django_geo_db_location" VALUES(37286,NULL,'Augusta, MI',15203,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37287,NULL,'Augusta, MI 49012',15203,222,NULL,40,21791,0);
INSERT INTO "django_geo_db_location" VALUES(37288,NULL,'Bangor, MI',15204,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37289,NULL,'Bangor, MI 49013',15204,222,NULL,40,21792,0);
INSERT INTO "django_geo_db_location" VALUES(37290,NULL,'Battle Creek, MI',15205,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37291,NULL,'Battle Creek, MI 49014',15205,222,NULL,40,21793,0);
INSERT INTO "django_geo_db_location" VALUES(37292,NULL,'Battle Creek, MI 49015',15205,222,NULL,40,21794,0);
INSERT INTO "django_geo_db_location" VALUES(37293,NULL,'Battle Creek, MI 49016',15205,222,NULL,40,21795,0);
INSERT INTO "django_geo_db_location" VALUES(37294,NULL,'Battle Creek, MI 49017',15205,222,NULL,40,21796,0);
INSERT INTO "django_geo_db_location" VALUES(37295,NULL,'Battle Creek, MI 49018',15205,222,NULL,40,21797,0);
INSERT INTO "django_geo_db_location" VALUES(37296,NULL,'Kalamazoo, MI 49019',15199,222,NULL,40,21798,0);
INSERT INTO "django_geo_db_location" VALUES(37297,NULL,'Bedford, MI',15206,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37298,NULL,'Bedford, MI 49020',15206,222,NULL,40,21799,0);
INSERT INTO "django_geo_db_location" VALUES(37299,NULL,'Bellevue, MI',15207,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37300,NULL,'Bellevue, MI 49021',15207,222,NULL,40,21800,0);
INSERT INTO "django_geo_db_location" VALUES(37301,NULL,'Benton Harbor, MI',15208,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37302,NULL,'Benton Harbor, MI 49022',15208,222,NULL,40,21801,0);
INSERT INTO "django_geo_db_location" VALUES(37303,NULL,'Benton Harbor, MI 49023',15208,222,NULL,40,21802,0);
INSERT INTO "django_geo_db_location" VALUES(37304,NULL,'Portage, MI 49024',15200,222,NULL,40,21803,0);
INSERT INTO "django_geo_db_location" VALUES(37305,NULL,'Bloomingdale, MI',15209,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37306,NULL,'Bloomingdale, MI 49026',15209,222,NULL,40,21804,0);
INSERT INTO "django_geo_db_location" VALUES(37307,NULL,'Breedsville, MI',15210,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37308,NULL,'Breedsville, MI 49027',15210,222,NULL,40,21805,0);
INSERT INTO "django_geo_db_location" VALUES(37309,NULL,'Bronson, MI',15211,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37310,NULL,'Bronson, MI 49028',15211,222,NULL,40,21806,0);
INSERT INTO "django_geo_db_location" VALUES(37311,NULL,'Burlington, MI',15212,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37312,NULL,'Burlington, MI 49029',15212,222,NULL,40,21807,0);
INSERT INTO "django_geo_db_location" VALUES(37313,NULL,'Burr Oak, MI',15213,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37314,NULL,'Burr Oak, MI 49030',15213,222,NULL,40,21808,0);
INSERT INTO "django_geo_db_location" VALUES(37315,NULL,'Cassopolis, MI',15214,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37316,NULL,'Cassopolis, MI 49031',15214,222,NULL,40,21809,0);
INSERT INTO "django_geo_db_location" VALUES(37317,NULL,'Centreville, MI',15215,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37318,NULL,'Centreville, MI 49032',15215,222,NULL,40,21810,0);
INSERT INTO "django_geo_db_location" VALUES(37319,NULL,'Ceresco, MI',15216,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37320,NULL,'Ceresco, MI 49033',15216,222,NULL,40,21811,0);
INSERT INTO "django_geo_db_location" VALUES(37321,NULL,'Climax, MI',15217,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37322,NULL,'Climax, MI 49034',15217,222,NULL,40,21812,0);
INSERT INTO "django_geo_db_location" VALUES(37323,NULL,'Cloverdale, MI',15218,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37324,NULL,'Cloverdale, MI 49035',15218,222,NULL,40,21813,0);
INSERT INTO "django_geo_db_location" VALUES(37325,NULL,'Coldwater, MI',15219,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37326,NULL,'Coldwater, MI 49036',15219,222,NULL,40,21814,0);
INSERT INTO "django_geo_db_location" VALUES(37327,NULL,'Coloma, MI',15220,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37328,NULL,'Coloma, MI 49038',15220,222,NULL,40,21815,0);
INSERT INTO "django_geo_db_location" VALUES(37329,NULL,'Hagar Shores, MI',15221,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37330,NULL,'Hagar Shores, MI 49039',15221,222,NULL,40,21816,0);
INSERT INTO "django_geo_db_location" VALUES(37331,NULL,'Colon, MI',15222,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37332,NULL,'Colon, MI 49040',15222,222,NULL,40,21817,0);
INSERT INTO "django_geo_db_location" VALUES(37333,NULL,'Comstock, MI',15223,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37334,NULL,'Comstock, MI 49041',15223,222,NULL,40,21818,0);
INSERT INTO "django_geo_db_location" VALUES(37335,NULL,'Constantine, MI',15224,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37336,NULL,'Constantine, MI 49042',15224,222,NULL,40,21819,0);
INSERT INTO "django_geo_db_location" VALUES(37337,NULL,'Covert, MI',15225,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37338,NULL,'Covert, MI 49043',15225,222,NULL,40,21820,0);
INSERT INTO "django_geo_db_location" VALUES(37339,NULL,'Decatur, MI',15226,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37340,NULL,'Decatur, MI 49045',15226,222,NULL,40,21821,0);
INSERT INTO "django_geo_db_location" VALUES(37341,NULL,'Delton, MI',15227,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37342,NULL,'Delton, MI 49046',15227,222,NULL,40,21822,0);
INSERT INTO "django_geo_db_location" VALUES(37343,NULL,'Dowagiac, MI',15228,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37344,NULL,'Dowagiac, MI 49047',15228,222,NULL,40,21823,0);
INSERT INTO "django_geo_db_location" VALUES(37345,NULL,'Kalamazoo, MI 49048',15199,222,NULL,40,21824,0);
INSERT INTO "django_geo_db_location" VALUES(37346,NULL,'Dowling, MI',15229,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37347,NULL,'Dowling, MI 49050',15229,222,NULL,40,21825,0);
INSERT INTO "django_geo_db_location" VALUES(37348,NULL,'East Leroy, MI',15230,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37349,NULL,'East Leroy, MI 49051',15230,222,NULL,40,21826,0);
INSERT INTO "django_geo_db_location" VALUES(37350,NULL,'Fulton, MI',15231,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37351,NULL,'Fulton, MI 49052',15231,222,NULL,40,21827,0);
INSERT INTO "django_geo_db_location" VALUES(37352,NULL,'Galesburg, MI',15232,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37353,NULL,'Galesburg, MI 49053',15232,222,NULL,40,21828,0);
INSERT INTO "django_geo_db_location" VALUES(37354,NULL,'Gobles, MI',15233,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37355,NULL,'Gobles, MI 49055',15233,222,NULL,40,21829,0);
INSERT INTO "django_geo_db_location" VALUES(37356,NULL,'Grand Junction, MI',15234,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37357,NULL,'Grand Junction, MI 49056',15234,222,NULL,40,21830,0);
INSERT INTO "django_geo_db_location" VALUES(37358,NULL,'Hartford, MI',15235,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37359,NULL,'Hartford, MI 49057',15235,222,NULL,40,21831,0);
INSERT INTO "django_geo_db_location" VALUES(37360,NULL,'Hastings, MI',15236,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37361,NULL,'Hastings, MI 49058',15236,222,NULL,40,21832,0);
INSERT INTO "django_geo_db_location" VALUES(37362,NULL,'Hickory Corners, MI',15237,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37363,NULL,'Hickory Corners, MI 49060',15237,222,NULL,40,21833,0);
INSERT INTO "django_geo_db_location" VALUES(37364,NULL,'Jones, MI',15238,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37365,NULL,'Jones, MI 49061',15238,222,NULL,40,21834,0);
INSERT INTO "django_geo_db_location" VALUES(37366,NULL,'Kendall, MI',15239,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37367,NULL,'Kendall, MI 49062',15239,222,NULL,40,21835,0);
INSERT INTO "django_geo_db_location" VALUES(37368,NULL,'Lacota, MI',15240,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37369,NULL,'Lacota, MI 49063',15240,222,NULL,40,21836,0);
INSERT INTO "django_geo_db_location" VALUES(37370,NULL,'Lawrence, MI',15241,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37371,NULL,'Lawrence, MI 49064',15241,222,NULL,40,21837,0);
INSERT INTO "django_geo_db_location" VALUES(37372,NULL,'Lawton, MI',15242,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37373,NULL,'Lawton, MI 49065',15242,222,NULL,40,21838,0);
INSERT INTO "django_geo_db_location" VALUES(37374,NULL,'Leonidas, MI',15243,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37375,NULL,'Leonidas, MI 49066',15243,222,NULL,40,21839,0);
INSERT INTO "django_geo_db_location" VALUES(37376,NULL,'Marcellus, MI',15244,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37377,NULL,'Marcellus, MI 49067',15244,222,NULL,40,21840,0);
INSERT INTO "django_geo_db_location" VALUES(37378,NULL,'Marshall, MI',15245,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37379,NULL,'Marshall, MI 49068',15245,222,NULL,40,21841,0);
INSERT INTO "django_geo_db_location" VALUES(37380,NULL,'Marshall, MI 49069',15245,222,NULL,40,21842,0);
INSERT INTO "django_geo_db_location" VALUES(37381,NULL,'Martin, MI',15246,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37382,NULL,'Martin, MI 49070',15246,222,NULL,40,21843,0);
INSERT INTO "django_geo_db_location" VALUES(37383,NULL,'Mattawan, MI',15247,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37384,NULL,'Mattawan, MI 49071',15247,222,NULL,40,21844,0);
INSERT INTO "django_geo_db_location" VALUES(37385,NULL,'Mendon, MI',15248,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37386,NULL,'Mendon, MI 49072',15248,222,NULL,40,21845,0);
INSERT INTO "django_geo_db_location" VALUES(37387,NULL,'Nashville, MI',15249,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37388,NULL,'Nashville, MI 49073',15249,222,NULL,40,21846,0);
INSERT INTO "django_geo_db_location" VALUES(37389,NULL,'Nazareth, MI',15250,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37390,NULL,'Nazareth, MI 49074',15250,222,NULL,40,21847,0);
INSERT INTO "django_geo_db_location" VALUES(37391,NULL,'Nottawa, MI',15251,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37392,NULL,'Nottawa, MI 49075',15251,222,NULL,40,21848,0);
INSERT INTO "django_geo_db_location" VALUES(37393,NULL,'Olivet, MI',15252,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37394,NULL,'Olivet, MI 49076',15252,222,NULL,40,21849,0);
INSERT INTO "django_geo_db_location" VALUES(37395,NULL,'Oshtemo, MI',15253,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37396,NULL,'Oshtemo, MI 49077',15253,222,NULL,40,21850,0);
INSERT INTO "django_geo_db_location" VALUES(37397,NULL,'Otsego, MI',15254,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37398,NULL,'Otsego, MI 49078',15254,222,NULL,40,21851,0);
INSERT INTO "django_geo_db_location" VALUES(37399,NULL,'Paw Paw, MI',15255,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37400,NULL,'Paw Paw, MI 49079',15255,222,NULL,40,21852,0);
INSERT INTO "django_geo_db_location" VALUES(37401,NULL,'Plainwell, MI',15256,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37402,NULL,'Plainwell, MI 49080',15256,222,NULL,40,21853,0);
INSERT INTO "django_geo_db_location" VALUES(37403,NULL,'Portage, MI 49081',15200,222,NULL,40,21854,0);
INSERT INTO "django_geo_db_location" VALUES(37404,NULL,'Quincy, MI',15257,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37405,NULL,'Quincy, MI 49082',15257,222,NULL,40,21855,0);
INSERT INTO "django_geo_db_location" VALUES(37406,NULL,'Richland, MI',15258,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37407,NULL,'Richland, MI 49083',15258,222,NULL,40,21856,0);
INSERT INTO "django_geo_db_location" VALUES(37408,NULL,'Riverside, MI',15259,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37409,NULL,'Riverside, MI 49084',15259,222,NULL,40,21857,0);
INSERT INTO "django_geo_db_location" VALUES(37410,NULL,'Saint Joseph, MI',15260,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37411,NULL,'Saint Joseph, MI 49085',15260,222,NULL,40,21858,0);
INSERT INTO "django_geo_db_location" VALUES(37412,NULL,'Schoolcraft, MI',15261,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37413,NULL,'Schoolcraft, MI 49087',15261,222,NULL,40,21859,0);
INSERT INTO "django_geo_db_location" VALUES(37414,NULL,'Scotts, MI',15262,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37415,NULL,'Scotts, MI 49088',15262,222,NULL,40,21860,0);
INSERT INTO "django_geo_db_location" VALUES(37416,NULL,'Sherwood, MI',15263,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37417,NULL,'Sherwood, MI 49089',15263,222,NULL,40,21861,0);
INSERT INTO "django_geo_db_location" VALUES(37418,NULL,'South Haven, MI',15264,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37419,NULL,'South Haven, MI 49090',15264,222,NULL,40,21862,0);
INSERT INTO "django_geo_db_location" VALUES(37420,NULL,'Sturgis, MI',15265,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37421,NULL,'Sturgis, MI 49091',15265,222,NULL,40,21863,0);
INSERT INTO "django_geo_db_location" VALUES(37422,NULL,'Tekonsha, MI',15266,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37423,NULL,'Tekonsha, MI 49092',15266,222,NULL,40,21864,0);
INSERT INTO "django_geo_db_location" VALUES(37424,NULL,'Three Rivers, MI',15267,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37425,NULL,'Three Rivers, MI 49093',15267,222,NULL,40,21865,0);
INSERT INTO "django_geo_db_location" VALUES(37426,NULL,'Union City, MI',15268,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37427,NULL,'Union City, MI 49094',15268,222,NULL,40,21866,0);
INSERT INTO "django_geo_db_location" VALUES(37428,NULL,'Vandalia, MI',15269,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37429,NULL,'Vandalia, MI 49095',15269,222,NULL,40,21867,0);
INSERT INTO "django_geo_db_location" VALUES(37430,NULL,'Vermontville, MI',15270,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37431,NULL,'Vermontville, MI 49096',15270,222,NULL,40,21868,0);
INSERT INTO "django_geo_db_location" VALUES(37432,NULL,'Vicksburg, MI',15271,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37433,NULL,'Vicksburg, MI 49097',15271,222,NULL,40,21869,0);
INSERT INTO "django_geo_db_location" VALUES(37434,NULL,'Watervliet, MI',15272,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37435,NULL,'Watervliet, MI 49098',15272,222,NULL,40,21870,0);
INSERT INTO "django_geo_db_location" VALUES(37436,NULL,'White Pigeon, MI',15273,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37437,NULL,'White Pigeon, MI 49099',15273,222,NULL,40,21871,0);
INSERT INTO "django_geo_db_location" VALUES(37438,NULL,'Baroda, MI',15274,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37439,NULL,'Baroda, MI 49101',15274,222,NULL,40,21872,0);
INSERT INTO "django_geo_db_location" VALUES(37440,NULL,'Berrien Center, MI',15275,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37441,NULL,'Berrien Center, MI 49102',15275,222,NULL,40,21873,0);
INSERT INTO "django_geo_db_location" VALUES(37442,NULL,'Berrien Springs, MI',15276,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37443,NULL,'Berrien Springs, MI 49103',15276,222,NULL,40,21874,0);
INSERT INTO "django_geo_db_location" VALUES(37444,NULL,'Berrien Springs, MI 49104',15276,222,NULL,40,21875,0);
INSERT INTO "django_geo_db_location" VALUES(37445,NULL,'Bridgman, MI',15277,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37446,NULL,'Bridgman, MI 49106',15277,222,NULL,40,21876,0);
INSERT INTO "django_geo_db_location" VALUES(37447,NULL,'Buchanan, MI',15278,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37448,NULL,'Buchanan, MI 49107',15278,222,NULL,40,21877,0);
INSERT INTO "django_geo_db_location" VALUES(37449,NULL,'Eau Claire, MI',15279,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37450,NULL,'Eau Claire, MI 49111',15279,222,NULL,40,21878,0);
INSERT INTO "django_geo_db_location" VALUES(37451,NULL,'Edwardsburg, MI',15280,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37452,NULL,'Edwardsburg, MI 49112',15280,222,NULL,40,21879,0);
INSERT INTO "django_geo_db_location" VALUES(37453,NULL,'Galien, MI',15281,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37454,NULL,'Galien, MI 49113',15281,222,NULL,40,21880,0);
INSERT INTO "django_geo_db_location" VALUES(37455,NULL,'Harbert, MI',15282,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37456,NULL,'Harbert, MI 49115',15282,222,NULL,40,21881,0);
INSERT INTO "django_geo_db_location" VALUES(37457,NULL,'Lakeside, MI',15283,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37458,NULL,'Lakeside, MI 49116',15283,222,NULL,40,21882,0);
INSERT INTO "django_geo_db_location" VALUES(37459,NULL,'New Buffalo, MI',15284,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37460,NULL,'New Buffalo, MI 49117',15284,222,NULL,40,21883,0);
INSERT INTO "django_geo_db_location" VALUES(37461,NULL,'New Troy, MI',15285,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37462,NULL,'New Troy, MI 49119',15285,222,NULL,40,21884,0);
INSERT INTO "django_geo_db_location" VALUES(37463,NULL,'Niles, MI',15286,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37464,NULL,'Niles, MI 49120',15286,222,NULL,40,21885,0);
INSERT INTO "django_geo_db_location" VALUES(37465,NULL,'Niles, MI 49121',15286,222,NULL,40,21886,0);
INSERT INTO "django_geo_db_location" VALUES(37466,NULL,'Sawyer, MI',15287,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37467,NULL,'Sawyer, MI 49125',15287,222,NULL,40,21887,0);
INSERT INTO "django_geo_db_location" VALUES(37468,NULL,'Sodus, MI',15288,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37469,NULL,'Sodus, MI 49126',15288,222,NULL,40,21888,0);
INSERT INTO "django_geo_db_location" VALUES(37470,NULL,'Stevensville, MI',15289,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37471,NULL,'Stevensville, MI 49127',15289,222,NULL,40,21889,0);
INSERT INTO "django_geo_db_location" VALUES(37472,NULL,'Three Oaks, MI',15290,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37473,NULL,'Three Oaks, MI 49128',15290,222,NULL,40,21890,0);
INSERT INTO "django_geo_db_location" VALUES(37474,NULL,'Union Pier, MI',15291,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37475,NULL,'Union Pier, MI 49129',15291,222,NULL,40,21891,0);
INSERT INTO "django_geo_db_location" VALUES(37476,NULL,'Union, MI',15292,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37477,NULL,'Union, MI 49130',15292,222,NULL,40,21892,0);
INSERT INTO "django_geo_db_location" VALUES(37478,NULL,'Lyndon, MI',15293,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37479,NULL,'Lyndon, MI 49137',15293,222,NULL,40,21893,0);
INSERT INTO "django_geo_db_location" VALUES(37480,NULL,'Richland, MI 49157',15258,222,NULL,40,21894,0);
INSERT INTO "django_geo_db_location" VALUES(37481,NULL,'Dickson, MI',15294,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37482,NULL,'Dickson, MI 49169',15294,222,NULL,40,21895,0);
INSERT INTO "django_geo_db_location" VALUES(37483,NULL,'Jackson, MI',15295,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37484,NULL,'Jackson, MI 49201',15295,222,NULL,40,21896,0);
INSERT INTO "django_geo_db_location" VALUES(37485,NULL,'Jackson, MI 49202',15295,222,NULL,40,21897,0);
INSERT INTO "django_geo_db_location" VALUES(37486,NULL,'Jackson, MI 49203',15295,222,NULL,40,21898,0);
INSERT INTO "django_geo_db_location" VALUES(37487,NULL,'Jackson, MI 49204',15295,222,NULL,40,21899,0);
INSERT INTO "django_geo_db_location" VALUES(37488,NULL,'Addison, MI',15296,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37489,NULL,'Addison, MI 49220',15296,222,NULL,40,21900,0);
INSERT INTO "django_geo_db_location" VALUES(37490,NULL,'Adrian, MI',15297,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37491,NULL,'Adrian, MI 49221',15297,222,NULL,40,21901,0);
INSERT INTO "django_geo_db_location" VALUES(37492,NULL,'Albion, MI',15298,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37493,NULL,'Albion, MI 49224',15298,222,NULL,40,21902,0);
INSERT INTO "django_geo_db_location" VALUES(37494,NULL,'Bloomingdale, MI 49226',15209,222,NULL,40,21903,0);
INSERT INTO "django_geo_db_location" VALUES(37495,NULL,'Allen, MI',15299,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37496,NULL,'Allen, MI 49227',15299,222,NULL,40,21904,0);
INSERT INTO "django_geo_db_location" VALUES(37497,NULL,'Blissfield, MI',15300,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37498,NULL,'Blissfield, MI 49228',15300,222,NULL,40,21905,0);
INSERT INTO "django_geo_db_location" VALUES(37499,NULL,'Britton, MI',15301,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37500,NULL,'Britton, MI 49229',15301,222,NULL,40,21906,0);
INSERT INTO "django_geo_db_location" VALUES(37501,NULL,'Brooklyn, MI',15302,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37502,NULL,'Brooklyn, MI 49230',15302,222,NULL,40,21907,0);
INSERT INTO "django_geo_db_location" VALUES(37503,NULL,'Camden, MI',15303,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37504,NULL,'Camden, MI 49232',15303,222,NULL,40,21908,0);
INSERT INTO "django_geo_db_location" VALUES(37505,NULL,'Cement City, MI',15304,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37506,NULL,'Cement City, MI 49233',15304,222,NULL,40,21909,0);
INSERT INTO "django_geo_db_location" VALUES(37507,NULL,'Clarklake, MI',15305,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37508,NULL,'Clarklake, MI 49234',15305,222,NULL,40,21910,0);
INSERT INTO "django_geo_db_location" VALUES(37509,NULL,'Clayton, MI',15306,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37510,NULL,'Clayton, MI 49235',15306,222,NULL,40,21911,0);
INSERT INTO "django_geo_db_location" VALUES(37511,NULL,'Clinton, MI 49236',14931,222,NULL,40,21912,0);
INSERT INTO "django_geo_db_location" VALUES(37512,NULL,'Concord, MI',15307,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37513,NULL,'Concord, MI 49237',15307,222,NULL,40,21913,0);
INSERT INTO "django_geo_db_location" VALUES(37514,NULL,'Deerfield, MI',15308,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37515,NULL,'Deerfield, MI 49238',15308,222,NULL,40,21914,0);
INSERT INTO "django_geo_db_location" VALUES(37516,NULL,'Frontier, MI',15309,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37517,NULL,'Frontier, MI 49239',15309,222,NULL,40,21915,0);
INSERT INTO "django_geo_db_location" VALUES(37518,NULL,'Grass Lake, MI',15310,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37519,NULL,'Grass Lake, MI 49240',15310,222,NULL,40,21916,0);
INSERT INTO "django_geo_db_location" VALUES(37520,NULL,'Hanover, MI',15311,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37521,NULL,'Hanover, MI 49241',15311,222,NULL,40,21917,0);
INSERT INTO "django_geo_db_location" VALUES(37522,NULL,'Hillsdale, MI',15312,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37523,NULL,'Hillsdale, MI 49242',15312,222,NULL,40,21918,0);
INSERT INTO "django_geo_db_location" VALUES(37524,NULL,'Homer, MI',15313,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37525,NULL,'Homer, MI 49245',15313,222,NULL,40,21919,0);
INSERT INTO "django_geo_db_location" VALUES(37526,NULL,'Horton, MI',15314,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37527,NULL,'Horton, MI 49246',15314,222,NULL,40,21920,0);
INSERT INTO "django_geo_db_location" VALUES(37528,NULL,'Hudson, MI',15315,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37529,NULL,'Hudson, MI 49247',15315,222,NULL,40,21921,0);
INSERT INTO "django_geo_db_location" VALUES(37530,NULL,'Jasper, MI',15316,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37531,NULL,'Jasper, MI 49248',15316,222,NULL,40,21922,0);
INSERT INTO "django_geo_db_location" VALUES(37532,NULL,'Jerome, MI',15317,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37533,NULL,'Jerome, MI 49249',15317,222,NULL,40,21923,0);
INSERT INTO "django_geo_db_location" VALUES(37534,NULL,'Jonesville, MI',15318,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37535,NULL,'Jonesville, MI 49250',15318,222,NULL,40,21924,0);
INSERT INTO "django_geo_db_location" VALUES(37536,NULL,'Leslie, MI',15319,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37537,NULL,'Leslie, MI 49251',15319,222,NULL,40,21925,0);
INSERT INTO "django_geo_db_location" VALUES(37538,NULL,'Litchfield, MI',15320,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37539,NULL,'Litchfield, MI 49252',15320,222,NULL,40,21926,0);
INSERT INTO "django_geo_db_location" VALUES(37540,NULL,'Manitou Beach, MI',15321,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37541,NULL,'Manitou Beach, MI 49253',15321,222,NULL,40,21927,0);
INSERT INTO "django_geo_db_location" VALUES(37542,NULL,'Michigan Center, MI',15322,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37543,NULL,'Michigan Center, MI 49254',15322,222,NULL,40,21928,0);
INSERT INTO "django_geo_db_location" VALUES(37544,NULL,'Montgomery, MI',15323,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37545,NULL,'Montgomery, MI 49255',15323,222,NULL,40,21929,0);
INSERT INTO "django_geo_db_location" VALUES(37546,NULL,'Morenci, MI',15324,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37547,NULL,'Morenci, MI 49256',15324,222,NULL,40,21930,0);
INSERT INTO "django_geo_db_location" VALUES(37548,NULL,'Moscow, MI',15325,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37549,NULL,'Moscow, MI 49257',15325,222,NULL,40,21931,0);
INSERT INTO "django_geo_db_location" VALUES(37550,NULL,'Mosherville, MI',15326,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37551,NULL,'Mosherville, MI 49258',15326,222,NULL,40,21932,0);
INSERT INTO "django_geo_db_location" VALUES(37552,NULL,'Munith, MI',15327,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37553,NULL,'Munith, MI 49259',15327,222,NULL,40,21933,0);
INSERT INTO "django_geo_db_location" VALUES(37554,NULL,'Napoleon, MI',15328,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37555,NULL,'Napoleon, MI 49261',15328,222,NULL,40,21934,0);
INSERT INTO "django_geo_db_location" VALUES(37556,NULL,'North Adams, MI',15329,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37557,NULL,'North Adams, MI 49262',15329,222,NULL,40,21935,0);
INSERT INTO "django_geo_db_location" VALUES(37558,NULL,'Norvell, MI',15330,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37559,NULL,'Norvell, MI 49263',15330,222,NULL,40,21936,0);
INSERT INTO "django_geo_db_location" VALUES(37560,NULL,'Onondaga, MI',15331,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37561,NULL,'Onondaga, MI 49264',15331,222,NULL,40,21937,0);
INSERT INTO "django_geo_db_location" VALUES(37562,NULL,'Onsted, MI',15332,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37563,NULL,'Onsted, MI 49265',15332,222,NULL,40,21938,0);
INSERT INTO "django_geo_db_location" VALUES(37564,NULL,'Osseo, MI',15333,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37565,NULL,'Osseo, MI 49266',15333,222,NULL,40,21939,0);
INSERT INTO "django_geo_db_location" VALUES(37566,NULL,'Ottawa Lake, MI',15334,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37567,NULL,'Ottawa Lake, MI 49267',15334,222,NULL,40,21940,0);
INSERT INTO "django_geo_db_location" VALUES(37568,NULL,'Palmyra, MI',15335,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37569,NULL,'Palmyra, MI 49268',15335,222,NULL,40,21941,0);
INSERT INTO "django_geo_db_location" VALUES(37570,NULL,'Parma, MI',15336,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37571,NULL,'Parma, MI 49269',15336,222,NULL,40,21942,0);
INSERT INTO "django_geo_db_location" VALUES(37572,NULL,'Petersburg, MI',15337,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37573,NULL,'Petersburg, MI 49270',15337,222,NULL,40,21943,0);
INSERT INTO "django_geo_db_location" VALUES(37574,NULL,'Pittsford, MI',15338,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37575,NULL,'Pittsford, MI 49271',15338,222,NULL,40,21944,0);
INSERT INTO "django_geo_db_location" VALUES(37576,NULL,'Pleasant Lake, MI',15339,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37577,NULL,'Pleasant Lake, MI 49272',15339,222,NULL,40,21945,0);
INSERT INTO "django_geo_db_location" VALUES(37578,NULL,'Reading, MI',15340,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37579,NULL,'Reading, MI 49274',15340,222,NULL,40,21946,0);
INSERT INTO "django_geo_db_location" VALUES(37580,NULL,'Ridgeway, MI',15341,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37581,NULL,'Ridgeway, MI 49275',15341,222,NULL,40,21947,0);
INSERT INTO "django_geo_db_location" VALUES(37582,NULL,'Riga, MI',15342,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37583,NULL,'Riga, MI 49276',15342,222,NULL,40,21948,0);
INSERT INTO "django_geo_db_location" VALUES(37584,NULL,'Rives Junction, MI',15343,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37585,NULL,'Rives Junction, MI 49277',15343,222,NULL,40,21949,0);
INSERT INTO "django_geo_db_location" VALUES(37586,NULL,'Rollin, MI',15344,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37587,NULL,'Rollin, MI 49278',15344,222,NULL,40,21950,0);
INSERT INTO "django_geo_db_location" VALUES(37588,NULL,'Sand Creek, MI',15345,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37589,NULL,'Sand Creek, MI 49279',15345,222,NULL,40,21951,0);
INSERT INTO "django_geo_db_location" VALUES(37590,NULL,'Seneca, MI',15346,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37591,NULL,'Seneca, MI 49280',15346,222,NULL,40,21952,0);
INSERT INTO "django_geo_db_location" VALUES(37592,NULL,'Somerset, MI',15347,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37593,NULL,'Somerset, MI 49281',15347,222,NULL,40,21953,0);
INSERT INTO "django_geo_db_location" VALUES(37594,NULL,'Somerset Center, MI',15348,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37595,NULL,'Somerset Center, MI 49282',15348,222,NULL,40,21954,0);
INSERT INTO "django_geo_db_location" VALUES(37596,NULL,'Spring Arbor, MI',15349,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37597,NULL,'Spring Arbor, MI 49283',15349,222,NULL,40,21955,0);
INSERT INTO "django_geo_db_location" VALUES(37598,NULL,'Springport, MI',15350,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37599,NULL,'Springport, MI 49284',15350,222,NULL,40,21956,0);
INSERT INTO "django_geo_db_location" VALUES(37600,NULL,'Stockbridge, MI',15351,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37601,NULL,'Stockbridge, MI 49285',15351,222,NULL,40,21957,0);
INSERT INTO "django_geo_db_location" VALUES(37602,NULL,'Tecumseh, MI',15352,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37603,NULL,'Tecumseh, MI 49286',15352,222,NULL,40,21958,0);
INSERT INTO "django_geo_db_location" VALUES(37604,NULL,'Tipton, MI',15353,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37605,NULL,'Tipton, MI 49287',15353,222,NULL,40,21959,0);
INSERT INTO "django_geo_db_location" VALUES(37606,NULL,'Waldron, MI',15354,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37607,NULL,'Waldron, MI 49288',15354,222,NULL,40,21960,0);
INSERT INTO "django_geo_db_location" VALUES(37608,NULL,'Weston, MI',15355,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37609,NULL,'Weston, MI 49289',15355,222,NULL,40,21961,0);
INSERT INTO "django_geo_db_location" VALUES(37610,NULL,'Ada, MI',15356,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37611,NULL,'Ada, MI 49301',15356,222,NULL,40,21962,0);
INSERT INTO "django_geo_db_location" VALUES(37612,NULL,'Alto, MI',15357,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37613,NULL,'Alto, MI 49302',15357,222,NULL,40,21963,0);
INSERT INTO "django_geo_db_location" VALUES(37614,NULL,'Bailey, MI',15358,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37615,NULL,'Bailey, MI 49303',15358,222,NULL,40,21964,0);
INSERT INTO "django_geo_db_location" VALUES(37616,NULL,'Baldwin, MI',15359,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37617,NULL,'Baldwin, MI 49304',15359,222,NULL,40,21965,0);
INSERT INTO "django_geo_db_location" VALUES(37618,NULL,'Barryton, MI',15360,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37619,NULL,'Barryton, MI 49305',15360,222,NULL,40,21966,0);
INSERT INTO "django_geo_db_location" VALUES(37620,NULL,'Belmont, MI',15361,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37621,NULL,'Belmont, MI 49306',15361,222,NULL,40,21967,0);
INSERT INTO "django_geo_db_location" VALUES(37622,NULL,'Big Rapids, MI',15362,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37623,NULL,'Big Rapids, MI 49307',15362,222,NULL,40,21968,0);
INSERT INTO "django_geo_db_location" VALUES(37624,NULL,'Bitely, MI',15363,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37625,NULL,'Bitely, MI 49309',15363,222,NULL,40,21969,0);
INSERT INTO "django_geo_db_location" VALUES(37626,NULL,'Blanchard, MI',15364,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37627,NULL,'Blanchard, MI 49310',15364,222,NULL,40,21970,0);
INSERT INTO "django_geo_db_location" VALUES(37628,NULL,'Bradley, MI',15365,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37629,NULL,'Bradley, MI 49311',15365,222,NULL,40,21971,0);
INSERT INTO "django_geo_db_location" VALUES(37630,NULL,'Brohman, MI',15366,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37631,NULL,'Brohman, MI 49312',15366,222,NULL,40,21972,0);
INSERT INTO "django_geo_db_location" VALUES(37632,NULL,'Burnips, MI',15367,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37633,NULL,'Burnips, MI 49314',15367,222,NULL,40,21973,0);
INSERT INTO "django_geo_db_location" VALUES(37634,NULL,'Byron Center, MI',15368,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37635,NULL,'Byron Center, MI 49315',15368,222,NULL,40,21974,0);
INSERT INTO "django_geo_db_location" VALUES(37636,NULL,'Caledonia, MI',15369,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37637,NULL,'Caledonia, MI 49316',15369,222,NULL,40,21975,0);
INSERT INTO "django_geo_db_location" VALUES(37638,NULL,'Cannonsburg, MI',15370,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37639,NULL,'Cannonsburg, MI 49317',15370,222,NULL,40,21976,0);
INSERT INTO "django_geo_db_location" VALUES(37640,NULL,'Casnovia, MI',15371,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37641,NULL,'Casnovia, MI 49318',15371,222,NULL,40,21977,0);
INSERT INTO "django_geo_db_location" VALUES(37642,NULL,'Cedar Springs, MI',15372,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37643,NULL,'Cedar Springs, MI 49319',15372,222,NULL,40,21978,0);
INSERT INTO "django_geo_db_location" VALUES(37644,NULL,'Chippewa Lake, MI',15373,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37645,NULL,'Chippewa Lake, MI 49320',15373,222,NULL,40,21979,0);
INSERT INTO "django_geo_db_location" VALUES(37646,NULL,'Comstock Park, MI',15374,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37647,NULL,'Comstock Park, MI 49321',15374,222,NULL,40,21980,0);
INSERT INTO "django_geo_db_location" VALUES(37648,NULL,'Coral, MI',15375,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37649,NULL,'Coral, MI 49322',15375,222,NULL,40,21981,0);
INSERT INTO "django_geo_db_location" VALUES(37650,NULL,'Dorr, MI',15376,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37651,NULL,'Dorr, MI 49323',15376,222,NULL,40,21982,0);
INSERT INTO "django_geo_db_location" VALUES(37652,NULL,'Freeport, MI',15377,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37653,NULL,'Freeport, MI 49325',15377,222,NULL,40,21983,0);
INSERT INTO "django_geo_db_location" VALUES(37654,NULL,'Gowen, MI',15378,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37655,NULL,'Gowen, MI 49326',15378,222,NULL,40,21984,0);
INSERT INTO "django_geo_db_location" VALUES(37656,NULL,'Grant, MI',15379,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37657,NULL,'Grant, MI 49327',15379,222,NULL,40,21985,0);
INSERT INTO "django_geo_db_location" VALUES(37658,NULL,'Hopkins, MI',15380,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37659,NULL,'Hopkins, MI 49328',15380,222,NULL,40,21986,0);
INSERT INTO "django_geo_db_location" VALUES(37660,NULL,'Howard City, MI',15381,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37661,NULL,'Howard City, MI 49329',15381,222,NULL,40,21987,0);
INSERT INTO "django_geo_db_location" VALUES(37662,NULL,'Kent City, MI',15382,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37663,NULL,'Kent City, MI 49330',15382,222,NULL,40,21988,0);
INSERT INTO "django_geo_db_location" VALUES(37664,NULL,'Lowell, MI',15383,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37665,NULL,'Lowell, MI 49331',15383,222,NULL,40,21989,0);
INSERT INTO "django_geo_db_location" VALUES(37666,NULL,'Mecosta, MI',15384,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37667,NULL,'Mecosta, MI 49332',15384,222,NULL,40,21990,0);
INSERT INTO "django_geo_db_location" VALUES(37668,NULL,'Middleville, MI',15385,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37669,NULL,'Middleville, MI 49333',15385,222,NULL,40,21991,0);
INSERT INTO "django_geo_db_location" VALUES(37670,NULL,'Moline, MI',15386,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37671,NULL,'Moline, MI 49335',15386,222,NULL,40,21992,0);
INSERT INTO "django_geo_db_location" VALUES(37672,NULL,'Morley, MI',15387,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37673,NULL,'Morley, MI 49336',15387,222,NULL,40,21993,0);
INSERT INTO "django_geo_db_location" VALUES(37674,NULL,'Newaygo, MI',15388,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37675,NULL,'Newaygo, MI 49337',15388,222,NULL,40,21994,0);
INSERT INTO "django_geo_db_location" VALUES(37676,NULL,'Paris, MI',15389,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37677,NULL,'Paris, MI 49338',15389,222,NULL,40,21995,0);
INSERT INTO "django_geo_db_location" VALUES(37678,NULL,'Pierson, MI',15390,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37679,NULL,'Pierson, MI 49339',15390,222,NULL,40,21996,0);
INSERT INTO "django_geo_db_location" VALUES(37680,NULL,'Remus, MI',15391,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37681,NULL,'Remus, MI 49340',15391,222,NULL,40,21997,0);
INSERT INTO "django_geo_db_location" VALUES(37682,NULL,'Rockford, MI',15392,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37683,NULL,'Rockford, MI 49341',15392,222,NULL,40,21998,0);
INSERT INTO "django_geo_db_location" VALUES(37684,NULL,'Rodney, MI',15393,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37685,NULL,'Rodney, MI 49342',15393,222,NULL,40,21999,0);
INSERT INTO "django_geo_db_location" VALUES(37686,NULL,'Sand Lake, MI',15394,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37687,NULL,'Sand Lake, MI 49343',15394,222,NULL,40,22000,0);
INSERT INTO "django_geo_db_location" VALUES(37688,NULL,'Shelbyville, MI',15395,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37689,NULL,'Shelbyville, MI 49344',15395,222,NULL,40,22001,0);
INSERT INTO "django_geo_db_location" VALUES(37690,NULL,'Sparta, MI',15396,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37691,NULL,'Sparta, MI 49345',15396,222,NULL,40,22002,0);
INSERT INTO "django_geo_db_location" VALUES(37692,NULL,'Stanwood, MI',15397,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37693,NULL,'Stanwood, MI 49346',15397,222,NULL,40,22003,0);
INSERT INTO "django_geo_db_location" VALUES(37694,NULL,'Trufant, MI',15398,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37695,NULL,'Trufant, MI 49347',15398,222,NULL,40,22004,0);
INSERT INTO "django_geo_db_location" VALUES(37696,NULL,'Wayland, MI',15399,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37697,NULL,'Wayland, MI 49348',15399,222,NULL,40,22005,0);
INSERT INTO "django_geo_db_location" VALUES(37698,NULL,'White Cloud, MI',15400,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37699,NULL,'White Cloud, MI 49349',15400,222,NULL,40,22006,0);
INSERT INTO "django_geo_db_location" VALUES(37700,NULL,'Rockford, MI 49351',15392,222,NULL,40,22007,0);
INSERT INTO "django_geo_db_location" VALUES(37701,NULL,'Ada, MI 49355',15356,222,NULL,40,22008,0);
INSERT INTO "django_geo_db_location" VALUES(37702,NULL,'Ada, MI 49356',15356,222,NULL,40,22009,0);
INSERT INTO "django_geo_db_location" VALUES(37703,NULL,'Ada, MI 49357',15356,222,NULL,40,22010,0);
INSERT INTO "django_geo_db_location" VALUES(37704,NULL,'Slagle, MI',15401,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37705,NULL,'Slagle, MI 49368',15401,222,NULL,40,22011,0);
INSERT INTO "django_geo_db_location" VALUES(37706,NULL,'Lincoln, MI 49394',15092,222,NULL,40,22012,0);
INSERT INTO "django_geo_db_location" VALUES(37707,NULL,'Allendale, MI',15402,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37708,NULL,'Allendale, MI 49401',15402,222,NULL,40,22013,0);
INSERT INTO "django_geo_db_location" VALUES(37709,NULL,'Branch, MI',15403,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37710,NULL,'Branch, MI 49402',15403,222,NULL,40,22014,0);
INSERT INTO "django_geo_db_location" VALUES(37711,NULL,'Conklin, MI',15404,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37712,NULL,'Conklin, MI 49403',15404,222,NULL,40,22015,0);
INSERT INTO "django_geo_db_location" VALUES(37713,NULL,'Coopersville, MI',15405,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37714,NULL,'Coopersville, MI 49404',15405,222,NULL,40,22016,0);
INSERT INTO "django_geo_db_location" VALUES(37715,NULL,'Custer, MI',15406,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37716,NULL,'Custer, MI 49405',15406,222,NULL,40,22017,0);
INSERT INTO "django_geo_db_location" VALUES(37717,NULL,'Douglas, MI',15407,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37718,NULL,'Douglas, MI 49406',15407,222,NULL,40,22018,0);
INSERT INTO "django_geo_db_location" VALUES(37719,NULL,'Fennville, MI',15408,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37720,NULL,'Fennville, MI 49408',15408,222,NULL,40,22019,0);
INSERT INTO "django_geo_db_location" VALUES(37721,NULL,'Ferrysburg, MI',15409,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37722,NULL,'Ferrysburg, MI 49409',15409,222,NULL,40,22020,0);
INSERT INTO "django_geo_db_location" VALUES(37723,NULL,'Fountain, MI',15410,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37724,NULL,'Fountain, MI 49410',15410,222,NULL,40,22021,0);
INSERT INTO "django_geo_db_location" VALUES(37725,NULL,'Free Soil, MI',15411,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37726,NULL,'Free Soil, MI 49411',15411,222,NULL,40,22022,0);
INSERT INTO "django_geo_db_location" VALUES(37727,NULL,'Fremont, MI',15412,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37728,NULL,'Fremont, MI 49412',15412,222,NULL,40,22023,0);
INSERT INTO "django_geo_db_location" VALUES(37729,NULL,'Fremont, MI 49413',15412,222,NULL,40,22024,0);
INSERT INTO "django_geo_db_location" VALUES(37730,NULL,'Fruitport, MI',15413,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37731,NULL,'Fruitport, MI 49415',15413,222,NULL,40,22025,0);
INSERT INTO "django_geo_db_location" VALUES(37732,NULL,'Glenn, MI',15414,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37733,NULL,'Glenn, MI 49416',15414,222,NULL,40,22026,0);
INSERT INTO "django_geo_db_location" VALUES(37734,NULL,'Grand Haven, MI',15415,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37735,NULL,'Grand Haven, MI 49417',15415,222,NULL,40,22027,0);
INSERT INTO "django_geo_db_location" VALUES(37736,NULL,'Grandville, MI',15416,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37737,NULL,'Grandville, MI 49418',15416,222,NULL,40,22028,0);
INSERT INTO "django_geo_db_location" VALUES(37738,NULL,'Hamilton, MI',15417,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37739,NULL,'Hamilton, MI 49419',15417,222,NULL,40,22029,0);
INSERT INTO "django_geo_db_location" VALUES(37740,NULL,'Hart, MI',15418,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37741,NULL,'Hart, MI 49420',15418,222,NULL,40,22030,0);
INSERT INTO "django_geo_db_location" VALUES(37742,NULL,'Hesperia, MI',15419,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37743,NULL,'Hesperia, MI 49421',15419,222,NULL,40,22031,0);
INSERT INTO "django_geo_db_location" VALUES(37744,NULL,'Holland, MI',15420,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37745,NULL,'Holland, MI 49422',15420,222,NULL,40,22032,0);
INSERT INTO "django_geo_db_location" VALUES(37746,NULL,'Holland, MI 49423',15420,222,NULL,40,22033,0);
INSERT INTO "django_geo_db_location" VALUES(37747,NULL,'Holland, MI 49424',15420,222,NULL,40,22034,0);
INSERT INTO "django_geo_db_location" VALUES(37748,NULL,'Holton, MI',15421,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37749,NULL,'Holton, MI 49425',15421,222,NULL,40,22035,0);
INSERT INTO "django_geo_db_location" VALUES(37750,NULL,'Hudsonville, MI',15422,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37751,NULL,'Hudsonville, MI 49426',15422,222,NULL,40,22036,0);
INSERT INTO "django_geo_db_location" VALUES(37752,NULL,'Jamestown, MI',15423,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37753,NULL,'Jamestown, MI 49427',15423,222,NULL,40,22037,0);
INSERT INTO "django_geo_db_location" VALUES(37754,NULL,'Jenison, MI',15424,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37755,NULL,'Jenison, MI 49428',15424,222,NULL,40,22038,0);
INSERT INTO "django_geo_db_location" VALUES(37756,NULL,'Jenison, MI 49429',15424,222,NULL,40,22039,0);
INSERT INTO "django_geo_db_location" VALUES(37757,NULL,'Lamont, MI',15425,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37758,NULL,'Lamont, MI 49430',15425,222,NULL,40,22040,0);
INSERT INTO "django_geo_db_location" VALUES(37759,NULL,'Ludington, MI',15426,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37760,NULL,'Ludington, MI 49431',15426,222,NULL,40,22041,0);
INSERT INTO "django_geo_db_location" VALUES(37761,NULL,'Macatawa, MI',15427,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37762,NULL,'Macatawa, MI 49434',15427,222,NULL,40,22042,0);
INSERT INTO "django_geo_db_location" VALUES(37763,NULL,'Marne, MI',15428,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37764,NULL,'Marne, MI 49435',15428,222,NULL,40,22043,0);
INSERT INTO "django_geo_db_location" VALUES(37765,NULL,'Mears, MI',15429,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37766,NULL,'Mears, MI 49436',15429,222,NULL,40,22044,0);
INSERT INTO "django_geo_db_location" VALUES(37767,NULL,'Montague, MI',15430,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37768,NULL,'Montague, MI 49437',15430,222,NULL,40,22045,0);
INSERT INTO "django_geo_db_location" VALUES(37769,NULL,'Muskegon, MI',15431,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37770,NULL,'Muskegon, MI 49440',15431,222,NULL,40,22046,0);
INSERT INTO "django_geo_db_location" VALUES(37771,NULL,'Muskegon, MI 49441',15431,222,NULL,40,22047,0);
INSERT INTO "django_geo_db_location" VALUES(37772,NULL,'Muskegon, MI 49442',15431,222,NULL,40,22048,0);
INSERT INTO "django_geo_db_location" VALUES(37773,NULL,'Muskegon, MI 49443',15431,222,NULL,40,22049,0);
INSERT INTO "django_geo_db_location" VALUES(37774,NULL,'Muskegon, MI 49444',15431,222,NULL,40,22050,0);
INSERT INTO "django_geo_db_location" VALUES(37775,NULL,'Muskegon, MI 49445',15431,222,NULL,40,22051,0);
INSERT INTO "django_geo_db_location" VALUES(37776,NULL,'New Era, MI',15432,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37777,NULL,'New Era, MI 49446',15432,222,NULL,40,22052,0);
INSERT INTO "django_geo_db_location" VALUES(37778,NULL,'Nunica, MI',15433,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37779,NULL,'Nunica, MI 49448',15433,222,NULL,40,22053,0);
INSERT INTO "django_geo_db_location" VALUES(37780,NULL,'Pentwater, MI',15434,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37781,NULL,'Pentwater, MI 49449',15434,222,NULL,40,22054,0);
INSERT INTO "django_geo_db_location" VALUES(37782,NULL,'Pullman, MI',15435,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37783,NULL,'Pullman, MI 49450',15435,222,NULL,40,22055,0);
INSERT INTO "django_geo_db_location" VALUES(37784,NULL,'Ravenna, MI',15436,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37785,NULL,'Ravenna, MI 49451',15436,222,NULL,40,22056,0);
INSERT INTO "django_geo_db_location" VALUES(37786,NULL,'Rothbury, MI',15437,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37787,NULL,'Rothbury, MI 49452',15437,222,NULL,40,22057,0);
INSERT INTO "django_geo_db_location" VALUES(37788,NULL,'Saugatuck, MI',15438,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37789,NULL,'Saugatuck, MI 49453',15438,222,NULL,40,22058,0);
INSERT INTO "django_geo_db_location" VALUES(37790,NULL,'Scottville, MI',15439,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37791,NULL,'Scottville, MI 49454',15439,222,NULL,40,22059,0);
INSERT INTO "django_geo_db_location" VALUES(37792,NULL,'Shelby, MI',15440,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37793,NULL,'Shelby, MI 49455',15440,222,NULL,40,22060,0);
INSERT INTO "django_geo_db_location" VALUES(37794,NULL,'Spring Lake, MI',15441,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37795,NULL,'Spring Lake, MI 49456',15441,222,NULL,40,22061,0);
INSERT INTO "django_geo_db_location" VALUES(37796,NULL,'Twin Lake, MI',15442,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37797,NULL,'Twin Lake, MI 49457',15442,222,NULL,40,22062,0);
INSERT INTO "django_geo_db_location" VALUES(37798,NULL,'Walhalla, MI',15443,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37799,NULL,'Walhalla, MI 49458',15443,222,NULL,40,22063,0);
INSERT INTO "django_geo_db_location" VALUES(37800,NULL,'Walkerville, MI',15444,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37801,NULL,'Walkerville, MI 49459',15444,222,NULL,40,22064,0);
INSERT INTO "django_geo_db_location" VALUES(37802,NULL,'West Olive, MI',15445,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37803,NULL,'West Olive, MI 49460',15445,222,NULL,40,22065,0);
INSERT INTO "django_geo_db_location" VALUES(37804,NULL,'Whitehall, MI',15446,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37805,NULL,'Whitehall, MI 49461',15446,222,NULL,40,22066,0);
INSERT INTO "django_geo_db_location" VALUES(37806,NULL,'Wabaningo, MI',15447,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37807,NULL,'Wabaningo, MI 49463',15447,222,NULL,40,22067,0);
INSERT INTO "django_geo_db_location" VALUES(37808,NULL,'Zeeland, MI',15448,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37809,NULL,'Zeeland, MI 49464',15448,222,NULL,40,22068,0);
INSERT INTO "django_geo_db_location" VALUES(37810,NULL,'Grandville, MI 49468',15416,222,NULL,40,22069,0);
INSERT INTO "django_geo_db_location" VALUES(37811,NULL,'Grand Rapids, MI',15449,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37812,NULL,'Grand Rapids, MI 49501',15449,222,NULL,40,22070,0);
INSERT INTO "django_geo_db_location" VALUES(37813,NULL,'Grand Rapids, MI 49502',15449,222,NULL,40,22071,0);
INSERT INTO "django_geo_db_location" VALUES(37814,NULL,'Grand Rapids, MI 49503',15449,222,NULL,40,22072,0);
INSERT INTO "django_geo_db_location" VALUES(37815,NULL,'Grand Rapids, MI 49504',15449,222,NULL,40,22073,0);
INSERT INTO "django_geo_db_location" VALUES(37816,NULL,'Grand Rapids, MI 49505',15449,222,NULL,40,22074,0);
INSERT INTO "django_geo_db_location" VALUES(37817,NULL,'Grand Rapids, MI 49506',15449,222,NULL,40,22075,0);
INSERT INTO "django_geo_db_location" VALUES(37818,NULL,'Grand Rapids, MI 49507',15449,222,NULL,40,22076,0);
INSERT INTO "django_geo_db_location" VALUES(37819,NULL,'Grand Rapids, MI 49508',15449,222,NULL,40,22077,0);
INSERT INTO "django_geo_db_location" VALUES(37820,NULL,'Grand Rapids, MI 49509',15449,222,NULL,40,22078,0);
INSERT INTO "django_geo_db_location" VALUES(37821,NULL,'Grand Rapids, MI 49510',15449,222,NULL,40,22079,0);
INSERT INTO "django_geo_db_location" VALUES(37822,NULL,'Grand Rapids, MI 49512',15449,222,NULL,40,22080,0);
INSERT INTO "django_geo_db_location" VALUES(37823,NULL,'Grand Rapids, MI 49514',15449,222,NULL,40,22081,0);
INSERT INTO "django_geo_db_location" VALUES(37824,NULL,'Grand Rapids, MI 49515',15449,222,NULL,40,22082,0);
INSERT INTO "django_geo_db_location" VALUES(37825,NULL,'Grand Rapids, MI 49516',15449,222,NULL,40,22083,0);
INSERT INTO "django_geo_db_location" VALUES(37826,NULL,'Grand Rapids, MI 49518',15449,222,NULL,40,22084,0);
INSERT INTO "django_geo_db_location" VALUES(37827,NULL,'Grand Rapids, MI 49523',15449,222,NULL,40,22085,0);
INSERT INTO "django_geo_db_location" VALUES(37828,NULL,'Grand Rapids, MI 49525',15449,222,NULL,40,22086,0);
INSERT INTO "django_geo_db_location" VALUES(37829,NULL,'Grand Rapids, MI 49530',15449,222,NULL,40,22087,0);
INSERT INTO "django_geo_db_location" VALUES(37830,NULL,'Grand Rapids, MI 49544',15449,222,NULL,40,22088,0);
INSERT INTO "django_geo_db_location" VALUES(37831,NULL,'Grand Rapids, MI 49546',15449,222,NULL,40,22089,0);
INSERT INTO "django_geo_db_location" VALUES(37832,NULL,'Grand Rapids, MI 49548',15449,222,NULL,40,22090,0);
INSERT INTO "django_geo_db_location" VALUES(37833,NULL,'Grand Rapids, MI 49550',15449,222,NULL,40,22091,0);
INSERT INTO "django_geo_db_location" VALUES(37834,NULL,'Grand Rapids, MI 49555',15449,222,NULL,40,22092,0);
INSERT INTO "django_geo_db_location" VALUES(37835,NULL,'Grand Rapids, MI 49560',15449,222,NULL,40,22093,0);
INSERT INTO "django_geo_db_location" VALUES(37836,NULL,'Glen Arbor, MI',15450,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37837,NULL,'Glen Arbor, MI 49564',15450,222,NULL,40,22094,0);
INSERT INTO "django_geo_db_location" VALUES(37838,NULL,'Newkirk, MI',15451,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37839,NULL,'Newkirk, MI 49565',15451,222,NULL,40,22095,0);
INSERT INTO "django_geo_db_location" VALUES(37840,NULL,'Colfax, MI',15452,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37841,NULL,'Colfax, MI 49582',15452,222,NULL,40,22096,0);
INSERT INTO "django_geo_db_location" VALUES(37842,NULL,'Grand Rapids, MI 49588',15449,222,NULL,40,22097,0);
INSERT INTO "django_geo_db_location" VALUES(37843,NULL,'Whitewater, MI',15453,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37844,NULL,'Whitewater, MI 49590',15453,222,NULL,40,22098,0);
INSERT INTO "django_geo_db_location" VALUES(37845,NULL,'Grand Rapids, MI 49599',15449,222,NULL,40,22099,0);
INSERT INTO "django_geo_db_location" VALUES(37846,NULL,'Cadillac, MI',15454,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37847,NULL,'Cadillac, MI 49601',15454,222,NULL,40,22100,0);
INSERT INTO "django_geo_db_location" VALUES(37848,NULL,'Acme, MI',15455,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37849,NULL,'Acme, MI 49610',15455,222,NULL,40,22101,0);
INSERT INTO "django_geo_db_location" VALUES(37850,NULL,'Alba, MI',15456,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37851,NULL,'Alba, MI 49611',15456,222,NULL,40,22102,0);
INSERT INTO "django_geo_db_location" VALUES(37852,NULL,'Alden, MI',15457,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37853,NULL,'Alden, MI 49612',15457,222,NULL,40,22103,0);
INSERT INTO "django_geo_db_location" VALUES(37854,NULL,'Arcadia, MI',15458,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37855,NULL,'Arcadia, MI 49613',15458,222,NULL,40,22104,0);
INSERT INTO "django_geo_db_location" VALUES(37856,NULL,'Bear Lake, MI',15459,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37857,NULL,'Bear Lake, MI 49614',15459,222,NULL,40,22105,0);
INSERT INTO "django_geo_db_location" VALUES(37858,NULL,'Bellaire, MI',15460,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37859,NULL,'Bellaire, MI 49615',15460,222,NULL,40,22106,0);
INSERT INTO "django_geo_db_location" VALUES(37860,NULL,'Benzonia, MI',15461,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37861,NULL,'Benzonia, MI 49616',15461,222,NULL,40,22107,0);
INSERT INTO "django_geo_db_location" VALUES(37862,NULL,'Beulah, MI',15462,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37863,NULL,'Beulah, MI 49617',15462,222,NULL,40,22108,0);
INSERT INTO "django_geo_db_location" VALUES(37864,NULL,'Boon, MI',15463,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37865,NULL,'Boon, MI 49618',15463,222,NULL,40,22109,0);
INSERT INTO "django_geo_db_location" VALUES(37866,NULL,'Brethren, MI',15464,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37867,NULL,'Brethren, MI 49619',15464,222,NULL,40,22110,0);
INSERT INTO "django_geo_db_location" VALUES(37868,NULL,'Buckley, MI',15465,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37869,NULL,'Buckley, MI 49620',15465,222,NULL,40,22111,0);
INSERT INTO "django_geo_db_location" VALUES(37870,NULL,'Cedar, MI',15466,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37871,NULL,'Cedar, MI 49621',15466,222,NULL,40,22112,0);
INSERT INTO "django_geo_db_location" VALUES(37872,NULL,'Central Lake, MI',15467,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37873,NULL,'Central Lake, MI 49622',15467,222,NULL,40,22113,0);
INSERT INTO "django_geo_db_location" VALUES(37874,NULL,'Chase, MI',15468,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37875,NULL,'Chase, MI 49623',15468,222,NULL,40,22114,0);
INSERT INTO "django_geo_db_location" VALUES(37876,NULL,'Copemish, MI',15469,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37877,NULL,'Copemish, MI 49625',15469,222,NULL,40,22115,0);
INSERT INTO "django_geo_db_location" VALUES(37878,NULL,'Eastlake, MI',15470,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37879,NULL,'Eastlake, MI 49626',15470,222,NULL,40,22116,0);
INSERT INTO "django_geo_db_location" VALUES(37880,NULL,'Eastport, MI',15471,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37881,NULL,'Eastport, MI 49627',15471,222,NULL,40,22117,0);
INSERT INTO "django_geo_db_location" VALUES(37882,NULL,'Elberta, MI',15472,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37883,NULL,'Elberta, MI 49628',15472,222,NULL,40,22118,0);
INSERT INTO "django_geo_db_location" VALUES(37884,NULL,'Elk Rapids, MI',15473,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37885,NULL,'Elk Rapids, MI 49629',15473,222,NULL,40,22119,0);
INSERT INTO "django_geo_db_location" VALUES(37886,NULL,'Empire, MI',15474,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37887,NULL,'Empire, MI 49630',15474,222,NULL,40,22120,0);
INSERT INTO "django_geo_db_location" VALUES(37888,NULL,'Evart, MI',15475,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37889,NULL,'Evart, MI 49631',15475,222,NULL,40,22121,0);
INSERT INTO "django_geo_db_location" VALUES(37890,NULL,'Falmouth, MI',15476,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37891,NULL,'Falmouth, MI 49632',15476,222,NULL,40,22122,0);
INSERT INTO "django_geo_db_location" VALUES(37892,NULL,'Fife Lake, MI',15477,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37893,NULL,'Fife Lake, MI 49633',15477,222,NULL,40,22123,0);
INSERT INTO "django_geo_db_location" VALUES(37894,NULL,'Filer City, MI',15478,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37895,NULL,'Filer City, MI 49634',15478,222,NULL,40,22124,0);
INSERT INTO "django_geo_db_location" VALUES(37896,NULL,'Frankfort, MI',15479,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37897,NULL,'Frankfort, MI 49635',15479,222,NULL,40,22125,0);
INSERT INTO "django_geo_db_location" VALUES(37898,NULL,'Glen Arbor, MI 49636',15450,222,NULL,40,22126,0);
INSERT INTO "django_geo_db_location" VALUES(37899,NULL,'Grawn, MI',15480,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37900,NULL,'Grawn, MI 49637',15480,222,NULL,40,22127,0);
INSERT INTO "django_geo_db_location" VALUES(37901,NULL,'Harrietta, MI',15481,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37902,NULL,'Harrietta, MI 49638',15481,222,NULL,40,22128,0);
INSERT INTO "django_geo_db_location" VALUES(37903,NULL,'Hersey, MI',15482,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37904,NULL,'Hersey, MI 49639',15482,222,NULL,40,22129,0);
INSERT INTO "django_geo_db_location" VALUES(37905,NULL,'Honor, MI',15483,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37906,NULL,'Honor, MI 49640',15483,222,NULL,40,22130,0);
INSERT INTO "django_geo_db_location" VALUES(37907,NULL,'Idlewild, MI',15484,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37908,NULL,'Idlewild, MI 49642',15484,222,NULL,40,22131,0);
INSERT INTO "django_geo_db_location" VALUES(37909,NULL,'Interlochen, MI',15485,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37910,NULL,'Interlochen, MI 49643',15485,222,NULL,40,22132,0);
INSERT INTO "django_geo_db_location" VALUES(37911,NULL,'Irons, MI',15486,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37912,NULL,'Irons, MI 49644',15486,222,NULL,40,22133,0);
INSERT INTO "django_geo_db_location" VALUES(37913,NULL,'Kaleva, MI',15487,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37914,NULL,'Kaleva, MI 49645',15487,222,NULL,40,22134,0);
INSERT INTO "django_geo_db_location" VALUES(37915,NULL,'Kalkaska, MI',15488,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37916,NULL,'Kalkaska, MI 49646',15488,222,NULL,40,22135,0);
INSERT INTO "django_geo_db_location" VALUES(37917,NULL,'Paradise, MI',15489,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37918,NULL,'Paradise, MI 49647',15489,222,NULL,40,22136,0);
INSERT INTO "django_geo_db_location" VALUES(37919,NULL,'Kewadin, MI',15490,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37920,NULL,'Kewadin, MI 49648',15490,222,NULL,40,22137,0);
INSERT INTO "django_geo_db_location" VALUES(37921,NULL,'Kingsley, MI',15491,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37922,NULL,'Kingsley, MI 49649',15491,222,NULL,40,22138,0);
INSERT INTO "django_geo_db_location" VALUES(37923,NULL,'Lake Ann, MI',15492,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37924,NULL,'Lake Ann, MI 49650',15492,222,NULL,40,22139,0);
INSERT INTO "django_geo_db_location" VALUES(37925,NULL,'Lake City, MI',15493,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37926,NULL,'Lake City, MI 49651',15493,222,NULL,40,22140,0);
INSERT INTO "django_geo_db_location" VALUES(37927,NULL,'Yates, MI',15494,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37928,NULL,'Yates, MI 49652',15494,222,NULL,40,22141,0);
INSERT INTO "django_geo_db_location" VALUES(37929,NULL,'Lake Leelanau, MI',15495,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37930,NULL,'Lake Leelanau, MI 49653',15495,222,NULL,40,22142,0);
INSERT INTO "django_geo_db_location" VALUES(37931,NULL,'Leland, MI',15496,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37932,NULL,'Leland, MI 49654',15496,222,NULL,40,22143,0);
INSERT INTO "django_geo_db_location" VALUES(37933,NULL,'Leroy, MI',15497,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37934,NULL,'Leroy, MI 49655',15497,222,NULL,40,22144,0);
INSERT INTO "django_geo_db_location" VALUES(37935,NULL,'Luther, MI',15498,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37936,NULL,'Luther, MI 49656',15498,222,NULL,40,22145,0);
INSERT INTO "django_geo_db_location" VALUES(37937,NULL,'McBain, MI',15499,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37938,NULL,'McBain, MI 49657',15499,222,NULL,40,22146,0);
INSERT INTO "django_geo_db_location" VALUES(37939,NULL,'Mancelona, MI',15500,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37940,NULL,'Mancelona, MI 49659',15500,222,NULL,40,22147,0);
INSERT INTO "django_geo_db_location" VALUES(37941,NULL,'Manistee, MI',15501,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37942,NULL,'Manistee, MI 49660',15501,222,NULL,40,22148,0);
INSERT INTO "django_geo_db_location" VALUES(37943,NULL,'Manton, MI',15502,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37944,NULL,'Manton, MI 49663',15502,222,NULL,40,22149,0);
INSERT INTO "django_geo_db_location" VALUES(37945,NULL,'Maple City, MI',15503,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37946,NULL,'Maple City, MI 49664',15503,222,NULL,40,22150,0);
INSERT INTO "django_geo_db_location" VALUES(37947,NULL,'Marion, MI',15504,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37948,NULL,'Marion, MI 49665',15504,222,NULL,40,22151,0);
INSERT INTO "django_geo_db_location" VALUES(37949,NULL,'Mayfield, MI',15505,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37950,NULL,'Mayfield, MI 49666',15505,222,NULL,40,22152,0);
INSERT INTO "django_geo_db_location" VALUES(37951,NULL,'Merritt, MI',15506,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37952,NULL,'Merritt, MI 49667',15506,222,NULL,40,22153,0);
INSERT INTO "django_geo_db_location" VALUES(37953,NULL,'Mesick, MI',15507,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37954,NULL,'Mesick, MI 49668',15507,222,NULL,40,22154,0);
INSERT INTO "django_geo_db_location" VALUES(37955,NULL,'Northport, MI',15508,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37956,NULL,'Northport, MI 49670',15508,222,NULL,40,22155,0);
INSERT INTO "django_geo_db_location" VALUES(37957,NULL,'Old Mission, MI',15509,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37958,NULL,'Old Mission, MI 49673',15509,222,NULL,40,22156,0);
INSERT INTO "django_geo_db_location" VALUES(37959,NULL,'Omena, MI',15510,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37960,NULL,'Omena, MI 49674',15510,222,NULL,40,22157,0);
INSERT INTO "django_geo_db_location" VALUES(37961,NULL,'Onekama, MI',15511,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37962,NULL,'Onekama, MI 49675',15511,222,NULL,40,22158,0);
INSERT INTO "django_geo_db_location" VALUES(37963,NULL,'Rapid City, MI',15512,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37964,NULL,'Rapid City, MI 49676',15512,222,NULL,40,22159,0);
INSERT INTO "django_geo_db_location" VALUES(37965,NULL,'Reed City, MI',15513,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37966,NULL,'Reed City, MI 49677',15513,222,NULL,40,22160,0);
INSERT INTO "django_geo_db_location" VALUES(37967,NULL,'Sears, MI',15514,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37968,NULL,'Sears, MI 49679',15514,222,NULL,40,22161,0);
INSERT INTO "django_geo_db_location" VALUES(37969,NULL,'South Boardman, MI',15515,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37970,NULL,'South Boardman, MI 49680',15515,222,NULL,40,22162,0);
INSERT INTO "django_geo_db_location" VALUES(37971,NULL,'Suttons Bay, MI',15516,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37972,NULL,'Suttons Bay, MI 49682',15516,222,NULL,40,22163,0);
INSERT INTO "django_geo_db_location" VALUES(37973,NULL,'Thompsonville, MI',15517,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37974,NULL,'Thompsonville, MI 49683',15517,222,NULL,40,22164,0);
INSERT INTO "django_geo_db_location" VALUES(37975,NULL,'Traverse City, MI',15518,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37976,NULL,'Traverse City, MI 49684',15518,222,NULL,40,22165,0);
INSERT INTO "django_geo_db_location" VALUES(37977,NULL,'Traverse City, MI 49685',15518,222,NULL,40,22166,0);
INSERT INTO "django_geo_db_location" VALUES(37978,NULL,'Traverse City, MI 49686',15518,222,NULL,40,22167,0);
INSERT INTO "django_geo_db_location" VALUES(37979,NULL,'Tustin, MI',15519,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37980,NULL,'Tustin, MI 49688',15519,222,NULL,40,22168,0);
INSERT INTO "django_geo_db_location" VALUES(37981,NULL,'Wellston, MI',15520,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37982,NULL,'Wellston, MI 49689',15520,222,NULL,40,22169,0);
INSERT INTO "django_geo_db_location" VALUES(37983,NULL,'Williamsburg, MI',15521,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37984,NULL,'Williamsburg, MI 49690',15521,222,NULL,40,22170,0);
INSERT INTO "django_geo_db_location" VALUES(37985,NULL,'Custer, MI 49695',15406,222,NULL,40,22171,0);
INSERT INTO "django_geo_db_location" VALUES(37986,NULL,'Traverse City, MI 49696',15518,222,NULL,40,22172,0);
INSERT INTO "django_geo_db_location" VALUES(37987,NULL,'Mackinaw City, MI',15522,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37988,NULL,'Mackinaw City, MI 49701',15522,222,NULL,40,22173,0);
INSERT INTO "django_geo_db_location" VALUES(37989,NULL,'Afton, MI',15523,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37990,NULL,'Afton, MI 49705',15523,222,NULL,40,22174,0);
INSERT INTO "django_geo_db_location" VALUES(37991,NULL,'Alanson, MI',15524,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37992,NULL,'Alanson, MI 49706',15524,222,NULL,40,22175,0);
INSERT INTO "django_geo_db_location" VALUES(37993,NULL,'Alpena, MI',15525,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37994,NULL,'Alpena, MI 49707',15525,222,NULL,40,22176,0);
INSERT INTO "django_geo_db_location" VALUES(37995,NULL,'Atlanta, MI',15526,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37996,NULL,'Atlanta, MI 49709',15526,222,NULL,40,22177,0);
INSERT INTO "django_geo_db_location" VALUES(37997,NULL,'Barbeau, MI',15527,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(37998,NULL,'Barbeau, MI 49710',15527,222,NULL,40,22178,0);
INSERT INTO "django_geo_db_location" VALUES(37999,NULL,'Bay Shore, MI',15528,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38000,NULL,'Bay Shore, MI 49711',15528,222,NULL,40,22179,0);
INSERT INTO "django_geo_db_location" VALUES(38001,NULL,'Boyne City, MI',15529,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38002,NULL,'Boyne City, MI 49712',15529,222,NULL,40,22180,0);
INSERT INTO "django_geo_db_location" VALUES(38003,NULL,'Boyne Falls, MI',15530,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38004,NULL,'Boyne Falls, MI 49713',15530,222,NULL,40,22181,0);
INSERT INTO "django_geo_db_location" VALUES(38005,NULL,'Brimley, MI',15531,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38006,NULL,'Brimley, MI 49715',15531,222,NULL,40,22182,0);
INSERT INTO "django_geo_db_location" VALUES(38007,NULL,'Brutus, MI',15532,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38008,NULL,'Brutus, MI 49716',15532,222,NULL,40,22183,0);
INSERT INTO "django_geo_db_location" VALUES(38009,NULL,'Burt Lake, MI',15533,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38010,NULL,'Burt Lake, MI 49717',15533,222,NULL,40,22184,0);
INSERT INTO "django_geo_db_location" VALUES(38011,NULL,'Carp Lake, MI',15534,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38012,NULL,'Carp Lake, MI 49718',15534,222,NULL,40,22185,0);
INSERT INTO "django_geo_db_location" VALUES(38013,NULL,'Cedarville, MI',15535,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38014,NULL,'Cedarville, MI 49719',15535,222,NULL,40,22186,0);
INSERT INTO "django_geo_db_location" VALUES(38015,NULL,'Charlevoix, MI',15536,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38016,NULL,'Charlevoix, MI 49720',15536,222,NULL,40,22187,0);
INSERT INTO "django_geo_db_location" VALUES(38017,NULL,'Cheboygan, MI',15537,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38018,NULL,'Cheboygan, MI 49721',15537,222,NULL,40,22188,0);
INSERT INTO "django_geo_db_location" VALUES(38019,NULL,'Conway, MI',15538,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38020,NULL,'Conway, MI 49722',15538,222,NULL,40,22189,0);
INSERT INTO "django_geo_db_location" VALUES(38021,NULL,'Cross Village, MI',15539,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38022,NULL,'Cross Village, MI 49723',15539,222,NULL,40,22190,0);
INSERT INTO "django_geo_db_location" VALUES(38023,NULL,'Dafter, MI',15540,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38024,NULL,'Dafter, MI 49724',15540,222,NULL,40,22191,0);
INSERT INTO "django_geo_db_location" VALUES(38025,NULL,'De Tour Village, MI',15541,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38026,NULL,'De Tour Village, MI 49725',15541,222,NULL,40,22192,0);
INSERT INTO "django_geo_db_location" VALUES(38027,NULL,'Drummond Island, MI',15542,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38028,NULL,'Drummond Island, MI 49726',15542,222,NULL,40,22193,0);
INSERT INTO "django_geo_db_location" VALUES(38029,NULL,'East Jordan, MI',15543,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38030,NULL,'East Jordan, MI 49727',15543,222,NULL,40,22194,0);
INSERT INTO "django_geo_db_location" VALUES(38031,NULL,'Eckerman, MI',15544,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38032,NULL,'Eckerman, MI 49728',15544,222,NULL,40,22195,0);
INSERT INTO "django_geo_db_location" VALUES(38033,NULL,'Ellsworth, MI',15545,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38034,NULL,'Ellsworth, MI 49729',15545,222,NULL,40,22196,0);
INSERT INTO "django_geo_db_location" VALUES(38035,NULL,'Elmira, MI',15546,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38036,NULL,'Elmira, MI 49730',15546,222,NULL,40,22197,0);
INSERT INTO "django_geo_db_location" VALUES(38037,NULL,'Forest, MI',15547,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38038,NULL,'Forest, MI 49732',15547,222,NULL,40,22198,0);
INSERT INTO "django_geo_db_location" VALUES(38039,NULL,'Frederic, MI',15548,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38040,NULL,'Frederic, MI 49733',15548,222,NULL,40,22199,0);
INSERT INTO "django_geo_db_location" VALUES(38041,NULL,'Gaylord, MI',15549,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38042,NULL,'Gaylord, MI 49734',15549,222,NULL,40,22200,0);
INSERT INTO "django_geo_db_location" VALUES(38043,NULL,'Gaylord, MI 49735',15549,222,NULL,40,22201,0);
INSERT INTO "django_geo_db_location" VALUES(38044,NULL,'Goetzville, MI',15550,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38045,NULL,'Goetzville, MI 49736',15550,222,NULL,40,22202,0);
INSERT INTO "django_geo_db_location" VALUES(38046,NULL,'Good Hart, MI',15551,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38047,NULL,'Good Hart, MI 49737',15551,222,NULL,40,22203,0);
INSERT INTO "django_geo_db_location" VALUES(38048,NULL,'Grayling, MI',15552,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38049,NULL,'Grayling, MI 49738',15552,222,NULL,40,22204,0);
INSERT INTO "django_geo_db_location" VALUES(38050,NULL,'Grayling, MI 49739',15552,222,NULL,40,22205,0);
INSERT INTO "django_geo_db_location" VALUES(38051,NULL,'Harbor Springs, MI',15553,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38052,NULL,'Harbor Springs, MI 49740',15553,222,NULL,40,22206,0);
INSERT INTO "django_geo_db_location" VALUES(38053,NULL,'Hawks, MI',15554,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38054,NULL,'Hawks, MI 49743',15554,222,NULL,40,22207,0);
INSERT INTO "django_geo_db_location" VALUES(38055,NULL,'Herron, MI',15555,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38056,NULL,'Herron, MI 49744',15555,222,NULL,40,22208,0);
INSERT INTO "django_geo_db_location" VALUES(38057,NULL,'Hessel, MI',15556,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38058,NULL,'Hessel, MI 49745',15556,222,NULL,40,22209,0);
INSERT INTO "django_geo_db_location" VALUES(38059,NULL,'Hillman, MI',15557,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38060,NULL,'Hillman, MI 49746',15557,222,NULL,40,22210,0);
INSERT INTO "django_geo_db_location" VALUES(38061,NULL,'Hubbard Lake, MI',15558,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38062,NULL,'Hubbard Lake, MI 49747',15558,222,NULL,40,22211,0);
INSERT INTO "django_geo_db_location" VALUES(38063,NULL,'Hulbert, MI',15559,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38064,NULL,'Hulbert, MI 49748',15559,222,NULL,40,22212,0);
INSERT INTO "django_geo_db_location" VALUES(38065,NULL,'Indian River, MI',15560,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38066,NULL,'Indian River, MI 49749',15560,222,NULL,40,22213,0);
INSERT INTO "django_geo_db_location" VALUES(38067,NULL,'Lewiston, MI',15561,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38068,NULL,'Lewiston, MI 49750',15561,222,NULL,40,22214,0);
INSERT INTO "django_geo_db_location" VALUES(38069,NULL,'Johannesburg, MI',15562,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38070,NULL,'Johannesburg, MI 49751',15562,222,NULL,40,22215,0);
INSERT INTO "django_geo_db_location" VALUES(38071,NULL,'Kinross, MI',15563,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38072,NULL,'Kinross, MI 49752',15563,222,NULL,40,22216,0);
INSERT INTO "django_geo_db_location" VALUES(38073,NULL,'Lachine, MI',15564,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38074,NULL,'Lachine, MI 49753',15564,222,NULL,40,22217,0);
INSERT INTO "django_geo_db_location" VALUES(38075,NULL,'Levering, MI',15565,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38076,NULL,'Levering, MI 49755',15565,222,NULL,40,22218,0);
INSERT INTO "django_geo_db_location" VALUES(38077,NULL,'Lewiston, MI 49756',15561,222,NULL,40,22219,0);
INSERT INTO "django_geo_db_location" VALUES(38078,NULL,'Mackinac Island, MI',15566,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38079,NULL,'Mackinac Island, MI 49757',15566,222,NULL,40,22220,0);
INSERT INTO "django_geo_db_location" VALUES(38080,NULL,'Greenwood, MI',15567,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38081,NULL,'Greenwood, MI 49758',15567,222,NULL,40,22221,0);
INSERT INTO "django_geo_db_location" VALUES(38082,NULL,'Millersburg, MI',15568,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38083,NULL,'Millersburg, MI 49759',15568,222,NULL,40,22222,0);
INSERT INTO "django_geo_db_location" VALUES(38084,NULL,'Moran, MI',15569,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38085,NULL,'Moran, MI 49760',15569,222,NULL,40,22223,0);
INSERT INTO "django_geo_db_location" VALUES(38086,NULL,'Mullett Lake, MI',15570,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38087,NULL,'Mullett Lake, MI 49761',15570,222,NULL,40,22224,0);
INSERT INTO "django_geo_db_location" VALUES(38088,NULL,'Naubinway, MI',15571,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38089,NULL,'Naubinway, MI 49762',15571,222,NULL,40,22225,0);
INSERT INTO "django_geo_db_location" VALUES(38090,NULL,'Oden, MI',15572,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38091,NULL,'Oden, MI 49764',15572,222,NULL,40,22226,0);
INSERT INTO "django_geo_db_location" VALUES(38092,NULL,'Onaway, MI',15573,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38093,NULL,'Onaway, MI 49765',15573,222,NULL,40,22227,0);
INSERT INTO "django_geo_db_location" VALUES(38094,NULL,'Ossineke, MI',15574,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38095,NULL,'Ossineke, MI 49766',15574,222,NULL,40,22228,0);
INSERT INTO "django_geo_db_location" VALUES(38096,NULL,'Paradise, MI 49768',15489,222,NULL,40,22229,0);
INSERT INTO "django_geo_db_location" VALUES(38097,NULL,'Pellston, MI',15575,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38098,NULL,'Pellston, MI 49769',15575,222,NULL,40,22230,0);
INSERT INTO "django_geo_db_location" VALUES(38099,NULL,'Petoskey, MI',15576,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38100,NULL,'Petoskey, MI 49770',15576,222,NULL,40,22231,0);
INSERT INTO "django_geo_db_location" VALUES(38101,NULL,'Pickford, MI',15577,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38102,NULL,'Pickford, MI 49774',15577,222,NULL,40,22232,0);
INSERT INTO "django_geo_db_location" VALUES(38103,NULL,'Pointe Aux Pins, MI',15578,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38104,NULL,'Pointe Aux Pins, MI 49775',15578,222,NULL,40,22233,0);
INSERT INTO "django_geo_db_location" VALUES(38105,NULL,'Posen, MI',15579,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38106,NULL,'Posen, MI 49776',15579,222,NULL,40,22234,0);
INSERT INTO "django_geo_db_location" VALUES(38107,NULL,'Presque Isle, MI',15580,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38108,NULL,'Presque Isle, MI 49777',15580,222,NULL,40,22235,0);
INSERT INTO "django_geo_db_location" VALUES(38109,NULL,'Brimley, MI 49778',15531,222,NULL,40,22236,0);
INSERT INTO "django_geo_db_location" VALUES(38110,NULL,'Rogers City, MI',15581,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38111,NULL,'Rogers City, MI 49779',15581,222,NULL,40,22237,0);
INSERT INTO "django_geo_db_location" VALUES(38112,NULL,'Rudyard, MI',15582,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38113,NULL,'Rudyard, MI 49780',15582,222,NULL,40,22238,0);
INSERT INTO "django_geo_db_location" VALUES(38114,NULL,'Saint Ignace, MI',15583,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38115,NULL,'Saint Ignace, MI 49781',15583,222,NULL,40,22239,0);
INSERT INTO "django_geo_db_location" VALUES(38116,NULL,'Beaver Island, MI',15584,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38117,NULL,'Beaver Island, MI 49782',15584,222,NULL,40,22240,0);
INSERT INTO "django_geo_db_location" VALUES(38118,NULL,'Sault Sainte Marie, MI',15585,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38119,NULL,'Sault Sainte Marie, MI 49783',15585,222,NULL,40,22241,0);
INSERT INTO "django_geo_db_location" VALUES(38120,NULL,'Kincheloe, MI',15586,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38121,NULL,'Kincheloe, MI 49784',15586,222,NULL,40,22242,0);
INSERT INTO "django_geo_db_location" VALUES(38122,NULL,'Kincheloe, MI 49785',15586,222,NULL,40,22243,0);
INSERT INTO "django_geo_db_location" VALUES(38123,NULL,'Kincheloe, MI 49786',15586,222,NULL,40,22244,0);
INSERT INTO "django_geo_db_location" VALUES(38124,NULL,'Kincheloe, MI 49788',15586,222,NULL,40,22245,0);
INSERT INTO "django_geo_db_location" VALUES(38125,NULL,'Strongs, MI',15587,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38126,NULL,'Strongs, MI 49790',15587,222,NULL,40,22246,0);
INSERT INTO "django_geo_db_location" VALUES(38127,NULL,'Topinabee, MI',15588,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38128,NULL,'Topinabee, MI 49791',15588,222,NULL,40,22247,0);
INSERT INTO "django_geo_db_location" VALUES(38129,NULL,'Tower, MI',15589,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38130,NULL,'Tower, MI 49792',15589,222,NULL,40,22248,0);
INSERT INTO "django_geo_db_location" VALUES(38131,NULL,'Trout Lake, MI',15590,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38132,NULL,'Trout Lake, MI 49793',15590,222,NULL,40,22249,0);
INSERT INTO "django_geo_db_location" VALUES(38133,NULL,'Vanderbilt, MI',15591,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38134,NULL,'Vanderbilt, MI 49795',15591,222,NULL,40,22250,0);
INSERT INTO "django_geo_db_location" VALUES(38135,NULL,'Walloon Lake, MI',15592,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38136,NULL,'Walloon Lake, MI 49796',15592,222,NULL,40,22251,0);
INSERT INTO "django_geo_db_location" VALUES(38137,NULL,'Waters, MI',15593,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38138,NULL,'Waters, MI 49797',15593,222,NULL,40,22252,0);
INSERT INTO "django_geo_db_location" VALUES(38139,NULL,'Wolverine, MI',15594,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38140,NULL,'Wolverine, MI 49799',15594,222,NULL,40,22253,0);
INSERT INTO "django_geo_db_location" VALUES(38141,NULL,'Iron Mountain, MI',15595,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38142,NULL,'Iron Mountain, MI 49801',15595,222,NULL,40,22254,0);
INSERT INTO "django_geo_db_location" VALUES(38143,NULL,'Kingsford, MI',15596,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38144,NULL,'Kingsford, MI 49802',15596,222,NULL,40,22255,0);
INSERT INTO "django_geo_db_location" VALUES(38145,NULL,'Allouez, MI',15597,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38146,NULL,'Allouez, MI 49805',15597,222,NULL,40,22256,0);
INSERT INTO "django_geo_db_location" VALUES(38147,NULL,'Au Train, MI',15598,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38148,NULL,'Au Train, MI 49806',15598,222,NULL,40,22257,0);
INSERT INTO "django_geo_db_location" VALUES(38149,NULL,'Bark River, MI',15599,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38150,NULL,'Bark River, MI 49807',15599,222,NULL,40,22258,0);
INSERT INTO "django_geo_db_location" VALUES(38151,NULL,'Big Bay, MI',15600,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38152,NULL,'Big Bay, MI 49808',15600,222,NULL,40,22259,0);
INSERT INTO "django_geo_db_location" VALUES(38153,NULL,'Carney, MI',15601,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38154,NULL,'Carney, MI 49812',15601,222,NULL,40,22260,0);
INSERT INTO "django_geo_db_location" VALUES(38155,NULL,'Cedar River, MI',15602,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38156,NULL,'Cedar River, MI 49813',15602,222,NULL,40,22261,0);
INSERT INTO "django_geo_db_location" VALUES(38157,NULL,'Champion, MI',15603,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38158,NULL,'Champion, MI 49814',15603,222,NULL,40,22262,0);
INSERT INTO "django_geo_db_location" VALUES(38159,NULL,'Channing, MI',15604,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38160,NULL,'Channing, MI 49815',15604,222,NULL,40,22263,0);
INSERT INTO "django_geo_db_location" VALUES(38161,NULL,'Chatham, MI',15605,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38162,NULL,'Chatham, MI 49816',15605,222,NULL,40,22264,0);
INSERT INTO "django_geo_db_location" VALUES(38163,NULL,'Cooks, MI',15606,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38164,NULL,'Cooks, MI 49817',15606,222,NULL,40,22265,0);
INSERT INTO "django_geo_db_location" VALUES(38165,NULL,'Cornell, MI',15607,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38166,NULL,'Cornell, MI 49818',15607,222,NULL,40,22266,0);
INSERT INTO "django_geo_db_location" VALUES(38167,NULL,'Arnold, MI',15608,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38168,NULL,'Arnold, MI 49819',15608,222,NULL,40,22267,0);
INSERT INTO "django_geo_db_location" VALUES(38169,NULL,'Curtis, MI',15609,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38170,NULL,'Curtis, MI 49820',15609,222,NULL,40,22268,0);
INSERT INTO "django_geo_db_location" VALUES(38171,NULL,'Daggett, MI',15610,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38172,NULL,'Daggett, MI 49821',15610,222,NULL,40,22269,0);
INSERT INTO "django_geo_db_location" VALUES(38173,NULL,'Deerton, MI',15611,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38174,NULL,'Deerton, MI 49822',15611,222,NULL,40,22270,0);
INSERT INTO "django_geo_db_location" VALUES(38175,NULL,'Eben Junction, MI',15612,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38176,NULL,'Eben Junction, MI 49825',15612,222,NULL,40,22271,0);
INSERT INTO "django_geo_db_location" VALUES(38177,NULL,'Rumely, MI',15613,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38178,NULL,'Rumely, MI 49826',15613,222,NULL,40,22272,0);
INSERT INTO "django_geo_db_location" VALUES(38179,NULL,'Engadine, MI',15614,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38180,NULL,'Engadine, MI 49827',15614,222,NULL,40,22273,0);
INSERT INTO "django_geo_db_location" VALUES(38181,NULL,'Escanaba, MI',15615,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38182,NULL,'Escanaba, MI 49829',15615,222,NULL,40,22274,0);
INSERT INTO "django_geo_db_location" VALUES(38183,NULL,'Felch, MI',15616,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38184,NULL,'Felch, MI 49831',15616,222,NULL,40,22275,0);
INSERT INTO "django_geo_db_location" VALUES(38185,NULL,'Little Lake, MI',15617,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38186,NULL,'Little Lake, MI 49833',15617,222,NULL,40,22276,0);
INSERT INTO "django_geo_db_location" VALUES(38187,NULL,'Foster City, MI',15618,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38188,NULL,'Foster City, MI 49834',15618,222,NULL,40,22277,0);
INSERT INTO "django_geo_db_location" VALUES(38189,NULL,'Garden, MI',15619,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38190,NULL,'Garden, MI 49835',15619,222,NULL,40,22278,0);
INSERT INTO "django_geo_db_location" VALUES(38191,NULL,'Germfask, MI',15620,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38192,NULL,'Germfask, MI 49836',15620,222,NULL,40,22279,0);
INSERT INTO "django_geo_db_location" VALUES(38193,NULL,'Gladstone, MI',15621,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38194,NULL,'Gladstone, MI 49837',15621,222,NULL,40,22280,0);
INSERT INTO "django_geo_db_location" VALUES(38195,NULL,'Gould City, MI',15622,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38196,NULL,'Gould City, MI 49838',15622,222,NULL,40,22281,0);
INSERT INTO "django_geo_db_location" VALUES(38197,NULL,'Grand Marais, MI',15623,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38198,NULL,'Grand Marais, MI 49839',15623,222,NULL,40,22282,0);
INSERT INTO "django_geo_db_location" VALUES(38199,NULL,'Gulliver, MI',15624,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38200,NULL,'Gulliver, MI 49840',15624,222,NULL,40,22283,0);
INSERT INTO "django_geo_db_location" VALUES(38201,NULL,'Gwinn, MI',15625,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38202,NULL,'Gwinn, MI 49841',15625,222,NULL,40,22284,0);
INSERT INTO "django_geo_db_location" VALUES(38203,NULL,'Harris, MI',15626,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38204,NULL,'Harris, MI 49845',15626,222,NULL,40,22285,0);
INSERT INTO "django_geo_db_location" VALUES(38205,NULL,'Hermansville, MI',15627,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38206,NULL,'Hermansville, MI 49847',15627,222,NULL,40,22286,0);
INSERT INTO "django_geo_db_location" VALUES(38207,NULL,'Ingalls, MI',15628,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38208,NULL,'Ingalls, MI 49848',15628,222,NULL,40,22287,0);
INSERT INTO "django_geo_db_location" VALUES(38209,NULL,'Ishpeming, MI',15629,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38210,NULL,'Ishpeming, MI 49849',15629,222,NULL,40,22288,0);
INSERT INTO "django_geo_db_location" VALUES(38211,NULL,'Loretto, MI',15630,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38212,NULL,'Loretto, MI 49852',15630,222,NULL,40,22289,0);
INSERT INTO "django_geo_db_location" VALUES(38213,NULL,'McMillan, MI',15631,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38214,NULL,'McMillan, MI 49853',15631,222,NULL,40,22290,0);
INSERT INTO "django_geo_db_location" VALUES(38215,NULL,'Manistique, MI',15632,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38216,NULL,'Manistique, MI 49854',15632,222,NULL,40,22291,0);
INSERT INTO "django_geo_db_location" VALUES(38217,NULL,'Marquette, MI',15633,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38218,NULL,'Marquette, MI 49855',15633,222,NULL,40,22292,0);
INSERT INTO "django_geo_db_location" VALUES(38219,NULL,'Menominee, MI',15634,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38220,NULL,'Menominee, MI 49858',15634,222,NULL,40,22293,0);
INSERT INTO "django_geo_db_location" VALUES(38221,NULL,'Michigamme, MI',15635,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38222,NULL,'Michigamme, MI 49861',15635,222,NULL,40,22294,0);
INSERT INTO "django_geo_db_location" VALUES(38223,NULL,'Munising, MI',15636,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38224,NULL,'Munising, MI 49862',15636,222,NULL,40,22295,0);
INSERT INTO "django_geo_db_location" VALUES(38225,NULL,'Nadeau, MI',15637,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38226,NULL,'Nadeau, MI 49863',15637,222,NULL,40,22296,0);
INSERT INTO "django_geo_db_location" VALUES(38227,NULL,'Nahma, MI',15638,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38228,NULL,'Nahma, MI 49864',15638,222,NULL,40,22297,0);
INSERT INTO "django_geo_db_location" VALUES(38229,NULL,'National Mine, MI',15639,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38230,NULL,'National Mine, MI 49865',15639,222,NULL,40,22298,0);
INSERT INTO "django_geo_db_location" VALUES(38231,NULL,'Negaunee, MI',15640,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38232,NULL,'Negaunee, MI 49866',15640,222,NULL,40,22299,0);
INSERT INTO "django_geo_db_location" VALUES(38233,NULL,'Newberry, MI',15641,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38234,NULL,'Newberry, MI 49868',15641,222,NULL,40,22300,0);
INSERT INTO "django_geo_db_location" VALUES(38235,NULL,'Wells, MI',15642,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38236,NULL,'Wells, MI 49869',15642,222,NULL,40,22301,0);
INSERT INTO "django_geo_db_location" VALUES(38237,NULL,'Norway, MI',15643,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38238,NULL,'Norway, MI 49870',15643,222,NULL,40,22302,0);
INSERT INTO "django_geo_db_location" VALUES(38239,NULL,'Palmer, MI',15644,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38240,NULL,'Palmer, MI 49871',15644,222,NULL,40,22303,0);
INSERT INTO "django_geo_db_location" VALUES(38241,NULL,'Perkins, MI',15645,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38242,NULL,'Perkins, MI 49872',15645,222,NULL,40,22304,0);
INSERT INTO "django_geo_db_location" VALUES(38243,NULL,'Perronville, MI',15646,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38244,NULL,'Perronville, MI 49873',15646,222,NULL,40,22305,0);
INSERT INTO "django_geo_db_location" VALUES(38245,NULL,'Powers, MI',15647,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38246,NULL,'Powers, MI 49874',15647,222,NULL,40,22306,0);
INSERT INTO "django_geo_db_location" VALUES(38247,NULL,'Quinnesec, MI',15648,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38248,NULL,'Quinnesec, MI 49876',15648,222,NULL,40,22307,0);
INSERT INTO "django_geo_db_location" VALUES(38249,NULL,'Ralph, MI',15649,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38250,NULL,'Ralph, MI 49877',15649,222,NULL,40,22308,0);
INSERT INTO "django_geo_db_location" VALUES(38251,NULL,'Rapid River, MI',15650,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38252,NULL,'Rapid River, MI 49878',15650,222,NULL,40,22309,0);
INSERT INTO "django_geo_db_location" VALUES(38253,NULL,'Republic, MI',15651,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38254,NULL,'Republic, MI 49879',15651,222,NULL,40,22310,0);
INSERT INTO "django_geo_db_location" VALUES(38255,NULL,'Rock, MI',15652,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38256,NULL,'Rock, MI 49880',15652,222,NULL,40,22311,0);
INSERT INTO "django_geo_db_location" VALUES(38257,NULL,'Sagola, MI',15653,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38258,NULL,'Sagola, MI 49881',15653,222,NULL,40,22312,0);
INSERT INTO "django_geo_db_location" VALUES(38259,NULL,'Seney, MI',15654,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38260,NULL,'Seney, MI 49883',15654,222,NULL,40,22313,0);
INSERT INTO "django_geo_db_location" VALUES(38261,NULL,'Shingleton, MI',15655,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38262,NULL,'Shingleton, MI 49884',15655,222,NULL,40,22314,0);
INSERT INTO "django_geo_db_location" VALUES(38263,NULL,'Skandia, MI',15656,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38264,NULL,'Skandia, MI 49885',15656,222,NULL,40,22315,0);
INSERT INTO "django_geo_db_location" VALUES(38265,NULL,'Spalding, MI',15657,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38266,NULL,'Spalding, MI 49886',15657,222,NULL,40,22316,0);
INSERT INTO "django_geo_db_location" VALUES(38267,NULL,'Stephenson, MI',15658,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38268,NULL,'Stephenson, MI 49887',15658,222,NULL,40,22317,0);
INSERT INTO "django_geo_db_location" VALUES(38269,NULL,'Trenary, MI',15659,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38270,NULL,'Trenary, MI 49891',15659,222,NULL,40,22318,0);
INSERT INTO "django_geo_db_location" VALUES(38271,NULL,'Vulcan, MI',15660,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38272,NULL,'Vulcan, MI 49892',15660,222,NULL,40,22319,0);
INSERT INTO "django_geo_db_location" VALUES(38273,NULL,'Wallace, MI',15661,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38274,NULL,'Wallace, MI 49893',15661,222,NULL,40,22320,0);
INSERT INTO "django_geo_db_location" VALUES(38275,NULL,'Wells, MI 49894',15642,222,NULL,40,22321,0);
INSERT INTO "django_geo_db_location" VALUES(38276,NULL,'Wetmore, MI',15662,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38277,NULL,'Wetmore, MI 49895',15662,222,NULL,40,22322,0);
INSERT INTO "django_geo_db_location" VALUES(38278,NULL,'Wilson, MI',15663,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38279,NULL,'Wilson, MI 49896',15663,222,NULL,40,22323,0);
INSERT INTO "django_geo_db_location" VALUES(38280,NULL,'Ahmeek, MI',15664,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38281,NULL,'Ahmeek, MI 49901',15664,222,NULL,40,22324,0);
INSERT INTO "django_geo_db_location" VALUES(38282,NULL,'Alpha, MI',15665,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38283,NULL,'Alpha, MI 49902',15665,222,NULL,40,22325,0);
INSERT INTO "django_geo_db_location" VALUES(38284,NULL,'Amasa, MI',15666,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38285,NULL,'Amasa, MI 49903',15666,222,NULL,40,22326,0);
INSERT INTO "django_geo_db_location" VALUES(38286,NULL,'Atlantic Mine, MI',15667,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38287,NULL,'Atlantic Mine, MI 49905',15667,222,NULL,40,22327,0);
INSERT INTO "django_geo_db_location" VALUES(38288,NULL,'Baraga, MI',15668,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38289,NULL,'Baraga, MI 49908',15668,222,NULL,40,22328,0);
INSERT INTO "django_geo_db_location" VALUES(38290,NULL,'Bergland, MI',15669,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38291,NULL,'Bergland, MI 49910',15669,222,NULL,40,22329,0);
INSERT INTO "django_geo_db_location" VALUES(38292,NULL,'Bessemer, MI',15670,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38293,NULL,'Bessemer, MI 49911',15670,222,NULL,40,22330,0);
INSERT INTO "django_geo_db_location" VALUES(38294,NULL,'Bruce Crossing, MI',15671,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38295,NULL,'Bruce Crossing, MI 49912',15671,222,NULL,40,22331,0);
INSERT INTO "django_geo_db_location" VALUES(38296,NULL,'Calumet, MI',15672,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38297,NULL,'Calumet, MI 49913',15672,222,NULL,40,22332,0);
INSERT INTO "django_geo_db_location" VALUES(38298,NULL,'Caspian, MI',15673,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38299,NULL,'Caspian, MI 49915',15673,222,NULL,40,22333,0);
INSERT INTO "django_geo_db_location" VALUES(38300,NULL,'Chassell, MI',15674,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38301,NULL,'Chassell, MI 49916',15674,222,NULL,40,22334,0);
INSERT INTO "django_geo_db_location" VALUES(38302,NULL,'Copper City, MI',15675,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38303,NULL,'Copper City, MI 49917',15675,222,NULL,40,22335,0);
INSERT INTO "django_geo_db_location" VALUES(38304,NULL,'Copper Harbor, MI',15676,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38305,NULL,'Copper Harbor, MI 49918',15676,222,NULL,40,22336,0);
INSERT INTO "django_geo_db_location" VALUES(38306,NULL,'Covington, MI',15677,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38307,NULL,'Covington, MI 49919',15677,222,NULL,40,22337,0);
INSERT INTO "django_geo_db_location" VALUES(38308,NULL,'Crystal Falls, MI',15678,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38309,NULL,'Crystal Falls, MI 49920',15678,222,NULL,40,22338,0);
INSERT INTO "django_geo_db_location" VALUES(38310,NULL,'Dodgeville, MI',15679,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38311,NULL,'Dodgeville, MI 49921',15679,222,NULL,40,22339,0);
INSERT INTO "django_geo_db_location" VALUES(38312,NULL,'Dollar Bay, MI',15680,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38313,NULL,'Dollar Bay, MI 49922',15680,222,NULL,40,22340,0);
INSERT INTO "django_geo_db_location" VALUES(38314,NULL,'Houghton, MI',15681,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38315,NULL,'Houghton, MI 49924',15681,222,NULL,40,22341,0);
INSERT INTO "django_geo_db_location" VALUES(38316,NULL,'Ewen, MI',15682,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38317,NULL,'Ewen, MI 49925',15682,222,NULL,40,22342,0);
INSERT INTO "django_geo_db_location" VALUES(38318,NULL,'Gaastra, MI',15683,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38319,NULL,'Gaastra, MI 49927',15683,222,NULL,40,22343,0);
INSERT INTO "django_geo_db_location" VALUES(38320,NULL,'Greenland, MI',15684,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38321,NULL,'Greenland, MI 49929',15684,222,NULL,40,22344,0);
INSERT INTO "django_geo_db_location" VALUES(38322,NULL,'Hancock, MI',15685,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38323,NULL,'Hancock, MI 49930',15685,222,NULL,40,22345,0);
INSERT INTO "django_geo_db_location" VALUES(38324,NULL,'Houghton, MI 49931',15681,222,NULL,40,22346,0);
INSERT INTO "django_geo_db_location" VALUES(38325,NULL,'Hubbell, MI',15686,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38326,NULL,'Hubbell, MI 49934',15686,222,NULL,40,22347,0);
INSERT INTO "django_geo_db_location" VALUES(38327,NULL,'Iron River, MI',15687,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38328,NULL,'Iron River, MI 49935',15687,222,NULL,40,22348,0);
INSERT INTO "django_geo_db_location" VALUES(38329,NULL,'Ironwood, MI',15688,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38330,NULL,'Ironwood, MI 49938',15688,222,NULL,40,22349,0);
INSERT INTO "django_geo_db_location" VALUES(38331,NULL,'Kearsarge, MI',15689,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38332,NULL,'Kearsarge, MI 49942',15689,222,NULL,40,22350,0);
INSERT INTO "django_geo_db_location" VALUES(38333,NULL,'Iron River, MI 49943',15687,222,NULL,40,22351,0);
INSERT INTO "django_geo_db_location" VALUES(38334,NULL,'Lake Linden, MI',15690,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38335,NULL,'Lake Linden, MI 49945',15690,222,NULL,40,22352,0);
INSERT INTO "django_geo_db_location" VALUES(38336,NULL,'Lanse, MI',15691,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38337,NULL,'Lanse, MI 49946',15691,222,NULL,40,22353,0);
INSERT INTO "django_geo_db_location" VALUES(38338,NULL,'Marenisco, MI',15692,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38339,NULL,'Marenisco, MI 49947',15692,222,NULL,40,22354,0);
INSERT INTO "django_geo_db_location" VALUES(38340,NULL,'Mass City, MI',15693,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38341,NULL,'Mass City, MI 49948',15693,222,NULL,40,22355,0);
INSERT INTO "django_geo_db_location" VALUES(38342,NULL,'Mohawk, MI',15694,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38343,NULL,'Mohawk, MI 49950',15694,222,NULL,40,22356,0);
INSERT INTO "django_geo_db_location" VALUES(38344,NULL,'Nisula, MI',15695,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38345,NULL,'Nisula, MI 49952',15695,222,NULL,40,22357,0);
INSERT INTO "django_geo_db_location" VALUES(38346,NULL,'Ontonagon, MI',15696,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38347,NULL,'Ontonagon, MI 49953',15696,222,NULL,40,22358,0);
INSERT INTO "django_geo_db_location" VALUES(38348,NULL,'Painesdale, MI',15697,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38349,NULL,'Painesdale, MI 49955',15697,222,NULL,40,22359,0);
INSERT INTO "django_geo_db_location" VALUES(38350,NULL,'Pelkie, MI',15698,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38351,NULL,'Pelkie, MI 49958',15698,222,NULL,40,22360,0);
INSERT INTO "django_geo_db_location" VALUES(38352,NULL,'Ramsay, MI',15699,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38353,NULL,'Ramsay, MI 49959',15699,222,NULL,40,22361,0);
INSERT INTO "django_geo_db_location" VALUES(38354,NULL,'Rockland, MI',15700,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38355,NULL,'Rockland, MI 49960',15700,222,NULL,40,22362,0);
INSERT INTO "django_geo_db_location" VALUES(38356,NULL,'Sidnaw, MI',15701,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38357,NULL,'Sidnaw, MI 49961',15701,222,NULL,40,22363,0);
INSERT INTO "django_geo_db_location" VALUES(38358,NULL,'Skanee, MI',15702,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38359,NULL,'Skanee, MI 49962',15702,222,NULL,40,22364,0);
INSERT INTO "django_geo_db_location" VALUES(38360,NULL,'South Range, MI',15703,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38361,NULL,'South Range, MI 49963',15703,222,NULL,40,22365,0);
INSERT INTO "django_geo_db_location" VALUES(38362,NULL,'Stambaugh, MI',15704,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38363,NULL,'Stambaugh, MI 49964',15704,222,NULL,40,22366,0);
INSERT INTO "django_geo_db_location" VALUES(38364,NULL,'Toivola, MI',15705,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38365,NULL,'Toivola, MI 49965',15705,222,NULL,40,22367,0);
INSERT INTO "django_geo_db_location" VALUES(38366,NULL,'Trout Creek, MI',15706,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38367,NULL,'Trout Creek, MI 49967',15706,222,NULL,40,22368,0);
INSERT INTO "django_geo_db_location" VALUES(38368,NULL,'Wakefield, MI',15707,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38369,NULL,'Wakefield, MI 49968',15707,222,NULL,40,22369,0);
INSERT INTO "django_geo_db_location" VALUES(38370,NULL,'Watersmeet, MI',15708,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38371,NULL,'Watersmeet, MI 49969',15708,222,NULL,40,22370,0);
INSERT INTO "django_geo_db_location" VALUES(38372,NULL,'Watton, MI',15709,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38373,NULL,'Watton, MI 49970',15709,222,NULL,40,22371,0);
INSERT INTO "django_geo_db_location" VALUES(38374,NULL,'White Pine, MI',15710,222,NULL,40,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38375,NULL,'White Pine, MI 49971',15710,222,NULL,40,22372,0);
INSERT INTO "django_geo_db_location" VALUES(38376,NULL,'Pickford, MI 49974',15577,222,NULL,40,22373,0);
INSERT INTO "django_geo_db_location" VALUES(38377,NULL,'Alpha, MI 49990',15665,222,NULL,40,22374,0);
INSERT INTO "django_geo_db_location" VALUES(38378,NULL,'Ackworth, IA',15711,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38379,NULL,'Ackworth, IA 50001',15711,222,NULL,19,22375,0);
INSERT INTO "django_geo_db_location" VALUES(38380,NULL,'Adair, IA',15712,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38381,NULL,'Adair, IA 50002',15712,222,NULL,19,22376,0);
INSERT INTO "django_geo_db_location" VALUES(38382,NULL,'Adel, IA',15713,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38383,NULL,'Adel, IA 50003',15713,222,NULL,19,22377,0);
INSERT INTO "django_geo_db_location" VALUES(38384,NULL,'Albion, IA',15714,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38385,NULL,'Albion, IA 50005',15714,222,NULL,19,22378,0);
INSERT INTO "django_geo_db_location" VALUES(38386,NULL,'Alden, IA',15715,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38387,NULL,'Alden, IA 50006',15715,222,NULL,19,22379,0);
INSERT INTO "django_geo_db_location" VALUES(38388,NULL,'Alleman, IA',15716,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38389,NULL,'Alleman, IA 50007',15716,222,NULL,19,22380,0);
INSERT INTO "django_geo_db_location" VALUES(38390,NULL,'Allerton, IA',15717,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38391,NULL,'Allerton, IA 50008',15717,222,NULL,19,22381,0);
INSERT INTO "django_geo_db_location" VALUES(38392,NULL,'Altoona, IA',15718,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38393,NULL,'Altoona, IA 50009',15718,222,NULL,19,22382,0);
INSERT INTO "django_geo_db_location" VALUES(38394,NULL,'Ames, IA',15719,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38395,NULL,'Ames, IA 50010',15719,222,NULL,19,22383,0);
INSERT INTO "django_geo_db_location" VALUES(38396,NULL,'Ames, IA 50011',15719,222,NULL,19,22384,0);
INSERT INTO "django_geo_db_location" VALUES(38397,NULL,'Ames, IA 50012',15719,222,NULL,19,22385,0);
INSERT INTO "django_geo_db_location" VALUES(38398,NULL,'Ames, IA 50013',15719,222,NULL,19,22386,0);
INSERT INTO "django_geo_db_location" VALUES(38399,NULL,'Ames, IA 50014',15719,222,NULL,19,22387,0);
INSERT INTO "django_geo_db_location" VALUES(38400,NULL,'Ankeny, IA',15720,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38401,NULL,'Ankeny, IA 50015',15720,222,NULL,19,22388,0);
INSERT INTO "django_geo_db_location" VALUES(38402,NULL,'Anita, IA',15721,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38403,NULL,'Anita, IA 50020',15721,222,NULL,19,22389,0);
INSERT INTO "django_geo_db_location" VALUES(38404,NULL,'Ankeny, IA 50021',15720,222,NULL,19,22390,0);
INSERT INTO "django_geo_db_location" VALUES(38405,NULL,'Atlantic, IA',15722,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38406,NULL,'Atlantic, IA 50022',15722,222,NULL,19,22391,0);
INSERT INTO "django_geo_db_location" VALUES(38407,NULL,'Audubon, IA',15723,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38408,NULL,'Audubon, IA 50025',15723,222,NULL,19,22392,0);
INSERT INTO "django_geo_db_location" VALUES(38409,NULL,'Bagley, IA',15724,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38410,NULL,'Bagley, IA 50026',15724,222,NULL,19,22393,0);
INSERT INTO "django_geo_db_location" VALUES(38411,NULL,'Barnes City, IA',15725,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38412,NULL,'Barnes City, IA 50027',15725,222,NULL,19,22394,0);
INSERT INTO "django_geo_db_location" VALUES(38413,NULL,'Baxter, IA',15726,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38414,NULL,'Baxter, IA 50028',15726,222,NULL,19,22395,0);
INSERT INTO "django_geo_db_location" VALUES(38415,NULL,'Bayard, IA',15727,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38416,NULL,'Bayard, IA 50029',15727,222,NULL,19,22396,0);
INSERT INTO "django_geo_db_location" VALUES(38417,NULL,'Beaver, IA',15728,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38418,NULL,'Beaver, IA 50031',15728,222,NULL,19,22397,0);
INSERT INTO "django_geo_db_location" VALUES(38419,NULL,'Berwick, IA',15729,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38420,NULL,'Berwick, IA 50032',15729,222,NULL,19,22398,0);
INSERT INTO "django_geo_db_location" VALUES(38421,NULL,'Bevington, IA',15730,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38422,NULL,'Bevington, IA 50033',15730,222,NULL,19,22399,0);
INSERT INTO "django_geo_db_location" VALUES(38423,NULL,'Blairsburg, IA',15731,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38424,NULL,'Blairsburg, IA 50034',15731,222,NULL,19,22400,0);
INSERT INTO "django_geo_db_location" VALUES(38425,NULL,'Bondurant, IA',15732,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38426,NULL,'Bondurant, IA 50035',15732,222,NULL,19,22401,0);
INSERT INTO "django_geo_db_location" VALUES(38427,NULL,'Boone, IA',15733,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38428,NULL,'Boone, IA 50036',15733,222,NULL,19,22402,0);
INSERT INTO "django_geo_db_location" VALUES(38429,NULL,'Boone, IA 50037',15733,222,NULL,19,22403,0);
INSERT INTO "django_geo_db_location" VALUES(38430,NULL,'Booneville, IA',15734,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38431,NULL,'Booneville, IA 50038',15734,222,NULL,19,22404,0);
INSERT INTO "django_geo_db_location" VALUES(38432,NULL,'Bouton, IA',15735,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38433,NULL,'Bouton, IA 50039',15735,222,NULL,19,22405,0);
INSERT INTO "django_geo_db_location" VALUES(38434,NULL,'Boxholm, IA',15736,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38435,NULL,'Boxholm, IA 50040',15736,222,NULL,19,22406,0);
INSERT INTO "django_geo_db_location" VALUES(38436,NULL,'Bradford, IA',15737,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38437,NULL,'Bradford, IA 50041',15737,222,NULL,19,22407,0);
INSERT INTO "django_geo_db_location" VALUES(38438,NULL,'Brayton, IA',15738,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38439,NULL,'Brayton, IA 50042',15738,222,NULL,19,22408,0);
INSERT INTO "django_geo_db_location" VALUES(38440,NULL,'Buckeye, IA',15739,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38441,NULL,'Buckeye, IA 50043',15739,222,NULL,19,22409,0);
INSERT INTO "django_geo_db_location" VALUES(38442,NULL,'Bussey, IA',15740,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38443,NULL,'Bussey, IA 50044',15740,222,NULL,19,22410,0);
INSERT INTO "django_geo_db_location" VALUES(38444,NULL,'Cambridge, IA',15741,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38445,NULL,'Cambridge, IA 50046',15741,222,NULL,19,22411,0);
INSERT INTO "django_geo_db_location" VALUES(38446,NULL,'Carlisle, IA',15742,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38447,NULL,'Carlisle, IA 50047',15742,222,NULL,19,22412,0);
INSERT INTO "django_geo_db_location" VALUES(38448,NULL,'Casey, IA',15743,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38449,NULL,'Casey, IA 50048',15743,222,NULL,19,22413,0);
INSERT INTO "django_geo_db_location" VALUES(38450,NULL,'Chariton, IA',15744,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38451,NULL,'Chariton, IA 50049',15744,222,NULL,19,22414,0);
INSERT INTO "django_geo_db_location" VALUES(38452,NULL,'Churdan, IA',15745,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38453,NULL,'Churdan, IA 50050',15745,222,NULL,19,22415,0);
INSERT INTO "django_geo_db_location" VALUES(38454,NULL,'Clemons, IA',15746,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38455,NULL,'Clemons, IA 50051',15746,222,NULL,19,22416,0);
INSERT INTO "django_geo_db_location" VALUES(38456,NULL,'Clio, IA',15747,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38457,NULL,'Clio, IA 50052',15747,222,NULL,19,22417,0);
INSERT INTO "django_geo_db_location" VALUES(38458,NULL,'Colfax, IA',15748,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38459,NULL,'Colfax, IA 50054',15748,222,NULL,19,22418,0);
INSERT INTO "django_geo_db_location" VALUES(38460,NULL,'Collins, IA',15749,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38461,NULL,'Collins, IA 50055',15749,222,NULL,19,22419,0);
INSERT INTO "django_geo_db_location" VALUES(38462,NULL,'Colo, IA',15750,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38463,NULL,'Colo, IA 50056',15750,222,NULL,19,22420,0);
INSERT INTO "django_geo_db_location" VALUES(38464,NULL,'Columbia, IA',15751,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38465,NULL,'Columbia, IA 50057',15751,222,NULL,19,22421,0);
INSERT INTO "django_geo_db_location" VALUES(38466,NULL,'Coon Rapids, IA',15752,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38467,NULL,'Coon Rapids, IA 50058',15752,222,NULL,19,22422,0);
INSERT INTO "django_geo_db_location" VALUES(38468,NULL,'Cooper, IA',15753,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38469,NULL,'Cooper, IA 50059',15753,222,NULL,19,22423,0);
INSERT INTO "django_geo_db_location" VALUES(38470,NULL,'Corydon, IA',15754,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38471,NULL,'Corydon, IA 50060',15754,222,NULL,19,22424,0);
INSERT INTO "django_geo_db_location" VALUES(38472,NULL,'Cumming, IA',15755,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38473,NULL,'Cumming, IA 50061',15755,222,NULL,19,22425,0);
INSERT INTO "django_geo_db_location" VALUES(38474,NULL,'Dallas, IA',15756,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38475,NULL,'Dallas, IA 50062',15756,222,NULL,19,22426,0);
INSERT INTO "django_geo_db_location" VALUES(38476,NULL,'Dallas Center, IA',15757,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38477,NULL,'Dallas Center, IA 50063',15757,222,NULL,19,22427,0);
INSERT INTO "django_geo_db_location" VALUES(38478,NULL,'Dana, IA',15758,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38479,NULL,'Dana, IA 50064',15758,222,NULL,19,22428,0);
INSERT INTO "django_geo_db_location" VALUES(38480,NULL,'Davis City, IA',15759,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38481,NULL,'Davis City, IA 50065',15759,222,NULL,19,22429,0);
INSERT INTO "django_geo_db_location" VALUES(38482,NULL,'Dawson, IA',15760,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38483,NULL,'Dawson, IA 50066',15760,222,NULL,19,22430,0);
INSERT INTO "django_geo_db_location" VALUES(38484,NULL,'Decatur, IA',15761,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38485,NULL,'Decatur, IA 50067',15761,222,NULL,19,22431,0);
INSERT INTO "django_geo_db_location" VALUES(38486,NULL,'Derby, IA',15762,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38487,NULL,'Derby, IA 50068',15762,222,NULL,19,22432,0);
INSERT INTO "django_geo_db_location" VALUES(38488,NULL,'De Soto, IA',15763,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38489,NULL,'De Soto, IA 50069',15763,222,NULL,19,22433,0);
INSERT INTO "django_geo_db_location" VALUES(38490,NULL,'Dexter, IA',15764,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38491,NULL,'Dexter, IA 50070',15764,222,NULL,19,22434,0);
INSERT INTO "django_geo_db_location" VALUES(38492,NULL,'Dows, IA',15765,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38493,NULL,'Dows, IA 50071',15765,222,NULL,19,22435,0);
INSERT INTO "django_geo_db_location" VALUES(38494,NULL,'Earlham, IA',15766,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38495,NULL,'Earlham, IA 50072',15766,222,NULL,19,22436,0);
INSERT INTO "django_geo_db_location" VALUES(38496,NULL,'Elkhart, IA',15767,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38497,NULL,'Elkhart, IA 50073',15767,222,NULL,19,22437,0);
INSERT INTO "django_geo_db_location" VALUES(38498,NULL,'Ellston, IA',15768,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38499,NULL,'Ellston, IA 50074',15768,222,NULL,19,22438,0);
INSERT INTO "django_geo_db_location" VALUES(38500,NULL,'Ellsworth, IA',15769,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38501,NULL,'Ellsworth, IA 50075',15769,222,NULL,19,22439,0);
INSERT INTO "django_geo_db_location" VALUES(38502,NULL,'Exira, IA',15770,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38503,NULL,'Exira, IA 50076',15770,222,NULL,19,22440,0);
INSERT INTO "django_geo_db_location" VALUES(38504,NULL,'Ferguson, IA',15771,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38505,NULL,'Ferguson, IA 50078',15771,222,NULL,19,22441,0);
INSERT INTO "django_geo_db_location" VALUES(38506,NULL,'Galt, IA',15772,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38507,NULL,'Galt, IA 50101',15772,222,NULL,19,22442,0);
INSERT INTO "django_geo_db_location" VALUES(38508,NULL,'Garden City, IA',15773,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38509,NULL,'Garden City, IA 50102',15773,222,NULL,19,22443,0);
INSERT INTO "django_geo_db_location" VALUES(38510,NULL,'Garden Grove, IA',15774,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38511,NULL,'Garden Grove, IA 50103',15774,222,NULL,19,22444,0);
INSERT INTO "django_geo_db_location" VALUES(38512,NULL,'Gibson, IA',15775,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38513,NULL,'Gibson, IA 50104',15775,222,NULL,19,22445,0);
INSERT INTO "django_geo_db_location" VALUES(38514,NULL,'Gilbert, IA',15776,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38515,NULL,'Gilbert, IA 50105',15776,222,NULL,19,22446,0);
INSERT INTO "django_geo_db_location" VALUES(38516,NULL,'Gilman, IA',15777,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38517,NULL,'Gilman, IA 50106',15777,222,NULL,19,22447,0);
INSERT INTO "django_geo_db_location" VALUES(38518,NULL,'Grand Junction, IA',15778,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38519,NULL,'Grand Junction, IA 50107',15778,222,NULL,19,22448,0);
INSERT INTO "django_geo_db_location" VALUES(38520,NULL,'Grand River, IA',15779,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38521,NULL,'Grand River, IA 50108',15779,222,NULL,19,22449,0);
INSERT INTO "django_geo_db_location" VALUES(38522,NULL,'Granger, IA',15780,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38523,NULL,'Granger, IA 50109',15780,222,NULL,19,22450,0);
INSERT INTO "django_geo_db_location" VALUES(38524,NULL,'Gray, IA',15781,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38525,NULL,'Gray, IA 50110',15781,222,NULL,19,22451,0);
INSERT INTO "django_geo_db_location" VALUES(38526,NULL,'Grimes, IA',15782,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38527,NULL,'Grimes, IA 50111',15782,222,NULL,19,22452,0);
INSERT INTO "django_geo_db_location" VALUES(38528,NULL,'Grinnell, IA',15783,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38529,NULL,'Grinnell, IA 50112',15783,222,NULL,19,22453,0);
INSERT INTO "django_geo_db_location" VALUES(38530,NULL,'Guthrie Center, IA',15784,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38531,NULL,'Guthrie Center, IA 50115',15784,222,NULL,19,22454,0);
INSERT INTO "django_geo_db_location" VALUES(38532,NULL,'Hamilton, IA',15785,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38533,NULL,'Hamilton, IA 50116',15785,222,NULL,19,22455,0);
INSERT INTO "django_geo_db_location" VALUES(38534,NULL,'Hamlin, IA',15786,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38535,NULL,'Hamlin, IA 50117',15786,222,NULL,19,22456,0);
INSERT INTO "django_geo_db_location" VALUES(38536,NULL,'Hartford, IA',15787,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38537,NULL,'Hartford, IA 50118',15787,222,NULL,19,22457,0);
INSERT INTO "django_geo_db_location" VALUES(38538,NULL,'Harvey, IA',15788,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38539,NULL,'Harvey, IA 50119',15788,222,NULL,19,22458,0);
INSERT INTO "django_geo_db_location" VALUES(38540,NULL,'Haverhill, IA',15789,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38541,NULL,'Haverhill, IA 50120',15789,222,NULL,19,22459,0);
INSERT INTO "django_geo_db_location" VALUES(38542,NULL,'Hubbard, IA',15790,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38543,NULL,'Hubbard, IA 50122',15790,222,NULL,19,22460,0);
INSERT INTO "django_geo_db_location" VALUES(38544,NULL,'Humeston, IA',15791,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38545,NULL,'Humeston, IA 50123',15791,222,NULL,19,22461,0);
INSERT INTO "django_geo_db_location" VALUES(38546,NULL,'Huxley, IA',15792,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38547,NULL,'Huxley, IA 50124',15792,222,NULL,19,22462,0);
INSERT INTO "django_geo_db_location" VALUES(38548,NULL,'Indianola, IA',15793,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38549,NULL,'Indianola, IA 50125',15793,222,NULL,19,22463,0);
INSERT INTO "django_geo_db_location" VALUES(38550,NULL,'Iowa Falls, IA',15794,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38551,NULL,'Iowa Falls, IA 50126',15794,222,NULL,19,22464,0);
INSERT INTO "django_geo_db_location" VALUES(38552,NULL,'Ira, IA',15795,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38553,NULL,'Ira, IA 50127',15795,222,NULL,19,22465,0);
INSERT INTO "django_geo_db_location" VALUES(38554,NULL,'Jamaica, IA',15796,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38555,NULL,'Jamaica, IA 50128',15796,222,NULL,19,22466,0);
INSERT INTO "django_geo_db_location" VALUES(38556,NULL,'Jefferson, IA',15797,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38557,NULL,'Jefferson, IA 50129',15797,222,NULL,19,22467,0);
INSERT INTO "django_geo_db_location" VALUES(38558,NULL,'Jewell, IA',15798,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38559,NULL,'Jewell, IA 50130',15798,222,NULL,19,22468,0);
INSERT INTO "django_geo_db_location" VALUES(38560,NULL,'Johnston, IA',15799,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38561,NULL,'Johnston, IA 50131',15799,222,NULL,19,22469,0);
INSERT INTO "django_geo_db_location" VALUES(38562,NULL,'Kamrar, IA',15800,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38563,NULL,'Kamrar, IA 50132',15800,222,NULL,19,22470,0);
INSERT INTO "django_geo_db_location" VALUES(38564,NULL,'Kellerton, IA',15801,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38565,NULL,'Kellerton, IA 50133',15801,222,NULL,19,22471,0);
INSERT INTO "django_geo_db_location" VALUES(38566,NULL,'Kelley, IA',15802,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38567,NULL,'Kelley, IA 50134',15802,222,NULL,19,22472,0);
INSERT INTO "django_geo_db_location" VALUES(38568,NULL,'Kellogg, IA',15803,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38569,NULL,'Kellogg, IA 50135',15803,222,NULL,19,22473,0);
INSERT INTO "django_geo_db_location" VALUES(38570,NULL,'Keswick, IA',15804,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38571,NULL,'Keswick, IA 50136',15804,222,NULL,19,22474,0);
INSERT INTO "django_geo_db_location" VALUES(38572,NULL,'Killduff, IA',15805,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38573,NULL,'Killduff, IA 50137',15805,222,NULL,19,22475,0);
INSERT INTO "django_geo_db_location" VALUES(38574,NULL,'Knoxville, IA',15806,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38575,NULL,'Knoxville, IA 50138',15806,222,NULL,19,22476,0);
INSERT INTO "django_geo_db_location" VALUES(38576,NULL,'Lacona, IA',15807,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38577,NULL,'Lacona, IA 50139',15807,222,NULL,19,22477,0);
INSERT INTO "django_geo_db_location" VALUES(38578,NULL,'Lamoni, IA',15808,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38579,NULL,'Lamoni, IA 50140',15808,222,NULL,19,22478,0);
INSERT INTO "django_geo_db_location" VALUES(38580,NULL,'Laurel, IA',15809,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38581,NULL,'Laurel, IA 50141',15809,222,NULL,19,22479,0);
INSERT INTO "django_geo_db_location" VALUES(38582,NULL,'Le Grand, IA',15810,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38583,NULL,'Le Grand, IA 50142',15810,222,NULL,19,22480,0);
INSERT INTO "django_geo_db_location" VALUES(38584,NULL,'Leighton, IA',15811,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38585,NULL,'Leighton, IA 50143',15811,222,NULL,19,22481,0);
INSERT INTO "django_geo_db_location" VALUES(38586,NULL,'Leon, IA',15812,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38587,NULL,'Leon, IA 50144',15812,222,NULL,19,22482,0);
INSERT INTO "django_geo_db_location" VALUES(38588,NULL,'Liberty Center, IA',15813,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38589,NULL,'Liberty Center, IA 50145',15813,222,NULL,19,22483,0);
INSERT INTO "django_geo_db_location" VALUES(38590,NULL,'Linden, IA',15814,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38591,NULL,'Linden, IA 50146',15814,222,NULL,19,22484,0);
INSERT INTO "django_geo_db_location" VALUES(38592,NULL,'Lineville, IA',15815,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38593,NULL,'Lineville, IA 50147',15815,222,NULL,19,22485,0);
INSERT INTO "django_geo_db_location" VALUES(38594,NULL,'Liscomb, IA',15816,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38595,NULL,'Liscomb, IA 50148',15816,222,NULL,19,22486,0);
INSERT INTO "django_geo_db_location" VALUES(38596,NULL,'Lorimor, IA',15817,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38597,NULL,'Lorimor, IA 50149',15817,222,NULL,19,22487,0);
INSERT INTO "django_geo_db_location" VALUES(38598,NULL,'Lovilia, IA',15818,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38599,NULL,'Lovilia, IA 50150',15818,222,NULL,19,22488,0);
INSERT INTO "django_geo_db_location" VALUES(38600,NULL,'Lucas, IA',15819,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38601,NULL,'Lucas, IA 50151',15819,222,NULL,19,22489,0);
INSERT INTO "django_geo_db_location" VALUES(38602,NULL,'Luther, IA',15820,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38603,NULL,'Luther, IA 50152',15820,222,NULL,19,22490,0);
INSERT INTO "django_geo_db_location" VALUES(38604,NULL,'Lynnville, IA',15821,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38605,NULL,'Lynnville, IA 50153',15821,222,NULL,19,22491,0);
INSERT INTO "django_geo_db_location" VALUES(38606,NULL,'McCallsburg, IA',15822,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38607,NULL,'McCallsburg, IA 50154',15822,222,NULL,19,22492,0);
INSERT INTO "django_geo_db_location" VALUES(38608,NULL,'Macksburg, IA',15823,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38609,NULL,'Macksburg, IA 50155',15823,222,NULL,19,22493,0);
INSERT INTO "django_geo_db_location" VALUES(38610,NULL,'Madrid, IA',15824,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38611,NULL,'Madrid, IA 50156',15824,222,NULL,19,22494,0);
INSERT INTO "django_geo_db_location" VALUES(38612,NULL,'Malcom, IA',15825,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38613,NULL,'Malcom, IA 50157',15825,222,NULL,19,22495,0);
INSERT INTO "django_geo_db_location" VALUES(38614,NULL,'Marshalltown, IA',15826,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38615,NULL,'Marshalltown, IA 50158',15826,222,NULL,19,22496,0);
INSERT INTO "django_geo_db_location" VALUES(38616,NULL,'Martensdale, IA',15827,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38617,NULL,'Martensdale, IA 50160',15827,222,NULL,19,22497,0);
INSERT INTO "django_geo_db_location" VALUES(38618,NULL,'Maxwell, IA',15828,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38619,NULL,'Maxwell, IA 50161',15828,222,NULL,19,22498,0);
INSERT INTO "django_geo_db_location" VALUES(38620,NULL,'Melbourne, IA',15829,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38621,NULL,'Melbourne, IA 50162',15829,222,NULL,19,22499,0);
INSERT INTO "django_geo_db_location" VALUES(38622,NULL,'Melcher, IA',15830,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38623,NULL,'Melcher, IA 50163',15830,222,NULL,19,22500,0);
INSERT INTO "django_geo_db_location" VALUES(38624,NULL,'Menlo, IA',15831,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38625,NULL,'Menlo, IA 50164',15831,222,NULL,19,22501,0);
INSERT INTO "django_geo_db_location" VALUES(38626,NULL,'Millerton, IA',15832,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38627,NULL,'Millerton, IA 50165',15832,222,NULL,19,22502,0);
INSERT INTO "django_geo_db_location" VALUES(38628,NULL,'Milo, IA',15833,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38629,NULL,'Milo, IA 50166',15833,222,NULL,19,22503,0);
INSERT INTO "django_geo_db_location" VALUES(38630,NULL,'Minburn, IA',15834,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38631,NULL,'Minburn, IA 50167',15834,222,NULL,19,22504,0);
INSERT INTO "django_geo_db_location" VALUES(38632,NULL,'Mingo, IA',15835,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38633,NULL,'Mingo, IA 50168',15835,222,NULL,19,22505,0);
INSERT INTO "django_geo_db_location" VALUES(38634,NULL,'Mitchellville, IA',15836,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38635,NULL,'Mitchellville, IA 50169',15836,222,NULL,19,22506,0);
INSERT INTO "django_geo_db_location" VALUES(38636,NULL,'Monroe, IA',15837,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38637,NULL,'Monroe, IA 50170',15837,222,NULL,19,22507,0);
INSERT INTO "django_geo_db_location" VALUES(38638,NULL,'Montezuma, IA',15838,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38639,NULL,'Montezuma, IA 50171',15838,222,NULL,19,22508,0);
INSERT INTO "django_geo_db_location" VALUES(38640,NULL,'Montour, IA',15839,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38641,NULL,'Montour, IA 50173',15839,222,NULL,19,22509,0);
INSERT INTO "django_geo_db_location" VALUES(38642,NULL,'Murray, IA',15840,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38643,NULL,'Murray, IA 50174',15840,222,NULL,19,22510,0);
INSERT INTO "django_geo_db_location" VALUES(38644,NULL,'Grinnell, IA 50177',15783,222,NULL,19,22511,0);
INSERT INTO "django_geo_db_location" VALUES(38645,NULL,'Knoxville, IA 50197',15806,222,NULL,19,22512,0);
INSERT INTO "django_geo_db_location" VALUES(38646,NULL,'Knoxville, IA 50198',15806,222,NULL,19,22513,0);
INSERT INTO "django_geo_db_location" VALUES(38647,NULL,'Nevada, IA',15841,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38648,NULL,'Nevada, IA 50201',15841,222,NULL,19,22514,0);
INSERT INTO "django_geo_db_location" VALUES(38649,NULL,'New Providence, IA',15842,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38650,NULL,'New Providence, IA 50206',15842,222,NULL,19,22515,0);
INSERT INTO "django_geo_db_location" VALUES(38651,NULL,'New Sharon, IA',15843,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38652,NULL,'New Sharon, IA 50207',15843,222,NULL,19,22516,0);
INSERT INTO "django_geo_db_location" VALUES(38653,NULL,'Newton, IA',15844,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38654,NULL,'Newton, IA 50208',15844,222,NULL,19,22517,0);
INSERT INTO "django_geo_db_location" VALUES(38655,NULL,'New Virginia, IA',15845,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38656,NULL,'New Virginia, IA 50210',15845,222,NULL,19,22518,0);
INSERT INTO "django_geo_db_location" VALUES(38657,NULL,'Norwalk, IA',15846,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38658,NULL,'Norwalk, IA 50211',15846,222,NULL,19,22519,0);
INSERT INTO "django_geo_db_location" VALUES(38659,NULL,'Ogden, IA',15847,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38660,NULL,'Ogden, IA 50212',15847,222,NULL,19,22520,0);
INSERT INTO "django_geo_db_location" VALUES(38661,NULL,'Osceola, IA',15848,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38662,NULL,'Osceola, IA 50213',15848,222,NULL,19,22521,0);
INSERT INTO "django_geo_db_location" VALUES(38663,NULL,'Otley, IA',15849,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38664,NULL,'Otley, IA 50214',15849,222,NULL,19,22522,0);
INSERT INTO "django_geo_db_location" VALUES(38665,NULL,'Panora, IA',15850,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38666,NULL,'Panora, IA 50216',15850,222,NULL,19,22523,0);
INSERT INTO "django_geo_db_location" VALUES(38667,NULL,'Paton, IA',15851,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38668,NULL,'Paton, IA 50217',15851,222,NULL,19,22524,0);
INSERT INTO "django_geo_db_location" VALUES(38669,NULL,'Patterson, IA',15852,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38670,NULL,'Patterson, IA 50218',15852,222,NULL,19,22525,0);
INSERT INTO "django_geo_db_location" VALUES(38671,NULL,'Pella, IA',15853,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38672,NULL,'Pella, IA 50219',15853,222,NULL,19,22526,0);
INSERT INTO "django_geo_db_location" VALUES(38673,NULL,'Perry, IA',15854,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38674,NULL,'Perry, IA 50220',15854,222,NULL,19,22527,0);
INSERT INTO "django_geo_db_location" VALUES(38675,NULL,'Peru, IA',15855,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38676,NULL,'Peru, IA 50222',15855,222,NULL,19,22528,0);
INSERT INTO "django_geo_db_location" VALUES(38677,NULL,'Pilot Mound, IA',15856,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38678,NULL,'Pilot Mound, IA 50223',15856,222,NULL,19,22529,0);
INSERT INTO "django_geo_db_location" VALUES(38679,NULL,'Pleasantville, IA',15857,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38680,NULL,'Pleasantville, IA 50225',15857,222,NULL,19,22530,0);
INSERT INTO "django_geo_db_location" VALUES(38681,NULL,'Polk City, IA',15858,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38682,NULL,'Polk City, IA 50226',15858,222,NULL,19,22531,0);
INSERT INTO "django_geo_db_location" VALUES(38683,NULL,'Popejoy, IA',15859,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38684,NULL,'Popejoy, IA 50227',15859,222,NULL,19,22532,0);
INSERT INTO "django_geo_db_location" VALUES(38685,NULL,'Prairie City, IA',15860,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38686,NULL,'Prairie City, IA 50228',15860,222,NULL,19,22533,0);
INSERT INTO "django_geo_db_location" VALUES(38687,NULL,'Prole, IA',15861,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38688,NULL,'Prole, IA 50229',15861,222,NULL,19,22534,0);
INSERT INTO "django_geo_db_location" VALUES(38689,NULL,'Radcliffe, IA',15862,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38690,NULL,'Radcliffe, IA 50230',15862,222,NULL,19,22535,0);
INSERT INTO "django_geo_db_location" VALUES(38691,NULL,'Randall, IA',15863,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38692,NULL,'Randall, IA 50231',15863,222,NULL,19,22536,0);
INSERT INTO "django_geo_db_location" VALUES(38693,NULL,'Reasnor, IA',15864,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38694,NULL,'Reasnor, IA 50232',15864,222,NULL,19,22537,0);
INSERT INTO "django_geo_db_location" VALUES(38695,NULL,'Redfield, IA',15865,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38696,NULL,'Redfield, IA 50233',15865,222,NULL,19,22538,0);
INSERT INTO "django_geo_db_location" VALUES(38697,NULL,'Rhodes, IA',15866,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38698,NULL,'Rhodes, IA 50234',15866,222,NULL,19,22539,0);
INSERT INTO "django_geo_db_location" VALUES(38699,NULL,'Rippey, IA',15867,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38700,NULL,'Rippey, IA 50235',15867,222,NULL,19,22540,0);
INSERT INTO "django_geo_db_location" VALUES(38701,NULL,'Roland, IA',15868,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38702,NULL,'Roland, IA 50236',15868,222,NULL,19,22541,0);
INSERT INTO "django_geo_db_location" VALUES(38703,NULL,'Runnells, IA',15869,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38704,NULL,'Runnells, IA 50237',15869,222,NULL,19,22542,0);
INSERT INTO "django_geo_db_location" VALUES(38705,NULL,'Russell, IA',15870,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38706,NULL,'Russell, IA 50238',15870,222,NULL,19,22543,0);
INSERT INTO "django_geo_db_location" VALUES(38707,NULL,'Saint Anthony, IA',15871,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38708,NULL,'Saint Anthony, IA 50239',15871,222,NULL,19,22544,0);
INSERT INTO "django_geo_db_location" VALUES(38709,NULL,'Saint Charles, IA',15872,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38710,NULL,'Saint Charles, IA 50240',15872,222,NULL,19,22545,0);
INSERT INTO "django_geo_db_location" VALUES(38711,NULL,'Saint Marys, IA',15873,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38712,NULL,'Saint Marys, IA 50241',15873,222,NULL,19,22546,0);
INSERT INTO "django_geo_db_location" VALUES(38713,NULL,'Searsboro, IA',15874,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38714,NULL,'Searsboro, IA 50242',15874,222,NULL,19,22547,0);
INSERT INTO "django_geo_db_location" VALUES(38715,NULL,'Sheldahl, IA',15875,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38716,NULL,'Sheldahl, IA 50243',15875,222,NULL,19,22548,0);
INSERT INTO "django_geo_db_location" VALUES(38717,NULL,'Slater, IA',15876,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38718,NULL,'Slater, IA 50244',15876,222,NULL,19,22549,0);
INSERT INTO "django_geo_db_location" VALUES(38719,NULL,'Stanhope, IA',15877,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38720,NULL,'Stanhope, IA 50246',15877,222,NULL,19,22550,0);
INSERT INTO "django_geo_db_location" VALUES(38721,NULL,'State Center, IA',15878,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38722,NULL,'State Center, IA 50247',15878,222,NULL,19,22551,0);
INSERT INTO "django_geo_db_location" VALUES(38723,NULL,'Story City, IA',15879,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38724,NULL,'Story City, IA 50248',15879,222,NULL,19,22552,0);
INSERT INTO "django_geo_db_location" VALUES(38725,NULL,'Stratford, IA',15880,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38726,NULL,'Stratford, IA 50249',15880,222,NULL,19,22553,0);
INSERT INTO "django_geo_db_location" VALUES(38727,NULL,'Stuart, IA',15881,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38728,NULL,'Stuart, IA 50250',15881,222,NULL,19,22554,0);
INSERT INTO "django_geo_db_location" VALUES(38729,NULL,'Sully, IA',15882,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38730,NULL,'Sully, IA 50251',15882,222,NULL,19,22555,0);
INSERT INTO "django_geo_db_location" VALUES(38731,NULL,'Swan, IA',15883,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38732,NULL,'Swan, IA 50252',15883,222,NULL,19,22556,0);
INSERT INTO "django_geo_db_location" VALUES(38733,NULL,'Thayer, IA',15884,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38734,NULL,'Thayer, IA 50254',15884,222,NULL,19,22557,0);
INSERT INTO "django_geo_db_location" VALUES(38735,NULL,'Thornburg, IA',15885,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38736,NULL,'Thornburg, IA 50255',15885,222,NULL,19,22558,0);
INSERT INTO "django_geo_db_location" VALUES(38737,NULL,'Tracy, IA',15886,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38738,NULL,'Tracy, IA 50256',15886,222,NULL,19,22559,0);
INSERT INTO "django_geo_db_location" VALUES(38739,NULL,'Truro, IA',15887,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38740,NULL,'Truro, IA 50257',15887,222,NULL,19,22560,0);
INSERT INTO "django_geo_db_location" VALUES(38741,NULL,'Union, IA',15888,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38742,NULL,'Union, IA 50258',15888,222,NULL,19,22561,0);
INSERT INTO "django_geo_db_location" VALUES(38743,NULL,'Gifford, IA',15889,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38744,NULL,'Gifford, IA 50259',15889,222,NULL,19,22562,0);
INSERT INTO "django_geo_db_location" VALUES(38745,NULL,'Van Meter, IA',15890,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38746,NULL,'Van Meter, IA 50261',15890,222,NULL,19,22563,0);
INSERT INTO "django_geo_db_location" VALUES(38747,NULL,'Van Wert, IA',15891,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38748,NULL,'Van Wert, IA 50262',15891,222,NULL,19,22564,0);
INSERT INTO "django_geo_db_location" VALUES(38749,NULL,'Waukee, IA',15892,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38750,NULL,'Waukee, IA 50263',15892,222,NULL,19,22565,0);
INSERT INTO "django_geo_db_location" VALUES(38751,NULL,'Weldon, IA',15893,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38752,NULL,'Weldon, IA 50264',15893,222,NULL,19,22566,0);
INSERT INTO "django_geo_db_location" VALUES(38753,NULL,'West Des Moines, IA',15894,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38754,NULL,'West Des Moines, IA 50265',15894,222,NULL,19,22567,0);
INSERT INTO "django_geo_db_location" VALUES(38755,NULL,'West Des Moines, IA 50266',15894,222,NULL,19,22568,0);
INSERT INTO "django_geo_db_location" VALUES(38756,NULL,'What Cheer, IA',15895,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38757,NULL,'What Cheer, IA 50268',15895,222,NULL,19,22569,0);
INSERT INTO "django_geo_db_location" VALUES(38758,NULL,'Whitten, IA',15896,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38759,NULL,'Whitten, IA 50269',15896,222,NULL,19,22570,0);
INSERT INTO "django_geo_db_location" VALUES(38760,NULL,'Williams, IA',15897,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38761,NULL,'Williams, IA 50271',15897,222,NULL,19,22571,0);
INSERT INTO "django_geo_db_location" VALUES(38762,NULL,'Williamson, IA',15898,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38763,NULL,'Williamson, IA 50272',15898,222,NULL,19,22572,0);
INSERT INTO "django_geo_db_location" VALUES(38764,NULL,'Winterset, IA',15899,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38765,NULL,'Winterset, IA 50273',15899,222,NULL,19,22573,0);
INSERT INTO "django_geo_db_location" VALUES(38766,NULL,'Wiota, IA',15900,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38767,NULL,'Wiota, IA 50274',15900,222,NULL,19,22574,0);
INSERT INTO "django_geo_db_location" VALUES(38768,NULL,'Woodburn, IA',15901,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38769,NULL,'Woodburn, IA 50275',15901,222,NULL,19,22575,0);
INSERT INTO "django_geo_db_location" VALUES(38770,NULL,'Woodward, IA',15902,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38771,NULL,'Woodward, IA 50276',15902,222,NULL,19,22576,0);
INSERT INTO "django_geo_db_location" VALUES(38772,NULL,'Yale, IA',15903,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38773,NULL,'Yale, IA 50277',15903,222,NULL,19,22577,0);
INSERT INTO "django_geo_db_location" VALUES(38774,NULL,'Zearing, IA',15904,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38775,NULL,'Zearing, IA 50278',15904,222,NULL,19,22578,0);
INSERT INTO "django_geo_db_location" VALUES(38776,NULL,'Stratford, IA 50294',15880,222,NULL,19,22579,0);
INSERT INTO "django_geo_db_location" VALUES(38777,NULL,'Des Moines, IA',15905,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38778,NULL,'Des Moines, IA 50301',15905,222,NULL,19,22580,0);
INSERT INTO "django_geo_db_location" VALUES(38779,NULL,'Des Moines, IA 50302',15905,222,NULL,19,22581,0);
INSERT INTO "django_geo_db_location" VALUES(38780,NULL,'Des Moines, IA 50303',15905,222,NULL,19,22582,0);
INSERT INTO "django_geo_db_location" VALUES(38781,NULL,'Des Moines, IA 50304',15905,222,NULL,19,22583,0);
INSERT INTO "django_geo_db_location" VALUES(38782,NULL,'Des Moines, IA 50305',15905,222,NULL,19,22584,0);
INSERT INTO "django_geo_db_location" VALUES(38783,NULL,'Des Moines, IA 50306',15905,222,NULL,19,22585,0);
INSERT INTO "django_geo_db_location" VALUES(38784,NULL,'Des Moines, IA 50307',15905,222,NULL,19,22586,0);
INSERT INTO "django_geo_db_location" VALUES(38785,NULL,'Des Moines, IA 50308',15905,222,NULL,19,22587,0);
INSERT INTO "django_geo_db_location" VALUES(38786,NULL,'Des Moines, IA 50309',15905,222,NULL,19,22588,0);
INSERT INTO "django_geo_db_location" VALUES(38787,NULL,'Des Moines, IA 50310',15905,222,NULL,19,22589,0);
INSERT INTO "django_geo_db_location" VALUES(38788,NULL,'Des Moines, IA 50311',15905,222,NULL,19,22590,0);
INSERT INTO "django_geo_db_location" VALUES(38789,NULL,'Des Moines, IA 50312',15905,222,NULL,19,22591,0);
INSERT INTO "django_geo_db_location" VALUES(38790,NULL,'Des Moines, IA 50313',15905,222,NULL,19,22592,0);
INSERT INTO "django_geo_db_location" VALUES(38791,NULL,'Des Moines, IA 50314',15905,222,NULL,19,22593,0);
INSERT INTO "django_geo_db_location" VALUES(38792,NULL,'Des Moines, IA 50315',15905,222,NULL,19,22594,0);
INSERT INTO "django_geo_db_location" VALUES(38793,NULL,'Des Moines, IA 50316',15905,222,NULL,19,22595,0);
INSERT INTO "django_geo_db_location" VALUES(38794,NULL,'Des Moines, IA 50317',15905,222,NULL,19,22596,0);
INSERT INTO "django_geo_db_location" VALUES(38795,NULL,'Des Moines, IA 50318',15905,222,NULL,19,22597,0);
INSERT INTO "django_geo_db_location" VALUES(38796,NULL,'Des Moines, IA 50319',15905,222,NULL,19,22598,0);
INSERT INTO "django_geo_db_location" VALUES(38797,NULL,'Des Moines, IA 50320',15905,222,NULL,19,22599,0);
INSERT INTO "django_geo_db_location" VALUES(38798,NULL,'Des Moines, IA 50321',15905,222,NULL,19,22600,0);
INSERT INTO "django_geo_db_location" VALUES(38799,NULL,'Urbandale, IA',15906,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38800,NULL,'Urbandale, IA 50322',15906,222,NULL,19,22601,0);
INSERT INTO "django_geo_db_location" VALUES(38801,NULL,'Urbandale, IA 50323',15906,222,NULL,19,22602,0);
INSERT INTO "django_geo_db_location" VALUES(38802,NULL,'Clive, IA',15907,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38803,NULL,'Clive, IA 50325',15907,222,NULL,19,22603,0);
INSERT INTO "django_geo_db_location" VALUES(38804,NULL,'Pleasant Hill, IA',15908,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38805,NULL,'Pleasant Hill, IA 50327',15908,222,NULL,19,22604,0);
INSERT INTO "django_geo_db_location" VALUES(38806,NULL,'Des Moines, IA 50328',15905,222,NULL,19,22605,0);
INSERT INTO "django_geo_db_location" VALUES(38807,NULL,'Des Moines, IA 50329',15905,222,NULL,19,22606,0);
INSERT INTO "django_geo_db_location" VALUES(38808,NULL,'Des Moines, IA 50330',15905,222,NULL,19,22607,0);
INSERT INTO "django_geo_db_location" VALUES(38809,NULL,'Des Moines, IA 50331',15905,222,NULL,19,22608,0);
INSERT INTO "django_geo_db_location" VALUES(38810,NULL,'Des Moines, IA 50332',15905,222,NULL,19,22609,0);
INSERT INTO "django_geo_db_location" VALUES(38811,NULL,'Des Moines, IA 50333',15905,222,NULL,19,22610,0);
INSERT INTO "django_geo_db_location" VALUES(38812,NULL,'Des Moines, IA 50334',15905,222,NULL,19,22611,0);
INSERT INTO "django_geo_db_location" VALUES(38813,NULL,'Des Moines, IA 50335',15905,222,NULL,19,22612,0);
INSERT INTO "django_geo_db_location" VALUES(38814,NULL,'Des Moines, IA 50336',15905,222,NULL,19,22613,0);
INSERT INTO "django_geo_db_location" VALUES(38815,NULL,'Des Moines, IA 50338',15905,222,NULL,19,22614,0);
INSERT INTO "django_geo_db_location" VALUES(38816,NULL,'Des Moines, IA 50339',15905,222,NULL,19,22615,0);
INSERT INTO "django_geo_db_location" VALUES(38817,NULL,'Des Moines, IA 50340',15905,222,NULL,19,22616,0);
INSERT INTO "django_geo_db_location" VALUES(38818,NULL,'Des Moines, IA 50347',15905,222,NULL,19,22617,0);
INSERT INTO "django_geo_db_location" VALUES(38819,NULL,'Des Moines, IA 50350',15905,222,NULL,19,22618,0);
INSERT INTO "django_geo_db_location" VALUES(38820,NULL,'Des Moines, IA 50359',15905,222,NULL,19,22619,0);
INSERT INTO "django_geo_db_location" VALUES(38821,NULL,'Des Moines, IA 50360',15905,222,NULL,19,22620,0);
INSERT INTO "django_geo_db_location" VALUES(38822,NULL,'Des Moines, IA 50361',15905,222,NULL,19,22621,0);
INSERT INTO "django_geo_db_location" VALUES(38823,NULL,'Des Moines, IA 50362',15905,222,NULL,19,22622,0);
INSERT INTO "django_geo_db_location" VALUES(38824,NULL,'Des Moines, IA 50363',15905,222,NULL,19,22623,0);
INSERT INTO "django_geo_db_location" VALUES(38825,NULL,'Des Moines, IA 50364',15905,222,NULL,19,22624,0);
INSERT INTO "django_geo_db_location" VALUES(38826,NULL,'Des Moines, IA 50367',15905,222,NULL,19,22625,0);
INSERT INTO "django_geo_db_location" VALUES(38827,NULL,'Des Moines, IA 50368',15905,222,NULL,19,22626,0);
INSERT INTO "django_geo_db_location" VALUES(38828,NULL,'Des Moines, IA 50369',15905,222,NULL,19,22627,0);
INSERT INTO "django_geo_db_location" VALUES(38829,NULL,'Des Moines, IA 50380',15905,222,NULL,19,22628,0);
INSERT INTO "django_geo_db_location" VALUES(38830,NULL,'Des Moines, IA 50381',15905,222,NULL,19,22629,0);
INSERT INTO "django_geo_db_location" VALUES(38831,NULL,'Des Moines, IA 50391',15905,222,NULL,19,22630,0);
INSERT INTO "django_geo_db_location" VALUES(38832,NULL,'Des Moines, IA 50392',15905,222,NULL,19,22631,0);
INSERT INTO "django_geo_db_location" VALUES(38833,NULL,'Des Moines, IA 50393',15905,222,NULL,19,22632,0);
INSERT INTO "django_geo_db_location" VALUES(38834,NULL,'Des Moines, IA 50394',15905,222,NULL,19,22633,0);
INSERT INTO "django_geo_db_location" VALUES(38835,NULL,'Des Moines, IA 50395',15905,222,NULL,19,22634,0);
INSERT INTO "django_geo_db_location" VALUES(38836,NULL,'Des Moines, IA 50396',15905,222,NULL,19,22635,0);
INSERT INTO "django_geo_db_location" VALUES(38837,NULL,'Des Moines, IA 50397',15905,222,NULL,19,22636,0);
INSERT INTO "django_geo_db_location" VALUES(38838,NULL,'West Des Moines, IA 50398',15894,222,NULL,19,22637,0);
INSERT INTO "django_geo_db_location" VALUES(38839,NULL,'Mason City, IA',15909,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38840,NULL,'Mason City, IA 50401',15909,222,NULL,19,22638,0);
INSERT INTO "django_geo_db_location" VALUES(38841,NULL,'Mason City, IA 50402',15909,222,NULL,19,22639,0);
INSERT INTO "django_geo_db_location" VALUES(38842,NULL,'Lake Mills, IA',15910,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38843,NULL,'Lake Mills, IA 50405',15910,222,NULL,19,22640,0);
INSERT INTO "django_geo_db_location" VALUES(38844,NULL,'Alexander, IA',15911,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38845,NULL,'Alexander, IA 50420',15911,222,NULL,19,22641,0);
INSERT INTO "django_geo_db_location" VALUES(38846,NULL,'Belmond, IA',15912,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38847,NULL,'Belmond, IA 50421',15912,222,NULL,19,22642,0);
INSERT INTO "django_geo_db_location" VALUES(38848,NULL,'Britt, IA',15913,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38849,NULL,'Britt, IA 50423',15913,222,NULL,19,22643,0);
INSERT INTO "django_geo_db_location" VALUES(38850,NULL,'Buffalo Center, IA',15914,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38851,NULL,'Buffalo Center, IA 50424',15914,222,NULL,19,22644,0);
INSERT INTO "django_geo_db_location" VALUES(38852,NULL,'Carpenter, IA',15915,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38853,NULL,'Carpenter, IA 50426',15915,222,NULL,19,22645,0);
INSERT INTO "django_geo_db_location" VALUES(38854,NULL,'Chapin, IA',15916,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38855,NULL,'Chapin, IA 50427',15916,222,NULL,19,22646,0);
INSERT INTO "django_geo_db_location" VALUES(38856,NULL,'Clear Lake, IA',15917,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38857,NULL,'Clear Lake, IA 50428',15917,222,NULL,19,22647,0);
INSERT INTO "django_geo_db_location" VALUES(38858,NULL,'Corwith, IA',15918,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38859,NULL,'Corwith, IA 50430',15918,222,NULL,19,22648,0);
INSERT INTO "django_geo_db_location" VALUES(38860,NULL,'Coulter, IA',15919,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38861,NULL,'Coulter, IA 50431',15919,222,NULL,19,22649,0);
INSERT INTO "django_geo_db_location" VALUES(38862,NULL,'Crystal Lake, IA',15920,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38863,NULL,'Crystal Lake, IA 50432',15920,222,NULL,19,22650,0);
INSERT INTO "django_geo_db_location" VALUES(38864,NULL,'Dougherty, IA',15921,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38865,NULL,'Dougherty, IA 50433',15921,222,NULL,19,22651,0);
INSERT INTO "django_geo_db_location" VALUES(38866,NULL,'Fertile, IA',15922,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38867,NULL,'Fertile, IA 50434',15922,222,NULL,19,22652,0);
INSERT INTO "django_geo_db_location" VALUES(38868,NULL,'Floyd, IA',15923,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38869,NULL,'Floyd, IA 50435',15923,222,NULL,19,22653,0);
INSERT INTO "django_geo_db_location" VALUES(38870,NULL,'Forest City, IA',15924,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38871,NULL,'Forest City, IA 50436',15924,222,NULL,19,22654,0);
INSERT INTO "django_geo_db_location" VALUES(38872,NULL,'Garner, IA',15925,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38873,NULL,'Garner, IA 50438',15925,222,NULL,19,22655,0);
INSERT INTO "django_geo_db_location" VALUES(38874,NULL,'Goodell, IA',15926,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38875,NULL,'Goodell, IA 50439',15926,222,NULL,19,22656,0);
INSERT INTO "django_geo_db_location" VALUES(38876,NULL,'Grafton, IA',15927,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38877,NULL,'Grafton, IA 50440',15927,222,NULL,19,22657,0);
INSERT INTO "django_geo_db_location" VALUES(38878,NULL,'Hampton, IA',15928,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38879,NULL,'Hampton, IA 50441',15928,222,NULL,19,22658,0);
INSERT INTO "django_geo_db_location" VALUES(38880,NULL,'Hanlontown, IA',15929,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38881,NULL,'Hanlontown, IA 50444',15929,222,NULL,19,22659,0);
INSERT INTO "django_geo_db_location" VALUES(38882,NULL,'Joice, IA',15930,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38883,NULL,'Joice, IA 50446',15930,222,NULL,19,22660,0);
INSERT INTO "django_geo_db_location" VALUES(38884,NULL,'Kanawha, IA',15931,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38885,NULL,'Kanawha, IA 50447',15931,222,NULL,19,22661,0);
INSERT INTO "django_geo_db_location" VALUES(38886,NULL,'Kensett, IA',15932,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38887,NULL,'Kensett, IA 50448',15932,222,NULL,19,22662,0);
INSERT INTO "django_geo_db_location" VALUES(38888,NULL,'Klemme, IA',15933,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38889,NULL,'Klemme, IA 50449',15933,222,NULL,19,22663,0);
INSERT INTO "django_geo_db_location" VALUES(38890,NULL,'Lake Mills, IA 50450',15910,222,NULL,19,22664,0);
INSERT INTO "django_geo_db_location" VALUES(38891,NULL,'Lakota, IA',15934,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38892,NULL,'Lakota, IA 50451',15934,222,NULL,19,22665,0);
INSERT INTO "django_geo_db_location" VALUES(38893,NULL,'Latimer, IA',15935,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38894,NULL,'Latimer, IA 50452',15935,222,NULL,19,22666,0);
INSERT INTO "django_geo_db_location" VALUES(38895,NULL,'Leland, IA',15936,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38896,NULL,'Leland, IA 50453',15936,222,NULL,19,22667,0);
INSERT INTO "django_geo_db_location" VALUES(38897,NULL,'Little Cedar, IA',15937,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38898,NULL,'Little Cedar, IA 50454',15937,222,NULL,19,22668,0);
INSERT INTO "django_geo_db_location" VALUES(38899,NULL,'McIntire, IA',15938,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38900,NULL,'McIntire, IA 50455',15938,222,NULL,19,22669,0);
INSERT INTO "django_geo_db_location" VALUES(38901,NULL,'Manly, IA',15939,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38902,NULL,'Manly, IA 50456',15939,222,NULL,19,22670,0);
INSERT INTO "django_geo_db_location" VALUES(38903,NULL,'Meservey, IA',15940,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38904,NULL,'Meservey, IA 50457',15940,222,NULL,19,22671,0);
INSERT INTO "django_geo_db_location" VALUES(38905,NULL,'Nora Springs, IA',15941,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38906,NULL,'Nora Springs, IA 50458',15941,222,NULL,19,22672,0);
INSERT INTO "django_geo_db_location" VALUES(38907,NULL,'Northwood, IA',15942,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38908,NULL,'Northwood, IA 50459',15942,222,NULL,19,22673,0);
INSERT INTO "django_geo_db_location" VALUES(38909,NULL,'Orchard, IA',15943,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38910,NULL,'Orchard, IA 50460',15943,222,NULL,19,22674,0);
INSERT INTO "django_geo_db_location" VALUES(38911,NULL,'Osage, IA',15944,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38912,NULL,'Osage, IA 50461',15944,222,NULL,19,22675,0);
INSERT INTO "django_geo_db_location" VALUES(38913,NULL,'Plymouth, IA',15945,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38914,NULL,'Plymouth, IA 50464',15945,222,NULL,19,22676,0);
INSERT INTO "django_geo_db_location" VALUES(38915,NULL,'Rake, IA',15946,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38916,NULL,'Rake, IA 50465',15946,222,NULL,19,22677,0);
INSERT INTO "django_geo_db_location" VALUES(38917,NULL,'Riceville, IA',15947,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38918,NULL,'Riceville, IA 50466',15947,222,NULL,19,22678,0);
INSERT INTO "django_geo_db_location" VALUES(38919,NULL,'Rock Falls, IA',15948,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38920,NULL,'Rock Falls, IA 50467',15948,222,NULL,19,22679,0);
INSERT INTO "django_geo_db_location" VALUES(38921,NULL,'Rockford, IA',15949,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38922,NULL,'Rockford, IA 50468',15949,222,NULL,19,22680,0);
INSERT INTO "django_geo_db_location" VALUES(38923,NULL,'Rockwell, IA',15950,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38924,NULL,'Rockwell, IA 50469',15950,222,NULL,19,22681,0);
INSERT INTO "django_geo_db_location" VALUES(38925,NULL,'Rowan, IA',15951,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38926,NULL,'Rowan, IA 50470',15951,222,NULL,19,22682,0);
INSERT INTO "django_geo_db_location" VALUES(38927,NULL,'Rudd, IA',15952,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38928,NULL,'Rudd, IA 50471',15952,222,NULL,19,22683,0);
INSERT INTO "django_geo_db_location" VALUES(38929,NULL,'Saint Ansgar, IA',15953,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38930,NULL,'Saint Ansgar, IA 50472',15953,222,NULL,19,22684,0);
INSERT INTO "django_geo_db_location" VALUES(38931,NULL,'Scarville, IA',15954,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38932,NULL,'Scarville, IA 50473',15954,222,NULL,19,22685,0);
INSERT INTO "django_geo_db_location" VALUES(38933,NULL,'Sheffield, IA',15955,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38934,NULL,'Sheffield, IA 50475',15955,222,NULL,19,22686,0);
INSERT INTO "django_geo_db_location" VALUES(38935,NULL,'Stacyville, IA',15956,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38936,NULL,'Stacyville, IA 50476',15956,222,NULL,19,22687,0);
INSERT INTO "django_geo_db_location" VALUES(38937,NULL,'Swaledale, IA',15957,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38938,NULL,'Swaledale, IA 50477',15957,222,NULL,19,22688,0);
INSERT INTO "django_geo_db_location" VALUES(38939,NULL,'Thompson, IA',15958,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38940,NULL,'Thompson, IA 50478',15958,222,NULL,19,22689,0);
INSERT INTO "django_geo_db_location" VALUES(38941,NULL,'Thornton, IA',15959,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38942,NULL,'Thornton, IA 50479',15959,222,NULL,19,22690,0);
INSERT INTO "django_geo_db_location" VALUES(38943,NULL,'Titonka, IA',15960,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38944,NULL,'Titonka, IA 50480',15960,222,NULL,19,22691,0);
INSERT INTO "django_geo_db_location" VALUES(38945,NULL,'Toeterville, IA',15961,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38946,NULL,'Toeterville, IA 50481',15961,222,NULL,19,22692,0);
INSERT INTO "django_geo_db_location" VALUES(38947,NULL,'Ventura, IA',15962,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38948,NULL,'Ventura, IA 50482',15962,222,NULL,19,22693,0);
INSERT INTO "django_geo_db_location" VALUES(38949,NULL,'Wesley, IA',15963,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38950,NULL,'Wesley, IA 50483',15963,222,NULL,19,22694,0);
INSERT INTO "django_geo_db_location" VALUES(38951,NULL,'Woden, IA',15964,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38952,NULL,'Woden, IA 50484',15964,222,NULL,19,22695,0);
INSERT INTO "django_geo_db_location" VALUES(38953,NULL,'Fort Dodge, IA',15965,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38954,NULL,'Fort Dodge, IA 50501',15965,222,NULL,19,22696,0);
INSERT INTO "django_geo_db_location" VALUES(38955,NULL,'Albert City, IA',15966,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38956,NULL,'Albert City, IA 50510',15966,222,NULL,19,22697,0);
INSERT INTO "django_geo_db_location" VALUES(38957,NULL,'Algona, IA',15967,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38958,NULL,'Algona, IA 50511',15967,222,NULL,19,22698,0);
INSERT INTO "django_geo_db_location" VALUES(38959,NULL,'Armstrong, IA',15968,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38960,NULL,'Armstrong, IA 50514',15968,222,NULL,19,22699,0);
INSERT INTO "django_geo_db_location" VALUES(38961,NULL,'Ayrshire, IA',15969,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38962,NULL,'Ayrshire, IA 50515',15969,222,NULL,19,22700,0);
INSERT INTO "django_geo_db_location" VALUES(38963,NULL,'Badger, IA',15970,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38964,NULL,'Badger, IA 50516',15970,222,NULL,19,22701,0);
INSERT INTO "django_geo_db_location" VALUES(38965,NULL,'Bancroft, IA',15971,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38966,NULL,'Bancroft, IA 50517',15971,222,NULL,19,22702,0);
INSERT INTO "django_geo_db_location" VALUES(38967,NULL,'Barnum, IA',15972,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38968,NULL,'Barnum, IA 50518',15972,222,NULL,19,22703,0);
INSERT INTO "django_geo_db_location" VALUES(38969,NULL,'Bode, IA',15973,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38970,NULL,'Bode, IA 50519',15973,222,NULL,19,22704,0);
INSERT INTO "django_geo_db_location" VALUES(38971,NULL,'Bradgate, IA',15974,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38972,NULL,'Bradgate, IA 50520',15974,222,NULL,19,22705,0);
INSERT INTO "django_geo_db_location" VALUES(38973,NULL,'Burnside, IA',15975,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38974,NULL,'Burnside, IA 50521',15975,222,NULL,19,22706,0);
INSERT INTO "django_geo_db_location" VALUES(38975,NULL,'Burt, IA',15976,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38976,NULL,'Burt, IA 50522',15976,222,NULL,19,22707,0);
INSERT INTO "django_geo_db_location" VALUES(38977,NULL,'Callender, IA',15977,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38978,NULL,'Callender, IA 50523',15977,222,NULL,19,22708,0);
INSERT INTO "django_geo_db_location" VALUES(38979,NULL,'Clare, IA',15978,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38980,NULL,'Clare, IA 50524',15978,222,NULL,19,22709,0);
INSERT INTO "django_geo_db_location" VALUES(38981,NULL,'Clarion, IA',15979,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38982,NULL,'Clarion, IA 50525',15979,222,NULL,19,22710,0);
INSERT INTO "django_geo_db_location" VALUES(38983,NULL,'Clarion, IA 50526',15979,222,NULL,19,22711,0);
INSERT INTO "django_geo_db_location" VALUES(38984,NULL,'Curlew, IA',15980,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38985,NULL,'Curlew, IA 50527',15980,222,NULL,19,22712,0);
INSERT INTO "django_geo_db_location" VALUES(38986,NULL,'Cylinder, IA',15981,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38987,NULL,'Cylinder, IA 50528',15981,222,NULL,19,22713,0);
INSERT INTO "django_geo_db_location" VALUES(38988,NULL,'Dakota City, IA',15982,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38989,NULL,'Dakota City, IA 50529',15982,222,NULL,19,22714,0);
INSERT INTO "django_geo_db_location" VALUES(38990,NULL,'Dayton, IA',15983,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38991,NULL,'Dayton, IA 50530',15983,222,NULL,19,22715,0);
INSERT INTO "django_geo_db_location" VALUES(38992,NULL,'Dolliver, IA',15984,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38993,NULL,'Dolliver, IA 50531',15984,222,NULL,19,22716,0);
INSERT INTO "django_geo_db_location" VALUES(38994,NULL,'Duncombe, IA',15985,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38995,NULL,'Duncombe, IA 50532',15985,222,NULL,19,22717,0);
INSERT INTO "django_geo_db_location" VALUES(38996,NULL,'Eagle Grove, IA',15986,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38997,NULL,'Eagle Grove, IA 50533',15986,222,NULL,19,22718,0);
INSERT INTO "django_geo_db_location" VALUES(38998,NULL,'Early, IA',15987,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(38999,NULL,'Early, IA 50535',15987,222,NULL,19,22719,0);
INSERT INTO "django_geo_db_location" VALUES(39000,NULL,'Emmetsburg, IA',15988,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39001,NULL,'Emmetsburg, IA 50536',15988,222,NULL,19,22720,0);
INSERT INTO "django_geo_db_location" VALUES(39002,NULL,'Farnhamville, IA',15989,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39003,NULL,'Farnhamville, IA 50538',15989,222,NULL,19,22721,0);
INSERT INTO "django_geo_db_location" VALUES(39004,NULL,'Fenton, IA',15990,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39005,NULL,'Fenton, IA 50539',15990,222,NULL,19,22722,0);
INSERT INTO "django_geo_db_location" VALUES(39006,NULL,'Fonda, IA',15991,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39007,NULL,'Fonda, IA 50540',15991,222,NULL,19,22723,0);
INSERT INTO "django_geo_db_location" VALUES(39008,NULL,'Gilmore City, IA',15992,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39009,NULL,'Gilmore City, IA 50541',15992,222,NULL,19,22724,0);
INSERT INTO "django_geo_db_location" VALUES(39010,NULL,'Goldfield, IA',15993,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39011,NULL,'Goldfield, IA 50542',15993,222,NULL,19,22725,0);
INSERT INTO "django_geo_db_location" VALUES(39012,NULL,'Gowrie, IA',15994,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39013,NULL,'Gowrie, IA 50543',15994,222,NULL,19,22726,0);
INSERT INTO "django_geo_db_location" VALUES(39014,NULL,'Harcourt, IA',15995,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39015,NULL,'Harcourt, IA 50544',15995,222,NULL,19,22727,0);
INSERT INTO "django_geo_db_location" VALUES(39016,NULL,'Hardy, IA',15996,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39017,NULL,'Hardy, IA 50545',15996,222,NULL,19,22728,0);
INSERT INTO "django_geo_db_location" VALUES(39018,NULL,'Havelock, IA',15997,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39019,NULL,'Havelock, IA 50546',15997,222,NULL,19,22729,0);
INSERT INTO "django_geo_db_location" VALUES(39020,NULL,'Humboldt, IA',15998,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39021,NULL,'Humboldt, IA 50548',15998,222,NULL,19,22730,0);
INSERT INTO "django_geo_db_location" VALUES(39022,NULL,'Jolley, IA',15999,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39023,NULL,'Jolley, IA 50551',15999,222,NULL,19,22731,0);
INSERT INTO "django_geo_db_location" VALUES(39024,NULL,'Knierim, IA',16000,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39025,NULL,'Knierim, IA 50552',16000,222,NULL,19,22732,0);
INSERT INTO "django_geo_db_location" VALUES(39026,NULL,'Laurens, IA',16001,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39027,NULL,'Laurens, IA 50554',16001,222,NULL,19,22733,0);
INSERT INTO "django_geo_db_location" VALUES(39028,NULL,'Ledyard, IA',16002,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39029,NULL,'Ledyard, IA 50556',16002,222,NULL,19,22734,0);
INSERT INTO "django_geo_db_location" VALUES(39030,NULL,'Lehigh, IA',16003,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39031,NULL,'Lehigh, IA 50557',16003,222,NULL,19,22735,0);
INSERT INTO "django_geo_db_location" VALUES(39032,NULL,'Livermore, IA',16004,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39033,NULL,'Livermore, IA 50558',16004,222,NULL,19,22736,0);
INSERT INTO "django_geo_db_location" VALUES(39034,NULL,'Lone Rock, IA',16005,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39035,NULL,'Lone Rock, IA 50559',16005,222,NULL,19,22737,0);
INSERT INTO "django_geo_db_location" VALUES(39036,NULL,'Lu Verne, IA',16006,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39037,NULL,'Lu Verne, IA 50560',16006,222,NULL,19,22738,0);
INSERT INTO "django_geo_db_location" VALUES(39038,NULL,'Lytton, IA',16007,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39039,NULL,'Lytton, IA 50561',16007,222,NULL,19,22739,0);
INSERT INTO "django_geo_db_location" VALUES(39040,NULL,'Mallard, IA',16008,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39041,NULL,'Mallard, IA 50562',16008,222,NULL,19,22740,0);
INSERT INTO "django_geo_db_location" VALUES(39042,NULL,'Manson, IA',16009,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39043,NULL,'Manson, IA 50563',16009,222,NULL,19,22741,0);
INSERT INTO "django_geo_db_location" VALUES(39044,NULL,'Marathon, IA',16010,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39045,NULL,'Marathon, IA 50565',16010,222,NULL,19,22742,0);
INSERT INTO "django_geo_db_location" VALUES(39046,NULL,'Moorland, IA',16011,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39047,NULL,'Moorland, IA 50566',16011,222,NULL,19,22743,0);
INSERT INTO "django_geo_db_location" VALUES(39048,NULL,'Nemaha, IA',16012,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39049,NULL,'Nemaha, IA 50567',16012,222,NULL,19,22744,0);
INSERT INTO "django_geo_db_location" VALUES(39050,NULL,'Newell, IA',16013,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39051,NULL,'Newell, IA 50568',16013,222,NULL,19,22745,0);
INSERT INTO "django_geo_db_location" VALUES(39052,NULL,'Otho, IA',16014,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39053,NULL,'Otho, IA 50569',16014,222,NULL,19,22746,0);
INSERT INTO "django_geo_db_location" VALUES(39054,NULL,'Ottosen, IA',16015,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39055,NULL,'Ottosen, IA 50570',16015,222,NULL,19,22747,0);
INSERT INTO "django_geo_db_location" VALUES(39056,NULL,'Palmer, IA',16016,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39057,NULL,'Palmer, IA 50571',16016,222,NULL,19,22748,0);
INSERT INTO "django_geo_db_location" VALUES(39058,NULL,'Plover, IA',16017,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39059,NULL,'Plover, IA 50573',16017,222,NULL,19,22749,0);
INSERT INTO "django_geo_db_location" VALUES(39060,NULL,'Pocahontas, IA',16018,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39061,NULL,'Pocahontas, IA 50574',16018,222,NULL,19,22750,0);
INSERT INTO "django_geo_db_location" VALUES(39062,NULL,'Pomeroy, IA',16019,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39063,NULL,'Pomeroy, IA 50575',16019,222,NULL,19,22751,0);
INSERT INTO "django_geo_db_location" VALUES(39064,NULL,'Rembrandt, IA',16020,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39065,NULL,'Rembrandt, IA 50576',16020,222,NULL,19,22752,0);
INSERT INTO "django_geo_db_location" VALUES(39066,NULL,'Renwick, IA',16021,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39067,NULL,'Renwick, IA 50577',16021,222,NULL,19,22753,0);
INSERT INTO "django_geo_db_location" VALUES(39068,NULL,'Ringsted, IA',16022,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39069,NULL,'Ringsted, IA 50578',16022,222,NULL,19,22754,0);
INSERT INTO "django_geo_db_location" VALUES(39070,NULL,'Rockwell City, IA',16023,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39071,NULL,'Rockwell City, IA 50579',16023,222,NULL,19,22755,0);
INSERT INTO "django_geo_db_location" VALUES(39072,NULL,'Rolfe, IA',16024,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39073,NULL,'Rolfe, IA 50581',16024,222,NULL,19,22756,0);
INSERT INTO "django_geo_db_location" VALUES(39074,NULL,'Rutland, IA',16025,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39075,NULL,'Rutland, IA 50582',16025,222,NULL,19,22757,0);
INSERT INTO "django_geo_db_location" VALUES(39076,NULL,'Sac City, IA',16026,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39077,NULL,'Sac City, IA 50583',16026,222,NULL,19,22758,0);
INSERT INTO "django_geo_db_location" VALUES(39078,NULL,'Sioux Rapids, IA',16027,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39079,NULL,'Sioux Rapids, IA 50585',16027,222,NULL,19,22759,0);
INSERT INTO "django_geo_db_location" VALUES(39080,NULL,'Somers, IA',16028,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39081,NULL,'Somers, IA 50586',16028,222,NULL,19,22760,0);
INSERT INTO "django_geo_db_location" VALUES(39082,NULL,'Rinard, IA',16029,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39083,NULL,'Rinard, IA 50587',16029,222,NULL,19,22761,0);
INSERT INTO "django_geo_db_location" VALUES(39084,NULL,'Storm Lake, IA',16030,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39085,NULL,'Storm Lake, IA 50588',16030,222,NULL,19,22762,0);
INSERT INTO "django_geo_db_location" VALUES(39086,NULL,'Swea City, IA',16031,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39087,NULL,'Swea City, IA 50590',16031,222,NULL,19,22763,0);
INSERT INTO "django_geo_db_location" VALUES(39088,NULL,'Thor, IA',16032,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39089,NULL,'Thor, IA 50591',16032,222,NULL,19,22764,0);
INSERT INTO "django_geo_db_location" VALUES(39090,NULL,'Truesdale, IA',16033,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39091,NULL,'Truesdale, IA 50592',16033,222,NULL,19,22765,0);
INSERT INTO "django_geo_db_location" VALUES(39092,NULL,'Varina, IA',16034,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39093,NULL,'Varina, IA 50593',16034,222,NULL,19,22766,0);
INSERT INTO "django_geo_db_location" VALUES(39094,NULL,'Vincent, IA',16035,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39095,NULL,'Vincent, IA 50594',16035,222,NULL,19,22767,0);
INSERT INTO "django_geo_db_location" VALUES(39096,NULL,'Webster City, IA',16036,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39097,NULL,'Webster City, IA 50595',16036,222,NULL,19,22768,0);
INSERT INTO "django_geo_db_location" VALUES(39098,NULL,'West Bend, IA',16037,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39099,NULL,'West Bend, IA 50597',16037,222,NULL,19,22769,0);
INSERT INTO "django_geo_db_location" VALUES(39100,NULL,'Whittemore, IA',16038,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39101,NULL,'Whittemore, IA 50598',16038,222,NULL,19,22770,0);
INSERT INTO "django_geo_db_location" VALUES(39102,NULL,'Woolstock, IA',16039,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39103,NULL,'Woolstock, IA 50599',16039,222,NULL,19,22771,0);
INSERT INTO "django_geo_db_location" VALUES(39104,NULL,'Ackley, IA',16040,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39105,NULL,'Ackley, IA 50601',16040,222,NULL,19,22772,0);
INSERT INTO "django_geo_db_location" VALUES(39106,NULL,'Allison, IA',16041,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39107,NULL,'Allison, IA 50602',16041,222,NULL,19,22773,0);
INSERT INTO "django_geo_db_location" VALUES(39108,NULL,'Alta Vista, IA',16042,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39109,NULL,'Alta Vista, IA 50603',16042,222,NULL,19,22774,0);
INSERT INTO "django_geo_db_location" VALUES(39110,NULL,'Aplington, IA',16043,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39111,NULL,'Aplington, IA 50604',16043,222,NULL,19,22775,0);
INSERT INTO "django_geo_db_location" VALUES(39112,NULL,'Aredale, IA',16044,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39113,NULL,'Aredale, IA 50605',16044,222,NULL,19,22776,0);
INSERT INTO "django_geo_db_location" VALUES(39114,NULL,'Arlington, IA',16045,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39115,NULL,'Arlington, IA 50606',16045,222,NULL,19,22777,0);
INSERT INTO "django_geo_db_location" VALUES(39116,NULL,'Aurora, IA',16046,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39117,NULL,'Aurora, IA 50607',16046,222,NULL,19,22778,0);
INSERT INTO "django_geo_db_location" VALUES(39118,NULL,'Austinville, IA',16047,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39119,NULL,'Austinville, IA 50608',16047,222,NULL,19,22779,0);
INSERT INTO "django_geo_db_location" VALUES(39120,NULL,'Beaman, IA',16048,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39121,NULL,'Beaman, IA 50609',16048,222,NULL,19,22780,0);
INSERT INTO "django_geo_db_location" VALUES(39122,NULL,'Bristow, IA',16049,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39123,NULL,'Bristow, IA 50611',16049,222,NULL,19,22781,0);
INSERT INTO "django_geo_db_location" VALUES(39124,NULL,'Buckingham, IA',16050,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39125,NULL,'Buckingham, IA 50612',16050,222,NULL,19,22782,0);
INSERT INTO "django_geo_db_location" VALUES(39126,NULL,'Cedar Falls, IA',16051,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39127,NULL,'Cedar Falls, IA 50613',16051,222,NULL,19,22783,0);
INSERT INTO "django_geo_db_location" VALUES(39128,NULL,'Cedar Falls, IA 50614',16051,222,NULL,19,22784,0);
INSERT INTO "django_geo_db_location" VALUES(39129,NULL,'Charles City, IA',16052,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39130,NULL,'Charles City, IA 50616',16052,222,NULL,19,22785,0);
INSERT INTO "django_geo_db_location" VALUES(39131,NULL,'Clarksville, IA',16053,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39132,NULL,'Clarksville, IA 50619',16053,222,NULL,19,22786,0);
INSERT INTO "django_geo_db_location" VALUES(39133,NULL,'Colwell, IA',16054,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39134,NULL,'Colwell, IA 50620',16054,222,NULL,19,22787,0);
INSERT INTO "django_geo_db_location" VALUES(39135,NULL,'Conrad, IA',16055,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39136,NULL,'Conrad, IA 50621',16055,222,NULL,19,22788,0);
INSERT INTO "django_geo_db_location" VALUES(39137,NULL,'Denver, IA',16056,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39138,NULL,'Denver, IA 50622',16056,222,NULL,19,22789,0);
INSERT INTO "django_geo_db_location" VALUES(39139,NULL,'Dewar, IA',16057,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39140,NULL,'Dewar, IA 50623',16057,222,NULL,19,22790,0);
INSERT INTO "django_geo_db_location" VALUES(39141,NULL,'Dike, IA',16058,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39142,NULL,'Dike, IA 50624',16058,222,NULL,19,22791,0);
INSERT INTO "django_geo_db_location" VALUES(39143,NULL,'Dumont, IA',16059,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39144,NULL,'Dumont, IA 50625',16059,222,NULL,19,22792,0);
INSERT INTO "django_geo_db_location" VALUES(39145,NULL,'Dunkerton, IA',16060,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39146,NULL,'Dunkerton, IA 50626',16060,222,NULL,19,22793,0);
INSERT INTO "django_geo_db_location" VALUES(39147,NULL,'Eldora, IA',16061,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39148,NULL,'Eldora, IA 50627',16061,222,NULL,19,22794,0);
INSERT INTO "django_geo_db_location" VALUES(39149,NULL,'Elma, IA',16062,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39150,NULL,'Elma, IA 50628',16062,222,NULL,19,22795,0);
INSERT INTO "django_geo_db_location" VALUES(39151,NULL,'Fairbank, IA',16063,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39152,NULL,'Fairbank, IA 50629',16063,222,NULL,19,22796,0);
INSERT INTO "django_geo_db_location" VALUES(39153,NULL,'Fredericksburg, IA',16064,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39154,NULL,'Fredericksburg, IA 50630',16064,222,NULL,19,22797,0);
INSERT INTO "django_geo_db_location" VALUES(39155,NULL,'Frederika, IA',16065,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39156,NULL,'Frederika, IA 50631',16065,222,NULL,19,22798,0);
INSERT INTO "django_geo_db_location" VALUES(39157,NULL,'Garwin, IA',16066,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39158,NULL,'Garwin, IA 50632',16066,222,NULL,19,22799,0);
INSERT INTO "django_geo_db_location" VALUES(39159,NULL,'Geneva, IA',16067,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39160,NULL,'Geneva, IA 50633',16067,222,NULL,19,22800,0);
INSERT INTO "django_geo_db_location" VALUES(39161,NULL,'Gilbertville, IA',16068,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39162,NULL,'Gilbertville, IA 50634',16068,222,NULL,19,22801,0);
INSERT INTO "django_geo_db_location" VALUES(39163,NULL,'Gladbrook, IA',16069,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39164,NULL,'Gladbrook, IA 50635',16069,222,NULL,19,22802,0);
INSERT INTO "django_geo_db_location" VALUES(39165,NULL,'Greene, IA',16070,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39166,NULL,'Greene, IA 50636',16070,222,NULL,19,22803,0);
INSERT INTO "django_geo_db_location" VALUES(39167,NULL,'Grundy Center, IA',16071,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39168,NULL,'Grundy Center, IA 50638',16071,222,NULL,19,22804,0);
INSERT INTO "django_geo_db_location" VALUES(39169,NULL,'Hazleton, IA',16072,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39170,NULL,'Hazleton, IA 50641',16072,222,NULL,19,22805,0);
INSERT INTO "django_geo_db_location" VALUES(39171,NULL,'Holland, IA',16073,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39172,NULL,'Holland, IA 50642',16073,222,NULL,19,22806,0);
INSERT INTO "django_geo_db_location" VALUES(39173,NULL,'Hudson, IA',16074,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39174,NULL,'Hudson, IA 50643',16074,222,NULL,19,22807,0);
INSERT INTO "django_geo_db_location" VALUES(39175,NULL,'Independence, IA',16075,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39176,NULL,'Independence, IA 50644',16075,222,NULL,19,22808,0);
INSERT INTO "django_geo_db_location" VALUES(39177,NULL,'Ionia, IA',16076,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39178,NULL,'Ionia, IA 50645',16076,222,NULL,19,22809,0);
INSERT INTO "django_geo_db_location" VALUES(39179,NULL,'Janesville, IA',16077,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39180,NULL,'Janesville, IA 50647',16077,222,NULL,19,22810,0);
INSERT INTO "django_geo_db_location" VALUES(39181,NULL,'Jesup, IA',16078,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39182,NULL,'Jesup, IA 50648',16078,222,NULL,19,22811,0);
INSERT INTO "django_geo_db_location" VALUES(39183,NULL,'Kesley, IA',16079,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39184,NULL,'Kesley, IA 50649',16079,222,NULL,19,22812,0);
INSERT INTO "django_geo_db_location" VALUES(39185,NULL,'Lamont, IA',16080,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39186,NULL,'Lamont, IA 50650',16080,222,NULL,19,22813,0);
INSERT INTO "django_geo_db_location" VALUES(39187,NULL,'La Porte City, IA',16081,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39188,NULL,'La Porte City, IA 50651',16081,222,NULL,19,22814,0);
INSERT INTO "django_geo_db_location" VALUES(39189,NULL,'Lincoln, IA',16082,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39190,NULL,'Lincoln, IA 50652',16082,222,NULL,19,22815,0);
INSERT INTO "django_geo_db_location" VALUES(39191,NULL,'Marble Rock, IA',16083,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39192,NULL,'Marble Rock, IA 50653',16083,222,NULL,19,22816,0);
INSERT INTO "django_geo_db_location" VALUES(39193,NULL,'Masonville, IA',16084,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39194,NULL,'Masonville, IA 50654',16084,222,NULL,19,22817,0);
INSERT INTO "django_geo_db_location" VALUES(39195,NULL,'Maynard, IA',16085,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39196,NULL,'Maynard, IA 50655',16085,222,NULL,19,22818,0);
INSERT INTO "django_geo_db_location" VALUES(39197,NULL,'Morrison, IA',16086,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39198,NULL,'Morrison, IA 50657',16086,222,NULL,19,22819,0);
INSERT INTO "django_geo_db_location" VALUES(39199,NULL,'Nashua, IA',16087,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39200,NULL,'Nashua, IA 50658',16087,222,NULL,19,22820,0);
INSERT INTO "django_geo_db_location" VALUES(39201,NULL,'New Hampton, IA',16088,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39202,NULL,'New Hampton, IA 50659',16088,222,NULL,19,22821,0);
INSERT INTO "django_geo_db_location" VALUES(39203,NULL,'New Hartford, IA',16089,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39204,NULL,'New Hartford, IA 50660',16089,222,NULL,19,22822,0);
INSERT INTO "django_geo_db_location" VALUES(39205,NULL,'North Washington, IA',16090,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39206,NULL,'North Washington, IA 50661',16090,222,NULL,19,22823,0);
INSERT INTO "django_geo_db_location" VALUES(39207,NULL,'Oelwein, IA',16091,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39208,NULL,'Oelwein, IA 50662',16091,222,NULL,19,22824,0);
INSERT INTO "django_geo_db_location" VALUES(39209,NULL,'Oran, IA',16092,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39210,NULL,'Oran, IA 50664',16092,222,NULL,19,22825,0);
INSERT INTO "django_geo_db_location" VALUES(39211,NULL,'Parkersburg, IA',16093,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39212,NULL,'Parkersburg, IA 50665',16093,222,NULL,19,22826,0);
INSERT INTO "django_geo_db_location" VALUES(39213,NULL,'Plainfield, IA',16094,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39214,NULL,'Plainfield, IA 50666',16094,222,NULL,19,22827,0);
INSERT INTO "django_geo_db_location" VALUES(39215,NULL,'Raymond, IA',16095,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39216,NULL,'Raymond, IA 50667',16095,222,NULL,19,22828,0);
INSERT INTO "django_geo_db_location" VALUES(39217,NULL,'Readlyn, IA',16096,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39218,NULL,'Readlyn, IA 50668',16096,222,NULL,19,22829,0);
INSERT INTO "django_geo_db_location" VALUES(39219,NULL,'Reinbeck, IA',16097,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39220,NULL,'Reinbeck, IA 50669',16097,222,NULL,19,22830,0);
INSERT INTO "django_geo_db_location" VALUES(39221,NULL,'Shell Rock, IA',16098,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39222,NULL,'Shell Rock, IA 50670',16098,222,NULL,19,22831,0);
INSERT INTO "django_geo_db_location" VALUES(39223,NULL,'Stanley, IA',16099,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39224,NULL,'Stanley, IA 50671',16099,222,NULL,19,22832,0);
INSERT INTO "django_geo_db_location" VALUES(39225,NULL,'Steamboat Rock, IA',16100,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39226,NULL,'Steamboat Rock, IA 50672',16100,222,NULL,19,22833,0);
INSERT INTO "django_geo_db_location" VALUES(39227,NULL,'Stout, IA',16101,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39228,NULL,'Stout, IA 50673',16101,222,NULL,19,22834,0);
INSERT INTO "django_geo_db_location" VALUES(39229,NULL,'Sumner, IA',16102,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39230,NULL,'Sumner, IA 50674',16102,222,NULL,19,22835,0);
INSERT INTO "django_geo_db_location" VALUES(39231,NULL,'Traer, IA',16103,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39232,NULL,'Traer, IA 50675',16103,222,NULL,19,22836,0);
INSERT INTO "django_geo_db_location" VALUES(39233,NULL,'Tripoli, IA',16104,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39234,NULL,'Tripoli, IA 50676',16104,222,NULL,19,22837,0);
INSERT INTO "django_geo_db_location" VALUES(39235,NULL,'Waverly, IA',16105,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39236,NULL,'Waverly, IA 50677',16105,222,NULL,19,22838,0);
INSERT INTO "django_geo_db_location" VALUES(39237,NULL,'Wellsburg, IA',16106,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39238,NULL,'Wellsburg, IA 50680',16106,222,NULL,19,22839,0);
INSERT INTO "django_geo_db_location" VALUES(39239,NULL,'Westgate, IA',16107,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39240,NULL,'Westgate, IA 50681',16107,222,NULL,19,22840,0);
INSERT INTO "django_geo_db_location" VALUES(39241,NULL,'Winthrop, IA',16108,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39242,NULL,'Winthrop, IA 50682',16108,222,NULL,19,22841,0);
INSERT INTO "django_geo_db_location" VALUES(39243,NULL,'Waterloo, IA',16109,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39244,NULL,'Waterloo, IA 50701',16109,222,NULL,19,22842,0);
INSERT INTO "django_geo_db_location" VALUES(39245,NULL,'Waterloo, IA 50702',16109,222,NULL,19,22843,0);
INSERT INTO "django_geo_db_location" VALUES(39246,NULL,'Waterloo, IA 50703',16109,222,NULL,19,22844,0);
INSERT INTO "django_geo_db_location" VALUES(39247,NULL,'Waterloo, IA 50704',16109,222,NULL,19,22845,0);
INSERT INTO "django_geo_db_location" VALUES(39248,NULL,'Waterloo, IA 50706',16109,222,NULL,19,22846,0);
INSERT INTO "django_geo_db_location" VALUES(39249,NULL,'Evansdale, IA',16110,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39250,NULL,'Evansdale, IA 50707',16110,222,NULL,19,22847,0);
INSERT INTO "django_geo_db_location" VALUES(39251,NULL,'Waterloo, IA 50799',16109,222,NULL,19,22848,0);
INSERT INTO "django_geo_db_location" VALUES(39252,NULL,'Creston, IA',16111,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39253,NULL,'Creston, IA 50801',16111,222,NULL,19,22849,0);
INSERT INTO "django_geo_db_location" VALUES(39254,NULL,'Afton, IA',16112,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39255,NULL,'Afton, IA 50830',16112,222,NULL,19,22850,0);
INSERT INTO "django_geo_db_location" VALUES(39256,NULL,'Arispe, IA',16113,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39257,NULL,'Arispe, IA 50831',16113,222,NULL,19,22851,0);
INSERT INTO "django_geo_db_location" VALUES(39258,NULL,'Bedford, IA',16114,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39259,NULL,'Bedford, IA 50833',16114,222,NULL,19,22852,0);
INSERT INTO "django_geo_db_location" VALUES(39260,NULL,'Benton, IA',16115,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39261,NULL,'Benton, IA 50835',16115,222,NULL,19,22853,0);
INSERT INTO "django_geo_db_location" VALUES(39262,NULL,'Blockton, IA',16116,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39263,NULL,'Blockton, IA 50836',16116,222,NULL,19,22854,0);
INSERT INTO "django_geo_db_location" VALUES(39264,NULL,'Bridgewater, IA',16117,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39265,NULL,'Bridgewater, IA 50837',16117,222,NULL,19,22855,0);
INSERT INTO "django_geo_db_location" VALUES(39266,NULL,'Carbon, IA',16118,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39267,NULL,'Carbon, IA 50839',16118,222,NULL,19,22856,0);
INSERT INTO "django_geo_db_location" VALUES(39268,NULL,'Clearfield, IA',16119,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39269,NULL,'Clearfield, IA 50840',16119,222,NULL,19,22857,0);
INSERT INTO "django_geo_db_location" VALUES(39270,NULL,'Corning, IA',16120,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39271,NULL,'Corning, IA 50841',16120,222,NULL,19,22858,0);
INSERT INTO "django_geo_db_location" VALUES(39272,NULL,'Cromwell, IA',16121,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39273,NULL,'Cromwell, IA 50842',16121,222,NULL,19,22859,0);
INSERT INTO "django_geo_db_location" VALUES(39274,NULL,'Cumberland, IA',16122,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39275,NULL,'Cumberland, IA 50843',16122,222,NULL,19,22860,0);
INSERT INTO "django_geo_db_location" VALUES(39276,NULL,'Diagonal, IA',16123,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39277,NULL,'Diagonal, IA 50845',16123,222,NULL,19,22861,0);
INSERT INTO "django_geo_db_location" VALUES(39278,NULL,'Fontanelle, IA',16124,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39279,NULL,'Fontanelle, IA 50846',16124,222,NULL,19,22862,0);
INSERT INTO "django_geo_db_location" VALUES(39280,NULL,'Grant, IA',16125,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39281,NULL,'Grant, IA 50847',16125,222,NULL,19,22863,0);
INSERT INTO "django_geo_db_location" VALUES(39282,NULL,'Gravity, IA',16126,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39283,NULL,'Gravity, IA 50848',16126,222,NULL,19,22864,0);
INSERT INTO "django_geo_db_location" VALUES(39284,NULL,'Greenfield, IA',16127,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39285,NULL,'Greenfield, IA 50849',16127,222,NULL,19,22865,0);
INSERT INTO "django_geo_db_location" VALUES(39286,NULL,'Lenox, IA',16128,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39287,NULL,'Lenox, IA 50851',16128,222,NULL,19,22866,0);
INSERT INTO "django_geo_db_location" VALUES(39288,NULL,'Massena, IA',16129,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39289,NULL,'Massena, IA 50853',16129,222,NULL,19,22867,0);
INSERT INTO "django_geo_db_location" VALUES(39290,NULL,'Mount Ayr, IA',16130,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39291,NULL,'Mount Ayr, IA 50854',16130,222,NULL,19,22868,0);
INSERT INTO "django_geo_db_location" VALUES(39292,NULL,'Nodaway, IA',16131,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39293,NULL,'Nodaway, IA 50857',16131,222,NULL,19,22869,0);
INSERT INTO "django_geo_db_location" VALUES(39294,NULL,'Orient, IA',16132,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39295,NULL,'Orient, IA 50858',16132,222,NULL,19,22870,0);
INSERT INTO "django_geo_db_location" VALUES(39296,NULL,'Prescott, IA',16133,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39297,NULL,'Prescott, IA 50859',16133,222,NULL,19,22871,0);
INSERT INTO "django_geo_db_location" VALUES(39298,NULL,'Redding, IA',16134,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39299,NULL,'Redding, IA 50860',16134,222,NULL,19,22872,0);
INSERT INTO "django_geo_db_location" VALUES(39300,NULL,'Shannon City, IA',16135,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39301,NULL,'Shannon City, IA 50861',16135,222,NULL,19,22873,0);
INSERT INTO "django_geo_db_location" VALUES(39302,NULL,'Sharpsburg, IA',16136,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39303,NULL,'Sharpsburg, IA 50862',16136,222,NULL,19,22874,0);
INSERT INTO "django_geo_db_location" VALUES(39304,NULL,'Tingley, IA',16137,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39305,NULL,'Tingley, IA 50863',16137,222,NULL,19,22875,0);
INSERT INTO "django_geo_db_location" VALUES(39306,NULL,'Villisca, IA',16138,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39307,NULL,'Villisca, IA 50864',16138,222,NULL,19,22876,0);
INSERT INTO "django_geo_db_location" VALUES(39308,NULL,'Des Moines, IA 50936',15905,222,NULL,19,22877,0);
INSERT INTO "django_geo_db_location" VALUES(39309,NULL,'Des Moines, IA 50940',15905,222,NULL,19,22878,0);
INSERT INTO "django_geo_db_location" VALUES(39310,NULL,'Des Moines, IA 50947',15905,222,NULL,19,22879,0);
INSERT INTO "django_geo_db_location" VALUES(39311,NULL,'Des Moines, IA 50950',15905,222,NULL,19,22880,0);
INSERT INTO "django_geo_db_location" VALUES(39312,NULL,'Des Moines, IA 50980',15905,222,NULL,19,22881,0);
INSERT INTO "django_geo_db_location" VALUES(39313,NULL,'Des Moines, IA 50981',15905,222,NULL,19,22882,0);
INSERT INTO "django_geo_db_location" VALUES(39314,NULL,'Akron, IA',16139,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39315,NULL,'Akron, IA 51001',16139,222,NULL,19,22883,0);
INSERT INTO "django_geo_db_location" VALUES(39316,NULL,'Alta, IA',16140,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39317,NULL,'Alta, IA 51002',16140,222,NULL,19,22884,0);
INSERT INTO "django_geo_db_location" VALUES(39318,NULL,'Alton, IA',16141,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39319,NULL,'Alton, IA 51003',16141,222,NULL,19,22885,0);
INSERT INTO "django_geo_db_location" VALUES(39320,NULL,'Anthon, IA',16142,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39321,NULL,'Anthon, IA 51004',16142,222,NULL,19,22886,0);
INSERT INTO "django_geo_db_location" VALUES(39322,NULL,'Aurelia, IA',16143,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39323,NULL,'Aurelia, IA 51005',16143,222,NULL,19,22887,0);
INSERT INTO "django_geo_db_location" VALUES(39324,NULL,'Battle Creek, IA',16144,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39325,NULL,'Battle Creek, IA 51006',16144,222,NULL,19,22888,0);
INSERT INTO "django_geo_db_location" VALUES(39326,NULL,'Bronson, IA',16145,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39327,NULL,'Bronson, IA 51007',16145,222,NULL,19,22889,0);
INSERT INTO "django_geo_db_location" VALUES(39328,NULL,'Brunsville, IA',16146,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39329,NULL,'Brunsville, IA 51008',16146,222,NULL,19,22890,0);
INSERT INTO "django_geo_db_location" VALUES(39330,NULL,'Calumet, IA',16147,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39331,NULL,'Calumet, IA 51009',16147,222,NULL,19,22891,0);
INSERT INTO "django_geo_db_location" VALUES(39332,NULL,'Castana, IA',16148,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39333,NULL,'Castana, IA 51010',16148,222,NULL,19,22892,0);
INSERT INTO "django_geo_db_location" VALUES(39334,NULL,'Chatsworth, IA',16149,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39335,NULL,'Chatsworth, IA 51011',16149,222,NULL,19,22893,0);
INSERT INTO "django_geo_db_location" VALUES(39336,NULL,'Cherokee, IA',16150,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39337,NULL,'Cherokee, IA 51012',16150,222,NULL,19,22894,0);
INSERT INTO "django_geo_db_location" VALUES(39338,NULL,'Cleghorn, IA',16151,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39339,NULL,'Cleghorn, IA 51014',16151,222,NULL,19,22895,0);
INSERT INTO "django_geo_db_location" VALUES(39340,NULL,'Climbing Hill, IA',16152,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39341,NULL,'Climbing Hill, IA 51015',16152,222,NULL,19,22896,0);
INSERT INTO "django_geo_db_location" VALUES(39342,NULL,'Correctionville, IA',16153,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39343,NULL,'Correctionville, IA 51016',16153,222,NULL,19,22897,0);
INSERT INTO "django_geo_db_location" VALUES(39344,NULL,'Craig, IA',16154,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39345,NULL,'Craig, IA 51017',16154,222,NULL,19,22898,0);
INSERT INTO "django_geo_db_location" VALUES(39346,NULL,'Cushing, IA',16155,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39347,NULL,'Cushing, IA 51018',16155,222,NULL,19,22899,0);
INSERT INTO "django_geo_db_location" VALUES(39348,NULL,'Danbury, IA',16156,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39349,NULL,'Danbury, IA 51019',16156,222,NULL,19,22900,0);
INSERT INTO "django_geo_db_location" VALUES(39350,NULL,'Galva, IA',16157,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39351,NULL,'Galva, IA 51020',16157,222,NULL,19,22901,0);
INSERT INTO "django_geo_db_location" VALUES(39352,NULL,'Granville, IA',16158,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39353,NULL,'Granville, IA 51022',16158,222,NULL,19,22902,0);
INSERT INTO "django_geo_db_location" VALUES(39354,NULL,'Hawarden, IA',16159,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39355,NULL,'Hawarden, IA 51023',16159,222,NULL,19,22903,0);
INSERT INTO "django_geo_db_location" VALUES(39356,NULL,'Hinton, IA',16160,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39357,NULL,'Hinton, IA 51024',16160,222,NULL,19,22904,0);
INSERT INTO "django_geo_db_location" VALUES(39358,NULL,'Holstein, IA',16161,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39359,NULL,'Holstein, IA 51025',16161,222,NULL,19,22905,0);
INSERT INTO "django_geo_db_location" VALUES(39360,NULL,'Hornick, IA',16162,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39361,NULL,'Hornick, IA 51026',16162,222,NULL,19,22906,0);
INSERT INTO "django_geo_db_location" VALUES(39362,NULL,'Ireton, IA',16163,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39363,NULL,'Ireton, IA 51027',16163,222,NULL,19,22907,0);
INSERT INTO "django_geo_db_location" VALUES(39364,NULL,'Kingsley, IA',16164,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39365,NULL,'Kingsley, IA 51028',16164,222,NULL,19,22908,0);
INSERT INTO "django_geo_db_location" VALUES(39366,NULL,'Larrabee, IA',16165,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39367,NULL,'Larrabee, IA 51029',16165,222,NULL,19,22909,0);
INSERT INTO "django_geo_db_location" VALUES(39368,NULL,'Lawton, IA',16166,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39369,NULL,'Lawton, IA 51030',16166,222,NULL,19,22910,0);
INSERT INTO "django_geo_db_location" VALUES(39370,NULL,'Le Mars, IA',16167,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39371,NULL,'Le Mars, IA 51031',16167,222,NULL,19,22911,0);
INSERT INTO "django_geo_db_location" VALUES(39372,NULL,'Linn Grove, IA',16168,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39373,NULL,'Linn Grove, IA 51033',16168,222,NULL,19,22912,0);
INSERT INTO "django_geo_db_location" VALUES(39374,NULL,'Mapleton, IA',16169,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39375,NULL,'Mapleton, IA 51034',16169,222,NULL,19,22913,0);
INSERT INTO "django_geo_db_location" VALUES(39376,NULL,'Marcus, IA',16170,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39377,NULL,'Marcus, IA 51035',16170,222,NULL,19,22914,0);
INSERT INTO "django_geo_db_location" VALUES(39378,NULL,'Maurice, IA',16171,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39379,NULL,'Maurice, IA 51036',16171,222,NULL,19,22915,0);
INSERT INTO "django_geo_db_location" VALUES(39380,NULL,'Meriden, IA',16172,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39381,NULL,'Meriden, IA 51037',16172,222,NULL,19,22916,0);
INSERT INTO "django_geo_db_location" VALUES(39382,NULL,'Merrill, IA',16173,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39383,NULL,'Merrill, IA 51038',16173,222,NULL,19,22917,0);
INSERT INTO "django_geo_db_location" VALUES(39384,NULL,'Moville, IA',16174,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39385,NULL,'Moville, IA 51039',16174,222,NULL,19,22918,0);
INSERT INTO "django_geo_db_location" VALUES(39386,NULL,'Onawa, IA',16175,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39387,NULL,'Onawa, IA 51040',16175,222,NULL,19,22919,0);
INSERT INTO "django_geo_db_location" VALUES(39388,NULL,'Orange City, IA',16176,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39389,NULL,'Orange City, IA 51041',16176,222,NULL,19,22920,0);
INSERT INTO "django_geo_db_location" VALUES(39390,NULL,'Oto, IA',16177,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39391,NULL,'Oto, IA 51044',16177,222,NULL,19,22921,0);
INSERT INTO "django_geo_db_location" VALUES(39392,NULL,'Oyens, IA',16178,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39393,NULL,'Oyens, IA 51045',16178,222,NULL,19,22922,0);
INSERT INTO "django_geo_db_location" VALUES(39394,NULL,'Paullina, IA',16179,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39395,NULL,'Paullina, IA 51046',16179,222,NULL,19,22923,0);
INSERT INTO "django_geo_db_location" VALUES(39396,NULL,'Peterson, IA',16180,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39397,NULL,'Peterson, IA 51047',16180,222,NULL,19,22924,0);
INSERT INTO "django_geo_db_location" VALUES(39398,NULL,'Pierson, IA',16181,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39399,NULL,'Pierson, IA 51048',16181,222,NULL,19,22925,0);
INSERT INTO "django_geo_db_location" VALUES(39400,NULL,'Quimby, IA',16182,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39401,NULL,'Quimby, IA 51049',16182,222,NULL,19,22926,0);
INSERT INTO "django_geo_db_location" VALUES(39402,NULL,'Remsen, IA',16183,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39403,NULL,'Remsen, IA 51050',16183,222,NULL,19,22927,0);
INSERT INTO "django_geo_db_location" VALUES(39404,NULL,'Rodney, IA',16184,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39405,NULL,'Rodney, IA 51051',16184,222,NULL,19,22928,0);
INSERT INTO "django_geo_db_location" VALUES(39406,NULL,'Salix, IA',16185,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39407,NULL,'Salix, IA 51052',16185,222,NULL,19,22929,0);
INSERT INTO "django_geo_db_location" VALUES(39408,NULL,'Schaller, IA',16186,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39409,NULL,'Schaller, IA 51053',16186,222,NULL,19,22930,0);
INSERT INTO "django_geo_db_location" VALUES(39410,NULL,'Sergeant Bluff, IA',16187,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39411,NULL,'Sergeant Bluff, IA 51054',16187,222,NULL,19,22931,0);
INSERT INTO "django_geo_db_location" VALUES(39412,NULL,'Sloan, IA',16188,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39413,NULL,'Sloan, IA 51055',16188,222,NULL,19,22932,0);
INSERT INTO "django_geo_db_location" VALUES(39414,NULL,'Smithland, IA',16189,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39415,NULL,'Smithland, IA 51056',16189,222,NULL,19,22933,0);
INSERT INTO "django_geo_db_location" VALUES(39416,NULL,'Struble, IA',16190,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39417,NULL,'Struble, IA 51057',16190,222,NULL,19,22934,0);
INSERT INTO "django_geo_db_location" VALUES(39418,NULL,'Sutherland, IA',16191,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39419,NULL,'Sutherland, IA 51058',16191,222,NULL,19,22935,0);
INSERT INTO "django_geo_db_location" VALUES(39420,NULL,'Turin, IA',16192,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39421,NULL,'Turin, IA 51059',16192,222,NULL,19,22936,0);
INSERT INTO "django_geo_db_location" VALUES(39422,NULL,'Ute, IA',16193,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39423,NULL,'Ute, IA 51060',16193,222,NULL,19,22937,0);
INSERT INTO "django_geo_db_location" VALUES(39424,NULL,'Washta, IA',16194,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39425,NULL,'Washta, IA 51061',16194,222,NULL,19,22938,0);
INSERT INTO "django_geo_db_location" VALUES(39426,NULL,'Westfield, IA',16195,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39427,NULL,'Westfield, IA 51062',16195,222,NULL,19,22939,0);
INSERT INTO "django_geo_db_location" VALUES(39428,NULL,'Whiting, IA',16196,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39429,NULL,'Whiting, IA 51063',16196,222,NULL,19,22940,0);
INSERT INTO "django_geo_db_location" VALUES(39430,NULL,'Sioux City, IA',16197,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39431,NULL,'Sioux City, IA 51101',16197,222,NULL,19,22941,0);
INSERT INTO "django_geo_db_location" VALUES(39432,NULL,'Sioux City, IA 51102',16197,222,NULL,19,22942,0);
INSERT INTO "django_geo_db_location" VALUES(39433,NULL,'Sioux City, IA 51103',16197,222,NULL,19,22943,0);
INSERT INTO "django_geo_db_location" VALUES(39434,NULL,'Sioux City, IA 51104',16197,222,NULL,19,22944,0);
INSERT INTO "django_geo_db_location" VALUES(39435,NULL,'Sioux City, IA 51105',16197,222,NULL,19,22945,0);
INSERT INTO "django_geo_db_location" VALUES(39436,NULL,'Sioux City, IA 51106',16197,222,NULL,19,22946,0);
INSERT INTO "django_geo_db_location" VALUES(39437,NULL,'Bronson, IA 51107',16145,222,NULL,19,22947,0);
INSERT INTO "django_geo_db_location" VALUES(39438,NULL,'Sioux City, IA 51108',16197,222,NULL,19,22948,0);
INSERT INTO "django_geo_db_location" VALUES(39439,NULL,'Sioux City, IA 51109',16197,222,NULL,19,22949,0);
INSERT INTO "django_geo_db_location" VALUES(39440,NULL,'Sioux City, IA 51111',16197,222,NULL,19,22950,0);
INSERT INTO "django_geo_db_location" VALUES(39441,NULL,'Sheldon, IA',16198,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39442,NULL,'Sheldon, IA 51201',16198,222,NULL,19,22951,0);
INSERT INTO "django_geo_db_location" VALUES(39443,NULL,'Alvord, IA',16199,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39444,NULL,'Alvord, IA 51230',16199,222,NULL,19,22952,0);
INSERT INTO "django_geo_db_location" VALUES(39445,NULL,'Archer, IA',16200,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39446,NULL,'Archer, IA 51231',16200,222,NULL,19,22953,0);
INSERT INTO "django_geo_db_location" VALUES(39447,NULL,'Ashton, IA',16201,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39448,NULL,'Ashton, IA 51232',16201,222,NULL,19,22954,0);
INSERT INTO "django_geo_db_location" VALUES(39449,NULL,'Boyden, IA',16202,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39450,NULL,'Boyden, IA 51234',16202,222,NULL,19,22955,0);
INSERT INTO "django_geo_db_location" VALUES(39451,NULL,'Doon, IA',16203,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39452,NULL,'Doon, IA 51235',16203,222,NULL,19,22956,0);
INSERT INTO "django_geo_db_location" VALUES(39453,NULL,'George, IA',16204,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39454,NULL,'George, IA 51237',16204,222,NULL,19,22957,0);
INSERT INTO "django_geo_db_location" VALUES(39455,NULL,'Hospers, IA',16205,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39456,NULL,'Hospers, IA 51238',16205,222,NULL,19,22958,0);
INSERT INTO "django_geo_db_location" VALUES(39457,NULL,'Hull, IA',16206,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39458,NULL,'Hull, IA 51239',16206,222,NULL,19,22959,0);
INSERT INTO "django_geo_db_location" VALUES(39459,NULL,'Inwood, IA',16207,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39460,NULL,'Inwood, IA 51240',16207,222,NULL,19,22960,0);
INSERT INTO "django_geo_db_location" VALUES(39461,NULL,'Larchwood, IA',16208,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39462,NULL,'Larchwood, IA 51241',16208,222,NULL,19,22961,0);
INSERT INTO "django_geo_db_location" VALUES(39463,NULL,'Lester, IA',16209,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39464,NULL,'Lester, IA 51242',16209,222,NULL,19,22962,0);
INSERT INTO "django_geo_db_location" VALUES(39465,NULL,'Little Rock, IA',16210,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39466,NULL,'Little Rock, IA 51243',16210,222,NULL,19,22963,0);
INSERT INTO "django_geo_db_location" VALUES(39467,NULL,'Matlock, IA',16211,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39468,NULL,'Matlock, IA 51244',16211,222,NULL,19,22964,0);
INSERT INTO "django_geo_db_location" VALUES(39469,NULL,'Primghar, IA',16212,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39470,NULL,'Primghar, IA 51245',16212,222,NULL,19,22965,0);
INSERT INTO "django_geo_db_location" VALUES(39471,NULL,'Rock Rapids, IA',16213,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39472,NULL,'Rock Rapids, IA 51246',16213,222,NULL,19,22966,0);
INSERT INTO "django_geo_db_location" VALUES(39473,NULL,'Rock Valley, IA',16214,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39474,NULL,'Rock Valley, IA 51247',16214,222,NULL,19,22967,0);
INSERT INTO "django_geo_db_location" VALUES(39475,NULL,'Sanborn, IA',16215,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39476,NULL,'Sanborn, IA 51248',16215,222,NULL,19,22968,0);
INSERT INTO "django_geo_db_location" VALUES(39477,NULL,'Sibley, IA',16216,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39478,NULL,'Sibley, IA 51249',16216,222,NULL,19,22969,0);
INSERT INTO "django_geo_db_location" VALUES(39479,NULL,'Sioux Center, IA',16217,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39480,NULL,'Sioux Center, IA 51250',16217,222,NULL,19,22970,0);
INSERT INTO "django_geo_db_location" VALUES(39481,NULL,'Spencer, IA',16218,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39482,NULL,'Spencer, IA 51301',16218,222,NULL,19,22971,0);
INSERT INTO "django_geo_db_location" VALUES(39483,NULL,'Allendorf, IA',16219,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39484,NULL,'Allendorf, IA 51330',16219,222,NULL,19,22972,0);
INSERT INTO "django_geo_db_location" VALUES(39485,NULL,'Arnolds Park, IA',16220,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39486,NULL,'Arnolds Park, IA 51331',16220,222,NULL,19,22973,0);
INSERT INTO "django_geo_db_location" VALUES(39487,NULL,'Dickens, IA',16221,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39488,NULL,'Dickens, IA 51333',16221,222,NULL,19,22974,0);
INSERT INTO "django_geo_db_location" VALUES(39489,NULL,'Estherville, IA',16222,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39490,NULL,'Estherville, IA 51334',16222,222,NULL,19,22975,0);
INSERT INTO "django_geo_db_location" VALUES(39491,NULL,'Everly, IA',16223,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39492,NULL,'Everly, IA 51338',16223,222,NULL,19,22976,0);
INSERT INTO "django_geo_db_location" VALUES(39493,NULL,'Fostoria, IA',16224,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39494,NULL,'Fostoria, IA 51340',16224,222,NULL,19,22977,0);
INSERT INTO "django_geo_db_location" VALUES(39495,NULL,'Gillett Grove, IA',16225,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39496,NULL,'Gillett Grove, IA 51341',16225,222,NULL,19,22978,0);
INSERT INTO "django_geo_db_location" VALUES(39497,NULL,'Graettinger, IA',16226,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39498,NULL,'Graettinger, IA 51342',16226,222,NULL,19,22979,0);
INSERT INTO "django_geo_db_location" VALUES(39499,NULL,'Greenville, IA',16227,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39500,NULL,'Greenville, IA 51343',16227,222,NULL,19,22980,0);
INSERT INTO "django_geo_db_location" VALUES(39501,NULL,'Gruver, IA',16228,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39502,NULL,'Gruver, IA 51344',16228,222,NULL,19,22981,0);
INSERT INTO "django_geo_db_location" VALUES(39503,NULL,'Harris, IA',16229,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39504,NULL,'Harris, IA 51345',16229,222,NULL,19,22982,0);
INSERT INTO "django_geo_db_location" VALUES(39505,NULL,'Hartley, IA',16230,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39506,NULL,'Hartley, IA 51346',16230,222,NULL,19,22983,0);
INSERT INTO "django_geo_db_location" VALUES(39507,NULL,'Lake Park, IA',16231,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39508,NULL,'Lake Park, IA 51347',16231,222,NULL,19,22984,0);
INSERT INTO "django_geo_db_location" VALUES(39509,NULL,'May City, IA',16232,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39510,NULL,'May City, IA 51349',16232,222,NULL,19,22985,0);
INSERT INTO "django_geo_db_location" VALUES(39511,NULL,'Melvin, IA',16233,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39512,NULL,'Melvin, IA 51350',16233,222,NULL,19,22986,0);
INSERT INTO "django_geo_db_location" VALUES(39513,NULL,'Milford, IA',16234,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39514,NULL,'Milford, IA 51351',16234,222,NULL,19,22987,0);
INSERT INTO "django_geo_db_location" VALUES(39515,NULL,'Ocheyedan, IA',16235,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39516,NULL,'Ocheyedan, IA 51354',16235,222,NULL,19,22988,0);
INSERT INTO "django_geo_db_location" VALUES(39517,NULL,'Okoboji, IA',16236,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39518,NULL,'Okoboji, IA 51355',16236,222,NULL,19,22989,0);
INSERT INTO "django_geo_db_location" VALUES(39519,NULL,'Royal, IA',16237,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39520,NULL,'Royal, IA 51357',16237,222,NULL,19,22990,0);
INSERT INTO "django_geo_db_location" VALUES(39521,NULL,'Ruthven, IA',16238,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39522,NULL,'Ruthven, IA 51358',16238,222,NULL,19,22991,0);
INSERT INTO "django_geo_db_location" VALUES(39523,NULL,'Spirit Lake, IA',16239,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39524,NULL,'Spirit Lake, IA 51360',16239,222,NULL,19,22992,0);
INSERT INTO "django_geo_db_location" VALUES(39525,NULL,'Superior, IA',16240,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39526,NULL,'Superior, IA 51363',16240,222,NULL,19,22993,0);
INSERT INTO "django_geo_db_location" VALUES(39527,NULL,'Terril, IA',16241,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39528,NULL,'Terril, IA 51364',16241,222,NULL,19,22994,0);
INSERT INTO "django_geo_db_location" VALUES(39529,NULL,'Wallingford, IA',16242,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39530,NULL,'Wallingford, IA 51365',16242,222,NULL,19,22995,0);
INSERT INTO "django_geo_db_location" VALUES(39531,NULL,'Webb, IA',16243,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39532,NULL,'Webb, IA 51366',16243,222,NULL,19,22996,0);
INSERT INTO "django_geo_db_location" VALUES(39533,NULL,'Carroll, IA',16244,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39534,NULL,'Carroll, IA 51401',16244,222,NULL,19,22997,0);
INSERT INTO "django_geo_db_location" VALUES(39535,NULL,'Arcadia, IA',16245,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39536,NULL,'Arcadia, IA 51430',16245,222,NULL,19,22998,0);
INSERT INTO "django_geo_db_location" VALUES(39537,NULL,'Arthur, IA',16246,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39538,NULL,'Arthur, IA 51431',16246,222,NULL,19,22999,0);
INSERT INTO "django_geo_db_location" VALUES(39539,NULL,'Aspinwall, IA',16247,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39540,NULL,'Aspinwall, IA 51432',16247,222,NULL,19,23000,0);
INSERT INTO "django_geo_db_location" VALUES(39541,NULL,'Auburn, IA',16248,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39542,NULL,'Auburn, IA 51433',16248,222,NULL,19,23001,0);
INSERT INTO "django_geo_db_location" VALUES(39543,NULL,'Breda, IA',16249,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39544,NULL,'Breda, IA 51436',16249,222,NULL,19,23002,0);
INSERT INTO "django_geo_db_location" VALUES(39545,NULL,'Charter Oak, IA',16250,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39546,NULL,'Charter Oak, IA 51439',16250,222,NULL,19,23003,0);
INSERT INTO "django_geo_db_location" VALUES(39547,NULL,'Dedham, IA',16251,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39548,NULL,'Dedham, IA 51440',16251,222,NULL,19,23004,0);
INSERT INTO "django_geo_db_location" VALUES(39549,NULL,'Deloit, IA',16252,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39550,NULL,'Deloit, IA 51441',16252,222,NULL,19,23005,0);
INSERT INTO "django_geo_db_location" VALUES(39551,NULL,'Denison, IA',16253,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39552,NULL,'Denison, IA 51442',16253,222,NULL,19,23006,0);
INSERT INTO "django_geo_db_location" VALUES(39553,NULL,'Glidden, IA',16254,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39554,NULL,'Glidden, IA 51443',16254,222,NULL,19,23007,0);
INSERT INTO "django_geo_db_location" VALUES(39555,NULL,'Halbur, IA',16255,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39556,NULL,'Halbur, IA 51444',16255,222,NULL,19,23008,0);
INSERT INTO "django_geo_db_location" VALUES(39557,NULL,'Ida Grove, IA',16256,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39558,NULL,'Ida Grove, IA 51445',16256,222,NULL,19,23009,0);
INSERT INTO "django_geo_db_location" VALUES(39559,NULL,'Irwin, IA',16257,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39560,NULL,'Irwin, IA 51446',16257,222,NULL,19,23010,0);
INSERT INTO "django_geo_db_location" VALUES(39561,NULL,'Kirkman, IA',16258,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39562,NULL,'Kirkman, IA 51447',16258,222,NULL,19,23011,0);
INSERT INTO "django_geo_db_location" VALUES(39563,NULL,'Kiron, IA',16259,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39564,NULL,'Kiron, IA 51448',16259,222,NULL,19,23012,0);
INSERT INTO "django_geo_db_location" VALUES(39565,NULL,'Lake City, IA',16260,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39566,NULL,'Lake City, IA 51449',16260,222,NULL,19,23013,0);
INSERT INTO "django_geo_db_location" VALUES(39567,NULL,'Lake View, IA',16261,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39568,NULL,'Lake View, IA 51450',16261,222,NULL,19,23014,0);
INSERT INTO "django_geo_db_location" VALUES(39569,NULL,'Lanesboro, IA',16262,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39570,NULL,'Lanesboro, IA 51451',16262,222,NULL,19,23015,0);
INSERT INTO "django_geo_db_location" VALUES(39571,NULL,'Lidderdale, IA',16263,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39572,NULL,'Lidderdale, IA 51452',16263,222,NULL,19,23016,0);
INSERT INTO "django_geo_db_location" VALUES(39573,NULL,'Lohrville, IA',16264,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39574,NULL,'Lohrville, IA 51453',16264,222,NULL,19,23017,0);
INSERT INTO "django_geo_db_location" VALUES(39575,NULL,'Manilla, IA',16265,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39576,NULL,'Manilla, IA 51454',16265,222,NULL,19,23018,0);
INSERT INTO "django_geo_db_location" VALUES(39577,NULL,'Manning, IA',16266,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39578,NULL,'Manning, IA 51455',16266,222,NULL,19,23019,0);
INSERT INTO "django_geo_db_location" VALUES(39579,NULL,'Odebolt, IA',16267,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39580,NULL,'Odebolt, IA 51458',16267,222,NULL,19,23020,0);
INSERT INTO "django_geo_db_location" VALUES(39581,NULL,'Ralston, IA',16268,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39582,NULL,'Ralston, IA 51459',16268,222,NULL,19,23021,0);
INSERT INTO "django_geo_db_location" VALUES(39583,NULL,'Ricketts, IA',16269,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39584,NULL,'Ricketts, IA 51460',16269,222,NULL,19,23022,0);
INSERT INTO "django_geo_db_location" VALUES(39585,NULL,'Schleswig, IA',16270,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39586,NULL,'Schleswig, IA 51461',16270,222,NULL,19,23023,0);
INSERT INTO "django_geo_db_location" VALUES(39587,NULL,'Scranton, IA',16271,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39588,NULL,'Scranton, IA 51462',16271,222,NULL,19,23024,0);
INSERT INTO "django_geo_db_location" VALUES(39589,NULL,'Templeton, IA',16272,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39590,NULL,'Templeton, IA 51463',16272,222,NULL,19,23025,0);
INSERT INTO "django_geo_db_location" VALUES(39591,NULL,'Vail, IA',16273,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39592,NULL,'Vail, IA 51465',16273,222,NULL,19,23026,0);
INSERT INTO "django_geo_db_location" VALUES(39593,NULL,'Wall Lake, IA',16274,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39594,NULL,'Wall Lake, IA 51466',16274,222,NULL,19,23027,0);
INSERT INTO "django_geo_db_location" VALUES(39595,NULL,'Westside, IA',16275,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39596,NULL,'Westside, IA 51467',16275,222,NULL,19,23028,0);
INSERT INTO "django_geo_db_location" VALUES(39597,NULL,'Templeton, IA 51496',16272,222,NULL,19,23029,0);
INSERT INTO "django_geo_db_location" VALUES(39598,NULL,'Council Bluffs, IA',16276,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39599,NULL,'Council Bluffs, IA 51501',16276,222,NULL,19,23030,0);
INSERT INTO "django_geo_db_location" VALUES(39600,NULL,'Council Bluffs, IA 51502',16276,222,NULL,19,23031,0);
INSERT INTO "django_geo_db_location" VALUES(39601,NULL,'Council Bluffs, IA 51503',16276,222,NULL,19,23032,0);
INSERT INTO "django_geo_db_location" VALUES(39602,NULL,'Carter Lake, IA',16277,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39603,NULL,'Carter Lake, IA 51510',16277,222,NULL,19,23033,0);
INSERT INTO "django_geo_db_location" VALUES(39604,NULL,'Griswold, IA',16278,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39605,NULL,'Griswold, IA 51515',16278,222,NULL,19,23034,0);
INSERT INTO "django_geo_db_location" VALUES(39606,NULL,'Arion, IA',16279,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39607,NULL,'Arion, IA 51520',16279,222,NULL,19,23035,0);
INSERT INTO "django_geo_db_location" VALUES(39608,NULL,'Avoca, IA',16280,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39609,NULL,'Avoca, IA 51521',16280,222,NULL,19,23036,0);
INSERT INTO "django_geo_db_location" VALUES(39610,NULL,'Blencoe, IA',16281,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39611,NULL,'Blencoe, IA 51523',16281,222,NULL,19,23037,0);
INSERT INTO "django_geo_db_location" VALUES(39612,NULL,'Carson, IA',16282,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39613,NULL,'Carson, IA 51525',16282,222,NULL,19,23038,0);
INSERT INTO "django_geo_db_location" VALUES(39614,NULL,'Crescent, IA',16283,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39615,NULL,'Crescent, IA 51526',16283,222,NULL,19,23039,0);
INSERT INTO "django_geo_db_location" VALUES(39616,NULL,'Defiance, IA',16284,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39617,NULL,'Defiance, IA 51527',16284,222,NULL,19,23040,0);
INSERT INTO "django_geo_db_location" VALUES(39618,NULL,'Dow City, IA',16285,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39619,NULL,'Dow City, IA 51528',16285,222,NULL,19,23041,0);
INSERT INTO "django_geo_db_location" VALUES(39620,NULL,'Dunlap, IA',16286,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39621,NULL,'Dunlap, IA 51529',16286,222,NULL,19,23042,0);
INSERT INTO "django_geo_db_location" VALUES(39622,NULL,'Earling, IA',16287,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39623,NULL,'Earling, IA 51530',16287,222,NULL,19,23043,0);
INSERT INTO "django_geo_db_location" VALUES(39624,NULL,'Elk Horn, IA',16288,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39625,NULL,'Elk Horn, IA 51531',16288,222,NULL,19,23044,0);
INSERT INTO "django_geo_db_location" VALUES(39626,NULL,'Elliott, IA',16289,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39627,NULL,'Elliott, IA 51532',16289,222,NULL,19,23045,0);
INSERT INTO "django_geo_db_location" VALUES(39628,NULL,'Emerson, IA',16290,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39629,NULL,'Emerson, IA 51533',16290,222,NULL,19,23046,0);
INSERT INTO "django_geo_db_location" VALUES(39630,NULL,'Glenwood, IA',16291,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39631,NULL,'Glenwood, IA 51534',16291,222,NULL,19,23047,0);
INSERT INTO "django_geo_db_location" VALUES(39632,NULL,'Griswold, IA 51535',16278,222,NULL,19,23048,0);
INSERT INTO "django_geo_db_location" VALUES(39633,NULL,'Hancock, IA',16292,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39634,NULL,'Hancock, IA 51536',16292,222,NULL,19,23049,0);
INSERT INTO "django_geo_db_location" VALUES(39635,NULL,'Harlan, IA',16293,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39636,NULL,'Harlan, IA 51537',16293,222,NULL,19,23050,0);
INSERT INTO "django_geo_db_location" VALUES(39637,NULL,'Hastings, IA',16294,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39638,NULL,'Hastings, IA 51540',16294,222,NULL,19,23051,0);
INSERT INTO "django_geo_db_location" VALUES(39639,NULL,'Henderson, IA',16295,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39640,NULL,'Henderson, IA 51541',16295,222,NULL,19,23052,0);
INSERT INTO "django_geo_db_location" VALUES(39641,NULL,'Honey Creek, IA',16296,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39642,NULL,'Honey Creek, IA 51542',16296,222,NULL,19,23053,0);
INSERT INTO "django_geo_db_location" VALUES(39643,NULL,'Kimballton, IA',16297,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39644,NULL,'Kimballton, IA 51543',16297,222,NULL,19,23054,0);
INSERT INTO "django_geo_db_location" VALUES(39645,NULL,'Lewis, IA',16298,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39646,NULL,'Lewis, IA 51544',16298,222,NULL,19,23055,0);
INSERT INTO "django_geo_db_location" VALUES(39647,NULL,'Little Sioux, IA',16299,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39648,NULL,'Little Sioux, IA 51545',16299,222,NULL,19,23056,0);
INSERT INTO "django_geo_db_location" VALUES(39649,NULL,'Logan, IA',16300,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39650,NULL,'Logan, IA 51546',16300,222,NULL,19,23057,0);
INSERT INTO "django_geo_db_location" VALUES(39651,NULL,'Kirkman, IA 51547',16258,222,NULL,19,23058,0);
INSERT INTO "django_geo_db_location" VALUES(39652,NULL,'McClelland, IA',16301,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39653,NULL,'McClelland, IA 51548',16301,222,NULL,19,23059,0);
INSERT INTO "django_geo_db_location" VALUES(39654,NULL,'Macedonia, IA',16302,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39655,NULL,'Macedonia, IA 51549',16302,222,NULL,19,23060,0);
INSERT INTO "django_geo_db_location" VALUES(39656,NULL,'Magnolia, IA',16303,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39657,NULL,'Magnolia, IA 51550',16303,222,NULL,19,23061,0);
INSERT INTO "django_geo_db_location" VALUES(39658,NULL,'Malvern, IA',16304,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39659,NULL,'Malvern, IA 51551',16304,222,NULL,19,23062,0);
INSERT INTO "django_geo_db_location" VALUES(39660,NULL,'Marne, IA',16305,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39661,NULL,'Marne, IA 51552',16305,222,NULL,19,23063,0);
INSERT INTO "django_geo_db_location" VALUES(39662,NULL,'Minden, IA',16306,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39663,NULL,'Minden, IA 51553',16306,222,NULL,19,23064,0);
INSERT INTO "django_geo_db_location" VALUES(39664,NULL,'Mineola, IA',16307,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39665,NULL,'Mineola, IA 51554',16307,222,NULL,19,23065,0);
INSERT INTO "django_geo_db_location" VALUES(39666,NULL,'Missouri Valley, IA',16308,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39667,NULL,'Missouri Valley, IA 51555',16308,222,NULL,19,23066,0);
INSERT INTO "django_geo_db_location" VALUES(39668,NULL,'Modale, IA',16309,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39669,NULL,'Modale, IA 51556',16309,222,NULL,19,23067,0);
INSERT INTO "django_geo_db_location" VALUES(39670,NULL,'Mondamin, IA',16310,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39671,NULL,'Mondamin, IA 51557',16310,222,NULL,19,23068,0);
INSERT INTO "django_geo_db_location" VALUES(39672,NULL,'Moorhead, IA',16311,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39673,NULL,'Moorhead, IA 51558',16311,222,NULL,19,23069,0);
INSERT INTO "django_geo_db_location" VALUES(39674,NULL,'Neola, IA',16312,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39675,NULL,'Neola, IA 51559',16312,222,NULL,19,23070,0);
INSERT INTO "django_geo_db_location" VALUES(39676,NULL,'Oakland, IA',16313,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39677,NULL,'Oakland, IA 51560',16313,222,NULL,19,23071,0);
INSERT INTO "django_geo_db_location" VALUES(39678,NULL,'Pacific Junction, IA',16314,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39679,NULL,'Pacific Junction, IA 51561',16314,222,NULL,19,23072,0);
INSERT INTO "django_geo_db_location" VALUES(39680,NULL,'Panama, IA',16315,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39681,NULL,'Panama, IA 51562',16315,222,NULL,19,23073,0);
INSERT INTO "django_geo_db_location" VALUES(39682,NULL,'Persia, IA',16316,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39683,NULL,'Persia, IA 51563',16316,222,NULL,19,23074,0);
INSERT INTO "django_geo_db_location" VALUES(39684,NULL,'Pisgah, IA',16317,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39685,NULL,'Pisgah, IA 51564',16317,222,NULL,19,23075,0);
INSERT INTO "django_geo_db_location" VALUES(39686,NULL,'Portsmouth, IA',16318,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39687,NULL,'Portsmouth, IA 51565',16318,222,NULL,19,23076,0);
INSERT INTO "django_geo_db_location" VALUES(39688,NULL,'Red Oak, IA',16319,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39689,NULL,'Red Oak, IA 51566',16319,222,NULL,19,23077,0);
INSERT INTO "django_geo_db_location" VALUES(39690,NULL,'Shelby, IA',16320,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39691,NULL,'Shelby, IA 51570',16320,222,NULL,19,23078,0);
INSERT INTO "django_geo_db_location" VALUES(39692,NULL,'Silver City, IA',16321,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39693,NULL,'Silver City, IA 51571',16321,222,NULL,19,23079,0);
INSERT INTO "django_geo_db_location" VALUES(39694,NULL,'Soldier, IA',16322,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39695,NULL,'Soldier, IA 51572',16322,222,NULL,19,23080,0);
INSERT INTO "django_geo_db_location" VALUES(39696,NULL,'Stanton, IA',16323,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39697,NULL,'Stanton, IA 51573',16323,222,NULL,19,23081,0);
INSERT INTO "django_geo_db_location" VALUES(39698,NULL,'Tennant, IA',16324,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39699,NULL,'Tennant, IA 51574',16324,222,NULL,19,23082,0);
INSERT INTO "django_geo_db_location" VALUES(39700,NULL,'Treynor, IA',16325,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39701,NULL,'Treynor, IA 51575',16325,222,NULL,19,23083,0);
INSERT INTO "django_geo_db_location" VALUES(39702,NULL,'Underwood, IA',16326,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39703,NULL,'Underwood, IA 51576',16326,222,NULL,19,23084,0);
INSERT INTO "django_geo_db_location" VALUES(39704,NULL,'Walnut, IA',16327,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39705,NULL,'Walnut, IA 51577',16327,222,NULL,19,23085,0);
INSERT INTO "django_geo_db_location" VALUES(39706,NULL,'Westphalia, IA',16328,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39707,NULL,'Westphalia, IA 51578',16328,222,NULL,19,23086,0);
INSERT INTO "django_geo_db_location" VALUES(39708,NULL,'Woodbine, IA',16329,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39709,NULL,'Woodbine, IA 51579',16329,222,NULL,19,23087,0);
INSERT INTO "django_geo_db_location" VALUES(39710,NULL,'Red Oak, IA 51591',16319,222,NULL,19,23088,0);
INSERT INTO "django_geo_db_location" VALUES(39711,NULL,'Harlan, IA 51593',16293,222,NULL,19,23089,0);
INSERT INTO "django_geo_db_location" VALUES(39712,NULL,'Shenandoah, IA',16330,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39713,NULL,'Shenandoah, IA 51601',16330,222,NULL,19,23090,0);
INSERT INTO "django_geo_db_location" VALUES(39714,NULL,'Shenandoah, IA 51602',16330,222,NULL,19,23091,0);
INSERT INTO "django_geo_db_location" VALUES(39715,NULL,'Shenandoah, IA 51603',16330,222,NULL,19,23092,0);
INSERT INTO "django_geo_db_location" VALUES(39716,NULL,'Blanchard, IA',16331,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39717,NULL,'Blanchard, IA 51630',16331,222,NULL,19,23093,0);
INSERT INTO "django_geo_db_location" VALUES(39718,NULL,'Braddyville, IA',16332,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39719,NULL,'Braddyville, IA 51631',16332,222,NULL,19,23094,0);
INSERT INTO "django_geo_db_location" VALUES(39720,NULL,'Clarinda, IA',16333,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39721,NULL,'Clarinda, IA 51632',16333,222,NULL,19,23095,0);
INSERT INTO "django_geo_db_location" VALUES(39722,NULL,'Coin, IA',16334,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39723,NULL,'Coin, IA 51636',16334,222,NULL,19,23096,0);
INSERT INTO "django_geo_db_location" VALUES(39724,NULL,'College Springs, IA',16335,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39725,NULL,'College Springs, IA 51637',16335,222,NULL,19,23097,0);
INSERT INTO "django_geo_db_location" VALUES(39726,NULL,'Essex, IA',16336,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39727,NULL,'Essex, IA 51638',16336,222,NULL,19,23098,0);
INSERT INTO "django_geo_db_location" VALUES(39728,NULL,'Farragut, IA',16337,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39729,NULL,'Farragut, IA 51639',16337,222,NULL,19,23099,0);
INSERT INTO "django_geo_db_location" VALUES(39730,NULL,'Hamburg, IA',16338,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39731,NULL,'Hamburg, IA 51640',16338,222,NULL,19,23100,0);
INSERT INTO "django_geo_db_location" VALUES(39732,NULL,'Imogene, IA',16339,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39733,NULL,'Imogene, IA 51645',16339,222,NULL,19,23101,0);
INSERT INTO "django_geo_db_location" VALUES(39734,NULL,'New Market, IA',16340,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39735,NULL,'New Market, IA 51646',16340,222,NULL,19,23102,0);
INSERT INTO "django_geo_db_location" VALUES(39736,NULL,'Northboro, IA',16341,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39737,NULL,'Northboro, IA 51647',16341,222,NULL,19,23103,0);
INSERT INTO "django_geo_db_location" VALUES(39738,NULL,'Percival, IA',16342,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39739,NULL,'Percival, IA 51648',16342,222,NULL,19,23104,0);
INSERT INTO "django_geo_db_location" VALUES(39740,NULL,'Randolph, IA',16343,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39741,NULL,'Randolph, IA 51649',16343,222,NULL,19,23105,0);
INSERT INTO "django_geo_db_location" VALUES(39742,NULL,'Riverton, IA',16344,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39743,NULL,'Riverton, IA 51650',16344,222,NULL,19,23106,0);
INSERT INTO "django_geo_db_location" VALUES(39744,NULL,'Shambaugh, IA',16345,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39745,NULL,'Shambaugh, IA 51651',16345,222,NULL,19,23107,0);
INSERT INTO "django_geo_db_location" VALUES(39746,NULL,'Sidney, IA',16346,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39747,NULL,'Sidney, IA 51652',16346,222,NULL,19,23108,0);
INSERT INTO "django_geo_db_location" VALUES(39748,NULL,'Tabor, IA',16347,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39749,NULL,'Tabor, IA 51653',16347,222,NULL,19,23109,0);
INSERT INTO "django_geo_db_location" VALUES(39750,NULL,'Thurman, IA',16348,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39751,NULL,'Thurman, IA 51654',16348,222,NULL,19,23110,0);
INSERT INTO "django_geo_db_location" VALUES(39752,NULL,'Yorktown, IA',16349,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39753,NULL,'Yorktown, IA 51656',16349,222,NULL,19,23111,0);
INSERT INTO "django_geo_db_location" VALUES(39754,NULL,'Dubuque, IA',16350,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39755,NULL,'Dubuque, IA 52001',16350,222,NULL,19,23112,0);
INSERT INTO "django_geo_db_location" VALUES(39756,NULL,'Dubuque, IA 52002',16350,222,NULL,19,23113,0);
INSERT INTO "django_geo_db_location" VALUES(39757,NULL,'Dubuque, IA 52003',16350,222,NULL,19,23114,0);
INSERT INTO "django_geo_db_location" VALUES(39758,NULL,'Dubuque, IA 52004',16350,222,NULL,19,23115,0);
INSERT INTO "django_geo_db_location" VALUES(39759,NULL,'Andrew, IA',16351,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39760,NULL,'Andrew, IA 52030',16351,222,NULL,19,23116,0);
INSERT INTO "django_geo_db_location" VALUES(39761,NULL,'Bellevue, IA',16352,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39762,NULL,'Bellevue, IA 52031',16352,222,NULL,19,23117,0);
INSERT INTO "django_geo_db_location" VALUES(39763,NULL,'Bernard, IA',16353,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39764,NULL,'Bernard, IA 52032',16353,222,NULL,19,23118,0);
INSERT INTO "django_geo_db_location" VALUES(39765,NULL,'Cascade, IA',16354,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39766,NULL,'Cascade, IA 52033',16354,222,NULL,19,23119,0);
INSERT INTO "django_geo_db_location" VALUES(39767,NULL,'Colesburg, IA',16355,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39768,NULL,'Colesburg, IA 52035',16355,222,NULL,19,23120,0);
INSERT INTO "django_geo_db_location" VALUES(39769,NULL,'Delaware, IA',16356,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39770,NULL,'Delaware, IA 52036',16356,222,NULL,19,23121,0);
INSERT INTO "django_geo_db_location" VALUES(39771,NULL,'Delmar, IA',16357,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39772,NULL,'Delmar, IA 52037',16357,222,NULL,19,23122,0);
INSERT INTO "django_geo_db_location" VALUES(39773,NULL,'Dundee, IA',16358,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39774,NULL,'Dundee, IA 52038',16358,222,NULL,19,23123,0);
INSERT INTO "django_geo_db_location" VALUES(39775,NULL,'Durango, IA',16359,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39776,NULL,'Durango, IA 52039',16359,222,NULL,19,23124,0);
INSERT INTO "django_geo_db_location" VALUES(39777,NULL,'Dyersville, IA',16360,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39778,NULL,'Dyersville, IA 52040',16360,222,NULL,19,23125,0);
INSERT INTO "django_geo_db_location" VALUES(39779,NULL,'Earlville, IA',16361,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39780,NULL,'Earlville, IA 52041',16361,222,NULL,19,23126,0);
INSERT INTO "django_geo_db_location" VALUES(39781,NULL,'Edgewood, IA',16362,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39782,NULL,'Edgewood, IA 52042',16362,222,NULL,19,23127,0);
INSERT INTO "django_geo_db_location" VALUES(39783,NULL,'Elkader, IA',16363,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39784,NULL,'Elkader, IA 52043',16363,222,NULL,19,23128,0);
INSERT INTO "django_geo_db_location" VALUES(39785,NULL,'Elkport, IA',16364,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39786,NULL,'Elkport, IA 52044',16364,222,NULL,19,23129,0);
INSERT INTO "django_geo_db_location" VALUES(39787,NULL,'Epworth, IA',16365,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39788,NULL,'Epworth, IA 52045',16365,222,NULL,19,23130,0);
INSERT INTO "django_geo_db_location" VALUES(39789,NULL,'Farley, IA',16366,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39790,NULL,'Farley, IA 52046',16366,222,NULL,19,23131,0);
INSERT INTO "django_geo_db_location" VALUES(39791,NULL,'Farmersburg, IA',16367,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39792,NULL,'Farmersburg, IA 52047',16367,222,NULL,19,23132,0);
INSERT INTO "django_geo_db_location" VALUES(39793,NULL,'Garber, IA',16368,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39794,NULL,'Garber, IA 52048',16368,222,NULL,19,23133,0);
INSERT INTO "django_geo_db_location" VALUES(39795,NULL,'Garnavillo, IA',16369,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39796,NULL,'Garnavillo, IA 52049',16369,222,NULL,19,23134,0);
INSERT INTO "django_geo_db_location" VALUES(39797,NULL,'Greeley, IA',16370,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39798,NULL,'Greeley, IA 52050',16370,222,NULL,19,23135,0);
INSERT INTO "django_geo_db_location" VALUES(39799,NULL,'Guttenberg, IA',16371,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39800,NULL,'Guttenberg, IA 52052',16371,222,NULL,19,23136,0);
INSERT INTO "django_geo_db_location" VALUES(39801,NULL,'Holy Cross, IA',16372,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39802,NULL,'Holy Cross, IA 52053',16372,222,NULL,19,23137,0);
INSERT INTO "django_geo_db_location" VALUES(39803,NULL,'La Motte, IA',16373,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39804,NULL,'La Motte, IA 52054',16373,222,NULL,19,23138,0);
INSERT INTO "django_geo_db_location" VALUES(39805,NULL,'Littleport, IA',16374,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39806,NULL,'Littleport, IA 52055',16374,222,NULL,19,23139,0);
INSERT INTO "django_geo_db_location" VALUES(39807,NULL,'Luxemburg, IA',16375,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39808,NULL,'Luxemburg, IA 52056',16375,222,NULL,19,23140,0);
INSERT INTO "django_geo_db_location" VALUES(39809,NULL,'Manchester, IA',16376,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39810,NULL,'Manchester, IA 52057',16376,222,NULL,19,23141,0);
INSERT INTO "django_geo_db_location" VALUES(39811,NULL,'Maquoketa, IA',16377,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39812,NULL,'Maquoketa, IA 52060',16377,222,NULL,19,23142,0);
INSERT INTO "django_geo_db_location" VALUES(39813,NULL,'Miles, IA',16378,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39814,NULL,'Miles, IA 52064',16378,222,NULL,19,23143,0);
INSERT INTO "django_geo_db_location" VALUES(39815,NULL,'New Vienna, IA',16379,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39816,NULL,'New Vienna, IA 52065',16379,222,NULL,19,23144,0);
INSERT INTO "django_geo_db_location" VALUES(39817,NULL,'North Buena Vista, IA',16380,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39818,NULL,'North Buena Vista, IA 52066',16380,222,NULL,19,23145,0);
INSERT INTO "django_geo_db_location" VALUES(39819,NULL,'Peosta, IA',16381,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39820,NULL,'Peosta, IA 52068',16381,222,NULL,19,23146,0);
INSERT INTO "django_geo_db_location" VALUES(39821,NULL,'Preston, IA',16382,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39822,NULL,'Preston, IA 52069',16382,222,NULL,19,23147,0);
INSERT INTO "django_geo_db_location" VALUES(39823,NULL,'Sabula, IA',16383,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39824,NULL,'Sabula, IA 52070',16383,222,NULL,19,23148,0);
INSERT INTO "django_geo_db_location" VALUES(39825,NULL,'Saint Donatus, IA',16384,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39826,NULL,'Saint Donatus, IA 52071',16384,222,NULL,19,23149,0);
INSERT INTO "django_geo_db_location" VALUES(39827,NULL,'Saint Olaf, IA',16385,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39828,NULL,'Saint Olaf, IA 52072',16385,222,NULL,19,23150,0);
INSERT INTO "django_geo_db_location" VALUES(39829,NULL,'Sherrill, IA',16386,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39830,NULL,'Sherrill, IA 52073',16386,222,NULL,19,23151,0);
INSERT INTO "django_geo_db_location" VALUES(39831,NULL,'Spragueville, IA',16387,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39832,NULL,'Spragueville, IA 52074',16387,222,NULL,19,23152,0);
INSERT INTO "django_geo_db_location" VALUES(39833,NULL,'Springbrook, IA',16388,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39834,NULL,'Springbrook, IA 52075',16388,222,NULL,19,23153,0);
INSERT INTO "django_geo_db_location" VALUES(39835,NULL,'Strawberry Point, IA',16389,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39836,NULL,'Strawberry Point, IA 52076',16389,222,NULL,19,23154,0);
INSERT INTO "django_geo_db_location" VALUES(39837,NULL,'Volga, IA',16390,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39838,NULL,'Volga, IA 52077',16390,222,NULL,19,23155,0);
INSERT INTO "django_geo_db_location" VALUES(39839,NULL,'Worthington, IA',16391,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39840,NULL,'Worthington, IA 52078',16391,222,NULL,19,23156,0);
INSERT INTO "django_geo_db_location" VALUES(39841,NULL,'Zwingle, IA',16392,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39842,NULL,'Zwingle, IA 52079',16392,222,NULL,19,23157,0);
INSERT INTO "django_geo_db_location" VALUES(39843,NULL,'Dubuque, IA 52099',16350,222,NULL,19,23158,0);
INSERT INTO "django_geo_db_location" VALUES(39844,NULL,'Decorah, IA',16393,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39845,NULL,'Decorah, IA 52101',16393,222,NULL,19,23159,0);
INSERT INTO "django_geo_db_location" VALUES(39846,NULL,'Burr Oak, IA',16394,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39847,NULL,'Burr Oak, IA 52131',16394,222,NULL,19,23160,0);
INSERT INTO "django_geo_db_location" VALUES(39848,NULL,'Calmar, IA',16395,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39849,NULL,'Calmar, IA 52132',16395,222,NULL,19,23161,0);
INSERT INTO "django_geo_db_location" VALUES(39850,NULL,'Castalia, IA',16396,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39851,NULL,'Castalia, IA 52133',16396,222,NULL,19,23162,0);
INSERT INTO "django_geo_db_location" VALUES(39852,NULL,'Chester, IA',16397,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39853,NULL,'Chester, IA 52134',16397,222,NULL,19,23163,0);
INSERT INTO "django_geo_db_location" VALUES(39854,NULL,'Clermont, IA',16398,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39855,NULL,'Clermont, IA 52135',16398,222,NULL,19,23164,0);
INSERT INTO "django_geo_db_location" VALUES(39856,NULL,'Cresco, IA',16399,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39857,NULL,'Cresco, IA 52136',16399,222,NULL,19,23165,0);
INSERT INTO "django_geo_db_location" VALUES(39858,NULL,'Dorchester, IA',16400,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39859,NULL,'Dorchester, IA 52140',16400,222,NULL,19,23166,0);
INSERT INTO "django_geo_db_location" VALUES(39860,NULL,'Elgin, IA',16401,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39861,NULL,'Elgin, IA 52141',16401,222,NULL,19,23167,0);
INSERT INTO "django_geo_db_location" VALUES(39862,NULL,'Fayette, IA',16402,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39863,NULL,'Fayette, IA 52142',16402,222,NULL,19,23168,0);
INSERT INTO "django_geo_db_location" VALUES(39864,NULL,'Fort Atkinson, IA',16403,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39865,NULL,'Fort Atkinson, IA 52144',16403,222,NULL,19,23169,0);
INSERT INTO "django_geo_db_location" VALUES(39866,NULL,'Harpers Ferry, IA',16404,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39867,NULL,'Harpers Ferry, IA 52146',16404,222,NULL,19,23170,0);
INSERT INTO "django_geo_db_location" VALUES(39868,NULL,'Hawkeye, IA',16405,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39869,NULL,'Hawkeye, IA 52147',16405,222,NULL,19,23171,0);
INSERT INTO "django_geo_db_location" VALUES(39870,NULL,'Highlandville, IA',16406,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39871,NULL,'Highlandville, IA 52149',16406,222,NULL,19,23172,0);
INSERT INTO "django_geo_db_location" VALUES(39872,NULL,'Lansing, IA',16407,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39873,NULL,'Lansing, IA 52151',16407,222,NULL,19,23173,0);
INSERT INTO "django_geo_db_location" VALUES(39874,NULL,'Lawler, IA',16408,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39875,NULL,'Lawler, IA 52154',16408,222,NULL,19,23174,0);
INSERT INTO "django_geo_db_location" VALUES(39876,NULL,'Lime Springs, IA',16409,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39877,NULL,'Lime Springs, IA 52155',16409,222,NULL,19,23175,0);
INSERT INTO "django_geo_db_location" VALUES(39878,NULL,'Luana, IA',16410,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39879,NULL,'Luana, IA 52156',16410,222,NULL,19,23176,0);
INSERT INTO "django_geo_db_location" VALUES(39880,NULL,'McGregor, IA',16411,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39881,NULL,'McGregor, IA 52157',16411,222,NULL,19,23177,0);
INSERT INTO "django_geo_db_location" VALUES(39882,NULL,'Marquette, IA',16412,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39883,NULL,'Marquette, IA 52158',16412,222,NULL,19,23178,0);
INSERT INTO "django_geo_db_location" VALUES(39884,NULL,'Monona, IA',16413,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39885,NULL,'Monona, IA 52159',16413,222,NULL,19,23179,0);
INSERT INTO "django_geo_db_location" VALUES(39886,NULL,'New Albin, IA',16414,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39887,NULL,'New Albin, IA 52160',16414,222,NULL,19,23180,0);
INSERT INTO "django_geo_db_location" VALUES(39888,NULL,'Ossian, IA',16415,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39889,NULL,'Ossian, IA 52161',16415,222,NULL,19,23181,0);
INSERT INTO "django_geo_db_location" VALUES(39890,NULL,'Postville, IA',16416,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39891,NULL,'Postville, IA 52162',16416,222,NULL,19,23182,0);
INSERT INTO "django_geo_db_location" VALUES(39892,NULL,'Protivin, IA',16417,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39893,NULL,'Protivin, IA 52163',16417,222,NULL,19,23183,0);
INSERT INTO "django_geo_db_location" VALUES(39894,NULL,'Randalia, IA',16418,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39895,NULL,'Randalia, IA 52164',16418,222,NULL,19,23184,0);
INSERT INTO "django_geo_db_location" VALUES(39896,NULL,'Ridgeway, IA',16419,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39897,NULL,'Ridgeway, IA 52165',16419,222,NULL,19,23185,0);
INSERT INTO "django_geo_db_location" VALUES(39898,NULL,'Saint Lucas, IA',16420,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39899,NULL,'Saint Lucas, IA 52166',16420,222,NULL,19,23186,0);
INSERT INTO "django_geo_db_location" VALUES(39900,NULL,'Spillville, IA',16421,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39901,NULL,'Spillville, IA 52168',16421,222,NULL,19,23187,0);
INSERT INTO "django_geo_db_location" VALUES(39902,NULL,'Wadena, IA',16422,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39903,NULL,'Wadena, IA 52169',16422,222,NULL,19,23188,0);
INSERT INTO "django_geo_db_location" VALUES(39904,NULL,'Waterville, IA',16423,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39905,NULL,'Waterville, IA 52170',16423,222,NULL,19,23189,0);
INSERT INTO "django_geo_db_location" VALUES(39906,NULL,'Waucoma, IA',16424,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39907,NULL,'Waucoma, IA 52171',16424,222,NULL,19,23190,0);
INSERT INTO "django_geo_db_location" VALUES(39908,NULL,'Waukon, IA',16425,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39909,NULL,'Waukon, IA 52172',16425,222,NULL,19,23191,0);
INSERT INTO "django_geo_db_location" VALUES(39910,NULL,'West Union, IA',16426,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39911,NULL,'West Union, IA 52175',16426,222,NULL,19,23192,0);
INSERT INTO "django_geo_db_location" VALUES(39912,NULL,'Ainsworth, IA',16427,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39913,NULL,'Ainsworth, IA 52201',16427,222,NULL,19,23193,0);
INSERT INTO "django_geo_db_location" VALUES(39914,NULL,'Alburnett, IA',16428,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39915,NULL,'Alburnett, IA 52202',16428,222,NULL,19,23194,0);
INSERT INTO "django_geo_db_location" VALUES(39916,NULL,'Amana, IA',16429,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39917,NULL,'Amana, IA 52203',16429,222,NULL,19,23195,0);
INSERT INTO "django_geo_db_location" VALUES(39918,NULL,'Amana, IA 52204',16429,222,NULL,19,23196,0);
INSERT INTO "django_geo_db_location" VALUES(39919,NULL,'Anamosa, IA',16430,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39920,NULL,'Anamosa, IA 52205',16430,222,NULL,19,23197,0);
INSERT INTO "django_geo_db_location" VALUES(39921,NULL,'Atkins, IA',16431,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39922,NULL,'Atkins, IA 52206',16431,222,NULL,19,23198,0);
INSERT INTO "django_geo_db_location" VALUES(39923,NULL,'Baldwin, IA',16432,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39924,NULL,'Baldwin, IA 52207',16432,222,NULL,19,23199,0);
INSERT INTO "django_geo_db_location" VALUES(39925,NULL,'Belle Plaine, IA',16433,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39926,NULL,'Belle Plaine, IA 52208',16433,222,NULL,19,23200,0);
INSERT INTO "django_geo_db_location" VALUES(39927,NULL,'Blairstown, IA',16434,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39928,NULL,'Blairstown, IA 52209',16434,222,NULL,19,23201,0);
INSERT INTO "django_geo_db_location" VALUES(39929,NULL,'Brandon, IA',16435,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39930,NULL,'Brandon, IA 52210',16435,222,NULL,19,23202,0);
INSERT INTO "django_geo_db_location" VALUES(39931,NULL,'Brooklyn, IA',16436,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39932,NULL,'Brooklyn, IA 52211',16436,222,NULL,19,23203,0);
INSERT INTO "django_geo_db_location" VALUES(39933,NULL,'Center Junction, IA',16437,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39934,NULL,'Center Junction, IA 52212',16437,222,NULL,19,23204,0);
INSERT INTO "django_geo_db_location" VALUES(39935,NULL,'Center Point, IA',16438,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39936,NULL,'Center Point, IA 52213',16438,222,NULL,19,23205,0);
INSERT INTO "django_geo_db_location" VALUES(39937,NULL,'Central City, IA',16439,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39938,NULL,'Central City, IA 52214',16439,222,NULL,19,23206,0);
INSERT INTO "django_geo_db_location" VALUES(39939,NULL,'Chelsea, IA',16440,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39940,NULL,'Chelsea, IA 52215',16440,222,NULL,19,23207,0);
INSERT INTO "django_geo_db_location" VALUES(39941,NULL,'Clarence, IA',16441,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39942,NULL,'Clarence, IA 52216',16441,222,NULL,19,23208,0);
INSERT INTO "django_geo_db_location" VALUES(39943,NULL,'Clutier, IA',16442,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39944,NULL,'Clutier, IA 52217',16442,222,NULL,19,23209,0);
INSERT INTO "django_geo_db_location" VALUES(39945,NULL,'Coggon, IA',16443,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39946,NULL,'Coggon, IA 52218',16443,222,NULL,19,23210,0);
INSERT INTO "django_geo_db_location" VALUES(39947,NULL,'Prairieburg, IA',16444,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39948,NULL,'Prairieburg, IA 52219',16444,222,NULL,19,23211,0);
INSERT INTO "django_geo_db_location" VALUES(39949,NULL,'Conroy, IA',16445,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39950,NULL,'Conroy, IA 52220',16445,222,NULL,19,23212,0);
INSERT INTO "django_geo_db_location" VALUES(39951,NULL,'Guernsey, IA',16446,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39952,NULL,'Guernsey, IA 52221',16446,222,NULL,19,23213,0);
INSERT INTO "django_geo_db_location" VALUES(39953,NULL,'Deep River, IA',16447,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39954,NULL,'Deep River, IA 52222',16447,222,NULL,19,23214,0);
INSERT INTO "django_geo_db_location" VALUES(39955,NULL,'Delhi, IA',16448,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39956,NULL,'Delhi, IA 52223',16448,222,NULL,19,23215,0);
INSERT INTO "django_geo_db_location" VALUES(39957,NULL,'Dysart, IA',16449,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39958,NULL,'Dysart, IA 52224',16449,222,NULL,19,23216,0);
INSERT INTO "django_geo_db_location" VALUES(39959,NULL,'Elberon, IA',16450,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39960,NULL,'Elberon, IA 52225',16450,222,NULL,19,23217,0);
INSERT INTO "django_geo_db_location" VALUES(39961,NULL,'Elwood, IA',16451,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39962,NULL,'Elwood, IA 52226',16451,222,NULL,19,23218,0);
INSERT INTO "django_geo_db_location" VALUES(39963,NULL,'Ely, IA',16452,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39964,NULL,'Ely, IA 52227',16452,222,NULL,19,23219,0);
INSERT INTO "django_geo_db_location" VALUES(39965,NULL,'Fairfax, IA',16453,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39966,NULL,'Fairfax, IA 52228',16453,222,NULL,19,23220,0);
INSERT INTO "django_geo_db_location" VALUES(39967,NULL,'Garrison, IA',16454,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39968,NULL,'Garrison, IA 52229',16454,222,NULL,19,23221,0);
INSERT INTO "django_geo_db_location" VALUES(39969,NULL,'Harper, IA',16455,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39970,NULL,'Harper, IA 52231',16455,222,NULL,19,23222,0);
INSERT INTO "django_geo_db_location" VALUES(39971,NULL,'Hartwick, IA',16456,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39972,NULL,'Hartwick, IA 52232',16456,222,NULL,19,23223,0);
INSERT INTO "django_geo_db_location" VALUES(39973,NULL,'Hiawatha, IA',16457,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39974,NULL,'Hiawatha, IA 52233',16457,222,NULL,19,23224,0);
INSERT INTO "django_geo_db_location" VALUES(39975,NULL,'Hills, IA',16458,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39976,NULL,'Hills, IA 52235',16458,222,NULL,19,23225,0);
INSERT INTO "django_geo_db_location" VALUES(39977,NULL,'Homestead, IA',16459,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39978,NULL,'Homestead, IA 52236',16459,222,NULL,19,23226,0);
INSERT INTO "django_geo_db_location" VALUES(39979,NULL,'Hopkinton, IA',16460,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39980,NULL,'Hopkinton, IA 52237',16460,222,NULL,19,23227,0);
INSERT INTO "django_geo_db_location" VALUES(39981,NULL,'Tama, IA',16461,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39982,NULL,'Tama, IA 52239',16461,222,NULL,19,23228,0);
INSERT INTO "django_geo_db_location" VALUES(39983,NULL,'Iowa City, IA',16462,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39984,NULL,'Iowa City, IA 52240',16462,222,NULL,19,23229,0);
INSERT INTO "django_geo_db_location" VALUES(39985,NULL,'Coralville, IA',16463,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39986,NULL,'Coralville, IA 52241',16463,222,NULL,19,23230,0);
INSERT INTO "django_geo_db_location" VALUES(39987,NULL,'Iowa City, IA 52242',16462,222,NULL,19,23231,0);
INSERT INTO "django_geo_db_location" VALUES(39988,NULL,'Iowa City, IA 52243',16462,222,NULL,19,23232,0);
INSERT INTO "django_geo_db_location" VALUES(39989,NULL,'Iowa City, IA 52244',16462,222,NULL,19,23233,0);
INSERT INTO "django_geo_db_location" VALUES(39990,NULL,'Iowa City, IA 52245',16462,222,NULL,19,23234,0);
INSERT INTO "django_geo_db_location" VALUES(39991,NULL,'Iowa City, IA 52246',16462,222,NULL,19,23235,0);
INSERT INTO "django_geo_db_location" VALUES(39992,NULL,'Kalona, IA',16464,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39993,NULL,'Kalona, IA 52247',16464,222,NULL,19,23236,0);
INSERT INTO "django_geo_db_location" VALUES(39994,NULL,'Keota, IA',16465,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39995,NULL,'Keota, IA 52248',16465,222,NULL,19,23237,0);
INSERT INTO "django_geo_db_location" VALUES(39996,NULL,'Keystone, IA',16466,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39997,NULL,'Keystone, IA 52249',16466,222,NULL,19,23238,0);
INSERT INTO "django_geo_db_location" VALUES(39998,NULL,'Ladora, IA',16467,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(39999,NULL,'Ladora, IA 52251',16467,222,NULL,19,23239,0);
INSERT INTO "django_geo_db_location" VALUES(40000,NULL,'Langworthy, IA',16468,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40001,NULL,'Langworthy, IA 52252',16468,222,NULL,19,23240,0);
INSERT INTO "django_geo_db_location" VALUES(40002,NULL,'Lisbon, IA',16469,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40003,NULL,'Lisbon, IA 52253',16469,222,NULL,19,23241,0);
INSERT INTO "django_geo_db_location" VALUES(40004,NULL,'Lost Nation, IA',16470,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40005,NULL,'Lost Nation, IA 52254',16470,222,NULL,19,23242,0);
INSERT INTO "django_geo_db_location" VALUES(40006,NULL,'Lowden, IA',16471,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40007,NULL,'Lowden, IA 52255',16471,222,NULL,19,23243,0);
INSERT INTO "django_geo_db_location" VALUES(40008,NULL,'Luzerne, IA',16472,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40009,NULL,'Luzerne, IA 52257',16472,222,NULL,19,23244,0);
INSERT INTO "django_geo_db_location" VALUES(40010,NULL,'Marengo, IA',16473,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40011,NULL,'Marengo, IA 52301',16473,222,NULL,19,23245,0);
INSERT INTO "django_geo_db_location" VALUES(40012,NULL,'Marion, IA',16474,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40013,NULL,'Marion, IA 52302',16474,222,NULL,19,23246,0);
INSERT INTO "django_geo_db_location" VALUES(40014,NULL,'Martelle, IA',16475,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40015,NULL,'Martelle, IA 52305',16475,222,NULL,19,23247,0);
INSERT INTO "django_geo_db_location" VALUES(40016,NULL,'Mechanicsville, IA',16476,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40017,NULL,'Mechanicsville, IA 52306',16476,222,NULL,19,23248,0);
INSERT INTO "django_geo_db_location" VALUES(40018,NULL,'Middle Amana, IA',16477,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40019,NULL,'Middle Amana, IA 52307',16477,222,NULL,19,23249,0);
INSERT INTO "django_geo_db_location" VALUES(40020,NULL,'Millersburg, IA',16478,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40021,NULL,'Millersburg, IA 52308',16478,222,NULL,19,23250,0);
INSERT INTO "django_geo_db_location" VALUES(40022,NULL,'Monmouth, IA',16479,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40023,NULL,'Monmouth, IA 52309',16479,222,NULL,19,23251,0);
INSERT INTO "django_geo_db_location" VALUES(40024,NULL,'Monticello, IA',16480,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40025,NULL,'Monticello, IA 52310',16480,222,NULL,19,23252,0);
INSERT INTO "django_geo_db_location" VALUES(40026,NULL,'Morley, IA',16481,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40027,NULL,'Morley, IA 52312',16481,222,NULL,19,23253,0);
INSERT INTO "django_geo_db_location" VALUES(40028,NULL,'Mount Auburn, IA',16482,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40029,NULL,'Mount Auburn, IA 52313',16482,222,NULL,19,23254,0);
INSERT INTO "django_geo_db_location" VALUES(40030,NULL,'Mount Vernon, IA',16483,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40031,NULL,'Mount Vernon, IA 52314',16483,222,NULL,19,23255,0);
INSERT INTO "django_geo_db_location" VALUES(40032,NULL,'Newhall, IA',16484,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40033,NULL,'Newhall, IA 52315',16484,222,NULL,19,23256,0);
INSERT INTO "django_geo_db_location" VALUES(40034,NULL,'North English, IA',16485,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40035,NULL,'North English, IA 52316',16485,222,NULL,19,23257,0);
INSERT INTO "django_geo_db_location" VALUES(40036,NULL,'North Liberty, IA',16486,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40037,NULL,'North Liberty, IA 52317',16486,222,NULL,19,23258,0);
INSERT INTO "django_geo_db_location" VALUES(40038,NULL,'Norway, IA',16487,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40039,NULL,'Norway, IA 52318',16487,222,NULL,19,23259,0);
INSERT INTO "django_geo_db_location" VALUES(40040,NULL,'Oakdale, IA',16488,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40041,NULL,'Oakdale, IA 52319',16488,222,NULL,19,23260,0);
INSERT INTO "django_geo_db_location" VALUES(40042,NULL,'Olin, IA',16489,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40043,NULL,'Olin, IA 52320',16489,222,NULL,19,23261,0);
INSERT INTO "django_geo_db_location" VALUES(40044,NULL,'Onslow, IA',16490,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40045,NULL,'Onslow, IA 52321',16490,222,NULL,19,23262,0);
INSERT INTO "django_geo_db_location" VALUES(40046,NULL,'Oxford, IA',16491,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40047,NULL,'Oxford, IA 52322',16491,222,NULL,19,23263,0);
INSERT INTO "django_geo_db_location" VALUES(40048,NULL,'Oxford Junction, IA',16492,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40049,NULL,'Oxford Junction, IA 52323',16492,222,NULL,19,23264,0);
INSERT INTO "django_geo_db_location" VALUES(40050,NULL,'Palo, IA',16493,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40051,NULL,'Palo, IA 52324',16493,222,NULL,19,23265,0);
INSERT INTO "django_geo_db_location" VALUES(40052,NULL,'Parnell, IA',16494,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40053,NULL,'Parnell, IA 52325',16494,222,NULL,19,23266,0);
INSERT INTO "django_geo_db_location" VALUES(40054,NULL,'Quasqueton, IA',16495,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40055,NULL,'Quasqueton, IA 52326',16495,222,NULL,19,23267,0);
INSERT INTO "django_geo_db_location" VALUES(40056,NULL,'Riverside, IA',16496,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40057,NULL,'Riverside, IA 52327',16496,222,NULL,19,23268,0);
INSERT INTO "django_geo_db_location" VALUES(40058,NULL,'Robins, IA',16497,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40059,NULL,'Robins, IA 52328',16497,222,NULL,19,23269,0);
INSERT INTO "django_geo_db_location" VALUES(40060,NULL,'Rowley, IA',16498,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40061,NULL,'Rowley, IA 52329',16498,222,NULL,19,23270,0);
INSERT INTO "django_geo_db_location" VALUES(40062,NULL,'Ryan, IA',16499,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40063,NULL,'Ryan, IA 52330',16499,222,NULL,19,23271,0);
INSERT INTO "django_geo_db_location" VALUES(40064,NULL,'Shellsburg, IA',16500,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40065,NULL,'Shellsburg, IA 52332',16500,222,NULL,19,23272,0);
INSERT INTO "django_geo_db_location" VALUES(40066,NULL,'Solon, IA',16501,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40067,NULL,'Solon, IA 52333',16501,222,NULL,19,23273,0);
INSERT INTO "django_geo_db_location" VALUES(40068,NULL,'South Amana, IA',16502,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40069,NULL,'South Amana, IA 52334',16502,222,NULL,19,23274,0);
INSERT INTO "django_geo_db_location" VALUES(40070,NULL,'South English, IA',16503,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40071,NULL,'South English, IA 52335',16503,222,NULL,19,23275,0);
INSERT INTO "django_geo_db_location" VALUES(40072,NULL,'Springville, IA',16504,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40073,NULL,'Springville, IA 52336',16504,222,NULL,19,23276,0);
INSERT INTO "django_geo_db_location" VALUES(40074,NULL,'Stanwood, IA',16505,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40075,NULL,'Stanwood, IA 52337',16505,222,NULL,19,23277,0);
INSERT INTO "django_geo_db_location" VALUES(40076,NULL,'Swisher, IA',16506,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40077,NULL,'Swisher, IA 52338',16506,222,NULL,19,23278,0);
INSERT INTO "django_geo_db_location" VALUES(40078,NULL,'Tama, IA 52339',16461,222,NULL,19,23279,0);
INSERT INTO "django_geo_db_location" VALUES(40079,NULL,'Tiffin, IA',16507,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40080,NULL,'Tiffin, IA 52340',16507,222,NULL,19,23280,0);
INSERT INTO "django_geo_db_location" VALUES(40081,NULL,'Toddville, IA',16508,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40082,NULL,'Toddville, IA 52341',16508,222,NULL,19,23281,0);
INSERT INTO "django_geo_db_location" VALUES(40083,NULL,'Toledo, IA',16509,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40084,NULL,'Toledo, IA 52342',16509,222,NULL,19,23282,0);
INSERT INTO "django_geo_db_location" VALUES(40085,NULL,'Troy Mills, IA',16510,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40086,NULL,'Troy Mills, IA 52344',16510,222,NULL,19,23283,0);
INSERT INTO "django_geo_db_location" VALUES(40087,NULL,'Urbana, IA',16511,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40088,NULL,'Urbana, IA 52345',16511,222,NULL,19,23284,0);
INSERT INTO "django_geo_db_location" VALUES(40089,NULL,'Van Horne, IA',16512,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40090,NULL,'Van Horne, IA 52346',16512,222,NULL,19,23285,0);
INSERT INTO "django_geo_db_location" VALUES(40091,NULL,'Victor, IA',16513,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40092,NULL,'Victor, IA 52347',16513,222,NULL,19,23286,0);
INSERT INTO "django_geo_db_location" VALUES(40093,NULL,'Vining, IA',16514,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40094,NULL,'Vining, IA 52348',16514,222,NULL,19,23287,0);
INSERT INTO "django_geo_db_location" VALUES(40095,NULL,'Vinton, IA',16515,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40096,NULL,'Vinton, IA 52349',16515,222,NULL,19,23288,0);
INSERT INTO "django_geo_db_location" VALUES(40097,NULL,'Viola, IA',16516,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40098,NULL,'Viola, IA 52350',16516,222,NULL,19,23289,0);
INSERT INTO "django_geo_db_location" VALUES(40099,NULL,'Walford, IA',16517,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40100,NULL,'Walford, IA 52351',16517,222,NULL,19,23290,0);
INSERT INTO "django_geo_db_location" VALUES(40101,NULL,'Walker, IA',16518,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40102,NULL,'Walker, IA 52352',16518,222,NULL,19,23291,0);
INSERT INTO "django_geo_db_location" VALUES(40103,NULL,'Washington, IA',16519,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40104,NULL,'Washington, IA 52353',16519,222,NULL,19,23292,0);
INSERT INTO "django_geo_db_location" VALUES(40105,NULL,'Watkins, IA',16520,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40106,NULL,'Watkins, IA 52354',16520,222,NULL,19,23293,0);
INSERT INTO "django_geo_db_location" VALUES(40107,NULL,'Webster, IA',16521,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40108,NULL,'Webster, IA 52355',16521,222,NULL,19,23294,0);
INSERT INTO "django_geo_db_location" VALUES(40109,NULL,'Wellman, IA',16522,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40110,NULL,'Wellman, IA 52356',16522,222,NULL,19,23295,0);
INSERT INTO "django_geo_db_location" VALUES(40111,NULL,'West Branch, IA',16523,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40112,NULL,'West Branch, IA 52358',16523,222,NULL,19,23296,0);
INSERT INTO "django_geo_db_location" VALUES(40113,NULL,'West Chester, IA',16524,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40114,NULL,'West Chester, IA 52359',16524,222,NULL,19,23297,0);
INSERT INTO "django_geo_db_location" VALUES(40115,NULL,'Williamsburg, IA',16525,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40116,NULL,'Williamsburg, IA 52361',16525,222,NULL,19,23298,0);
INSERT INTO "django_geo_db_location" VALUES(40117,NULL,'Wyoming, IA',16526,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40118,NULL,'Wyoming, IA 52362',16526,222,NULL,19,23299,0);
INSERT INTO "django_geo_db_location" VALUES(40119,NULL,'Cedar Rapids, IA',16527,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40120,NULL,'Cedar Rapids, IA 52401',16527,222,NULL,19,23300,0);
INSERT INTO "django_geo_db_location" VALUES(40121,NULL,'Cedar Rapids, IA 52402',16527,222,NULL,19,23301,0);
INSERT INTO "django_geo_db_location" VALUES(40122,NULL,'Cedar Rapids, IA 52403',16527,222,NULL,19,23302,0);
INSERT INTO "django_geo_db_location" VALUES(40123,NULL,'Cedar Rapids, IA 52404',16527,222,NULL,19,23303,0);
INSERT INTO "django_geo_db_location" VALUES(40124,NULL,'Cedar Rapids, IA 52405',16527,222,NULL,19,23304,0);
INSERT INTO "django_geo_db_location" VALUES(40125,NULL,'Cedar Rapids, IA 52406',16527,222,NULL,19,23305,0);
INSERT INTO "django_geo_db_location" VALUES(40126,NULL,'Cedar Rapids, IA 52407',16527,222,NULL,19,23306,0);
INSERT INTO "django_geo_db_location" VALUES(40127,NULL,'Cedar Rapids, IA 52408',16527,222,NULL,19,23307,0);
INSERT INTO "django_geo_db_location" VALUES(40128,NULL,'Cedar Rapids, IA 52409',16527,222,NULL,19,23308,0);
INSERT INTO "django_geo_db_location" VALUES(40129,NULL,'Cedar Rapids, IA 52410',16527,222,NULL,19,23309,0);
INSERT INTO "django_geo_db_location" VALUES(40130,NULL,'Cedar Rapids, IA 52411',16527,222,NULL,19,23310,0);
INSERT INTO "django_geo_db_location" VALUES(40131,NULL,'Cedar Rapids, IA 52497',16527,222,NULL,19,23311,0);
INSERT INTO "django_geo_db_location" VALUES(40132,NULL,'Cedar Rapids, IA 52498',16527,222,NULL,19,23312,0);
INSERT INTO "django_geo_db_location" VALUES(40133,NULL,'Cedar Rapids, IA 52499',16527,222,NULL,19,23313,0);
INSERT INTO "django_geo_db_location" VALUES(40134,NULL,'Ottumwa, IA',16528,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40135,NULL,'Ottumwa, IA 52501',16528,222,NULL,19,23314,0);
INSERT INTO "django_geo_db_location" VALUES(40136,NULL,'Agency, IA',16529,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40137,NULL,'Agency, IA 52530',16529,222,NULL,19,23315,0);
INSERT INTO "django_geo_db_location" VALUES(40138,NULL,'Albia, IA',16530,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40139,NULL,'Albia, IA 52531',16530,222,NULL,19,23316,0);
INSERT INTO "django_geo_db_location" VALUES(40140,NULL,'Batavia, IA',16531,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40141,NULL,'Batavia, IA 52533',16531,222,NULL,19,23317,0);
INSERT INTO "django_geo_db_location" VALUES(40142,NULL,'Beacon, IA',16532,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40143,NULL,'Beacon, IA 52534',16532,222,NULL,19,23318,0);
INSERT INTO "django_geo_db_location" VALUES(40144,NULL,'Birmingham, IA',16533,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40145,NULL,'Birmingham, IA 52535',16533,222,NULL,19,23319,0);
INSERT INTO "django_geo_db_location" VALUES(40146,NULL,'Blakesburg, IA',16534,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40147,NULL,'Blakesburg, IA 52536',16534,222,NULL,19,23320,0);
INSERT INTO "django_geo_db_location" VALUES(40148,NULL,'Bloomfield, IA',16535,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40149,NULL,'Bloomfield, IA 52537',16535,222,NULL,19,23321,0);
INSERT INTO "django_geo_db_location" VALUES(40150,NULL,'West Grove, IA',16536,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40151,NULL,'West Grove, IA 52538',16536,222,NULL,19,23322,0);
INSERT INTO "django_geo_db_location" VALUES(40152,NULL,'Brighton, IA',16537,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40153,NULL,'Brighton, IA 52540',16537,222,NULL,19,23323,0);
INSERT INTO "django_geo_db_location" VALUES(40154,NULL,'Cantril, IA',16538,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40155,NULL,'Cantril, IA 52542',16538,222,NULL,19,23324,0);
INSERT INTO "django_geo_db_location" VALUES(40156,NULL,'Cedar, IA',16539,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40157,NULL,'Cedar, IA 52543',16539,222,NULL,19,23325,0);
INSERT INTO "django_geo_db_location" VALUES(40158,NULL,'Centerville, IA',16540,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40159,NULL,'Centerville, IA 52544',16540,222,NULL,19,23326,0);
INSERT INTO "django_geo_db_location" VALUES(40160,NULL,'Chillicothe, IA',16541,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40161,NULL,'Chillicothe, IA 52548',16541,222,NULL,19,23327,0);
INSERT INTO "django_geo_db_location" VALUES(40162,NULL,'Cincinnati, IA',16542,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40163,NULL,'Cincinnati, IA 52549',16542,222,NULL,19,23328,0);
INSERT INTO "django_geo_db_location" VALUES(40164,NULL,'Delta, IA',16543,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40165,NULL,'Delta, IA 52550',16543,222,NULL,19,23329,0);
INSERT INTO "django_geo_db_location" VALUES(40166,NULL,'Douds, IA',16544,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40167,NULL,'Douds, IA 52551',16544,222,NULL,19,23330,0);
INSERT INTO "django_geo_db_location" VALUES(40168,NULL,'Drakesville, IA',16545,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40169,NULL,'Drakesville, IA 52552',16545,222,NULL,19,23331,0);
INSERT INTO "django_geo_db_location" VALUES(40170,NULL,'Eddyville, IA',16546,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40171,NULL,'Eddyville, IA 52553',16546,222,NULL,19,23332,0);
INSERT INTO "django_geo_db_location" VALUES(40172,NULL,'Eldon, IA',16547,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40173,NULL,'Eldon, IA 52554',16547,222,NULL,19,23333,0);
INSERT INTO "django_geo_db_location" VALUES(40174,NULL,'Exline, IA',16548,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40175,NULL,'Exline, IA 52555',16548,222,NULL,19,23334,0);
INSERT INTO "django_geo_db_location" VALUES(40176,NULL,'Fairfield, IA',16549,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40177,NULL,'Fairfield, IA 52556',16549,222,NULL,19,23335,0);
INSERT INTO "django_geo_db_location" VALUES(40178,NULL,'Fairfield, IA 52557',16549,222,NULL,19,23336,0);
INSERT INTO "django_geo_db_location" VALUES(40179,NULL,'Floris, IA',16550,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40180,NULL,'Floris, IA 52560',16550,222,NULL,19,23337,0);
INSERT INTO "django_geo_db_location" VALUES(40181,NULL,'Fremont, IA',16551,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40182,NULL,'Fremont, IA 52561',16551,222,NULL,19,23338,0);
INSERT INTO "django_geo_db_location" VALUES(40183,NULL,'Hayesville, IA',16552,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40184,NULL,'Hayesville, IA 52562',16552,222,NULL,19,23339,0);
INSERT INTO "django_geo_db_location" VALUES(40185,NULL,'Hedrick, IA',16553,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40186,NULL,'Hedrick, IA 52563',16553,222,NULL,19,23340,0);
INSERT INTO "django_geo_db_location" VALUES(40187,NULL,'Keosauqua, IA',16554,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40188,NULL,'Keosauqua, IA 52565',16554,222,NULL,19,23341,0);
INSERT INTO "django_geo_db_location" VALUES(40189,NULL,'Kirkville, IA',16555,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40190,NULL,'Kirkville, IA 52566',16555,222,NULL,19,23342,0);
INSERT INTO "django_geo_db_location" VALUES(40191,NULL,'Libertyville, IA',16556,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40192,NULL,'Libertyville, IA 52567',16556,222,NULL,19,23343,0);
INSERT INTO "django_geo_db_location" VALUES(40193,NULL,'Martinsburg, IA',16557,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40194,NULL,'Martinsburg, IA 52568',16557,222,NULL,19,23344,0);
INSERT INTO "django_geo_db_location" VALUES(40195,NULL,'Melrose, IA',16558,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40196,NULL,'Melrose, IA 52569',16558,222,NULL,19,23345,0);
INSERT INTO "django_geo_db_location" VALUES(40197,NULL,'Milton, IA',16559,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40198,NULL,'Milton, IA 52570',16559,222,NULL,19,23346,0);
INSERT INTO "django_geo_db_location" VALUES(40199,NULL,'Moravia, IA',16560,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40200,NULL,'Moravia, IA 52571',16560,222,NULL,19,23347,0);
INSERT INTO "django_geo_db_location" VALUES(40201,NULL,'Moulton, IA',16561,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40202,NULL,'Moulton, IA 52572',16561,222,NULL,19,23348,0);
INSERT INTO "django_geo_db_location" VALUES(40203,NULL,'Mount Sterling, IA',16562,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40204,NULL,'Mount Sterling, IA 52573',16562,222,NULL,19,23349,0);
INSERT INTO "django_geo_db_location" VALUES(40205,NULL,'Mystic, IA',16563,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40206,NULL,'Mystic, IA 52574',16563,222,NULL,19,23350,0);
INSERT INTO "django_geo_db_location" VALUES(40207,NULL,'Ollie, IA',16564,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40208,NULL,'Ollie, IA 52576',16564,222,NULL,19,23351,0);
INSERT INTO "django_geo_db_location" VALUES(40209,NULL,'Oskaloosa, IA',16565,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40210,NULL,'Oskaloosa, IA 52577',16565,222,NULL,19,23352,0);
INSERT INTO "django_geo_db_location" VALUES(40211,NULL,'Packwood, IA',16566,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40212,NULL,'Packwood, IA 52580',16566,222,NULL,19,23353,0);
INSERT INTO "django_geo_db_location" VALUES(40213,NULL,'Plano, IA',16567,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40214,NULL,'Plano, IA 52581',16567,222,NULL,19,23354,0);
INSERT INTO "django_geo_db_location" VALUES(40215,NULL,'Promise City, IA',16568,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40216,NULL,'Promise City, IA 52583',16568,222,NULL,19,23355,0);
INSERT INTO "django_geo_db_location" VALUES(40217,NULL,'Pulaski, IA',16569,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40218,NULL,'Pulaski, IA 52584',16569,222,NULL,19,23356,0);
INSERT INTO "django_geo_db_location" VALUES(40219,NULL,'Richland, IA',16570,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40220,NULL,'Richland, IA 52585',16570,222,NULL,19,23357,0);
INSERT INTO "django_geo_db_location" VALUES(40221,NULL,'Rose Hill, IA',16571,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40222,NULL,'Rose Hill, IA 52586',16571,222,NULL,19,23358,0);
INSERT INTO "django_geo_db_location" VALUES(40223,NULL,'Selma, IA',16572,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40224,NULL,'Selma, IA 52588',16572,222,NULL,19,23359,0);
INSERT INTO "django_geo_db_location" VALUES(40225,NULL,'Seymour, IA',16573,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40226,NULL,'Seymour, IA 52590',16573,222,NULL,19,23360,0);
INSERT INTO "django_geo_db_location" VALUES(40227,NULL,'Sigourney, IA',16574,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40228,NULL,'Sigourney, IA 52591',16574,222,NULL,19,23361,0);
INSERT INTO "django_geo_db_location" VALUES(40229,NULL,'Udell, IA',16575,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40230,NULL,'Udell, IA 52593',16575,222,NULL,19,23362,0);
INSERT INTO "django_geo_db_location" VALUES(40231,NULL,'Unionville, IA',16576,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40232,NULL,'Unionville, IA 52594',16576,222,NULL,19,23363,0);
INSERT INTO "django_geo_db_location" VALUES(40233,NULL,'University Park, IA',16577,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40234,NULL,'University Park, IA 52595',16577,222,NULL,19,23364,0);
INSERT INTO "django_geo_db_location" VALUES(40235,NULL,'Burlington, IA',16578,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40236,NULL,'Burlington, IA 52601',16578,222,NULL,19,23365,0);
INSERT INTO "django_geo_db_location" VALUES(40237,NULL,'Argyle, IA',16579,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40238,NULL,'Argyle, IA 52619',16579,222,NULL,19,23366,0);
INSERT INTO "django_geo_db_location" VALUES(40239,NULL,'Bonaparte, IA',16580,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40240,NULL,'Bonaparte, IA 52620',16580,222,NULL,19,23367,0);
INSERT INTO "django_geo_db_location" VALUES(40241,NULL,'Crawfordsville, IA',16581,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40242,NULL,'Crawfordsville, IA 52621',16581,222,NULL,19,23368,0);
INSERT INTO "django_geo_db_location" VALUES(40243,NULL,'Danville, IA',16582,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40244,NULL,'Danville, IA 52623',16582,222,NULL,19,23369,0);
INSERT INTO "django_geo_db_location" VALUES(40245,NULL,'Denmark, IA',16583,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40246,NULL,'Denmark, IA 52624',16583,222,NULL,19,23370,0);
INSERT INTO "django_geo_db_location" VALUES(40247,NULL,'Donnellson, IA',16584,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40248,NULL,'Donnellson, IA 52625',16584,222,NULL,19,23371,0);
INSERT INTO "django_geo_db_location" VALUES(40249,NULL,'Farmington, IA',16585,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40250,NULL,'Farmington, IA 52626',16585,222,NULL,19,23372,0);
INSERT INTO "django_geo_db_location" VALUES(40251,NULL,'Fort Madison, IA',16586,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40252,NULL,'Fort Madison, IA 52627',16586,222,NULL,19,23373,0);
INSERT INTO "django_geo_db_location" VALUES(40253,NULL,'Hillsboro, IA',16587,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40254,NULL,'Hillsboro, IA 52630',16587,222,NULL,19,23374,0);
INSERT INTO "django_geo_db_location" VALUES(40255,NULL,'Houghton, IA',16588,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40256,NULL,'Houghton, IA 52631',16588,222,NULL,19,23375,0);
INSERT INTO "django_geo_db_location" VALUES(40257,NULL,'Keokuk, IA',16589,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40258,NULL,'Keokuk, IA 52632',16589,222,NULL,19,23376,0);
INSERT INTO "django_geo_db_location" VALUES(40259,NULL,'Lockridge, IA',16590,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40260,NULL,'Lockridge, IA 52635',16590,222,NULL,19,23377,0);
INSERT INTO "django_geo_db_location" VALUES(40261,NULL,'Mediapolis, IA',16591,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40262,NULL,'Mediapolis, IA 52637',16591,222,NULL,19,23378,0);
INSERT INTO "django_geo_db_location" VALUES(40263,NULL,'Middletown, IA',16592,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40264,NULL,'Middletown, IA 52638',16592,222,NULL,19,23379,0);
INSERT INTO "django_geo_db_location" VALUES(40265,NULL,'Montrose, IA',16593,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40266,NULL,'Montrose, IA 52639',16593,222,NULL,19,23380,0);
INSERT INTO "django_geo_db_location" VALUES(40267,NULL,'Morning Sun, IA',16594,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40268,NULL,'Morning Sun, IA 52640',16594,222,NULL,19,23381,0);
INSERT INTO "django_geo_db_location" VALUES(40269,NULL,'Mount Pleasant, IA',16595,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40270,NULL,'Mount Pleasant, IA 52641',16595,222,NULL,19,23382,0);
INSERT INTO "django_geo_db_location" VALUES(40271,NULL,'Rome, IA',16596,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40272,NULL,'Rome, IA 52642',16596,222,NULL,19,23383,0);
INSERT INTO "django_geo_db_location" VALUES(40273,NULL,'Mount Union, IA',16597,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40274,NULL,'Mount Union, IA 52644',16597,222,NULL,19,23384,0);
INSERT INTO "django_geo_db_location" VALUES(40275,NULL,'New London, IA',16598,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40276,NULL,'New London, IA 52645',16598,222,NULL,19,23385,0);
INSERT INTO "django_geo_db_location" VALUES(40277,NULL,'Oakville, IA',16599,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40278,NULL,'Oakville, IA 52646',16599,222,NULL,19,23386,0);
INSERT INTO "django_geo_db_location" VALUES(40279,NULL,'Olds, IA',16600,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40280,NULL,'Olds, IA 52647',16600,222,NULL,19,23387,0);
INSERT INTO "django_geo_db_location" VALUES(40281,NULL,'Pilot Grove, IA',16601,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40282,NULL,'Pilot Grove, IA 52648',16601,222,NULL,19,23388,0);
INSERT INTO "django_geo_db_location" VALUES(40283,NULL,'Salem, IA',16602,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40284,NULL,'Salem, IA 52649',16602,222,NULL,19,23389,0);
INSERT INTO "django_geo_db_location" VALUES(40285,NULL,'Sperry, IA',16603,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40286,NULL,'Sperry, IA 52650',16603,222,NULL,19,23390,0);
INSERT INTO "django_geo_db_location" VALUES(40287,NULL,'Stockport, IA',16604,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40288,NULL,'Stockport, IA 52651',16604,222,NULL,19,23391,0);
INSERT INTO "django_geo_db_location" VALUES(40289,NULL,'Swedesburg, IA',16605,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40290,NULL,'Swedesburg, IA 52652',16605,222,NULL,19,23392,0);
INSERT INTO "django_geo_db_location" VALUES(40291,NULL,'Wapello, IA',16606,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40292,NULL,'Wapello, IA 52653',16606,222,NULL,19,23393,0);
INSERT INTO "django_geo_db_location" VALUES(40293,NULL,'Wayland, IA',16607,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40294,NULL,'Wayland, IA 52654',16607,222,NULL,19,23394,0);
INSERT INTO "django_geo_db_location" VALUES(40295,NULL,'West Burlington, IA',16608,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40296,NULL,'West Burlington, IA 52655',16608,222,NULL,19,23395,0);
INSERT INTO "django_geo_db_location" VALUES(40297,NULL,'West Point, IA',16609,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40298,NULL,'West Point, IA 52656',16609,222,NULL,19,23396,0);
INSERT INTO "django_geo_db_location" VALUES(40299,NULL,'Saint Paul, IA',16610,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40300,NULL,'Saint Paul, IA 52657',16610,222,NULL,19,23397,0);
INSERT INTO "django_geo_db_location" VALUES(40301,NULL,'Wever, IA',16611,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40302,NULL,'Wever, IA 52658',16611,222,NULL,19,23398,0);
INSERT INTO "django_geo_db_location" VALUES(40303,NULL,'Winfield, IA',16612,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40304,NULL,'Winfield, IA 52659',16612,222,NULL,19,23399,0);
INSERT INTO "django_geo_db_location" VALUES(40305,NULL,'Yarmouth, IA',16613,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40306,NULL,'Yarmouth, IA 52660',16613,222,NULL,19,23400,0);
INSERT INTO "django_geo_db_location" VALUES(40307,NULL,'Andover, IA',16614,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40308,NULL,'Andover, IA 52701',16614,222,NULL,19,23401,0);
INSERT INTO "django_geo_db_location" VALUES(40309,NULL,'Blue Grass, IA',16615,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40310,NULL,'Blue Grass, IA 52706',16615,222,NULL,19,23402,0);
INSERT INTO "django_geo_db_location" VALUES(40311,NULL,'Atalissa, IA',16616,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40312,NULL,'Atalissa, IA 52720',16616,222,NULL,19,23403,0);
INSERT INTO "django_geo_db_location" VALUES(40313,NULL,'Bennett, IA',16617,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40314,NULL,'Bennett, IA 52721',16617,222,NULL,19,23404,0);
INSERT INTO "django_geo_db_location" VALUES(40315,NULL,'Bettendorf, IA',16618,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40316,NULL,'Bettendorf, IA 52722',16618,222,NULL,19,23405,0);
INSERT INTO "django_geo_db_location" VALUES(40317,NULL,'Blue Grass, IA 52726',16615,222,NULL,19,23406,0);
INSERT INTO "django_geo_db_location" VALUES(40318,NULL,'Bryant, IA',16619,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40319,NULL,'Bryant, IA 52727',16619,222,NULL,19,23407,0);
INSERT INTO "django_geo_db_location" VALUES(40320,NULL,'Buffalo, IA',16620,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40321,NULL,'Buffalo, IA 52728',16620,222,NULL,19,23408,0);
INSERT INTO "django_geo_db_location" VALUES(40322,NULL,'Calamus, IA',16621,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40323,NULL,'Calamus, IA 52729',16621,222,NULL,19,23409,0);
INSERT INTO "django_geo_db_location" VALUES(40324,NULL,'Camanche, IA',16622,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40325,NULL,'Camanche, IA 52730',16622,222,NULL,19,23410,0);
INSERT INTO "django_geo_db_location" VALUES(40326,NULL,'Charlotte, IA',16623,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40327,NULL,'Charlotte, IA 52731',16623,222,NULL,19,23411,0);
INSERT INTO "django_geo_db_location" VALUES(40328,NULL,'Clinton, IA',16624,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40329,NULL,'Clinton, IA 52732',16624,222,NULL,19,23412,0);
INSERT INTO "django_geo_db_location" VALUES(40330,NULL,'Clinton, IA 52733',16624,222,NULL,19,23413,0);
INSERT INTO "django_geo_db_location" VALUES(40331,NULL,'Clinton, IA 52736',16624,222,NULL,19,23414,0);
INSERT INTO "django_geo_db_location" VALUES(40332,NULL,'Columbus City, IA',16625,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40333,NULL,'Columbus City, IA 52737',16625,222,NULL,19,23415,0);
INSERT INTO "django_geo_db_location" VALUES(40334,NULL,'Columbus Junction, IA',16626,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40335,NULL,'Columbus Junction, IA 52738',16626,222,NULL,19,23416,0);
INSERT INTO "django_geo_db_location" VALUES(40336,NULL,'Conesville, IA',16627,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40337,NULL,'Conesville, IA 52739',16627,222,NULL,19,23417,0);
INSERT INTO "django_geo_db_location" VALUES(40338,NULL,'De Witt, IA',16628,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40339,NULL,'De Witt, IA 52742',16628,222,NULL,19,23418,0);
INSERT INTO "django_geo_db_location" VALUES(40340,NULL,'Dixon, IA',16629,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40341,NULL,'Dixon, IA 52745',16629,222,NULL,19,23419,0);
INSERT INTO "django_geo_db_location" VALUES(40342,NULL,'Donahue, IA',16630,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40343,NULL,'Donahue, IA 52746',16630,222,NULL,19,23420,0);
INSERT INTO "django_geo_db_location" VALUES(40344,NULL,'Durant, IA',16631,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40345,NULL,'Durant, IA 52747',16631,222,NULL,19,23421,0);
INSERT INTO "django_geo_db_location" VALUES(40346,NULL,'Eldridge, IA',16632,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40347,NULL,'Eldridge, IA 52748',16632,222,NULL,19,23422,0);
INSERT INTO "django_geo_db_location" VALUES(40348,NULL,'Fruitland, IA',16633,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40349,NULL,'Fruitland, IA 52749',16633,222,NULL,19,23423,0);
INSERT INTO "django_geo_db_location" VALUES(40350,NULL,'Goose Lake, IA',16634,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40351,NULL,'Goose Lake, IA 52750',16634,222,NULL,19,23424,0);
INSERT INTO "django_geo_db_location" VALUES(40352,NULL,'Grand Mound, IA',16635,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40353,NULL,'Grand Mound, IA 52751',16635,222,NULL,19,23425,0);
INSERT INTO "django_geo_db_location" VALUES(40354,NULL,'Grandview, IA',16636,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40355,NULL,'Grandview, IA 52752',16636,222,NULL,19,23426,0);
INSERT INTO "django_geo_db_location" VALUES(40356,NULL,'Le Claire, IA',16637,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40357,NULL,'Le Claire, IA 52753',16637,222,NULL,19,23427,0);
INSERT INTO "django_geo_db_location" VALUES(40358,NULL,'Letts, IA',16638,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40359,NULL,'Letts, IA 52754',16638,222,NULL,19,23428,0);
INSERT INTO "django_geo_db_location" VALUES(40360,NULL,'Lone Tree, IA',16639,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40361,NULL,'Lone Tree, IA 52755',16639,222,NULL,19,23429,0);
INSERT INTO "django_geo_db_location" VALUES(40362,NULL,'Long Grove, IA',16640,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40363,NULL,'Long Grove, IA 52756',16640,222,NULL,19,23430,0);
INSERT INTO "django_geo_db_location" VALUES(40364,NULL,'Low Moor, IA',16641,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40365,NULL,'Low Moor, IA 52757',16641,222,NULL,19,23431,0);
INSERT INTO "django_geo_db_location" VALUES(40366,NULL,'McCausland, IA',16642,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40367,NULL,'McCausland, IA 52758',16642,222,NULL,19,23432,0);
INSERT INTO "django_geo_db_location" VALUES(40368,NULL,'Montpelier, IA',16643,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40369,NULL,'Montpelier, IA 52759',16643,222,NULL,19,23433,0);
INSERT INTO "django_geo_db_location" VALUES(40370,NULL,'Moscow, IA',16644,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40371,NULL,'Moscow, IA 52760',16644,222,NULL,19,23434,0);
INSERT INTO "django_geo_db_location" VALUES(40372,NULL,'Muscatine, IL',16645,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40373,NULL,'Muscatine, IL 52761',16645,222,NULL,17,23435,0);
INSERT INTO "django_geo_db_location" VALUES(40374,NULL,'New Liberty, IA',16646,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40375,NULL,'New Liberty, IA 52765',16646,222,NULL,19,23436,0);
INSERT INTO "django_geo_db_location" VALUES(40376,NULL,'Nichols, IA',16647,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40377,NULL,'Nichols, IA 52766',16647,222,NULL,19,23437,0);
INSERT INTO "django_geo_db_location" VALUES(40378,NULL,'Pleasant Valley, IA',16648,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40379,NULL,'Pleasant Valley, IA 52767',16648,222,NULL,19,23438,0);
INSERT INTO "django_geo_db_location" VALUES(40380,NULL,'Princeton, IA',16649,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40381,NULL,'Princeton, IA 52768',16649,222,NULL,19,23439,0);
INSERT INTO "django_geo_db_location" VALUES(40382,NULL,'Stockton, IA',16650,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40383,NULL,'Stockton, IA 52769',16650,222,NULL,19,23440,0);
INSERT INTO "django_geo_db_location" VALUES(40384,NULL,'Teeds Grove, IA',16651,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40385,NULL,'Teeds Grove, IA 52771',16651,222,NULL,19,23441,0);
INSERT INTO "django_geo_db_location" VALUES(40386,NULL,'Tipton, IA',16652,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40387,NULL,'Tipton, IA 52772',16652,222,NULL,19,23442,0);
INSERT INTO "django_geo_db_location" VALUES(40388,NULL,'Walcott, IA',16653,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40389,NULL,'Walcott, IA 52773',16653,222,NULL,19,23443,0);
INSERT INTO "django_geo_db_location" VALUES(40390,NULL,'Welton, IA',16654,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40391,NULL,'Welton, IA 52774',16654,222,NULL,19,23444,0);
INSERT INTO "django_geo_db_location" VALUES(40392,NULL,'West Liberty, IA',16655,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40393,NULL,'West Liberty, IA 52776',16655,222,NULL,19,23445,0);
INSERT INTO "django_geo_db_location" VALUES(40394,NULL,'Wheatland, IA',16656,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40395,NULL,'Wheatland, IA 52777',16656,222,NULL,19,23446,0);
INSERT INTO "django_geo_db_location" VALUES(40396,NULL,'Wilton, IA',16657,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40397,NULL,'Wilton, IA 52778',16657,222,NULL,19,23447,0);
INSERT INTO "django_geo_db_location" VALUES(40398,NULL,'Davenport, IA',16658,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40399,NULL,'Davenport, IA 52801',16658,222,NULL,19,23448,0);
INSERT INTO "django_geo_db_location" VALUES(40400,NULL,'Davenport, IA 52802',16658,222,NULL,19,23449,0);
INSERT INTO "django_geo_db_location" VALUES(40401,NULL,'Davenport, IA 52803',16658,222,NULL,19,23450,0);
INSERT INTO "django_geo_db_location" VALUES(40402,NULL,'Davenport, IA 52804',16658,222,NULL,19,23451,0);
INSERT INTO "django_geo_db_location" VALUES(40403,NULL,'Davenport, IA 52805',16658,222,NULL,19,23452,0);
INSERT INTO "django_geo_db_location" VALUES(40404,NULL,'Davenport, IA 52806',16658,222,NULL,19,23453,0);
INSERT INTO "django_geo_db_location" VALUES(40405,NULL,'Davenport, IA 52807',16658,222,NULL,19,23454,0);
INSERT INTO "django_geo_db_location" VALUES(40406,NULL,'Davenport, IA 52808',16658,222,NULL,19,23455,0);
INSERT INTO "django_geo_db_location" VALUES(40407,NULL,'Davenport, IA 52809',16658,222,NULL,19,23456,0);
INSERT INTO "django_geo_db_location" VALUES(40408,NULL,'Tennyson, WI',16659,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40409,NULL,'Tennyson, WI 52820',16659,222,NULL,58,23457,0);
INSERT INTO "django_geo_db_location" VALUES(40410,NULL,'Adell, WI',16660,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40411,NULL,'Adell, WI 53001',16660,222,NULL,58,23458,0);
INSERT INTO "django_geo_db_location" VALUES(40412,NULL,'Allenton, WI',16661,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40413,NULL,'Allenton, WI 53002',16661,222,NULL,58,23459,0);
INSERT INTO "django_geo_db_location" VALUES(40414,NULL,'Ashippun, WI',16662,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40415,NULL,'Ashippun, WI 53003',16662,222,NULL,58,23460,0);
INSERT INTO "django_geo_db_location" VALUES(40416,NULL,'Belgium, WI',16663,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40417,NULL,'Belgium, WI 53004',16663,222,NULL,58,23461,0);
INSERT INTO "django_geo_db_location" VALUES(40418,NULL,'Brookfield, WI',16664,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40419,NULL,'Brookfield, WI 53005',16664,222,NULL,58,23462,0);
INSERT INTO "django_geo_db_location" VALUES(40420,NULL,'Brownsville, WI',16665,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40421,NULL,'Brownsville, WI 53006',16665,222,NULL,58,23463,0);
INSERT INTO "django_geo_db_location" VALUES(40422,NULL,'Butler, WI',16666,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40423,NULL,'Butler, WI 53007',16666,222,NULL,58,23464,0);
INSERT INTO "django_geo_db_location" VALUES(40424,NULL,'Brookfield, WI 53008',16664,222,NULL,58,23465,0);
INSERT INTO "django_geo_db_location" VALUES(40425,NULL,'Byron, WI',16667,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40426,NULL,'Byron, WI 53009',16667,222,NULL,58,23466,0);
INSERT INTO "django_geo_db_location" VALUES(40427,NULL,'Campbellsport, WI',16668,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40428,NULL,'Campbellsport, WI 53010',16668,222,NULL,58,23467,0);
INSERT INTO "django_geo_db_location" VALUES(40429,NULL,'Cascade, WI',16669,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40430,NULL,'Cascade, WI 53011',16669,222,NULL,58,23468,0);
INSERT INTO "django_geo_db_location" VALUES(40431,NULL,'Cedarburg, WI',16670,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40432,NULL,'Cedarburg, WI 53012',16670,222,NULL,58,23469,0);
INSERT INTO "django_geo_db_location" VALUES(40433,NULL,'Cedar Grove, WI',16671,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40434,NULL,'Cedar Grove, WI 53013',16671,222,NULL,58,23470,0);
INSERT INTO "django_geo_db_location" VALUES(40435,NULL,'Chilton, WI',16672,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40436,NULL,'Chilton, WI 53014',16672,222,NULL,58,23471,0);
INSERT INTO "django_geo_db_location" VALUES(40437,NULL,'Cleveland, WI',16673,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40438,NULL,'Cleveland, WI 53015',16673,222,NULL,58,23472,0);
INSERT INTO "django_geo_db_location" VALUES(40439,NULL,'Clyman, WI',16674,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40440,NULL,'Clyman, WI 53016',16674,222,NULL,58,23473,0);
INSERT INTO "django_geo_db_location" VALUES(40441,NULL,'Colgate, WI',16675,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40442,NULL,'Colgate, WI 53017',16675,222,NULL,58,23474,0);
INSERT INTO "django_geo_db_location" VALUES(40443,NULL,'Delafield, WI',16676,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40444,NULL,'Delafield, WI 53018',16676,222,NULL,58,23475,0);
INSERT INTO "django_geo_db_location" VALUES(40445,NULL,'Eden, WI',16677,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40446,NULL,'Eden, WI 53019',16677,222,NULL,58,23476,0);
INSERT INTO "django_geo_db_location" VALUES(40447,NULL,'Elkhart Lake, WI',16678,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40448,NULL,'Elkhart Lake, WI 53020',16678,222,NULL,58,23477,0);
INSERT INTO "django_geo_db_location" VALUES(40449,NULL,'Fredonia, WI',16679,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40450,NULL,'Fredonia, WI 53021',16679,222,NULL,58,23478,0);
INSERT INTO "django_geo_db_location" VALUES(40451,NULL,'Germantown, WI',16680,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40452,NULL,'Germantown, WI 53022',16680,222,NULL,58,23479,0);
INSERT INTO "django_geo_db_location" VALUES(40453,NULL,'Glenbeulah, WI',16681,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40454,NULL,'Glenbeulah, WI 53023',16681,222,NULL,58,23480,0);
INSERT INTO "django_geo_db_location" VALUES(40455,NULL,'Grafton, WI',16682,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40456,NULL,'Grafton, WI 53024',16682,222,NULL,58,23481,0);
INSERT INTO "django_geo_db_location" VALUES(40457,NULL,'Greenbush, WI',16683,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40458,NULL,'Greenbush, WI 53026',16683,222,NULL,58,23482,0);
INSERT INTO "django_geo_db_location" VALUES(40459,NULL,'Hartford, WI',16684,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40460,NULL,'Hartford, WI 53027',16684,222,NULL,58,23483,0);
INSERT INTO "django_geo_db_location" VALUES(40461,NULL,'Hartland, WI',16685,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40462,NULL,'Hartland, WI 53029',16685,222,NULL,58,23484,0);
INSERT INTO "django_geo_db_location" VALUES(40463,NULL,'Hingham, WI',16686,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40464,NULL,'Hingham, WI 53031',16686,222,NULL,58,23485,0);
INSERT INTO "django_geo_db_location" VALUES(40465,NULL,'Horicon, WI',16687,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40466,NULL,'Horicon, WI 53032',16687,222,NULL,58,23486,0);
INSERT INTO "django_geo_db_location" VALUES(40467,NULL,'Hubertus, WI',16688,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40468,NULL,'Hubertus, WI 53033',16688,222,NULL,58,23487,0);
INSERT INTO "django_geo_db_location" VALUES(40469,NULL,'Hustisford, WI',16689,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40470,NULL,'Hustisford, WI 53034',16689,222,NULL,58,23488,0);
INSERT INTO "django_geo_db_location" VALUES(40471,NULL,'Iron Ridge, WI',16690,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40472,NULL,'Iron Ridge, WI 53035',16690,222,NULL,58,23489,0);
INSERT INTO "django_geo_db_location" VALUES(40473,NULL,'Ixonia, WI',16691,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40474,NULL,'Ixonia, WI 53036',16691,222,NULL,58,23490,0);
INSERT INTO "django_geo_db_location" VALUES(40475,NULL,'Jackson, WI',16692,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40476,NULL,'Jackson, WI 53037',16692,222,NULL,58,23491,0);
INSERT INTO "django_geo_db_location" VALUES(40477,NULL,'Johnson Creek, WI',16693,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40478,NULL,'Johnson Creek, WI 53038',16693,222,NULL,58,23492,0);
INSERT INTO "django_geo_db_location" VALUES(40479,NULL,'Juneau, WI',16694,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40480,NULL,'Juneau, WI 53039',16694,222,NULL,58,23493,0);
INSERT INTO "django_geo_db_location" VALUES(40481,NULL,'Kewaskum, WI',16695,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40482,NULL,'Kewaskum, WI 53040',16695,222,NULL,58,23494,0);
INSERT INTO "django_geo_db_location" VALUES(40483,NULL,'Kiel, WI',16696,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40484,NULL,'Kiel, WI 53042',16696,222,NULL,58,23495,0);
INSERT INTO "django_geo_db_location" VALUES(40485,NULL,'Kohler, WI',16697,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40486,NULL,'Kohler, WI 53044',16697,222,NULL,58,23496,0);
INSERT INTO "django_geo_db_location" VALUES(40487,NULL,'Brookfield, WI 53045',16664,222,NULL,58,23497,0);
INSERT INTO "django_geo_db_location" VALUES(40488,NULL,'Lannon, WI',16698,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40489,NULL,'Lannon, WI 53046',16698,222,NULL,58,23498,0);
INSERT INTO "django_geo_db_location" VALUES(40490,NULL,'Lebanon, WI',16699,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40491,NULL,'Lebanon, WI 53047',16699,222,NULL,58,23499,0);
INSERT INTO "django_geo_db_location" VALUES(40492,NULL,'Lomira, WI',16700,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40493,NULL,'Lomira, WI 53048',16700,222,NULL,58,23500,0);
INSERT INTO "django_geo_db_location" VALUES(40494,NULL,'Malone, WI',16701,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40495,NULL,'Malone, WI 53049',16701,222,NULL,58,23501,0);
INSERT INTO "django_geo_db_location" VALUES(40496,NULL,'Mayville, WI',16702,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40497,NULL,'Mayville, WI 53050',16702,222,NULL,58,23502,0);
INSERT INTO "django_geo_db_location" VALUES(40498,NULL,'Menomonee Falls, WI',16703,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40499,NULL,'Menomonee Falls, WI 53051',16703,222,NULL,58,23503,0);
INSERT INTO "django_geo_db_location" VALUES(40500,NULL,'Menomonee Falls, WI 53052',16703,222,NULL,58,23504,0);
INSERT INTO "django_geo_db_location" VALUES(40501,NULL,'Merton, WI',16704,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40502,NULL,'Merton, WI 53056',16704,222,NULL,58,23505,0);
INSERT INTO "django_geo_db_location" VALUES(40503,NULL,'Mount Calvary, WI',16705,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40504,NULL,'Mount Calvary, WI 53057',16705,222,NULL,58,23506,0);
INSERT INTO "django_geo_db_location" VALUES(40505,NULL,'Nashotah, WI',16706,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40506,NULL,'Nashotah, WI 53058',16706,222,NULL,58,23507,0);
INSERT INTO "django_geo_db_location" VALUES(40507,NULL,'Neosho, WI',16707,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40508,NULL,'Neosho, WI 53059',16707,222,NULL,58,23508,0);
INSERT INTO "django_geo_db_location" VALUES(40509,NULL,'Newburg, WI',16708,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40510,NULL,'Newburg, WI 53060',16708,222,NULL,58,23509,0);
INSERT INTO "django_geo_db_location" VALUES(40511,NULL,'New Holstein, WI',16709,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40512,NULL,'New Holstein, WI 53061',16709,222,NULL,58,23510,0);
INSERT INTO "django_geo_db_location" VALUES(40513,NULL,'New Holstein, WI 53062',16709,222,NULL,58,23511,0);
INSERT INTO "django_geo_db_location" VALUES(40514,NULL,'Newton, WI',16710,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40515,NULL,'Newton, WI 53063',16710,222,NULL,58,23512,0);
INSERT INTO "django_geo_db_location" VALUES(40516,NULL,'North Lake, WI',16711,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40517,NULL,'North Lake, WI 53064',16711,222,NULL,58,23513,0);
INSERT INTO "django_geo_db_location" VALUES(40518,NULL,'Oakfield, WI',16712,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40519,NULL,'Oakfield, WI 53065',16712,222,NULL,58,23514,0);
INSERT INTO "django_geo_db_location" VALUES(40520,NULL,'Oconomowoc, WI',16713,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40521,NULL,'Oconomowoc, WI 53066',16713,222,NULL,58,23515,0);
INSERT INTO "django_geo_db_location" VALUES(40522,NULL,'Okauchee, WI',16714,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40523,NULL,'Okauchee, WI 53069',16714,222,NULL,58,23516,0);
INSERT INTO "django_geo_db_location" VALUES(40524,NULL,'Oostburg, WI',16715,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40525,NULL,'Oostburg, WI 53070',16715,222,NULL,58,23517,0);
INSERT INTO "django_geo_db_location" VALUES(40526,NULL,'Pewaukee, WI',16716,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40527,NULL,'Pewaukee, WI 53072',16716,222,NULL,58,23518,0);
INSERT INTO "django_geo_db_location" VALUES(40528,NULL,'Plymouth, WI',16717,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40529,NULL,'Plymouth, WI 53073',16717,222,NULL,58,23519,0);
INSERT INTO "django_geo_db_location" VALUES(40530,NULL,'Port Washington, WI',16718,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40531,NULL,'Port Washington, WI 53074',16718,222,NULL,58,23520,0);
INSERT INTO "django_geo_db_location" VALUES(40532,NULL,'Random Lake, WI',16719,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40533,NULL,'Random Lake, WI 53075',16719,222,NULL,58,23521,0);
INSERT INTO "django_geo_db_location" VALUES(40534,NULL,'Richfield, WI',16720,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40535,NULL,'Richfield, WI 53076',16720,222,NULL,58,23522,0);
INSERT INTO "django_geo_db_location" VALUES(40536,NULL,'Rubicon, WI',16721,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40537,NULL,'Rubicon, WI 53078',16721,222,NULL,58,23523,0);
INSERT INTO "django_geo_db_location" VALUES(40538,NULL,'Saint Cloud, WI',16722,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40539,NULL,'Saint Cloud, WI 53079',16722,222,NULL,58,23524,0);
INSERT INTO "django_geo_db_location" VALUES(40540,NULL,'Saukville, WI',16723,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40541,NULL,'Saukville, WI 53080',16723,222,NULL,58,23525,0);
INSERT INTO "django_geo_db_location" VALUES(40542,NULL,'Sheboygan, WI',16724,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40543,NULL,'Sheboygan, WI 53081',16724,222,NULL,58,23526,0);
INSERT INTO "django_geo_db_location" VALUES(40544,NULL,'Sheboygan, WI 53082',16724,222,NULL,58,23527,0);
INSERT INTO "django_geo_db_location" VALUES(40545,NULL,'Sheboygan, WI 53083',16724,222,NULL,58,23528,0);
INSERT INTO "django_geo_db_location" VALUES(40546,NULL,'Sheboygan Falls, WI',16725,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40547,NULL,'Sheboygan Falls, WI 53085',16725,222,NULL,58,23529,0);
INSERT INTO "django_geo_db_location" VALUES(40548,NULL,'Slinger, WI',16726,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40549,NULL,'Slinger, WI 53086',16726,222,NULL,58,23530,0);
INSERT INTO "django_geo_db_location" VALUES(40550,NULL,'Stockbridge, WI',16727,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40551,NULL,'Stockbridge, WI 53088',16727,222,NULL,58,23531,0);
INSERT INTO "django_geo_db_location" VALUES(40552,NULL,'Sussex, WI',16728,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40553,NULL,'Sussex, WI 53089',16728,222,NULL,58,23532,0);
INSERT INTO "django_geo_db_location" VALUES(40554,NULL,'West Bend, WI',16729,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40555,NULL,'West Bend, WI 53090',16729,222,NULL,58,23533,0);
INSERT INTO "django_geo_db_location" VALUES(40556,NULL,'Theresa, WI',16730,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40557,NULL,'Theresa, WI 53091',16730,222,NULL,58,23534,0);
INSERT INTO "django_geo_db_location" VALUES(40558,NULL,'Thiensville, WI',16731,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40559,NULL,'Thiensville, WI 53092',16731,222,NULL,58,23535,0);
INSERT INTO "django_geo_db_location" VALUES(40560,NULL,'Waldo, WI',16732,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40561,NULL,'Waldo, WI 53093',16732,222,NULL,58,23536,0);
INSERT INTO "django_geo_db_location" VALUES(40562,NULL,'Watertown, WI',16733,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40563,NULL,'Watertown, WI 53094',16733,222,NULL,58,23537,0);
INSERT INTO "django_geo_db_location" VALUES(40564,NULL,'West Bend, WI 53095',16729,222,NULL,58,23538,0);
INSERT INTO "django_geo_db_location" VALUES(40565,NULL,'Mequon, WI',16734,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40566,NULL,'Mequon, WI 53097',16734,222,NULL,58,23539,0);
INSERT INTO "django_geo_db_location" VALUES(40567,NULL,'Watertown, WI 53098',16733,222,NULL,58,23540,0);
INSERT INTO "django_geo_db_location" VALUES(40568,NULL,'Woodland, WI',16735,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40569,NULL,'Woodland, WI 53099',16735,222,NULL,58,23541,0);
INSERT INTO "django_geo_db_location" VALUES(40570,NULL,'Bassett, WI',16736,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40571,NULL,'Bassett, WI 53101',16736,222,NULL,58,23542,0);
INSERT INTO "django_geo_db_location" VALUES(40572,NULL,'Benet Lake, WI',16737,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40573,NULL,'Benet Lake, WI 53102',16737,222,NULL,58,23543,0);
INSERT INTO "django_geo_db_location" VALUES(40574,NULL,'Big Bend, WI',16738,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40575,NULL,'Big Bend, WI 53103',16738,222,NULL,58,23544,0);
INSERT INTO "django_geo_db_location" VALUES(40576,NULL,'Bristol, WI',16739,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40577,NULL,'Bristol, WI 53104',16739,222,NULL,58,23545,0);
INSERT INTO "django_geo_db_location" VALUES(40578,NULL,'Burlington, WI',16740,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40579,NULL,'Burlington, WI 53105',16740,222,NULL,58,23546,0);
INSERT INTO "django_geo_db_location" VALUES(40580,NULL,'Caledonia, WI',16741,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40581,NULL,'Caledonia, WI 53108',16741,222,NULL,58,23547,0);
INSERT INTO "django_geo_db_location" VALUES(40582,NULL,'Camp Lake, WI',16742,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40583,NULL,'Camp Lake, WI 53109',16742,222,NULL,58,23548,0);
INSERT INTO "django_geo_db_location" VALUES(40584,NULL,'Cudahy, WI',16743,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40585,NULL,'Cudahy, WI 53110',16743,222,NULL,58,23549,0);
INSERT INTO "django_geo_db_location" VALUES(40586,NULL,'Darien, WI',16744,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40587,NULL,'Darien, WI 53114',16744,222,NULL,58,23550,0);
INSERT INTO "django_geo_db_location" VALUES(40588,NULL,'Delavan, WI',16745,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40589,NULL,'Delavan, WI 53115',16745,222,NULL,58,23551,0);
INSERT INTO "django_geo_db_location" VALUES(40590,NULL,'Dousman, WI',16746,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40591,NULL,'Dousman, WI 53118',16746,222,NULL,58,23552,0);
INSERT INTO "django_geo_db_location" VALUES(40592,NULL,'Eagle, WI',16747,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40593,NULL,'Eagle, WI 53119',16747,222,NULL,58,23553,0);
INSERT INTO "django_geo_db_location" VALUES(40594,NULL,'East Troy, WI',16748,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40595,NULL,'East Troy, WI 53120',16748,222,NULL,58,23554,0);
INSERT INTO "django_geo_db_location" VALUES(40596,NULL,'Elkhorn, WI',16749,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40597,NULL,'Elkhorn, WI 53121',16749,222,NULL,58,23555,0);
INSERT INTO "django_geo_db_location" VALUES(40598,NULL,'Elm Grove, WI',16750,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40599,NULL,'Elm Grove, WI 53122',16750,222,NULL,58,23556,0);
INSERT INTO "django_geo_db_location" VALUES(40600,NULL,'Fontana, WI',16751,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40601,NULL,'Fontana, WI 53125',16751,222,NULL,58,23557,0);
INSERT INTO "django_geo_db_location" VALUES(40602,NULL,'Franksville, WI',16752,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40603,NULL,'Franksville, WI 53126',16752,222,NULL,58,23558,0);
INSERT INTO "django_geo_db_location" VALUES(40604,NULL,'Genesee Depot, WI',16753,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40605,NULL,'Genesee Depot, WI 53127',16753,222,NULL,58,23559,0);
INSERT INTO "django_geo_db_location" VALUES(40606,NULL,'Genoa City, WI',16754,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40607,NULL,'Genoa City, WI 53128',16754,222,NULL,58,23560,0);
INSERT INTO "django_geo_db_location" VALUES(40608,NULL,'Greendale, WI',16755,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40609,NULL,'Greendale, WI 53129',16755,222,NULL,58,23561,0);
INSERT INTO "django_geo_db_location" VALUES(40610,NULL,'Hales Corners, WI',16756,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40611,NULL,'Hales Corners, WI 53130',16756,222,NULL,58,23562,0);
INSERT INTO "django_geo_db_location" VALUES(40612,NULL,'Franklin, WI',16757,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40613,NULL,'Franklin, WI 53132',16757,222,NULL,58,23563,0);
INSERT INTO "django_geo_db_location" VALUES(40614,NULL,'Walworth, WI',16758,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40615,NULL,'Walworth, WI 53134',16758,222,NULL,58,23564,0);
INSERT INTO "django_geo_db_location" VALUES(40616,NULL,'Helenville, WI',16759,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40617,NULL,'Helenville, WI 53137',16759,222,NULL,58,23565,0);
INSERT INTO "django_geo_db_location" VALUES(40618,NULL,'Honey Creek, WI',16760,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40619,NULL,'Honey Creek, WI 53138',16760,222,NULL,58,23566,0);
INSERT INTO "django_geo_db_location" VALUES(40620,NULL,'Kansasville, WI',16761,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40621,NULL,'Kansasville, WI 53139',16761,222,NULL,58,23567,0);
INSERT INTO "django_geo_db_location" VALUES(40622,NULL,'Kenosha, WI',16762,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40623,NULL,'Kenosha, WI 53140',16762,222,NULL,58,23568,0);
INSERT INTO "django_geo_db_location" VALUES(40624,NULL,'Kenosha, WI 53141',16762,222,NULL,58,23569,0);
INSERT INTO "django_geo_db_location" VALUES(40625,NULL,'Kenosha, WI 53142',16762,222,NULL,58,23570,0);
INSERT INTO "django_geo_db_location" VALUES(40626,NULL,'Kenosha, WI 53143',16762,222,NULL,58,23571,0);
INSERT INTO "django_geo_db_location" VALUES(40627,NULL,'Kenosha, WI 53144',16762,222,NULL,58,23572,0);
INSERT INTO "django_geo_db_location" VALUES(40628,NULL,'New Berlin, WI',16763,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40629,NULL,'New Berlin, WI 53146',16763,222,NULL,58,23573,0);
INSERT INTO "django_geo_db_location" VALUES(40630,NULL,'Lake Geneva, WI',16764,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40631,NULL,'Lake Geneva, WI 53147',16764,222,NULL,58,23574,0);
INSERT INTO "django_geo_db_location" VALUES(40632,NULL,'Lyons, WI',16765,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40633,NULL,'Lyons, WI 53148',16765,222,NULL,58,23575,0);
INSERT INTO "django_geo_db_location" VALUES(40634,NULL,'Mukwonago, WI',16766,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40635,NULL,'Mukwonago, WI 53149',16766,222,NULL,58,23576,0);
INSERT INTO "django_geo_db_location" VALUES(40636,NULL,'Muskego, WI',16767,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40637,NULL,'Muskego, WI 53150',16767,222,NULL,58,23577,0);
INSERT INTO "django_geo_db_location" VALUES(40638,NULL,'New Berlin, WI 53151',16763,222,NULL,58,23578,0);
INSERT INTO "django_geo_db_location" VALUES(40639,NULL,'New Munster, WI',16768,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40640,NULL,'New Munster, WI 53152',16768,222,NULL,58,23579,0);
INSERT INTO "django_geo_db_location" VALUES(40641,NULL,'North Prairie, WI',16769,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40642,NULL,'North Prairie, WI 53153',16769,222,NULL,58,23580,0);
INSERT INTO "django_geo_db_location" VALUES(40643,NULL,'Oak Creek, WI',16770,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40644,NULL,'Oak Creek, WI 53154',16770,222,NULL,58,23581,0);
INSERT INTO "django_geo_db_location" VALUES(40645,NULL,'Palmyra, WI',16771,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40646,NULL,'Palmyra, WI 53156',16771,222,NULL,58,23582,0);
INSERT INTO "django_geo_db_location" VALUES(40647,NULL,'Pell Lake, WI',16772,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40648,NULL,'Pell Lake, WI 53157',16772,222,NULL,58,23583,0);
INSERT INTO "django_geo_db_location" VALUES(40649,NULL,'Pleasant Prairie, WI',16773,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40650,NULL,'Pleasant Prairie, WI 53158',16773,222,NULL,58,23584,0);
INSERT INTO "django_geo_db_location" VALUES(40651,NULL,'Powers Lake, WI',16774,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40652,NULL,'Powers Lake, WI 53159',16774,222,NULL,58,23585,0);
INSERT INTO "django_geo_db_location" VALUES(40653,NULL,'Rochester, WI',16775,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40654,NULL,'Rochester, WI 53167',16775,222,NULL,58,23586,0);
INSERT INTO "django_geo_db_location" VALUES(40655,NULL,'Salem, WI',16776,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40656,NULL,'Salem, WI 53168',16776,222,NULL,58,23587,0);
INSERT INTO "django_geo_db_location" VALUES(40657,NULL,'Silver Lake, WI',16777,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40658,NULL,'Silver Lake, WI 53170',16777,222,NULL,58,23588,0);
INSERT INTO "django_geo_db_location" VALUES(40659,NULL,'Somers, WI',16778,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40660,NULL,'Somers, WI 53171',16778,222,NULL,58,23589,0);
INSERT INTO "django_geo_db_location" VALUES(40661,NULL,'South Milwaukee, WI',16779,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40662,NULL,'South Milwaukee, WI 53172',16779,222,NULL,58,23590,0);
INSERT INTO "django_geo_db_location" VALUES(40663,NULL,'Springfield, WI',16780,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40664,NULL,'Springfield, WI 53176',16780,222,NULL,58,23591,0);
INSERT INTO "django_geo_db_location" VALUES(40665,NULL,'Sturtevant, WI',16781,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40666,NULL,'Sturtevant, WI 53177',16781,222,NULL,58,23592,0);
INSERT INTO "django_geo_db_location" VALUES(40667,NULL,'Sullivan, WI',16782,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40668,NULL,'Sullivan, WI 53178',16782,222,NULL,58,23593,0);
INSERT INTO "django_geo_db_location" VALUES(40669,NULL,'Trevor, WI',16783,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40670,NULL,'Trevor, WI 53179',16783,222,NULL,58,23594,0);
INSERT INTO "django_geo_db_location" VALUES(40671,NULL,'Twin Lakes, WI',16784,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40672,NULL,'Twin Lakes, WI 53181',16784,222,NULL,58,23595,0);
INSERT INTO "django_geo_db_location" VALUES(40673,NULL,'Union Grove, WI',16785,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40674,NULL,'Union Grove, WI 53182',16785,222,NULL,58,23596,0);
INSERT INTO "django_geo_db_location" VALUES(40675,NULL,'Wales, WI',16786,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40676,NULL,'Wales, WI 53183',16786,222,NULL,58,23597,0);
INSERT INTO "django_geo_db_location" VALUES(40677,NULL,'Walworth, WI 53184',16758,222,NULL,58,23598,0);
INSERT INTO "django_geo_db_location" VALUES(40678,NULL,'Waterford, WI',16787,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40679,NULL,'Waterford, WI 53185',16787,222,NULL,58,23599,0);
INSERT INTO "django_geo_db_location" VALUES(40680,NULL,'Waukesha, WI',16788,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40681,NULL,'Waukesha, WI 53186',16788,222,NULL,58,23600,0);
INSERT INTO "django_geo_db_location" VALUES(40682,NULL,'Waukesha, WI 53187',16788,222,NULL,58,23601,0);
INSERT INTO "django_geo_db_location" VALUES(40683,NULL,'Waukesha, WI 53188',16788,222,NULL,58,23602,0);
INSERT INTO "django_geo_db_location" VALUES(40684,NULL,'Waukesha, WI 53189',16788,222,NULL,58,23603,0);
INSERT INTO "django_geo_db_location" VALUES(40685,NULL,'Whitewater, WI',16789,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40686,NULL,'Whitewater, WI 53190',16789,222,NULL,58,23604,0);
INSERT INTO "django_geo_db_location" VALUES(40687,NULL,'Williams Bay, WI',16790,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40688,NULL,'Williams Bay, WI 53191',16790,222,NULL,58,23605,0);
INSERT INTO "django_geo_db_location" VALUES(40689,NULL,'Wilmot, WI',16791,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40690,NULL,'Wilmot, WI 53192',16791,222,NULL,58,23606,0);
INSERT INTO "django_geo_db_location" VALUES(40691,NULL,'Woodworth, WI',16792,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40692,NULL,'Woodworth, WI 53194',16792,222,NULL,58,23607,0);
INSERT INTO "django_geo_db_location" VALUES(40693,NULL,'Zenda, WI',16793,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40694,NULL,'Zenda, WI 53195',16793,222,NULL,58,23608,0);
INSERT INTO "django_geo_db_location" VALUES(40695,NULL,'Walworth, WI 53197',16758,222,NULL,58,23609,0);
INSERT INTO "django_geo_db_location" VALUES(40696,NULL,'Milwaukee, WI',16794,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40697,NULL,'Milwaukee, WI 53201',16794,222,NULL,58,23610,0);
INSERT INTO "django_geo_db_location" VALUES(40698,NULL,'Milwaukee, WI 53202',16794,222,NULL,58,23611,0);
INSERT INTO "django_geo_db_location" VALUES(40699,NULL,'Milwaukee, WI 53203',16794,222,NULL,58,23612,0);
INSERT INTO "django_geo_db_location" VALUES(40700,NULL,'Milwaukee, WI 53204',16794,222,NULL,58,23613,0);
INSERT INTO "django_geo_db_location" VALUES(40701,NULL,'Milwaukee, WI 53205',16794,222,NULL,58,23614,0);
INSERT INTO "django_geo_db_location" VALUES(40702,NULL,'Milwaukee, WI 53206',16794,222,NULL,58,23615,0);
INSERT INTO "django_geo_db_location" VALUES(40703,NULL,'Milwaukee, WI 53207',16794,222,NULL,58,23616,0);
INSERT INTO "django_geo_db_location" VALUES(40704,NULL,'Milwaukee, WI 53208',16794,222,NULL,58,23617,0);
INSERT INTO "django_geo_db_location" VALUES(40705,NULL,'Milwaukee, WI 53209',16794,222,NULL,58,23618,0);
INSERT INTO "django_geo_db_location" VALUES(40706,NULL,'Milwaukee, WI 53210',16794,222,NULL,58,23619,0);
INSERT INTO "django_geo_db_location" VALUES(40707,NULL,'Milwaukee, WI 53211',16794,222,NULL,58,23620,0);
INSERT INTO "django_geo_db_location" VALUES(40708,NULL,'Milwaukee, WI 53212',16794,222,NULL,58,23621,0);
INSERT INTO "django_geo_db_location" VALUES(40709,NULL,'Milwaukee, WI 53213',16794,222,NULL,58,23622,0);
INSERT INTO "django_geo_db_location" VALUES(40710,NULL,'Milwaukee, WI 53214',16794,222,NULL,58,23623,0);
INSERT INTO "django_geo_db_location" VALUES(40711,NULL,'Milwaukee, WI 53215',16794,222,NULL,58,23624,0);
INSERT INTO "django_geo_db_location" VALUES(40712,NULL,'Milwaukee, WI 53216',16794,222,NULL,58,23625,0);
INSERT INTO "django_geo_db_location" VALUES(40713,NULL,'Milwaukee, WI 53217',16794,222,NULL,58,23626,0);
INSERT INTO "django_geo_db_location" VALUES(40714,NULL,'Milwaukee, WI 53218',16794,222,NULL,58,23627,0);
INSERT INTO "django_geo_db_location" VALUES(40715,NULL,'Milwaukee, WI 53219',16794,222,NULL,58,23628,0);
INSERT INTO "django_geo_db_location" VALUES(40716,NULL,'Milwaukee, WI 53220',16794,222,NULL,58,23629,0);
INSERT INTO "django_geo_db_location" VALUES(40717,NULL,'Milwaukee, WI 53221',16794,222,NULL,58,23630,0);
INSERT INTO "django_geo_db_location" VALUES(40718,NULL,'Milwaukee, WI 53222',16794,222,NULL,58,23631,0);
INSERT INTO "django_geo_db_location" VALUES(40719,NULL,'Milwaukee, WI 53223',16794,222,NULL,58,23632,0);
INSERT INTO "django_geo_db_location" VALUES(40720,NULL,'Milwaukee, WI 53224',16794,222,NULL,58,23633,0);
INSERT INTO "django_geo_db_location" VALUES(40721,NULL,'Milwaukee, WI 53225',16794,222,NULL,58,23634,0);
INSERT INTO "django_geo_db_location" VALUES(40722,NULL,'Milwaukee, WI 53226',16794,222,NULL,58,23635,0);
INSERT INTO "django_geo_db_location" VALUES(40723,NULL,'Milwaukee, WI 53227',16794,222,NULL,58,23636,0);
INSERT INTO "django_geo_db_location" VALUES(40724,NULL,'Milwaukee, WI 53228',16794,222,NULL,58,23637,0);
INSERT INTO "django_geo_db_location" VALUES(40725,NULL,'Milwaukee, WI 53233',16794,222,NULL,58,23638,0);
INSERT INTO "django_geo_db_location" VALUES(40726,NULL,'Milwaukee, WI 53234',16794,222,NULL,58,23639,0);
INSERT INTO "django_geo_db_location" VALUES(40727,NULL,'Saint Francis, WI',16795,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40728,NULL,'Saint Francis, WI 53235',16795,222,NULL,58,23640,0);
INSERT INTO "django_geo_db_location" VALUES(40729,NULL,'Milwaukee, WI 53237',16794,222,NULL,58,23641,0);
INSERT INTO "django_geo_db_location" VALUES(40730,NULL,'Eaton, WI',16796,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40731,NULL,'Eaton, WI 53245',16796,222,NULL,58,23642,0);
INSERT INTO "django_geo_db_location" VALUES(40732,NULL,'Milwaukee, WI 53259',16794,222,NULL,58,23643,0);
INSERT INTO "django_geo_db_location" VALUES(40733,NULL,'Milwaukee, WI 53263',16794,222,NULL,58,23644,0);
INSERT INTO "django_geo_db_location" VALUES(40734,NULL,'Milwaukee, WI 53267',16794,222,NULL,58,23645,0);
INSERT INTO "django_geo_db_location" VALUES(40735,NULL,'Milwaukee, WI 53268',16794,222,NULL,58,23646,0);
INSERT INTO "django_geo_db_location" VALUES(40736,NULL,'Milwaukee, WI 53270',16794,222,NULL,58,23647,0);
INSERT INTO "django_geo_db_location" VALUES(40737,NULL,'Milwaukee, WI 53274',16794,222,NULL,58,23648,0);
INSERT INTO "django_geo_db_location" VALUES(40738,NULL,'Milwaukee, WI 53277',16794,222,NULL,58,23649,0);
INSERT INTO "django_geo_db_location" VALUES(40739,NULL,'Milwaukee, WI 53278',16794,222,NULL,58,23650,0);
INSERT INTO "django_geo_db_location" VALUES(40740,NULL,'Milwaukee, WI 53280',16794,222,NULL,58,23651,0);
INSERT INTO "django_geo_db_location" VALUES(40741,NULL,'Milwaukee, WI 53281',16794,222,NULL,58,23652,0);
INSERT INTO "django_geo_db_location" VALUES(40742,NULL,'Milwaukee, WI 53284',16794,222,NULL,58,23653,0);
INSERT INTO "django_geo_db_location" VALUES(40743,NULL,'Milwaukee, WI 53285',16794,222,NULL,58,23654,0);
INSERT INTO "django_geo_db_location" VALUES(40744,NULL,'Milwaukee, WI 53288',16794,222,NULL,58,23655,0);
INSERT INTO "django_geo_db_location" VALUES(40745,NULL,'Milwaukee, WI 53290',16794,222,NULL,58,23656,0);
INSERT INTO "django_geo_db_location" VALUES(40746,NULL,'Milwaukee, WI 53293',16794,222,NULL,58,23657,0);
INSERT INTO "django_geo_db_location" VALUES(40747,NULL,'Milwaukee, WI 53295',16794,222,NULL,58,23658,0);
INSERT INTO "django_geo_db_location" VALUES(40748,NULL,'Racine, WI',16797,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40749,NULL,'Racine, WI 53401',16797,222,NULL,58,23659,0);
INSERT INTO "django_geo_db_location" VALUES(40750,NULL,'Racine, WI 53402',16797,222,NULL,58,23660,0);
INSERT INTO "django_geo_db_location" VALUES(40751,NULL,'Racine, WI 53403',16797,222,NULL,58,23661,0);
INSERT INTO "django_geo_db_location" VALUES(40752,NULL,'Racine, WI 53404',16797,222,NULL,58,23662,0);
INSERT INTO "django_geo_db_location" VALUES(40753,NULL,'Racine, WI 53405',16797,222,NULL,58,23663,0);
INSERT INTO "django_geo_db_location" VALUES(40754,NULL,'Racine, WI 53406',16797,222,NULL,58,23664,0);
INSERT INTO "django_geo_db_location" VALUES(40755,NULL,'Racine, WI 53407',16797,222,NULL,58,23665,0);
INSERT INTO "django_geo_db_location" VALUES(40756,NULL,'Racine, WI 53408',16797,222,NULL,58,23666,0);
INSERT INTO "django_geo_db_location" VALUES(40757,NULL,'Jefferson, WI',16798,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40758,NULL,'Jefferson, WI 53449',16798,222,NULL,58,23667,0);
INSERT INTO "django_geo_db_location" VALUES(40759,NULL,'Racine, WI 53490',16797,222,NULL,58,23668,0);
INSERT INTO "django_geo_db_location" VALUES(40760,NULL,'Afton, WI',16799,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40761,NULL,'Afton, WI 53501',16799,222,NULL,58,23669,0);
INSERT INTO "django_geo_db_location" VALUES(40762,NULL,'Albany, WI',16800,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40763,NULL,'Albany, WI 53502',16800,222,NULL,58,23670,0);
INSERT INTO "django_geo_db_location" VALUES(40764,NULL,'Arena, WI',16801,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40765,NULL,'Arena, WI 53503',16801,222,NULL,58,23671,0);
INSERT INTO "django_geo_db_location" VALUES(40766,NULL,'Argyle, WI',16802,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40767,NULL,'Argyle, WI 53504',16802,222,NULL,58,23672,0);
INSERT INTO "django_geo_db_location" VALUES(40768,NULL,'Avalon, WI',16803,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40769,NULL,'Avalon, WI 53505',16803,222,NULL,58,23673,0);
INSERT INTO "django_geo_db_location" VALUES(40770,NULL,'Avoca, WI',16804,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40771,NULL,'Avoca, WI 53506',16804,222,NULL,58,23674,0);
INSERT INTO "django_geo_db_location" VALUES(40772,NULL,'Barneveld, WI',16805,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40773,NULL,'Barneveld, WI 53507',16805,222,NULL,58,23675,0);
INSERT INTO "django_geo_db_location" VALUES(40774,NULL,'Belleville, WI',16806,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40775,NULL,'Belleville, WI 53508',16806,222,NULL,58,23676,0);
INSERT INTO "django_geo_db_location" VALUES(40776,NULL,'Belmont, WI',16807,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40777,NULL,'Belmont, WI 53510',16807,222,NULL,58,23677,0);
INSERT INTO "django_geo_db_location" VALUES(40778,NULL,'Beloit, WI',16808,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40779,NULL,'Beloit, WI 53511',16808,222,NULL,58,23678,0);
INSERT INTO "django_geo_db_location" VALUES(40780,NULL,'Beloit, WI 53512',16808,222,NULL,58,23679,0);
INSERT INTO "django_geo_db_location" VALUES(40781,NULL,'Black Earth, WI',16809,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40782,NULL,'Black Earth, WI 53515',16809,222,NULL,58,23680,0);
INSERT INTO "django_geo_db_location" VALUES(40783,NULL,'Blanchardville, WI',16810,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40784,NULL,'Blanchardville, WI 53516',16810,222,NULL,58,23681,0);
INSERT INTO "django_geo_db_location" VALUES(40785,NULL,'Blue Mounds, WI',16811,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40786,NULL,'Blue Mounds, WI 53517',16811,222,NULL,58,23682,0);
INSERT INTO "django_geo_db_location" VALUES(40787,NULL,'Blue River, WI',16812,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40788,NULL,'Blue River, WI 53518',16812,222,NULL,58,23683,0);
INSERT INTO "django_geo_db_location" VALUES(40789,NULL,'Brodhead, WI',16813,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40790,NULL,'Brodhead, WI 53520',16813,222,NULL,58,23684,0);
INSERT INTO "django_geo_db_location" VALUES(40791,NULL,'Brooklyn, WI',16814,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40792,NULL,'Brooklyn, WI 53521',16814,222,NULL,58,23685,0);
INSERT INTO "django_geo_db_location" VALUES(40793,NULL,'Browntown, WI',16815,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40794,NULL,'Browntown, WI 53522',16815,222,NULL,58,23686,0);
INSERT INTO "django_geo_db_location" VALUES(40795,NULL,'Cambridge, WI',16816,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40796,NULL,'Cambridge, WI 53523',16816,222,NULL,58,23687,0);
INSERT INTO "django_geo_db_location" VALUES(40797,NULL,'Clinton, WI',16817,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40798,NULL,'Clinton, WI 53525',16817,222,NULL,58,23688,0);
INSERT INTO "django_geo_db_location" VALUES(40799,NULL,'Cobb, WI',16818,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40800,NULL,'Cobb, WI 53526',16818,222,NULL,58,23689,0);
INSERT INTO "django_geo_db_location" VALUES(40801,NULL,'Cottage Grove, WI',16819,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40802,NULL,'Cottage Grove, WI 53527',16819,222,NULL,58,23690,0);
INSERT INTO "django_geo_db_location" VALUES(40803,NULL,'Cross Plains, WI',16820,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40804,NULL,'Cross Plains, WI 53528',16820,222,NULL,58,23691,0);
INSERT INTO "django_geo_db_location" VALUES(40805,NULL,'Dane, WI',16821,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40806,NULL,'Dane, WI 53529',16821,222,NULL,58,23692,0);
INSERT INTO "django_geo_db_location" VALUES(40807,NULL,'Darlington, WI',16822,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40808,NULL,'Darlington, WI 53530',16822,222,NULL,58,23693,0);
INSERT INTO "django_geo_db_location" VALUES(40809,NULL,'Deerfield, WI',16823,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40810,NULL,'Deerfield, WI 53531',16823,222,NULL,58,23694,0);
INSERT INTO "django_geo_db_location" VALUES(40811,NULL,'De Forest, WI',16824,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40812,NULL,'De Forest, WI 53532',16824,222,NULL,58,23695,0);
INSERT INTO "django_geo_db_location" VALUES(40813,NULL,'Dodgeville, WI',16825,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40814,NULL,'Dodgeville, WI 53533',16825,222,NULL,58,23696,0);
INSERT INTO "django_geo_db_location" VALUES(40815,NULL,'Edgerton, WI',16826,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40816,NULL,'Edgerton, WI 53534',16826,222,NULL,58,23697,0);
INSERT INTO "django_geo_db_location" VALUES(40817,NULL,'Edmund, WI',16827,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40818,NULL,'Edmund, WI 53535',16827,222,NULL,58,23698,0);
INSERT INTO "django_geo_db_location" VALUES(40819,NULL,'Evansville, WI',16828,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40820,NULL,'Evansville, WI 53536',16828,222,NULL,58,23699,0);
INSERT INTO "django_geo_db_location" VALUES(40821,NULL,'Footville, WI',16829,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40822,NULL,'Footville, WI 53537',16829,222,NULL,58,23700,0);
INSERT INTO "django_geo_db_location" VALUES(40823,NULL,'Fort Atkinson, WI',16830,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40824,NULL,'Fort Atkinson, WI 53538',16830,222,NULL,58,23701,0);
INSERT INTO "django_geo_db_location" VALUES(40825,NULL,'Gotham, WI',16831,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40826,NULL,'Gotham, WI 53540',16831,222,NULL,58,23702,0);
INSERT INTO "django_geo_db_location" VALUES(40827,NULL,'Gratiot, WI',16832,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40828,NULL,'Gratiot, WI 53541',16832,222,NULL,58,23703,0);
INSERT INTO "django_geo_db_location" VALUES(40829,NULL,'Hanover, WI',16833,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40830,NULL,'Hanover, WI 53542',16833,222,NULL,58,23704,0);
INSERT INTO "django_geo_db_location" VALUES(40831,NULL,'Highland, WI',16834,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40832,NULL,'Highland, WI 53543',16834,222,NULL,58,23705,0);
INSERT INTO "django_geo_db_location" VALUES(40833,NULL,'Hollandale, WI',16835,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40834,NULL,'Hollandale, WI 53544',16835,222,NULL,58,23706,0);
INSERT INTO "django_geo_db_location" VALUES(40835,NULL,'Janesville, WI',16836,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40836,NULL,'Janesville, WI 53545',16836,222,NULL,58,23707,0);
INSERT INTO "django_geo_db_location" VALUES(40837,NULL,'Janesville, WI 53546',16836,222,NULL,58,23708,0);
INSERT INTO "django_geo_db_location" VALUES(40838,NULL,'Janesville, WI 53547',16836,222,NULL,58,23709,0);
INSERT INTO "django_geo_db_location" VALUES(40839,NULL,'Jefferson, WI 53549',16798,222,NULL,58,23710,0);
INSERT INTO "django_geo_db_location" VALUES(40840,NULL,'Juda, WI',16837,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40841,NULL,'Juda, WI 53550',16837,222,NULL,58,23711,0);
INSERT INTO "django_geo_db_location" VALUES(40842,NULL,'Lake Mills, WI',16838,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40843,NULL,'Lake Mills, WI 53551',16838,222,NULL,58,23712,0);
INSERT INTO "django_geo_db_location" VALUES(40844,NULL,'Linden, WI',16839,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40845,NULL,'Linden, WI 53553',16839,222,NULL,58,23713,0);
INSERT INTO "django_geo_db_location" VALUES(40846,NULL,'Livingston, WI',16840,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40847,NULL,'Livingston, WI 53554',16840,222,NULL,58,23714,0);
INSERT INTO "django_geo_db_location" VALUES(40848,NULL,'Lodi, WI',16841,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40849,NULL,'Lodi, WI 53555',16841,222,NULL,58,23715,0);
INSERT INTO "django_geo_db_location" VALUES(40850,NULL,'Lone Rock, WI',16842,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40851,NULL,'Lone Rock, WI 53556',16842,222,NULL,58,23716,0);
INSERT INTO "django_geo_db_location" VALUES(40852,NULL,'Lowell, WI',16843,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40853,NULL,'Lowell, WI 53557',16843,222,NULL,58,23717,0);
INSERT INTO "django_geo_db_location" VALUES(40854,NULL,'McFarland, WI',16844,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40855,NULL,'McFarland, WI 53558',16844,222,NULL,58,23718,0);
INSERT INTO "django_geo_db_location" VALUES(40856,NULL,'Marshall, WI',16845,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40857,NULL,'Marshall, WI 53559',16845,222,NULL,58,23719,0);
INSERT INTO "django_geo_db_location" VALUES(40858,NULL,'Mazomanie, WI',16846,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40859,NULL,'Mazomanie, WI 53560',16846,222,NULL,58,23720,0);
INSERT INTO "django_geo_db_location" VALUES(40860,NULL,'Merrimac, WI',16847,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40861,NULL,'Merrimac, WI 53561',16847,222,NULL,58,23721,0);
INSERT INTO "django_geo_db_location" VALUES(40862,NULL,'Middleton, WI',16848,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40863,NULL,'Middleton, WI 53562',16848,222,NULL,58,23722,0);
INSERT INTO "django_geo_db_location" VALUES(40864,NULL,'Milton, WI',16849,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40865,NULL,'Milton, WI 53563',16849,222,NULL,58,23723,0);
INSERT INTO "django_geo_db_location" VALUES(40866,NULL,'Mineral Point, WI',16850,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40867,NULL,'Mineral Point, WI 53565',16850,222,NULL,58,23724,0);
INSERT INTO "django_geo_db_location" VALUES(40868,NULL,'Monroe, WI',16851,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40869,NULL,'Monroe, WI 53566',16851,222,NULL,58,23725,0);
INSERT INTO "django_geo_db_location" VALUES(40870,NULL,'Montfort, WI',16852,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40871,NULL,'Montfort, WI 53569',16852,222,NULL,58,23726,0);
INSERT INTO "django_geo_db_location" VALUES(40872,NULL,'Monticello, WI',16853,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40873,NULL,'Monticello, WI 53570',16853,222,NULL,58,23727,0);
INSERT INTO "django_geo_db_location" VALUES(40874,NULL,'Morrisonville, WI',16854,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40875,NULL,'Morrisonville, WI 53571',16854,222,NULL,58,23728,0);
INSERT INTO "django_geo_db_location" VALUES(40876,NULL,'Mount Horeb, WI',16855,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40877,NULL,'Mount Horeb, WI 53572',16855,222,NULL,58,23729,0);
INSERT INTO "django_geo_db_location" VALUES(40878,NULL,'Muscoda, WI',16856,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40879,NULL,'Muscoda, WI 53573',16856,222,NULL,58,23730,0);
INSERT INTO "django_geo_db_location" VALUES(40880,NULL,'New Glarus, WI',16857,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40881,NULL,'New Glarus, WI 53574',16857,222,NULL,58,23731,0);
INSERT INTO "django_geo_db_location" VALUES(40882,NULL,'Oregon, WI',16858,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40883,NULL,'Oregon, WI 53575',16858,222,NULL,58,23732,0);
INSERT INTO "django_geo_db_location" VALUES(40884,NULL,'Orfordville, WI',16859,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40885,NULL,'Orfordville, WI 53576',16859,222,NULL,58,23733,0);
INSERT INTO "django_geo_db_location" VALUES(40886,NULL,'Plain, WI',16860,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40887,NULL,'Plain, WI 53577',16860,222,NULL,58,23734,0);
INSERT INTO "django_geo_db_location" VALUES(40888,NULL,'Prairie Du Sac, WI',16861,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40889,NULL,'Prairie Du Sac, WI 53578',16861,222,NULL,58,23735,0);
INSERT INTO "django_geo_db_location" VALUES(40890,NULL,'Reeseville, WI',16862,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40891,NULL,'Reeseville, WI 53579',16862,222,NULL,58,23736,0);
INSERT INTO "django_geo_db_location" VALUES(40892,NULL,'Rewey, WI',16863,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40893,NULL,'Rewey, WI 53580',16863,222,NULL,58,23737,0);
INSERT INTO "django_geo_db_location" VALUES(40894,NULL,'Richland Center, WI',16864,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40895,NULL,'Richland Center, WI 53581',16864,222,NULL,58,23738,0);
INSERT INTO "django_geo_db_location" VALUES(40896,NULL,'Ridgeway, WI',16865,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40897,NULL,'Ridgeway, WI 53582',16865,222,NULL,58,23739,0);
INSERT INTO "django_geo_db_location" VALUES(40898,NULL,'Sauk City, WI',16866,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40899,NULL,'Sauk City, WI 53583',16866,222,NULL,58,23740,0);
INSERT INTO "django_geo_db_location" VALUES(40900,NULL,'Sextonville, WI',16867,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40901,NULL,'Sextonville, WI 53584',16867,222,NULL,58,23741,0);
INSERT INTO "django_geo_db_location" VALUES(40902,NULL,'Sharon, WI',16868,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40903,NULL,'Sharon, WI 53585',16868,222,NULL,58,23742,0);
INSERT INTO "django_geo_db_location" VALUES(40904,NULL,'Shullsburg, WI',16869,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40905,NULL,'Shullsburg, WI 53586',16869,222,NULL,58,23743,0);
INSERT INTO "django_geo_db_location" VALUES(40906,NULL,'South Wayne, WI',16870,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40907,NULL,'South Wayne, WI 53587',16870,222,NULL,58,23744,0);
INSERT INTO "django_geo_db_location" VALUES(40908,NULL,'Spring Green, WI',16871,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40909,NULL,'Spring Green, WI 53588',16871,222,NULL,58,23745,0);
INSERT INTO "django_geo_db_location" VALUES(40910,NULL,'Stoughton, WI',16872,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40911,NULL,'Stoughton, WI 53589',16872,222,NULL,58,23746,0);
INSERT INTO "django_geo_db_location" VALUES(40912,NULL,'Sun Prairie, WI',16873,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40913,NULL,'Sun Prairie, WI 53590',16873,222,NULL,58,23747,0);
INSERT INTO "django_geo_db_location" VALUES(40914,NULL,'Sun Prairie, WI 53591',16873,222,NULL,58,23748,0);
INSERT INTO "django_geo_db_location" VALUES(40915,NULL,'Verona, WI',16874,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40916,NULL,'Verona, WI 53593',16874,222,NULL,58,23749,0);
INSERT INTO "django_geo_db_location" VALUES(40917,NULL,'Waterloo, WI',16875,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40918,NULL,'Waterloo, WI 53594',16875,222,NULL,58,23750,0);
INSERT INTO "django_geo_db_location" VALUES(40919,NULL,'Dodgeville, WI 53595',16825,222,NULL,58,23751,0);
INSERT INTO "django_geo_db_location" VALUES(40920,NULL,'Sun Prairie, WI 53596',16873,222,NULL,58,23752,0);
INSERT INTO "django_geo_db_location" VALUES(40921,NULL,'Waunakee, WI',16876,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40922,NULL,'Waunakee, WI 53597',16876,222,NULL,58,23753,0);
INSERT INTO "django_geo_db_location" VALUES(40923,NULL,'Windsor, WI',16877,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40924,NULL,'Windsor, WI 53598',16877,222,NULL,58,23754,0);
INSERT INTO "django_geo_db_location" VALUES(40925,NULL,'Woodford, WI',16878,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40926,NULL,'Woodford, WI 53599',16878,222,NULL,58,23755,0);
INSERT INTO "django_geo_db_location" VALUES(40927,NULL,'Salem, WI 53648',16776,222,NULL,58,23756,0);
INSERT INTO "django_geo_db_location" VALUES(40928,NULL,'Union Center, WI',16879,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40929,NULL,'Union Center, WI 53698',16879,222,NULL,58,23757,0);
INSERT INTO "django_geo_db_location" VALUES(40930,NULL,'Madison, WI',16880,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40931,NULL,'Madison, WI 53701',16880,222,NULL,58,23758,0);
INSERT INTO "django_geo_db_location" VALUES(40932,NULL,'Madison, WI 53702',16880,222,NULL,58,23759,0);
INSERT INTO "django_geo_db_location" VALUES(40933,NULL,'Madison, WI 53703',16880,222,NULL,58,23760,0);
INSERT INTO "django_geo_db_location" VALUES(40934,NULL,'Madison, WI 53704',16880,222,NULL,58,23761,0);
INSERT INTO "django_geo_db_location" VALUES(40935,NULL,'Madison, WI 53705',16880,222,NULL,58,23762,0);
INSERT INTO "django_geo_db_location" VALUES(40936,NULL,'Madison, WI 53706',16880,222,NULL,58,23763,0);
INSERT INTO "django_geo_db_location" VALUES(40937,NULL,'Madison, WI 53707',16880,222,NULL,58,23764,0);
INSERT INTO "django_geo_db_location" VALUES(40938,NULL,'Madison, WI 53708',16880,222,NULL,58,23765,0);
INSERT INTO "django_geo_db_location" VALUES(40939,NULL,'Madison, WI 53709',16880,222,NULL,58,23766,0);
INSERT INTO "django_geo_db_location" VALUES(40940,NULL,'Madison, WI 53710',16880,222,NULL,58,23767,0);
INSERT INTO "django_geo_db_location" VALUES(40941,NULL,'Madison, WI 53711',16880,222,NULL,58,23768,0);
INSERT INTO "django_geo_db_location" VALUES(40942,NULL,'Madison, WI 53713',16880,222,NULL,58,23769,0);
INSERT INTO "django_geo_db_location" VALUES(40943,NULL,'Madison, WI 53714',16880,222,NULL,58,23770,0);
INSERT INTO "django_geo_db_location" VALUES(40944,NULL,'Madison, WI 53715',16880,222,NULL,58,23771,0);
INSERT INTO "django_geo_db_location" VALUES(40945,NULL,'Madison, WI 53716',16880,222,NULL,58,23772,0);
INSERT INTO "django_geo_db_location" VALUES(40946,NULL,'Madison, WI 53717',16880,222,NULL,58,23773,0);
INSERT INTO "django_geo_db_location" VALUES(40947,NULL,'Madison, WI 53718',16880,222,NULL,58,23774,0);
INSERT INTO "django_geo_db_location" VALUES(40948,NULL,'Madison, WI 53719',16880,222,NULL,58,23775,0);
INSERT INTO "django_geo_db_location" VALUES(40949,NULL,'Madison, WI 53725',16880,222,NULL,58,23776,0);
INSERT INTO "django_geo_db_location" VALUES(40950,NULL,'Madison, WI 53726',16880,222,NULL,58,23777,0);
INSERT INTO "django_geo_db_location" VALUES(40951,NULL,'Madison, WI 53744',16880,222,NULL,58,23778,0);
INSERT INTO "django_geo_db_location" VALUES(40952,NULL,'Madison, WI 53777',16880,222,NULL,58,23779,0);
INSERT INTO "django_geo_db_location" VALUES(40953,NULL,'Madison, WI 53778',16880,222,NULL,58,23780,0);
INSERT INTO "django_geo_db_location" VALUES(40954,NULL,'Madison, WI 53779',16880,222,NULL,58,23781,0);
INSERT INTO "django_geo_db_location" VALUES(40955,NULL,'Madison, WI 53780',16880,222,NULL,58,23782,0);
INSERT INTO "django_geo_db_location" VALUES(40956,NULL,'Madison, WI 53782',16880,222,NULL,58,23783,0);
INSERT INTO "django_geo_db_location" VALUES(40957,NULL,'Madison, WI 53783',16880,222,NULL,58,23784,0);
INSERT INTO "django_geo_db_location" VALUES(40958,NULL,'Madison, WI 53784',16880,222,NULL,58,23785,0);
INSERT INTO "django_geo_db_location" VALUES(40959,NULL,'Madison, WI 53785',16880,222,NULL,58,23786,0);
INSERT INTO "django_geo_db_location" VALUES(40960,NULL,'Madison, WI 53786',16880,222,NULL,58,23787,0);
INSERT INTO "django_geo_db_location" VALUES(40961,NULL,'Madison, WI 53787',16880,222,NULL,58,23788,0);
INSERT INTO "django_geo_db_location" VALUES(40962,NULL,'Madison, WI 53788',16880,222,NULL,58,23789,0);
INSERT INTO "django_geo_db_location" VALUES(40963,NULL,'Madison, WI 53789',16880,222,NULL,58,23790,0);
INSERT INTO "django_geo_db_location" VALUES(40964,NULL,'Madison, WI 53790',16880,222,NULL,58,23791,0);
INSERT INTO "django_geo_db_location" VALUES(40965,NULL,'Madison, WI 53791',16880,222,NULL,58,23792,0);
INSERT INTO "django_geo_db_location" VALUES(40966,NULL,'Madison, WI 53792',16880,222,NULL,58,23793,0);
INSERT INTO "django_geo_db_location" VALUES(40967,NULL,'Madison, WI 53793',16880,222,NULL,58,23794,0);
INSERT INTO "django_geo_db_location" VALUES(40968,NULL,'Madison, WI 53794',16880,222,NULL,58,23795,0);
INSERT INTO "django_geo_db_location" VALUES(40969,NULL,'Bagley, WI',16881,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40970,NULL,'Bagley, WI 53801',16881,222,NULL,58,23796,0);
INSERT INTO "django_geo_db_location" VALUES(40971,NULL,'Beetown, WI',16882,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40972,NULL,'Beetown, WI 53802',16882,222,NULL,58,23797,0);
INSERT INTO "django_geo_db_location" VALUES(40973,NULL,'Benton, WI',16883,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40974,NULL,'Benton, WI 53803',16883,222,NULL,58,23798,0);
INSERT INTO "django_geo_db_location" VALUES(40975,NULL,'Bloomington, WI',16884,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40976,NULL,'Bloomington, WI 53804',16884,222,NULL,58,23799,0);
INSERT INTO "django_geo_db_location" VALUES(40977,NULL,'Boscobel, WI',16885,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40978,NULL,'Boscobel, WI 53805',16885,222,NULL,58,23800,0);
INSERT INTO "django_geo_db_location" VALUES(40979,NULL,'Cassville, WI',16886,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40980,NULL,'Cassville, WI 53806',16886,222,NULL,58,23801,0);
INSERT INTO "django_geo_db_location" VALUES(40981,NULL,'Cuba City, WI',16887,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40982,NULL,'Cuba City, WI 53807',16887,222,NULL,58,23802,0);
INSERT INTO "django_geo_db_location" VALUES(40983,NULL,'Dickeyville, WI',16888,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40984,NULL,'Dickeyville, WI 53808',16888,222,NULL,58,23803,0);
INSERT INTO "django_geo_db_location" VALUES(40985,NULL,'Fennimore, WI',16889,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40986,NULL,'Fennimore, WI 53809',16889,222,NULL,58,23804,0);
INSERT INTO "django_geo_db_location" VALUES(40987,NULL,'Glen Haven, WI',16890,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40988,NULL,'Glen Haven, WI 53810',16890,222,NULL,58,23805,0);
INSERT INTO "django_geo_db_location" VALUES(40989,NULL,'Hazel Green, WI',16891,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40990,NULL,'Hazel Green, WI 53811',16891,222,NULL,58,23806,0);
INSERT INTO "django_geo_db_location" VALUES(40991,NULL,'Kieler, WI',16892,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40992,NULL,'Kieler, WI 53812',16892,222,NULL,58,23807,0);
INSERT INTO "django_geo_db_location" VALUES(40993,NULL,'Lancaster, WI',16893,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40994,NULL,'Lancaster, WI 53813',16893,222,NULL,58,23808,0);
INSERT INTO "django_geo_db_location" VALUES(40995,NULL,'Mount Hope, WI',16894,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40996,NULL,'Mount Hope, WI 53816',16894,222,NULL,58,23809,0);
INSERT INTO "django_geo_db_location" VALUES(40997,NULL,'Patch Grove, WI',16895,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(40998,NULL,'Patch Grove, WI 53817',16895,222,NULL,58,23810,0);
INSERT INTO "django_geo_db_location" VALUES(40999,NULL,'Platteville, WI',16896,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41000,NULL,'Platteville, WI 53818',16896,222,NULL,58,23811,0);
INSERT INTO "django_geo_db_location" VALUES(41001,NULL,'Potosi, WI',16897,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41002,NULL,'Potosi, WI 53820',16897,222,NULL,58,23812,0);
INSERT INTO "django_geo_db_location" VALUES(41003,NULL,'Prairie Du Chien, WI',16898,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41004,NULL,'Prairie Du Chien, WI 53821',16898,222,NULL,58,23813,0);
INSERT INTO "django_geo_db_location" VALUES(41005,NULL,'Sinsinawa, WI',16899,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41006,NULL,'Sinsinawa, WI 53824',16899,222,NULL,58,23814,0);
INSERT INTO "django_geo_db_location" VALUES(41007,NULL,'Stitzer, WI',16900,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41008,NULL,'Stitzer, WI 53825',16900,222,NULL,58,23815,0);
INSERT INTO "django_geo_db_location" VALUES(41009,NULL,'Wauzeka, WI',16901,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41010,NULL,'Wauzeka, WI 53826',16901,222,NULL,58,23816,0);
INSERT INTO "django_geo_db_location" VALUES(41011,NULL,'Woodman, WI',16902,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41012,NULL,'Woodman, WI 53827',16902,222,NULL,58,23817,0);
INSERT INTO "django_geo_db_location" VALUES(41013,NULL,'New Diggings, WI',16903,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41014,NULL,'New Diggings, WI 53886',16903,222,NULL,58,23818,0);
INSERT INTO "django_geo_db_location" VALUES(41015,NULL,'Portage, WI',16904,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41016,NULL,'Portage, WI 53901',16904,222,NULL,58,23819,0);
INSERT INTO "django_geo_db_location" VALUES(41017,NULL,'Adams, WI',16905,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41018,NULL,'Adams, WI 53910',16905,222,NULL,58,23820,0);
INSERT INTO "django_geo_db_location" VALUES(41019,NULL,'Arlington, WI',16906,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41020,NULL,'Arlington, WI 53911',16906,222,NULL,58,23821,0);
INSERT INTO "django_geo_db_location" VALUES(41021,NULL,'Baraboo, WI',16907,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41022,NULL,'Baraboo, WI 53913',16907,222,NULL,58,23822,0);
INSERT INTO "django_geo_db_location" VALUES(41023,NULL,'Beaver Dam, WI',16908,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41024,NULL,'Beaver Dam, WI 53916',16908,222,NULL,58,23823,0);
INSERT INTO "django_geo_db_location" VALUES(41025,NULL,'Beaver Dam, WI 53917',16908,222,NULL,58,23824,0);
INSERT INTO "django_geo_db_location" VALUES(41026,NULL,'Brandon, WI',16909,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41027,NULL,'Brandon, WI 53919',16909,222,NULL,58,23825,0);
INSERT INTO "django_geo_db_location" VALUES(41028,NULL,'Briggsville, WI',16910,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41029,NULL,'Briggsville, WI 53920',16910,222,NULL,58,23826,0);
INSERT INTO "django_geo_db_location" VALUES(41030,NULL,'Burnett, WI',16911,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41031,NULL,'Burnett, WI 53922',16911,222,NULL,58,23827,0);
INSERT INTO "django_geo_db_location" VALUES(41032,NULL,'Cambria, WI',16912,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41033,NULL,'Cambria, WI 53923',16912,222,NULL,58,23828,0);
INSERT INTO "django_geo_db_location" VALUES(41034,NULL,'Cazenovia, WI',16913,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41035,NULL,'Cazenovia, WI 53924',16913,222,NULL,58,23829,0);
INSERT INTO "django_geo_db_location" VALUES(41036,NULL,'Columbus, WI',16914,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41037,NULL,'Columbus, WI 53925',16914,222,NULL,58,23830,0);
INSERT INTO "django_geo_db_location" VALUES(41038,NULL,'Dalton, WI',16915,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41039,NULL,'Dalton, WI 53926',16915,222,NULL,58,23831,0);
INSERT INTO "django_geo_db_location" VALUES(41040,NULL,'Dellwood, WI',16916,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41041,NULL,'Dellwood, WI 53927',16916,222,NULL,58,23832,0);
INSERT INTO "django_geo_db_location" VALUES(41042,NULL,'Doylestown, WI',16917,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41043,NULL,'Doylestown, WI 53928',16917,222,NULL,58,23833,0);
INSERT INTO "django_geo_db_location" VALUES(41044,NULL,'Elroy, WI',16918,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41045,NULL,'Elroy, WI 53929',16918,222,NULL,58,23834,0);
INSERT INTO "django_geo_db_location" VALUES(41046,NULL,'Endeavor, WI',16919,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41047,NULL,'Endeavor, WI 53930',16919,222,NULL,58,23835,0);
INSERT INTO "django_geo_db_location" VALUES(41048,NULL,'Fairwater, WI',16920,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41049,NULL,'Fairwater, WI 53931',16920,222,NULL,58,23836,0);
INSERT INTO "django_geo_db_location" VALUES(41050,NULL,'Fall River, WI',16921,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41051,NULL,'Fall River, WI 53932',16921,222,NULL,58,23837,0);
INSERT INTO "django_geo_db_location" VALUES(41052,NULL,'Fox Lake, WI',16922,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41053,NULL,'Fox Lake, WI 53933',16922,222,NULL,58,23838,0);
INSERT INTO "django_geo_db_location" VALUES(41054,NULL,'Friendship, WI',16923,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41055,NULL,'Friendship, WI 53934',16923,222,NULL,58,23839,0);
INSERT INTO "django_geo_db_location" VALUES(41056,NULL,'Friesland, WI',16924,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41057,NULL,'Friesland, WI 53935',16924,222,NULL,58,23840,0);
INSERT INTO "django_geo_db_location" VALUES(41058,NULL,'Grand Marsh, WI',16925,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41059,NULL,'Grand Marsh, WI 53936',16925,222,NULL,58,23841,0);
INSERT INTO "django_geo_db_location" VALUES(41060,NULL,'Hillpoint, WI',16926,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41061,NULL,'Hillpoint, WI 53937',16926,222,NULL,58,23842,0);
INSERT INTO "django_geo_db_location" VALUES(41062,NULL,'Kingston, WI',16927,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41063,NULL,'Kingston, WI 53939',16927,222,NULL,58,23843,0);
INSERT INTO "django_geo_db_location" VALUES(41064,NULL,'Lake Delton, WI',16928,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41065,NULL,'Lake Delton, WI 53940',16928,222,NULL,58,23844,0);
INSERT INTO "django_geo_db_location" VALUES(41066,NULL,'La Valle, WI',16929,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41067,NULL,'La Valle, WI 53941',16929,222,NULL,58,23845,0);
INSERT INTO "django_geo_db_location" VALUES(41068,NULL,'Lime Ridge, WI',16930,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41069,NULL,'Lime Ridge, WI 53942',16930,222,NULL,58,23846,0);
INSERT INTO "django_geo_db_location" VALUES(41070,NULL,'Loganville, WI',16931,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41071,NULL,'Loganville, WI 53943',16931,222,NULL,58,23847,0);
INSERT INTO "django_geo_db_location" VALUES(41072,NULL,'Lyndon Station, WI',16932,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41073,NULL,'Lyndon Station, WI 53944',16932,222,NULL,58,23848,0);
INSERT INTO "django_geo_db_location" VALUES(41074,NULL,'Markesan, WI',16933,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41075,NULL,'Markesan, WI 53946',16933,222,NULL,58,23849,0);
INSERT INTO "django_geo_db_location" VALUES(41076,NULL,'Marquette, WI',16934,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41077,NULL,'Marquette, WI 53947',16934,222,NULL,58,23850,0);
INSERT INTO "django_geo_db_location" VALUES(41078,NULL,'Mauston, WI',16935,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41079,NULL,'Mauston, WI 53948',16935,222,NULL,58,23851,0);
INSERT INTO "django_geo_db_location" VALUES(41080,NULL,'Montello, WI',16936,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41081,NULL,'Montello, WI 53949',16936,222,NULL,58,23852,0);
INSERT INTO "django_geo_db_location" VALUES(41082,NULL,'New Lisbon, WI',16937,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41083,NULL,'New Lisbon, WI 53950',16937,222,NULL,58,23853,0);
INSERT INTO "django_geo_db_location" VALUES(41084,NULL,'North Freedom, WI',16938,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41085,NULL,'North Freedom, WI 53951',16938,222,NULL,58,23854,0);
INSERT INTO "django_geo_db_location" VALUES(41086,NULL,'Oxford, WI',16939,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41087,NULL,'Oxford, WI 53952',16939,222,NULL,58,23855,0);
INSERT INTO "django_geo_db_location" VALUES(41088,NULL,'Packwaukee, WI',16940,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41089,NULL,'Packwaukee, WI 53953',16940,222,NULL,58,23856,0);
INSERT INTO "django_geo_db_location" VALUES(41090,NULL,'Pardeeville, WI',16941,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41091,NULL,'Pardeeville, WI 53954',16941,222,NULL,58,23857,0);
INSERT INTO "django_geo_db_location" VALUES(41092,NULL,'Poynette, WI',16942,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41093,NULL,'Poynette, WI 53955',16942,222,NULL,58,23858,0);
INSERT INTO "django_geo_db_location" VALUES(41094,NULL,'Randolph, WI',16943,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41095,NULL,'Randolph, WI 53956',16943,222,NULL,58,23859,0);
INSERT INTO "django_geo_db_location" VALUES(41096,NULL,'Randolph, WI 53957',16943,222,NULL,58,23860,0);
INSERT INTO "django_geo_db_location" VALUES(41097,NULL,'Reedsburg, WI',16944,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41098,NULL,'Reedsburg, WI 53958',16944,222,NULL,58,23861,0);
INSERT INTO "django_geo_db_location" VALUES(41099,NULL,'Reedsburg, WI 53959',16944,222,NULL,58,23862,0);
INSERT INTO "django_geo_db_location" VALUES(41100,NULL,'Rio, WI',16945,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41101,NULL,'Rio, WI 53960',16945,222,NULL,58,23863,0);
INSERT INTO "django_geo_db_location" VALUES(41102,NULL,'Rock Springs, WI',16946,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41103,NULL,'Rock Springs, WI 53961',16946,222,NULL,58,23864,0);
INSERT INTO "django_geo_db_location" VALUES(41104,NULL,'Union Center, WI 53962',16879,222,NULL,58,23865,0);
INSERT INTO "django_geo_db_location" VALUES(41105,NULL,'Waupun, WI',16947,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41106,NULL,'Waupun, WI 53963',16947,222,NULL,58,23866,0);
INSERT INTO "django_geo_db_location" VALUES(41107,NULL,'Westfield, WI',16948,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41108,NULL,'Westfield, WI 53964',16948,222,NULL,58,23867,0);
INSERT INTO "django_geo_db_location" VALUES(41109,NULL,'Wisconsin Dells, WI',16949,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41110,NULL,'Wisconsin Dells, WI 53965',16949,222,NULL,58,23868,0);
INSERT INTO "django_geo_db_location" VALUES(41111,NULL,'Wonewoc, WI',16950,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41112,NULL,'Wonewoc, WI 53968',16950,222,NULL,58,23869,0);
INSERT INTO "django_geo_db_location" VALUES(41113,NULL,'Wyocena, WI',16951,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41114,NULL,'Wyocena, WI 53969',16951,222,NULL,58,23870,0);
INSERT INTO "django_geo_db_location" VALUES(41115,NULL,'Willow, WI',16952,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41116,NULL,'Willow, WI 53981',16952,222,NULL,58,23871,0);
INSERT INTO "django_geo_db_location" VALUES(41117,NULL,'Poynette, WI 53995',16942,222,NULL,58,23872,0);
INSERT INTO "django_geo_db_location" VALUES(41118,NULL,'Amery, WI',16953,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41119,NULL,'Amery, WI 54001',16953,222,NULL,58,23873,0);
INSERT INTO "django_geo_db_location" VALUES(41120,NULL,'Baldwin, WI',16954,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41121,NULL,'Baldwin, WI 54002',16954,222,NULL,58,23874,0);
INSERT INTO "django_geo_db_location" VALUES(41122,NULL,'Beldenville, WI',16955,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41123,NULL,'Beldenville, WI 54003',16955,222,NULL,58,23875,0);
INSERT INTO "django_geo_db_location" VALUES(41124,NULL,'Clayton, WI',16956,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41125,NULL,'Clayton, WI 54004',16956,222,NULL,58,23876,0);
INSERT INTO "django_geo_db_location" VALUES(41126,NULL,'Clear Lake, WI',16957,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41127,NULL,'Clear Lake, WI 54005',16957,222,NULL,58,23877,0);
INSERT INTO "django_geo_db_location" VALUES(41128,NULL,'Cushing, WI',16958,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41129,NULL,'Cushing, WI 54006',16958,222,NULL,58,23878,0);
INSERT INTO "django_geo_db_location" VALUES(41130,NULL,'Deer Park, WI',16959,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41131,NULL,'Deer Park, WI 54007',16959,222,NULL,58,23879,0);
INSERT INTO "django_geo_db_location" VALUES(41132,NULL,'Dresser, WI',16960,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41133,NULL,'Dresser, WI 54009',16960,222,NULL,58,23880,0);
INSERT INTO "django_geo_db_location" VALUES(41134,NULL,'East Ellsworth, WI',16961,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41135,NULL,'East Ellsworth, WI 54010',16961,222,NULL,58,23881,0);
INSERT INTO "django_geo_db_location" VALUES(41136,NULL,'Ellsworth, WI',16962,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41137,NULL,'Ellsworth, WI 54011',16962,222,NULL,58,23882,0);
INSERT INTO "django_geo_db_location" VALUES(41138,NULL,'Emerald, WI',16963,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41139,NULL,'Emerald, WI 54012',16963,222,NULL,58,23883,0);
INSERT INTO "django_geo_db_location" VALUES(41140,NULL,'Glenwood City, WI',16964,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41141,NULL,'Glenwood City, WI 54013',16964,222,NULL,58,23884,0);
INSERT INTO "django_geo_db_location" VALUES(41142,NULL,'Hager City, WI',16965,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41143,NULL,'Hager City, WI 54014',16965,222,NULL,58,23885,0);
INSERT INTO "django_geo_db_location" VALUES(41144,NULL,'Hammond, WI',16966,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41145,NULL,'Hammond, WI 54015',16966,222,NULL,58,23886,0);
INSERT INTO "django_geo_db_location" VALUES(41146,NULL,'Hudson, WI',16967,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41147,NULL,'Hudson, WI 54016',16967,222,NULL,58,23887,0);
INSERT INTO "django_geo_db_location" VALUES(41148,NULL,'New Richmond, WI',16968,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41149,NULL,'New Richmond, WI 54017',16968,222,NULL,58,23888,0);
INSERT INTO "django_geo_db_location" VALUES(41150,NULL,'Osceola, WI',16969,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41151,NULL,'Osceola, WI 54020',16969,222,NULL,58,23889,0);
INSERT INTO "django_geo_db_location" VALUES(41152,NULL,'Prescott, WI',16970,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41153,NULL,'Prescott, WI 54021',16970,222,NULL,58,23890,0);
INSERT INTO "django_geo_db_location" VALUES(41154,NULL,'River Falls, WI',16971,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41155,NULL,'River Falls, WI 54022',16971,222,NULL,58,23891,0);
INSERT INTO "django_geo_db_location" VALUES(41156,NULL,'Roberts, WI',16972,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41157,NULL,'Roberts, WI 54023',16972,222,NULL,58,23892,0);
INSERT INTO "django_geo_db_location" VALUES(41158,NULL,'Saint Croix Falls, WI',16973,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41159,NULL,'Saint Croix Falls, WI 54024',16973,222,NULL,58,23893,0);
INSERT INTO "django_geo_db_location" VALUES(41160,NULL,'Somerset, WI',16974,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41161,NULL,'Somerset, WI 54025',16974,222,NULL,58,23894,0);
INSERT INTO "django_geo_db_location" VALUES(41162,NULL,'Star Prairie, WI',16975,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41163,NULL,'Star Prairie, WI 54026',16975,222,NULL,58,23895,0);
INSERT INTO "django_geo_db_location" VALUES(41164,NULL,'Wilson, WI',16976,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41165,NULL,'Wilson, WI 54027',16976,222,NULL,58,23896,0);
INSERT INTO "django_geo_db_location" VALUES(41166,NULL,'Woodville, WI',16977,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41167,NULL,'Woodville, WI 54028',16977,222,NULL,58,23897,0);
INSERT INTO "django_geo_db_location" VALUES(41168,NULL,'Forest, WI',16978,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41169,NULL,'Forest, WI 54034',16978,222,NULL,58,23898,0);
INSERT INTO "django_geo_db_location" VALUES(41170,NULL,'Fond du Lac, WI',16979,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41171,NULL,'Fond du Lac, WI 54035',16979,222,NULL,58,23899,0);
INSERT INTO "django_geo_db_location" VALUES(41172,NULL,'Kickapoo, WI',16980,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41173,NULL,'Kickapoo, WI 54052',16980,222,NULL,58,23900,0);
INSERT INTO "django_geo_db_location" VALUES(41174,NULL,'New London, WI',16981,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41175,NULL,'New London, WI 54061',16981,222,NULL,58,23901,0);
INSERT INTO "django_geo_db_location" VALUES(41176,NULL,'Saint Joseph, WI',16982,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41177,NULL,'Saint Joseph, WI 54082',16982,222,NULL,58,23902,0);
INSERT INTO "django_geo_db_location" VALUES(41178,NULL,'Abrams, WI',16983,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41179,NULL,'Abrams, WI 54101',16983,222,NULL,58,23903,0);
INSERT INTO "django_geo_db_location" VALUES(41180,NULL,'Amberg, WI',16984,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41181,NULL,'Amberg, WI 54102',16984,222,NULL,58,23904,0);
INSERT INTO "django_geo_db_location" VALUES(41182,NULL,'Armstrong Creek, WI',16985,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41183,NULL,'Armstrong Creek, WI 54103',16985,222,NULL,58,23905,0);
INSERT INTO "django_geo_db_location" VALUES(41184,NULL,'Athelstane, WI',16986,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41185,NULL,'Athelstane, WI 54104',16986,222,NULL,58,23906,0);
INSERT INTO "django_geo_db_location" VALUES(41186,NULL,'Black Creek, WI',16987,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41187,NULL,'Black Creek, WI 54106',16987,222,NULL,58,23907,0);
INSERT INTO "django_geo_db_location" VALUES(41188,NULL,'Bonduel, WI',16988,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41189,NULL,'Bonduel, WI 54107',16988,222,NULL,58,23908,0);
INSERT INTO "django_geo_db_location" VALUES(41190,NULL,'Brillion, WI',16989,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41191,NULL,'Brillion, WI 54110',16989,222,NULL,58,23909,0);
INSERT INTO "django_geo_db_location" VALUES(41192,NULL,'Cecil, WI',16990,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41193,NULL,'Cecil, WI 54111',16990,222,NULL,58,23910,0);
INSERT INTO "django_geo_db_location" VALUES(41194,NULL,'Coleman, WI',16991,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41195,NULL,'Coleman, WI 54112',16991,222,NULL,58,23911,0);
INSERT INTO "django_geo_db_location" VALUES(41196,NULL,'Combined Locks, WI',16992,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41197,NULL,'Combined Locks, WI 54113',16992,222,NULL,58,23912,0);
INSERT INTO "django_geo_db_location" VALUES(41198,NULL,'Crivitz, WI',16993,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41199,NULL,'Crivitz, WI 54114',16993,222,NULL,58,23913,0);
INSERT INTO "django_geo_db_location" VALUES(41200,NULL,'De Pere, WI',16994,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41201,NULL,'De Pere, WI 54115',16994,222,NULL,58,23914,0);
INSERT INTO "django_geo_db_location" VALUES(41202,NULL,'Dunbar, WI',16995,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41203,NULL,'Dunbar, WI 54119',16995,222,NULL,58,23915,0);
INSERT INTO "django_geo_db_location" VALUES(41204,NULL,'Fence, WI',16996,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41205,NULL,'Fence, WI 54120',16996,222,NULL,58,23916,0);
INSERT INTO "django_geo_db_location" VALUES(41206,NULL,'Florence, WI',16997,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41207,NULL,'Florence, WI 54121',16997,222,NULL,58,23917,0);
INSERT INTO "django_geo_db_location" VALUES(41208,NULL,'Forest Junction, WI',16998,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41209,NULL,'Forest Junction, WI 54123',16998,222,NULL,58,23918,0);
INSERT INTO "django_geo_db_location" VALUES(41210,NULL,'Gillett, WI',16999,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41211,NULL,'Gillett, WI 54124',16999,222,NULL,58,23919,0);
INSERT INTO "django_geo_db_location" VALUES(41212,NULL,'Goodman, WI',17000,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41213,NULL,'Goodman, WI 54125',17000,222,NULL,58,23920,0);
INSERT INTO "django_geo_db_location" VALUES(41214,NULL,'Greenleaf, WI',17001,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41215,NULL,'Greenleaf, WI 54126',17001,222,NULL,58,23921,0);
INSERT INTO "django_geo_db_location" VALUES(41216,NULL,'Green Valley, WI',17002,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41217,NULL,'Green Valley, WI 54127',17002,222,NULL,58,23922,0);
INSERT INTO "django_geo_db_location" VALUES(41218,NULL,'Gresham, WI',17003,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41219,NULL,'Gresham, WI 54128',17003,222,NULL,58,23923,0);
INSERT INTO "django_geo_db_location" VALUES(41220,NULL,'Hilbert, WI',17004,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41221,NULL,'Hilbert, WI 54129',17004,222,NULL,58,23924,0);
INSERT INTO "django_geo_db_location" VALUES(41222,NULL,'Kaukauna, WI',17005,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41223,NULL,'Kaukauna, WI 54130',17005,222,NULL,58,23925,0);
INSERT INTO "django_geo_db_location" VALUES(41224,NULL,'Freedom, WI',17006,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41225,NULL,'Freedom, WI 54131',17006,222,NULL,58,23926,0);
INSERT INTO "django_geo_db_location" VALUES(41226,NULL,'Keshena, WI',17007,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41227,NULL,'Keshena, WI 54135',17007,222,NULL,58,23927,0);
INSERT INTO "django_geo_db_location" VALUES(41228,NULL,'Kimberly, WI',17008,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41229,NULL,'Kimberly, WI 54136',17008,222,NULL,58,23928,0);
INSERT INTO "django_geo_db_location" VALUES(41230,NULL,'Krakow, WI',17009,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41231,NULL,'Krakow, WI 54137',17009,222,NULL,58,23929,0);
INSERT INTO "django_geo_db_location" VALUES(41232,NULL,'Lakewood, WI',17010,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41233,NULL,'Lakewood, WI 54138',17010,222,NULL,58,23930,0);
INSERT INTO "django_geo_db_location" VALUES(41234,NULL,'Lena, WI',17011,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41235,NULL,'Lena, WI 54139',17011,222,NULL,58,23931,0);
INSERT INTO "django_geo_db_location" VALUES(41236,NULL,'Little Chute, WI',17012,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41237,NULL,'Little Chute, WI 54140',17012,222,NULL,58,23932,0);
INSERT INTO "django_geo_db_location" VALUES(41238,NULL,'Little Suamico, WI',17013,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41239,NULL,'Little Suamico, WI 54141',17013,222,NULL,58,23933,0);
INSERT INTO "django_geo_db_location" VALUES(41240,NULL,'Marinette, WI',17014,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41241,NULL,'Marinette, WI 54143',17014,222,NULL,58,23934,0);
INSERT INTO "django_geo_db_location" VALUES(41242,NULL,'Mountain, WI',17015,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41243,NULL,'Mountain, WI 54149',17015,222,NULL,58,23935,0);
INSERT INTO "django_geo_db_location" VALUES(41244,NULL,'Neopit, WI',17016,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41245,NULL,'Neopit, WI 54150',17016,222,NULL,58,23936,0);
INSERT INTO "django_geo_db_location" VALUES(41246,NULL,'Niagara, WI',17017,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41247,NULL,'Niagara, WI 54151',17017,222,NULL,58,23937,0);
INSERT INTO "django_geo_db_location" VALUES(41248,NULL,'Nichols, WI',17018,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41249,NULL,'Nichols, WI 54152',17018,222,NULL,58,23938,0);
INSERT INTO "django_geo_db_location" VALUES(41250,NULL,'Oconto, WI',17019,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41251,NULL,'Oconto, WI 54153',17019,222,NULL,58,23939,0);
INSERT INTO "django_geo_db_location" VALUES(41252,NULL,'Oconto Falls, WI',17020,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41253,NULL,'Oconto Falls, WI 54154',17020,222,NULL,58,23940,0);
INSERT INTO "django_geo_db_location" VALUES(41254,NULL,'Oneida, WI',17021,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41255,NULL,'Oneida, WI 54155',17021,222,NULL,58,23941,0);
INSERT INTO "django_geo_db_location" VALUES(41256,NULL,'Pembine, WI',17022,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41257,NULL,'Pembine, WI 54156',17022,222,NULL,58,23942,0);
INSERT INTO "django_geo_db_location" VALUES(41258,NULL,'Peshtigo, WI',17023,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41259,NULL,'Peshtigo, WI 54157',17023,222,NULL,58,23943,0);
INSERT INTO "django_geo_db_location" VALUES(41260,NULL,'Porterfield, WI',17024,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41261,NULL,'Porterfield, WI 54159',17024,222,NULL,58,23944,0);
INSERT INTO "django_geo_db_location" VALUES(41262,NULL,'Potter, WI',17025,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41263,NULL,'Potter, WI 54160',17025,222,NULL,58,23945,0);
INSERT INTO "django_geo_db_location" VALUES(41264,NULL,'Pound, WI',17026,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41265,NULL,'Pound, WI 54161',17026,222,NULL,58,23946,0);
INSERT INTO "django_geo_db_location" VALUES(41266,NULL,'Pulaski, WI',17027,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41267,NULL,'Pulaski, WI 54162',17027,222,NULL,58,23947,0);
INSERT INTO "django_geo_db_location" VALUES(41268,NULL,'Seymour, WI',17028,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41269,NULL,'Seymour, WI 54165',17028,222,NULL,58,23948,0);
INSERT INTO "django_geo_db_location" VALUES(41270,NULL,'Shawano, WI',17029,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41271,NULL,'Shawano, WI 54166',17029,222,NULL,58,23949,0);
INSERT INTO "django_geo_db_location" VALUES(41272,NULL,'Sherwood, WI',17030,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41273,NULL,'Sherwood, WI 54169',17030,222,NULL,58,23950,0);
INSERT INTO "django_geo_db_location" VALUES(41274,NULL,'Shiocton, WI',17031,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41275,NULL,'Shiocton, WI 54170',17031,222,NULL,58,23951,0);
INSERT INTO "django_geo_db_location" VALUES(41276,NULL,'Sobieski, WI',17032,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41277,NULL,'Sobieski, WI 54171',17032,222,NULL,58,23952,0);
INSERT INTO "django_geo_db_location" VALUES(41278,NULL,'Suamico, WI',17033,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41279,NULL,'Suamico, WI 54173',17033,222,NULL,58,23953,0);
INSERT INTO "django_geo_db_location" VALUES(41280,NULL,'Suring, WI',17034,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41281,NULL,'Suring, WI 54174',17034,222,NULL,58,23954,0);
INSERT INTO "django_geo_db_location" VALUES(41282,NULL,'Townsend, WI',17035,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41283,NULL,'Townsend, WI 54175',17035,222,NULL,58,23955,0);
INSERT INTO "django_geo_db_location" VALUES(41284,NULL,'Wausaukee, WI',17036,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41285,NULL,'Wausaukee, WI 54177',17036,222,NULL,58,23956,0);
INSERT INTO "django_geo_db_location" VALUES(41286,NULL,'Wrightstown, WI',17037,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41287,NULL,'Wrightstown, WI 54180',17037,222,NULL,58,23957,0);
INSERT INTO "django_geo_db_location" VALUES(41288,NULL,'Zachow, WI',17038,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41289,NULL,'Zachow, WI 54182',17038,222,NULL,58,23958,0);
INSERT INTO "django_geo_db_location" VALUES(41290,NULL,'Algoma, WI',17039,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41291,NULL,'Algoma, WI 54201',17039,222,NULL,58,23959,0);
INSERT INTO "django_geo_db_location" VALUES(41292,NULL,'Baileys Harbor, WI',17040,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41293,NULL,'Baileys Harbor, WI 54202',17040,222,NULL,58,23960,0);
INSERT INTO "django_geo_db_location" VALUES(41294,NULL,'Branch, WI',17041,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41295,NULL,'Branch, WI 54203',17041,222,NULL,58,23961,0);
INSERT INTO "django_geo_db_location" VALUES(41296,NULL,'Brussels, WI',17042,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41297,NULL,'Brussels, WI 54204',17042,222,NULL,58,23962,0);
INSERT INTO "django_geo_db_location" VALUES(41298,NULL,'Casco, WI',17043,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41299,NULL,'Casco, WI 54205',17043,222,NULL,58,23963,0);
INSERT INTO "django_geo_db_location" VALUES(41300,NULL,'Kossuth, WI',17044,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41301,NULL,'Kossuth, WI 54206',17044,222,NULL,58,23964,0);
INSERT INTO "django_geo_db_location" VALUES(41302,NULL,'Collins, WI',17045,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41303,NULL,'Collins, WI 54207',17045,222,NULL,58,23965,0);
INSERT INTO "django_geo_db_location" VALUES(41304,NULL,'Denmark, WI',17046,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41305,NULL,'Denmark, WI 54208',17046,222,NULL,58,23966,0);
INSERT INTO "django_geo_db_location" VALUES(41306,NULL,'Egg Harbor, WI',17047,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41307,NULL,'Egg Harbor, WI 54209',17047,222,NULL,58,23967,0);
INSERT INTO "django_geo_db_location" VALUES(41308,NULL,'Ellison Bay, WI',17048,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41309,NULL,'Ellison Bay, WI 54210',17048,222,NULL,58,23968,0);
INSERT INTO "django_geo_db_location" VALUES(41310,NULL,'Ephraim, WI',17049,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41311,NULL,'Ephraim, WI 54211',17049,222,NULL,58,23969,0);
INSERT INTO "django_geo_db_location" VALUES(41312,NULL,'Fish Creek, WI',17050,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41313,NULL,'Fish Creek, WI 54212',17050,222,NULL,58,23970,0);
INSERT INTO "django_geo_db_location" VALUES(41314,NULL,'Forestville, WI',17051,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41315,NULL,'Forestville, WI 54213',17051,222,NULL,58,23971,0);
INSERT INTO "django_geo_db_location" VALUES(41316,NULL,'Francis Creek, WI',17052,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41317,NULL,'Francis Creek, WI 54214',17052,222,NULL,58,23972,0);
INSERT INTO "django_geo_db_location" VALUES(41318,NULL,'Kellnersville, WI',17053,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41319,NULL,'Kellnersville, WI 54215',17053,222,NULL,58,23973,0);
INSERT INTO "django_geo_db_location" VALUES(41320,NULL,'Kewaunee, WI',17054,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41321,NULL,'Kewaunee, WI 54216',17054,222,NULL,58,23974,0);
INSERT INTO "django_geo_db_location" VALUES(41322,NULL,'Luxemburg, WI',17055,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41323,NULL,'Luxemburg, WI 54217',17055,222,NULL,58,23975,0);
INSERT INTO "django_geo_db_location" VALUES(41324,NULL,'Manitowoc, WI',17056,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41325,NULL,'Manitowoc, WI 54220',17056,222,NULL,58,23976,0);
INSERT INTO "django_geo_db_location" VALUES(41326,NULL,'Manitowoc, WI 54221',17056,222,NULL,58,23977,0);
INSERT INTO "django_geo_db_location" VALUES(41327,NULL,'Maplewood, WI',17057,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41328,NULL,'Maplewood, WI 54226',17057,222,NULL,58,23978,0);
INSERT INTO "django_geo_db_location" VALUES(41329,NULL,'Maribel, WI',17058,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41330,NULL,'Maribel, WI 54227',17058,222,NULL,58,23979,0);
INSERT INTO "django_geo_db_location" VALUES(41331,NULL,'Mishicot, WI',17059,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41332,NULL,'Mishicot, WI 54228',17059,222,NULL,58,23980,0);
INSERT INTO "django_geo_db_location" VALUES(41333,NULL,'New Franken, WI',17060,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41334,NULL,'New Franken, WI 54229',17060,222,NULL,58,23981,0);
INSERT INTO "django_geo_db_location" VALUES(41335,NULL,'Reedsville, WI',17061,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41336,NULL,'Reedsville, WI 54230',17061,222,NULL,58,23982,0);
INSERT INTO "django_geo_db_location" VALUES(41337,NULL,'Saint Nazianz, WI',17062,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41338,NULL,'Saint Nazianz, WI 54232',17062,222,NULL,58,23983,0);
INSERT INTO "django_geo_db_location" VALUES(41339,NULL,'Sister Bay, WI',17063,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41340,NULL,'Sister Bay, WI 54234',17063,222,NULL,58,23984,0);
INSERT INTO "django_geo_db_location" VALUES(41341,NULL,'Sturgeon Bay, WI',17064,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41342,NULL,'Sturgeon Bay, WI 54235',17064,222,NULL,58,23985,0);
INSERT INTO "django_geo_db_location" VALUES(41343,NULL,'Tisch Mills, WI',17065,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41344,NULL,'Tisch Mills, WI 54240',17065,222,NULL,58,23986,0);
INSERT INTO "django_geo_db_location" VALUES(41345,NULL,'Two Rivers, WI',17066,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41346,NULL,'Two Rivers, WI 54241',17066,222,NULL,58,23987,0);
INSERT INTO "django_geo_db_location" VALUES(41347,NULL,'Ludington, WI',17067,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41348,NULL,'Ludington, WI 54242',17067,222,NULL,58,23988,0);
INSERT INTO "django_geo_db_location" VALUES(41349,NULL,'Valders, WI',17068,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41350,NULL,'Valders, WI 54245',17068,222,NULL,58,23989,0);
INSERT INTO "django_geo_db_location" VALUES(41351,NULL,'Washington Island, WI',17069,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41352,NULL,'Washington Island, WI 54246',17069,222,NULL,58,23990,0);
INSERT INTO "django_geo_db_location" VALUES(41353,NULL,'Whitelaw, WI',17070,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41354,NULL,'Whitelaw, WI 54247',17070,222,NULL,58,23991,0);
INSERT INTO "django_geo_db_location" VALUES(41355,NULL,'Green Bay, WI',17071,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41356,NULL,'Green Bay, WI 54301',17071,222,NULL,58,23992,0);
INSERT INTO "django_geo_db_location" VALUES(41357,NULL,'Green Bay, WI 54302',17071,222,NULL,58,23993,0);
INSERT INTO "django_geo_db_location" VALUES(41358,NULL,'Green Bay, WI 54303',17071,222,NULL,58,23994,0);
INSERT INTO "django_geo_db_location" VALUES(41359,NULL,'Green Bay, WI 54304',17071,222,NULL,58,23995,0);
INSERT INTO "django_geo_db_location" VALUES(41360,NULL,'Green Bay, WI 54305',17071,222,NULL,58,23996,0);
INSERT INTO "django_geo_db_location" VALUES(41361,NULL,'Green Bay, WI 54306',17071,222,NULL,58,23997,0);
INSERT INTO "django_geo_db_location" VALUES(41362,NULL,'Green Bay, WI 54307',17071,222,NULL,58,23998,0);
INSERT INTO "django_geo_db_location" VALUES(41363,NULL,'Green Bay, WI 54308',17071,222,NULL,58,23999,0);
INSERT INTO "django_geo_db_location" VALUES(41364,NULL,'Liberty Grove, WI',17072,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41365,NULL,'Liberty Grove, WI 54310',17072,222,NULL,58,24000,0);
INSERT INTO "django_geo_db_location" VALUES(41366,NULL,'Green Bay, WI 54311',17071,222,NULL,58,24001,0);
INSERT INTO "django_geo_db_location" VALUES(41367,NULL,'Green Bay, WI 54313',17071,222,NULL,58,24002,0);
INSERT INTO "django_geo_db_location" VALUES(41368,NULL,'Green Bay, WI 54324',17071,222,NULL,58,24003,0);
INSERT INTO "django_geo_db_location" VALUES(41369,NULL,'Bone Lake, WI',17073,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41370,NULL,'Bone Lake, WI 54337',17073,222,NULL,58,24004,0);
INSERT INTO "django_geo_db_location" VALUES(41371,NULL,'Green Bay, WI 54344',17071,222,NULL,58,24005,0);
INSERT INTO "django_geo_db_location" VALUES(41372,NULL,'Georgetown, WI',17074,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41373,NULL,'Georgetown, WI 54353',17074,222,NULL,58,24006,0);
INSERT INTO "django_geo_db_location" VALUES(41374,NULL,'Wascott, WI',17075,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41375,NULL,'Wascott, WI 54383',17075,222,NULL,58,24007,0);
INSERT INTO "django_geo_db_location" VALUES(41376,NULL,'Wausau, WI',17076,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41377,NULL,'Wausau, WI 54401',17076,222,NULL,58,24008,0);
INSERT INTO "django_geo_db_location" VALUES(41378,NULL,'Wausau, WI 54402',17076,222,NULL,58,24009,0);
INSERT INTO "django_geo_db_location" VALUES(41379,NULL,'Wausau, WI 54403',17076,222,NULL,58,24010,0);
INSERT INTO "django_geo_db_location" VALUES(41380,NULL,'Marshfield, WI',17077,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41381,NULL,'Marshfield, WI 54404',17077,222,NULL,58,24011,0);
INSERT INTO "django_geo_db_location" VALUES(41382,NULL,'Abbotsford, WI',17078,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41383,NULL,'Abbotsford, WI 54405',17078,222,NULL,58,24012,0);
INSERT INTO "django_geo_db_location" VALUES(41384,NULL,'Amherst, WI',17079,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41385,NULL,'Amherst, WI 54406',17079,222,NULL,58,24013,0);
INSERT INTO "django_geo_db_location" VALUES(41386,NULL,'Amherst Junction, WI',17080,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41387,NULL,'Amherst Junction, WI 54407',17080,222,NULL,58,24014,0);
INSERT INTO "django_geo_db_location" VALUES(41388,NULL,'Aniwa, WI',17081,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41389,NULL,'Aniwa, WI 54408',17081,222,NULL,58,24015,0);
INSERT INTO "django_geo_db_location" VALUES(41390,NULL,'Antigo, WI',17082,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41391,NULL,'Antigo, WI 54409',17082,222,NULL,58,24016,0);
INSERT INTO "django_geo_db_location" VALUES(41392,NULL,'Arpin, WI',17083,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41393,NULL,'Arpin, WI 54410',17083,222,NULL,58,24017,0);
INSERT INTO "django_geo_db_location" VALUES(41394,NULL,'Athens, WI',17084,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41395,NULL,'Athens, WI 54411',17084,222,NULL,58,24018,0);
INSERT INTO "django_geo_db_location" VALUES(41396,NULL,'Auburndale, WI',17085,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41397,NULL,'Auburndale, WI 54412',17085,222,NULL,58,24019,0);
INSERT INTO "django_geo_db_location" VALUES(41398,NULL,'Babcock, WI',17086,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41399,NULL,'Babcock, WI 54413',17086,222,NULL,58,24020,0);
INSERT INTO "django_geo_db_location" VALUES(41400,NULL,'Birnamwood, WI',17087,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41401,NULL,'Birnamwood, WI 54414',17087,222,NULL,58,24021,0);
INSERT INTO "django_geo_db_location" VALUES(41402,NULL,'Blenker, WI',17088,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41403,NULL,'Blenker, WI 54415',17088,222,NULL,58,24022,0);
INSERT INTO "django_geo_db_location" VALUES(41404,NULL,'Bowler, WI',17089,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41405,NULL,'Bowler, WI 54416',17089,222,NULL,58,24023,0);
INSERT INTO "django_geo_db_location" VALUES(41406,NULL,'Brokaw, WI',17090,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41407,NULL,'Brokaw, WI 54417',17090,222,NULL,58,24024,0);
INSERT INTO "django_geo_db_location" VALUES(41408,NULL,'Bryant, WI',17091,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41409,NULL,'Bryant, WI 54418',17091,222,NULL,58,24025,0);
INSERT INTO "django_geo_db_location" VALUES(41410,NULL,'Chelsea, WI',17092,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41411,NULL,'Chelsea, WI 54419',17092,222,NULL,58,24026,0);
INSERT INTO "django_geo_db_location" VALUES(41412,NULL,'Chili, WI',17093,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41413,NULL,'Chili, WI 54420',17093,222,NULL,58,24027,0);
INSERT INTO "django_geo_db_location" VALUES(41414,NULL,'Colby, WI',17094,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41415,NULL,'Colby, WI 54421',17094,222,NULL,58,24028,0);
INSERT INTO "django_geo_db_location" VALUES(41416,NULL,'Curtiss, WI',17095,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41417,NULL,'Curtiss, WI 54422',17095,222,NULL,58,24029,0);
INSERT INTO "django_geo_db_location" VALUES(41418,NULL,'Custer, WI',17096,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41419,NULL,'Custer, WI 54423',17096,222,NULL,58,24030,0);
INSERT INTO "django_geo_db_location" VALUES(41420,NULL,'Deerbrook, WI',17097,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41421,NULL,'Deerbrook, WI 54424',17097,222,NULL,58,24031,0);
INSERT INTO "django_geo_db_location" VALUES(41422,NULL,'Dorchester, WI',17098,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41423,NULL,'Dorchester, WI 54425',17098,222,NULL,58,24032,0);
INSERT INTO "django_geo_db_location" VALUES(41424,NULL,'Edgar, WI',17099,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41425,NULL,'Edgar, WI 54426',17099,222,NULL,58,24033,0);
INSERT INTO "django_geo_db_location" VALUES(41426,NULL,'Eland, WI',17100,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41427,NULL,'Eland, WI 54427',17100,222,NULL,58,24034,0);
INSERT INTO "django_geo_db_location" VALUES(41428,NULL,'Elcho, WI',17101,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41429,NULL,'Elcho, WI 54428',17101,222,NULL,58,24035,0);
INSERT INTO "django_geo_db_location" VALUES(41430,NULL,'Elderon, WI',17102,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41431,NULL,'Elderon, WI 54429',17102,222,NULL,58,24036,0);
INSERT INTO "django_geo_db_location" VALUES(41432,NULL,'Elton, WI',17103,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41433,NULL,'Elton, WI 54430',17103,222,NULL,58,24037,0);
INSERT INTO "django_geo_db_location" VALUES(41434,NULL,'Little Black, WI',17104,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41435,NULL,'Little Black, WI 54431',17104,222,NULL,58,24038,0);
INSERT INTO "django_geo_db_location" VALUES(41436,NULL,'Galloway, WI',17105,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41437,NULL,'Galloway, WI 54432',17105,222,NULL,58,24039,0);
INSERT INTO "django_geo_db_location" VALUES(41438,NULL,'Gilman, WI',17106,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41439,NULL,'Gilman, WI 54433',17106,222,NULL,58,24040,0);
INSERT INTO "django_geo_db_location" VALUES(41440,NULL,'Jump River, WI',17107,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41441,NULL,'Jump River, WI 54434',17107,222,NULL,58,24041,0);
INSERT INTO "django_geo_db_location" VALUES(41442,NULL,'Gleason, WI',17108,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41443,NULL,'Gleason, WI 54435',17108,222,NULL,58,24042,0);
INSERT INTO "django_geo_db_location" VALUES(41444,NULL,'Granton, WI',17109,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41445,NULL,'Granton, WI 54436',17109,222,NULL,58,24043,0);
INSERT INTO "django_geo_db_location" VALUES(41446,NULL,'Greenwood, WI',17110,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41447,NULL,'Greenwood, WI 54437',17110,222,NULL,58,24044,0);
INSERT INTO "django_geo_db_location" VALUES(41448,NULL,'Hannibal, WI',17111,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41449,NULL,'Hannibal, WI 54439',17111,222,NULL,58,24045,0);
INSERT INTO "django_geo_db_location" VALUES(41450,NULL,'Hatley, WI',17112,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41451,NULL,'Hatley, WI 54440',17112,222,NULL,58,24046,0);
INSERT INTO "django_geo_db_location" VALUES(41452,NULL,'Hewitt, WI',17113,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41453,NULL,'Hewitt, WI 54441',17113,222,NULL,58,24047,0);
INSERT INTO "django_geo_db_location" VALUES(41454,NULL,'Irma, WI',17114,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41455,NULL,'Irma, WI 54442',17114,222,NULL,58,24048,0);
INSERT INTO "django_geo_db_location" VALUES(41456,NULL,'Junction City, WI',17115,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41457,NULL,'Junction City, WI 54443',17115,222,NULL,58,24049,0);
INSERT INTO "django_geo_db_location" VALUES(41458,NULL,'Kempster, WI',17116,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41459,NULL,'Kempster, WI 54444',17116,222,NULL,58,24050,0);
INSERT INTO "django_geo_db_location" VALUES(41460,NULL,'Loyal, WI',17117,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41461,NULL,'Loyal, WI 54446',17117,222,NULL,58,24051,0);
INSERT INTO "django_geo_db_location" VALUES(41462,NULL,'Lublin, WI',17118,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41463,NULL,'Lublin, WI 54447',17118,222,NULL,58,24052,0);
INSERT INTO "django_geo_db_location" VALUES(41464,NULL,'Marathon, WI',17119,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41465,NULL,'Marathon, WI 54448',17119,222,NULL,58,24053,0);
INSERT INTO "django_geo_db_location" VALUES(41466,NULL,'Marshfield, WI 54449',17077,222,NULL,58,24054,0);
INSERT INTO "django_geo_db_location" VALUES(41467,NULL,'Mattoon, WI',17120,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41468,NULL,'Mattoon, WI 54450',17120,222,NULL,58,24055,0);
INSERT INTO "django_geo_db_location" VALUES(41469,NULL,'Medford, WI',17121,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41470,NULL,'Medford, WI 54451',17121,222,NULL,58,24056,0);
INSERT INTO "django_geo_db_location" VALUES(41471,NULL,'Merrill, WI',17122,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41472,NULL,'Merrill, WI 54452',17122,222,NULL,58,24057,0);
INSERT INTO "django_geo_db_location" VALUES(41473,NULL,'Milladore, WI',17123,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41474,NULL,'Milladore, WI 54454',17123,222,NULL,58,24058,0);
INSERT INTO "django_geo_db_location" VALUES(41475,NULL,'Mosinee, WI',17124,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41476,NULL,'Mosinee, WI 54455',17124,222,NULL,58,24059,0);
INSERT INTO "django_geo_db_location" VALUES(41477,NULL,'Neillsville, WI',17125,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41478,NULL,'Neillsville, WI 54456',17125,222,NULL,58,24060,0);
INSERT INTO "django_geo_db_location" VALUES(41479,NULL,'Nekoosa, WI',17126,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41480,NULL,'Nekoosa, WI 54457',17126,222,NULL,58,24061,0);
INSERT INTO "django_geo_db_location" VALUES(41481,NULL,'Nelsonville, WI',17127,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41482,NULL,'Nelsonville, WI 54458',17127,222,NULL,58,24062,0);
INSERT INTO "django_geo_db_location" VALUES(41483,NULL,'Ogema, WI',17128,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41484,NULL,'Ogema, WI 54459',17128,222,NULL,58,24063,0);
INSERT INTO "django_geo_db_location" VALUES(41485,NULL,'Owen, WI',17129,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41486,NULL,'Owen, WI 54460',17129,222,NULL,58,24064,0);
INSERT INTO "django_geo_db_location" VALUES(41487,NULL,'Pearson, WI',17130,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41488,NULL,'Pearson, WI 54462',17130,222,NULL,58,24065,0);
INSERT INTO "django_geo_db_location" VALUES(41489,NULL,'Pelican Lake, WI',17131,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41490,NULL,'Pelican Lake, WI 54463',17131,222,NULL,58,24066,0);
INSERT INTO "django_geo_db_location" VALUES(41491,NULL,'Phlox, WI',17132,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41492,NULL,'Phlox, WI 54464',17132,222,NULL,58,24067,0);
INSERT INTO "django_geo_db_location" VALUES(41493,NULL,'Pickerel, WI',17133,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41494,NULL,'Pickerel, WI 54465',17133,222,NULL,58,24068,0);
INSERT INTO "django_geo_db_location" VALUES(41495,NULL,'Pittsville, WI',17134,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41496,NULL,'Pittsville, WI 54466',17134,222,NULL,58,24069,0);
INSERT INTO "django_geo_db_location" VALUES(41497,NULL,'Plover, WI',17135,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41498,NULL,'Plover, WI 54467',17135,222,NULL,58,24070,0);
INSERT INTO "django_geo_db_location" VALUES(41499,NULL,'Port Edwards, WI',17136,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41500,NULL,'Port Edwards, WI 54469',17136,222,NULL,58,24071,0);
INSERT INTO "django_geo_db_location" VALUES(41501,NULL,'Rib Lake, WI',17137,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41502,NULL,'Rib Lake, WI 54470',17137,222,NULL,58,24072,0);
INSERT INTO "django_geo_db_location" VALUES(41503,NULL,'Ringle, WI',17138,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41504,NULL,'Ringle, WI 54471',17138,222,NULL,58,24073,0);
INSERT INTO "django_geo_db_location" VALUES(41505,NULL,'Marshfield, WI 54472',17077,222,NULL,58,24074,0);
INSERT INTO "django_geo_db_location" VALUES(41506,NULL,'Rosholt, WI',17139,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41507,NULL,'Rosholt, WI 54473',17139,222,NULL,58,24075,0);
INSERT INTO "django_geo_db_location" VALUES(41508,NULL,'Rothschild, WI',17140,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41509,NULL,'Rothschild, WI 54474',17140,222,NULL,58,24076,0);
INSERT INTO "django_geo_db_location" VALUES(41510,NULL,'Rudolph, WI',17141,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41511,NULL,'Rudolph, WI 54475',17141,222,NULL,58,24077,0);
INSERT INTO "django_geo_db_location" VALUES(41512,NULL,'Schofield, WI',17142,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41513,NULL,'Schofield, WI 54476',17142,222,NULL,58,24078,0);
INSERT INTO "django_geo_db_location" VALUES(41514,NULL,'Spencer, WI',17143,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41515,NULL,'Spencer, WI 54479',17143,222,NULL,58,24079,0);
INSERT INTO "django_geo_db_location" VALUES(41516,NULL,'Stetsonville, WI',17144,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41517,NULL,'Stetsonville, WI 54480',17144,222,NULL,58,24080,0);
INSERT INTO "django_geo_db_location" VALUES(41518,NULL,'Stevens Point, WI',17145,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41519,NULL,'Stevens Point, WI 54481',17145,222,NULL,58,24081,0);
INSERT INTO "django_geo_db_location" VALUES(41520,NULL,'Stratford, WI',17146,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41521,NULL,'Stratford, WI 54484',17146,222,NULL,58,24082,0);
INSERT INTO "django_geo_db_location" VALUES(41522,NULL,'Summit Lake, WI',17147,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41523,NULL,'Summit Lake, WI 54485',17147,222,NULL,58,24083,0);
INSERT INTO "django_geo_db_location" VALUES(41524,NULL,'Tigerton, WI',17148,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41525,NULL,'Tigerton, WI 54486',17148,222,NULL,58,24084,0);
INSERT INTO "django_geo_db_location" VALUES(41526,NULL,'Tomahawk, WI',17149,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41527,NULL,'Tomahawk, WI 54487',17149,222,NULL,58,24085,0);
INSERT INTO "django_geo_db_location" VALUES(41528,NULL,'Unity, WI',17150,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41529,NULL,'Unity, WI 54488',17150,222,NULL,58,24086,0);
INSERT INTO "django_geo_db_location" VALUES(41530,NULL,'Vesper, WI',17151,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41531,NULL,'Vesper, WI 54489',17151,222,NULL,58,24087,0);
INSERT INTO "django_geo_db_location" VALUES(41532,NULL,'Westboro, WI',17152,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41533,NULL,'Westboro, WI 54490',17152,222,NULL,58,24088,0);
INSERT INTO "django_geo_db_location" VALUES(41534,NULL,'White Lake, WI',17153,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41535,NULL,'White Lake, WI 54491',17153,222,NULL,58,24089,0);
INSERT INTO "django_geo_db_location" VALUES(41536,NULL,'Stevens Point, WI 54492',17145,222,NULL,58,24090,0);
INSERT INTO "django_geo_db_location" VALUES(41537,NULL,'Willard, WI',17154,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41538,NULL,'Willard, WI 54493',17154,222,NULL,58,24091,0);
INSERT INTO "django_geo_db_location" VALUES(41539,NULL,'Wisconsin Rapids, WI',17155,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41540,NULL,'Wisconsin Rapids, WI 54494',17155,222,NULL,58,24092,0);
INSERT INTO "django_geo_db_location" VALUES(41541,NULL,'Wisconsin Rapids, WI 54495',17155,222,NULL,58,24093,0);
INSERT INTO "django_geo_db_location" VALUES(41542,NULL,'Withee, WI',17156,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41543,NULL,'Withee, WI 54498',17156,222,NULL,58,24094,0);
INSERT INTO "django_geo_db_location" VALUES(41544,NULL,'Wittenberg, WI',17157,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41545,NULL,'Wittenberg, WI 54499',17157,222,NULL,58,24095,0);
INSERT INTO "django_geo_db_location" VALUES(41546,NULL,'Rhinelander, WI',17158,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41547,NULL,'Rhinelander, WI 54501',17158,222,NULL,58,24096,0);
INSERT INTO "django_geo_db_location" VALUES(41548,NULL,'Argonne, WI',17159,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41549,NULL,'Argonne, WI 54511',17159,222,NULL,58,24097,0);
INSERT INTO "django_geo_db_location" VALUES(41550,NULL,'Boulder Junction, WI',17160,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41551,NULL,'Boulder Junction, WI 54512',17160,222,NULL,58,24098,0);
INSERT INTO "django_geo_db_location" VALUES(41552,NULL,'Brantwood, WI',17161,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41553,NULL,'Brantwood, WI 54513',17161,222,NULL,58,24099,0);
INSERT INTO "django_geo_db_location" VALUES(41554,NULL,'Butternut, WI',17162,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41555,NULL,'Butternut, WI 54514',17162,222,NULL,58,24100,0);
INSERT INTO "django_geo_db_location" VALUES(41556,NULL,'Catawba, WI',17163,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41557,NULL,'Catawba, WI 54515',17163,222,NULL,58,24101,0);
INSERT INTO "django_geo_db_location" VALUES(41558,NULL,'Clam Lake, WI',17164,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41559,NULL,'Clam Lake, WI 54517',17164,222,NULL,58,24102,0);
INSERT INTO "django_geo_db_location" VALUES(41560,NULL,'Conover, WI',17165,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41561,NULL,'Conover, WI 54519',17165,222,NULL,58,24103,0);
INSERT INTO "django_geo_db_location" VALUES(41562,NULL,'Crandon, WI',17166,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41563,NULL,'Crandon, WI 54520',17166,222,NULL,58,24104,0);
INSERT INTO "django_geo_db_location" VALUES(41564,NULL,'Eagle River, WI',17167,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41565,NULL,'Eagle River, WI 54521',17167,222,NULL,58,24105,0);
INSERT INTO "django_geo_db_location" VALUES(41566,NULL,'Fifield, WI',17168,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41567,NULL,'Fifield, WI 54524',17168,222,NULL,58,24106,0);
INSERT INTO "django_geo_db_location" VALUES(41568,NULL,'Gile, WI',17169,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41569,NULL,'Gile, WI 54525',17169,222,NULL,58,24107,0);
INSERT INTO "django_geo_db_location" VALUES(41570,NULL,'Glen Flora, WI',17170,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41571,NULL,'Glen Flora, WI 54526',17170,222,NULL,58,24108,0);
INSERT INTO "django_geo_db_location" VALUES(41572,NULL,'Glidden, WI',17171,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41573,NULL,'Glidden, WI 54527',17171,222,NULL,58,24109,0);
INSERT INTO "django_geo_db_location" VALUES(41574,NULL,'Harshaw, WI',17172,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41575,NULL,'Harshaw, WI 54529',17172,222,NULL,58,24110,0);
INSERT INTO "django_geo_db_location" VALUES(41576,NULL,'Hawkins, WI',17173,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41577,NULL,'Hawkins, WI 54530',17173,222,NULL,58,24111,0);
INSERT INTO "django_geo_db_location" VALUES(41578,NULL,'Hazelhurst, WI',17174,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41579,NULL,'Hazelhurst, WI 54531',17174,222,NULL,58,24112,0);
INSERT INTO "django_geo_db_location" VALUES(41580,NULL,'Heafford Junction, WI',17175,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41581,NULL,'Heafford Junction, WI 54532',17175,222,NULL,58,24113,0);
INSERT INTO "django_geo_db_location" VALUES(41582,NULL,'Hurley, WI',17176,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41583,NULL,'Hurley, WI 54534',17176,222,NULL,58,24114,0);
INSERT INTO "django_geo_db_location" VALUES(41584,NULL,'Iron Belt, WI',17177,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41585,NULL,'Iron Belt, WI 54536',17177,222,NULL,58,24115,0);
INSERT INTO "django_geo_db_location" VALUES(41586,NULL,'Kennan, WI',17178,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41587,NULL,'Kennan, WI 54537',17178,222,NULL,58,24116,0);
INSERT INTO "django_geo_db_location" VALUES(41588,NULL,'Lac Du Flambeau, WI',17179,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41589,NULL,'Lac Du Flambeau, WI 54538',17179,222,NULL,58,24117,0);
INSERT INTO "django_geo_db_location" VALUES(41590,NULL,'Lake Tomahawk, WI',17180,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41591,NULL,'Lake Tomahawk, WI 54539',17180,222,NULL,58,24118,0);
INSERT INTO "django_geo_db_location" VALUES(41592,NULL,'Land O Lakes, WI',17181,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41593,NULL,'Land O Lakes, WI 54540',17181,222,NULL,58,24119,0);
INSERT INTO "django_geo_db_location" VALUES(41594,NULL,'Laona, WI',17182,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41595,NULL,'Laona, WI 54541',17182,222,NULL,58,24120,0);
INSERT INTO "django_geo_db_location" VALUES(41596,NULL,'Long Lake, WI',17183,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41597,NULL,'Long Lake, WI 54542',17183,222,NULL,58,24121,0);
INSERT INTO "django_geo_db_location" VALUES(41598,NULL,'McNaughton, WI',17184,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41599,NULL,'McNaughton, WI 54543',17184,222,NULL,58,24122,0);
INSERT INTO "django_geo_db_location" VALUES(41600,NULL,'Manitowish Waters, WI',17185,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41601,NULL,'Manitowish Waters, WI 54545',17185,222,NULL,58,24123,0);
INSERT INTO "django_geo_db_location" VALUES(41602,NULL,'Mellen, WI',17186,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41603,NULL,'Mellen, WI 54546',17186,222,NULL,58,24124,0);
INSERT INTO "django_geo_db_location" VALUES(41604,NULL,'Mercer, WI',17187,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41605,NULL,'Mercer, WI 54547',17187,222,NULL,58,24125,0);
INSERT INTO "django_geo_db_location" VALUES(41606,NULL,'Minocqua, WI',17188,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41607,NULL,'Minocqua, WI 54548',17188,222,NULL,58,24126,0);
INSERT INTO "django_geo_db_location" VALUES(41608,NULL,'Montreal, WI',17189,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41609,NULL,'Montreal, WI 54550',17189,222,NULL,58,24127,0);
INSERT INTO "django_geo_db_location" VALUES(41610,NULL,'Presque Isle, WI',17190,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41611,NULL,'Presque Isle, WI 54551',17190,222,NULL,58,24128,0);
INSERT INTO "django_geo_db_location" VALUES(41612,NULL,'Park Falls, WI',17191,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41613,NULL,'Park Falls, WI 54552',17191,222,NULL,58,24129,0);
INSERT INTO "django_geo_db_location" VALUES(41614,NULL,'Phelps, WI',17192,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41615,NULL,'Phelps, WI 54554',17192,222,NULL,58,24130,0);
INSERT INTO "django_geo_db_location" VALUES(41616,NULL,'Phillips, WI',17193,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41617,NULL,'Phillips, WI 54555',17193,222,NULL,58,24131,0);
INSERT INTO "django_geo_db_location" VALUES(41618,NULL,'Prentice, WI',17194,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41619,NULL,'Prentice, WI 54556',17194,222,NULL,58,24132,0);
INSERT INTO "django_geo_db_location" VALUES(41620,NULL,'Presque Isle, WI 54557',17190,222,NULL,58,24133,0);
INSERT INTO "django_geo_db_location" VALUES(41621,NULL,'Saint Germain, WI',17195,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41622,NULL,'Saint Germain, WI 54558',17195,222,NULL,58,24134,0);
INSERT INTO "django_geo_db_location" VALUES(41623,NULL,'Saxon, WI',17196,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41624,NULL,'Saxon, WI 54559',17196,222,NULL,58,24135,0);
INSERT INTO "django_geo_db_location" VALUES(41625,NULL,'Sayner, WI',17197,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41626,NULL,'Sayner, WI 54560',17197,222,NULL,58,24136,0);
INSERT INTO "django_geo_db_location" VALUES(41627,NULL,'Star Lake, WI',17198,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41628,NULL,'Star Lake, WI 54561',17198,222,NULL,58,24137,0);
INSERT INTO "django_geo_db_location" VALUES(41629,NULL,'Three Lakes, WI',17199,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41630,NULL,'Three Lakes, WI 54562',17199,222,NULL,58,24138,0);
INSERT INTO "django_geo_db_location" VALUES(41631,NULL,'Tony, WI',17200,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41632,NULL,'Tony, WI 54563',17200,222,NULL,58,24139,0);
INSERT INTO "django_geo_db_location" VALUES(41633,NULL,'Tripoli, WI',17201,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41634,NULL,'Tripoli, WI 54564',17201,222,NULL,58,24140,0);
INSERT INTO "django_geo_db_location" VALUES(41635,NULL,'Upson, WI',17202,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41636,NULL,'Upson, WI 54565',17202,222,NULL,58,24141,0);
INSERT INTO "django_geo_db_location" VALUES(41637,NULL,'Wabeno, WI',17203,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41638,NULL,'Wabeno, WI 54566',17203,222,NULL,58,24142,0);
INSERT INTO "django_geo_db_location" VALUES(41639,NULL,'Woodruff, WI',17204,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41640,NULL,'Woodruff, WI 54568',17204,222,NULL,58,24143,0);
INSERT INTO "django_geo_db_location" VALUES(41641,NULL,'La Crosse, WI',17205,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41642,NULL,'La Crosse, WI 54601',17205,222,NULL,58,24144,0);
INSERT INTO "django_geo_db_location" VALUES(41643,NULL,'La Crosse, WI 54602',17205,222,NULL,58,24145,0);
INSERT INTO "django_geo_db_location" VALUES(41644,NULL,'La Crosse, WI 54603',17205,222,NULL,58,24146,0);
INSERT INTO "django_geo_db_location" VALUES(41645,NULL,'Alma, WI',17206,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41646,NULL,'Alma, WI 54610',17206,222,NULL,58,24147,0);
INSERT INTO "django_geo_db_location" VALUES(41647,NULL,'Alma Center, WI',17207,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41648,NULL,'Alma Center, WI 54611',17207,222,NULL,58,24148,0);
INSERT INTO "django_geo_db_location" VALUES(41649,NULL,'Arcadia, WI',17208,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41650,NULL,'Arcadia, WI 54612',17208,222,NULL,58,24149,0);
INSERT INTO "django_geo_db_location" VALUES(41651,NULL,'Arkdale, WI',17209,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41652,NULL,'Arkdale, WI 54613',17209,222,NULL,58,24150,0);
INSERT INTO "django_geo_db_location" VALUES(41653,NULL,'Bangor, WI',17210,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41654,NULL,'Bangor, WI 54614',17210,222,NULL,58,24151,0);
INSERT INTO "django_geo_db_location" VALUES(41655,NULL,'Black River Falls, WI',17211,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41656,NULL,'Black River Falls, WI 54615',17211,222,NULL,58,24152,0);
INSERT INTO "django_geo_db_location" VALUES(41657,NULL,'Blair, WI',17212,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41658,NULL,'Blair, WI 54616',17212,222,NULL,58,24153,0);
INSERT INTO "django_geo_db_location" VALUES(41659,NULL,'Camp Douglas, WI',17213,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41660,NULL,'Camp Douglas, WI 54618',17213,222,NULL,58,24154,0);
INSERT INTO "django_geo_db_location" VALUES(41661,NULL,'Cashton, WI',17214,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41662,NULL,'Cashton, WI 54619',17214,222,NULL,58,24155,0);
INSERT INTO "django_geo_db_location" VALUES(41663,NULL,'Cataract, WI',17215,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41664,NULL,'Cataract, WI 54620',17215,222,NULL,58,24156,0);
INSERT INTO "django_geo_db_location" VALUES(41665,NULL,'Chaseburg, WI',17216,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41666,NULL,'Chaseburg, WI 54621',17216,222,NULL,58,24157,0);
INSERT INTO "django_geo_db_location" VALUES(41667,NULL,'Cochrane, WI',17217,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41668,NULL,'Cochrane, WI 54622',17217,222,NULL,58,24158,0);
INSERT INTO "django_geo_db_location" VALUES(41669,NULL,'Coon Valley, WI',17218,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41670,NULL,'Coon Valley, WI 54623',17218,222,NULL,58,24159,0);
INSERT INTO "django_geo_db_location" VALUES(41671,NULL,'De Soto, WI',17219,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41672,NULL,'De Soto, WI 54624',17219,222,NULL,58,24160,0);
INSERT INTO "django_geo_db_location" VALUES(41673,NULL,'Dodge, WI',17220,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41674,NULL,'Dodge, WI 54625',17220,222,NULL,58,24161,0);
INSERT INTO "django_geo_db_location" VALUES(41675,NULL,'Eastman, WI',17221,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41676,NULL,'Eastman, WI 54626',17221,222,NULL,58,24162,0);
INSERT INTO "django_geo_db_location" VALUES(41677,NULL,'Ettrick, WI',17222,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41678,NULL,'Ettrick, WI 54627',17222,222,NULL,58,24163,0);
INSERT INTO "django_geo_db_location" VALUES(41679,NULL,'Ferryville, WI',17223,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41680,NULL,'Ferryville, WI 54628',17223,222,NULL,58,24164,0);
INSERT INTO "django_geo_db_location" VALUES(41681,NULL,'Fountain City, WI',17224,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41682,NULL,'Fountain City, WI 54629',17224,222,NULL,58,24165,0);
INSERT INTO "django_geo_db_location" VALUES(41683,NULL,'Galesville, WI',17225,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41684,NULL,'Galesville, WI 54630',17225,222,NULL,58,24166,0);
INSERT INTO "django_geo_db_location" VALUES(41685,NULL,'Gays Mills, WI',17226,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41686,NULL,'Gays Mills, WI 54631',17226,222,NULL,58,24167,0);
INSERT INTO "django_geo_db_location" VALUES(41687,NULL,'Genoa, WI',17227,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41688,NULL,'Genoa, WI 54632',17227,222,NULL,58,24168,0);
INSERT INTO "django_geo_db_location" VALUES(41689,NULL,'Hillsboro, WI',17228,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41690,NULL,'Hillsboro, WI 54634',17228,222,NULL,58,24169,0);
INSERT INTO "django_geo_db_location" VALUES(41691,NULL,'Hixton, WI',17229,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41692,NULL,'Hixton, WI 54635',17229,222,NULL,58,24170,0);
INSERT INTO "django_geo_db_location" VALUES(41693,NULL,'Holmen, WI',17230,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41694,NULL,'Holmen, WI 54636',17230,222,NULL,58,24171,0);
INSERT INTO "django_geo_db_location" VALUES(41695,NULL,'Hustler, WI',17231,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41696,NULL,'Hustler, WI 54637',17231,222,NULL,58,24172,0);
INSERT INTO "django_geo_db_location" VALUES(41697,NULL,'Kendall, WI',17232,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41698,NULL,'Kendall, WI 54638',17232,222,NULL,58,24173,0);
INSERT INTO "django_geo_db_location" VALUES(41699,NULL,'La Farge, WI',17233,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41700,NULL,'La Farge, WI 54639',17233,222,NULL,58,24174,0);
INSERT INTO "django_geo_db_location" VALUES(41701,NULL,'Lynxville, WI',17234,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41702,NULL,'Lynxville, WI 54640',17234,222,NULL,58,24175,0);
INSERT INTO "django_geo_db_location" VALUES(41703,NULL,'Mather, WI',17235,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41704,NULL,'Mather, WI 54641',17235,222,NULL,58,24176,0);
INSERT INTO "django_geo_db_location" VALUES(41705,NULL,'Melrose, WI',17236,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41706,NULL,'Melrose, WI 54642',17236,222,NULL,58,24177,0);
INSERT INTO "django_geo_db_location" VALUES(41707,NULL,'Millston, WI',17237,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41708,NULL,'Millston, WI 54643',17237,222,NULL,58,24178,0);
INSERT INTO "django_geo_db_location" VALUES(41709,NULL,'Mindoro, WI',17238,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41710,NULL,'Mindoro, WI 54644',17238,222,NULL,58,24179,0);
INSERT INTO "django_geo_db_location" VALUES(41711,NULL,'Mount Sterling, WI',17239,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41712,NULL,'Mount Sterling, WI 54645',17239,222,NULL,58,24180,0);
INSERT INTO "django_geo_db_location" VALUES(41713,NULL,'Necedah, WI',17240,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41714,NULL,'Necedah, WI 54646',17240,222,NULL,58,24181,0);
INSERT INTO "django_geo_db_location" VALUES(41715,NULL,'Norwalk, WI',17241,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41716,NULL,'Norwalk, WI 54648',17241,222,NULL,58,24182,0);
INSERT INTO "django_geo_db_location" VALUES(41717,NULL,'Oakdale, WI',17242,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41718,NULL,'Oakdale, WI 54649',17242,222,NULL,58,24183,0);
INSERT INTO "django_geo_db_location" VALUES(41719,NULL,'Onalaska, WI',17243,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41720,NULL,'Onalaska, WI 54650',17243,222,NULL,58,24184,0);
INSERT INTO "django_geo_db_location" VALUES(41721,NULL,'Ontario, WI',17244,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41722,NULL,'Ontario, WI 54651',17244,222,NULL,58,24185,0);
INSERT INTO "django_geo_db_location" VALUES(41723,NULL,'Readstown, WI',17245,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41724,NULL,'Readstown, WI 54652',17245,222,NULL,58,24186,0);
INSERT INTO "django_geo_db_location" VALUES(41725,NULL,'Rockland, WI',17246,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41726,NULL,'Rockland, WI 54653',17246,222,NULL,58,24187,0);
INSERT INTO "django_geo_db_location" VALUES(41727,NULL,'Seneca, WI',17247,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41728,NULL,'Seneca, WI 54654',17247,222,NULL,58,24188,0);
INSERT INTO "django_geo_db_location" VALUES(41729,NULL,'Soldiers Grove, WI',17248,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41730,NULL,'Soldiers Grove, WI 54655',17248,222,NULL,58,24189,0);
INSERT INTO "django_geo_db_location" VALUES(41731,NULL,'Sparta, WI',17249,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41732,NULL,'Sparta, WI 54656',17249,222,NULL,58,24190,0);
INSERT INTO "django_geo_db_location" VALUES(41733,NULL,'Steuben, WI',17250,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41734,NULL,'Steuben, WI 54657',17250,222,NULL,58,24191,0);
INSERT INTO "django_geo_db_location" VALUES(41735,NULL,'Stoddard, WI',17251,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41736,NULL,'Stoddard, WI 54658',17251,222,NULL,58,24192,0);
INSERT INTO "django_geo_db_location" VALUES(41737,NULL,'Taylor, WI',17252,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41738,NULL,'Taylor, WI 54659',17252,222,NULL,58,24193,0);
INSERT INTO "django_geo_db_location" VALUES(41739,NULL,'Tomah, WI',17253,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41740,NULL,'Tomah, WI 54660',17253,222,NULL,58,24194,0);
INSERT INTO "django_geo_db_location" VALUES(41741,NULL,'Trempealeau, WI',17254,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41742,NULL,'Trempealeau, WI 54661',17254,222,NULL,58,24195,0);
INSERT INTO "django_geo_db_location" VALUES(41743,NULL,'Tunnel City, WI',17255,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41744,NULL,'Tunnel City, WI 54662',17255,222,NULL,58,24196,0);
INSERT INTO "django_geo_db_location" VALUES(41745,NULL,'Viola, WI',17256,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41746,NULL,'Viola, WI 54664',17256,222,NULL,58,24197,0);
INSERT INTO "django_geo_db_location" VALUES(41747,NULL,'Viroqua, WI',17257,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41748,NULL,'Viroqua, WI 54665',17257,222,NULL,58,24198,0);
INSERT INTO "django_geo_db_location" VALUES(41749,NULL,'Warrens, WI',17258,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41750,NULL,'Warrens, WI 54666',17258,222,NULL,58,24199,0);
INSERT INTO "django_geo_db_location" VALUES(41751,NULL,'Westby, WI',17259,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41752,NULL,'Westby, WI 54667',17259,222,NULL,58,24200,0);
INSERT INTO "django_geo_db_location" VALUES(41753,NULL,'West Salem, WI',17260,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41754,NULL,'West Salem, WI 54669',17260,222,NULL,58,24201,0);
INSERT INTO "django_geo_db_location" VALUES(41755,NULL,'Wilton, WI',17261,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41756,NULL,'Wilton, WI 54670',17261,222,NULL,58,24202,0);
INSERT INTO "django_geo_db_location" VALUES(41757,NULL,'West Salem, WI 54699',17260,222,NULL,58,24203,0);
INSERT INTO "django_geo_db_location" VALUES(41758,NULL,'Eau Claire, WI',17262,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41759,NULL,'Eau Claire, WI 54701',17262,222,NULL,58,24204,0);
INSERT INTO "django_geo_db_location" VALUES(41760,NULL,'Eau Claire, WI 54702',17262,222,NULL,58,24205,0);
INSERT INTO "django_geo_db_location" VALUES(41761,NULL,'Eau Claire, WI 54703',17262,222,NULL,58,24206,0);
INSERT INTO "django_geo_db_location" VALUES(41762,NULL,'Altoona, WI',17263,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41763,NULL,'Altoona, WI 54720',17263,222,NULL,58,24207,0);
INSERT INTO "django_geo_db_location" VALUES(41764,NULL,'Arkansaw, WI',17264,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41765,NULL,'Arkansaw, WI 54721',17264,222,NULL,58,24208,0);
INSERT INTO "django_geo_db_location" VALUES(41766,NULL,'Augusta, WI',17265,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41767,NULL,'Augusta, WI 54722',17265,222,NULL,58,24209,0);
INSERT INTO "django_geo_db_location" VALUES(41768,NULL,'Bay City, WI',17266,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41769,NULL,'Bay City, WI 54723',17266,222,NULL,58,24210,0);
INSERT INTO "django_geo_db_location" VALUES(41770,NULL,'Bloomer, WI',17267,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41771,NULL,'Bloomer, WI 54724',17267,222,NULL,58,24211,0);
INSERT INTO "django_geo_db_location" VALUES(41772,NULL,'Boyceville, WI',17268,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41773,NULL,'Boyceville, WI 54725',17268,222,NULL,58,24212,0);
INSERT INTO "django_geo_db_location" VALUES(41774,NULL,'Boyd, WI',17269,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41775,NULL,'Boyd, WI 54726',17269,222,NULL,58,24213,0);
INSERT INTO "django_geo_db_location" VALUES(41776,NULL,'Cadott, WI',17270,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41777,NULL,'Cadott, WI 54727',17270,222,NULL,58,24214,0);
INSERT INTO "django_geo_db_location" VALUES(41778,NULL,'Chetek, WI',17271,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41779,NULL,'Chetek, WI 54728',17271,222,NULL,58,24215,0);
INSERT INTO "django_geo_db_location" VALUES(41780,NULL,'Chippewa Falls, WI',17272,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41781,NULL,'Chippewa Falls, WI 54729',17272,222,NULL,58,24216,0);
INSERT INTO "django_geo_db_location" VALUES(41782,NULL,'Colfax, WI',17273,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41783,NULL,'Colfax, WI 54730',17273,222,NULL,58,24217,0);
INSERT INTO "django_geo_db_location" VALUES(41784,NULL,'Conrath, WI',17274,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41785,NULL,'Conrath, WI 54731',17274,222,NULL,58,24218,0);
INSERT INTO "django_geo_db_location" VALUES(41786,NULL,'Cornell, WI',17275,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41787,NULL,'Cornell, WI 54732',17275,222,NULL,58,24219,0);
INSERT INTO "django_geo_db_location" VALUES(41788,NULL,'Dallas, WI',17276,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41789,NULL,'Dallas, WI 54733',17276,222,NULL,58,24220,0);
INSERT INTO "django_geo_db_location" VALUES(41790,NULL,'Downing, WI',17277,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41791,NULL,'Downing, WI 54734',17277,222,NULL,58,24221,0);
INSERT INTO "django_geo_db_location" VALUES(41792,NULL,'Downsville, WI',17278,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41793,NULL,'Downsville, WI 54735',17278,222,NULL,58,24222,0);
INSERT INTO "django_geo_db_location" VALUES(41794,NULL,'Durand, WI',17279,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41795,NULL,'Durand, WI 54736',17279,222,NULL,58,24223,0);
INSERT INTO "django_geo_db_location" VALUES(41796,NULL,'Eau Galle, WI',17280,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41797,NULL,'Eau Galle, WI 54737',17280,222,NULL,58,24224,0);
INSERT INTO "django_geo_db_location" VALUES(41798,NULL,'Eleva, WI',17281,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41799,NULL,'Eleva, WI 54738',17281,222,NULL,58,24225,0);
INSERT INTO "django_geo_db_location" VALUES(41800,NULL,'Elk Mound, WI',17282,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41801,NULL,'Elk Mound, WI 54739',17282,222,NULL,58,24226,0);
INSERT INTO "django_geo_db_location" VALUES(41802,NULL,'Elmwood, WI',17283,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41803,NULL,'Elmwood, WI 54740',17283,222,NULL,58,24227,0);
INSERT INTO "django_geo_db_location" VALUES(41804,NULL,'Fairchild, WI',17284,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41805,NULL,'Fairchild, WI 54741',17284,222,NULL,58,24228,0);
INSERT INTO "django_geo_db_location" VALUES(41806,NULL,'Fall Creek, WI',17285,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41807,NULL,'Fall Creek, WI 54742',17285,222,NULL,58,24229,0);
INSERT INTO "django_geo_db_location" VALUES(41808,NULL,'Gilmanton, WI',17286,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41809,NULL,'Gilmanton, WI 54743',17286,222,NULL,58,24230,0);
INSERT INTO "django_geo_db_location" VALUES(41810,NULL,'Hillsdale, WI',17287,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41811,NULL,'Hillsdale, WI 54744',17287,222,NULL,58,24231,0);
INSERT INTO "django_geo_db_location" VALUES(41812,NULL,'Holcombe, WI',17288,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41813,NULL,'Holcombe, WI 54745',17288,222,NULL,58,24232,0);
INSERT INTO "django_geo_db_location" VALUES(41814,NULL,'Humbird, WI',17289,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41815,NULL,'Humbird, WI 54746',17289,222,NULL,58,24233,0);
INSERT INTO "django_geo_db_location" VALUES(41816,NULL,'Independence, WI',17290,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41817,NULL,'Independence, WI 54747',17290,222,NULL,58,24234,0);
INSERT INTO "django_geo_db_location" VALUES(41818,NULL,'Jim Falls, WI',17291,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41819,NULL,'Jim Falls, WI 54748',17291,222,NULL,58,24235,0);
INSERT INTO "django_geo_db_location" VALUES(41820,NULL,'Knapp, WI',17292,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41821,NULL,'Knapp, WI 54749',17292,222,NULL,58,24236,0);
INSERT INTO "django_geo_db_location" VALUES(41822,NULL,'Maiden Rock, WI',17293,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41823,NULL,'Maiden Rock, WI 54750',17293,222,NULL,58,24237,0);
INSERT INTO "django_geo_db_location" VALUES(41824,NULL,'Menomonie, WI',17294,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41825,NULL,'Menomonie, WI 54751',17294,222,NULL,58,24238,0);
INSERT INTO "django_geo_db_location" VALUES(41826,NULL,'Merrillan, WI',17295,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41827,NULL,'Merrillan, WI 54754',17295,222,NULL,58,24239,0);
INSERT INTO "django_geo_db_location" VALUES(41828,NULL,'Mondovi, WI',17296,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41829,NULL,'Mondovi, WI 54755',17296,222,NULL,58,24240,0);
INSERT INTO "django_geo_db_location" VALUES(41830,NULL,'Nelson, WI',17297,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41831,NULL,'Nelson, WI 54756',17297,222,NULL,58,24241,0);
INSERT INTO "django_geo_db_location" VALUES(41832,NULL,'New Auburn, WI',17298,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41833,NULL,'New Auburn, WI 54757',17298,222,NULL,58,24242,0);
INSERT INTO "django_geo_db_location" VALUES(41834,NULL,'Osseo, WI',17299,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41835,NULL,'Osseo, WI 54758',17299,222,NULL,58,24243,0);
INSERT INTO "django_geo_db_location" VALUES(41836,NULL,'Pepin, WI',17300,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41837,NULL,'Pepin, WI 54759',17300,222,NULL,58,24244,0);
INSERT INTO "django_geo_db_location" VALUES(41838,NULL,'Pigeon Falls, WI',17301,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41839,NULL,'Pigeon Falls, WI 54760',17301,222,NULL,58,24245,0);
INSERT INTO "django_geo_db_location" VALUES(41840,NULL,'Plum City, WI',17302,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41841,NULL,'Plum City, WI 54761',17302,222,NULL,58,24246,0);
INSERT INTO "django_geo_db_location" VALUES(41842,NULL,'Prairie Farm, WI',17303,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41843,NULL,'Prairie Farm, WI 54762',17303,222,NULL,58,24247,0);
INSERT INTO "django_geo_db_location" VALUES(41844,NULL,'Ridgeland, WI',17304,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41845,NULL,'Ridgeland, WI 54763',17304,222,NULL,58,24248,0);
INSERT INTO "django_geo_db_location" VALUES(41846,NULL,'Rock Falls, WI',17305,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41847,NULL,'Rock Falls, WI 54764',17305,222,NULL,58,24249,0);
INSERT INTO "django_geo_db_location" VALUES(41848,NULL,'Sand Creek, WI',17306,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41849,NULL,'Sand Creek, WI 54765',17306,222,NULL,58,24250,0);
INSERT INTO "django_geo_db_location" VALUES(41850,NULL,'Sheldon, WI',17307,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41851,NULL,'Sheldon, WI 54766',17307,222,NULL,58,24251,0);
INSERT INTO "django_geo_db_location" VALUES(41852,NULL,'Spring Valley, WI',17308,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41853,NULL,'Spring Valley, WI 54767',17308,222,NULL,58,24252,0);
INSERT INTO "django_geo_db_location" VALUES(41854,NULL,'Stanley, WI',17309,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41855,NULL,'Stanley, WI 54768',17309,222,NULL,58,24253,0);
INSERT INTO "django_geo_db_location" VALUES(41856,NULL,'Stockholm, WI',17310,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41857,NULL,'Stockholm, WI 54769',17310,222,NULL,58,24254,0);
INSERT INTO "django_geo_db_location" VALUES(41858,NULL,'Strum, WI',17311,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41859,NULL,'Strum, WI 54770',17311,222,NULL,58,24255,0);
INSERT INTO "django_geo_db_location" VALUES(41860,NULL,'Thorp, WI',17312,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41861,NULL,'Thorp, WI 54771',17312,222,NULL,58,24256,0);
INSERT INTO "django_geo_db_location" VALUES(41862,NULL,'Wheeler, WI',17313,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41863,NULL,'Wheeler, WI 54772',17313,222,NULL,58,24257,0);
INSERT INTO "django_geo_db_location" VALUES(41864,NULL,'Whitehall, WI',17314,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41865,NULL,'Whitehall, WI 54773',17314,222,NULL,58,24258,0);
INSERT INTO "django_geo_db_location" VALUES(41866,NULL,'Chippewa Falls, WI 54774',17272,222,NULL,58,24259,0);
INSERT INTO "django_geo_db_location" VALUES(41867,NULL,'Spooner, WI',17315,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41868,NULL,'Spooner, WI 54801',17315,222,NULL,58,24260,0);
INSERT INTO "django_geo_db_location" VALUES(41869,NULL,'Almena, WI',17316,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41870,NULL,'Almena, WI 54805',17316,222,NULL,58,24261,0);
INSERT INTO "django_geo_db_location" VALUES(41871,NULL,'Ashland, WI',17317,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41872,NULL,'Ashland, WI 54806',17317,222,NULL,58,24262,0);
INSERT INTO "django_geo_db_location" VALUES(41873,NULL,'Balsam Lake, WI',17318,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41874,NULL,'Balsam Lake, WI 54810',17318,222,NULL,58,24263,0);
INSERT INTO "django_geo_db_location" VALUES(41875,NULL,'Barron, WI',17319,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41876,NULL,'Barron, WI 54812',17319,222,NULL,58,24264,0);
INSERT INTO "django_geo_db_location" VALUES(41877,NULL,'Barronett, WI',17320,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41878,NULL,'Barronett, WI 54813',17320,222,NULL,58,24265,0);
INSERT INTO "django_geo_db_location" VALUES(41879,NULL,'Bayfield, WI',17321,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41880,NULL,'Bayfield, WI 54814',17321,222,NULL,58,24266,0);
INSERT INTO "django_geo_db_location" VALUES(41881,NULL,'Benoit, WI',17322,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41882,NULL,'Benoit, WI 54816',17322,222,NULL,58,24267,0);
INSERT INTO "django_geo_db_location" VALUES(41883,NULL,'Birchwood, WI',17323,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41884,NULL,'Birchwood, WI 54817',17323,222,NULL,58,24268,0);
INSERT INTO "django_geo_db_location" VALUES(41885,NULL,'Brill, WI',17324,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41886,NULL,'Brill, WI 54818',17324,222,NULL,58,24269,0);
INSERT INTO "django_geo_db_location" VALUES(41887,NULL,'Bruce, WI',17325,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41888,NULL,'Bruce, WI 54819',17325,222,NULL,58,24270,0);
INSERT INTO "django_geo_db_location" VALUES(41889,NULL,'Brule, WI',17326,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41890,NULL,'Brule, WI 54820',17326,222,NULL,58,24271,0);
INSERT INTO "django_geo_db_location" VALUES(41891,NULL,'Cable, WI',17327,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41892,NULL,'Cable, WI 54821',17327,222,NULL,58,24272,0);
INSERT INTO "django_geo_db_location" VALUES(41893,NULL,'Cameron, WI',17328,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41894,NULL,'Cameron, WI 54822',17328,222,NULL,58,24273,0);
INSERT INTO "django_geo_db_location" VALUES(41895,NULL,'Centuria, WI',17329,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41896,NULL,'Centuria, WI 54824',17329,222,NULL,58,24274,0);
INSERT INTO "django_geo_db_location" VALUES(41897,NULL,'Comstock, WI',17330,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41898,NULL,'Comstock, WI 54826',17330,222,NULL,58,24275,0);
INSERT INTO "django_geo_db_location" VALUES(41899,NULL,'Cornucopia, WI',17331,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41900,NULL,'Cornucopia, WI 54827',17331,222,NULL,58,24276,0);
INSERT INTO "django_geo_db_location" VALUES(41901,NULL,'Couderay, WI',17332,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41902,NULL,'Couderay, WI 54828',17332,222,NULL,58,24277,0);
INSERT INTO "django_geo_db_location" VALUES(41903,NULL,'Cumberland, WI',17333,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41904,NULL,'Cumberland, WI 54829',17333,222,NULL,58,24278,0);
INSERT INTO "django_geo_db_location" VALUES(41905,NULL,'Danbury, WI',17334,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41906,NULL,'Danbury, WI 54830',17334,222,NULL,58,24279,0);
INSERT INTO "django_geo_db_location" VALUES(41907,NULL,'Drummond, WI',17335,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41908,NULL,'Drummond, WI 54832',17335,222,NULL,58,24280,0);
INSERT INTO "django_geo_db_location" VALUES(41909,NULL,'Edgewater, WI',17336,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41910,NULL,'Edgewater, WI 54834',17336,222,NULL,58,24281,0);
INSERT INTO "django_geo_db_location" VALUES(41911,NULL,'Exeland, WI',17337,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41912,NULL,'Exeland, WI 54835',17337,222,NULL,58,24282,0);
INSERT INTO "django_geo_db_location" VALUES(41913,NULL,'Foxboro, WI',17338,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41914,NULL,'Foxboro, WI 54836',17338,222,NULL,58,24283,0);
INSERT INTO "django_geo_db_location" VALUES(41915,NULL,'Frederic, WI',17339,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41916,NULL,'Frederic, WI 54837',17339,222,NULL,58,24284,0);
INSERT INTO "django_geo_db_location" VALUES(41917,NULL,'Gordon, WI',17340,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41918,NULL,'Gordon, WI 54838',17340,222,NULL,58,24285,0);
INSERT INTO "django_geo_db_location" VALUES(41919,NULL,'Grand View, WI',17341,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41920,NULL,'Grand View, WI 54839',17341,222,NULL,58,24286,0);
INSERT INTO "django_geo_db_location" VALUES(41921,NULL,'Grantsburg, WI',17342,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41922,NULL,'Grantsburg, WI 54840',17342,222,NULL,58,24287,0);
INSERT INTO "django_geo_db_location" VALUES(41923,NULL,'Haugen, WI',17343,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41924,NULL,'Haugen, WI 54841',17343,222,NULL,58,24288,0);
INSERT INTO "django_geo_db_location" VALUES(41925,NULL,'Hawthorne, WI',17344,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41926,NULL,'Hawthorne, WI 54842',17344,222,NULL,58,24289,0);
INSERT INTO "django_geo_db_location" VALUES(41927,NULL,'Hayward, WI',17345,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41928,NULL,'Hayward, WI 54843',17345,222,NULL,58,24290,0);
INSERT INTO "django_geo_db_location" VALUES(41929,NULL,'Herbster, WI',17346,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41930,NULL,'Herbster, WI 54844',17346,222,NULL,58,24291,0);
INSERT INTO "django_geo_db_location" VALUES(41931,NULL,'Hertel, WI',17347,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41932,NULL,'Hertel, WI 54845',17347,222,NULL,58,24292,0);
INSERT INTO "django_geo_db_location" VALUES(41933,NULL,'High Bridge, WI',17348,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41934,NULL,'High Bridge, WI 54846',17348,222,NULL,58,24293,0);
INSERT INTO "django_geo_db_location" VALUES(41935,NULL,'Iron River, WI',17349,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41936,NULL,'Iron River, WI 54847',17349,222,NULL,58,24294,0);
INSERT INTO "django_geo_db_location" VALUES(41937,NULL,'Ladysmith, WI',17350,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41938,NULL,'Ladysmith, WI 54848',17350,222,NULL,58,24295,0);
INSERT INTO "django_geo_db_location" VALUES(41939,NULL,'Lake Nebagamon, WI',17351,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41940,NULL,'Lake Nebagamon, WI 54849',17351,222,NULL,58,24296,0);
INSERT INTO "django_geo_db_location" VALUES(41941,NULL,'La Pointe, WI',17352,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41942,NULL,'La Pointe, WI 54850',17352,222,NULL,58,24297,0);
INSERT INTO "django_geo_db_location" VALUES(41943,NULL,'Lewis, WI',17353,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41944,NULL,'Lewis, WI 54851',17353,222,NULL,58,24298,0);
INSERT INTO "django_geo_db_location" VALUES(41945,NULL,'Luck, WI',17354,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41946,NULL,'Luck, WI 54853',17354,222,NULL,58,24299,0);
INSERT INTO "django_geo_db_location" VALUES(41947,NULL,'Maple, WI',17355,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41948,NULL,'Maple, WI 54854',17355,222,NULL,58,24300,0);
INSERT INTO "django_geo_db_location" VALUES(41949,NULL,'Marengo, WI',17356,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41950,NULL,'Marengo, WI 54855',17356,222,NULL,58,24301,0);
INSERT INTO "django_geo_db_location" VALUES(41951,NULL,'Mason, WI',17357,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41952,NULL,'Mason, WI 54856',17357,222,NULL,58,24302,0);
INSERT INTO "django_geo_db_location" VALUES(41953,NULL,'Mikana, WI',17358,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41954,NULL,'Mikana, WI 54857',17358,222,NULL,58,24303,0);
INSERT INTO "django_geo_db_location" VALUES(41955,NULL,'Milltown, WI',17359,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41956,NULL,'Milltown, WI 54858',17359,222,NULL,58,24304,0);
INSERT INTO "django_geo_db_location" VALUES(41957,NULL,'Minong, WI',17360,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41958,NULL,'Minong, WI 54859',17360,222,NULL,58,24305,0);
INSERT INTO "django_geo_db_location" VALUES(41959,NULL,'Odanah, WI',17361,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41960,NULL,'Odanah, WI 54861',17361,222,NULL,58,24306,0);
INSERT INTO "django_geo_db_location" VALUES(41961,NULL,'Ojibwa, WI',17362,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41962,NULL,'Ojibwa, WI 54862',17362,222,NULL,58,24307,0);
INSERT INTO "django_geo_db_location" VALUES(41963,NULL,'Stanley, WI 54863',17309,222,NULL,58,24308,0);
INSERT INTO "django_geo_db_location" VALUES(41964,NULL,'Poplar, WI',17363,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41965,NULL,'Poplar, WI 54864',17363,222,NULL,58,24309,0);
INSERT INTO "django_geo_db_location" VALUES(41966,NULL,'Port Wing, WI',17364,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41967,NULL,'Port Wing, WI 54865',17364,222,NULL,58,24310,0);
INSERT INTO "django_geo_db_location" VALUES(41968,NULL,'Radisson, WI',17365,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41969,NULL,'Radisson, WI 54867',17365,222,NULL,58,24311,0);
INSERT INTO "django_geo_db_location" VALUES(41970,NULL,'Rice Lake, WI',17366,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41971,NULL,'Rice Lake, WI 54868',17366,222,NULL,58,24312,0);
INSERT INTO "django_geo_db_location" VALUES(41972,NULL,'Sarona, WI',17367,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41973,NULL,'Sarona, WI 54870',17367,222,NULL,58,24313,0);
INSERT INTO "django_geo_db_location" VALUES(41974,NULL,'Shell Lake, WI',17368,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41975,NULL,'Shell Lake, WI 54871',17368,222,NULL,58,24314,0);
INSERT INTO "django_geo_db_location" VALUES(41976,NULL,'Siren, WI',17369,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41977,NULL,'Siren, WI 54872',17369,222,NULL,58,24315,0);
INSERT INTO "django_geo_db_location" VALUES(41978,NULL,'Solon Springs, WI',17370,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41979,NULL,'Solon Springs, WI 54873',17370,222,NULL,58,24316,0);
INSERT INTO "django_geo_db_location" VALUES(41980,NULL,'South Range, WI',17371,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41981,NULL,'South Range, WI 54874',17371,222,NULL,58,24317,0);
INSERT INTO "django_geo_db_location" VALUES(41982,NULL,'Springbrook, WI',17372,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41983,NULL,'Springbrook, WI 54875',17372,222,NULL,58,24318,0);
INSERT INTO "django_geo_db_location" VALUES(41984,NULL,'Stone Lake, WI',17373,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41985,NULL,'Stone Lake, WI 54876',17373,222,NULL,58,24319,0);
INSERT INTO "django_geo_db_location" VALUES(41986,NULL,'Superior, WI',17374,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41987,NULL,'Superior, WI 54880',17374,222,NULL,58,24320,0);
INSERT INTO "django_geo_db_location" VALUES(41988,NULL,'Winter, WI',17375,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41989,NULL,'Winter, WI 54886',17375,222,NULL,58,24321,0);
INSERT INTO "django_geo_db_location" VALUES(41990,NULL,'Trego, WI',17376,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41991,NULL,'Trego, WI 54888',17376,222,NULL,58,24322,0);
INSERT INTO "django_geo_db_location" VALUES(41992,NULL,'Turtle Lake, WI',17377,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41993,NULL,'Turtle Lake, WI 54889',17377,222,NULL,58,24323,0);
INSERT INTO "django_geo_db_location" VALUES(41994,NULL,'Wascott, WI 54890',17075,222,NULL,58,24324,0);
INSERT INTO "django_geo_db_location" VALUES(41995,NULL,'Washburn, WI',17378,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41996,NULL,'Washburn, WI 54891',17378,222,NULL,58,24325,0);
INSERT INTO "django_geo_db_location" VALUES(41997,NULL,'Webster, WI',17379,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(41998,NULL,'Webster, WI 54893',17379,222,NULL,58,24326,0);
INSERT INTO "django_geo_db_location" VALUES(41999,NULL,'Weyerhaeuser, WI',17380,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42000,NULL,'Weyerhaeuser, WI 54895',17380,222,NULL,58,24327,0);
INSERT INTO "django_geo_db_location" VALUES(42001,NULL,'Winter, WI 54896',17375,222,NULL,58,24328,0);
INSERT INTO "django_geo_db_location" VALUES(42002,NULL,'Oshkosh, WI',17381,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42003,NULL,'Oshkosh, WI 54901',17381,222,NULL,58,24329,0);
INSERT INTO "django_geo_db_location" VALUES(42004,NULL,'Oshkosh, WI 54902',17381,222,NULL,58,24330,0);
INSERT INTO "django_geo_db_location" VALUES(42005,NULL,'Oshkosh, WI 54903',17381,222,NULL,58,24331,0);
INSERT INTO "django_geo_db_location" VALUES(42006,NULL,'Oshkosh, WI 54904',17381,222,NULL,58,24332,0);
INSERT INTO "django_geo_db_location" VALUES(42007,NULL,'Oshkosh, WI 54906',17381,222,NULL,58,24333,0);
INSERT INTO "django_geo_db_location" VALUES(42008,NULL,'Almond, WI',17382,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42009,NULL,'Almond, WI 54909',17382,222,NULL,58,24334,0);
INSERT INTO "django_geo_db_location" VALUES(42010,NULL,'Appleton, WI',17383,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42011,NULL,'Appleton, WI 54911',17383,222,NULL,58,24335,0);
INSERT INTO "django_geo_db_location" VALUES(42012,NULL,'Appleton, WI 54912',17383,222,NULL,58,24336,0);
INSERT INTO "django_geo_db_location" VALUES(42013,NULL,'Appleton, WI 54913',17383,222,NULL,58,24337,0);
INSERT INTO "django_geo_db_location" VALUES(42014,NULL,'Appleton, WI 54914',17383,222,NULL,58,24338,0);
INSERT INTO "django_geo_db_location" VALUES(42015,NULL,'Appleton, WI 54915',17383,222,NULL,58,24339,0);
INSERT INTO "django_geo_db_location" VALUES(42016,NULL,'Appleton, WI 54919',17383,222,NULL,58,24340,0);
INSERT INTO "django_geo_db_location" VALUES(42017,NULL,'Bancroft, WI',17384,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42018,NULL,'Bancroft, WI 54921',17384,222,NULL,58,24341,0);
INSERT INTO "django_geo_db_location" VALUES(42019,NULL,'Bear Creek, WI',17385,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42020,NULL,'Bear Creek, WI 54922',17385,222,NULL,58,24342,0);
INSERT INTO "django_geo_db_location" VALUES(42021,NULL,'Berlin, WI',17386,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42022,NULL,'Berlin, WI 54923',17386,222,NULL,58,24343,0);
INSERT INTO "django_geo_db_location" VALUES(42023,NULL,'Big Falls, WI',17387,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42024,NULL,'Big Falls, WI 54926',17387,222,NULL,58,24344,0);
INSERT INTO "django_geo_db_location" VALUES(42025,NULL,'Butte Des Morts, WI',17388,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42026,NULL,'Butte Des Morts, WI 54927',17388,222,NULL,58,24345,0);
INSERT INTO "django_geo_db_location" VALUES(42027,NULL,'Caroline, WI',17389,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42028,NULL,'Caroline, WI 54928',17389,222,NULL,58,24346,0);
INSERT INTO "django_geo_db_location" VALUES(42029,NULL,'Clintonville, WI',17390,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42030,NULL,'Clintonville, WI 54929',17390,222,NULL,58,24347,0);
INSERT INTO "django_geo_db_location" VALUES(42031,NULL,'Coloma, WI',17391,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42032,NULL,'Coloma, WI 54930',17391,222,NULL,58,24348,0);
INSERT INTO "django_geo_db_location" VALUES(42033,NULL,'Dale, WI',17392,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42034,NULL,'Dale, WI 54931',17392,222,NULL,58,24349,0);
INSERT INTO "django_geo_db_location" VALUES(42035,NULL,'Eldorado, WI',17393,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42036,NULL,'Eldorado, WI 54932',17393,222,NULL,58,24350,0);
INSERT INTO "django_geo_db_location" VALUES(42037,NULL,'Embarrass, WI',17394,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42038,NULL,'Embarrass, WI 54933',17394,222,NULL,58,24351,0);
INSERT INTO "django_geo_db_location" VALUES(42039,NULL,'Eureka, WI',17395,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42040,NULL,'Eureka, WI 54934',17395,222,NULL,58,24352,0);
INSERT INTO "django_geo_db_location" VALUES(42041,NULL,'Fond Du Lac, WI',17396,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42042,NULL,'Fond Du Lac, WI 54935',17396,222,NULL,58,24353,0);
INSERT INTO "django_geo_db_location" VALUES(42043,NULL,'Fond Du Lac, WI 54936',17396,222,NULL,58,24354,0);
INSERT INTO "django_geo_db_location" VALUES(42044,NULL,'Fond Du Lac, WI 54937',17396,222,NULL,58,24355,0);
INSERT INTO "django_geo_db_location" VALUES(42045,NULL,'Fremont, WI',17397,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42046,NULL,'Fremont, WI 54940',17397,222,NULL,58,24356,0);
INSERT INTO "django_geo_db_location" VALUES(42047,NULL,'Green Lake, WI',17398,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42048,NULL,'Green Lake, WI 54941',17398,222,NULL,58,24357,0);
INSERT INTO "django_geo_db_location" VALUES(42049,NULL,'Greenville, WI',17399,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42050,NULL,'Greenville, WI 54942',17399,222,NULL,58,24358,0);
INSERT INTO "django_geo_db_location" VALUES(42051,NULL,'Hancock, WI',17400,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42052,NULL,'Hancock, WI 54943',17400,222,NULL,58,24359,0);
INSERT INTO "django_geo_db_location" VALUES(42053,NULL,'Hortonville, WI',17401,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42054,NULL,'Hortonville, WI 54944',17401,222,NULL,58,24360,0);
INSERT INTO "django_geo_db_location" VALUES(42055,NULL,'Iola, WI',17402,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42056,NULL,'Iola, WI 54945',17402,222,NULL,58,24361,0);
INSERT INTO "django_geo_db_location" VALUES(42057,NULL,'King, WI',17403,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42058,NULL,'King, WI 54946',17403,222,NULL,58,24362,0);
INSERT INTO "django_geo_db_location" VALUES(42059,NULL,'Larsen, WI',17404,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42060,NULL,'Larsen, WI 54947',17404,222,NULL,58,24363,0);
INSERT INTO "django_geo_db_location" VALUES(42061,NULL,'Leopolis, WI',17405,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42062,NULL,'Leopolis, WI 54948',17405,222,NULL,58,24364,0);
INSERT INTO "django_geo_db_location" VALUES(42063,NULL,'Manawa, WI',17406,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42064,NULL,'Manawa, WI 54949',17406,222,NULL,58,24365,0);
INSERT INTO "django_geo_db_location" VALUES(42065,NULL,'Marion, WI',17407,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42066,NULL,'Marion, WI 54950',17407,222,NULL,58,24366,0);
INSERT INTO "django_geo_db_location" VALUES(42067,NULL,'Medina, WI',17408,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42068,NULL,'Medina, WI 54951',17408,222,NULL,58,24367,0);
INSERT INTO "django_geo_db_location" VALUES(42069,NULL,'Menasha, WI',17409,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42070,NULL,'Menasha, WI 54952',17409,222,NULL,58,24368,0);
INSERT INTO "django_geo_db_location" VALUES(42071,NULL,'Neenah, WI',17410,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42072,NULL,'Neenah, WI 54956',17410,222,NULL,58,24369,0);
INSERT INTO "django_geo_db_location" VALUES(42073,NULL,'Neenah, WI 54957',17410,222,NULL,58,24370,0);
INSERT INTO "django_geo_db_location" VALUES(42074,NULL,'Neshkoro, WI',17411,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42075,NULL,'Neshkoro, WI 54960',17411,222,NULL,58,24371,0);
INSERT INTO "django_geo_db_location" VALUES(42076,NULL,'New London, WI 54961',16981,222,NULL,58,24372,0);
INSERT INTO "django_geo_db_location" VALUES(42077,NULL,'Ogdensburg, WI',17412,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42078,NULL,'Ogdensburg, WI 54962',17412,222,NULL,58,24373,0);
INSERT INTO "django_geo_db_location" VALUES(42079,NULL,'Omro, WI',17413,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42080,NULL,'Omro, WI 54963',17413,222,NULL,58,24374,0);
INSERT INTO "django_geo_db_location" VALUES(42081,NULL,'Pickett, WI',17414,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42082,NULL,'Pickett, WI 54964',17414,222,NULL,58,24375,0);
INSERT INTO "django_geo_db_location" VALUES(42083,NULL,'Pine River, WI',17415,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42084,NULL,'Pine River, WI 54965',17415,222,NULL,58,24376,0);
INSERT INTO "django_geo_db_location" VALUES(42085,NULL,'Plainfield, WI',17416,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42086,NULL,'Plainfield, WI 54966',17416,222,NULL,58,24377,0);
INSERT INTO "django_geo_db_location" VALUES(42087,NULL,'Poy Sippi, WI',17417,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42088,NULL,'Poy Sippi, WI 54967',17417,222,NULL,58,24378,0);
INSERT INTO "django_geo_db_location" VALUES(42089,NULL,'Princeton, WI',17418,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42090,NULL,'Princeton, WI 54968',17418,222,NULL,58,24379,0);
INSERT INTO "django_geo_db_location" VALUES(42091,NULL,'Readfield, WI',17419,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42092,NULL,'Readfield, WI 54969',17419,222,NULL,58,24380,0);
INSERT INTO "django_geo_db_location" VALUES(42093,NULL,'Redgranite, WI',17420,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42094,NULL,'Redgranite, WI 54970',17420,222,NULL,58,24381,0);
INSERT INTO "django_geo_db_location" VALUES(42095,NULL,'Ripon, WI',17421,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42096,NULL,'Ripon, WI 54971',17421,222,NULL,58,24382,0);
INSERT INTO "django_geo_db_location" VALUES(42097,NULL,'Rosendale, WI',17422,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42098,NULL,'Rosendale, WI 54974',17422,222,NULL,58,24383,0);
INSERT INTO "django_geo_db_location" VALUES(42099,NULL,'Royalton, WI',17423,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42100,NULL,'Royalton, WI 54975',17423,222,NULL,58,24384,0);
INSERT INTO "django_geo_db_location" VALUES(42101,NULL,'Saxeville, WI',17424,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42102,NULL,'Saxeville, WI 54976',17424,222,NULL,58,24385,0);
INSERT INTO "django_geo_db_location" VALUES(42103,NULL,'Scandinavia, WI',17425,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42104,NULL,'Scandinavia, WI 54977',17425,222,NULL,58,24386,0);
INSERT INTO "django_geo_db_location" VALUES(42105,NULL,'Tilleda, WI',17426,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42106,NULL,'Tilleda, WI 54978',17426,222,NULL,58,24387,0);
INSERT INTO "django_geo_db_location" VALUES(42107,NULL,'Van Dyne, WI',17427,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42108,NULL,'Van Dyne, WI 54979',17427,222,NULL,58,24388,0);
INSERT INTO "django_geo_db_location" VALUES(42109,NULL,'Waukau, WI',17428,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42110,NULL,'Waukau, WI 54980',17428,222,NULL,58,24389,0);
INSERT INTO "django_geo_db_location" VALUES(42111,NULL,'Waupaca, WI',17429,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42112,NULL,'Waupaca, WI 54981',17429,222,NULL,58,24390,0);
INSERT INTO "django_geo_db_location" VALUES(42113,NULL,'Wautoma, WI',17430,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42114,NULL,'Wautoma, WI 54982',17430,222,NULL,58,24391,0);
INSERT INTO "django_geo_db_location" VALUES(42115,NULL,'Weyauwega, WI',17431,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42116,NULL,'Weyauwega, WI 54983',17431,222,NULL,58,24392,0);
INSERT INTO "django_geo_db_location" VALUES(42117,NULL,'Wild Rose, WI',17432,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42118,NULL,'Wild Rose, WI 54984',17432,222,NULL,58,24393,0);
INSERT INTO "django_geo_db_location" VALUES(42119,NULL,'Winnebago, WI',17433,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42120,NULL,'Winnebago, WI 54985',17433,222,NULL,58,24394,0);
INSERT INTO "django_geo_db_location" VALUES(42121,NULL,'Winneconne, WI',17434,222,NULL,58,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42122,NULL,'Winneconne, WI 54986',17434,222,NULL,58,24395,0);
INSERT INTO "django_geo_db_location" VALUES(42123,NULL,'Iola, WI 54990',17402,222,NULL,58,24396,0);
INSERT INTO "django_geo_db_location" VALUES(42124,NULL,'Afton, MN',17435,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42125,NULL,'Afton, MN 55001',17435,222,NULL,41,24397,0);
INSERT INTO "django_geo_db_location" VALUES(42126,NULL,'Almelund, MN',17436,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42127,NULL,'Almelund, MN 55002',17436,222,NULL,41,24398,0);
INSERT INTO "django_geo_db_location" VALUES(42128,NULL,'Bayport, MN',17437,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42129,NULL,'Bayport, MN 55003',17437,222,NULL,41,24399,0);
INSERT INTO "django_geo_db_location" VALUES(42130,NULL,'Bethel, MN',17438,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42131,NULL,'Bethel, MN 55005',17438,222,NULL,41,24400,0);
INSERT INTO "django_geo_db_location" VALUES(42132,NULL,'Braham, MN',17439,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42133,NULL,'Braham, MN 55006',17439,222,NULL,41,24401,0);
INSERT INTO "django_geo_db_location" VALUES(42134,NULL,'Brook Park, MN',17440,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42135,NULL,'Brook Park, MN 55007',17440,222,NULL,41,24402,0);
INSERT INTO "django_geo_db_location" VALUES(42136,NULL,'Cambridge, MN',17441,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42137,NULL,'Cambridge, MN 55008',17441,222,NULL,41,24403,0);
INSERT INTO "django_geo_db_location" VALUES(42138,NULL,'Cannon Falls, MN',17442,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42139,NULL,'Cannon Falls, MN 55009',17442,222,NULL,41,24404,0);
INSERT INTO "django_geo_db_location" VALUES(42140,NULL,'Castle Rock, MN',17443,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42141,NULL,'Castle Rock, MN 55010',17443,222,NULL,41,24405,0);
INSERT INTO "django_geo_db_location" VALUES(42142,NULL,'Cedar, MN',17444,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42143,NULL,'Cedar, MN 55011',17444,222,NULL,41,24406,0);
INSERT INTO "django_geo_db_location" VALUES(42144,NULL,'Center City, MN',17445,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42145,NULL,'Center City, MN 55012',17445,222,NULL,41,24407,0);
INSERT INTO "django_geo_db_location" VALUES(42146,NULL,'Chisago City, MN',17446,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42147,NULL,'Chisago City, MN 55013',17446,222,NULL,41,24408,0);
INSERT INTO "django_geo_db_location" VALUES(42148,NULL,'Circle Pines, MN',17447,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42149,NULL,'Circle Pines, MN 55014',17447,222,NULL,41,24409,0);
INSERT INTO "django_geo_db_location" VALUES(42150,NULL,'Cottage Grove, MN',17448,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42151,NULL,'Cottage Grove, MN 55016',17448,222,NULL,41,24410,0);
INSERT INTO "django_geo_db_location" VALUES(42152,NULL,'Dalbo, MN',17449,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42153,NULL,'Dalbo, MN 55017',17449,222,NULL,41,24411,0);
INSERT INTO "django_geo_db_location" VALUES(42154,NULL,'Dennison, MN',17450,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42155,NULL,'Dennison, MN 55018',17450,222,NULL,41,24412,0);
INSERT INTO "django_geo_db_location" VALUES(42156,NULL,'Dundas, MN',17451,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42157,NULL,'Dundas, MN 55019',17451,222,NULL,41,24413,0);
INSERT INTO "django_geo_db_location" VALUES(42158,NULL,'Elko, MN',17452,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42159,NULL,'Elko, MN 55020',17452,222,NULL,41,24414,0);
INSERT INTO "django_geo_db_location" VALUES(42160,NULL,'Faribault, MN',17453,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42161,NULL,'Faribault, MN 55021',17453,222,NULL,41,24415,0);
INSERT INTO "django_geo_db_location" VALUES(42162,NULL,'Farmington, MN',17454,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42163,NULL,'Farmington, MN 55024',17454,222,NULL,41,24416,0);
INSERT INTO "django_geo_db_location" VALUES(42164,NULL,'Forest Lake, MN',17455,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42165,NULL,'Forest Lake, MN 55025',17455,222,NULL,41,24417,0);
INSERT INTO "django_geo_db_location" VALUES(42166,NULL,'Frontenac, MN',17456,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42167,NULL,'Frontenac, MN 55026',17456,222,NULL,41,24418,0);
INSERT INTO "django_geo_db_location" VALUES(42168,NULL,'Goodhue, MN',17457,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42169,NULL,'Goodhue, MN 55027',17457,222,NULL,41,24419,0);
INSERT INTO "django_geo_db_location" VALUES(42170,NULL,'Grandy, MN',17458,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42171,NULL,'Grandy, MN 55029',17458,222,NULL,41,24420,0);
INSERT INTO "django_geo_db_location" VALUES(42172,NULL,'Grasston, MN',17459,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42173,NULL,'Grasston, MN 55030',17459,222,NULL,41,24421,0);
INSERT INTO "django_geo_db_location" VALUES(42174,NULL,'Hampton, MN',17460,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42175,NULL,'Hampton, MN 55031',17460,222,NULL,41,24422,0);
INSERT INTO "django_geo_db_location" VALUES(42176,NULL,'Harris, MN',17461,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42177,NULL,'Harris, MN 55032',17461,222,NULL,41,24423,0);
INSERT INTO "django_geo_db_location" VALUES(42178,NULL,'Hastings, MN',17462,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42179,NULL,'Hastings, MN 55033',17462,222,NULL,41,24424,0);
INSERT INTO "django_geo_db_location" VALUES(42180,NULL,'Henriette, MN',17463,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42181,NULL,'Henriette, MN 55036',17463,222,NULL,41,24425,0);
INSERT INTO "django_geo_db_location" VALUES(42182,NULL,'Hinckley, MN',17464,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42183,NULL,'Hinckley, MN 55037',17464,222,NULL,41,24426,0);
INSERT INTO "django_geo_db_location" VALUES(42184,NULL,'Hugo, MN',17465,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42185,NULL,'Hugo, MN 55038',17465,222,NULL,41,24427,0);
INSERT INTO "django_geo_db_location" VALUES(42186,NULL,'Isanti, MN',17466,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42187,NULL,'Isanti, MN 55040',17466,222,NULL,41,24428,0);
INSERT INTO "django_geo_db_location" VALUES(42188,NULL,'Lake City, MN',17467,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42189,NULL,'Lake City, MN 55041',17467,222,NULL,41,24429,0);
INSERT INTO "django_geo_db_location" VALUES(42190,NULL,'Lake Elmo, MN',17468,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42191,NULL,'Lake Elmo, MN 55042',17468,222,NULL,41,24430,0);
INSERT INTO "django_geo_db_location" VALUES(42192,NULL,'Lakeland, MN',17469,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42193,NULL,'Lakeland, MN 55043',17469,222,NULL,41,24431,0);
INSERT INTO "django_geo_db_location" VALUES(42194,NULL,'Lakeville, MN',17470,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42195,NULL,'Lakeville, MN 55044',17470,222,NULL,41,24432,0);
INSERT INTO "django_geo_db_location" VALUES(42196,NULL,'Lindstrom, MN',17471,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42197,NULL,'Lindstrom, MN 55045',17471,222,NULL,41,24433,0);
INSERT INTO "django_geo_db_location" VALUES(42198,NULL,'Lonsdale, MN',17472,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42199,NULL,'Lonsdale, MN 55046',17472,222,NULL,41,24434,0);
INSERT INTO "django_geo_db_location" VALUES(42200,NULL,'Marine On Saint Croix, MN',17473,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42201,NULL,'Marine On Saint Croix, MN 55047',17473,222,NULL,41,24435,0);
INSERT INTO "django_geo_db_location" VALUES(42202,NULL,'Medford, MN',17474,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42203,NULL,'Medford, MN 55049',17474,222,NULL,41,24436,0);
INSERT INTO "django_geo_db_location" VALUES(42204,NULL,'Mora, MN',17475,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42205,NULL,'Mora, MN 55051',17475,222,NULL,41,24437,0);
INSERT INTO "django_geo_db_location" VALUES(42206,NULL,'Morristown, MN',17476,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42207,NULL,'Morristown, MN 55052',17476,222,NULL,41,24438,0);
INSERT INTO "django_geo_db_location" VALUES(42208,NULL,'Nerstrand, MN',17477,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42209,NULL,'Nerstrand, MN 55053',17477,222,NULL,41,24439,0);
INSERT INTO "django_geo_db_location" VALUES(42210,NULL,'New Market, MN',17478,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42211,NULL,'New Market, MN 55054',17478,222,NULL,41,24440,0);
INSERT INTO "django_geo_db_location" VALUES(42212,NULL,'Newport, MN',17479,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42213,NULL,'Newport, MN 55055',17479,222,NULL,41,24441,0);
INSERT INTO "django_geo_db_location" VALUES(42214,NULL,'North Branch, MN',17480,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42215,NULL,'North Branch, MN 55056',17480,222,NULL,41,24442,0);
INSERT INTO "django_geo_db_location" VALUES(42216,NULL,'Northfield, MN',17481,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42217,NULL,'Northfield, MN 55057',17481,222,NULL,41,24443,0);
INSERT INTO "django_geo_db_location" VALUES(42218,NULL,'Owatonna, MN',17482,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42219,NULL,'Owatonna, MN 55060',17482,222,NULL,41,24444,0);
INSERT INTO "django_geo_db_location" VALUES(42220,NULL,'Pine City, MN',17483,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42221,NULL,'Pine City, MN 55063',17483,222,NULL,41,24445,0);
INSERT INTO "django_geo_db_location" VALUES(42222,NULL,'Randolph, MN',17484,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42223,NULL,'Randolph, MN 55065',17484,222,NULL,41,24446,0);
INSERT INTO "django_geo_db_location" VALUES(42224,NULL,'Red Wing, MN',17485,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42225,NULL,'Red Wing, MN 55066',17485,222,NULL,41,24447,0);
INSERT INTO "django_geo_db_location" VALUES(42226,NULL,'Rock Creek, MN',17486,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42227,NULL,'Rock Creek, MN 55067',17486,222,NULL,41,24448,0);
INSERT INTO "django_geo_db_location" VALUES(42228,NULL,'Rosemount, MN',17487,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42229,NULL,'Rosemount, MN 55068',17487,222,NULL,41,24449,0);
INSERT INTO "django_geo_db_location" VALUES(42230,NULL,'Rush City, MN',17488,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42231,NULL,'Rush City, MN 55069',17488,222,NULL,41,24450,0);
INSERT INTO "django_geo_db_location" VALUES(42232,NULL,'Saint Francis, MN',17489,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42233,NULL,'Saint Francis, MN 55070',17489,222,NULL,41,24451,0);
INSERT INTO "django_geo_db_location" VALUES(42234,NULL,'Saint Paul Park, MN',17490,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42235,NULL,'Saint Paul Park, MN 55071',17490,222,NULL,41,24452,0);
INSERT INTO "django_geo_db_location" VALUES(42236,NULL,'Sandstone, MN',17491,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42237,NULL,'Sandstone, MN 55072',17491,222,NULL,41,24453,0);
INSERT INTO "django_geo_db_location" VALUES(42238,NULL,'Scandia, MN',17492,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42239,NULL,'Scandia, MN 55073',17492,222,NULL,41,24454,0);
INSERT INTO "django_geo_db_location" VALUES(42240,NULL,'Shafer, MN',17493,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42241,NULL,'Shafer, MN 55074',17493,222,NULL,41,24455,0);
INSERT INTO "django_geo_db_location" VALUES(42242,NULL,'South Saint Paul, MN',17494,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42243,NULL,'South Saint Paul, MN 55075',17494,222,NULL,41,24456,0);
INSERT INTO "django_geo_db_location" VALUES(42244,NULL,'Inver Grove Heights, MN',17495,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42245,NULL,'Inver Grove Heights, MN 55076',17495,222,NULL,41,24457,0);
INSERT INTO "django_geo_db_location" VALUES(42246,NULL,'Inver Grove Heights, MN 55077',17495,222,NULL,41,24458,0);
INSERT INTO "django_geo_db_location" VALUES(42247,NULL,'Stacy, MN',17496,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42248,NULL,'Stacy, MN 55078',17496,222,NULL,41,24459,0);
INSERT INTO "django_geo_db_location" VALUES(42249,NULL,'Stacy, MN 55079',17496,222,NULL,41,24460,0);
INSERT INTO "django_geo_db_location" VALUES(42250,NULL,'Stanchfield, MN',17497,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42251,NULL,'Stanchfield, MN 55080',17497,222,NULL,41,24461,0);
INSERT INTO "django_geo_db_location" VALUES(42252,NULL,'Stillwater, MN',17498,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42253,NULL,'Stillwater, MN 55082',17498,222,NULL,41,24462,0);
INSERT INTO "django_geo_db_location" VALUES(42254,NULL,'Stillwater, MN 55083',17498,222,NULL,41,24463,0);
INSERT INTO "django_geo_db_location" VALUES(42255,NULL,'Taylors Falls, MN',17499,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42256,NULL,'Taylors Falls, MN 55084',17499,222,NULL,41,24464,0);
INSERT INTO "django_geo_db_location" VALUES(42257,NULL,'Vermillion, MN',17500,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42258,NULL,'Vermillion, MN 55085',17500,222,NULL,41,24465,0);
INSERT INTO "django_geo_db_location" VALUES(42259,NULL,'Warsaw, MN',17501,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42260,NULL,'Warsaw, MN 55087',17501,222,NULL,41,24466,0);
INSERT INTO "django_geo_db_location" VALUES(42261,NULL,'Webster, MN',17502,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42262,NULL,'Webster, MN 55088',17502,222,NULL,41,24467,0);
INSERT INTO "django_geo_db_location" VALUES(42263,NULL,'Welch, MN',17503,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42264,NULL,'Welch, MN 55089',17503,222,NULL,41,24468,0);
INSERT INTO "django_geo_db_location" VALUES(42265,NULL,'Willernie, MN',17504,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42266,NULL,'Willernie, MN 55090',17504,222,NULL,41,24469,0);
INSERT INTO "django_geo_db_location" VALUES(42267,NULL,'Wyoming, MN',17505,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42268,NULL,'Wyoming, MN 55092',17505,222,NULL,41,24470,0);
INSERT INTO "django_geo_db_location" VALUES(42269,NULL,'Saint Paul, MN',17506,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42270,NULL,'Saint Paul, MN 55101',17506,222,NULL,41,24471,0);
INSERT INTO "django_geo_db_location" VALUES(42271,NULL,'Saint Paul, MN 55102',17506,222,NULL,41,24472,0);
INSERT INTO "django_geo_db_location" VALUES(42272,NULL,'Saint Paul, MN 55103',17506,222,NULL,41,24473,0);
INSERT INTO "django_geo_db_location" VALUES(42273,NULL,'Saint Paul, MN 55104',17506,222,NULL,41,24474,0);
INSERT INTO "django_geo_db_location" VALUES(42274,NULL,'Saint Paul, MN 55105',17506,222,NULL,41,24475,0);
INSERT INTO "django_geo_db_location" VALUES(42275,NULL,'Saint Paul, MN 55106',17506,222,NULL,41,24476,0);
INSERT INTO "django_geo_db_location" VALUES(42276,NULL,'Saint Paul, MN 55107',17506,222,NULL,41,24477,0);
INSERT INTO "django_geo_db_location" VALUES(42277,NULL,'Saint Paul, MN 55108',17506,222,NULL,41,24478,0);
INSERT INTO "django_geo_db_location" VALUES(42278,NULL,'Saint Paul, MN 55109',17506,222,NULL,41,24479,0);
INSERT INTO "django_geo_db_location" VALUES(42279,NULL,'Saint Paul, MN 55110',17506,222,NULL,41,24480,0);
INSERT INTO "django_geo_db_location" VALUES(42280,NULL,'Saint Paul, MN 55111',17506,222,NULL,41,24481,0);
INSERT INTO "django_geo_db_location" VALUES(42281,NULL,'Saint Paul, MN 55112',17506,222,NULL,41,24482,0);
INSERT INTO "django_geo_db_location" VALUES(42282,NULL,'Saint Paul, MN 55113',17506,222,NULL,41,24483,0);
INSERT INTO "django_geo_db_location" VALUES(42283,NULL,'Saint Paul, MN 55114',17506,222,NULL,41,24484,0);
INSERT INTO "django_geo_db_location" VALUES(42284,NULL,'Saint Paul, MN 55115',17506,222,NULL,41,24485,0);
INSERT INTO "django_geo_db_location" VALUES(42285,NULL,'Saint Paul, MN 55116',17506,222,NULL,41,24486,0);
INSERT INTO "django_geo_db_location" VALUES(42286,NULL,'Saint Paul, MN 55117',17506,222,NULL,41,24487,0);
INSERT INTO "django_geo_db_location" VALUES(42287,NULL,'Saint Paul, MN 55118',17506,222,NULL,41,24488,0);
INSERT INTO "django_geo_db_location" VALUES(42288,NULL,'Saint Paul, MN 55119',17506,222,NULL,41,24489,0);
INSERT INTO "django_geo_db_location" VALUES(42289,NULL,'Saint Paul, MN 55120',17506,222,NULL,41,24490,0);
INSERT INTO "django_geo_db_location" VALUES(42290,NULL,'Saint Paul, MN 55121',17506,222,NULL,41,24491,0);
INSERT INTO "django_geo_db_location" VALUES(42291,NULL,'Saint Paul, MN 55122',17506,222,NULL,41,24492,0);
INSERT INTO "django_geo_db_location" VALUES(42292,NULL,'Saint Paul, MN 55123',17506,222,NULL,41,24493,0);
INSERT INTO "django_geo_db_location" VALUES(42293,NULL,'Saint Paul, MN 55124',17506,222,NULL,41,24494,0);
INSERT INTO "django_geo_db_location" VALUES(42294,NULL,'Saint Paul, MN 55125',17506,222,NULL,41,24495,0);
INSERT INTO "django_geo_db_location" VALUES(42295,NULL,'Saint Paul, MN 55126',17506,222,NULL,41,24496,0);
INSERT INTO "django_geo_db_location" VALUES(42296,NULL,'Saint Paul, MN 55127',17506,222,NULL,41,24497,0);
INSERT INTO "django_geo_db_location" VALUES(42297,NULL,'Saint Paul, MN 55128',17506,222,NULL,41,24498,0);
INSERT INTO "django_geo_db_location" VALUES(42298,NULL,'Saint Paul, MN 55129',17506,222,NULL,41,24499,0);
INSERT INTO "django_geo_db_location" VALUES(42299,NULL,'Saint Paul, MN 55133',17506,222,NULL,41,24500,0);
INSERT INTO "django_geo_db_location" VALUES(42300,NULL,'Saint Paul, MN 55144',17506,222,NULL,41,24501,0);
INSERT INTO "django_geo_db_location" VALUES(42301,NULL,'Saint Paul, MN 55145',17506,222,NULL,41,24502,0);
INSERT INTO "django_geo_db_location" VALUES(42302,NULL,'Saint Paul, MN 55146',17506,222,NULL,41,24503,0);
INSERT INTO "django_geo_db_location" VALUES(42303,NULL,'Mendota, MN',17507,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42304,NULL,'Mendota, MN 55150',17507,222,NULL,41,24504,0);
INSERT INTO "django_geo_db_location" VALUES(42305,NULL,'Saint Paul, MN 55155',17506,222,NULL,41,24505,0);
INSERT INTO "django_geo_db_location" VALUES(42306,NULL,'Saint Paul, MN 55161',17506,222,NULL,41,24506,0);
INSERT INTO "django_geo_db_location" VALUES(42307,NULL,'Saint Paul, MN 55164',17506,222,NULL,41,24507,0);
INSERT INTO "django_geo_db_location" VALUES(42308,NULL,'Saint Paul, MN 55165',17506,222,NULL,41,24508,0);
INSERT INTO "django_geo_db_location" VALUES(42309,NULL,'Saint Paul, MN 55166',17506,222,NULL,41,24509,0);
INSERT INTO "django_geo_db_location" VALUES(42310,NULL,'Saint Paul, MN 55168',17506,222,NULL,41,24510,0);
INSERT INTO "django_geo_db_location" VALUES(42311,NULL,'Saint Paul, MN 55169',17506,222,NULL,41,24511,0);
INSERT INTO "django_geo_db_location" VALUES(42312,NULL,'Saint Paul, MN 55170',17506,222,NULL,41,24512,0);
INSERT INTO "django_geo_db_location" VALUES(42313,NULL,'Saint Paul, MN 55171',17506,222,NULL,41,24513,0);
INSERT INTO "django_geo_db_location" VALUES(42314,NULL,'Saint Paul, MN 55172',17506,222,NULL,41,24514,0);
INSERT INTO "django_geo_db_location" VALUES(42315,NULL,'Saint Paul, MN 55175',17506,222,NULL,41,24515,0);
INSERT INTO "django_geo_db_location" VALUES(42316,NULL,'Saint Paul, MN 55177',17506,222,NULL,41,24516,0);
INSERT INTO "django_geo_db_location" VALUES(42317,NULL,'Saint Paul, MN 55182',17506,222,NULL,41,24517,0);
INSERT INTO "django_geo_db_location" VALUES(42318,NULL,'Duluth, MN',17508,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42319,NULL,'Duluth, MN 55184',17508,222,NULL,41,24518,0);
INSERT INTO "django_geo_db_location" VALUES(42320,NULL,'Saint Paul, MN 55187',17506,222,NULL,41,24519,0);
INSERT INTO "django_geo_db_location" VALUES(42321,NULL,'Saint Paul, MN 55188',17506,222,NULL,41,24520,0);
INSERT INTO "django_geo_db_location" VALUES(42322,NULL,'Saint Paul, MN 55189',17506,222,NULL,41,24521,0);
INSERT INTO "django_geo_db_location" VALUES(42323,NULL,'Saint Paul, MN 55190',17506,222,NULL,41,24522,0);
INSERT INTO "django_geo_db_location" VALUES(42324,NULL,'Saint Paul, MN 55191',17506,222,NULL,41,24523,0);
INSERT INTO "django_geo_db_location" VALUES(42325,NULL,'Kroschel, MN',17509,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42326,NULL,'Kroschel, MN 55272',17509,222,NULL,41,24524,0);
INSERT INTO "django_geo_db_location" VALUES(42327,NULL,'Albertville, MN',17510,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42328,NULL,'Albertville, MN 55301',17510,222,NULL,41,24525,0);
INSERT INTO "django_geo_db_location" VALUES(42329,NULL,'Annandale, MN',17511,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42330,NULL,'Annandale, MN 55302',17511,222,NULL,41,24526,0);
INSERT INTO "django_geo_db_location" VALUES(42331,NULL,'Anoka, MN',17512,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42332,NULL,'Anoka, MN 55303',17512,222,NULL,41,24527,0);
INSERT INTO "django_geo_db_location" VALUES(42333,NULL,'Andover, MN',17513,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42334,NULL,'Andover, MN 55304',17513,222,NULL,41,24528,0);
INSERT INTO "django_geo_db_location" VALUES(42335,NULL,'Hopkins, MN',17514,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42336,NULL,'Hopkins, MN 55305',17514,222,NULL,41,24529,0);
INSERT INTO "django_geo_db_location" VALUES(42337,NULL,'Burnsville, MN',17515,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42338,NULL,'Burnsville, MN 55306',17515,222,NULL,41,24530,0);
INSERT INTO "django_geo_db_location" VALUES(42339,NULL,'Arlington, MN',17516,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42340,NULL,'Arlington, MN 55307',17516,222,NULL,41,24531,0);
INSERT INTO "django_geo_db_location" VALUES(42341,NULL,'Becker, MN',17517,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42342,NULL,'Becker, MN 55308',17517,222,NULL,41,24532,0);
INSERT INTO "django_geo_db_location" VALUES(42343,NULL,'Big Lake, MN',17518,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42344,NULL,'Big Lake, MN 55309',17518,222,NULL,41,24533,0);
INSERT INTO "django_geo_db_location" VALUES(42345,NULL,'Bird Island, MN',17519,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42346,NULL,'Bird Island, MN 55310',17519,222,NULL,41,24534,0);
INSERT INTO "django_geo_db_location" VALUES(42347,NULL,'Osseo, MN',17520,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42348,NULL,'Osseo, MN 55311',17520,222,NULL,41,24535,0);
INSERT INTO "django_geo_db_location" VALUES(42349,NULL,'Brownton, MN',17521,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42350,NULL,'Brownton, MN 55312',17521,222,NULL,41,24536,0);
INSERT INTO "django_geo_db_location" VALUES(42351,NULL,'Buffalo, MN',17522,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42352,NULL,'Buffalo, MN 55313',17522,222,NULL,41,24537,0);
INSERT INTO "django_geo_db_location" VALUES(42353,NULL,'Buffalo Lake, MN',17523,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42354,NULL,'Buffalo Lake, MN 55314',17523,222,NULL,41,24538,0);
INSERT INTO "django_geo_db_location" VALUES(42355,NULL,'Carver, MN',17524,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42356,NULL,'Carver, MN 55315',17524,222,NULL,41,24539,0);
INSERT INTO "django_geo_db_location" VALUES(42357,NULL,'Champlin, MN',17525,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42358,NULL,'Champlin, MN 55316',17525,222,NULL,41,24540,0);
INSERT INTO "django_geo_db_location" VALUES(42359,NULL,'Chanhassen, MN',17526,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42360,NULL,'Chanhassen, MN 55317',17526,222,NULL,41,24541,0);
INSERT INTO "django_geo_db_location" VALUES(42361,NULL,'Chaska, MN',17527,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42362,NULL,'Chaska, MN 55318',17527,222,NULL,41,24542,0);
INSERT INTO "django_geo_db_location" VALUES(42363,NULL,'Clear Lake, MN',17528,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42364,NULL,'Clear Lake, MN 55319',17528,222,NULL,41,24543,0);
INSERT INTO "django_geo_db_location" VALUES(42365,NULL,'Clearwater, MN',17529,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42366,NULL,'Clearwater, MN 55320',17529,222,NULL,41,24544,0);
INSERT INTO "django_geo_db_location" VALUES(42367,NULL,'Cokato, MN',17530,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42368,NULL,'Cokato, MN 55321',17530,222,NULL,41,24545,0);
INSERT INTO "django_geo_db_location" VALUES(42369,NULL,'Cologne, MN',17531,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42370,NULL,'Cologne, MN 55322',17531,222,NULL,41,24546,0);
INSERT INTO "django_geo_db_location" VALUES(42371,NULL,'Crystal Bay, MN',17532,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42372,NULL,'Crystal Bay, MN 55323',17532,222,NULL,41,24547,0);
INSERT INTO "django_geo_db_location" VALUES(42373,NULL,'Darwin, MN',17533,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42374,NULL,'Darwin, MN 55324',17533,222,NULL,41,24548,0);
INSERT INTO "django_geo_db_location" VALUES(42375,NULL,'Dassel, MN',17534,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42376,NULL,'Dassel, MN 55325',17534,222,NULL,41,24549,0);
INSERT INTO "django_geo_db_location" VALUES(42377,NULL,'Dayton, MN',17535,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42378,NULL,'Dayton, MN 55327',17535,222,NULL,41,24550,0);
INSERT INTO "django_geo_db_location" VALUES(42379,NULL,'Delano, MN',17536,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42380,NULL,'Delano, MN 55328',17536,222,NULL,41,24551,0);
INSERT INTO "django_geo_db_location" VALUES(42381,NULL,'Eden Valley, MN',17537,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42382,NULL,'Eden Valley, MN 55329',17537,222,NULL,41,24552,0);
INSERT INTO "django_geo_db_location" VALUES(42383,NULL,'Elk River, MN',17538,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42384,NULL,'Elk River, MN 55330',17538,222,NULL,41,24553,0);
INSERT INTO "django_geo_db_location" VALUES(42385,NULL,'Excelsior, MN',17539,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42386,NULL,'Excelsior, MN 55331',17539,222,NULL,41,24554,0);
INSERT INTO "django_geo_db_location" VALUES(42387,NULL,'Fairfax, MN',17540,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42388,NULL,'Fairfax, MN 55332',17540,222,NULL,41,24555,0);
INSERT INTO "django_geo_db_location" VALUES(42389,NULL,'Franklin, MN',17541,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42390,NULL,'Franklin, MN 55333',17541,222,NULL,41,24556,0);
INSERT INTO "django_geo_db_location" VALUES(42391,NULL,'Gaylord, MN',17542,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42392,NULL,'Gaylord, MN 55334',17542,222,NULL,41,24557,0);
INSERT INTO "django_geo_db_location" VALUES(42393,NULL,'Gibbon, MN',17543,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42394,NULL,'Gibbon, MN 55335',17543,222,NULL,41,24558,0);
INSERT INTO "django_geo_db_location" VALUES(42395,NULL,'Glencoe, MN',17544,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42396,NULL,'Glencoe, MN 55336',17544,222,NULL,41,24559,0);
INSERT INTO "django_geo_db_location" VALUES(42397,NULL,'Burnsville, MN 55337',17515,222,NULL,41,24560,0);
INSERT INTO "django_geo_db_location" VALUES(42398,NULL,'Green Isle, MN',17545,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42399,NULL,'Green Isle, MN 55338',17545,222,NULL,41,24561,0);
INSERT INTO "django_geo_db_location" VALUES(42400,NULL,'Hamburg, MN',17546,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42401,NULL,'Hamburg, MN 55339',17546,222,NULL,41,24562,0);
INSERT INTO "django_geo_db_location" VALUES(42402,NULL,'Hamel, MN',17547,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42403,NULL,'Hamel, MN 55340',17547,222,NULL,41,24563,0);
INSERT INTO "django_geo_db_location" VALUES(42404,NULL,'Hanover, MN',17548,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42405,NULL,'Hanover, MN 55341',17548,222,NULL,41,24564,0);
INSERT INTO "django_geo_db_location" VALUES(42406,NULL,'Hector, MN',17549,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42407,NULL,'Hector, MN 55342',17549,222,NULL,41,24565,0);
INSERT INTO "django_geo_db_location" VALUES(42408,NULL,'Hopkins, MN 55343',17514,222,NULL,41,24566,0);
INSERT INTO "django_geo_db_location" VALUES(42409,NULL,'Eden Prairie, MN',17550,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42410,NULL,'Eden Prairie, MN 55344',17550,222,NULL,41,24567,0);
INSERT INTO "django_geo_db_location" VALUES(42411,NULL,'Minnetonka, MN',17551,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42412,NULL,'Minnetonka, MN 55345',17551,222,NULL,41,24568,0);
INSERT INTO "django_geo_db_location" VALUES(42413,NULL,'Eden Prairie, MN 55346',17550,222,NULL,41,24569,0);
INSERT INTO "django_geo_db_location" VALUES(42414,NULL,'Eden Prairie, MN 55347',17550,222,NULL,41,24570,0);
INSERT INTO "django_geo_db_location" VALUES(42415,NULL,'Maple Plain, MN',17552,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42416,NULL,'Maple Plain, MN 55348',17552,222,NULL,41,24571,0);
INSERT INTO "django_geo_db_location" VALUES(42417,NULL,'Howard Lake, MN',17553,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42418,NULL,'Howard Lake, MN 55349',17553,222,NULL,41,24572,0);
INSERT INTO "django_geo_db_location" VALUES(42419,NULL,'Hutchinson, MN',17554,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42420,NULL,'Hutchinson, MN 55350',17554,222,NULL,41,24573,0);
INSERT INTO "django_geo_db_location" VALUES(42421,NULL,'Jordan, MN',17555,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42422,NULL,'Jordan, MN 55352',17555,222,NULL,41,24574,0);
INSERT INTO "django_geo_db_location" VALUES(42423,NULL,'Kimball, MN',17556,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42424,NULL,'Kimball, MN 55353',17556,222,NULL,41,24575,0);
INSERT INTO "django_geo_db_location" VALUES(42425,NULL,'Lester Prairie, MN',17557,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42426,NULL,'Lester Prairie, MN 55354',17557,222,NULL,41,24576,0);
INSERT INTO "django_geo_db_location" VALUES(42427,NULL,'Litchfield, MN',17558,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42428,NULL,'Litchfield, MN 55355',17558,222,NULL,41,24577,0);
INSERT INTO "django_geo_db_location" VALUES(42429,NULL,'Long Lake, MN',17559,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42430,NULL,'Long Lake, MN 55356',17559,222,NULL,41,24578,0);
INSERT INTO "django_geo_db_location" VALUES(42431,NULL,'Loretto, MN',17560,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42432,NULL,'Loretto, MN 55357',17560,222,NULL,41,24579,0);
INSERT INTO "django_geo_db_location" VALUES(42433,NULL,'Maple Lake, MN',17561,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42434,NULL,'Maple Lake, MN 55358',17561,222,NULL,41,24580,0);
INSERT INTO "django_geo_db_location" VALUES(42435,NULL,'Maple Plain, MN 55359',17552,222,NULL,41,24581,0);
INSERT INTO "django_geo_db_location" VALUES(42436,NULL,'Mayer, MN',17562,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42437,NULL,'Mayer, MN 55360',17562,222,NULL,41,24582,0);
INSERT INTO "django_geo_db_location" VALUES(42438,NULL,'Minnetonka Beach, MN',17563,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42439,NULL,'Minnetonka Beach, MN 55361',17563,222,NULL,41,24583,0);
INSERT INTO "django_geo_db_location" VALUES(42440,NULL,'Monticello, MN',17564,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42441,NULL,'Monticello, MN 55362',17564,222,NULL,41,24584,0);
INSERT INTO "django_geo_db_location" VALUES(42442,NULL,'Montrose, MN',17565,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42443,NULL,'Montrose, MN 55363',17565,222,NULL,41,24585,0);
INSERT INTO "django_geo_db_location" VALUES(42444,NULL,'Mound, MN',17566,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42445,NULL,'Mound, MN 55364',17566,222,NULL,41,24586,0);
INSERT INTO "django_geo_db_location" VALUES(42446,NULL,'Monticello, MN 55365',17564,222,NULL,41,24587,0);
INSERT INTO "django_geo_db_location" VALUES(42447,NULL,'New Auburn, MN',17567,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42448,NULL,'New Auburn, MN 55366',17567,222,NULL,41,24588,0);
INSERT INTO "django_geo_db_location" VALUES(42449,NULL,'New Germany, MN',17568,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42450,NULL,'New Germany, MN 55367',17568,222,NULL,41,24589,0);
INSERT INTO "django_geo_db_location" VALUES(42451,NULL,'Norwood, MN',17569,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42452,NULL,'Norwood, MN 55368',17569,222,NULL,41,24590,0);
INSERT INTO "django_geo_db_location" VALUES(42453,NULL,'Osseo, MN 55369',17520,222,NULL,41,24591,0);
INSERT INTO "django_geo_db_location" VALUES(42454,NULL,'Plato, MN',17570,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42455,NULL,'Plato, MN 55370',17570,222,NULL,41,24592,0);
INSERT INTO "django_geo_db_location" VALUES(42456,NULL,'Princeton, MN',17571,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42457,NULL,'Princeton, MN 55371',17571,222,NULL,41,24593,0);
INSERT INTO "django_geo_db_location" VALUES(42458,NULL,'Prior Lake, MN',17572,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42459,NULL,'Prior Lake, MN 55372',17572,222,NULL,41,24594,0);
INSERT INTO "django_geo_db_location" VALUES(42460,NULL,'Rockford, MN',17573,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42461,NULL,'Rockford, MN 55373',17573,222,NULL,41,24595,0);
INSERT INTO "django_geo_db_location" VALUES(42462,NULL,'Rogers, MN',17574,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42463,NULL,'Rogers, MN 55374',17574,222,NULL,41,24596,0);
INSERT INTO "django_geo_db_location" VALUES(42464,NULL,'Saint Bonifacius, MN',17575,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42465,NULL,'Saint Bonifacius, MN 55375',17575,222,NULL,41,24597,0);
INSERT INTO "django_geo_db_location" VALUES(42466,NULL,'Saint Michael, MN',17576,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42467,NULL,'Saint Michael, MN 55376',17576,222,NULL,41,24598,0);
INSERT INTO "django_geo_db_location" VALUES(42468,NULL,'Santiago, MN',17577,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42469,NULL,'Santiago, MN 55377',17577,222,NULL,41,24599,0);
INSERT INTO "django_geo_db_location" VALUES(42470,NULL,'Savage, MN',17578,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42471,NULL,'Savage, MN 55378',17578,222,NULL,41,24600,0);
INSERT INTO "django_geo_db_location" VALUES(42472,NULL,'Shakopee, MN',17579,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42473,NULL,'Shakopee, MN 55379',17579,222,NULL,41,24601,0);
INSERT INTO "django_geo_db_location" VALUES(42474,NULL,'Silver Creek, MN',17580,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42475,NULL,'Silver Creek, MN 55380',17580,222,NULL,41,24602,0);
INSERT INTO "django_geo_db_location" VALUES(42476,NULL,'Silver Lake, MN',17581,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42477,NULL,'Silver Lake, MN 55381',17581,222,NULL,41,24603,0);
INSERT INTO "django_geo_db_location" VALUES(42478,NULL,'South Haven, MN',17582,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42479,NULL,'South Haven, MN 55382',17582,222,NULL,41,24604,0);
INSERT INTO "django_geo_db_location" VALUES(42480,NULL,'Norwood, MN 55383',17569,222,NULL,41,24605,0);
INSERT INTO "django_geo_db_location" VALUES(42481,NULL,'Spring Park, MN',17583,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42482,NULL,'Spring Park, MN 55384',17583,222,NULL,41,24606,0);
INSERT INTO "django_geo_db_location" VALUES(42483,NULL,'Stewart, MN',17584,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42484,NULL,'Stewart, MN 55385',17584,222,NULL,41,24607,0);
INSERT INTO "django_geo_db_location" VALUES(42485,NULL,'Victoria, MN',17585,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42486,NULL,'Victoria, MN 55386',17585,222,NULL,41,24608,0);
INSERT INTO "django_geo_db_location" VALUES(42487,NULL,'Waconia, MN',17586,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42488,NULL,'Waconia, MN 55387',17586,222,NULL,41,24609,0);
INSERT INTO "django_geo_db_location" VALUES(42489,NULL,'Watertown, MN',17587,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42490,NULL,'Watertown, MN 55388',17587,222,NULL,41,24610,0);
INSERT INTO "django_geo_db_location" VALUES(42491,NULL,'Watkins, MN',17588,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42492,NULL,'Watkins, MN 55389',17588,222,NULL,41,24611,0);
INSERT INTO "django_geo_db_location" VALUES(42493,NULL,'Waverly, MN',17589,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42494,NULL,'Waverly, MN 55390',17589,222,NULL,41,24612,0);
INSERT INTO "django_geo_db_location" VALUES(42495,NULL,'Wayzata, MN',17590,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42496,NULL,'Wayzata, MN 55391',17590,222,NULL,41,24613,0);
INSERT INTO "django_geo_db_location" VALUES(42497,NULL,'Navarre, MN',17591,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42498,NULL,'Navarre, MN 55392',17591,222,NULL,41,24614,0);
INSERT INTO "django_geo_db_location" VALUES(42499,NULL,'Maple Plain, MN 55393',17552,222,NULL,41,24615,0);
INSERT INTO "django_geo_db_location" VALUES(42500,NULL,'Young America, MN',17592,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42501,NULL,'Young America, MN 55394',17592,222,NULL,41,24616,0);
INSERT INTO "django_geo_db_location" VALUES(42502,NULL,'Winsted, MN',17593,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42503,NULL,'Winsted, MN 55395',17593,222,NULL,41,24617,0);
INSERT INTO "django_geo_db_location" VALUES(42504,NULL,'Winthrop, MN',17594,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42505,NULL,'Winthrop, MN 55396',17594,222,NULL,41,24618,0);
INSERT INTO "django_geo_db_location" VALUES(42506,NULL,'Young America, MN 55397',17592,222,NULL,41,24619,0);
INSERT INTO "django_geo_db_location" VALUES(42507,NULL,'Zimmerman, MN',17595,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42508,NULL,'Zimmerman, MN 55398',17595,222,NULL,41,24620,0);
INSERT INTO "django_geo_db_location" VALUES(42509,NULL,'Young America, MN 55399',17592,222,NULL,41,24621,0);
INSERT INTO "django_geo_db_location" VALUES(42510,NULL,'Minneapolis, MN',17596,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42511,NULL,'Minneapolis, MN 55401',17596,222,NULL,41,24622,0);
INSERT INTO "django_geo_db_location" VALUES(42512,NULL,'Minneapolis, MN 55402',17596,222,NULL,41,24623,0);
INSERT INTO "django_geo_db_location" VALUES(42513,NULL,'Minneapolis, MN 55403',17596,222,NULL,41,24624,0);
INSERT INTO "django_geo_db_location" VALUES(42514,NULL,'Minneapolis, MN 55404',17596,222,NULL,41,24625,0);
INSERT INTO "django_geo_db_location" VALUES(42515,NULL,'Minneapolis, MN 55405',17596,222,NULL,41,24626,0);
INSERT INTO "django_geo_db_location" VALUES(42516,NULL,'Minneapolis, MN 55406',17596,222,NULL,41,24627,0);
INSERT INTO "django_geo_db_location" VALUES(42517,NULL,'Minneapolis, MN 55407',17596,222,NULL,41,24628,0);
INSERT INTO "django_geo_db_location" VALUES(42518,NULL,'Minneapolis, MN 55408',17596,222,NULL,41,24629,0);
INSERT INTO "django_geo_db_location" VALUES(42519,NULL,'Minneapolis, MN 55409',17596,222,NULL,41,24630,0);
INSERT INTO "django_geo_db_location" VALUES(42520,NULL,'Minneapolis, MN 55410',17596,222,NULL,41,24631,0);
INSERT INTO "django_geo_db_location" VALUES(42521,NULL,'Minneapolis, MN 55411',17596,222,NULL,41,24632,0);
INSERT INTO "django_geo_db_location" VALUES(42522,NULL,'Minneapolis, MN 55412',17596,222,NULL,41,24633,0);
INSERT INTO "django_geo_db_location" VALUES(42523,NULL,'Minneapolis, MN 55413',17596,222,NULL,41,24634,0);
INSERT INTO "django_geo_db_location" VALUES(42524,NULL,'Minneapolis, MN 55414',17596,222,NULL,41,24635,0);
INSERT INTO "django_geo_db_location" VALUES(42525,NULL,'Minneapolis, MN 55415',17596,222,NULL,41,24636,0);
INSERT INTO "django_geo_db_location" VALUES(42526,NULL,'Minneapolis, MN 55416',17596,222,NULL,41,24637,0);
INSERT INTO "django_geo_db_location" VALUES(42527,NULL,'Minneapolis, MN 55417',17596,222,NULL,41,24638,0);
INSERT INTO "django_geo_db_location" VALUES(42528,NULL,'Minneapolis, MN 55418',17596,222,NULL,41,24639,0);
INSERT INTO "django_geo_db_location" VALUES(42529,NULL,'Minneapolis, MN 55419',17596,222,NULL,41,24640,0);
INSERT INTO "django_geo_db_location" VALUES(42530,NULL,'Minneapolis, MN 55420',17596,222,NULL,41,24641,0);
INSERT INTO "django_geo_db_location" VALUES(42531,NULL,'Minneapolis, MN 55421',17596,222,NULL,41,24642,0);
INSERT INTO "django_geo_db_location" VALUES(42532,NULL,'Minneapolis, MN 55422',17596,222,NULL,41,24643,0);
INSERT INTO "django_geo_db_location" VALUES(42533,NULL,'Minneapolis, MN 55423',17596,222,NULL,41,24644,0);
INSERT INTO "django_geo_db_location" VALUES(42534,NULL,'Minneapolis, MN 55424',17596,222,NULL,41,24645,0);
INSERT INTO "django_geo_db_location" VALUES(42535,NULL,'Minneapolis, MN 55425',17596,222,NULL,41,24646,0);
INSERT INTO "django_geo_db_location" VALUES(42536,NULL,'Minneapolis, MN 55426',17596,222,NULL,41,24647,0);
INSERT INTO "django_geo_db_location" VALUES(42537,NULL,'Minneapolis, MN 55427',17596,222,NULL,41,24648,0);
INSERT INTO "django_geo_db_location" VALUES(42538,NULL,'Minneapolis, MN 55428',17596,222,NULL,41,24649,0);
INSERT INTO "django_geo_db_location" VALUES(42539,NULL,'Minneapolis, MN 55429',17596,222,NULL,41,24650,0);
INSERT INTO "django_geo_db_location" VALUES(42540,NULL,'Minneapolis, MN 55430',17596,222,NULL,41,24651,0);
INSERT INTO "django_geo_db_location" VALUES(42541,NULL,'Minneapolis, MN 55431',17596,222,NULL,41,24652,0);
INSERT INTO "django_geo_db_location" VALUES(42542,NULL,'Minneapolis, MN 55432',17596,222,NULL,41,24653,0);
INSERT INTO "django_geo_db_location" VALUES(42543,NULL,'Minneapolis, MN 55433',17596,222,NULL,41,24654,0);
INSERT INTO "django_geo_db_location" VALUES(42544,NULL,'Minneapolis, MN 55434',17596,222,NULL,41,24655,0);
INSERT INTO "django_geo_db_location" VALUES(42545,NULL,'Minneapolis, MN 55435',17596,222,NULL,41,24656,0);
INSERT INTO "django_geo_db_location" VALUES(42546,NULL,'Minneapolis, MN 55436',17596,222,NULL,41,24657,0);
INSERT INTO "django_geo_db_location" VALUES(42547,NULL,'Minneapolis, MN 55437',17596,222,NULL,41,24658,0);
INSERT INTO "django_geo_db_location" VALUES(42548,NULL,'Minneapolis, MN 55438',17596,222,NULL,41,24659,0);
INSERT INTO "django_geo_db_location" VALUES(42549,NULL,'Minneapolis, MN 55439',17596,222,NULL,41,24660,0);
INSERT INTO "django_geo_db_location" VALUES(42550,NULL,'Minneapolis, MN 55440',17596,222,NULL,41,24661,0);
INSERT INTO "django_geo_db_location" VALUES(42551,NULL,'Minneapolis, MN 55441',17596,222,NULL,41,24662,0);
INSERT INTO "django_geo_db_location" VALUES(42552,NULL,'Minneapolis, MN 55442',17596,222,NULL,41,24663,0);
INSERT INTO "django_geo_db_location" VALUES(42553,NULL,'Minneapolis, MN 55443',17596,222,NULL,41,24664,0);
INSERT INTO "django_geo_db_location" VALUES(42554,NULL,'Minneapolis, MN 55444',17596,222,NULL,41,24665,0);
INSERT INTO "django_geo_db_location" VALUES(42555,NULL,'Minneapolis, MN 55445',17596,222,NULL,41,24666,0);
INSERT INTO "django_geo_db_location" VALUES(42556,NULL,'Minneapolis, MN 55446',17596,222,NULL,41,24667,0);
INSERT INTO "django_geo_db_location" VALUES(42557,NULL,'Minneapolis, MN 55447',17596,222,NULL,41,24668,0);
INSERT INTO "django_geo_db_location" VALUES(42558,NULL,'Minneapolis, MN 55448',17596,222,NULL,41,24669,0);
INSERT INTO "django_geo_db_location" VALUES(42559,NULL,'Minneapolis, MN 55449',17596,222,NULL,41,24670,0);
INSERT INTO "django_geo_db_location" VALUES(42560,NULL,'Minneapolis, MN 55450',17596,222,NULL,41,24671,0);
INSERT INTO "django_geo_db_location" VALUES(42561,NULL,'Minneapolis, MN 55454',17596,222,NULL,41,24672,0);
INSERT INTO "django_geo_db_location" VALUES(42562,NULL,'Minneapolis, MN 55455',17596,222,NULL,41,24673,0);
INSERT INTO "django_geo_db_location" VALUES(42563,NULL,'Minneapolis, MN 55458',17596,222,NULL,41,24674,0);
INSERT INTO "django_geo_db_location" VALUES(42564,NULL,'Minneapolis, MN 55459',17596,222,NULL,41,24675,0);
INSERT INTO "django_geo_db_location" VALUES(42565,NULL,'Minneapolis, MN 55460',17596,222,NULL,41,24676,0);
INSERT INTO "django_geo_db_location" VALUES(42566,NULL,'Minneapolis, MN 55468',17596,222,NULL,41,24677,0);
INSERT INTO "django_geo_db_location" VALUES(42567,NULL,'Minneapolis, MN 55470',17596,222,NULL,41,24678,0);
INSERT INTO "django_geo_db_location" VALUES(42568,NULL,'Minneapolis, MN 55472',17596,222,NULL,41,24679,0);
INSERT INTO "django_geo_db_location" VALUES(42569,NULL,'Minneapolis, MN 55473',17596,222,NULL,41,24680,0);
INSERT INTO "django_geo_db_location" VALUES(42570,NULL,'Minneapolis, MN 55474',17596,222,NULL,41,24681,0);
INSERT INTO "django_geo_db_location" VALUES(42571,NULL,'Minneapolis, MN 55478',17596,222,NULL,41,24682,0);
INSERT INTO "django_geo_db_location" VALUES(42572,NULL,'Minneapolis, MN 55479',17596,222,NULL,41,24683,0);
INSERT INTO "django_geo_db_location" VALUES(42573,NULL,'Minneapolis, MN 55480',17596,222,NULL,41,24684,0);
INSERT INTO "django_geo_db_location" VALUES(42574,NULL,'Minneapolis, MN 55483',17596,222,NULL,41,24685,0);
INSERT INTO "django_geo_db_location" VALUES(42575,NULL,'Minneapolis, MN 55484',17596,222,NULL,41,24686,0);
INSERT INTO "django_geo_db_location" VALUES(42576,NULL,'Minneapolis, MN 55485',17596,222,NULL,41,24687,0);
INSERT INTO "django_geo_db_location" VALUES(42577,NULL,'Minneapolis, MN 55486',17596,222,NULL,41,24688,0);
INSERT INTO "django_geo_db_location" VALUES(42578,NULL,'Minneapolis, MN 55487',17596,222,NULL,41,24689,0);
INSERT INTO "django_geo_db_location" VALUES(42579,NULL,'Minneapolis, MN 55488',17596,222,NULL,41,24690,0);
INSERT INTO "django_geo_db_location" VALUES(42580,NULL,'Elk River, MN 55530',17538,222,NULL,41,24691,0);
INSERT INTO "django_geo_db_location" VALUES(42581,NULL,'Young America, MN 55550',17592,222,NULL,41,24692,0);
INSERT INTO "django_geo_db_location" VALUES(42582,NULL,'Young America, MN 55551',17592,222,NULL,41,24693,0);
INSERT INTO "django_geo_db_location" VALUES(42583,NULL,'Young America, MN 55552',17592,222,NULL,41,24694,0);
INSERT INTO "django_geo_db_location" VALUES(42584,NULL,'Young America, MN 55553',17592,222,NULL,41,24695,0);
INSERT INTO "django_geo_db_location" VALUES(42585,NULL,'Norwood, MN 55554',17569,222,NULL,41,24696,0);
INSERT INTO "django_geo_db_location" VALUES(42586,NULL,'Young America, MN 55555',17592,222,NULL,41,24697,0);
INSERT INTO "django_geo_db_location" VALUES(42587,NULL,'Young America, MN 55556',17592,222,NULL,41,24698,0);
INSERT INTO "django_geo_db_location" VALUES(42588,NULL,'Young America, MN 55557',17592,222,NULL,41,24699,0);
INSERT INTO "django_geo_db_location" VALUES(42589,NULL,'Young America, MN 55558',17592,222,NULL,41,24700,0);
INSERT INTO "django_geo_db_location" VALUES(42590,NULL,'Young America, MN 55559',17592,222,NULL,41,24701,0);
INSERT INTO "django_geo_db_location" VALUES(42591,NULL,'Young America, MN 55560',17592,222,NULL,41,24702,0);
INSERT INTO "django_geo_db_location" VALUES(42592,NULL,'Monticello, MN 55561',17564,222,NULL,41,24703,0);
INSERT INTO "django_geo_db_location" VALUES(42593,NULL,'Young America, MN 55562',17592,222,NULL,41,24704,0);
INSERT INTO "django_geo_db_location" VALUES(42594,NULL,'Monticello, MN 55563',17564,222,NULL,41,24705,0);
INSERT INTO "django_geo_db_location" VALUES(42595,NULL,'Young America, MN 55564',17592,222,NULL,41,24706,0);
INSERT INTO "django_geo_db_location" VALUES(42596,NULL,'Monticello, MN 55565',17564,222,NULL,41,24707,0);
INSERT INTO "django_geo_db_location" VALUES(42597,NULL,'Young America, MN 55566',17592,222,NULL,41,24708,0);
INSERT INTO "django_geo_db_location" VALUES(42598,NULL,'Young America, MN 55567',17592,222,NULL,41,24709,0);
INSERT INTO "django_geo_db_location" VALUES(42599,NULL,'Young America, MN 55568',17592,222,NULL,41,24710,0);
INSERT INTO "django_geo_db_location" VALUES(42600,NULL,'Osseo, MN 55569',17520,222,NULL,41,24711,0);
INSERT INTO "django_geo_db_location" VALUES(42601,NULL,'Maple Plain, MN 55570',17552,222,NULL,41,24712,0);
INSERT INTO "django_geo_db_location" VALUES(42602,NULL,'Maple Plain, MN 55571',17552,222,NULL,41,24713,0);
INSERT INTO "django_geo_db_location" VALUES(42603,NULL,'Maple Plain, MN 55572',17552,222,NULL,41,24714,0);
INSERT INTO "django_geo_db_location" VALUES(42604,NULL,'Young America, MN 55573',17592,222,NULL,41,24715,0);
INSERT INTO "django_geo_db_location" VALUES(42605,NULL,'Maple Plain, MN 55574',17552,222,NULL,41,24716,0);
INSERT INTO "django_geo_db_location" VALUES(42606,NULL,'Howard Lake, MN 55575',17553,222,NULL,41,24717,0);
INSERT INTO "django_geo_db_location" VALUES(42607,NULL,'Maple Plain, MN 55576',17552,222,NULL,41,24718,0);
INSERT INTO "django_geo_db_location" VALUES(42608,NULL,'Maple Plain, MN 55577',17552,222,NULL,41,24719,0);
INSERT INTO "django_geo_db_location" VALUES(42609,NULL,'Maple Plain, MN 55578',17552,222,NULL,41,24720,0);
INSERT INTO "django_geo_db_location" VALUES(42610,NULL,'Maple Plain, MN 55579',17552,222,NULL,41,24721,0);
INSERT INTO "django_geo_db_location" VALUES(42611,NULL,'Monticello, MN 55580',17564,222,NULL,41,24722,0);
INSERT INTO "django_geo_db_location" VALUES(42612,NULL,'Monticello, MN 55581',17564,222,NULL,41,24723,0);
INSERT INTO "django_geo_db_location" VALUES(42613,NULL,'Monticello, MN 55582',17564,222,NULL,41,24724,0);
INSERT INTO "django_geo_db_location" VALUES(42614,NULL,'Norwood, MN 55583',17569,222,NULL,41,24725,0);
INSERT INTO "django_geo_db_location" VALUES(42615,NULL,'Monticello, MN 55584',17564,222,NULL,41,24726,0);
INSERT INTO "django_geo_db_location" VALUES(42616,NULL,'Monticello, MN 55585',17564,222,NULL,41,24727,0);
INSERT INTO "django_geo_db_location" VALUES(42617,NULL,'Monticello, MN 55586',17564,222,NULL,41,24728,0);
INSERT INTO "django_geo_db_location" VALUES(42618,NULL,'Monticello, MN 55587',17564,222,NULL,41,24729,0);
INSERT INTO "django_geo_db_location" VALUES(42619,NULL,'Monticello, MN 55588',17564,222,NULL,41,24730,0);
INSERT INTO "django_geo_db_location" VALUES(42620,NULL,'Monticello, MN 55589',17564,222,NULL,41,24731,0);
INSERT INTO "django_geo_db_location" VALUES(42621,NULL,'Monticello, MN 55590',17564,222,NULL,41,24732,0);
INSERT INTO "django_geo_db_location" VALUES(42622,NULL,'Monticello, MN 55591',17564,222,NULL,41,24733,0);
INSERT INTO "django_geo_db_location" VALUES(42623,NULL,'Maple Plain, MN 55592',17552,222,NULL,41,24734,0);
INSERT INTO "django_geo_db_location" VALUES(42624,NULL,'Maple Plain, MN 55593',17552,222,NULL,41,24735,0);
INSERT INTO "django_geo_db_location" VALUES(42625,NULL,'Young America, MN 55594',17592,222,NULL,41,24736,0);
INSERT INTO "django_geo_db_location" VALUES(42626,NULL,'Loretto, MN 55595',17560,222,NULL,41,24737,0);
INSERT INTO "django_geo_db_location" VALUES(42627,NULL,'Loretto, MN 55596',17560,222,NULL,41,24738,0);
INSERT INTO "django_geo_db_location" VALUES(42628,NULL,'Loretto, MN 55597',17560,222,NULL,41,24739,0);
INSERT INTO "django_geo_db_location" VALUES(42629,NULL,'Loretto, MN 55598',17560,222,NULL,41,24740,0);
INSERT INTO "django_geo_db_location" VALUES(42630,NULL,'Loretto, MN 55599',17560,222,NULL,41,24741,0);
INSERT INTO "django_geo_db_location" VALUES(42631,NULL,'Beaver Bay, MN',17597,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42632,NULL,'Beaver Bay, MN 55601',17597,222,NULL,41,24742,0);
INSERT INTO "django_geo_db_location" VALUES(42633,NULL,'Brimson, MN',17598,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42634,NULL,'Brimson, MN 55602',17598,222,NULL,41,24743,0);
INSERT INTO "django_geo_db_location" VALUES(42635,NULL,'Finland, MN',17599,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42636,NULL,'Finland, MN 55603',17599,222,NULL,41,24744,0);
INSERT INTO "django_geo_db_location" VALUES(42637,NULL,'Grand Marais, MN',17600,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42638,NULL,'Grand Marais, MN 55604',17600,222,NULL,41,24745,0);
INSERT INTO "django_geo_db_location" VALUES(42639,NULL,'Grand Portage, MN',17601,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42640,NULL,'Grand Portage, MN 55605',17601,222,NULL,41,24746,0);
INSERT INTO "django_geo_db_location" VALUES(42641,NULL,'Hovland, MN',17602,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42642,NULL,'Hovland, MN 55606',17602,222,NULL,41,24747,0);
INSERT INTO "django_geo_db_location" VALUES(42643,NULL,'Isabella, MN',17603,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42644,NULL,'Isabella, MN 55607',17603,222,NULL,41,24748,0);
INSERT INTO "django_geo_db_location" VALUES(42645,NULL,'Rosemount, MN 55608',17487,222,NULL,41,24749,0);
INSERT INTO "django_geo_db_location" VALUES(42646,NULL,'Knife River, MN',17604,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42647,NULL,'Knife River, MN 55609',17604,222,NULL,41,24750,0);
INSERT INTO "django_geo_db_location" VALUES(42648,NULL,'Lutsen, MN',17605,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42649,NULL,'Lutsen, MN 55612',17605,222,NULL,41,24751,0);
INSERT INTO "django_geo_db_location" VALUES(42650,NULL,'Schroeder, MN',17606,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42651,NULL,'Schroeder, MN 55613',17606,222,NULL,41,24752,0);
INSERT INTO "django_geo_db_location" VALUES(42652,NULL,'Silver Bay, MN',17607,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42653,NULL,'Silver Bay, MN 55614',17607,222,NULL,41,24753,0);
INSERT INTO "django_geo_db_location" VALUES(42654,NULL,'Tofte, MN',17608,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42655,NULL,'Tofte, MN 55615',17608,222,NULL,41,24754,0);
INSERT INTO "django_geo_db_location" VALUES(42656,NULL,'Two Harbors, MN',17609,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42657,NULL,'Two Harbors, MN 55616',17609,222,NULL,41,24755,0);
INSERT INTO "django_geo_db_location" VALUES(42658,NULL,'Barnum, MN',17610,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42659,NULL,'Barnum, MN 55676',17610,222,NULL,41,24756,0);
INSERT INTO "django_geo_db_location" VALUES(42660,NULL,'Adolph, MN',17611,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42661,NULL,'Adolph, MN 55701',17611,222,NULL,41,24757,0);
INSERT INTO "django_geo_db_location" VALUES(42662,NULL,'Alborn, MN',17612,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42663,NULL,'Alborn, MN 55702',17612,222,NULL,41,24758,0);
INSERT INTO "django_geo_db_location" VALUES(42664,NULL,'Angora, MN',17613,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42665,NULL,'Angora, MN 55703',17613,222,NULL,41,24759,0);
INSERT INTO "django_geo_db_location" VALUES(42666,NULL,'Askov, MN',17614,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42667,NULL,'Askov, MN 55704',17614,222,NULL,41,24760,0);
INSERT INTO "django_geo_db_location" VALUES(42668,NULL,'Aurora, MN',17615,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42669,NULL,'Aurora, MN 55705',17615,222,NULL,41,24761,0);
INSERT INTO "django_geo_db_location" VALUES(42670,NULL,'Babbitt, MN',17616,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42671,NULL,'Babbitt, MN 55706',17616,222,NULL,41,24762,0);
INSERT INTO "django_geo_db_location" VALUES(42672,NULL,'Barnum, MN 55707',17610,222,NULL,41,24763,0);
INSERT INTO "django_geo_db_location" VALUES(42673,NULL,'Biwabik, MN',17617,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42674,NULL,'Biwabik, MN 55708',17617,222,NULL,41,24764,0);
INSERT INTO "django_geo_db_location" VALUES(42675,NULL,'Bovey, MN',17618,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42676,NULL,'Bovey, MN 55709',17618,222,NULL,41,24765,0);
INSERT INTO "django_geo_db_location" VALUES(42677,NULL,'Britt, MN',17619,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42678,NULL,'Britt, MN 55710',17619,222,NULL,41,24766,0);
INSERT INTO "django_geo_db_location" VALUES(42679,NULL,'Brookston, MN',17620,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42680,NULL,'Brookston, MN 55711',17620,222,NULL,41,24767,0);
INSERT INTO "django_geo_db_location" VALUES(42681,NULL,'Bruno, MN',17621,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42682,NULL,'Bruno, MN 55712',17621,222,NULL,41,24768,0);
INSERT INTO "django_geo_db_location" VALUES(42683,NULL,'Buhl, MN',17622,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42684,NULL,'Buhl, MN 55713',17622,222,NULL,41,24769,0);
INSERT INTO "django_geo_db_location" VALUES(42685,NULL,'Buhl, MN 55715',17622,222,NULL,41,24770,0);
INSERT INTO "django_geo_db_location" VALUES(42686,NULL,'Calumet, MN',17623,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42687,NULL,'Calumet, MN 55716',17623,222,NULL,41,24771,0);
INSERT INTO "django_geo_db_location" VALUES(42688,NULL,'Canyon, MN',17624,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42689,NULL,'Canyon, MN 55717',17624,222,NULL,41,24772,0);
INSERT INTO "django_geo_db_location" VALUES(42690,NULL,'Carlton, MN',17625,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42691,NULL,'Carlton, MN 55718',17625,222,NULL,41,24773,0);
INSERT INTO "django_geo_db_location" VALUES(42692,NULL,'Chisholm, MN',17626,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42693,NULL,'Chisholm, MN 55719',17626,222,NULL,41,24774,0);
INSERT INTO "django_geo_db_location" VALUES(42694,NULL,'Cloquet, MN',17627,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42695,NULL,'Cloquet, MN 55720',17627,222,NULL,41,24775,0);
INSERT INTO "django_geo_db_location" VALUES(42696,NULL,'Cohasset, MN',17628,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42697,NULL,'Cohasset, MN 55721',17628,222,NULL,41,24776,0);
INSERT INTO "django_geo_db_location" VALUES(42698,NULL,'Coleraine, MN',17629,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42699,NULL,'Coleraine, MN 55722',17629,222,NULL,41,24777,0);
INSERT INTO "django_geo_db_location" VALUES(42700,NULL,'Cook, MN',17630,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42701,NULL,'Cook, MN 55723',17630,222,NULL,41,24778,0);
INSERT INTO "django_geo_db_location" VALUES(42702,NULL,'Cotton, MN',17631,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42703,NULL,'Cotton, MN 55724',17631,222,NULL,41,24779,0);
INSERT INTO "django_geo_db_location" VALUES(42704,NULL,'Crane Lake, MN',17632,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42705,NULL,'Crane Lake, MN 55725',17632,222,NULL,41,24780,0);
INSERT INTO "django_geo_db_location" VALUES(42706,NULL,'Cromwell, MN',17633,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42707,NULL,'Cromwell, MN 55726',17633,222,NULL,41,24781,0);
INSERT INTO "django_geo_db_location" VALUES(42708,NULL,'Bigfork, MN',17634,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42709,NULL,'Bigfork, MN 55728',17634,222,NULL,41,24782,0);
INSERT INTO "django_geo_db_location" VALUES(42710,NULL,'Grand Rapids, MN',17635,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42711,NULL,'Grand Rapids, MN 55730',17635,222,NULL,41,24783,0);
INSERT INTO "django_geo_db_location" VALUES(42712,NULL,'Ely, MN',17636,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42713,NULL,'Ely, MN 55731',17636,222,NULL,41,24784,0);
INSERT INTO "django_geo_db_location" VALUES(42714,NULL,'Embarrass, MN',17637,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42715,NULL,'Embarrass, MN 55732',17637,222,NULL,41,24785,0);
INSERT INTO "django_geo_db_location" VALUES(42716,NULL,'Esko, MN',17638,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42717,NULL,'Esko, MN 55733',17638,222,NULL,41,24786,0);
INSERT INTO "django_geo_db_location" VALUES(42718,NULL,'Eveleth, MN',17639,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42719,NULL,'Eveleth, MN 55734',17639,222,NULL,41,24787,0);
INSERT INTO "django_geo_db_location" VALUES(42720,NULL,'Finlayson, MN',17640,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42721,NULL,'Finlayson, MN 55735',17640,222,NULL,41,24788,0);
INSERT INTO "django_geo_db_location" VALUES(42722,NULL,'Floodwood, MN',17641,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42723,NULL,'Floodwood, MN 55736',17641,222,NULL,41,24789,0);
INSERT INTO "django_geo_db_location" VALUES(42724,NULL,'Forbes, MN',17642,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42725,NULL,'Forbes, MN 55738',17642,222,NULL,41,24790,0);
INSERT INTO "django_geo_db_location" VALUES(42726,NULL,'Gilbert, MN',17643,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42727,NULL,'Gilbert, MN 55741',17643,222,NULL,41,24791,0);
INSERT INTO "django_geo_db_location" VALUES(42728,NULL,'Goodland, MN',17644,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42729,NULL,'Goodland, MN 55742',17644,222,NULL,41,24792,0);
INSERT INTO "django_geo_db_location" VALUES(42730,NULL,'Grand Rapids, MN 55744',17635,222,NULL,41,24793,0);
INSERT INTO "django_geo_db_location" VALUES(42731,NULL,'Grand Rapids, MN 55745',17635,222,NULL,41,24794,0);
INSERT INTO "django_geo_db_location" VALUES(42732,NULL,'Hibbing, MN',17645,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42733,NULL,'Hibbing, MN 55746',17645,222,NULL,41,24795,0);
INSERT INTO "django_geo_db_location" VALUES(42734,NULL,'Hibbing, MN 55747',17645,222,NULL,41,24796,0);
INSERT INTO "django_geo_db_location" VALUES(42735,NULL,'Hill City, MN',17646,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42736,NULL,'Hill City, MN 55748',17646,222,NULL,41,24797,0);
INSERT INTO "django_geo_db_location" VALUES(42737,NULL,'Holyoke, MN',17647,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42738,NULL,'Holyoke, MN 55749',17647,222,NULL,41,24798,0);
INSERT INTO "django_geo_db_location" VALUES(42739,NULL,'Hoyt Lakes, MN',17648,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42740,NULL,'Hoyt Lakes, MN 55750',17648,222,NULL,41,24799,0);
INSERT INTO "django_geo_db_location" VALUES(42741,NULL,'Iron, MN',17649,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42742,NULL,'Iron, MN 55751',17649,222,NULL,41,24800,0);
INSERT INTO "django_geo_db_location" VALUES(42743,NULL,'Jacobson, MN',17650,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42744,NULL,'Jacobson, MN 55752',17650,222,NULL,41,24801,0);
INSERT INTO "django_geo_db_location" VALUES(42745,NULL,'Keewatin, MN',17651,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42746,NULL,'Keewatin, MN 55753',17651,222,NULL,41,24802,0);
INSERT INTO "django_geo_db_location" VALUES(42747,NULL,'Kerrick, MN',17652,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42748,NULL,'Kerrick, MN 55756',17652,222,NULL,41,24803,0);
INSERT INTO "django_geo_db_location" VALUES(42749,NULL,'Kettle River, MN',17653,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42750,NULL,'Kettle River, MN 55757',17653,222,NULL,41,24804,0);
INSERT INTO "django_geo_db_location" VALUES(42751,NULL,'Kinney, MN',17654,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42752,NULL,'Kinney, MN 55758',17654,222,NULL,41,24805,0);
INSERT INTO "django_geo_db_location" VALUES(42753,NULL,'Mcgregor, MN',17655,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42754,NULL,'Mcgregor, MN 55760',17655,222,NULL,41,24806,0);
INSERT INTO "django_geo_db_location" VALUES(42755,NULL,'McKinley, MN',17656,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42756,NULL,'McKinley, MN 55761',17656,222,NULL,41,24807,0);
INSERT INTO "django_geo_db_location" VALUES(42757,NULL,'Makinen, MN',17657,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42758,NULL,'Makinen, MN 55763',17657,222,NULL,41,24808,0);
INSERT INTO "django_geo_db_location" VALUES(42759,NULL,'Marble, MN',17658,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42760,NULL,'Marble, MN 55764',17658,222,NULL,41,24809,0);
INSERT INTO "django_geo_db_location" VALUES(42761,NULL,'Meadowlands, MN',17659,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42762,NULL,'Meadowlands, MN 55765',17659,222,NULL,41,24810,0);
INSERT INTO "django_geo_db_location" VALUES(42763,NULL,'Melrude, MN',17660,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42764,NULL,'Melrude, MN 55766',17660,222,NULL,41,24811,0);
INSERT INTO "django_geo_db_location" VALUES(42765,NULL,'Moose Lake, MN',17661,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42766,NULL,'Moose Lake, MN 55767',17661,222,NULL,41,24812,0);
INSERT INTO "django_geo_db_location" VALUES(42767,NULL,'Mountain Iron, MN',17662,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42768,NULL,'Mountain Iron, MN 55768',17662,222,NULL,41,24813,0);
INSERT INTO "django_geo_db_location" VALUES(42769,NULL,'Nashwauk, MN',17663,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42770,NULL,'Nashwauk, MN 55769',17663,222,NULL,41,24814,0);
INSERT INTO "django_geo_db_location" VALUES(42771,NULL,'Orr, MN',17664,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42772,NULL,'Orr, MN 55771',17664,222,NULL,41,24815,0);
INSERT INTO "django_geo_db_location" VALUES(42773,NULL,'Nett Lake, MN',17665,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42774,NULL,'Nett Lake, MN 55772',17665,222,NULL,41,24816,0);
INSERT INTO "django_geo_db_location" VALUES(42775,NULL,'Pengilly, MN',17666,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42776,NULL,'Pengilly, MN 55775',17666,222,NULL,41,24817,0);
INSERT INTO "django_geo_db_location" VALUES(42777,NULL,'Virginia, MN',17667,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42778,NULL,'Virginia, MN 55777',17667,222,NULL,41,24818,0);
INSERT INTO "django_geo_db_location" VALUES(42779,NULL,'Clark, MN',17668,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42780,NULL,'Clark, MN 55778',17668,222,NULL,41,24819,0);
INSERT INTO "django_geo_db_location" VALUES(42781,NULL,'Saginaw, MN',17669,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42782,NULL,'Saginaw, MN 55779',17669,222,NULL,41,24820,0);
INSERT INTO "django_geo_db_location" VALUES(42783,NULL,'Sawyer, MN',17670,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42784,NULL,'Sawyer, MN 55780',17670,222,NULL,41,24821,0);
INSERT INTO "django_geo_db_location" VALUES(42785,NULL,'Side Lake, MN',17671,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42786,NULL,'Side Lake, MN 55781',17671,222,NULL,41,24822,0);
INSERT INTO "django_geo_db_location" VALUES(42787,NULL,'Soudan, MN',17672,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42788,NULL,'Soudan, MN 55782',17672,222,NULL,41,24823,0);
INSERT INTO "django_geo_db_location" VALUES(42789,NULL,'Sturgeon Lake, MN',17673,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42790,NULL,'Sturgeon Lake, MN 55783',17673,222,NULL,41,24824,0);
INSERT INTO "django_geo_db_location" VALUES(42791,NULL,'Swan River, MN',17674,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42792,NULL,'Swan River, MN 55784',17674,222,NULL,41,24825,0);
INSERT INTO "django_geo_db_location" VALUES(42793,NULL,'Swatara, MN',17675,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42794,NULL,'Swatara, MN 55785',17675,222,NULL,41,24826,0);
INSERT INTO "django_geo_db_location" VALUES(42795,NULL,'Taconite, MN',17676,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42796,NULL,'Taconite, MN 55786',17676,222,NULL,41,24827,0);
INSERT INTO "django_geo_db_location" VALUES(42797,NULL,'Tamarack, MN',17677,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42798,NULL,'Tamarack, MN 55787',17677,222,NULL,41,24828,0);
INSERT INTO "django_geo_db_location" VALUES(42799,NULL,'Tower, MN',17678,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42800,NULL,'Tower, MN 55790',17678,222,NULL,41,24829,0);
INSERT INTO "django_geo_db_location" VALUES(42801,NULL,'Twig, MN',17679,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42802,NULL,'Twig, MN 55791',17679,222,NULL,41,24830,0);
INSERT INTO "django_geo_db_location" VALUES(42803,NULL,'Virginia, MN 55792',17667,222,NULL,41,24831,0);
INSERT INTO "django_geo_db_location" VALUES(42804,NULL,'Warba, MN',17680,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42805,NULL,'Warba, MN 55793',17680,222,NULL,41,24832,0);
INSERT INTO "django_geo_db_location" VALUES(42806,NULL,'Willow River, MN',17681,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42807,NULL,'Willow River, MN 55795',17681,222,NULL,41,24833,0);
INSERT INTO "django_geo_db_location" VALUES(42808,NULL,'Winton, MN',17682,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42809,NULL,'Winton, MN 55796',17682,222,NULL,41,24834,0);
INSERT INTO "django_geo_db_location" VALUES(42810,NULL,'Wrenshall, MN',17683,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42811,NULL,'Wrenshall, MN 55797',17683,222,NULL,41,24835,0);
INSERT INTO "django_geo_db_location" VALUES(42812,NULL,'Wright, MN',17684,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42813,NULL,'Wright, MN 55798',17684,222,NULL,41,24836,0);
INSERT INTO "django_geo_db_location" VALUES(42814,NULL,'Duluth, MN 55801',17508,222,NULL,41,24837,0);
INSERT INTO "django_geo_db_location" VALUES(42815,NULL,'Duluth, MN 55802',17508,222,NULL,41,24838,0);
INSERT INTO "django_geo_db_location" VALUES(42816,NULL,'Duluth, MN 55803',17508,222,NULL,41,24839,0);
INSERT INTO "django_geo_db_location" VALUES(42817,NULL,'Duluth, MN 55804',17508,222,NULL,41,24840,0);
INSERT INTO "django_geo_db_location" VALUES(42818,NULL,'Duluth, MN 55805',17508,222,NULL,41,24841,0);
INSERT INTO "django_geo_db_location" VALUES(42819,NULL,'Duluth, MN 55806',17508,222,NULL,41,24842,0);
INSERT INTO "django_geo_db_location" VALUES(42820,NULL,'Duluth, MN 55807',17508,222,NULL,41,24843,0);
INSERT INTO "django_geo_db_location" VALUES(42821,NULL,'Duluth, MN 55808',17508,222,NULL,41,24844,0);
INSERT INTO "django_geo_db_location" VALUES(42822,NULL,'Duluth, MN 55810',17508,222,NULL,41,24845,0);
INSERT INTO "django_geo_db_location" VALUES(42823,NULL,'Duluth, MN 55811',17508,222,NULL,41,24846,0);
INSERT INTO "django_geo_db_location" VALUES(42824,NULL,'Duluth, MN 55812',17508,222,NULL,41,24847,0);
INSERT INTO "django_geo_db_location" VALUES(42825,NULL,'Duluth, MN 55814',17508,222,NULL,41,24848,0);
INSERT INTO "django_geo_db_location" VALUES(42826,NULL,'Duluth, MN 55815',17508,222,NULL,41,24849,0);
INSERT INTO "django_geo_db_location" VALUES(42827,NULL,'Duluth, MN 55816',17508,222,NULL,41,24850,0);
INSERT INTO "django_geo_db_location" VALUES(42828,NULL,'Rochester, MN',17685,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42829,NULL,'Rochester, MN 55901',17685,222,NULL,41,24851,0);
INSERT INTO "django_geo_db_location" VALUES(42830,NULL,'Rochester, MN 55902',17685,222,NULL,41,24852,0);
INSERT INTO "django_geo_db_location" VALUES(42831,NULL,'Rochester, MN 55903',17685,222,NULL,41,24853,0);
INSERT INTO "django_geo_db_location" VALUES(42832,NULL,'Rochester, MN 55904',17685,222,NULL,41,24854,0);
INSERT INTO "django_geo_db_location" VALUES(42833,NULL,'Rochester, MN 55905',17685,222,NULL,41,24855,0);
INSERT INTO "django_geo_db_location" VALUES(42834,NULL,'Rochester, MN 55906',17685,222,NULL,41,24856,0);
INSERT INTO "django_geo_db_location" VALUES(42835,NULL,'Adams, MN',17686,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42836,NULL,'Adams, MN 55909',17686,222,NULL,41,24857,0);
INSERT INTO "django_geo_db_location" VALUES(42837,NULL,'Altura, MN',17687,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42838,NULL,'Altura, MN 55910',17687,222,NULL,41,24858,0);
INSERT INTO "django_geo_db_location" VALUES(42839,NULL,'Austin, MN',17688,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42840,NULL,'Austin, MN 55912',17688,222,NULL,41,24859,0);
INSERT INTO "django_geo_db_location" VALUES(42841,NULL,'Blooming Prairie, MN',17689,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42842,NULL,'Blooming Prairie, MN 55917',17689,222,NULL,41,24860,0);
INSERT INTO "django_geo_db_location" VALUES(42843,NULL,'Brownsdale, MN',17690,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42844,NULL,'Brownsdale, MN 55918',17690,222,NULL,41,24861,0);
INSERT INTO "django_geo_db_location" VALUES(42845,NULL,'Brownsville, MN',17691,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42846,NULL,'Brownsville, MN 55919',17691,222,NULL,41,24862,0);
INSERT INTO "django_geo_db_location" VALUES(42847,NULL,'Byron, MN',17692,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42848,NULL,'Byron, MN 55920',17692,222,NULL,41,24863,0);
INSERT INTO "django_geo_db_location" VALUES(42849,NULL,'Caledonia, MN',17693,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42850,NULL,'Caledonia, MN 55921',17693,222,NULL,41,24864,0);
INSERT INTO "django_geo_db_location" VALUES(42851,NULL,'Canton, MN',17694,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42852,NULL,'Canton, MN 55922',17694,222,NULL,41,24865,0);
INSERT INTO "django_geo_db_location" VALUES(42853,NULL,'Chatfield, MN',17695,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42854,NULL,'Chatfield, MN 55923',17695,222,NULL,41,24866,0);
INSERT INTO "django_geo_db_location" VALUES(42855,NULL,'Claremont, MN',17696,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42856,NULL,'Claremont, MN 55924',17696,222,NULL,41,24867,0);
INSERT INTO "django_geo_db_location" VALUES(42857,NULL,'Dakota, MN',17697,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42858,NULL,'Dakota, MN 55925',17697,222,NULL,41,24868,0);
INSERT INTO "django_geo_db_location" VALUES(42859,NULL,'Dexter, MN',17698,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42860,NULL,'Dexter, MN 55926',17698,222,NULL,41,24869,0);
INSERT INTO "django_geo_db_location" VALUES(42861,NULL,'Dodge Center, MN',17699,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42862,NULL,'Dodge Center, MN 55927',17699,222,NULL,41,24870,0);
INSERT INTO "django_geo_db_location" VALUES(42863,NULL,'Dover, MN',17700,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42864,NULL,'Dover, MN 55929',17700,222,NULL,41,24871,0);
INSERT INTO "django_geo_db_location" VALUES(42865,NULL,'Eitzen, MN',17701,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42866,NULL,'Eitzen, MN 55931',17701,222,NULL,41,24872,0);
INSERT INTO "django_geo_db_location" VALUES(42867,NULL,'Elgin, MN',17702,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42868,NULL,'Elgin, MN 55932',17702,222,NULL,41,24873,0);
INSERT INTO "django_geo_db_location" VALUES(42869,NULL,'Elkton, MN',17703,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42870,NULL,'Elkton, MN 55933',17703,222,NULL,41,24874,0);
INSERT INTO "django_geo_db_location" VALUES(42871,NULL,'Eyota, MN',17704,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42872,NULL,'Eyota, MN 55934',17704,222,NULL,41,24875,0);
INSERT INTO "django_geo_db_location" VALUES(42873,NULL,'Fountain, MN',17705,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42874,NULL,'Fountain, MN 55935',17705,222,NULL,41,24876,0);
INSERT INTO "django_geo_db_location" VALUES(42875,NULL,'Grand Meadow, MN',17706,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42876,NULL,'Grand Meadow, MN 55936',17706,222,NULL,41,24877,0);
INSERT INTO "django_geo_db_location" VALUES(42877,NULL,'Harmony, MN',17707,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42878,NULL,'Harmony, MN 55939',17707,222,NULL,41,24878,0);
INSERT INTO "django_geo_db_location" VALUES(42879,NULL,'Hayfield, MN',17708,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42880,NULL,'Hayfield, MN 55940',17708,222,NULL,41,24879,0);
INSERT INTO "django_geo_db_location" VALUES(42881,NULL,'Hokah, MN',17709,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42882,NULL,'Hokah, MN 55941',17709,222,NULL,41,24880,0);
INSERT INTO "django_geo_db_location" VALUES(42883,NULL,'Homer, MN',17710,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42884,NULL,'Homer, MN 55942',17710,222,NULL,41,24881,0);
INSERT INTO "django_geo_db_location" VALUES(42885,NULL,'Houston, MN',17711,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42886,NULL,'Houston, MN 55943',17711,222,NULL,41,24882,0);
INSERT INTO "django_geo_db_location" VALUES(42887,NULL,'Kasson, MN',17712,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42888,NULL,'Kasson, MN 55944',17712,222,NULL,41,24883,0);
INSERT INTO "django_geo_db_location" VALUES(42889,NULL,'Kellogg, MN',17713,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42890,NULL,'Kellogg, MN 55945',17713,222,NULL,41,24884,0);
INSERT INTO "django_geo_db_location" VALUES(42891,NULL,'Kenyon, MN',17714,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42892,NULL,'Kenyon, MN 55946',17714,222,NULL,41,24885,0);
INSERT INTO "django_geo_db_location" VALUES(42893,NULL,'La Crescent, MN',17715,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42894,NULL,'La Crescent, MN 55947',17715,222,NULL,41,24886,0);
INSERT INTO "django_geo_db_location" VALUES(42895,NULL,'Lanesboro, MN',17716,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42896,NULL,'Lanesboro, MN 55949',17716,222,NULL,41,24887,0);
INSERT INTO "django_geo_db_location" VALUES(42897,NULL,'Lansing, MN',17717,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42898,NULL,'Lansing, MN 55950',17717,222,NULL,41,24888,0);
INSERT INTO "django_geo_db_location" VALUES(42899,NULL,'Le Roy, MN',17718,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42900,NULL,'Le Roy, MN 55951',17718,222,NULL,41,24889,0);
INSERT INTO "django_geo_db_location" VALUES(42901,NULL,'Lewiston, MN',17719,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42902,NULL,'Lewiston, MN 55952',17719,222,NULL,41,24890,0);
INSERT INTO "django_geo_db_location" VALUES(42903,NULL,'Lyle, MN',17720,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42904,NULL,'Lyle, MN 55953',17720,222,NULL,41,24891,0);
INSERT INTO "django_geo_db_location" VALUES(42905,NULL,'Mabel, IA',17721,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42906,NULL,'Mabel, IA 55954',17721,222,NULL,19,24892,0);
INSERT INTO "django_geo_db_location" VALUES(42907,NULL,'Mantorville, MN',17722,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42908,NULL,'Mantorville, MN 55955',17722,222,NULL,41,24893,0);
INSERT INTO "django_geo_db_location" VALUES(42909,NULL,'Mazeppa, MN',17723,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42910,NULL,'Mazeppa, MN 55956',17723,222,NULL,41,24894,0);
INSERT INTO "django_geo_db_location" VALUES(42911,NULL,'Millville, MN',17724,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42912,NULL,'Millville, MN 55957',17724,222,NULL,41,24895,0);
INSERT INTO "django_geo_db_location" VALUES(42913,NULL,'Minnesota City, MN',17725,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42914,NULL,'Minnesota City, MN 55959',17725,222,NULL,41,24896,0);
INSERT INTO "django_geo_db_location" VALUES(42915,NULL,'Oronoco, MN',17726,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42916,NULL,'Oronoco, MN 55960',17726,222,NULL,41,24897,0);
INSERT INTO "django_geo_db_location" VALUES(42917,NULL,'Ostrander, MN',17727,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42918,NULL,'Ostrander, MN 55961',17727,222,NULL,41,24898,0);
INSERT INTO "django_geo_db_location" VALUES(42919,NULL,'Peterson, MN',17728,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42920,NULL,'Peterson, MN 55962',17728,222,NULL,41,24899,0);
INSERT INTO "django_geo_db_location" VALUES(42921,NULL,'Pine Island, MN',17729,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42922,NULL,'Pine Island, MN 55963',17729,222,NULL,41,24900,0);
INSERT INTO "django_geo_db_location" VALUES(42923,NULL,'Plainview, MN',17730,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42924,NULL,'Plainview, MN 55964',17730,222,NULL,41,24901,0);
INSERT INTO "django_geo_db_location" VALUES(42925,NULL,'Preston, MN',17731,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42926,NULL,'Preston, MN 55965',17731,222,NULL,41,24902,0);
INSERT INTO "django_geo_db_location" VALUES(42927,NULL,'Racine, MN',17732,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42928,NULL,'Racine, MN 55967',17732,222,NULL,41,24903,0);
INSERT INTO "django_geo_db_location" VALUES(42929,NULL,'Reads Landing, MN',17733,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42930,NULL,'Reads Landing, MN 55968',17733,222,NULL,41,24904,0);
INSERT INTO "django_geo_db_location" VALUES(42931,NULL,'Rollingstone, MN',17734,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42932,NULL,'Rollingstone, MN 55969',17734,222,NULL,41,24905,0);
INSERT INTO "django_geo_db_location" VALUES(42933,NULL,'Rose Creek, MN',17735,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42934,NULL,'Rose Creek, MN 55970',17735,222,NULL,41,24906,0);
INSERT INTO "django_geo_db_location" VALUES(42935,NULL,'Rushford, MN',17736,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42936,NULL,'Rushford, MN 55971',17736,222,NULL,41,24907,0);
INSERT INTO "django_geo_db_location" VALUES(42937,NULL,'Saint Charles, MN',17737,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42938,NULL,'Saint Charles, MN 55972',17737,222,NULL,41,24908,0);
INSERT INTO "django_geo_db_location" VALUES(42939,NULL,'Sargeant, MN',17738,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42940,NULL,'Sargeant, MN 55973',17738,222,NULL,41,24909,0);
INSERT INTO "django_geo_db_location" VALUES(42941,NULL,'Spring Grove, MN',17739,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42942,NULL,'Spring Grove, MN 55974',17739,222,NULL,41,24910,0);
INSERT INTO "django_geo_db_location" VALUES(42943,NULL,'Spring Valley, MN',17740,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42944,NULL,'Spring Valley, MN 55975',17740,222,NULL,41,24911,0);
INSERT INTO "django_geo_db_location" VALUES(42945,NULL,'Stewartville, MN',17741,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42946,NULL,'Stewartville, MN 55976',17741,222,NULL,41,24912,0);
INSERT INTO "django_geo_db_location" VALUES(42947,NULL,'Taopi, MN',17742,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42948,NULL,'Taopi, MN 55977',17742,222,NULL,41,24913,0);
INSERT INTO "django_geo_db_location" VALUES(42949,NULL,'West Albany, MN',17743,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42950,NULL,'West Albany, MN 55978',17743,222,NULL,41,24914,0);
INSERT INTO "django_geo_db_location" VALUES(42951,NULL,'Utica, MN',17744,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42952,NULL,'Utica, MN 55979',17744,222,NULL,41,24915,0);
INSERT INTO "django_geo_db_location" VALUES(42953,NULL,'Wabasha, MN',17745,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42954,NULL,'Wabasha, MN 55981',17745,222,NULL,41,24916,0);
INSERT INTO "django_geo_db_location" VALUES(42955,NULL,'Waltham, MN',17746,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42956,NULL,'Waltham, MN 55982',17746,222,NULL,41,24917,0);
INSERT INTO "django_geo_db_location" VALUES(42957,NULL,'Wanamingo, MN',17747,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42958,NULL,'Wanamingo, MN 55983',17747,222,NULL,41,24918,0);
INSERT INTO "django_geo_db_location" VALUES(42959,NULL,'West Concord, MN',17748,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42960,NULL,'West Concord, MN 55985',17748,222,NULL,41,24919,0);
INSERT INTO "django_geo_db_location" VALUES(42961,NULL,'Winona, MN',17749,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42962,NULL,'Winona, MN 55987',17749,222,NULL,41,24920,0);
INSERT INTO "django_geo_db_location" VALUES(42963,NULL,'Stockton, MN',17750,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42964,NULL,'Stockton, MN 55988',17750,222,NULL,41,24921,0);
INSERT INTO "django_geo_db_location" VALUES(42965,NULL,'Wykoff, MN',17751,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42966,NULL,'Wykoff, MN 55990',17751,222,NULL,41,24922,0);
INSERT INTO "django_geo_db_location" VALUES(42967,NULL,'Zumbro Falls, MN',17752,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42968,NULL,'Zumbro Falls, MN 55991',17752,222,NULL,41,24923,0);
INSERT INTO "django_geo_db_location" VALUES(42969,NULL,'Zumbrota, MN',17753,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42970,NULL,'Zumbrota, MN 55992',17753,222,NULL,41,24924,0);
INSERT INTO "django_geo_db_location" VALUES(42971,NULL,'Mankato, MN',17754,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42972,NULL,'Mankato, MN 56001',17754,222,NULL,41,24925,0);
INSERT INTO "django_geo_db_location" VALUES(42973,NULL,'Mankato, MN 56002',17754,222,NULL,41,24926,0);
INSERT INTO "django_geo_db_location" VALUES(42974,NULL,'Mankato, MN 56003',17754,222,NULL,41,24927,0);
INSERT INTO "django_geo_db_location" VALUES(42975,NULL,'Mankato, MN 56006',17754,222,NULL,41,24928,0);
INSERT INTO "django_geo_db_location" VALUES(42976,NULL,'Albert Lea, MN',17755,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42977,NULL,'Albert Lea, MN 56007',17755,222,NULL,41,24929,0);
INSERT INTO "django_geo_db_location" VALUES(42978,NULL,'Alden, MN',17756,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42979,NULL,'Alden, MN 56009',17756,222,NULL,41,24930,0);
INSERT INTO "django_geo_db_location" VALUES(42980,NULL,'Amboy, MN',17757,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42981,NULL,'Amboy, MN 56010',17757,222,NULL,41,24931,0);
INSERT INTO "django_geo_db_location" VALUES(42982,NULL,'Belle Plaine, MN',17758,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42983,NULL,'Belle Plaine, MN 56011',17758,222,NULL,41,24932,0);
INSERT INTO "django_geo_db_location" VALUES(42984,NULL,'Blue Earth, MN',17759,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42985,NULL,'Blue Earth, MN 56013',17759,222,NULL,41,24933,0);
INSERT INTO "django_geo_db_location" VALUES(42986,NULL,'Bricelyn, MN',17760,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42987,NULL,'Bricelyn, MN 56014',17760,222,NULL,41,24934,0);
INSERT INTO "django_geo_db_location" VALUES(42988,NULL,'Clarks Grove, MN',17761,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42989,NULL,'Clarks Grove, MN 56016',17761,222,NULL,41,24935,0);
INSERT INTO "django_geo_db_location" VALUES(42990,NULL,'Cleveland, MN',17762,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42991,NULL,'Cleveland, MN 56017',17762,222,NULL,41,24936,0);
INSERT INTO "django_geo_db_location" VALUES(42992,NULL,'Comfrey, MN',17763,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42993,NULL,'Comfrey, MN 56019',17763,222,NULL,41,24937,0);
INSERT INTO "django_geo_db_location" VALUES(42994,NULL,'Conger, MN',17764,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42995,NULL,'Conger, MN 56020',17764,222,NULL,41,24938,0);
INSERT INTO "django_geo_db_location" VALUES(42996,NULL,'Courtland, MN',17765,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42997,NULL,'Courtland, MN 56021',17765,222,NULL,41,24939,0);
INSERT INTO "django_geo_db_location" VALUES(42998,NULL,'Darfur, MN',17766,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(42999,NULL,'Darfur, MN 56022',17766,222,NULL,41,24940,0);
INSERT INTO "django_geo_db_location" VALUES(43000,NULL,'Delavan, MN',17767,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43001,NULL,'Delavan, MN 56023',17767,222,NULL,41,24941,0);
INSERT INTO "django_geo_db_location" VALUES(43002,NULL,'Eagle Lake, MN',17768,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43003,NULL,'Eagle Lake, MN 56024',17768,222,NULL,41,24942,0);
INSERT INTO "django_geo_db_location" VALUES(43004,NULL,'Easton, MN',17769,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43005,NULL,'Easton, MN 56025',17769,222,NULL,41,24943,0);
INSERT INTO "django_geo_db_location" VALUES(43006,NULL,'Ellendale, MN',17770,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43007,NULL,'Ellendale, MN 56026',17770,222,NULL,41,24944,0);
INSERT INTO "django_geo_db_location" VALUES(43008,NULL,'Elmore, IA',17771,222,NULL,19,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43009,NULL,'Elmore, IA 56027',17771,222,NULL,19,24945,0);
INSERT INTO "django_geo_db_location" VALUES(43010,NULL,'Elysian, MN',17772,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43011,NULL,'Elysian, MN 56028',17772,222,NULL,41,24946,0);
INSERT INTO "django_geo_db_location" VALUES(43012,NULL,'Emmons, MN',17773,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43013,NULL,'Emmons, MN 56029',17773,222,NULL,41,24947,0);
INSERT INTO "django_geo_db_location" VALUES(43014,NULL,'Essig, MN',17774,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43015,NULL,'Essig, MN 56030',17774,222,NULL,41,24948,0);
INSERT INTO "django_geo_db_location" VALUES(43016,NULL,'Fairmont, MN',17775,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43017,NULL,'Fairmont, MN 56031',17775,222,NULL,41,24949,0);
INSERT INTO "django_geo_db_location" VALUES(43018,NULL,'Freeborn, MN',17776,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43019,NULL,'Freeborn, MN 56032',17776,222,NULL,41,24950,0);
INSERT INTO "django_geo_db_location" VALUES(43020,NULL,'Frost, MN',17777,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43021,NULL,'Frost, MN 56033',17777,222,NULL,41,24951,0);
INSERT INTO "django_geo_db_location" VALUES(43022,NULL,'Garden City, MN',17778,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43023,NULL,'Garden City, MN 56034',17778,222,NULL,41,24952,0);
INSERT INTO "django_geo_db_location" VALUES(43024,NULL,'Geneva, MN',17779,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43025,NULL,'Geneva, MN 56035',17779,222,NULL,41,24953,0);
INSERT INTO "django_geo_db_location" VALUES(43026,NULL,'Glenville, MN',17780,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43027,NULL,'Glenville, MN 56036',17780,222,NULL,41,24954,0);
INSERT INTO "django_geo_db_location" VALUES(43028,NULL,'Good Thunder, MN',17781,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43029,NULL,'Good Thunder, MN 56037',17781,222,NULL,41,24955,0);
INSERT INTO "django_geo_db_location" VALUES(43030,NULL,'Granada, MN',17782,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43031,NULL,'Granada, MN 56039',17782,222,NULL,41,24956,0);
INSERT INTO "django_geo_db_location" VALUES(43032,NULL,'Hanska, MN',17783,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43033,NULL,'Hanska, MN 56041',17783,222,NULL,41,24957,0);
INSERT INTO "django_geo_db_location" VALUES(43034,NULL,'Hartland, MN',17784,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43035,NULL,'Hartland, MN 56042',17784,222,NULL,41,24958,0);
INSERT INTO "django_geo_db_location" VALUES(43036,NULL,'Hayward, MN',17785,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43037,NULL,'Hayward, MN 56043',17785,222,NULL,41,24959,0);
INSERT INTO "django_geo_db_location" VALUES(43038,NULL,'Henderson, MN',17786,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43039,NULL,'Henderson, MN 56044',17786,222,NULL,41,24960,0);
INSERT INTO "django_geo_db_location" VALUES(43040,NULL,'Hollandale, MN',17787,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43041,NULL,'Hollandale, MN 56045',17787,222,NULL,41,24961,0);
INSERT INTO "django_geo_db_location" VALUES(43042,NULL,'Hope, MN',17788,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43043,NULL,'Hope, MN 56046',17788,222,NULL,41,24962,0);
INSERT INTO "django_geo_db_location" VALUES(43044,NULL,'Huntley, MN',17789,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43045,NULL,'Huntley, MN 56047',17789,222,NULL,41,24963,0);
INSERT INTO "django_geo_db_location" VALUES(43046,NULL,'Janesville, MN',17790,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43047,NULL,'Janesville, MN 56048',17790,222,NULL,41,24964,0);
INSERT INTO "django_geo_db_location" VALUES(43048,NULL,'Kasota, MN',17791,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43049,NULL,'Kasota, MN 56050',17791,222,NULL,41,24965,0);
INSERT INTO "django_geo_db_location" VALUES(43050,NULL,'Kiester, MN',17792,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43051,NULL,'Kiester, MN 56051',17792,222,NULL,41,24966,0);
INSERT INTO "django_geo_db_location" VALUES(43052,NULL,'Kilkenny, MN',17793,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43053,NULL,'Kilkenny, MN 56052',17793,222,NULL,41,24967,0);
INSERT INTO "django_geo_db_location" VALUES(43054,NULL,'Lafayette, MN',17794,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43055,NULL,'Lafayette, MN 56054',17794,222,NULL,41,24968,0);
INSERT INTO "django_geo_db_location" VALUES(43056,NULL,'Lake Crystal, MN',17795,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43057,NULL,'Lake Crystal, MN 56055',17795,222,NULL,41,24969,0);
INSERT INTO "django_geo_db_location" VALUES(43058,NULL,'La Salle, MN',17796,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43059,NULL,'La Salle, MN 56056',17796,222,NULL,41,24970,0);
INSERT INTO "django_geo_db_location" VALUES(43060,NULL,'Le Center, MN',17797,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43061,NULL,'Le Center, MN 56057',17797,222,NULL,41,24971,0);
INSERT INTO "django_geo_db_location" VALUES(43062,NULL,'Le Sueur, MN',17798,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43063,NULL,'Le Sueur, MN 56058',17798,222,NULL,41,24972,0);
INSERT INTO "django_geo_db_location" VALUES(43064,NULL,'Lewisville, MN',17799,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43065,NULL,'Lewisville, MN 56060',17799,222,NULL,41,24973,0);
INSERT INTO "django_geo_db_location" VALUES(43066,NULL,'Madelia, MN',17800,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43067,NULL,'Madelia, MN 56062',17800,222,NULL,41,24974,0);
INSERT INTO "django_geo_db_location" VALUES(43068,NULL,'Madison Lake, MN',17801,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43069,NULL,'Madison Lake, MN 56063',17801,222,NULL,41,24975,0);
INSERT INTO "django_geo_db_location" VALUES(43070,NULL,'Manchester, MN',17802,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43071,NULL,'Manchester, MN 56064',17802,222,NULL,41,24976,0);
INSERT INTO "django_geo_db_location" VALUES(43072,NULL,'Mapleton, MN',17803,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43073,NULL,'Mapleton, MN 56065',17803,222,NULL,41,24977,0);
INSERT INTO "django_geo_db_location" VALUES(43074,NULL,'Minnesota Lake, MN',17804,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43075,NULL,'Minnesota Lake, MN 56068',17804,222,NULL,41,24978,0);
INSERT INTO "django_geo_db_location" VALUES(43076,NULL,'Montgomery, MN',17805,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43077,NULL,'Montgomery, MN 56069',17805,222,NULL,41,24979,0);
INSERT INTO "django_geo_db_location" VALUES(43078,NULL,'New Prague, MN',17806,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43079,NULL,'New Prague, MN 56071',17806,222,NULL,41,24980,0);
INSERT INTO "django_geo_db_location" VALUES(43080,NULL,'New Richland, MN',17807,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43081,NULL,'New Richland, MN 56072',17807,222,NULL,41,24981,0);
INSERT INTO "django_geo_db_location" VALUES(43082,NULL,'New Ulm, MN',17808,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43083,NULL,'New Ulm, MN 56073',17808,222,NULL,41,24982,0);
INSERT INTO "django_geo_db_location" VALUES(43084,NULL,'Nicollet, MN',17809,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43085,NULL,'Nicollet, MN 56074',17809,222,NULL,41,24983,0);
INSERT INTO "django_geo_db_location" VALUES(43086,NULL,'Northrop, MN',17810,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43087,NULL,'Northrop, MN 56075',17810,222,NULL,41,24984,0);
INSERT INTO "django_geo_db_location" VALUES(43088,NULL,'Oakland, MN',17811,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43089,NULL,'Oakland, MN 56076',17811,222,NULL,41,24985,0);
INSERT INTO "django_geo_db_location" VALUES(43090,NULL,'Pemberton, MN',17812,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43091,NULL,'Pemberton, MN 56078',17812,222,NULL,41,24986,0);
INSERT INTO "django_geo_db_location" VALUES(43092,NULL,'Saint Clair, MN',17813,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43093,NULL,'Saint Clair, MN 56080',17813,222,NULL,41,24987,0);
INSERT INTO "django_geo_db_location" VALUES(43094,NULL,'Saint James, MN',17814,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43095,NULL,'Saint James, MN 56081',17814,222,NULL,41,24988,0);
INSERT INTO "django_geo_db_location" VALUES(43096,NULL,'Saint Peter, MN',17815,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43097,NULL,'Saint Peter, MN 56082',17815,222,NULL,41,24989,0);
INSERT INTO "django_geo_db_location" VALUES(43098,NULL,'Sanborn, MN',17816,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43099,NULL,'Sanborn, MN 56083',17816,222,NULL,41,24990,0);
INSERT INTO "django_geo_db_location" VALUES(43100,NULL,'Searles, MN',17817,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43101,NULL,'Searles, MN 56084',17817,222,NULL,41,24991,0);
INSERT INTO "django_geo_db_location" VALUES(43102,NULL,'Sleepy Eye, MN',17818,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43103,NULL,'Sleepy Eye, MN 56085',17818,222,NULL,41,24992,0);
INSERT INTO "django_geo_db_location" VALUES(43104,NULL,'Springfield, MN',17819,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43105,NULL,'Springfield, MN 56087',17819,222,NULL,41,24993,0);
INSERT INTO "django_geo_db_location" VALUES(43106,NULL,'Truman, MN',17820,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43107,NULL,'Truman, MN 56088',17820,222,NULL,41,24994,0);
INSERT INTO "django_geo_db_location" VALUES(43108,NULL,'Twin Lakes, MN',17821,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43109,NULL,'Twin Lakes, MN 56089',17821,222,NULL,41,24995,0);
INSERT INTO "django_geo_db_location" VALUES(43110,NULL,'Vernon Center, MN',17822,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43111,NULL,'Vernon Center, MN 56090',17822,222,NULL,41,24996,0);
INSERT INTO "django_geo_db_location" VALUES(43112,NULL,'Waldorf, MN',17823,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43113,NULL,'Waldorf, MN 56091',17823,222,NULL,41,24997,0);
INSERT INTO "django_geo_db_location" VALUES(43114,NULL,'Waseca, MN',17824,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43115,NULL,'Waseca, MN 56093',17824,222,NULL,41,24998,0);
INSERT INTO "django_geo_db_location" VALUES(43116,NULL,'Waterville, MN',17825,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43117,NULL,'Waterville, MN 56096',17825,222,NULL,41,24999,0);
INSERT INTO "django_geo_db_location" VALUES(43118,NULL,'Wells, MN',17826,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43119,NULL,'Wells, MN 56097',17826,222,NULL,41,25000,0);
INSERT INTO "django_geo_db_location" VALUES(43120,NULL,'Winnebago, MN',17827,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43121,NULL,'Winnebago, MN 56098',17827,222,NULL,41,25001,0);
INSERT INTO "django_geo_db_location" VALUES(43122,NULL,'Windom, MN',17828,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43123,NULL,'Windom, MN 56101',17828,222,NULL,41,25002,0);
INSERT INTO "django_geo_db_location" VALUES(43124,NULL,'Adrian, MN',17829,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43125,NULL,'Adrian, MN 56110',17829,222,NULL,41,25003,0);
INSERT INTO "django_geo_db_location" VALUES(43126,NULL,'Alpha, MN',17830,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43127,NULL,'Alpha, MN 56111',17830,222,NULL,41,25004,0);
INSERT INTO "django_geo_db_location" VALUES(43128,NULL,'Arco, MN',17831,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43129,NULL,'Arco, MN 56113',17831,222,NULL,41,25005,0);
INSERT INTO "django_geo_db_location" VALUES(43130,NULL,'Avoca, MN',17832,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43131,NULL,'Avoca, MN 56114',17832,222,NULL,41,25006,0);
INSERT INTO "django_geo_db_location" VALUES(43132,NULL,'Balaton, MN',17833,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43133,NULL,'Balaton, MN 56115',17833,222,NULL,41,25007,0);
INSERT INTO "django_geo_db_location" VALUES(43134,NULL,'Beaver Creek, MN',17834,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43135,NULL,'Beaver Creek, MN 56116',17834,222,NULL,41,25008,0);
INSERT INTO "django_geo_db_location" VALUES(43136,NULL,'Bigelow, MN',17835,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43137,NULL,'Bigelow, MN 56117',17835,222,NULL,41,25009,0);
INSERT INTO "django_geo_db_location" VALUES(43138,NULL,'Bingham Lake, MN',17836,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43139,NULL,'Bingham Lake, MN 56118',17836,222,NULL,41,25010,0);
INSERT INTO "django_geo_db_location" VALUES(43140,NULL,'Brewster, MN',17837,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43141,NULL,'Brewster, MN 56119',17837,222,NULL,41,25011,0);
INSERT INTO "django_geo_db_location" VALUES(43142,NULL,'Butterfield, MN',17838,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43143,NULL,'Butterfield, MN 56120',17838,222,NULL,41,25012,0);
INSERT INTO "django_geo_db_location" VALUES(43144,NULL,'Ceylon, MN',17839,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43145,NULL,'Ceylon, MN 56121',17839,222,NULL,41,25013,0);
INSERT INTO "django_geo_db_location" VALUES(43146,NULL,'Chandler, MN',17840,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43147,NULL,'Chandler, MN 56122',17840,222,NULL,41,25014,0);
INSERT INTO "django_geo_db_location" VALUES(43148,NULL,'Currie, MN',17841,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43149,NULL,'Currie, MN 56123',17841,222,NULL,41,25015,0);
INSERT INTO "django_geo_db_location" VALUES(43150,NULL,'Dovray, MN',17842,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43151,NULL,'Dovray, MN 56125',17842,222,NULL,41,25016,0);
INSERT INTO "django_geo_db_location" VALUES(43152,NULL,'Graham Lakes, MN',17843,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43153,NULL,'Graham Lakes, MN 56126',17843,222,NULL,41,25017,0);
INSERT INTO "django_geo_db_location" VALUES(43154,NULL,'Dunnell, MN',17844,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43155,NULL,'Dunnell, MN 56127',17844,222,NULL,41,25018,0);
INSERT INTO "django_geo_db_location" VALUES(43156,NULL,'Edgerton, MN',17845,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43157,NULL,'Edgerton, MN 56128',17845,222,NULL,41,25019,0);
INSERT INTO "django_geo_db_location" VALUES(43158,NULL,'Ellsworth, IA 56129',15769,222,NULL,19,25020,0);
INSERT INTO "django_geo_db_location" VALUES(43159,NULL,'Florence, MN',17846,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43160,NULL,'Florence, MN 56130',17846,222,NULL,41,25021,0);
INSERT INTO "django_geo_db_location" VALUES(43161,NULL,'Fulda, MN',17847,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43162,NULL,'Fulda, MN 56131',17847,222,NULL,41,25022,0);
INSERT INTO "django_geo_db_location" VALUES(43163,NULL,'Garvin, MN',17848,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43164,NULL,'Garvin, MN 56132',17848,222,NULL,41,25023,0);
INSERT INTO "django_geo_db_location" VALUES(43165,NULL,'Hardwick, MN',17849,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43166,NULL,'Hardwick, MN 56134',17849,222,NULL,41,25024,0);
INSERT INTO "django_geo_db_location" VALUES(43167,NULL,'Powers, MN',17850,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43168,NULL,'Powers, MN 56135',17850,222,NULL,41,25025,0);
INSERT INTO "django_geo_db_location" VALUES(43169,NULL,'Hendricks, MN',17851,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43170,NULL,'Hendricks, MN 56136',17851,222,NULL,41,25026,0);
INSERT INTO "django_geo_db_location" VALUES(43171,NULL,'Heron Lake, MN',17852,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43172,NULL,'Heron Lake, MN 56137',17852,222,NULL,41,25027,0);
INSERT INTO "django_geo_db_location" VALUES(43173,NULL,'Hills, MN',17853,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43174,NULL,'Hills, MN 56138',17853,222,NULL,41,25028,0);
INSERT INTO "django_geo_db_location" VALUES(43175,NULL,'Holland, MN',17854,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43176,NULL,'Holland, MN 56139',17854,222,NULL,41,25029,0);
INSERT INTO "django_geo_db_location" VALUES(43177,NULL,'Ihlen, MN',17855,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43178,NULL,'Ihlen, MN 56140',17855,222,NULL,41,25030,0);
INSERT INTO "django_geo_db_location" VALUES(43179,NULL,'Iona, MN',17856,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43180,NULL,'Iona, MN 56141',17856,222,NULL,41,25031,0);
INSERT INTO "django_geo_db_location" VALUES(43181,NULL,'Ivanhoe, MN',17857,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43182,NULL,'Ivanhoe, MN 56142',17857,222,NULL,41,25032,0);
INSERT INTO "django_geo_db_location" VALUES(43183,NULL,'Jackson, MN',17858,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43184,NULL,'Jackson, MN 56143',17858,222,NULL,41,25033,0);
INSERT INTO "django_geo_db_location" VALUES(43185,NULL,'Jasper, MN',17859,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43186,NULL,'Jasper, MN 56144',17859,222,NULL,41,25034,0);
INSERT INTO "django_geo_db_location" VALUES(43187,NULL,'Jeffers, MN',17860,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43188,NULL,'Jeffers, MN 56145',17860,222,NULL,41,25035,0);
INSERT INTO "django_geo_db_location" VALUES(43189,NULL,'Kanaranzi, MN',17861,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43190,NULL,'Kanaranzi, MN 56146',17861,222,NULL,41,25036,0);
INSERT INTO "django_geo_db_location" VALUES(43191,NULL,'Kenneth, MN',17862,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43192,NULL,'Kenneth, MN 56147',17862,222,NULL,41,25037,0);
INSERT INTO "django_geo_db_location" VALUES(43193,NULL,'Lake Benton, MN',17863,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43194,NULL,'Lake Benton, MN 56149',17863,222,NULL,41,25038,0);
INSERT INTO "django_geo_db_location" VALUES(43195,NULL,'Lakefield, MN',17864,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43196,NULL,'Lakefield, MN 56150',17864,222,NULL,41,25039,0);
INSERT INTO "django_geo_db_location" VALUES(43197,NULL,'Lake Wilson, MN',17865,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43198,NULL,'Lake Wilson, MN 56151',17865,222,NULL,41,25040,0);
INSERT INTO "django_geo_db_location" VALUES(43199,NULL,'Lamberton, MN',17866,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43200,NULL,'Lamberton, MN 56152',17866,222,NULL,41,25041,0);
INSERT INTO "django_geo_db_location" VALUES(43201,NULL,'Leota, MN',17867,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43202,NULL,'Leota, MN 56153',17867,222,NULL,41,25042,0);
INSERT INTO "django_geo_db_location" VALUES(43203,NULL,'Lismore, MN',17868,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43204,NULL,'Lismore, MN 56155',17868,222,NULL,41,25043,0);
INSERT INTO "django_geo_db_location" VALUES(43205,NULL,'Luverne, MN',17869,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43206,NULL,'Luverne, MN 56156',17869,222,NULL,41,25044,0);
INSERT INTO "django_geo_db_location" VALUES(43207,NULL,'Lynd, MN',17870,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43208,NULL,'Lynd, MN 56157',17870,222,NULL,41,25045,0);
INSERT INTO "django_geo_db_location" VALUES(43209,NULL,'Magnolia, MN',17871,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43210,NULL,'Magnolia, MN 56158',17871,222,NULL,41,25046,0);
INSERT INTO "django_geo_db_location" VALUES(43211,NULL,'Mountain Lake, MN',17872,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43212,NULL,'Mountain Lake, MN 56159',17872,222,NULL,41,25047,0);
INSERT INTO "django_geo_db_location" VALUES(43213,NULL,'Odin, MN',17873,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43214,NULL,'Odin, MN 56160',17873,222,NULL,41,25048,0);
INSERT INTO "django_geo_db_location" VALUES(43215,NULL,'Okabena, MN',17874,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43216,NULL,'Okabena, MN 56161',17874,222,NULL,41,25049,0);
INSERT INTO "django_geo_db_location" VALUES(43217,NULL,'Ormsby, MN',17875,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43218,NULL,'Ormsby, MN 56162',17875,222,NULL,41,25050,0);
INSERT INTO "django_geo_db_location" VALUES(43219,NULL,'Pipestone, MN',17876,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43220,NULL,'Pipestone, MN 56164',17876,222,NULL,41,25051,0);
INSERT INTO "django_geo_db_location" VALUES(43221,NULL,'Reading, MN',17877,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43222,NULL,'Reading, MN 56165',17877,222,NULL,41,25052,0);
INSERT INTO "django_geo_db_location" VALUES(43223,NULL,'Revere, MN',17878,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43224,NULL,'Revere, MN 56166',17878,222,NULL,41,25053,0);
INSERT INTO "django_geo_db_location" VALUES(43225,NULL,'Round Lake, MN',17879,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43226,NULL,'Round Lake, MN 56167',17879,222,NULL,41,25054,0);
INSERT INTO "django_geo_db_location" VALUES(43227,NULL,'Rushmore, MN',17880,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43228,NULL,'Rushmore, MN 56168',17880,222,NULL,41,25055,0);
INSERT INTO "django_geo_db_location" VALUES(43229,NULL,'Russell, MN',17881,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43230,NULL,'Russell, MN 56169',17881,222,NULL,41,25056,0);
INSERT INTO "django_geo_db_location" VALUES(43231,NULL,'Ruthton, MN',17882,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43232,NULL,'Ruthton, MN 56170',17882,222,NULL,41,25057,0);
INSERT INTO "django_geo_db_location" VALUES(43233,NULL,'Sherburn, MN',17883,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43234,NULL,'Sherburn, MN 56171',17883,222,NULL,41,25058,0);
INSERT INTO "django_geo_db_location" VALUES(43235,NULL,'Slayton, MN',17884,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43236,NULL,'Slayton, MN 56172',17884,222,NULL,41,25059,0);
INSERT INTO "django_geo_db_location" VALUES(43237,NULL,'Steen, MN',17885,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43238,NULL,'Steen, MN 56173',17885,222,NULL,41,25060,0);
INSERT INTO "django_geo_db_location" VALUES(43239,NULL,'Storden, MN',17886,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43240,NULL,'Storden, MN 56174',17886,222,NULL,41,25061,0);
INSERT INTO "django_geo_db_location" VALUES(43241,NULL,'Tracy, MN',17887,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43242,NULL,'Tracy, MN 56175',17887,222,NULL,41,25062,0);
INSERT INTO "django_geo_db_location" VALUES(43243,NULL,'Trimont, MN',17888,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43244,NULL,'Trimont, MN 56176',17888,222,NULL,41,25063,0);
INSERT INTO "django_geo_db_location" VALUES(43245,NULL,'Trosky, MN',17889,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43246,NULL,'Trosky, MN 56177',17889,222,NULL,41,25064,0);
INSERT INTO "django_geo_db_location" VALUES(43247,NULL,'Tyler, MN',17890,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43248,NULL,'Tyler, MN 56178',17890,222,NULL,41,25065,0);
INSERT INTO "django_geo_db_location" VALUES(43249,NULL,'Walnut Grove, MN',17891,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43250,NULL,'Walnut Grove, MN 56180',17891,222,NULL,41,25066,0);
INSERT INTO "django_geo_db_location" VALUES(43251,NULL,'Welcome, MN',17892,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43252,NULL,'Welcome, MN 56181',17892,222,NULL,41,25067,0);
INSERT INTO "django_geo_db_location" VALUES(43253,NULL,'Westbrook, MN',17893,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43254,NULL,'Westbrook, MN 56183',17893,222,NULL,41,25068,0);
INSERT INTO "django_geo_db_location" VALUES(43255,NULL,'Wilmont, MN',17894,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43256,NULL,'Wilmont, MN 56185',17894,222,NULL,41,25069,0);
INSERT INTO "django_geo_db_location" VALUES(43257,NULL,'Woodstock, MN',17895,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43258,NULL,'Woodstock, MN 56186',17895,222,NULL,41,25070,0);
INSERT INTO "django_geo_db_location" VALUES(43259,NULL,'Worthington, MN',17896,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43260,NULL,'Worthington, MN 56187',17896,222,NULL,41,25071,0);
INSERT INTO "django_geo_db_location" VALUES(43261,NULL,'Willmar, MN',17897,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43262,NULL,'Willmar, MN 56201',17897,222,NULL,41,25072,0);
INSERT INTO "django_geo_db_location" VALUES(43263,NULL,'Alberta, MN',17898,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43264,NULL,'Alberta, MN 56207',17898,222,NULL,41,25073,0);
INSERT INTO "django_geo_db_location" VALUES(43265,NULL,'Appleton, MN',17899,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43266,NULL,'Appleton, MN 56208',17899,222,NULL,41,25074,0);
INSERT INTO "django_geo_db_location" VALUES(43267,NULL,'Atwater, MN',17900,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43268,NULL,'Atwater, MN 56209',17900,222,NULL,41,25075,0);
INSERT INTO "django_geo_db_location" VALUES(43269,NULL,'Barry, MN',17901,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43270,NULL,'Barry, MN 56210',17901,222,NULL,41,25076,0);
INSERT INTO "django_geo_db_location" VALUES(43271,NULL,'Beardsley, MN',17902,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43272,NULL,'Beardsley, MN 56211',17902,222,NULL,41,25077,0);
INSERT INTO "django_geo_db_location" VALUES(43273,NULL,'Bellingham, MN',17903,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43274,NULL,'Bellingham, MN 56212',17903,222,NULL,41,25078,0);
INSERT INTO "django_geo_db_location" VALUES(43275,NULL,'Belview, MN',17904,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43276,NULL,'Belview, MN 56214',17904,222,NULL,41,25079,0);
INSERT INTO "django_geo_db_location" VALUES(43277,NULL,'Benson, MN',17905,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43278,NULL,'Benson, MN 56215',17905,222,NULL,41,25080,0);
INSERT INTO "django_geo_db_location" VALUES(43279,NULL,'Blomkest, MN',17906,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43280,NULL,'Blomkest, MN 56216',17906,222,NULL,41,25081,0);
INSERT INTO "django_geo_db_location" VALUES(43281,NULL,'Boyd, MN',17907,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43282,NULL,'Boyd, MN 56218',17907,222,NULL,41,25082,0);
INSERT INTO "django_geo_db_location" VALUES(43283,NULL,'Browns Valley, MN',17908,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43284,NULL,'Browns Valley, MN 56219',17908,222,NULL,41,25083,0);
INSERT INTO "django_geo_db_location" VALUES(43285,NULL,'Canby, MN',17909,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43286,NULL,'Canby, MN 56220',17909,222,NULL,41,25084,0);
INSERT INTO "django_geo_db_location" VALUES(43287,NULL,'Chokio, MN',17910,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43288,NULL,'Chokio, MN 56221',17910,222,NULL,41,25085,0);
INSERT INTO "django_geo_db_location" VALUES(43289,NULL,'Clara City, MN',17911,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43290,NULL,'Clara City, MN 56222',17911,222,NULL,41,25086,0);
INSERT INTO "django_geo_db_location" VALUES(43291,NULL,'Clarkfield, MN',17912,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43292,NULL,'Clarkfield, MN 56223',17912,222,NULL,41,25087,0);
INSERT INTO "django_geo_db_location" VALUES(43293,NULL,'Clements, MN',17913,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43294,NULL,'Clements, MN 56224',17913,222,NULL,41,25088,0);
INSERT INTO "django_geo_db_location" VALUES(43295,NULL,'Clinton, MN',17914,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43296,NULL,'Clinton, MN 56225',17914,222,NULL,41,25089,0);
INSERT INTO "django_geo_db_location" VALUES(43297,NULL,'Clontarf, MN',17915,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43298,NULL,'Clontarf, MN 56226',17915,222,NULL,41,25090,0);
INSERT INTO "django_geo_db_location" VALUES(43299,NULL,'Correll, MN',17916,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43300,NULL,'Correll, MN 56227',17916,222,NULL,41,25091,0);
INSERT INTO "django_geo_db_location" VALUES(43301,NULL,'Cosmos, MN',17917,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43302,NULL,'Cosmos, MN 56228',17917,222,NULL,41,25092,0);
INSERT INTO "django_geo_db_location" VALUES(43303,NULL,'Cottonwood, MN',17918,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43304,NULL,'Cottonwood, MN 56229',17918,222,NULL,41,25093,0);
INSERT INTO "django_geo_db_location" VALUES(43305,NULL,'Danube, MN',17919,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43306,NULL,'Danube, MN 56230',17919,222,NULL,41,25094,0);
INSERT INTO "django_geo_db_location" VALUES(43307,NULL,'Danvers, MN',17920,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43308,NULL,'Danvers, MN 56231',17920,222,NULL,41,25095,0);
INSERT INTO "django_geo_db_location" VALUES(43309,NULL,'Dawson, MN',17921,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43310,NULL,'Dawson, MN 56232',17921,222,NULL,41,25096,0);
INSERT INTO "django_geo_db_location" VALUES(43311,NULL,'Donnelly, MN',17922,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43312,NULL,'Donnelly, MN 56235',17922,222,NULL,41,25097,0);
INSERT INTO "django_geo_db_location" VALUES(43313,NULL,'Dumont, MN',17923,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43314,NULL,'Dumont, MN 56236',17923,222,NULL,41,25098,0);
INSERT INTO "django_geo_db_location" VALUES(43315,NULL,'Echo, MN',17924,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43316,NULL,'Echo, MN 56237',17924,222,NULL,41,25099,0);
INSERT INTO "django_geo_db_location" VALUES(43317,NULL,'Ghent, MN',17925,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43318,NULL,'Ghent, MN 56239',17925,222,NULL,41,25100,0);
INSERT INTO "django_geo_db_location" VALUES(43319,NULL,'Graceville, MN',17926,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43320,NULL,'Graceville, MN 56240',17926,222,NULL,41,25101,0);
INSERT INTO "django_geo_db_location" VALUES(43321,NULL,'Granite Falls, MN',17927,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43322,NULL,'Granite Falls, MN 56241',17927,222,NULL,41,25102,0);
INSERT INTO "django_geo_db_location" VALUES(43323,NULL,'Grove City, MN',17928,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43324,NULL,'Grove City, MN 56243',17928,222,NULL,41,25103,0);
INSERT INTO "django_geo_db_location" VALUES(43325,NULL,'Hancock, MN',17929,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43326,NULL,'Hancock, MN 56244',17929,222,NULL,41,25104,0);
INSERT INTO "django_geo_db_location" VALUES(43327,NULL,'Hanley Falls, MN',17930,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43328,NULL,'Hanley Falls, MN 56245',17930,222,NULL,41,25105,0);
INSERT INTO "django_geo_db_location" VALUES(43329,NULL,'Hawick, MN',17931,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43330,NULL,'Hawick, MN 56246',17931,222,NULL,41,25106,0);
INSERT INTO "django_geo_db_location" VALUES(43331,NULL,'Herman, MN',17932,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43332,NULL,'Herman, MN 56248',17932,222,NULL,41,25107,0);
INSERT INTO "django_geo_db_location" VALUES(43333,NULL,'Holloway, MN',17933,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43334,NULL,'Holloway, MN 56249',17933,222,NULL,41,25108,0);
INSERT INTO "django_geo_db_location" VALUES(43335,NULL,'Kandiyohi, MN',17934,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43336,NULL,'Kandiyohi, MN 56251',17934,222,NULL,41,25109,0);
INSERT INTO "django_geo_db_location" VALUES(43337,NULL,'Kerkhoven, MN',17935,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43338,NULL,'Kerkhoven, MN 56252',17935,222,NULL,41,25110,0);
INSERT INTO "django_geo_db_location" VALUES(43339,NULL,'Lake Lillian, MN',17936,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43340,NULL,'Lake Lillian, MN 56253',17936,222,NULL,41,25111,0);
INSERT INTO "django_geo_db_location" VALUES(43341,NULL,'Lucan, MN',17937,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43342,NULL,'Lucan, MN 56255',17937,222,NULL,41,25112,0);
INSERT INTO "django_geo_db_location" VALUES(43343,NULL,'Madison, MN',17938,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43344,NULL,'Madison, MN 56256',17938,222,NULL,41,25113,0);
INSERT INTO "django_geo_db_location" VALUES(43345,NULL,'Marietta, MN',17939,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43346,NULL,'Marietta, MN 56257',17939,222,NULL,41,25114,0);
INSERT INTO "django_geo_db_location" VALUES(43347,NULL,'Marshall, MN',17940,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43348,NULL,'Marshall, MN 56258',17940,222,NULL,41,25115,0);
INSERT INTO "django_geo_db_location" VALUES(43349,NULL,'Maynard, MN',17941,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43350,NULL,'Maynard, MN 56260',17941,222,NULL,41,25116,0);
INSERT INTO "django_geo_db_location" VALUES(43351,NULL,'Milan, MN',17942,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43352,NULL,'Milan, MN 56262',17942,222,NULL,41,25117,0);
INSERT INTO "django_geo_db_location" VALUES(43353,NULL,'Milroy, MN',17943,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43354,NULL,'Milroy, MN 56263',17943,222,NULL,41,25118,0);
INSERT INTO "django_geo_db_location" VALUES(43355,NULL,'Minneota, MN',17944,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43356,NULL,'Minneota, MN 56264',17944,222,NULL,41,25119,0);
INSERT INTO "django_geo_db_location" VALUES(43357,NULL,'Montevideo, MN',17945,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43358,NULL,'Montevideo, MN 56265',17945,222,NULL,41,25120,0);
INSERT INTO "django_geo_db_location" VALUES(43359,NULL,'Morgan, MN',17946,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43360,NULL,'Morgan, MN 56266',17946,222,NULL,41,25121,0);
INSERT INTO "django_geo_db_location" VALUES(43361,NULL,'Morris, MN',17947,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43362,NULL,'Morris, MN 56267',17947,222,NULL,41,25122,0);
INSERT INTO "django_geo_db_location" VALUES(43363,NULL,'Morton, MN',17948,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43364,NULL,'Morton, MN 56270',17948,222,NULL,41,25123,0);
INSERT INTO "django_geo_db_location" VALUES(43365,NULL,'Murdock, MN',17949,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43366,NULL,'Murdock, MN 56271',17949,222,NULL,41,25124,0);
INSERT INTO "django_geo_db_location" VALUES(43367,NULL,'New London, MN',17950,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43368,NULL,'New London, MN 56273',17950,222,NULL,41,25125,0);
INSERT INTO "django_geo_db_location" VALUES(43369,NULL,'Norcross, MN',17951,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43370,NULL,'Norcross, MN 56274',17951,222,NULL,41,25126,0);
INSERT INTO "django_geo_db_location" VALUES(43371,NULL,'Odessa, MN',17952,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43372,NULL,'Odessa, MN 56276',17952,222,NULL,41,25127,0);
INSERT INTO "django_geo_db_location" VALUES(43373,NULL,'Olivia, MN',17953,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43374,NULL,'Olivia, MN 56277',17953,222,NULL,41,25128,0);
INSERT INTO "django_geo_db_location" VALUES(43375,NULL,'Ortonville, MN',17954,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43376,NULL,'Ortonville, MN 56278',17954,222,NULL,41,25129,0);
INSERT INTO "django_geo_db_location" VALUES(43377,NULL,'Pennock, MN',17955,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43378,NULL,'Pennock, MN 56279',17955,222,NULL,41,25130,0);
INSERT INTO "django_geo_db_location" VALUES(43379,NULL,'Porter, MN',17956,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43380,NULL,'Porter, MN 56280',17956,222,NULL,41,25131,0);
INSERT INTO "django_geo_db_location" VALUES(43381,NULL,'Prinsburg, MN',17957,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43382,NULL,'Prinsburg, MN 56281',17957,222,NULL,41,25132,0);
INSERT INTO "django_geo_db_location" VALUES(43383,NULL,'Raymond, MN',17958,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43384,NULL,'Raymond, MN 56282',17958,222,NULL,41,25133,0);
INSERT INTO "django_geo_db_location" VALUES(43385,NULL,'Redwood Falls, MN',17959,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43386,NULL,'Redwood Falls, MN 56283',17959,222,NULL,41,25134,0);
INSERT INTO "django_geo_db_location" VALUES(43387,NULL,'Renville, MN',17960,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43388,NULL,'Renville, MN 56284',17960,222,NULL,41,25135,0);
INSERT INTO "django_geo_db_location" VALUES(43389,NULL,'Sacred Heart, MN',17961,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43390,NULL,'Sacred Heart, MN 56285',17961,222,NULL,41,25136,0);
INSERT INTO "django_geo_db_location" VALUES(43391,NULL,'St. Leo, MN',17962,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43392,NULL,'St. Leo, MN 56286',17962,222,NULL,41,25137,0);
INSERT INTO "django_geo_db_location" VALUES(43393,NULL,'Seaforth, MN',17963,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43394,NULL,'Seaforth, MN 56287',17963,222,NULL,41,25138,0);
INSERT INTO "django_geo_db_location" VALUES(43395,NULL,'Spicer, MN',17964,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43396,NULL,'Spicer, MN 56288',17964,222,NULL,41,25139,0);
INSERT INTO "django_geo_db_location" VALUES(43397,NULL,'Sunburg, MN',17965,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43398,NULL,'Sunburg, MN 56289',17965,222,NULL,41,25140,0);
INSERT INTO "django_geo_db_location" VALUES(43399,NULL,'Taunton, MN',17966,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43400,NULL,'Taunton, MN 56291',17966,222,NULL,41,25141,0);
INSERT INTO "django_geo_db_location" VALUES(43401,NULL,'Vesta, MN',17967,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43402,NULL,'Vesta, MN 56292',17967,222,NULL,41,25142,0);
INSERT INTO "django_geo_db_location" VALUES(43403,NULL,'Wabasso, MN',17968,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43404,NULL,'Wabasso, MN 56293',17968,222,NULL,41,25143,0);
INSERT INTO "django_geo_db_location" VALUES(43405,NULL,'Wanda, MN',17969,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43406,NULL,'Wanda, MN 56294',17969,222,NULL,41,25144,0);
INSERT INTO "django_geo_db_location" VALUES(43407,NULL,'Watson, MN',17970,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43408,NULL,'Watson, MN 56295',17970,222,NULL,41,25145,0);
INSERT INTO "django_geo_db_location" VALUES(43409,NULL,'Wheaton, MN',17971,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43410,NULL,'Wheaton, MN 56296',17971,222,NULL,41,25146,0);
INSERT INTO "django_geo_db_location" VALUES(43411,NULL,'Wood Lake, MN',17972,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43412,NULL,'Wood Lake, MN 56297',17972,222,NULL,41,25147,0);
INSERT INTO "django_geo_db_location" VALUES(43413,NULL,'Saint Cloud, MN',17973,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43414,NULL,'Saint Cloud, MN 56301',17973,222,NULL,41,25148,0);
INSERT INTO "django_geo_db_location" VALUES(43415,NULL,'Saint Cloud, MN 56302',17973,222,NULL,41,25149,0);
INSERT INTO "django_geo_db_location" VALUES(43416,NULL,'Saint Cloud, MN 56303',17973,222,NULL,41,25150,0);
INSERT INTO "django_geo_db_location" VALUES(43417,NULL,'Saint Cloud, MN 56304',17973,222,NULL,41,25151,0);
INSERT INTO "django_geo_db_location" VALUES(43418,NULL,'Albany, MN',17974,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43419,NULL,'Albany, MN 56307',17974,222,NULL,41,25152,0);
INSERT INTO "django_geo_db_location" VALUES(43420,NULL,'Alexandria, MN',17975,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43421,NULL,'Alexandria, MN 56308',17975,222,NULL,41,25153,0);
INSERT INTO "django_geo_db_location" VALUES(43422,NULL,'Ashby, MN',17976,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43423,NULL,'Ashby, MN 56309',17976,222,NULL,41,25154,0);
INSERT INTO "django_geo_db_location" VALUES(43424,NULL,'Avon, MN',17977,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43425,NULL,'Avon, MN 56310',17977,222,NULL,41,25155,0);
INSERT INTO "django_geo_db_location" VALUES(43426,NULL,'Barrett, MN',17978,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43427,NULL,'Barrett, MN 56311',17978,222,NULL,41,25156,0);
INSERT INTO "django_geo_db_location" VALUES(43428,NULL,'Belgrade, MN',17979,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43429,NULL,'Belgrade, MN 56312',17979,222,NULL,41,25157,0);
INSERT INTO "django_geo_db_location" VALUES(43430,NULL,'Bock, MN',17980,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43431,NULL,'Bock, MN 56313',17980,222,NULL,41,25158,0);
INSERT INTO "django_geo_db_location" VALUES(43432,NULL,'Bowlus, MN',17981,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43433,NULL,'Bowlus, MN 56314',17981,222,NULL,41,25159,0);
INSERT INTO "django_geo_db_location" VALUES(43434,NULL,'Brandon, MN',17982,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43435,NULL,'Brandon, MN 56315',17982,222,NULL,41,25160,0);
INSERT INTO "django_geo_db_location" VALUES(43436,NULL,'Brooten, MN',17983,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43437,NULL,'Brooten, MN 56316',17983,222,NULL,41,25161,0);
INSERT INTO "django_geo_db_location" VALUES(43438,NULL,'Buckman, MN',17984,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43439,NULL,'Buckman, MN 56317',17984,222,NULL,41,25162,0);
INSERT INTO "django_geo_db_location" VALUES(43440,NULL,'Burtrum, MN',17985,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43441,NULL,'Burtrum, MN 56318',17985,222,NULL,41,25163,0);
INSERT INTO "django_geo_db_location" VALUES(43442,NULL,'Carlos, MN',17986,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43443,NULL,'Carlos, MN 56319',17986,222,NULL,41,25164,0);
INSERT INTO "django_geo_db_location" VALUES(43444,NULL,'Cold Spring, MN',17987,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43445,NULL,'Cold Spring, MN 56320',17987,222,NULL,41,25165,0);
INSERT INTO "django_geo_db_location" VALUES(43446,NULL,'Collegeville, MN',17988,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43447,NULL,'Collegeville, MN 56321',17988,222,NULL,41,25166,0);
INSERT INTO "django_geo_db_location" VALUES(43448,NULL,'Cyrus, MN',17989,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43449,NULL,'Cyrus, MN 56323',17989,222,NULL,41,25167,0);
INSERT INTO "django_geo_db_location" VALUES(43450,NULL,'Dalton, MN',17990,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43451,NULL,'Dalton, MN 56324',17990,222,NULL,41,25168,0);
INSERT INTO "django_geo_db_location" VALUES(43452,NULL,'Elrosa, MN',17991,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43453,NULL,'Elrosa, MN 56325',17991,222,NULL,41,25169,0);
INSERT INTO "django_geo_db_location" VALUES(43454,NULL,'Evansville, MN',17992,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43455,NULL,'Evansville, MN 56326',17992,222,NULL,41,25170,0);
INSERT INTO "django_geo_db_location" VALUES(43456,NULL,'Farwell, MN',17993,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43457,NULL,'Farwell, MN 56327',17993,222,NULL,41,25171,0);
INSERT INTO "django_geo_db_location" VALUES(43458,NULL,'Flensburg, MN',17994,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43459,NULL,'Flensburg, MN 56328',17994,222,NULL,41,25172,0);
INSERT INTO "django_geo_db_location" VALUES(43460,NULL,'Foley, MN',17995,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43461,NULL,'Foley, MN 56329',17995,222,NULL,41,25173,0);
INSERT INTO "django_geo_db_location" VALUES(43462,NULL,'Foreston, MN',17996,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43463,NULL,'Foreston, MN 56330',17996,222,NULL,41,25174,0);
INSERT INTO "django_geo_db_location" VALUES(43464,NULL,'Freeport, MN',17997,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43465,NULL,'Freeport, MN 56331',17997,222,NULL,41,25175,0);
INSERT INTO "django_geo_db_location" VALUES(43466,NULL,'Garfield, MN',17998,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43467,NULL,'Garfield, MN 56332',17998,222,NULL,41,25176,0);
INSERT INTO "django_geo_db_location" VALUES(43468,NULL,'Gilman, MN',17999,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43469,NULL,'Gilman, MN 56333',17999,222,NULL,41,25177,0);
INSERT INTO "django_geo_db_location" VALUES(43470,NULL,'Glenwood, MN',18000,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43471,NULL,'Glenwood, MN 56334',18000,222,NULL,41,25178,0);
INSERT INTO "django_geo_db_location" VALUES(43472,NULL,'Greenwald, MN',18001,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43473,NULL,'Greenwald, MN 56335',18001,222,NULL,41,25179,0);
INSERT INTO "django_geo_db_location" VALUES(43474,NULL,'Grey Eagle, MN',18002,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43475,NULL,'Grey Eagle, MN 56336',18002,222,NULL,41,25180,0);
INSERT INTO "django_geo_db_location" VALUES(43476,NULL,'Hillman, MN',18003,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43477,NULL,'Hillman, MN 56338',18003,222,NULL,41,25181,0);
INSERT INTO "django_geo_db_location" VALUES(43478,NULL,'Hoffman, MN',18004,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43479,NULL,'Hoffman, MN 56339',18004,222,NULL,41,25182,0);
INSERT INTO "django_geo_db_location" VALUES(43480,NULL,'Holdingford, MN',18005,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43481,NULL,'Holdingford, MN 56340',18005,222,NULL,41,25183,0);
INSERT INTO "django_geo_db_location" VALUES(43482,NULL,'Holmes City, MN',18006,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43483,NULL,'Holmes City, MN 56341',18006,222,NULL,41,25184,0);
INSERT INTO "django_geo_db_location" VALUES(43484,NULL,'Isle, MN',18007,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43485,NULL,'Isle, MN 56342',18007,222,NULL,41,25185,0);
INSERT INTO "django_geo_db_location" VALUES(43486,NULL,'Kensington, MN',18008,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43487,NULL,'Kensington, MN 56343',18008,222,NULL,41,25186,0);
INSERT INTO "django_geo_db_location" VALUES(43488,NULL,'Lastrup, MN',18009,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43489,NULL,'Lastrup, MN 56344',18009,222,NULL,41,25187,0);
INSERT INTO "django_geo_db_location" VALUES(43490,NULL,'Little Falls, MN',18010,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43491,NULL,'Little Falls, MN 56345',18010,222,NULL,41,25188,0);
INSERT INTO "django_geo_db_location" VALUES(43492,NULL,'Long Prairie, MN',18011,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43493,NULL,'Long Prairie, MN 56347',18011,222,NULL,41,25189,0);
INSERT INTO "django_geo_db_location" VALUES(43494,NULL,'Lowry, MN',18012,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43495,NULL,'Lowry, MN 56349',18012,222,NULL,41,25190,0);
INSERT INTO "django_geo_db_location" VALUES(43496,NULL,'McGrath, MN',18013,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43497,NULL,'McGrath, MN 56350',18013,222,NULL,41,25191,0);
INSERT INTO "django_geo_db_location" VALUES(43498,NULL,'Melrose, MN',18014,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43499,NULL,'Melrose, MN 56352',18014,222,NULL,41,25192,0);
INSERT INTO "django_geo_db_location" VALUES(43500,NULL,'Milaca, MN',18015,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43501,NULL,'Milaca, MN 56353',18015,222,NULL,41,25193,0);
INSERT INTO "django_geo_db_location" VALUES(43502,NULL,'Miltona, MN',18016,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43503,NULL,'Miltona, MN 56354',18016,222,NULL,41,25194,0);
INSERT INTO "django_geo_db_location" VALUES(43504,NULL,'Nelson, MN',18017,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43505,NULL,'Nelson, MN 56355',18017,222,NULL,41,25195,0);
INSERT INTO "django_geo_db_location" VALUES(43506,NULL,'New Munich, MN',18018,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43507,NULL,'New Munich, MN 56356',18018,222,NULL,41,25196,0);
INSERT INTO "django_geo_db_location" VALUES(43508,NULL,'Oak Park, MN',18019,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43509,NULL,'Oak Park, MN 56357',18019,222,NULL,41,25197,0);
INSERT INTO "django_geo_db_location" VALUES(43510,NULL,'Ogilvie, MN',18020,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43511,NULL,'Ogilvie, MN 56358',18020,222,NULL,41,25198,0);
INSERT INTO "django_geo_db_location" VALUES(43512,NULL,'Onamia, MN',18021,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43513,NULL,'Onamia, MN 56359',18021,222,NULL,41,25199,0);
INSERT INTO "django_geo_db_location" VALUES(43514,NULL,'Osakis, MN',18022,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43515,NULL,'Osakis, MN 56360',18022,222,NULL,41,25200,0);
INSERT INTO "django_geo_db_location" VALUES(43516,NULL,'Parkers Prairie, MN',18023,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43517,NULL,'Parkers Prairie, MN 56361',18023,222,NULL,41,25201,0);
INSERT INTO "django_geo_db_location" VALUES(43518,NULL,'Paynesville, MN',18024,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43519,NULL,'Paynesville, MN 56362',18024,222,NULL,41,25202,0);
INSERT INTO "django_geo_db_location" VALUES(43520,NULL,'Pease, MN',18025,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43521,NULL,'Pease, MN 56363',18025,222,NULL,41,25203,0);
INSERT INTO "django_geo_db_location" VALUES(43522,NULL,'Pierz, MN',18026,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43523,NULL,'Pierz, MN 56364',18026,222,NULL,41,25204,0);
INSERT INTO "django_geo_db_location" VALUES(43524,NULL,'Bowstring, MN',18027,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43525,NULL,'Bowstring, MN 56366',18027,222,NULL,41,25205,0);
INSERT INTO "django_geo_db_location" VALUES(43526,NULL,'Rice, MN',18028,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43527,NULL,'Rice, MN 56367',18028,222,NULL,41,25206,0);
INSERT INTO "django_geo_db_location" VALUES(43528,NULL,'Richmond, MN',18029,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43529,NULL,'Richmond, MN 56368',18029,222,NULL,41,25207,0);
INSERT INTO "django_geo_db_location" VALUES(43530,NULL,'Rockville, MN',18030,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43531,NULL,'Rockville, MN 56369',18030,222,NULL,41,25208,0);
INSERT INTO "django_geo_db_location" VALUES(43532,NULL,'Roscoe, MN',18031,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43533,NULL,'Roscoe, MN 56371',18031,222,NULL,41,25209,0);
INSERT INTO "django_geo_db_location" VALUES(43534,NULL,'Saint Cloud, MN 56372',17973,222,NULL,41,25210,0);
INSERT INTO "django_geo_db_location" VALUES(43535,NULL,'Royalton, MN',18032,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43536,NULL,'Royalton, MN 56373',18032,222,NULL,41,25211,0);
INSERT INTO "django_geo_db_location" VALUES(43537,NULL,'Saint Joseph, MN',18033,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43538,NULL,'Saint Joseph, MN 56374',18033,222,NULL,41,25212,0);
INSERT INTO "django_geo_db_location" VALUES(43539,NULL,'Saint Stephen, MN',18034,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43540,NULL,'Saint Stephen, MN 56375',18034,222,NULL,41,25213,0);
INSERT INTO "django_geo_db_location" VALUES(43541,NULL,'Saint Martin, MN',18035,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43542,NULL,'Saint Martin, MN 56376',18035,222,NULL,41,25214,0);
INSERT INTO "django_geo_db_location" VALUES(43543,NULL,'Sartell, MN',18036,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43544,NULL,'Sartell, MN 56377',18036,222,NULL,41,25215,0);
INSERT INTO "django_geo_db_location" VALUES(43545,NULL,'Sauk Centre, MN',18037,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43546,NULL,'Sauk Centre, MN 56378',18037,222,NULL,41,25216,0);
INSERT INTO "django_geo_db_location" VALUES(43547,NULL,'Sauk Rapids, MN',18038,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43548,NULL,'Sauk Rapids, MN 56379',18038,222,NULL,41,25217,0);
INSERT INTO "django_geo_db_location" VALUES(43549,NULL,'Starbuck, MN',18039,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43550,NULL,'Starbuck, MN 56381',18039,222,NULL,41,25218,0);
INSERT INTO "django_geo_db_location" VALUES(43551,NULL,'Swanville, MN',18040,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43552,NULL,'Swanville, MN 56382',18040,222,NULL,41,25219,0);
INSERT INTO "django_geo_db_location" VALUES(43553,NULL,'Upsala, MN',18041,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43554,NULL,'Upsala, MN 56384',18041,222,NULL,41,25220,0);
INSERT INTO "django_geo_db_location" VALUES(43555,NULL,'Villard, MN',18042,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43556,NULL,'Villard, MN 56385',18042,222,NULL,41,25221,0);
INSERT INTO "django_geo_db_location" VALUES(43557,NULL,'Wahkon, MN',18043,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43558,NULL,'Wahkon, MN 56386',18043,222,NULL,41,25222,0);
INSERT INTO "django_geo_db_location" VALUES(43559,NULL,'Waite Park, MN',18044,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43560,NULL,'Waite Park, MN 56387',18044,222,NULL,41,25223,0);
INSERT INTO "django_geo_db_location" VALUES(43561,NULL,'Mount Morris, MN',18045,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43562,NULL,'Mount Morris, MN 56388',18045,222,NULL,41,25224,0);
INSERT INTO "django_geo_db_location" VALUES(43563,NULL,'West Union, MN',18046,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43564,NULL,'West Union, MN 56389',18046,222,NULL,41,25225,0);
INSERT INTO "django_geo_db_location" VALUES(43565,NULL,'Saint Cloud, MN 56393',17973,222,NULL,41,25226,0);
INSERT INTO "django_geo_db_location" VALUES(43566,NULL,'Saint Cloud, MN 56395',17973,222,NULL,41,25227,0);
INSERT INTO "django_geo_db_location" VALUES(43567,NULL,'Saint Cloud, MN 56396',17973,222,NULL,41,25228,0);
INSERT INTO "django_geo_db_location" VALUES(43568,NULL,'Saint Cloud, MN 56397',17973,222,NULL,41,25229,0);
INSERT INTO "django_geo_db_location" VALUES(43569,NULL,'Saint Cloud, MN 56398',17973,222,NULL,41,25230,0);
INSERT INTO "django_geo_db_location" VALUES(43570,NULL,'Saint Cloud, MN 56399',17973,222,NULL,41,25231,0);
INSERT INTO "django_geo_db_location" VALUES(43571,NULL,'Brainerd, MN',18047,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43572,NULL,'Brainerd, MN 56401',18047,222,NULL,41,25232,0);
INSERT INTO "django_geo_db_location" VALUES(43573,NULL,'Baxter, MN',18048,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43574,NULL,'Baxter, MN 56425',18048,222,NULL,41,25233,0);
INSERT INTO "django_geo_db_location" VALUES(43575,NULL,'Ah Gwah Ching, MN',18049,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43576,NULL,'Ah Gwah Ching, MN 56430',18049,222,NULL,41,25234,0);
INSERT INTO "django_geo_db_location" VALUES(43577,NULL,'Aitkin, MN',18050,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43578,NULL,'Aitkin, MN 56431',18050,222,NULL,41,25235,0);
INSERT INTO "django_geo_db_location" VALUES(43579,NULL,'Acton, MN',18051,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43580,NULL,'Acton, MN 56432',18051,222,NULL,41,25236,0);
INSERT INTO "django_geo_db_location" VALUES(43581,NULL,'Akeley, MN',18052,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43582,NULL,'Akeley, MN 56433',18052,222,NULL,41,25237,0);
INSERT INTO "django_geo_db_location" VALUES(43583,NULL,'Aldrich, MN',18053,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43584,NULL,'Aldrich, MN 56434',18053,222,NULL,41,25238,0);
INSERT INTO "django_geo_db_location" VALUES(43585,NULL,'Backus, MN',18054,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43586,NULL,'Backus, MN 56435',18054,222,NULL,41,25239,0);
INSERT INTO "django_geo_db_location" VALUES(43587,NULL,'Benedict, MN',18055,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43588,NULL,'Benedict, MN 56436',18055,222,NULL,41,25240,0);
INSERT INTO "django_geo_db_location" VALUES(43589,NULL,'Bertha, MN',18056,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43590,NULL,'Bertha, MN 56437',18056,222,NULL,41,25241,0);
INSERT INTO "django_geo_db_location" VALUES(43591,NULL,'Browerville, MN',18057,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43592,NULL,'Browerville, MN 56438',18057,222,NULL,41,25242,0);
INSERT INTO "django_geo_db_location" VALUES(43593,NULL,'Clarissa, MN',18058,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43594,NULL,'Clarissa, MN 56440',18058,222,NULL,41,25243,0);
INSERT INTO "django_geo_db_location" VALUES(43595,NULL,'Crosby, MN',18059,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43596,NULL,'Crosby, MN 56441',18059,222,NULL,41,25244,0);
INSERT INTO "django_geo_db_location" VALUES(43597,NULL,'Crosslake, MN',18060,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43598,NULL,'Crosslake, MN 56442',18060,222,NULL,41,25245,0);
INSERT INTO "django_geo_db_location" VALUES(43599,NULL,'Cushing, MN',18061,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43600,NULL,'Cushing, MN 56443',18061,222,NULL,41,25246,0);
INSERT INTO "django_geo_db_location" VALUES(43601,NULL,'Deerwood, MN',18062,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43602,NULL,'Deerwood, MN 56444',18062,222,NULL,41,25247,0);
INSERT INTO "django_geo_db_location" VALUES(43603,NULL,'Eagle Bend, MN',18063,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43604,NULL,'Eagle Bend, MN 56446',18063,222,NULL,41,25248,0);
INSERT INTO "django_geo_db_location" VALUES(43605,NULL,'Emily, MN',18064,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43606,NULL,'Emily, MN 56447',18064,222,NULL,41,25249,0);
INSERT INTO "django_geo_db_location" VALUES(43607,NULL,'Fifty Lakes, MN',18065,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43608,NULL,'Fifty Lakes, MN 56448',18065,222,NULL,41,25250,0);
INSERT INTO "django_geo_db_location" VALUES(43609,NULL,'Fort Ripley, MN',18066,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43610,NULL,'Fort Ripley, MN 56449',18066,222,NULL,41,25251,0);
INSERT INTO "django_geo_db_location" VALUES(43611,NULL,'Garrison, MN',18067,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43612,NULL,'Garrison, MN 56450',18067,222,NULL,41,25252,0);
INSERT INTO "django_geo_db_location" VALUES(43613,NULL,'Hackensack, MN',18068,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43614,NULL,'Hackensack, MN 56452',18068,222,NULL,41,25253,0);
INSERT INTO "django_geo_db_location" VALUES(43615,NULL,'Hewitt, MN',18069,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43616,NULL,'Hewitt, MN 56453',18069,222,NULL,41,25254,0);
INSERT INTO "django_geo_db_location" VALUES(43617,NULL,'Ironton, MN',18070,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43618,NULL,'Ironton, MN 56455',18070,222,NULL,41,25255,0);
INSERT INTO "django_geo_db_location" VALUES(43619,NULL,'Jenkins, MN',18071,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43620,NULL,'Jenkins, MN 56456',18071,222,NULL,41,25256,0);
INSERT INTO "django_geo_db_location" VALUES(43621,NULL,'Lake George, MN',18072,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43622,NULL,'Lake George, MN 56458',18072,222,NULL,41,25257,0);
INSERT INTO "django_geo_db_location" VALUES(43623,NULL,'Lake Hubert, MN',18073,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43624,NULL,'Lake Hubert, MN 56459',18073,222,NULL,41,25258,0);
INSERT INTO "django_geo_db_location" VALUES(43625,NULL,'Itasca, MN',18074,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43626,NULL,'Itasca, MN 56460',18074,222,NULL,41,25259,0);
INSERT INTO "django_geo_db_location" VALUES(43627,NULL,'Laporte, MN',18075,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43628,NULL,'Laporte, MN 56461',18075,222,NULL,41,25260,0);
INSERT INTO "django_geo_db_location" VALUES(43629,NULL,'Menahga, MN',18076,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43630,NULL,'Menahga, MN 56464',18076,222,NULL,41,25261,0);
INSERT INTO "django_geo_db_location" VALUES(43631,NULL,'Merrifield, MN',18077,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43632,NULL,'Merrifield, MN 56465',18077,222,NULL,41,25262,0);
INSERT INTO "django_geo_db_location" VALUES(43633,NULL,'Motley, MN',18078,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43634,NULL,'Motley, MN 56466',18078,222,NULL,41,25263,0);
INSERT INTO "django_geo_db_location" VALUES(43635,NULL,'Nevis, MN',18079,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43636,NULL,'Nevis, MN 56467',18079,222,NULL,41,25264,0);
INSERT INTO "django_geo_db_location" VALUES(43637,NULL,'Nisswa, MN',18080,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43638,NULL,'Nisswa, MN 56468',18080,222,NULL,41,25265,0);
INSERT INTO "django_geo_db_location" VALUES(43639,NULL,'Palisade, MN',18081,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43640,NULL,'Palisade, MN 56469',18081,222,NULL,41,25266,0);
INSERT INTO "django_geo_db_location" VALUES(43641,NULL,'Park Rapids, MN',18082,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43642,NULL,'Park Rapids, MN 56470',18082,222,NULL,41,25267,0);
INSERT INTO "django_geo_db_location" VALUES(43643,NULL,'Pequot Lakes, MN',18083,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43644,NULL,'Pequot Lakes, MN 56472',18083,222,NULL,41,25268,0);
INSERT INTO "django_geo_db_location" VALUES(43645,NULL,'Pillager, MN',18084,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43646,NULL,'Pillager, MN 56473',18084,222,NULL,41,25269,0);
INSERT INTO "django_geo_db_location" VALUES(43647,NULL,'Pine River, MN',18085,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43648,NULL,'Pine River, MN 56474',18085,222,NULL,41,25270,0);
INSERT INTO "django_geo_db_location" VALUES(43649,NULL,'Randall, MN',18086,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43650,NULL,'Randall, MN 56475',18086,222,NULL,41,25271,0);
INSERT INTO "django_geo_db_location" VALUES(43651,NULL,'Sebeka, MN',18087,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43652,NULL,'Sebeka, MN 56477',18087,222,NULL,41,25272,0);
INSERT INTO "django_geo_db_location" VALUES(43653,NULL,'Nimrod, MN',18088,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43654,NULL,'Nimrod, MN 56478',18088,222,NULL,41,25273,0);
INSERT INTO "django_geo_db_location" VALUES(43655,NULL,'Staples, MN',18089,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43656,NULL,'Staples, MN 56479',18089,222,NULL,41,25274,0);
INSERT INTO "django_geo_db_location" VALUES(43657,NULL,'Verndale, MN',18090,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43658,NULL,'Verndale, MN 56481',18090,222,NULL,41,25275,0);
INSERT INTO "django_geo_db_location" VALUES(43659,NULL,'Wadena, MN',18091,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43660,NULL,'Wadena, MN 56482',18091,222,NULL,41,25276,0);
INSERT INTO "django_geo_db_location" VALUES(43661,NULL,'Wadena, MN 56483',18091,222,NULL,41,25277,0);
INSERT INTO "django_geo_db_location" VALUES(43662,NULL,'Walker, MN',18092,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43663,NULL,'Walker, MN 56484',18092,222,NULL,41,25278,0);
INSERT INTO "django_geo_db_location" VALUES(43664,NULL,'Detroit Lakes, MN',18093,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43665,NULL,'Detroit Lakes, MN 56501',18093,222,NULL,41,25279,0);
INSERT INTO "django_geo_db_location" VALUES(43666,NULL,'Detroit Lakes, MN 56502',18093,222,NULL,41,25280,0);
INSERT INTO "django_geo_db_location" VALUES(43667,NULL,'Lake Eunice, MN',18094,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43668,NULL,'Lake Eunice, MN 56508',18094,222,NULL,41,25281,0);
INSERT INTO "django_geo_db_location" VALUES(43669,NULL,'Ada, MN',18095,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43670,NULL,'Ada, MN 56510',18095,222,NULL,41,25282,0);
INSERT INTO "django_geo_db_location" VALUES(43671,NULL,'Audubon, MN',18096,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43672,NULL,'Audubon, MN 56511',18096,222,NULL,41,25283,0);
INSERT INTO "django_geo_db_location" VALUES(43673,NULL,'Baker, MN',18097,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43674,NULL,'Baker, MN 56513',18097,222,NULL,41,25284,0);
INSERT INTO "django_geo_db_location" VALUES(43675,NULL,'Barnesville, MN',18098,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43676,NULL,'Barnesville, MN 56514',18098,222,NULL,41,25285,0);
INSERT INTO "django_geo_db_location" VALUES(43677,NULL,'Battle Lake, MN',18099,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43678,NULL,'Battle Lake, MN 56515',18099,222,NULL,41,25286,0);
INSERT INTO "django_geo_db_location" VALUES(43679,NULL,'Bejou, MN',18100,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43680,NULL,'Bejou, MN 56516',18100,222,NULL,41,25287,0);
INSERT INTO "django_geo_db_location" VALUES(43681,NULL,'Beltrami, MN',18101,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43682,NULL,'Beltrami, MN 56517',18101,222,NULL,41,25288,0);
INSERT INTO "django_geo_db_location" VALUES(43683,NULL,'Bluffton, MN',18102,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43684,NULL,'Bluffton, MN 56518',18102,222,NULL,41,25289,0);
INSERT INTO "django_geo_db_location" VALUES(43685,NULL,'Borup, MN',18103,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43686,NULL,'Borup, MN 56519',18103,222,NULL,41,25290,0);
INSERT INTO "django_geo_db_location" VALUES(43687,NULL,'Breckenridge, MN',18104,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43688,NULL,'Breckenridge, MN 56520',18104,222,NULL,41,25291,0);
INSERT INTO "django_geo_db_location" VALUES(43689,NULL,'Callaway, MN',18105,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43690,NULL,'Callaway, MN 56521',18105,222,NULL,41,25292,0);
INSERT INTO "django_geo_db_location" VALUES(43691,NULL,'Campbell, MN',18106,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43692,NULL,'Campbell, MN 56522',18106,222,NULL,41,25293,0);
INSERT INTO "django_geo_db_location" VALUES(43693,NULL,'Climax, MN',18107,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43694,NULL,'Climax, MN 56523',18107,222,NULL,41,25294,0);
INSERT INTO "django_geo_db_location" VALUES(43695,NULL,'Clitherall, MN',18108,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43696,NULL,'Clitherall, MN 56524',18108,222,NULL,41,25295,0);
INSERT INTO "django_geo_db_location" VALUES(43697,NULL,'Comstock, MN',18109,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43698,NULL,'Comstock, MN 56525',18109,222,NULL,41,25296,0);
INSERT INTO "django_geo_db_location" VALUES(43699,NULL,'Deer Creek, MN',18110,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43700,NULL,'Deer Creek, MN 56527',18110,222,NULL,41,25297,0);
INSERT INTO "django_geo_db_location" VALUES(43701,NULL,'Dent, MN',18111,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43702,NULL,'Dent, MN 56528',18111,222,NULL,41,25298,0);
INSERT INTO "django_geo_db_location" VALUES(43703,NULL,'Dilworth, MN',18112,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43704,NULL,'Dilworth, MN 56529',18112,222,NULL,41,25299,0);
INSERT INTO "django_geo_db_location" VALUES(43705,NULL,'Elbow Lake, MN',18113,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43706,NULL,'Elbow Lake, MN 56531',18113,222,NULL,41,25300,0);
INSERT INTO "django_geo_db_location" VALUES(43707,NULL,'Elizabeth, MN',18114,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43708,NULL,'Elizabeth, MN 56533',18114,222,NULL,41,25301,0);
INSERT INTO "django_geo_db_location" VALUES(43709,NULL,'Erhard, MN',18115,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43710,NULL,'Erhard, MN 56534',18115,222,NULL,41,25302,0);
INSERT INTO "django_geo_db_location" VALUES(43711,NULL,'Erskine, MN',18116,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43712,NULL,'Erskine, MN 56535',18116,222,NULL,41,25303,0);
INSERT INTO "django_geo_db_location" VALUES(43713,NULL,'Felton, MN',18117,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43714,NULL,'Felton, MN 56536',18117,222,NULL,41,25304,0);
INSERT INTO "django_geo_db_location" VALUES(43715,NULL,'Fergus Falls, MN',18118,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43716,NULL,'Fergus Falls, MN 56537',18118,222,NULL,41,25305,0);
INSERT INTO "django_geo_db_location" VALUES(43717,NULL,'Fergus Falls, MN 56538',18118,222,NULL,41,25306,0);
INSERT INTO "django_geo_db_location" VALUES(43718,NULL,'Fertile, MN',18119,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43719,NULL,'Fertile, MN 56540',18119,222,NULL,41,25307,0);
INSERT INTO "django_geo_db_location" VALUES(43720,NULL,'Flom, MN',18120,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43721,NULL,'Flom, MN 56541',18120,222,NULL,41,25308,0);
INSERT INTO "django_geo_db_location" VALUES(43722,NULL,'Fosston, MN',18121,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43723,NULL,'Fosston, MN 56542',18121,222,NULL,41,25309,0);
INSERT INTO "django_geo_db_location" VALUES(43724,NULL,'Foxhome, MN',18122,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43725,NULL,'Foxhome, MN 56543',18122,222,NULL,41,25310,0);
INSERT INTO "django_geo_db_location" VALUES(43726,NULL,'Frazee, MN',18123,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43727,NULL,'Frazee, MN 56544',18123,222,NULL,41,25311,0);
INSERT INTO "django_geo_db_location" VALUES(43728,NULL,'Gary, MN',18124,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43729,NULL,'Gary, MN 56545',18124,222,NULL,41,25312,0);
INSERT INTO "django_geo_db_location" VALUES(43730,NULL,'Georgetown, MN',18125,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43731,NULL,'Georgetown, MN 56546',18125,222,NULL,41,25313,0);
INSERT INTO "django_geo_db_location" VALUES(43732,NULL,'Glyndon, MN',18126,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43733,NULL,'Glyndon, MN 56547',18126,222,NULL,41,25314,0);
INSERT INTO "django_geo_db_location" VALUES(43734,NULL,'Halstad, MN',18127,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43735,NULL,'Halstad, MN 56548',18127,222,NULL,41,25315,0);
INSERT INTO "django_geo_db_location" VALUES(43736,NULL,'Hawley, MN',18128,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43737,NULL,'Hawley, MN 56549',18128,222,NULL,41,25316,0);
INSERT INTO "django_geo_db_location" VALUES(43738,NULL,'Hendrum, MN',18129,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43739,NULL,'Hendrum, MN 56550',18129,222,NULL,41,25317,0);
INSERT INTO "django_geo_db_location" VALUES(43740,NULL,'Henning, MN',18130,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43741,NULL,'Henning, MN 56551',18130,222,NULL,41,25318,0);
INSERT INTO "django_geo_db_location" VALUES(43742,NULL,'Hitterdal, MN',18131,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43743,NULL,'Hitterdal, MN 56552',18131,222,NULL,41,25319,0);
INSERT INTO "django_geo_db_location" VALUES(43744,NULL,'Kent, MN',18132,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43745,NULL,'Kent, MN 56553',18132,222,NULL,41,25320,0);
INSERT INTO "django_geo_db_location" VALUES(43746,NULL,'Lake Park, MN',18133,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43747,NULL,'Lake Park, MN 56554',18133,222,NULL,41,25321,0);
INSERT INTO "django_geo_db_location" VALUES(43748,NULL,'Mcintosh, MN',18134,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43749,NULL,'Mcintosh, MN 56556',18134,222,NULL,41,25322,0);
INSERT INTO "django_geo_db_location" VALUES(43750,NULL,'Mahnomen, MN',18135,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43751,NULL,'Mahnomen, MN 56557',18135,222,NULL,41,25323,0);
INSERT INTO "django_geo_db_location" VALUES(43752,NULL,'Moorhead, MN',18136,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43753,NULL,'Moorhead, MN 56560',18136,222,NULL,41,25324,0);
INSERT INTO "django_geo_db_location" VALUES(43754,NULL,'Moorhead, MN 56561',18136,222,NULL,41,25325,0);
INSERT INTO "django_geo_db_location" VALUES(43755,NULL,'Moorhead, MN 56562',18136,222,NULL,41,25326,0);
INSERT INTO "django_geo_db_location" VALUES(43756,NULL,'Moorhead, MN 56563',18136,222,NULL,41,25327,0);
INSERT INTO "django_geo_db_location" VALUES(43757,NULL,'Nashua, MN',18137,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43758,NULL,'Nashua, MN 56565',18137,222,NULL,41,25328,0);
INSERT INTO "django_geo_db_location" VALUES(43759,NULL,'Naytahwaush, MN',18138,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43760,NULL,'Naytahwaush, MN 56566',18138,222,NULL,41,25329,0);
INSERT INTO "django_geo_db_location" VALUES(43761,NULL,'New York Mills, MN',18139,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43762,NULL,'New York Mills, MN 56567',18139,222,NULL,41,25330,0);
INSERT INTO "django_geo_db_location" VALUES(43763,NULL,'Nielsville, MN',18140,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43764,NULL,'Nielsville, MN 56568',18140,222,NULL,41,25331,0);
INSERT INTO "django_geo_db_location" VALUES(43765,NULL,'Ogema, MN',18141,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43766,NULL,'Ogema, MN 56569',18141,222,NULL,41,25332,0);
INSERT INTO "django_geo_db_location" VALUES(43767,NULL,'Osage, MN',18142,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43768,NULL,'Osage, MN 56570',18142,222,NULL,41,25333,0);
INSERT INTO "django_geo_db_location" VALUES(43769,NULL,'Ottertail, MN',18143,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43770,NULL,'Ottertail, MN 56571',18143,222,NULL,41,25334,0);
INSERT INTO "django_geo_db_location" VALUES(43771,NULL,'Pelican Rapids, MN',18144,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43772,NULL,'Pelican Rapids, MN 56572',18144,222,NULL,41,25335,0);
INSERT INTO "django_geo_db_location" VALUES(43773,NULL,'Perham, MN',18145,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43774,NULL,'Perham, MN 56573',18145,222,NULL,41,25336,0);
INSERT INTO "django_geo_db_location" VALUES(43775,NULL,'Perley, MN',18146,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43776,NULL,'Perley, MN 56574',18146,222,NULL,41,25337,0);
INSERT INTO "django_geo_db_location" VALUES(43777,NULL,'Ponsford, MN',18147,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43778,NULL,'Ponsford, MN 56575',18147,222,NULL,41,25338,0);
INSERT INTO "django_geo_db_location" VALUES(43779,NULL,'Richville, MN',18148,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43780,NULL,'Richville, MN 56576',18148,222,NULL,41,25339,0);
INSERT INTO "django_geo_db_location" VALUES(43781,NULL,'Richwood, MN',18149,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43782,NULL,'Richwood, MN 56577',18149,222,NULL,41,25340,0);
INSERT INTO "django_geo_db_location" VALUES(43783,NULL,'Rochert, MN',18150,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43784,NULL,'Rochert, MN 56578',18150,222,NULL,41,25341,0);
INSERT INTO "django_geo_db_location" VALUES(43785,NULL,'Rothsay, MN',18151,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43786,NULL,'Rothsay, MN 56579',18151,222,NULL,41,25342,0);
INSERT INTO "django_geo_db_location" VALUES(43787,NULL,'Sabin, MN',18152,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43788,NULL,'Sabin, MN 56580',18152,222,NULL,41,25343,0);
INSERT INTO "django_geo_db_location" VALUES(43789,NULL,'Shelly, MN',18153,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43790,NULL,'Shelly, MN 56581',18153,222,NULL,41,25344,0);
INSERT INTO "django_geo_db_location" VALUES(43791,NULL,'Tintah, MN',18154,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43792,NULL,'Tintah, MN 56583',18154,222,NULL,41,25345,0);
INSERT INTO "django_geo_db_location" VALUES(43793,NULL,'Twin Valley, MN',18155,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43794,NULL,'Twin Valley, MN 56584',18155,222,NULL,41,25346,0);
INSERT INTO "django_geo_db_location" VALUES(43795,NULL,'Ulen, MN',18156,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43796,NULL,'Ulen, MN 56585',18156,222,NULL,41,25347,0);
INSERT INTO "django_geo_db_location" VALUES(43797,NULL,'Underwood, MN',18157,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43798,NULL,'Underwood, MN 56586',18157,222,NULL,41,25348,0);
INSERT INTO "django_geo_db_location" VALUES(43799,NULL,'Vergas, MN',18158,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43800,NULL,'Vergas, MN 56587',18158,222,NULL,41,25349,0);
INSERT INTO "django_geo_db_location" VALUES(43801,NULL,'Vining, MN',18159,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43802,NULL,'Vining, MN 56588',18159,222,NULL,41,25350,0);
INSERT INTO "django_geo_db_location" VALUES(43803,NULL,'Waubun, MN',18160,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43804,NULL,'Waubun, MN 56589',18160,222,NULL,41,25351,0);
INSERT INTO "django_geo_db_location" VALUES(43805,NULL,'Wendell, MN',18161,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43806,NULL,'Wendell, MN 56590',18161,222,NULL,41,25352,0);
INSERT INTO "django_geo_db_location" VALUES(43807,NULL,'White Earth, MN',18162,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43808,NULL,'White Earth, MN 56591',18162,222,NULL,41,25353,0);
INSERT INTO "django_geo_db_location" VALUES(43809,NULL,'Winger, MN',18163,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43810,NULL,'Winger, MN 56592',18163,222,NULL,41,25354,0);
INSERT INTO "django_geo_db_location" VALUES(43811,NULL,'Wolf Lake, MN',18164,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43812,NULL,'Wolf Lake, MN 56593',18164,222,NULL,41,25355,0);
INSERT INTO "django_geo_db_location" VALUES(43813,NULL,'Wolverton, MN',18165,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43814,NULL,'Wolverton, MN 56594',18165,222,NULL,41,25356,0);
INSERT INTO "django_geo_db_location" VALUES(43815,NULL,'Bemidji, MN',18166,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43816,NULL,'Bemidji, MN 56601',18166,222,NULL,41,25357,0);
INSERT INTO "django_geo_db_location" VALUES(43817,NULL,'Bemidji, MN 56619',18166,222,NULL,41,25358,0);
INSERT INTO "django_geo_db_location" VALUES(43818,NULL,'Bagley, MN',18167,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43819,NULL,'Bagley, MN 56621',18167,222,NULL,41,25359,0);
INSERT INTO "django_geo_db_location" VALUES(43820,NULL,'Baudette, MN',18168,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43821,NULL,'Baudette, MN 56623',18168,222,NULL,41,25360,0);
INSERT INTO "django_geo_db_location" VALUES(43822,NULL,'Bena, MN',18169,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43823,NULL,'Bena, MN 56626',18169,222,NULL,41,25361,0);
INSERT INTO "django_geo_db_location" VALUES(43824,NULL,'Big Falls, MN',18170,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43825,NULL,'Big Falls, MN 56627',18170,222,NULL,41,25362,0);
INSERT INTO "django_geo_db_location" VALUES(43826,NULL,'Bigfork, MN 56628',17634,222,NULL,41,25363,0);
INSERT INTO "django_geo_db_location" VALUES(43827,NULL,'Birchdale, MN',18171,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43828,NULL,'Birchdale, MN 56629',18171,222,NULL,41,25364,0);
INSERT INTO "django_geo_db_location" VALUES(43829,NULL,'Blackduck, MN',18172,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43830,NULL,'Blackduck, MN 56630',18172,222,NULL,41,25365,0);
INSERT INTO "django_geo_db_location" VALUES(43831,NULL,'Bowstring, MN 56631',18027,222,NULL,41,25366,0);
INSERT INTO "django_geo_db_location" VALUES(43832,NULL,'Cass Lake, MN',18173,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43833,NULL,'Cass Lake, MN 56633',18173,222,NULL,41,25367,0);
INSERT INTO "django_geo_db_location" VALUES(43834,NULL,'Clearbrook, MN',18174,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43835,NULL,'Clearbrook, MN 56634',18174,222,NULL,41,25368,0);
INSERT INTO "django_geo_db_location" VALUES(43836,NULL,'Deer River, MN',18175,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43837,NULL,'Deer River, MN 56636',18175,222,NULL,41,25369,0);
INSERT INTO "django_geo_db_location" VALUES(43838,NULL,'Talmoon, MN',18176,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43839,NULL,'Talmoon, MN 56637',18176,222,NULL,41,25370,0);
INSERT INTO "django_geo_db_location" VALUES(43840,NULL,'Effie, MN',18177,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43841,NULL,'Effie, MN 56639',18177,222,NULL,41,25371,0);
INSERT INTO "django_geo_db_location" VALUES(43842,NULL,'Federal Dam, MN',18178,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43843,NULL,'Federal Dam, MN 56641',18178,222,NULL,41,25372,0);
INSERT INTO "django_geo_db_location" VALUES(43844,NULL,'Fleming, MN',18179,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43845,NULL,'Fleming, MN 56643',18179,222,NULL,41,25373,0);
INSERT INTO "django_geo_db_location" VALUES(43846,NULL,'Gonvick, MN',18180,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43847,NULL,'Gonvick, MN 56644',18180,222,NULL,41,25374,0);
INSERT INTO "django_geo_db_location" VALUES(43848,NULL,'Gully, MN',18181,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43849,NULL,'Gully, MN 56646',18181,222,NULL,41,25375,0);
INSERT INTO "django_geo_db_location" VALUES(43850,NULL,'Hines, MN',18182,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43851,NULL,'Hines, MN 56647',18182,222,NULL,41,25376,0);
INSERT INTO "django_geo_db_location" VALUES(43852,NULL,'International Falls, MN',18183,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43853,NULL,'International Falls, MN 56649',18183,222,NULL,41,25377,0);
INSERT INTO "django_geo_db_location" VALUES(43854,NULL,'Kelliher, MN',18184,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43855,NULL,'Kelliher, MN 56650',18184,222,NULL,41,25378,0);
INSERT INTO "django_geo_db_location" VALUES(43856,NULL,'Lengby, MN',18185,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43857,NULL,'Lengby, MN 56651',18185,222,NULL,41,25379,0);
INSERT INTO "django_geo_db_location" VALUES(43858,NULL,'Leonard, MN',18186,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43859,NULL,'Leonard, MN 56652',18186,222,NULL,41,25380,0);
INSERT INTO "django_geo_db_location" VALUES(43860,NULL,'Littlefork, MN',18187,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43861,NULL,'Littlefork, MN 56653',18187,222,NULL,41,25381,0);
INSERT INTO "django_geo_db_location" VALUES(43862,NULL,'Loman, MN',18188,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43863,NULL,'Loman, MN 56654',18188,222,NULL,41,25382,0);
INSERT INTO "django_geo_db_location" VALUES(43864,NULL,'Longville, MN',18189,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43865,NULL,'Longville, MN 56655',18189,222,NULL,41,25383,0);
INSERT INTO "django_geo_db_location" VALUES(43866,NULL,'Marcell, MN',18190,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43867,NULL,'Marcell, MN 56657',18190,222,NULL,41,25384,0);
INSERT INTO "django_geo_db_location" VALUES(43868,NULL,'Margie, MN',18191,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43869,NULL,'Margie, MN 56658',18191,222,NULL,41,25385,0);
INSERT INTO "django_geo_db_location" VALUES(43870,NULL,'Max, MN',18192,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43871,NULL,'Max, MN 56659',18192,222,NULL,41,25386,0);
INSERT INTO "django_geo_db_location" VALUES(43872,NULL,'Mizpah, MN',18193,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43873,NULL,'Mizpah, MN 56660',18193,222,NULL,41,25387,0);
INSERT INTO "django_geo_db_location" VALUES(43874,NULL,'Northome, MN',18194,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43875,NULL,'Northome, MN 56661',18194,222,NULL,41,25388,0);
INSERT INTO "django_geo_db_location" VALUES(43876,NULL,'Outing, MN',18195,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43877,NULL,'Outing, MN 56662',18195,222,NULL,41,25389,0);
INSERT INTO "django_geo_db_location" VALUES(43878,NULL,'Pennington, MN',18196,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43879,NULL,'Pennington, MN 56663',18196,222,NULL,41,25390,0);
INSERT INTO "django_geo_db_location" VALUES(43880,NULL,'Ponemah, MN',18197,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43881,NULL,'Ponemah, MN 56666',18197,222,NULL,41,25391,0);
INSERT INTO "django_geo_db_location" VALUES(43882,NULL,'Puposky, MN',18198,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43883,NULL,'Puposky, MN 56667',18198,222,NULL,41,25392,0);
INSERT INTO "django_geo_db_location" VALUES(43884,NULL,'Ranier, MN',18199,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43885,NULL,'Ranier, MN 56668',18199,222,NULL,41,25393,0);
INSERT INTO "django_geo_db_location" VALUES(43886,NULL,'Ray, MN',18200,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43887,NULL,'Ray, MN 56669',18200,222,NULL,41,25394,0);
INSERT INTO "django_geo_db_location" VALUES(43888,NULL,'Redby, MN',18201,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43889,NULL,'Redby, MN 56670',18201,222,NULL,41,25395,0);
INSERT INTO "django_geo_db_location" VALUES(43890,NULL,'Redlake, MN',18202,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43891,NULL,'Redlake, MN 56671',18202,222,NULL,41,25396,0);
INSERT INTO "django_geo_db_location" VALUES(43892,NULL,'Remer, MN',18203,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43893,NULL,'Remer, MN 56672',18203,222,NULL,41,25397,0);
INSERT INTO "django_geo_db_location" VALUES(43894,NULL,'Roosevelt, MN',18204,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43895,NULL,'Roosevelt, MN 56673',18204,222,NULL,41,25398,0);
INSERT INTO "django_geo_db_location" VALUES(43896,NULL,'Shevlin, MN',18205,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43897,NULL,'Shevlin, MN 56676',18205,222,NULL,41,25399,0);
INSERT INTO "django_geo_db_location" VALUES(43898,NULL,'Solway, MN',18206,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43899,NULL,'Solway, MN 56678',18206,222,NULL,41,25400,0);
INSERT INTO "django_geo_db_location" VALUES(43900,NULL,'South International Falls, MN',18207,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43901,NULL,'South International Falls, MN 56679',18207,222,NULL,41,25401,0);
INSERT INTO "django_geo_db_location" VALUES(43902,NULL,'Spring Lake, MN',18208,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43903,NULL,'Spring Lake, MN 56680',18208,222,NULL,41,25402,0);
INSERT INTO "django_geo_db_location" VALUES(43904,NULL,'Squaw Lake, MN',18209,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43905,NULL,'Squaw Lake, MN 56681',18209,222,NULL,41,25403,0);
INSERT INTO "django_geo_db_location" VALUES(43906,NULL,'Swift, MN',18210,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43907,NULL,'Swift, MN 56682',18210,222,NULL,41,25404,0);
INSERT INTO "django_geo_db_location" VALUES(43908,NULL,'Tenstrike, MN',18211,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43909,NULL,'Tenstrike, MN 56683',18211,222,NULL,41,25405,0);
INSERT INTO "django_geo_db_location" VALUES(43910,NULL,'Trail, MN',18212,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43911,NULL,'Trail, MN 56684',18212,222,NULL,41,25406,0);
INSERT INTO "django_geo_db_location" VALUES(43912,NULL,'Waskish, MN',18213,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43913,NULL,'Waskish, MN 56685',18213,222,NULL,41,25407,0);
INSERT INTO "django_geo_db_location" VALUES(43914,NULL,'Williams, MN',18214,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43915,NULL,'Williams, MN 56686',18214,222,NULL,41,25408,0);
INSERT INTO "django_geo_db_location" VALUES(43916,NULL,'Wilton, MN',18215,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43917,NULL,'Wilton, MN 56687',18215,222,NULL,41,25409,0);
INSERT INTO "django_geo_db_location" VALUES(43918,NULL,'Wirt, MN',18216,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43919,NULL,'Wirt, MN 56688',18216,222,NULL,41,25410,0);
INSERT INTO "django_geo_db_location" VALUES(43920,NULL,'Thief River Falls, MN',18217,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43921,NULL,'Thief River Falls, MN 56701',18217,222,NULL,41,25411,0);
INSERT INTO "django_geo_db_location" VALUES(43922,NULL,'Alvarado, MN',18218,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43923,NULL,'Alvarado, MN 56710',18218,222,NULL,41,25412,0);
INSERT INTO "django_geo_db_location" VALUES(43924,NULL,'Angle Inlet, MN',18219,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43925,NULL,'Angle Inlet, MN 56711',18219,222,NULL,41,25413,0);
INSERT INTO "django_geo_db_location" VALUES(43926,NULL,'Angus, MN',18220,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43927,NULL,'Angus, MN 56712',18220,222,NULL,41,25414,0);
INSERT INTO "django_geo_db_location" VALUES(43928,NULL,'Argyle, MN',18221,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43929,NULL,'Argyle, MN 56713',18221,222,NULL,41,25415,0);
INSERT INTO "django_geo_db_location" VALUES(43930,NULL,'Badger, MN',18222,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43931,NULL,'Badger, MN 56714',18222,222,NULL,41,25416,0);
INSERT INTO "django_geo_db_location" VALUES(43932,NULL,'Brooks, MN',18223,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43933,NULL,'Brooks, MN 56715',18223,222,NULL,41,25417,0);
INSERT INTO "django_geo_db_location" VALUES(43934,NULL,'Crookston, MN',18224,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43935,NULL,'Crookston, MN 56716',18224,222,NULL,41,25418,0);
INSERT INTO "django_geo_db_location" VALUES(43936,NULL,'Donaldson, MN',18225,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43937,NULL,'Donaldson, MN 56720',18225,222,NULL,41,25419,0);
INSERT INTO "django_geo_db_location" VALUES(43938,NULL,'East Grand Forks, MN',18226,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43939,NULL,'East Grand Forks, MN 56721',18226,222,NULL,41,25420,0);
INSERT INTO "django_geo_db_location" VALUES(43940,NULL,'Euclid, MN',18227,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43941,NULL,'Euclid, MN 56722',18227,222,NULL,41,25421,0);
INSERT INTO "django_geo_db_location" VALUES(43942,NULL,'Fisher, MN',18228,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43943,NULL,'Fisher, MN 56723',18228,222,NULL,41,25422,0);
INSERT INTO "django_geo_db_location" VALUES(43944,NULL,'Gatzke, MN',18229,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43945,NULL,'Gatzke, MN 56724',18229,222,NULL,41,25423,0);
INSERT INTO "django_geo_db_location" VALUES(43946,NULL,'Goodridge, MN',18230,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43947,NULL,'Goodridge, MN 56725',18230,222,NULL,41,25424,0);
INSERT INTO "django_geo_db_location" VALUES(43948,NULL,'Greenbush, MN',18231,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43949,NULL,'Greenbush, MN 56726',18231,222,NULL,41,25425,0);
INSERT INTO "django_geo_db_location" VALUES(43950,NULL,'Grygla, MN',18232,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43951,NULL,'Grygla, MN 56727',18232,222,NULL,41,25426,0);
INSERT INTO "django_geo_db_location" VALUES(43952,NULL,'Hallock, MN',18233,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43953,NULL,'Hallock, MN 56728',18233,222,NULL,41,25427,0);
INSERT INTO "django_geo_db_location" VALUES(43954,NULL,'Halma, MN',18234,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43955,NULL,'Halma, MN 56729',18234,222,NULL,41,25428,0);
INSERT INTO "django_geo_db_location" VALUES(43956,NULL,'Humboldt, MN',18235,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43957,NULL,'Humboldt, MN 56731',18235,222,NULL,41,25429,0);
INSERT INTO "django_geo_db_location" VALUES(43958,NULL,'Karlstad, MN',18236,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43959,NULL,'Karlstad, MN 56732',18236,222,NULL,41,25430,0);
INSERT INTO "django_geo_db_location" VALUES(43960,NULL,'Kennedy, MN',18237,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43961,NULL,'Kennedy, MN 56733',18237,222,NULL,41,25431,0);
INSERT INTO "django_geo_db_location" VALUES(43962,NULL,'Lake Bronson, MN',18238,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43963,NULL,'Lake Bronson, MN 56734',18238,222,NULL,41,25432,0);
INSERT INTO "django_geo_db_location" VALUES(43964,NULL,'Lancaster, MN',18239,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43965,NULL,'Lancaster, MN 56735',18239,222,NULL,41,25433,0);
INSERT INTO "django_geo_db_location" VALUES(43966,NULL,'Mentor, MN',18240,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43967,NULL,'Mentor, MN 56736',18240,222,NULL,41,25434,0);
INSERT INTO "django_geo_db_location" VALUES(43968,NULL,'Middle River, MN',18241,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43969,NULL,'Middle River, MN 56737',18241,222,NULL,41,25435,0);
INSERT INTO "django_geo_db_location" VALUES(43970,NULL,'Newfolden, MN',18242,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43971,NULL,'Newfolden, MN 56738',18242,222,NULL,41,25436,0);
INSERT INTO "django_geo_db_location" VALUES(43972,NULL,'Noyes, MN',18243,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43973,NULL,'Noyes, MN 56740',18243,222,NULL,41,25437,0);
INSERT INTO "django_geo_db_location" VALUES(43974,NULL,'Oak Island, MN',18244,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43975,NULL,'Oak Island, MN 56741',18244,222,NULL,41,25438,0);
INSERT INTO "django_geo_db_location" VALUES(43976,NULL,'Oklee, MN',18245,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43977,NULL,'Oklee, MN 56742',18245,222,NULL,41,25439,0);
INSERT INTO "django_geo_db_location" VALUES(43978,NULL,'Oslo, MN',18246,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43979,NULL,'Oslo, MN 56744',18246,222,NULL,41,25440,0);
INSERT INTO "django_geo_db_location" VALUES(43980,NULL,'Plummer, MN',18247,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43981,NULL,'Plummer, MN 56748',18247,222,NULL,41,25441,0);
INSERT INTO "django_geo_db_location" VALUES(43982,NULL,'Red Lake Falls, MN',18248,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43983,NULL,'Red Lake Falls, MN 56750',18248,222,NULL,41,25442,0);
INSERT INTO "django_geo_db_location" VALUES(43984,NULL,'Roseau, MN',18249,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43985,NULL,'Roseau, MN 56751',18249,222,NULL,41,25443,0);
INSERT INTO "django_geo_db_location" VALUES(43986,NULL,'Saint Hilaire, MN',18250,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43987,NULL,'Saint Hilaire, MN 56754',18250,222,NULL,41,25444,0);
INSERT INTO "django_geo_db_location" VALUES(43988,NULL,'Saint Vincent, MN',18251,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43989,NULL,'Saint Vincent, MN 56755',18251,222,NULL,41,25445,0);
INSERT INTO "django_geo_db_location" VALUES(43990,NULL,'Salol, MN',18252,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43991,NULL,'Salol, MN 56756',18252,222,NULL,41,25446,0);
INSERT INTO "django_geo_db_location" VALUES(43992,NULL,'Stephen, MN',18253,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43993,NULL,'Stephen, MN 56757',18253,222,NULL,41,25447,0);
INSERT INTO "django_geo_db_location" VALUES(43994,NULL,'Strandquist, MN',18254,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43995,NULL,'Strandquist, MN 56758',18254,222,NULL,41,25448,0);
INSERT INTO "django_geo_db_location" VALUES(43996,NULL,'Strathcona, MN',18255,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43997,NULL,'Strathcona, MN 56759',18255,222,NULL,41,25449,0);
INSERT INTO "django_geo_db_location" VALUES(43998,NULL,'Viking, MN',18256,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(43999,NULL,'Viking, MN 56760',18256,222,NULL,41,25450,0);
INSERT INTO "django_geo_db_location" VALUES(44000,NULL,'Wannaska, MN',18257,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44001,NULL,'Wannaska, MN 56761',18257,222,NULL,41,25451,0);
INSERT INTO "django_geo_db_location" VALUES(44002,NULL,'Warren, MN',18258,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44003,NULL,'Warren, MN 56762',18258,222,NULL,41,25452,0);
INSERT INTO "django_geo_db_location" VALUES(44004,NULL,'Warroad, MN',18259,222,NULL,41,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44005,NULL,'Warroad, MN 56763',18259,222,NULL,41,25453,0);
INSERT INTO "django_geo_db_location" VALUES(44006,NULL,'Alcester, SD',18260,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44007,NULL,'Alcester, SD 57001',18260,222,NULL,49,25454,0);
INSERT INTO "django_geo_db_location" VALUES(44008,NULL,'Aurora, SD',18261,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44009,NULL,'Aurora, SD 57002',18261,222,NULL,49,25455,0);
INSERT INTO "django_geo_db_location" VALUES(44010,NULL,'Baltic, SD',18262,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44011,NULL,'Baltic, SD 57003',18262,222,NULL,49,25456,0);
INSERT INTO "django_geo_db_location" VALUES(44012,NULL,'Beresford, SD',18263,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44013,NULL,'Beresford, SD 57004',18263,222,NULL,49,25457,0);
INSERT INTO "django_geo_db_location" VALUES(44014,NULL,'Brandon, SD',18264,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44015,NULL,'Brandon, SD 57005',18264,222,NULL,49,25458,0);
INSERT INTO "django_geo_db_location" VALUES(44016,NULL,'Brookings, SD',18265,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44017,NULL,'Brookings, SD 57006',18265,222,NULL,49,25459,0);
INSERT INTO "django_geo_db_location" VALUES(44018,NULL,'Brookings, SD 57007',18265,222,NULL,49,25460,0);
INSERT INTO "django_geo_db_location" VALUES(44019,NULL,'Burbank, SD',18266,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44020,NULL,'Burbank, SD 57010',18266,222,NULL,49,25461,0);
INSERT INTO "django_geo_db_location" VALUES(44021,NULL,'Canistota, SD',18267,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44022,NULL,'Canistota, SD 57012',18267,222,NULL,49,25462,0);
INSERT INTO "django_geo_db_location" VALUES(44023,NULL,'Canton, SD',18268,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44024,NULL,'Canton, SD 57013',18268,222,NULL,49,25463,0);
INSERT INTO "django_geo_db_location" VALUES(44025,NULL,'Centerville, SD',18269,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44026,NULL,'Centerville, SD 57014',18269,222,NULL,49,25464,0);
INSERT INTO "django_geo_db_location" VALUES(44027,NULL,'Chancellor, SD',18270,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44028,NULL,'Chancellor, SD 57015',18270,222,NULL,49,25465,0);
INSERT INTO "django_geo_db_location" VALUES(44029,NULL,'Chester, SD',18271,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44030,NULL,'Chester, SD 57016',18271,222,NULL,49,25466,0);
INSERT INTO "django_geo_db_location" VALUES(44031,NULL,'Colman, SD',18272,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44032,NULL,'Colman, SD 57017',18272,222,NULL,49,25467,0);
INSERT INTO "django_geo_db_location" VALUES(44033,NULL,'Colton, SD',18273,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44034,NULL,'Colton, SD 57018',18273,222,NULL,49,25468,0);
INSERT INTO "django_geo_db_location" VALUES(44035,NULL,'Crooks, SD',18274,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44036,NULL,'Crooks, SD 57020',18274,222,NULL,49,25469,0);
INSERT INTO "django_geo_db_location" VALUES(44037,NULL,'Davis, SD',18275,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44038,NULL,'Davis, SD 57021',18275,222,NULL,49,25470,0);
INSERT INTO "django_geo_db_location" VALUES(44039,NULL,'Dell Rapids, SD',18276,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44040,NULL,'Dell Rapids, SD 57022',18276,222,NULL,49,25471,0);
INSERT INTO "django_geo_db_location" VALUES(44041,NULL,'Egan, SD',18277,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44042,NULL,'Egan, SD 57024',18277,222,NULL,49,25472,0);
INSERT INTO "django_geo_db_location" VALUES(44043,NULL,'Elk Point, SD',18278,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44044,NULL,'Elk Point, SD 57025',18278,222,NULL,49,25473,0);
INSERT INTO "django_geo_db_location" VALUES(44045,NULL,'Elkton, SD',18279,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44046,NULL,'Elkton, SD 57026',18279,222,NULL,49,25474,0);
INSERT INTO "django_geo_db_location" VALUES(44047,NULL,'Fairview, SD',18280,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44048,NULL,'Fairview, SD 57027',18280,222,NULL,49,25475,0);
INSERT INTO "django_geo_db_location" VALUES(44049,NULL,'Flandreau, SD',18281,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44050,NULL,'Flandreau, SD 57028',18281,222,NULL,49,25476,0);
INSERT INTO "django_geo_db_location" VALUES(44051,NULL,'Freeman, SD',18282,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44052,NULL,'Freeman, SD 57029',18282,222,NULL,49,25477,0);
INSERT INTO "django_geo_db_location" VALUES(44053,NULL,'Garretson, SD',18283,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44054,NULL,'Garretson, SD 57030',18283,222,NULL,49,25478,0);
INSERT INTO "django_geo_db_location" VALUES(44055,NULL,'Gayville, SD',18284,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44056,NULL,'Gayville, SD 57031',18284,222,NULL,49,25479,0);
INSERT INTO "django_geo_db_location" VALUES(44057,NULL,'Harrisburg, SD',18285,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44058,NULL,'Harrisburg, SD 57032',18285,222,NULL,49,25480,0);
INSERT INTO "django_geo_db_location" VALUES(44059,NULL,'Hartford, SD',18286,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44060,NULL,'Hartford, SD 57033',18286,222,NULL,49,25481,0);
INSERT INTO "django_geo_db_location" VALUES(44061,NULL,'Hudson, SD',18287,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44062,NULL,'Hudson, SD 57034',18287,222,NULL,49,25482,0);
INSERT INTO "django_geo_db_location" VALUES(44063,NULL,'Humboldt, SD',18288,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44064,NULL,'Humboldt, SD 57035',18288,222,NULL,49,25483,0);
INSERT INTO "django_geo_db_location" VALUES(44065,NULL,'Hurley, SD',18289,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44066,NULL,'Hurley, SD 57036',18289,222,NULL,49,25484,0);
INSERT INTO "django_geo_db_location" VALUES(44067,NULL,'Irene, SD',18290,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44068,NULL,'Irene, SD 57037',18290,222,NULL,49,25485,0);
INSERT INTO "django_geo_db_location" VALUES(44069,NULL,'Jefferson, SD',18291,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44070,NULL,'Jefferson, SD 57038',18291,222,NULL,49,25486,0);
INSERT INTO "django_geo_db_location" VALUES(44071,NULL,'Lennox, SD',18292,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44072,NULL,'Lennox, SD 57039',18292,222,NULL,49,25487,0);
INSERT INTO "django_geo_db_location" VALUES(44073,NULL,'Lesterville, SD',18293,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44074,NULL,'Lesterville, SD 57040',18293,222,NULL,49,25488,0);
INSERT INTO "django_geo_db_location" VALUES(44075,NULL,'Lyons, SD',18294,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44076,NULL,'Lyons, SD 57041',18294,222,NULL,49,25489,0);
INSERT INTO "django_geo_db_location" VALUES(44077,NULL,'Madison, SD',18295,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44078,NULL,'Madison, SD 57042',18295,222,NULL,49,25490,0);
INSERT INTO "django_geo_db_location" VALUES(44079,NULL,'Marion, SD',18296,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44080,NULL,'Marion, SD 57043',18296,222,NULL,49,25491,0);
INSERT INTO "django_geo_db_location" VALUES(44081,NULL,'Meckling, SD',18297,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44082,NULL,'Meckling, SD 57044',18297,222,NULL,49,25492,0);
INSERT INTO "django_geo_db_location" VALUES(44083,NULL,'Menno, SD',18298,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44084,NULL,'Menno, SD 57045',18298,222,NULL,49,25493,0);
INSERT INTO "django_geo_db_location" VALUES(44085,NULL,'Mission Hill, SD',18299,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44086,NULL,'Mission Hill, SD 57046',18299,222,NULL,49,25494,0);
INSERT INTO "django_geo_db_location" VALUES(44087,NULL,'Monroe, SD',18300,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44088,NULL,'Monroe, SD 57047',18300,222,NULL,49,25495,0);
INSERT INTO "django_geo_db_location" VALUES(44089,NULL,'Montrose, SD',18301,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44090,NULL,'Montrose, SD 57048',18301,222,NULL,49,25496,0);
INSERT INTO "django_geo_db_location" VALUES(44091,NULL,'North Sioux City, SD',18302,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44092,NULL,'North Sioux City, SD 57049',18302,222,NULL,49,25497,0);
INSERT INTO "django_geo_db_location" VALUES(44093,NULL,'Nunda, SD',18303,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44094,NULL,'Nunda, SD 57050',18303,222,NULL,49,25498,0);
INSERT INTO "django_geo_db_location" VALUES(44095,NULL,'Oldham, SD',18304,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44096,NULL,'Oldham, SD 57051',18304,222,NULL,49,25499,0);
INSERT INTO "django_geo_db_location" VALUES(44097,NULL,'Olivet, SD',18305,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44098,NULL,'Olivet, SD 57052',18305,222,NULL,49,25500,0);
INSERT INTO "django_geo_db_location" VALUES(44099,NULL,'Parker, SD',18306,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44100,NULL,'Parker, SD 57053',18306,222,NULL,49,25501,0);
INSERT INTO "django_geo_db_location" VALUES(44101,NULL,'Ramona, SD',18307,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44102,NULL,'Ramona, SD 57054',18307,222,NULL,49,25502,0);
INSERT INTO "django_geo_db_location" VALUES(44103,NULL,'Renner, SD',18308,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44104,NULL,'Renner, SD 57055',18308,222,NULL,49,25503,0);
INSERT INTO "django_geo_db_location" VALUES(44105,NULL,'Rowena, SD',18309,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44106,NULL,'Rowena, SD 57056',18309,222,NULL,49,25504,0);
INSERT INTO "django_geo_db_location" VALUES(44107,NULL,'Rutland, SD',18310,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44108,NULL,'Rutland, SD 57057',18310,222,NULL,49,25505,0);
INSERT INTO "django_geo_db_location" VALUES(44109,NULL,'Salem, SD',18311,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44110,NULL,'Salem, SD 57058',18311,222,NULL,49,25506,0);
INSERT INTO "django_geo_db_location" VALUES(44111,NULL,'Scotland, SD',18312,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44112,NULL,'Scotland, SD 57059',18312,222,NULL,49,25507,0);
INSERT INTO "django_geo_db_location" VALUES(44113,NULL,'Sinai, SD',18313,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44114,NULL,'Sinai, SD 57061',18313,222,NULL,49,25508,0);
INSERT INTO "django_geo_db_location" VALUES(44115,NULL,'Springfield, SD',18314,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44116,NULL,'Springfield, SD 57062',18314,222,NULL,49,25509,0);
INSERT INTO "django_geo_db_location" VALUES(44117,NULL,'Tabor, SD',18315,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44118,NULL,'Tabor, SD 57063',18315,222,NULL,49,25510,0);
INSERT INTO "django_geo_db_location" VALUES(44119,NULL,'Tea, SD',18316,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44120,NULL,'Tea, SD 57064',18316,222,NULL,49,25511,0);
INSERT INTO "django_geo_db_location" VALUES(44121,NULL,'Trent, SD',18317,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44122,NULL,'Trent, SD 57065',18317,222,NULL,49,25512,0);
INSERT INTO "django_geo_db_location" VALUES(44123,NULL,'Tyndall, SD',18318,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44124,NULL,'Tyndall, SD 57066',18318,222,NULL,49,25513,0);
INSERT INTO "django_geo_db_location" VALUES(44125,NULL,'Utica, SD',18319,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44126,NULL,'Utica, SD 57067',18319,222,NULL,49,25514,0);
INSERT INTO "django_geo_db_location" VALUES(44127,NULL,'Valley Springs, SD',18320,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44128,NULL,'Valley Springs, SD 57068',18320,222,NULL,49,25515,0);
INSERT INTO "django_geo_db_location" VALUES(44129,NULL,'Vermillion, SD',18321,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44130,NULL,'Vermillion, SD 57069',18321,222,NULL,49,25516,0);
INSERT INTO "django_geo_db_location" VALUES(44131,NULL,'Viborg, SD',18322,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44132,NULL,'Viborg, SD 57070',18322,222,NULL,49,25517,0);
INSERT INTO "django_geo_db_location" VALUES(44133,NULL,'Volga, SD',18323,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44134,NULL,'Volga, SD 57071',18323,222,NULL,49,25518,0);
INSERT INTO "django_geo_db_location" VALUES(44135,NULL,'Volin, SD',18324,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44136,NULL,'Volin, SD 57072',18324,222,NULL,49,25519,0);
INSERT INTO "django_geo_db_location" VALUES(44137,NULL,'Wakonda, SD',18325,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44138,NULL,'Wakonda, SD 57073',18325,222,NULL,49,25520,0);
INSERT INTO "django_geo_db_location" VALUES(44139,NULL,'Ward, SD',18326,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44140,NULL,'Ward, SD 57074',18326,222,NULL,49,25521,0);
INSERT INTO "django_geo_db_location" VALUES(44141,NULL,'Wentworth, SD',18327,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44142,NULL,'Wentworth, SD 57075',18327,222,NULL,49,25522,0);
INSERT INTO "django_geo_db_location" VALUES(44143,NULL,'Winfred, SD',18328,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44144,NULL,'Winfred, SD 57076',18328,222,NULL,49,25523,0);
INSERT INTO "django_geo_db_location" VALUES(44145,NULL,'Worthing, SD',18329,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44146,NULL,'Worthing, SD 57077',18329,222,NULL,49,25524,0);
INSERT INTO "django_geo_db_location" VALUES(44147,NULL,'Yankton, SD',18330,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44148,NULL,'Yankton, SD 57078',18330,222,NULL,49,25525,0);
INSERT INTO "django_geo_db_location" VALUES(44149,NULL,'Yankton, SD 57079',18330,222,NULL,49,25526,0);
INSERT INTO "django_geo_db_location" VALUES(44150,NULL,'Sioux Falls, SD',18331,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44151,NULL,'Sioux Falls, SD 57101',18331,222,NULL,49,25527,0);
INSERT INTO "django_geo_db_location" VALUES(44152,NULL,'Sioux Falls, SD 57103',18331,222,NULL,49,25528,0);
INSERT INTO "django_geo_db_location" VALUES(44153,NULL,'Sioux Falls, SD 57104',18331,222,NULL,49,25529,0);
INSERT INTO "django_geo_db_location" VALUES(44154,NULL,'Sioux Falls, SD 57105',18331,222,NULL,49,25530,0);
INSERT INTO "django_geo_db_location" VALUES(44155,NULL,'Sioux Falls, SD 57106',18331,222,NULL,49,25531,0);
INSERT INTO "django_geo_db_location" VALUES(44156,NULL,'Sioux Falls, SD 57107',18331,222,NULL,49,25532,0);
INSERT INTO "django_geo_db_location" VALUES(44157,NULL,'Sioux Falls, SD 57108',18331,222,NULL,49,25533,0);
INSERT INTO "django_geo_db_location" VALUES(44158,NULL,'Sioux Falls, SD 57109',18331,222,NULL,49,25534,0);
INSERT INTO "django_geo_db_location" VALUES(44159,NULL,'Sioux Falls, SD 57110',18331,222,NULL,49,25535,0);
INSERT INTO "django_geo_db_location" VALUES(44160,NULL,'Buffalo Ridge, SD',18332,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44161,NULL,'Buffalo Ridge, SD 57115',18332,222,NULL,49,25536,0);
INSERT INTO "django_geo_db_location" VALUES(44162,NULL,'Sioux Falls, SD 57117',18331,222,NULL,49,25537,0);
INSERT INTO "django_geo_db_location" VALUES(44163,NULL,'Sioux Falls, SD 57118',18331,222,NULL,49,25538,0);
INSERT INTO "django_geo_db_location" VALUES(44164,NULL,'Sioux Falls, SD 57188',18331,222,NULL,49,25539,0);
INSERT INTO "django_geo_db_location" VALUES(44165,NULL,'Sioux Falls, SD 57189',18331,222,NULL,49,25540,0);
INSERT INTO "django_geo_db_location" VALUES(44166,NULL,'Sioux Falls, SD 57192',18331,222,NULL,49,25541,0);
INSERT INTO "django_geo_db_location" VALUES(44167,NULL,'Sioux Falls, SD 57193',18331,222,NULL,49,25542,0);
INSERT INTO "django_geo_db_location" VALUES(44168,NULL,'Sioux Falls, SD 57194',18331,222,NULL,49,25543,0);
INSERT INTO "django_geo_db_location" VALUES(44169,NULL,'Sioux Falls, SD 57195',18331,222,NULL,49,25544,0);
INSERT INTO "django_geo_db_location" VALUES(44170,NULL,'Sioux Falls, SD 57196',18331,222,NULL,49,25545,0);
INSERT INTO "django_geo_db_location" VALUES(44171,NULL,'Sioux Falls, SD 57197',18331,222,NULL,49,25546,0);
INSERT INTO "django_geo_db_location" VALUES(44172,NULL,'Sioux Falls, SD 57198',18331,222,NULL,49,25547,0);
INSERT INTO "django_geo_db_location" VALUES(44173,NULL,'Watertown, SD',18333,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44174,NULL,'Watertown, SD 57201',18333,222,NULL,49,25548,0);
INSERT INTO "django_geo_db_location" VALUES(44175,NULL,'Waverly, SD',18334,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44176,NULL,'Waverly, SD 57202',18334,222,NULL,49,25549,0);
INSERT INTO "django_geo_db_location" VALUES(44177,NULL,'Cleveland, SD',18335,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44178,NULL,'Cleveland, SD 57211',18335,222,NULL,49,25550,0);
INSERT INTO "django_geo_db_location" VALUES(44179,NULL,'Arlington, SD',18336,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44180,NULL,'Arlington, SD 57212',18336,222,NULL,49,25551,0);
INSERT INTO "django_geo_db_location" VALUES(44181,NULL,'Astoria, SD',18337,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44182,NULL,'Astoria, SD 57213',18337,222,NULL,49,25552,0);
INSERT INTO "django_geo_db_location" VALUES(44183,NULL,'Badger, SD',18338,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44184,NULL,'Badger, SD 57214',18338,222,NULL,49,25553,0);
INSERT INTO "django_geo_db_location" VALUES(44185,NULL,'Big Stone City, SD',18339,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44186,NULL,'Big Stone City, SD 57216',18339,222,NULL,49,25554,0);
INSERT INTO "django_geo_db_location" VALUES(44187,NULL,'Bradley, SD',18340,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44188,NULL,'Bradley, SD 57217',18340,222,NULL,49,25555,0);
INSERT INTO "django_geo_db_location" VALUES(44189,NULL,'Brandt, SD',18341,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44190,NULL,'Brandt, SD 57218',18341,222,NULL,49,25556,0);
INSERT INTO "django_geo_db_location" VALUES(44191,NULL,'Bristol, SD',18342,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44192,NULL,'Bristol, SD 57219',18342,222,NULL,49,25557,0);
INSERT INTO "django_geo_db_location" VALUES(44193,NULL,'Bruce, SD',18343,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44194,NULL,'Bruce, SD 57220',18343,222,NULL,49,25558,0);
INSERT INTO "django_geo_db_location" VALUES(44195,NULL,'Bryant, SD',18344,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44196,NULL,'Bryant, SD 57221',18344,222,NULL,49,25559,0);
INSERT INTO "django_geo_db_location" VALUES(44197,NULL,'Castlewood, SD',18345,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44198,NULL,'Castlewood, SD 57223',18345,222,NULL,49,25560,0);
INSERT INTO "django_geo_db_location" VALUES(44199,NULL,'Claire City, SD',18346,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44200,NULL,'Claire City, SD 57224',18346,222,NULL,49,25561,0);
INSERT INTO "django_geo_db_location" VALUES(44201,NULL,'Clark, SD',18347,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44202,NULL,'Clark, SD 57225',18347,222,NULL,49,25562,0);
INSERT INTO "django_geo_db_location" VALUES(44203,NULL,'Clear Lake, SD',18348,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44204,NULL,'Clear Lake, SD 57226',18348,222,NULL,49,25563,0);
INSERT INTO "django_geo_db_location" VALUES(44205,NULL,'Corona, SD',18349,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44206,NULL,'Corona, SD 57227',18349,222,NULL,49,25564,0);
INSERT INTO "django_geo_db_location" VALUES(44207,NULL,'De Smet, SD',18350,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44208,NULL,'De Smet, SD 57230',18350,222,NULL,49,25565,0);
INSERT INTO "django_geo_db_location" VALUES(44209,NULL,'De Smet, SD 57231',18350,222,NULL,49,25566,0);
INSERT INTO "django_geo_db_location" VALUES(44210,NULL,'Eden, SD',18351,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44211,NULL,'Eden, SD 57232',18351,222,NULL,49,25567,0);
INSERT INTO "django_geo_db_location" VALUES(44212,NULL,'Erwin, SD',18352,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44213,NULL,'Erwin, SD 57233',18352,222,NULL,49,25568,0);
INSERT INTO "django_geo_db_location" VALUES(44214,NULL,'Estelline, SD',18353,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44215,NULL,'Estelline, SD 57234',18353,222,NULL,49,25569,0);
INSERT INTO "django_geo_db_location" VALUES(44216,NULL,'Florence, SD',18354,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44217,NULL,'Florence, SD 57235',18354,222,NULL,49,25570,0);
INSERT INTO "django_geo_db_location" VALUES(44218,NULL,'Garden City, SD',18355,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44219,NULL,'Garden City, SD 57236',18355,222,NULL,49,25571,0);
INSERT INTO "django_geo_db_location" VALUES(44220,NULL,'Gary, SD',18356,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44221,NULL,'Gary, SD 57237',18356,222,NULL,49,25572,0);
INSERT INTO "django_geo_db_location" VALUES(44222,NULL,'Goodwin, SD',18357,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44223,NULL,'Goodwin, SD 57238',18357,222,NULL,49,25573,0);
INSERT INTO "django_geo_db_location" VALUES(44224,NULL,'Grenville, SD',18358,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44225,NULL,'Grenville, SD 57239',18358,222,NULL,49,25574,0);
INSERT INTO "django_geo_db_location" VALUES(44226,NULL,'Hayti, SD',18359,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44227,NULL,'Hayti, SD 57241',18359,222,NULL,49,25575,0);
INSERT INTO "django_geo_db_location" VALUES(44228,NULL,'Hazel, SD',18360,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44229,NULL,'Hazel, SD 57242',18360,222,NULL,49,25576,0);
INSERT INTO "django_geo_db_location" VALUES(44230,NULL,'Henry, SD',18361,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44231,NULL,'Henry, SD 57243',18361,222,NULL,49,25577,0);
INSERT INTO "django_geo_db_location" VALUES(44232,NULL,'Hetland, SD',18362,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44233,NULL,'Hetland, SD 57244',18362,222,NULL,49,25578,0);
INSERT INTO "django_geo_db_location" VALUES(44234,NULL,'Kranzburg, SD',18363,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44235,NULL,'Kranzburg, SD 57245',18363,222,NULL,49,25579,0);
INSERT INTO "django_geo_db_location" VALUES(44236,NULL,'Labolt, SD',18364,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44237,NULL,'Labolt, SD 57246',18364,222,NULL,49,25580,0);
INSERT INTO "django_geo_db_location" VALUES(44238,NULL,'Lake City, SD',18365,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44239,NULL,'Lake City, SD 57247',18365,222,NULL,49,25581,0);
INSERT INTO "django_geo_db_location" VALUES(44240,NULL,'Lake Norden, SD',18366,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44241,NULL,'Lake Norden, SD 57248',18366,222,NULL,49,25582,0);
INSERT INTO "django_geo_db_location" VALUES(44242,NULL,'Lake Preston, SD',18367,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44243,NULL,'Lake Preston, SD 57249',18367,222,NULL,49,25583,0);
INSERT INTO "django_geo_db_location" VALUES(44244,NULL,'Marvin, SD',18368,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44245,NULL,'Marvin, SD 57251',18368,222,NULL,49,25584,0);
INSERT INTO "django_geo_db_location" VALUES(44246,NULL,'Milbank, SD',18369,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44247,NULL,'Milbank, SD 57252',18369,222,NULL,49,25585,0);
INSERT INTO "django_geo_db_location" VALUES(44248,NULL,'Milbank, SD 57253',18369,222,NULL,49,25586,0);
INSERT INTO "django_geo_db_location" VALUES(44249,NULL,'New Effington, SD',18370,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44250,NULL,'New Effington, SD 57255',18370,222,NULL,49,25587,0);
INSERT INTO "django_geo_db_location" VALUES(44251,NULL,'Ortley, SD',18371,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44252,NULL,'Ortley, SD 57256',18371,222,NULL,49,25588,0);
INSERT INTO "django_geo_db_location" VALUES(44253,NULL,'Peever, SD',18372,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44254,NULL,'Peever, SD 57257',18372,222,NULL,49,25589,0);
INSERT INTO "django_geo_db_location" VALUES(44255,NULL,'Raymond, SD',18373,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44256,NULL,'Raymond, SD 57258',18373,222,NULL,49,25590,0);
INSERT INTO "django_geo_db_location" VALUES(44257,NULL,'Revillo, SD',18374,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44258,NULL,'Revillo, SD 57259',18374,222,NULL,49,25591,0);
INSERT INTO "django_geo_db_location" VALUES(44259,NULL,'Rosholt, SD',18375,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44260,NULL,'Rosholt, SD 57260',18375,222,NULL,49,25592,0);
INSERT INTO "django_geo_db_location" VALUES(44261,NULL,'Roslyn, SD',18376,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44262,NULL,'Roslyn, SD 57261',18376,222,NULL,49,25593,0);
INSERT INTO "django_geo_db_location" VALUES(44263,NULL,'Sisseton, SD',18377,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44264,NULL,'Sisseton, SD 57262',18377,222,NULL,49,25594,0);
INSERT INTO "django_geo_db_location" VALUES(44265,NULL,'South Shore, SD',18378,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44266,NULL,'South Shore, SD 57263',18378,222,NULL,49,25595,0);
INSERT INTO "django_geo_db_location" VALUES(44267,NULL,'Stockholm, SD',18379,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44268,NULL,'Stockholm, SD 57264',18379,222,NULL,49,25596,0);
INSERT INTO "django_geo_db_location" VALUES(44269,NULL,'Strandburg, SD',18380,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44270,NULL,'Strandburg, SD 57265',18380,222,NULL,49,25597,0);
INSERT INTO "django_geo_db_location" VALUES(44271,NULL,'Summit, SD',18381,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44272,NULL,'Summit, SD 57266',18381,222,NULL,49,25598,0);
INSERT INTO "django_geo_db_location" VALUES(44273,NULL,'Toronto, SD',18382,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44274,NULL,'Toronto, SD 57268',18382,222,NULL,49,25599,0);
INSERT INTO "django_geo_db_location" VALUES(44275,NULL,'Twin Brooks, SD',18383,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44276,NULL,'Twin Brooks, SD 57269',18383,222,NULL,49,25600,0);
INSERT INTO "django_geo_db_location" VALUES(44277,NULL,'Veblen, SD',18384,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44278,NULL,'Veblen, SD 57270',18384,222,NULL,49,25601,0);
INSERT INTO "django_geo_db_location" VALUES(44279,NULL,'Vienna, SD',18385,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44280,NULL,'Vienna, SD 57271',18385,222,NULL,49,25602,0);
INSERT INTO "django_geo_db_location" VALUES(44281,NULL,'Wallace, SD',18386,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44282,NULL,'Wallace, SD 57272',18386,222,NULL,49,25603,0);
INSERT INTO "django_geo_db_location" VALUES(44283,NULL,'Waubay, SD',18387,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44284,NULL,'Waubay, SD 57273',18387,222,NULL,49,25604,0);
INSERT INTO "django_geo_db_location" VALUES(44285,NULL,'Webster, SD',18388,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44286,NULL,'Webster, SD 57274',18388,222,NULL,49,25605,0);
INSERT INTO "django_geo_db_location" VALUES(44287,NULL,'White, SD',18389,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44288,NULL,'White, SD 57276',18389,222,NULL,49,25606,0);
INSERT INTO "django_geo_db_location" VALUES(44289,NULL,'Willow Lake, SD',18390,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44290,NULL,'Willow Lake, SD 57278',18390,222,NULL,49,25607,0);
INSERT INTO "django_geo_db_location" VALUES(44291,NULL,'Wilmot, SD',18391,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44292,NULL,'Wilmot, SD 57279',18391,222,NULL,49,25608,0);
INSERT INTO "django_geo_db_location" VALUES(44293,NULL,'Mitchell, SD',18392,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44294,NULL,'Mitchell, SD 57301',18392,222,NULL,49,25609,0);
INSERT INTO "django_geo_db_location" VALUES(44295,NULL,'Perry, SD',18393,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44296,NULL,'Perry, SD 57309',18393,222,NULL,49,25610,0);
INSERT INTO "django_geo_db_location" VALUES(44297,NULL,'Alexandria, SD',18394,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44298,NULL,'Alexandria, SD 57311',18394,222,NULL,49,25611,0);
INSERT INTO "django_geo_db_location" VALUES(44299,NULL,'Alpena, SD',18395,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44300,NULL,'Alpena, SD 57312',18395,222,NULL,49,25612,0);
INSERT INTO "django_geo_db_location" VALUES(44301,NULL,'Armour, SD',18396,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44302,NULL,'Armour, SD 57313',18396,222,NULL,49,25613,0);
INSERT INTO "django_geo_db_location" VALUES(44303,NULL,'Artesian, SD',18397,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44304,NULL,'Artesian, SD 57314',18397,222,NULL,49,25614,0);
INSERT INTO "django_geo_db_location" VALUES(44305,NULL,'Avon, SD',18398,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44306,NULL,'Avon, SD 57315',18398,222,NULL,49,25615,0);
INSERT INTO "django_geo_db_location" VALUES(44307,NULL,'Bonesteel, SD',18399,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44308,NULL,'Bonesteel, SD 57317',18399,222,NULL,49,25616,0);
INSERT INTO "django_geo_db_location" VALUES(44309,NULL,'Bridgewater, SD',18400,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44310,NULL,'Bridgewater, SD 57319',18400,222,NULL,49,25617,0);
INSERT INTO "django_geo_db_location" VALUES(44311,NULL,'Canova, SD',18401,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44312,NULL,'Canova, SD 57321',18401,222,NULL,49,25618,0);
INSERT INTO "django_geo_db_location" VALUES(44313,NULL,'Carpenter, SD',18402,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44314,NULL,'Carpenter, SD 57322',18402,222,NULL,49,25619,0);
INSERT INTO "django_geo_db_location" VALUES(44315,NULL,'Carthage, SD',18403,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44316,NULL,'Carthage, SD 57323',18403,222,NULL,49,25620,0);
INSERT INTO "django_geo_db_location" VALUES(44317,NULL,'Cavour, SD',18404,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44318,NULL,'Cavour, SD 57324',18404,222,NULL,49,25621,0);
INSERT INTO "django_geo_db_location" VALUES(44319,NULL,'Chamberlain, SD',18405,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44320,NULL,'Chamberlain, SD 57325',18405,222,NULL,49,25622,0);
INSERT INTO "django_geo_db_location" VALUES(44321,NULL,'Chamberlain, SD 57326',18405,222,NULL,49,25623,0);
INSERT INTO "django_geo_db_location" VALUES(44322,NULL,'Corsica, SD',18406,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44323,NULL,'Corsica, SD 57328',18406,222,NULL,49,25624,0);
INSERT INTO "django_geo_db_location" VALUES(44324,NULL,'Dante, SD',18407,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44325,NULL,'Dante, SD 57329',18407,222,NULL,49,25625,0);
INSERT INTO "django_geo_db_location" VALUES(44326,NULL,'Delmont, SD',18408,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44327,NULL,'Delmont, SD 57330',18408,222,NULL,49,25626,0);
INSERT INTO "django_geo_db_location" VALUES(44328,NULL,'Dimock, SD',18409,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44329,NULL,'Dimock, SD 57331',18409,222,NULL,49,25627,0);
INSERT INTO "django_geo_db_location" VALUES(44330,NULL,'Emery, SD',18410,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44331,NULL,'Emery, SD 57332',18410,222,NULL,49,25628,0);
INSERT INTO "django_geo_db_location" VALUES(44332,NULL,'Ethan, SD',18411,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44333,NULL,'Ethan, SD 57334',18411,222,NULL,49,25629,0);
INSERT INTO "django_geo_db_location" VALUES(44334,NULL,'Fairfax, SD',18412,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44335,NULL,'Fairfax, SD 57335',18412,222,NULL,49,25630,0);
INSERT INTO "django_geo_db_location" VALUES(44336,NULL,'Fedora, SD',18413,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44337,NULL,'Fedora, SD 57337',18413,222,NULL,49,25631,0);
INSERT INTO "django_geo_db_location" VALUES(44338,NULL,'Fort Thompson, SD',18414,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44339,NULL,'Fort Thompson, SD 57339',18414,222,NULL,49,25632,0);
INSERT INTO "django_geo_db_location" VALUES(44340,NULL,'Fulton, SD',18415,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44341,NULL,'Fulton, SD 57340',18415,222,NULL,49,25633,0);
INSERT INTO "django_geo_db_location" VALUES(44342,NULL,'Gann Valley, SD',18416,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44343,NULL,'Gann Valley, SD 57341',18416,222,NULL,49,25634,0);
INSERT INTO "django_geo_db_location" VALUES(44344,NULL,'Geddes, SD',18417,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44345,NULL,'Geddes, SD 57342',18417,222,NULL,49,25635,0);
INSERT INTO "django_geo_db_location" VALUES(44346,NULL,'Harrison, SD',18418,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44347,NULL,'Harrison, SD 57344',18418,222,NULL,49,25636,0);
INSERT INTO "django_geo_db_location" VALUES(44348,NULL,'Highmore, SD',18419,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44349,NULL,'Highmore, SD 57345',18419,222,NULL,49,25637,0);
INSERT INTO "django_geo_db_location" VALUES(44350,NULL,'Stephan, SD',18420,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44351,NULL,'Stephan, SD 57346',18420,222,NULL,49,25638,0);
INSERT INTO "django_geo_db_location" VALUES(44352,NULL,'Benton, SD',18421,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44353,NULL,'Benton, SD 57347',18421,222,NULL,49,25639,0);
INSERT INTO "django_geo_db_location" VALUES(44354,NULL,'Hitchcock, SD',18422,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44355,NULL,'Hitchcock, SD 57348',18422,222,NULL,49,25640,0);
INSERT INTO "django_geo_db_location" VALUES(44356,NULL,'Howard, SD',18423,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44357,NULL,'Howard, SD 57349',18423,222,NULL,49,25641,0);
INSERT INTO "django_geo_db_location" VALUES(44358,NULL,'Huron, SD',18424,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44359,NULL,'Huron, SD 57350',18424,222,NULL,49,25642,0);
INSERT INTO "django_geo_db_location" VALUES(44360,NULL,'Iroquois, SD',18425,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44361,NULL,'Iroquois, SD 57353',18425,222,NULL,49,25643,0);
INSERT INTO "django_geo_db_location" VALUES(44362,NULL,'Kaylor, SD',18426,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44363,NULL,'Kaylor, SD 57354',18426,222,NULL,49,25644,0);
INSERT INTO "django_geo_db_location" VALUES(44364,NULL,'Kimball, SD',18427,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44365,NULL,'Kimball, SD 57355',18427,222,NULL,49,25645,0);
INSERT INTO "django_geo_db_location" VALUES(44366,NULL,'Lake Andes, SD',18428,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44367,NULL,'Lake Andes, SD 57356',18428,222,NULL,49,25646,0);
INSERT INTO "django_geo_db_location" VALUES(44368,NULL,'Ravinia, SD',18429,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44369,NULL,'Ravinia, SD 57357',18429,222,NULL,49,25647,0);
INSERT INTO "django_geo_db_location" VALUES(44370,NULL,'Lane, SD',18430,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44371,NULL,'Lane, SD 57358',18430,222,NULL,49,25648,0);
INSERT INTO "django_geo_db_location" VALUES(44372,NULL,'Letcher, SD',18431,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44373,NULL,'Letcher, SD 57359',18431,222,NULL,49,25649,0);
INSERT INTO "django_geo_db_location" VALUES(44374,NULL,'Marty, SD',18432,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44375,NULL,'Marty, SD 57361',18432,222,NULL,49,25650,0);
INSERT INTO "django_geo_db_location" VALUES(44376,NULL,'Miller, SD',18433,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44377,NULL,'Miller, SD 57362',18433,222,NULL,49,25651,0);
INSERT INTO "django_geo_db_location" VALUES(44378,NULL,'Mount Vernon, SD',18434,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44379,NULL,'Mount Vernon, SD 57363',18434,222,NULL,49,25652,0);
INSERT INTO "django_geo_db_location" VALUES(44380,NULL,'New Holland, SD',18435,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44381,NULL,'New Holland, SD 57364',18435,222,NULL,49,25653,0);
INSERT INTO "django_geo_db_location" VALUES(44382,NULL,'Oacoma, SD',18436,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44383,NULL,'Oacoma, SD 57365',18436,222,NULL,49,25654,0);
INSERT INTO "django_geo_db_location" VALUES(44384,NULL,'Parkston, SD',18437,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44385,NULL,'Parkston, SD 57366',18437,222,NULL,49,25655,0);
INSERT INTO "django_geo_db_location" VALUES(44386,NULL,'Pickstown, SD',18438,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44387,NULL,'Pickstown, SD 57367',18438,222,NULL,49,25656,0);
INSERT INTO "django_geo_db_location" VALUES(44388,NULL,'Plankinton, SD',18439,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44389,NULL,'Plankinton, SD 57368',18439,222,NULL,49,25657,0);
INSERT INTO "django_geo_db_location" VALUES(44390,NULL,'Platte, SD',18440,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44391,NULL,'Platte, SD 57369',18440,222,NULL,49,25658,0);
INSERT INTO "django_geo_db_location" VALUES(44392,NULL,'Pukwana, SD',18441,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44393,NULL,'Pukwana, SD 57370',18441,222,NULL,49,25659,0);
INSERT INTO "django_geo_db_location" VALUES(44394,NULL,'Ree Heights, SD',18442,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44395,NULL,'Ree Heights, SD 57371',18442,222,NULL,49,25660,0);
INSERT INTO "django_geo_db_location" VALUES(44396,NULL,'Saint Lawrence, SD',18443,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44397,NULL,'Saint Lawrence, SD 57373',18443,222,NULL,49,25661,0);
INSERT INTO "django_geo_db_location" VALUES(44398,NULL,'Spencer, SD',18444,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44399,NULL,'Spencer, SD 57374',18444,222,NULL,49,25662,0);
INSERT INTO "django_geo_db_location" VALUES(44400,NULL,'Stickney, SD',18445,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44401,NULL,'Stickney, SD 57375',18445,222,NULL,49,25663,0);
INSERT INTO "django_geo_db_location" VALUES(44402,NULL,'Tripp, SD',18446,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44403,NULL,'Tripp, SD 57376',18446,222,NULL,49,25664,0);
INSERT INTO "django_geo_db_location" VALUES(44404,NULL,'Virgil, SD',18447,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44405,NULL,'Virgil, SD 57379',18447,222,NULL,49,25665,0);
INSERT INTO "django_geo_db_location" VALUES(44406,NULL,'Wagner, SD',18448,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44407,NULL,'Wagner, SD 57380',18448,222,NULL,49,25666,0);
INSERT INTO "django_geo_db_location" VALUES(44408,NULL,'Wessington, SD',18449,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44409,NULL,'Wessington, SD 57381',18449,222,NULL,49,25667,0);
INSERT INTO "django_geo_db_location" VALUES(44410,NULL,'Wessington Springs, SD',18450,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44411,NULL,'Wessington Springs, SD 57382',18450,222,NULL,49,25668,0);
INSERT INTO "django_geo_db_location" VALUES(44412,NULL,'White Lake, SD',18451,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44413,NULL,'White Lake, SD 57383',18451,222,NULL,49,25669,0);
INSERT INTO "django_geo_db_location" VALUES(44414,NULL,'Wolsey, SD',18452,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44415,NULL,'Wolsey, SD 57384',18452,222,NULL,49,25670,0);
INSERT INTO "django_geo_db_location" VALUES(44416,NULL,'Woonsocket, SD',18453,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44417,NULL,'Woonsocket, SD 57385',18453,222,NULL,49,25671,0);
INSERT INTO "django_geo_db_location" VALUES(44418,NULL,'Yale, SD',18454,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44419,NULL,'Yale, SD 57386',18454,222,NULL,49,25672,0);
INSERT INTO "django_geo_db_location" VALUES(44420,NULL,'Huron, SD 57399',18424,222,NULL,49,25673,0);
INSERT INTO "django_geo_db_location" VALUES(44421,NULL,'Aberdeen, SD',18455,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44422,NULL,'Aberdeen, SD 57401',18455,222,NULL,49,25674,0);
INSERT INTO "django_geo_db_location" VALUES(44423,NULL,'Aberdeen, SD 57402',18455,222,NULL,49,25675,0);
INSERT INTO "django_geo_db_location" VALUES(44424,NULL,'Bryant, SD 57411',18344,222,NULL,49,25676,0);
INSERT INTO "django_geo_db_location" VALUES(44425,NULL,'Akaska, SD',18456,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44426,NULL,'Akaska, SD 57420',18456,222,NULL,49,25677,0);
INSERT INTO "django_geo_db_location" VALUES(44427,NULL,'Amherst, SD',18457,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44428,NULL,'Amherst, SD 57421',18457,222,NULL,49,25678,0);
INSERT INTO "django_geo_db_location" VALUES(44429,NULL,'Andover, SD',18458,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44430,NULL,'Andover, SD 57422',18458,222,NULL,49,25679,0);
INSERT INTO "django_geo_db_location" VALUES(44431,NULL,'Ashton, SD',18459,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44432,NULL,'Ashton, SD 57424',18459,222,NULL,49,25680,0);
INSERT INTO "django_geo_db_location" VALUES(44433,NULL,'Barnard, SD',18460,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44434,NULL,'Barnard, SD 57426',18460,222,NULL,49,25681,0);
INSERT INTO "django_geo_db_location" VALUES(44435,NULL,'Bath, SD',18461,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44436,NULL,'Bath, SD 57427',18461,222,NULL,49,25682,0);
INSERT INTO "django_geo_db_location" VALUES(44437,NULL,'Bowdle, SD',18462,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44438,NULL,'Bowdle, SD 57428',18462,222,NULL,49,25683,0);
INSERT INTO "django_geo_db_location" VALUES(44439,NULL,'Brentford, SD',18463,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44440,NULL,'Brentford, SD 57429',18463,222,NULL,49,25684,0);
INSERT INTO "django_geo_db_location" VALUES(44441,NULL,'Britton, SD',18464,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44442,NULL,'Britton, SD 57430',18464,222,NULL,49,25685,0);
INSERT INTO "django_geo_db_location" VALUES(44443,NULL,'Claremont, SD',18465,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44444,NULL,'Claremont, SD 57432',18465,222,NULL,49,25686,0);
INSERT INTO "django_geo_db_location" VALUES(44445,NULL,'Columbia, SD',18466,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44446,NULL,'Columbia, SD 57433',18466,222,NULL,49,25687,0);
INSERT INTO "django_geo_db_location" VALUES(44447,NULL,'Conde, SD',18467,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44448,NULL,'Conde, SD 57434',18467,222,NULL,49,25688,0);
INSERT INTO "django_geo_db_location" VALUES(44449,NULL,'Cresbard, SD',18468,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44450,NULL,'Cresbard, SD 57435',18468,222,NULL,49,25689,0);
INSERT INTO "django_geo_db_location" VALUES(44451,NULL,'Doland, SD',18469,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44452,NULL,'Doland, SD 57436',18469,222,NULL,49,25690,0);
INSERT INTO "django_geo_db_location" VALUES(44453,NULL,'Eureka, SD',18470,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44454,NULL,'Eureka, SD 57437',18470,222,NULL,49,25691,0);
INSERT INTO "django_geo_db_location" VALUES(44455,NULL,'Faulkton, SD',18471,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44456,NULL,'Faulkton, SD 57438',18471,222,NULL,49,25692,0);
INSERT INTO "django_geo_db_location" VALUES(44457,NULL,'Ferney, SD',18472,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44458,NULL,'Ferney, SD 57439',18472,222,NULL,49,25693,0);
INSERT INTO "django_geo_db_location" VALUES(44459,NULL,'Frankfort, SD',18473,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44460,NULL,'Frankfort, SD 57440',18473,222,NULL,49,25694,0);
INSERT INTO "django_geo_db_location" VALUES(44461,NULL,'Frederick, SD',18474,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44462,NULL,'Frederick, SD 57441',18474,222,NULL,49,25695,0);
INSERT INTO "django_geo_db_location" VALUES(44463,NULL,'Gettysburg, SD',18475,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44464,NULL,'Gettysburg, SD 57442',18475,222,NULL,49,25696,0);
INSERT INTO "django_geo_db_location" VALUES(44465,NULL,'Cambria, SD',18476,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44466,NULL,'Cambria, SD 57443',18476,222,NULL,49,25697,0);
INSERT INTO "django_geo_db_location" VALUES(44467,NULL,'Groton, SD',18477,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44468,NULL,'Groton, SD 57445',18477,222,NULL,49,25698,0);
INSERT INTO "django_geo_db_location" VALUES(44469,NULL,'Hecla, SD',18478,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44470,NULL,'Hecla, SD 57446',18478,222,NULL,49,25699,0);
INSERT INTO "django_geo_db_location" VALUES(44471,NULL,'Hosmer, SD',18479,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44472,NULL,'Hosmer, SD 57448',18479,222,NULL,49,25700,0);
INSERT INTO "django_geo_db_location" VALUES(44473,NULL,'Houghton, SD',18480,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44474,NULL,'Houghton, SD 57449',18480,222,NULL,49,25701,0);
INSERT INTO "django_geo_db_location" VALUES(44475,NULL,'Hoven, SD',18481,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44476,NULL,'Hoven, SD 57450',18481,222,NULL,49,25702,0);
INSERT INTO "django_geo_db_location" VALUES(44477,NULL,'Ipswich, SD',18482,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44478,NULL,'Ipswich, SD 57451',18482,222,NULL,49,25703,0);
INSERT INTO "django_geo_db_location" VALUES(44479,NULL,'Java, SD',18483,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44480,NULL,'Java, SD 57452',18483,222,NULL,49,25704,0);
INSERT INTO "django_geo_db_location" VALUES(44481,NULL,'Langford, SD',18484,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44482,NULL,'Langford, SD 57454',18484,222,NULL,49,25705,0);
INSERT INTO "django_geo_db_location" VALUES(44483,NULL,'Lebanon, SD',18485,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44484,NULL,'Lebanon, SD 57455',18485,222,NULL,49,25706,0);
INSERT INTO "django_geo_db_location" VALUES(44485,NULL,'Leola, SD',18486,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44486,NULL,'Leola, SD 57456',18486,222,NULL,49,25707,0);
INSERT INTO "django_geo_db_location" VALUES(44487,NULL,'Longlake, SD',18487,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44488,NULL,'Longlake, SD 57457',18487,222,NULL,49,25708,0);
INSERT INTO "django_geo_db_location" VALUES(44489,NULL,'Mansfield, SD',18488,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44490,NULL,'Mansfield, SD 57460',18488,222,NULL,49,25709,0);
INSERT INTO "django_geo_db_location" VALUES(44491,NULL,'Mellette, SD',18489,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44492,NULL,'Mellette, SD 57461',18489,222,NULL,49,25710,0);
INSERT INTO "django_geo_db_location" VALUES(44493,NULL,'Mina, SD',18490,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44494,NULL,'Mina, SD 57462',18490,222,NULL,49,25711,0);
INSERT INTO "django_geo_db_location" VALUES(44495,NULL,'Northville, SD',18491,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44496,NULL,'Northville, SD 57465',18491,222,NULL,49,25712,0);
INSERT INTO "django_geo_db_location" VALUES(44497,NULL,'Onaka, SD',18492,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44498,NULL,'Onaka, SD 57466',18492,222,NULL,49,25713,0);
INSERT INTO "django_geo_db_location" VALUES(44499,NULL,'Orient, SD',18493,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44500,NULL,'Orient, SD 57467',18493,222,NULL,49,25714,0);
INSERT INTO "django_geo_db_location" VALUES(44501,NULL,'Pierpont, SD',18494,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44502,NULL,'Pierpont, SD 57468',18494,222,NULL,49,25715,0);
INSERT INTO "django_geo_db_location" VALUES(44503,NULL,'Redfield, SD',18495,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44504,NULL,'Redfield, SD 57469',18495,222,NULL,49,25716,0);
INSERT INTO "django_geo_db_location" VALUES(44505,NULL,'Rockham, SD',18496,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44506,NULL,'Rockham, SD 57470',18496,222,NULL,49,25717,0);
INSERT INTO "django_geo_db_location" VALUES(44507,NULL,'Roscoe, SD',18497,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44508,NULL,'Roscoe, SD 57471',18497,222,NULL,49,25718,0);
INSERT INTO "django_geo_db_location" VALUES(44509,NULL,'Selby, SD',18498,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44510,NULL,'Selby, SD 57472',18498,222,NULL,49,25719,0);
INSERT INTO "django_geo_db_location" VALUES(44511,NULL,'Seneca, SD',18499,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44512,NULL,'Seneca, SD 57473',18499,222,NULL,49,25720,0);
INSERT INTO "django_geo_db_location" VALUES(44513,NULL,'Stratford, SD',18500,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44514,NULL,'Stratford, SD 57474',18500,222,NULL,49,25721,0);
INSERT INTO "django_geo_db_location" VALUES(44515,NULL,'Tolstoy, SD',18501,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44516,NULL,'Tolstoy, SD 57475',18501,222,NULL,49,25722,0);
INSERT INTO "django_geo_db_location" VALUES(44517,NULL,'Tulare, SD',18502,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44518,NULL,'Tulare, SD 57476',18502,222,NULL,49,25723,0);
INSERT INTO "django_geo_db_location" VALUES(44519,NULL,'Turton, SD',18503,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44520,NULL,'Turton, SD 57477',18503,222,NULL,49,25724,0);
INSERT INTO "django_geo_db_location" VALUES(44521,NULL,'Warner, SD',18504,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44522,NULL,'Warner, SD 57479',18504,222,NULL,49,25725,0);
INSERT INTO "django_geo_db_location" VALUES(44523,NULL,'Westport, SD',18505,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44524,NULL,'Westport, SD 57481',18505,222,NULL,49,25726,0);
INSERT INTO "django_geo_db_location" VALUES(44525,NULL,'Pierre, SD',18506,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44526,NULL,'Pierre, SD 57501',18506,222,NULL,49,25727,0);
INSERT INTO "django_geo_db_location" VALUES(44527,NULL,'Agar, SD',18507,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44528,NULL,'Agar, SD 57520',18507,222,NULL,49,25728,0);
INSERT INTO "django_geo_db_location" VALUES(44529,NULL,'Belvidere, SD',18508,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44530,NULL,'Belvidere, SD 57521',18508,222,NULL,49,25729,0);
INSERT INTO "django_geo_db_location" VALUES(44531,NULL,'Blunt, SD',18509,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44532,NULL,'Blunt, SD 57522',18509,222,NULL,49,25730,0);
INSERT INTO "django_geo_db_location" VALUES(44533,NULL,'Burke, SD',18510,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44534,NULL,'Burke, SD 57523',18510,222,NULL,49,25731,0);
INSERT INTO "django_geo_db_location" VALUES(44535,NULL,'Carter, SD',18511,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44536,NULL,'Carter, SD 57526',18511,222,NULL,49,25732,0);
INSERT INTO "django_geo_db_location" VALUES(44537,NULL,'Colome, SD',18512,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44538,NULL,'Colome, SD 57528',18512,222,NULL,49,25733,0);
INSERT INTO "django_geo_db_location" VALUES(44539,NULL,'Dallas, SD',18513,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44540,NULL,'Dallas, SD 57529',18513,222,NULL,49,25734,0);
INSERT INTO "django_geo_db_location" VALUES(44541,NULL,'Draper, SD',18514,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44542,NULL,'Draper, SD 57531',18514,222,NULL,49,25735,0);
INSERT INTO "django_geo_db_location" VALUES(44543,NULL,'Fort Pierre, SD',18515,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44544,NULL,'Fort Pierre, SD 57532',18515,222,NULL,49,25736,0);
INSERT INTO "django_geo_db_location" VALUES(44545,NULL,'Gregory, SD',18516,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44546,NULL,'Gregory, SD 57533',18516,222,NULL,49,25737,0);
INSERT INTO "django_geo_db_location" VALUES(44547,NULL,'Hamill, SD',18517,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44548,NULL,'Hamill, SD 57534',18517,222,NULL,49,25738,0);
INSERT INTO "django_geo_db_location" VALUES(44549,NULL,'Harrold, SD',18518,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44550,NULL,'Harrold, SD 57536',18518,222,NULL,49,25739,0);
INSERT INTO "django_geo_db_location" VALUES(44551,NULL,'Hayes, SD',18519,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44552,NULL,'Hayes, SD 57537',18519,222,NULL,49,25740,0);
INSERT INTO "django_geo_db_location" VALUES(44553,NULL,'Herrick, SD',18520,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44554,NULL,'Herrick, SD 57538',18520,222,NULL,49,25741,0);
INSERT INTO "django_geo_db_location" VALUES(44555,NULL,'Holabird, SD',18521,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44556,NULL,'Holabird, SD 57540',18521,222,NULL,49,25742,0);
INSERT INTO "django_geo_db_location" VALUES(44557,NULL,'Ideal, SD',18522,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44558,NULL,'Ideal, SD 57541',18522,222,NULL,49,25743,0);
INSERT INTO "django_geo_db_location" VALUES(44559,NULL,'Iona, SD',18523,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44560,NULL,'Iona, SD 57542',18523,222,NULL,49,25744,0);
INSERT INTO "django_geo_db_location" VALUES(44561,NULL,'Kadoka, SD',18524,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44562,NULL,'Kadoka, SD 57543',18524,222,NULL,49,25745,0);
INSERT INTO "django_geo_db_location" VALUES(44563,NULL,'Kennebec, SD',18525,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44564,NULL,'Kennebec, SD 57544',18525,222,NULL,49,25746,0);
INSERT INTO "django_geo_db_location" VALUES(44565,NULL,'Long Valley, SD',18526,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44566,NULL,'Long Valley, SD 57547',18526,222,NULL,49,25747,0);
INSERT INTO "django_geo_db_location" VALUES(44567,NULL,'Lower Brule, SD',18527,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44568,NULL,'Lower Brule, SD 57548',18527,222,NULL,49,25748,0);
INSERT INTO "django_geo_db_location" VALUES(44569,NULL,'Martin, SD',18528,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44570,NULL,'Martin, SD 57551',18528,222,NULL,49,25749,0);
INSERT INTO "django_geo_db_location" VALUES(44571,NULL,'Midland, SD',18529,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44572,NULL,'Midland, SD 57552',18529,222,NULL,49,25750,0);
INSERT INTO "django_geo_db_location" VALUES(44573,NULL,'Milesville, SD',18530,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44574,NULL,'Milesville, SD 57553',18530,222,NULL,49,25751,0);
INSERT INTO "django_geo_db_location" VALUES(44575,NULL,'Mission, SD',18531,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44576,NULL,'Mission, SD 57555',18531,222,NULL,49,25752,0);
INSERT INTO "django_geo_db_location" VALUES(44577,NULL,'Mission Ridge, SD',18532,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44578,NULL,'Mission Ridge, SD 57557',18532,222,NULL,49,25753,0);
INSERT INTO "django_geo_db_location" VALUES(44579,NULL,'Murdo, SD',18533,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44580,NULL,'Murdo, SD 57559',18533,222,NULL,49,25754,0);
INSERT INTO "django_geo_db_location" VALUES(44581,NULL,'Norris, SD',18534,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44582,NULL,'Norris, SD 57560',18534,222,NULL,49,25755,0);
INSERT INTO "django_geo_db_location" VALUES(44583,NULL,'Okaton, SD',18535,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44584,NULL,'Okaton, SD 57562',18535,222,NULL,49,25756,0);
INSERT INTO "django_geo_db_location" VALUES(44585,NULL,'Okreek, SD',18536,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44586,NULL,'Okreek, SD 57563',18536,222,NULL,49,25757,0);
INSERT INTO "django_geo_db_location" VALUES(44587,NULL,'Onida, SD',18537,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44588,NULL,'Onida, SD 57564',18537,222,NULL,49,25758,0);
INSERT INTO "django_geo_db_location" VALUES(44589,NULL,'Timber Lake, SD',18538,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44590,NULL,'Timber Lake, SD 57565',18538,222,NULL,49,25759,0);
INSERT INTO "django_geo_db_location" VALUES(44591,NULL,'Parmelee, SD',18539,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44592,NULL,'Parmelee, SD 57566',18539,222,NULL,49,25760,0);
INSERT INTO "django_geo_db_location" VALUES(44593,NULL,'Philip, SD',18540,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44594,NULL,'Philip, SD 57567',18540,222,NULL,49,25761,0);
INSERT INTO "django_geo_db_location" VALUES(44595,NULL,'Presho, SD',18541,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44596,NULL,'Presho, SD 57568',18541,222,NULL,49,25762,0);
INSERT INTO "django_geo_db_location" VALUES(44597,NULL,'Reliance, SD',18542,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44598,NULL,'Reliance, SD 57569',18542,222,NULL,49,25763,0);
INSERT INTO "django_geo_db_location" VALUES(44599,NULL,'Rosebud, SD',18543,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44600,NULL,'Rosebud, SD 57570',18543,222,NULL,49,25764,0);
INSERT INTO "django_geo_db_location" VALUES(44601,NULL,'Saint Charles, SD',18544,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44602,NULL,'Saint Charles, SD 57571',18544,222,NULL,49,25765,0);
INSERT INTO "django_geo_db_location" VALUES(44603,NULL,'Saint Francis, SD',18545,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44604,NULL,'Saint Francis, SD 57572',18545,222,NULL,49,25766,0);
INSERT INTO "django_geo_db_location" VALUES(44605,NULL,'Tuthill, SD',18546,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44606,NULL,'Tuthill, SD 57574',18546,222,NULL,49,25767,0);
INSERT INTO "django_geo_db_location" VALUES(44607,NULL,'Vivian, SD',18547,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44608,NULL,'Vivian, SD 57576',18547,222,NULL,49,25768,0);
INSERT INTO "django_geo_db_location" VALUES(44609,NULL,'Wanblee, SD',18548,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44610,NULL,'Wanblee, SD 57577',18548,222,NULL,49,25769,0);
INSERT INTO "django_geo_db_location" VALUES(44611,NULL,'Wewela, SD',18549,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44612,NULL,'Wewela, SD 57578',18549,222,NULL,49,25770,0);
INSERT INTO "django_geo_db_location" VALUES(44613,NULL,'White River, SD',18550,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44614,NULL,'White River, SD 57579',18550,222,NULL,49,25771,0);
INSERT INTO "django_geo_db_location" VALUES(44615,NULL,'Winner, SD',18551,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44616,NULL,'Winner, SD 57580',18551,222,NULL,49,25772,0);
INSERT INTO "django_geo_db_location" VALUES(44617,NULL,'Witten, SD',18552,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44618,NULL,'Witten, SD 57584',18552,222,NULL,49,25773,0);
INSERT INTO "django_geo_db_location" VALUES(44619,NULL,'Wood, SD',18553,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44620,NULL,'Wood, SD 57585',18553,222,NULL,49,25774,0);
INSERT INTO "django_geo_db_location" VALUES(44621,NULL,'Mobridge, SD',18554,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44622,NULL,'Mobridge, SD 57601',18554,222,NULL,49,25775,0);
INSERT INTO "django_geo_db_location" VALUES(44623,NULL,'Bison, SD',18555,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44624,NULL,'Bison, SD 57620',18555,222,NULL,49,25776,0);
INSERT INTO "django_geo_db_location" VALUES(44625,NULL,'Bullhead, SD',18556,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44626,NULL,'Bullhead, SD 57621',18556,222,NULL,49,25777,0);
INSERT INTO "django_geo_db_location" VALUES(44627,NULL,'Cherry Creek, SD',18557,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44628,NULL,'Cherry Creek, SD 57622',18557,222,NULL,49,25778,0);
INSERT INTO "django_geo_db_location" VALUES(44629,NULL,'Dupree, SD',18558,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44630,NULL,'Dupree, SD 57623',18558,222,NULL,49,25779,0);
INSERT INTO "django_geo_db_location" VALUES(44631,NULL,'Eagle Butte, SD',18559,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44632,NULL,'Eagle Butte, SD 57625',18559,222,NULL,49,25780,0);
INSERT INTO "django_geo_db_location" VALUES(44633,NULL,'Faith, SD',18560,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44634,NULL,'Faith, SD 57626',18560,222,NULL,49,25781,0);
INSERT INTO "django_geo_db_location" VALUES(44635,NULL,'Firesteel, SD',18561,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44636,NULL,'Firesteel, SD 57628',18561,222,NULL,49,25782,0);
INSERT INTO "django_geo_db_location" VALUES(44637,NULL,'Glad Valley, SD',18562,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44638,NULL,'Glad Valley, SD 57629',18562,222,NULL,49,25783,0);
INSERT INTO "django_geo_db_location" VALUES(44639,NULL,'Glencross, SD',18563,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44640,NULL,'Glencross, SD 57630',18563,222,NULL,49,25784,0);
INSERT INTO "django_geo_db_location" VALUES(44641,NULL,'Glenham, SD',18564,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44642,NULL,'Glenham, SD 57631',18564,222,NULL,49,25785,0);
INSERT INTO "django_geo_db_location" VALUES(44643,NULL,'Herreid, SD',18565,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44644,NULL,'Herreid, SD 57632',18565,222,NULL,49,25786,0);
INSERT INTO "django_geo_db_location" VALUES(44645,NULL,'Isabel, SD',18566,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44646,NULL,'Isabel, SD 57633',18566,222,NULL,49,25787,0);
INSERT INTO "django_geo_db_location" VALUES(44647,NULL,'Keldron, SD',18567,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44648,NULL,'Keldron, SD 57634',18567,222,NULL,49,25788,0);
INSERT INTO "django_geo_db_location" VALUES(44649,NULL,'Lantry, SD',18568,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44650,NULL,'Lantry, SD 57636',18568,222,NULL,49,25789,0);
INSERT INTO "django_geo_db_location" VALUES(44651,NULL,'Lemmon, ND',18569,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44652,NULL,'Lemmon, ND 57638',18569,222,NULL,34,25790,0);
INSERT INTO "django_geo_db_location" VALUES(44653,NULL,'Little Eagle, SD',18570,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44654,NULL,'Little Eagle, SD 57639',18570,222,NULL,49,25791,0);
INSERT INTO "django_geo_db_location" VALUES(44655,NULL,'Lodgepole, SD',18571,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44656,NULL,'Lodgepole, SD 57640',18571,222,NULL,49,25792,0);
INSERT INTO "django_geo_db_location" VALUES(44657,NULL,'McIntosh, SD',18572,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44658,NULL,'McIntosh, SD 57641',18572,222,NULL,49,25793,0);
INSERT INTO "django_geo_db_location" VALUES(44659,NULL,'McLaughlin, SD',18573,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44660,NULL,'McLaughlin, SD 57642',18573,222,NULL,49,25794,0);
INSERT INTO "django_geo_db_location" VALUES(44661,NULL,'Mahto, SD',18574,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44662,NULL,'Mahto, SD 57643',18574,222,NULL,49,25795,0);
INSERT INTO "django_geo_db_location" VALUES(44663,NULL,'Meadow, SD',18575,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44664,NULL,'Meadow, SD 57644',18575,222,NULL,49,25796,0);
INSERT INTO "django_geo_db_location" VALUES(44665,NULL,'Morristown, SD',18576,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44666,NULL,'Morristown, SD 57645',18576,222,NULL,49,25797,0);
INSERT INTO "django_geo_db_location" VALUES(44667,NULL,'Mound City, SD',18577,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44668,NULL,'Mound City, SD 57646',18577,222,NULL,49,25798,0);
INSERT INTO "django_geo_db_location" VALUES(44669,NULL,'Parade, SD',18578,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44670,NULL,'Parade, SD 57647',18578,222,NULL,49,25799,0);
INSERT INTO "django_geo_db_location" VALUES(44671,NULL,'Pollock, SD',18579,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44672,NULL,'Pollock, SD 57648',18579,222,NULL,49,25800,0);
INSERT INTO "django_geo_db_location" VALUES(44673,NULL,'Prairie City, SD',18580,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44674,NULL,'Prairie City, SD 57649',18580,222,NULL,49,25801,0);
INSERT INTO "django_geo_db_location" VALUES(44675,NULL,'Ralph, SD',18581,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44676,NULL,'Ralph, SD 57650',18581,222,NULL,49,25802,0);
INSERT INTO "django_geo_db_location" VALUES(44677,NULL,'Reva, SD',18582,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44678,NULL,'Reva, SD 57651',18582,222,NULL,49,25803,0);
INSERT INTO "django_geo_db_location" VALUES(44679,NULL,'Ridgeview, SD',18583,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44680,NULL,'Ridgeview, SD 57652',18583,222,NULL,49,25804,0);
INSERT INTO "django_geo_db_location" VALUES(44681,NULL,'Shadehill, SD',18584,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44682,NULL,'Shadehill, SD 57653',18584,222,NULL,49,25805,0);
INSERT INTO "django_geo_db_location" VALUES(44683,NULL,'Timber Lake, SD 57656',18538,222,NULL,49,25806,0);
INSERT INTO "django_geo_db_location" VALUES(44684,NULL,'Trail City, SD',18585,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44685,NULL,'Trail City, SD 57657',18585,222,NULL,49,25807,0);
INSERT INTO "django_geo_db_location" VALUES(44686,NULL,'Wakpala, SD',18586,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44687,NULL,'Wakpala, SD 57658',18586,222,NULL,49,25808,0);
INSERT INTO "django_geo_db_location" VALUES(44688,NULL,'Walker, SD',18587,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44689,NULL,'Walker, SD 57659',18587,222,NULL,49,25809,0);
INSERT INTO "django_geo_db_location" VALUES(44690,NULL,'Watauga, SD',18588,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44691,NULL,'Watauga, SD 57660',18588,222,NULL,49,25810,0);
INSERT INTO "django_geo_db_location" VALUES(44692,NULL,'Whitehorse, SD',18589,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44693,NULL,'Whitehorse, SD 57661',18589,222,NULL,49,25811,0);
INSERT INTO "django_geo_db_location" VALUES(44694,NULL,'McIntosh, SD 57671',18572,222,NULL,49,25812,0);
INSERT INTO "django_geo_db_location" VALUES(44695,NULL,'York, SD',18590,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44696,NULL,'York, SD 57673',18590,222,NULL,49,25813,0);
INSERT INTO "django_geo_db_location" VALUES(44697,NULL,'Orange, ND',18591,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44698,NULL,'Orange, ND 57683',18591,222,NULL,34,25814,0);
INSERT INTO "django_geo_db_location" VALUES(44699,NULL,'Rapid City, SD',18592,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44700,NULL,'Rapid City, SD 57700',18592,222,NULL,49,25815,0);
INSERT INTO "django_geo_db_location" VALUES(44701,NULL,'Rapid City, SD 57701',18592,222,NULL,49,25816,0);
INSERT INTO "django_geo_db_location" VALUES(44702,NULL,'Rapid City, SD 57702',18592,222,NULL,49,25817,0);
INSERT INTO "django_geo_db_location" VALUES(44703,NULL,'Rapid City, SD 57703',18592,222,NULL,49,25818,0);
INSERT INTO "django_geo_db_location" VALUES(44704,NULL,'Ellsworth AFB, SD',18593,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44705,NULL,'Ellsworth AFB, SD 57706',18593,222,NULL,49,25819,0);
INSERT INTO "django_geo_db_location" VALUES(44706,NULL,'Bethlehem, SD',18594,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44707,NULL,'Bethlehem, SD 57708',18594,222,NULL,49,25820,0);
INSERT INTO "django_geo_db_location" VALUES(44708,NULL,'Rapid City, SD 57709',18592,222,NULL,49,25821,0);
INSERT INTO "django_geo_db_location" VALUES(44709,NULL,'Allen, SD',18595,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44710,NULL,'Allen, SD 57714',18595,222,NULL,49,25822,0);
INSERT INTO "django_geo_db_location" VALUES(44711,NULL,'Batesland, SD',18596,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44712,NULL,'Batesland, SD 57716',18596,222,NULL,49,25823,0);
INSERT INTO "django_geo_db_location" VALUES(44713,NULL,'Belle Fourche, SD',18597,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44714,NULL,'Belle Fourche, SD 57717',18597,222,NULL,49,25824,0);
INSERT INTO "django_geo_db_location" VALUES(44715,NULL,'Black Hawk, SD',18598,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44716,NULL,'Black Hawk, SD 57718',18598,222,NULL,49,25825,0);
INSERT INTO "django_geo_db_location" VALUES(44717,NULL,'Box Elder, SD',18599,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44718,NULL,'Box Elder, SD 57719',18599,222,NULL,49,25826,0);
INSERT INTO "django_geo_db_location" VALUES(44719,NULL,'Buffalo, SD',18600,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44720,NULL,'Buffalo, SD 57720',18600,222,NULL,49,25827,0);
INSERT INTO "django_geo_db_location" VALUES(44721,NULL,'Buffalo Gap, SD',18601,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44722,NULL,'Buffalo Gap, SD 57722',18601,222,NULL,49,25828,0);
INSERT INTO "django_geo_db_location" VALUES(44723,NULL,'Camp Crook, SD',18602,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44724,NULL,'Camp Crook, SD 57724',18602,222,NULL,49,25829,0);
INSERT INTO "django_geo_db_location" VALUES(44725,NULL,'Caputa, SD',18603,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44726,NULL,'Caputa, SD 57725',18603,222,NULL,49,25830,0);
INSERT INTO "django_geo_db_location" VALUES(44727,NULL,'Creighton, SD',18604,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44728,NULL,'Creighton, SD 57729',18604,222,NULL,49,25831,0);
INSERT INTO "django_geo_db_location" VALUES(44729,NULL,'Custer, SD',18605,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44730,NULL,'Custer, SD 57730',18605,222,NULL,49,25832,0);
INSERT INTO "django_geo_db_location" VALUES(44731,NULL,'Deadwood, SD',18606,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44732,NULL,'Deadwood, SD 57732',18606,222,NULL,49,25833,0);
INSERT INTO "django_geo_db_location" VALUES(44733,NULL,'Edgemont, SD',18607,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44734,NULL,'Edgemont, SD 57735',18607,222,NULL,49,25834,0);
INSERT INTO "django_geo_db_location" VALUES(44735,NULL,'Elm Springs, SD',18608,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44736,NULL,'Elm Springs, SD 57736',18608,222,NULL,49,25835,0);
INSERT INTO "django_geo_db_location" VALUES(44737,NULL,'Enning, SD',18609,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44738,NULL,'Enning, SD 57737',18609,222,NULL,49,25836,0);
INSERT INTO "django_geo_db_location" VALUES(44739,NULL,'Fairburn, SD',18610,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44740,NULL,'Fairburn, SD 57738',18610,222,NULL,49,25837,0);
INSERT INTO "django_geo_db_location" VALUES(44741,NULL,'Fort Meade, SD',18611,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44742,NULL,'Fort Meade, SD 57741',18611,222,NULL,49,25838,0);
INSERT INTO "django_geo_db_location" VALUES(44743,NULL,'Fruitdale, SD',18612,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44744,NULL,'Fruitdale, SD 57742',18612,222,NULL,49,25839,0);
INSERT INTO "django_geo_db_location" VALUES(44745,NULL,'Hermosa, SD',18613,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44746,NULL,'Hermosa, SD 57744',18613,222,NULL,49,25840,0);
INSERT INTO "django_geo_db_location" VALUES(44747,NULL,'Hill City, SD',18614,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44748,NULL,'Hill City, SD 57745',18614,222,NULL,49,25841,0);
INSERT INTO "django_geo_db_location" VALUES(44749,NULL,'Hot Springs, SD',18615,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44750,NULL,'Hot Springs, SD 57747',18615,222,NULL,49,25842,0);
INSERT INTO "django_geo_db_location" VALUES(44751,NULL,'Howes, SD',18616,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44752,NULL,'Howes, SD 57748',18616,222,NULL,49,25843,0);
INSERT INTO "django_geo_db_location" VALUES(44753,NULL,'Interior, SD',18617,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44754,NULL,'Interior, SD 57750',18617,222,NULL,49,25844,0);
INSERT INTO "django_geo_db_location" VALUES(44755,NULL,'Keystone, SD',18618,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44756,NULL,'Keystone, SD 57751',18618,222,NULL,49,25845,0);
INSERT INTO "django_geo_db_location" VALUES(44757,NULL,'Kyle, SD',18619,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44758,NULL,'Kyle, SD 57752',18619,222,NULL,49,25846,0);
INSERT INTO "django_geo_db_location" VALUES(44759,NULL,'Lead, SD',18620,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44760,NULL,'Lead, SD 57754',18620,222,NULL,49,25847,0);
INSERT INTO "django_geo_db_location" VALUES(44761,NULL,'Ludlow, SD',18621,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44762,NULL,'Ludlow, SD 57755',18621,222,NULL,49,25848,0);
INSERT INTO "django_geo_db_location" VALUES(44763,NULL,'Manderson, SD',18622,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44764,NULL,'Manderson, SD 57756',18622,222,NULL,49,25849,0);
INSERT INTO "django_geo_db_location" VALUES(44765,NULL,'Mud Butte, SD',18623,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44766,NULL,'Mud Butte, SD 57758',18623,222,NULL,49,25850,0);
INSERT INTO "django_geo_db_location" VALUES(44767,NULL,'Nemo, SD',18624,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44768,NULL,'Nemo, SD 57759',18624,222,NULL,49,25851,0);
INSERT INTO "django_geo_db_location" VALUES(44769,NULL,'Newell, SD',18625,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44770,NULL,'Newell, SD 57760',18625,222,NULL,49,25852,0);
INSERT INTO "django_geo_db_location" VALUES(44771,NULL,'New Underwood, SD',18626,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44772,NULL,'New Underwood, SD 57761',18626,222,NULL,49,25853,0);
INSERT INTO "django_geo_db_location" VALUES(44773,NULL,'Nisland, SD',18627,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44774,NULL,'Nisland, SD 57762',18627,222,NULL,49,25854,0);
INSERT INTO "django_geo_db_location" VALUES(44775,NULL,'Oelrichs, SD',18628,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44776,NULL,'Oelrichs, SD 57763',18628,222,NULL,49,25855,0);
INSERT INTO "django_geo_db_location" VALUES(44777,NULL,'Oglala, SD',18629,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44778,NULL,'Oglala, SD 57764',18629,222,NULL,49,25856,0);
INSERT INTO "django_geo_db_location" VALUES(44779,NULL,'Opal, SD',18630,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44780,NULL,'Opal, SD 57765',18630,222,NULL,49,25857,0);
INSERT INTO "django_geo_db_location" VALUES(44781,NULL,'Oral, SD',18631,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44782,NULL,'Oral, SD 57766',18631,222,NULL,49,25858,0);
INSERT INTO "django_geo_db_location" VALUES(44783,NULL,'Owanka, SD',18632,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44784,NULL,'Owanka, SD 57767',18632,222,NULL,49,25859,0);
INSERT INTO "django_geo_db_location" VALUES(44785,NULL,'Piedmont, SD',18633,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44786,NULL,'Piedmont, SD 57769',18633,222,NULL,49,25860,0);
INSERT INTO "django_geo_db_location" VALUES(44787,NULL,'Pine Ridge, SD',18634,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44788,NULL,'Pine Ridge, SD 57770',18634,222,NULL,49,25861,0);
INSERT INTO "django_geo_db_location" VALUES(44789,NULL,'Porcupine, SD',18635,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44790,NULL,'Porcupine, SD 57772',18635,222,NULL,49,25862,0);
INSERT INTO "django_geo_db_location" VALUES(44791,NULL,'Pringle, SD',18636,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44792,NULL,'Pringle, SD 57773',18636,222,NULL,49,25863,0);
INSERT INTO "django_geo_db_location" VALUES(44793,NULL,'Provo, SD',18637,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44794,NULL,'Provo, SD 57774',18637,222,NULL,49,25864,0);
INSERT INTO "django_geo_db_location" VALUES(44795,NULL,'Quinn, SD',18638,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44796,NULL,'Quinn, SD 57775',18638,222,NULL,49,25865,0);
INSERT INTO "django_geo_db_location" VALUES(44797,NULL,'Redig, SD',18639,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44798,NULL,'Redig, SD 57776',18639,222,NULL,49,25866,0);
INSERT INTO "django_geo_db_location" VALUES(44799,NULL,'Red Owl, SD',18640,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44800,NULL,'Red Owl, SD 57777',18640,222,NULL,49,25867,0);
INSERT INTO "django_geo_db_location" VALUES(44801,NULL,'Rochford, SD',18641,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44802,NULL,'Rochford, SD 57778',18641,222,NULL,49,25868,0);
INSERT INTO "django_geo_db_location" VALUES(44803,NULL,'Saint Onge, SD',18642,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44804,NULL,'Saint Onge, SD 57779',18642,222,NULL,49,25869,0);
INSERT INTO "django_geo_db_location" VALUES(44805,NULL,'Scenic, SD',18643,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44806,NULL,'Scenic, SD 57780',18643,222,NULL,49,25870,0);
INSERT INTO "django_geo_db_location" VALUES(44807,NULL,'Smithwick, SD',18644,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44808,NULL,'Smithwick, SD 57782',18644,222,NULL,49,25871,0);
INSERT INTO "django_geo_db_location" VALUES(44809,NULL,'Spearfish, SD',18645,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44810,NULL,'Spearfish, SD 57783',18645,222,NULL,49,25872,0);
INSERT INTO "django_geo_db_location" VALUES(44811,NULL,'Sturgis, SD',18646,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44812,NULL,'Sturgis, SD 57785',18646,222,NULL,49,25873,0);
INSERT INTO "django_geo_db_location" VALUES(44813,NULL,'Union Center, SD',18647,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44814,NULL,'Union Center, SD 57787',18647,222,NULL,49,25874,0);
INSERT INTO "django_geo_db_location" VALUES(44815,NULL,'Vale, SD',18648,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44816,NULL,'Vale, SD 57788',18648,222,NULL,49,25875,0);
INSERT INTO "django_geo_db_location" VALUES(44817,NULL,'Wall, SD',18649,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44818,NULL,'Wall, SD 57790',18649,222,NULL,49,25876,0);
INSERT INTO "django_geo_db_location" VALUES(44819,NULL,'Wasta, SD',18650,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44820,NULL,'Wasta, SD 57791',18650,222,NULL,49,25877,0);
INSERT INTO "django_geo_db_location" VALUES(44821,NULL,'White Owl, SD',18651,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44822,NULL,'White Owl, SD 57792',18651,222,NULL,49,25878,0);
INSERT INTO "django_geo_db_location" VALUES(44823,NULL,'Whitewood, SD',18652,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44824,NULL,'Whitewood, SD 57793',18652,222,NULL,49,25879,0);
INSERT INTO "django_geo_db_location" VALUES(44825,NULL,'Wounded Knee, SD',18653,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44826,NULL,'Wounded Knee, SD 57794',18653,222,NULL,49,25880,0);
INSERT INTO "django_geo_db_location" VALUES(44827,NULL,'Wall, SD 57796',18649,222,NULL,49,25881,0);
INSERT INTO "django_geo_db_location" VALUES(44828,NULL,'Spearfish, SD 57799',18645,222,NULL,49,25882,0);
INSERT INTO "django_geo_db_location" VALUES(44829,NULL,'Harrison, SD 57840',18418,222,NULL,49,25883,0);
INSERT INTO "django_geo_db_location" VALUES(44830,NULL,'Carlisle, SD',18654,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44831,NULL,'Carlisle, SD 57841',18654,222,NULL,49,25884,0);
INSERT INTO "django_geo_db_location" VALUES(44832,NULL,'Big Sioux, SD',18655,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44833,NULL,'Big Sioux, SD 57949',18655,222,NULL,49,25885,0);
INSERT INTO "django_geo_db_location" VALUES(44834,NULL,'Minot, ND',18656,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44835,NULL,'Minot, ND 58000',18656,222,NULL,34,25886,0);
INSERT INTO "django_geo_db_location" VALUES(44836,NULL,'Abercrombie, ND',18657,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44837,NULL,'Abercrombie, ND 58001',18657,222,NULL,34,25887,0);
INSERT INTO "django_geo_db_location" VALUES(44838,NULL,'Absaraka, ND',18658,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44839,NULL,'Absaraka, ND 58002',18658,222,NULL,34,25888,0);
INSERT INTO "django_geo_db_location" VALUES(44840,NULL,'Amenia, ND',18659,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44841,NULL,'Amenia, ND 58004',18659,222,NULL,34,25889,0);
INSERT INTO "django_geo_db_location" VALUES(44842,NULL,'Argusville, ND',18660,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44843,NULL,'Argusville, ND 58005',18660,222,NULL,34,25890,0);
INSERT INTO "django_geo_db_location" VALUES(44844,NULL,'Arthur, ND',18661,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44845,NULL,'Arthur, ND 58006',18661,222,NULL,34,25891,0);
INSERT INTO "django_geo_db_location" VALUES(44846,NULL,'Ayr, ND',18662,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44847,NULL,'Ayr, ND 58007',18662,222,NULL,34,25892,0);
INSERT INTO "django_geo_db_location" VALUES(44848,NULL,'Barney, ND',18663,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44849,NULL,'Barney, ND 58008',18663,222,NULL,34,25893,0);
INSERT INTO "django_geo_db_location" VALUES(44850,NULL,'Blanchard, ND',18664,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44851,NULL,'Blanchard, ND 58009',18664,222,NULL,34,25894,0);
INSERT INTO "django_geo_db_location" VALUES(44852,NULL,'Buffalo, ND',18665,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44853,NULL,'Buffalo, ND 58011',18665,222,NULL,34,25895,0);
INSERT INTO "django_geo_db_location" VALUES(44854,NULL,'Casselton, ND',18666,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44855,NULL,'Casselton, ND 58012',18666,222,NULL,34,25896,0);
INSERT INTO "django_geo_db_location" VALUES(44856,NULL,'Cayuga, ND',18667,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44857,NULL,'Cayuga, ND 58013',18667,222,NULL,34,25897,0);
INSERT INTO "django_geo_db_location" VALUES(44858,NULL,'Chaffee, ND',18668,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44859,NULL,'Chaffee, ND 58014',18668,222,NULL,34,25898,0);
INSERT INTO "django_geo_db_location" VALUES(44860,NULL,'Christine, ND',18669,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44861,NULL,'Christine, ND 58015',18669,222,NULL,34,25899,0);
INSERT INTO "django_geo_db_location" VALUES(44862,NULL,'Clifford, ND',18670,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44863,NULL,'Clifford, ND 58016',18670,222,NULL,34,25900,0);
INSERT INTO "django_geo_db_location" VALUES(44864,NULL,'Cogswell, ND',18671,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44865,NULL,'Cogswell, ND 58017',18671,222,NULL,34,25901,0);
INSERT INTO "django_geo_db_location" VALUES(44866,NULL,'Colfax, ND',18672,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44867,NULL,'Colfax, ND 58018',18672,222,NULL,34,25902,0);
INSERT INTO "django_geo_db_location" VALUES(44868,NULL,'Davenport, ND',18673,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44869,NULL,'Davenport, ND 58021',18673,222,NULL,34,25903,0);
INSERT INTO "django_geo_db_location" VALUES(44870,NULL,'Enderlin, ND',18674,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44871,NULL,'Enderlin, ND 58027',18674,222,NULL,34,25904,0);
INSERT INTO "django_geo_db_location" VALUES(44872,NULL,'Erie, ND',18675,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44873,NULL,'Erie, ND 58029',18675,222,NULL,34,25905,0);
INSERT INTO "django_geo_db_location" VALUES(44874,NULL,'Fairmount, ND',18676,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44875,NULL,'Fairmount, ND 58030',18676,222,NULL,34,25906,0);
INSERT INTO "django_geo_db_location" VALUES(44876,NULL,'Fingal, ND',18677,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44877,NULL,'Fingal, ND 58031',18677,222,NULL,34,25907,0);
INSERT INTO "django_geo_db_location" VALUES(44878,NULL,'Forman, ND',18678,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44879,NULL,'Forman, ND 58032',18678,222,NULL,34,25908,0);
INSERT INTO "django_geo_db_location" VALUES(44880,NULL,'Fort Ransom, ND',18679,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44881,NULL,'Fort Ransom, ND 58033',18679,222,NULL,34,25909,0);
INSERT INTO "django_geo_db_location" VALUES(44882,NULL,'Galesburg, ND',18680,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44883,NULL,'Galesburg, ND 58035',18680,222,NULL,34,25910,0);
INSERT INTO "django_geo_db_location" VALUES(44884,NULL,'Gardner, ND',18681,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44885,NULL,'Gardner, ND 58036',18681,222,NULL,34,25911,0);
INSERT INTO "django_geo_db_location" VALUES(44886,NULL,'Grandin, ND',18682,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44887,NULL,'Grandin, ND 58038',18682,222,NULL,34,25912,0);
INSERT INTO "django_geo_db_location" VALUES(44888,NULL,'Great Bend, ND',18683,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44889,NULL,'Great Bend, ND 58039',18683,222,NULL,34,25913,0);
INSERT INTO "django_geo_db_location" VALUES(44890,NULL,'Gwinner, ND',18684,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44891,NULL,'Gwinner, ND 58040',18684,222,NULL,34,25914,0);
INSERT INTO "django_geo_db_location" VALUES(44892,NULL,'Hankinson, ND',18685,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44893,NULL,'Hankinson, ND 58041',18685,222,NULL,34,25915,0);
INSERT INTO "django_geo_db_location" VALUES(44894,NULL,'Harwood, ND',18686,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44895,NULL,'Harwood, ND 58042',18686,222,NULL,34,25916,0);
INSERT INTO "django_geo_db_location" VALUES(44896,NULL,'Havana, ND',18687,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44897,NULL,'Havana, ND 58043',18687,222,NULL,34,25917,0);
INSERT INTO "django_geo_db_location" VALUES(44898,NULL,'Hillsboro, ND',18688,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44899,NULL,'Hillsboro, ND 58045',18688,222,NULL,34,25918,0);
INSERT INTO "django_geo_db_location" VALUES(44900,NULL,'Hope, ND',18689,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44901,NULL,'Hope, ND 58046',18689,222,NULL,34,25919,0);
INSERT INTO "django_geo_db_location" VALUES(44902,NULL,'Horace, ND',18690,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44903,NULL,'Horace, ND 58047',18690,222,NULL,34,25920,0);
INSERT INTO "django_geo_db_location" VALUES(44904,NULL,'Hunter, ND',18691,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44905,NULL,'Hunter, ND 58048',18691,222,NULL,34,25921,0);
INSERT INTO "django_geo_db_location" VALUES(44906,NULL,'Kathryn, ND',18692,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44907,NULL,'Kathryn, ND 58049',18692,222,NULL,34,25922,0);
INSERT INTO "django_geo_db_location" VALUES(44908,NULL,'Kindred, ND',18693,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44909,NULL,'Kindred, ND 58051',18693,222,NULL,34,25923,0);
INSERT INTO "django_geo_db_location" VALUES(44910,NULL,'Leonard, ND',18694,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44911,NULL,'Leonard, ND 58052',18694,222,NULL,34,25924,0);
INSERT INTO "django_geo_db_location" VALUES(44912,NULL,'Lidgerwood, ND',18695,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44913,NULL,'Lidgerwood, ND 58053',18695,222,NULL,34,25925,0);
INSERT INTO "django_geo_db_location" VALUES(44914,NULL,'Lisbon, ND',18696,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44915,NULL,'Lisbon, ND 58054',18696,222,NULL,34,25926,0);
INSERT INTO "django_geo_db_location" VALUES(44916,NULL,'Luverne, ND',18697,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44917,NULL,'Luverne, ND 58056',18697,222,NULL,34,25927,0);
INSERT INTO "django_geo_db_location" VALUES(44918,NULL,'Mcleod, ND',18698,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44919,NULL,'Mcleod, ND 58057',18698,222,NULL,34,25928,0);
INSERT INTO "django_geo_db_location" VALUES(44920,NULL,'Mantador, ND',18699,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44921,NULL,'Mantador, ND 58058',18699,222,NULL,34,25929,0);
INSERT INTO "django_geo_db_location" VALUES(44922,NULL,'Mapleton, ND',18700,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44923,NULL,'Mapleton, ND 58059',18700,222,NULL,34,25930,0);
INSERT INTO "django_geo_db_location" VALUES(44924,NULL,'Milnor, ND',18701,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44925,NULL,'Milnor, ND 58060',18701,222,NULL,34,25931,0);
INSERT INTO "django_geo_db_location" VALUES(44926,NULL,'Mooreton, ND',18702,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44927,NULL,'Mooreton, ND 58061',18702,222,NULL,34,25932,0);
INSERT INTO "django_geo_db_location" VALUES(44928,NULL,'Nome, ND',18703,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44929,NULL,'Nome, ND 58062',18703,222,NULL,34,25933,0);
INSERT INTO "django_geo_db_location" VALUES(44930,NULL,'Oriska, ND',18704,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44931,NULL,'Oriska, ND 58063',18704,222,NULL,34,25934,0);
INSERT INTO "django_geo_db_location" VALUES(44932,NULL,'Page, ND',18705,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44933,NULL,'Page, ND 58064',18705,222,NULL,34,25935,0);
INSERT INTO "django_geo_db_location" VALUES(44934,NULL,'Pillsbury, ND',18706,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44935,NULL,'Pillsbury, ND 58065',18706,222,NULL,34,25936,0);
INSERT INTO "django_geo_db_location" VALUES(44936,NULL,'Rutland, ND',18707,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44937,NULL,'Rutland, ND 58067',18707,222,NULL,34,25937,0);
INSERT INTO "django_geo_db_location" VALUES(44938,NULL,'Sheldon, ND',18708,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44939,NULL,'Sheldon, ND 58068',18708,222,NULL,34,25938,0);
INSERT INTO "django_geo_db_location" VALUES(44940,NULL,'Stirum, ND',18709,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44941,NULL,'Stirum, ND 58069',18709,222,NULL,34,25939,0);
INSERT INTO "django_geo_db_location" VALUES(44942,NULL,'Tower City, ND',18710,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44943,NULL,'Tower City, ND 58071',18710,222,NULL,34,25940,0);
INSERT INTO "django_geo_db_location" VALUES(44944,NULL,'Valley City, ND',18711,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44945,NULL,'Valley City, ND 58072',18711,222,NULL,34,25941,0);
INSERT INTO "django_geo_db_location" VALUES(44946,NULL,'Wahpeton, ND',18712,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44947,NULL,'Wahpeton, ND 58074',18712,222,NULL,34,25942,0);
INSERT INTO "django_geo_db_location" VALUES(44948,NULL,'Wahpeton, ND 58075',18712,222,NULL,34,25943,0);
INSERT INTO "django_geo_db_location" VALUES(44949,NULL,'Wahpeton, ND 58076',18712,222,NULL,34,25944,0);
INSERT INTO "django_geo_db_location" VALUES(44950,NULL,'Walcott, ND',18713,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44951,NULL,'Walcott, ND 58077',18713,222,NULL,34,25945,0);
INSERT INTO "django_geo_db_location" VALUES(44952,NULL,'West Fargo, ND',18714,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44953,NULL,'West Fargo, ND 58078',18714,222,NULL,34,25946,0);
INSERT INTO "django_geo_db_location" VALUES(44954,NULL,'Wheatland, ND',18715,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44955,NULL,'Wheatland, ND 58079',18715,222,NULL,34,25947,0);
INSERT INTO "django_geo_db_location" VALUES(44956,NULL,'Wyndmere, ND',18716,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44957,NULL,'Wyndmere, ND 58081',18716,222,NULL,34,25948,0);
INSERT INTO "django_geo_db_location" VALUES(44958,NULL,'Fargo, ND',18717,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44959,NULL,'Fargo, ND 58102',18717,222,NULL,34,25949,0);
INSERT INTO "django_geo_db_location" VALUES(44960,NULL,'Fargo, ND 58103',18717,222,NULL,34,25950,0);
INSERT INTO "django_geo_db_location" VALUES(44961,NULL,'Fargo, ND 58104',18717,222,NULL,34,25951,0);
INSERT INTO "django_geo_db_location" VALUES(44962,NULL,'Fargo, ND 58105',18717,222,NULL,34,25952,0);
INSERT INTO "django_geo_db_location" VALUES(44963,NULL,'Fargo, ND 58106',18717,222,NULL,34,25953,0);
INSERT INTO "django_geo_db_location" VALUES(44964,NULL,'Fargo, ND 58107',18717,222,NULL,34,25954,0);
INSERT INTO "django_geo_db_location" VALUES(44965,NULL,'Fargo, ND 58108',18717,222,NULL,34,25955,0);
INSERT INTO "django_geo_db_location" VALUES(44966,NULL,'Fargo, ND 58109',18717,222,NULL,34,25956,0);
INSERT INTO "django_geo_db_location" VALUES(44967,NULL,'Fargo, ND 58121',18717,222,NULL,34,25957,0);
INSERT INTO "django_geo_db_location" VALUES(44968,NULL,'Fargo, ND 58122',18717,222,NULL,34,25958,0);
INSERT INTO "django_geo_db_location" VALUES(44969,NULL,'Fargo, ND 58123',18717,222,NULL,34,25959,0);
INSERT INTO "django_geo_db_location" VALUES(44970,NULL,'Fargo, ND 58124',18717,222,NULL,34,25960,0);
INSERT INTO "django_geo_db_location" VALUES(44971,NULL,'Fargo, ND 58125',18717,222,NULL,34,25961,0);
INSERT INTO "django_geo_db_location" VALUES(44972,NULL,'Fargo, ND 58126',18717,222,NULL,34,25962,0);
INSERT INTO "django_geo_db_location" VALUES(44973,NULL,'Grand Forks, ND',18718,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44974,NULL,'Grand Forks, ND 58201',18718,222,NULL,34,25963,0);
INSERT INTO "django_geo_db_location" VALUES(44975,NULL,'Grand Forks, ND 58202',18718,222,NULL,34,25964,0);
INSERT INTO "django_geo_db_location" VALUES(44976,NULL,'Grand Forks, ND 58203',18718,222,NULL,34,25965,0);
INSERT INTO "django_geo_db_location" VALUES(44977,NULL,'Grand Forks AFB, ND',18719,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44978,NULL,'Grand Forks AFB, ND 58204',18719,222,NULL,34,25966,0);
INSERT INTO "django_geo_db_location" VALUES(44979,NULL,'Grand Forks AFB, ND 58205',18719,222,NULL,34,25967,0);
INSERT INTO "django_geo_db_location" VALUES(44980,NULL,'Grand Forks, ND 58206',18718,222,NULL,34,25968,0);
INSERT INTO "django_geo_db_location" VALUES(44981,NULL,'Grand Forks, ND 58207',18718,222,NULL,34,25969,0);
INSERT INTO "django_geo_db_location" VALUES(44982,NULL,'Grand Forks, ND 58208',18718,222,NULL,34,25970,0);
INSERT INTO "django_geo_db_location" VALUES(44983,NULL,'Adams, ND',18720,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44984,NULL,'Adams, ND 58210',18720,222,NULL,34,25971,0);
INSERT INTO "django_geo_db_location" VALUES(44985,NULL,'Aneta, ND',18721,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44986,NULL,'Aneta, ND 58212',18721,222,NULL,34,25972,0);
INSERT INTO "django_geo_db_location" VALUES(44987,NULL,'Ardoch, ND',18722,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44988,NULL,'Ardoch, ND 58213',18722,222,NULL,34,25973,0);
INSERT INTO "django_geo_db_location" VALUES(44989,NULL,'Arvilla, ND',18723,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44990,NULL,'Arvilla, ND 58214',18723,222,NULL,34,25974,0);
INSERT INTO "django_geo_db_location" VALUES(44991,NULL,'Bathgate, ND',18724,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44992,NULL,'Bathgate, ND 58216',18724,222,NULL,34,25975,0);
INSERT INTO "django_geo_db_location" VALUES(44993,NULL,'Buxton, ND',18725,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44994,NULL,'Buxton, ND 58218',18725,222,NULL,34,25976,0);
INSERT INTO "django_geo_db_location" VALUES(44995,NULL,'Caledonia, ND',18726,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44996,NULL,'Caledonia, ND 58219',18726,222,NULL,34,25977,0);
INSERT INTO "django_geo_db_location" VALUES(44997,NULL,'Cavalier, ND',18727,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(44998,NULL,'Cavalier, ND 58220',18727,222,NULL,34,25978,0);
INSERT INTO "django_geo_db_location" VALUES(44999,NULL,'Crystal, ND',18728,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45000,NULL,'Crystal, ND 58222',18728,222,NULL,34,25979,0);
INSERT INTO "django_geo_db_location" VALUES(45001,NULL,'Cummings, ND',18729,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45002,NULL,'Cummings, ND 58223',18729,222,NULL,34,25980,0);
INSERT INTO "django_geo_db_location" VALUES(45003,NULL,'Dahlen, ND',18730,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45004,NULL,'Dahlen, ND 58224',18730,222,NULL,34,25981,0);
INSERT INTO "django_geo_db_location" VALUES(45005,NULL,'Drayton, ND',18731,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45006,NULL,'Drayton, ND 58225',18731,222,NULL,34,25982,0);
INSERT INTO "django_geo_db_location" VALUES(45007,NULL,'Edinburg, ND',18732,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45008,NULL,'Edinburg, ND 58227',18732,222,NULL,34,25983,0);
INSERT INTO "django_geo_db_location" VALUES(45009,NULL,'Emerado, ND',18733,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45010,NULL,'Emerado, ND 58228',18733,222,NULL,34,25984,0);
INSERT INTO "django_geo_db_location" VALUES(45011,NULL,'Fairdale, ND',18734,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45012,NULL,'Fairdale, ND 58229',18734,222,NULL,34,25985,0);
INSERT INTO "django_geo_db_location" VALUES(45013,NULL,'Finley, ND',18735,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45014,NULL,'Finley, ND 58230',18735,222,NULL,34,25986,0);
INSERT INTO "django_geo_db_location" VALUES(45015,NULL,'Fordville, ND',18736,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45016,NULL,'Fordville, ND 58231',18736,222,NULL,34,25987,0);
INSERT INTO "django_geo_db_location" VALUES(45017,NULL,'Forest River, ND',18737,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45018,NULL,'Forest River, ND 58233',18737,222,NULL,34,25988,0);
INSERT INTO "django_geo_db_location" VALUES(45019,NULL,'Brantford, SD',18738,222,NULL,49,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45020,NULL,'Brantford, SD 58234',18738,222,NULL,49,25989,0);
INSERT INTO "django_geo_db_location" VALUES(45021,NULL,'Gilby, ND',18739,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45022,NULL,'Gilby, ND 58235',18739,222,NULL,34,25990,0);
INSERT INTO "django_geo_db_location" VALUES(45023,NULL,'Glasston, ND',18740,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45024,NULL,'Glasston, ND 58236',18740,222,NULL,34,25991,0);
INSERT INTO "django_geo_db_location" VALUES(45025,NULL,'Grafton, ND',18741,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45026,NULL,'Grafton, ND 58237',18741,222,NULL,34,25992,0);
INSERT INTO "django_geo_db_location" VALUES(45027,NULL,'Hamilton, ND',18742,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45028,NULL,'Hamilton, ND 58238',18742,222,NULL,34,25993,0);
INSERT INTO "django_geo_db_location" VALUES(45029,NULL,'Hannah, ND',18743,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45030,NULL,'Hannah, ND 58239',18743,222,NULL,34,25994,0);
INSERT INTO "django_geo_db_location" VALUES(45031,NULL,'Hatton, ND',18744,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45032,NULL,'Hatton, ND 58240',18744,222,NULL,34,25995,0);
INSERT INTO "django_geo_db_location" VALUES(45033,NULL,'Hensel, ND',18745,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45034,NULL,'Hensel, ND 58241',18745,222,NULL,34,25996,0);
INSERT INTO "django_geo_db_location" VALUES(45035,NULL,'Hoople, ND',18746,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45036,NULL,'Hoople, ND 58243',18746,222,NULL,34,25997,0);
INSERT INTO "django_geo_db_location" VALUES(45037,NULL,'Inkster, ND',18747,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45038,NULL,'Inkster, ND 58244',18747,222,NULL,34,25998,0);
INSERT INTO "django_geo_db_location" VALUES(45039,NULL,'Langdon, ND',18748,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45040,NULL,'Langdon, ND 58249',18748,222,NULL,34,25999,0);
INSERT INTO "django_geo_db_location" VALUES(45041,NULL,'Lankin, ND',18749,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45042,NULL,'Lankin, ND 58250',18749,222,NULL,34,26000,0);
INSERT INTO "django_geo_db_location" VALUES(45043,NULL,'Larimore, ND',18750,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45044,NULL,'Larimore, ND 58251',18750,222,NULL,34,26001,0);
INSERT INTO "django_geo_db_location" VALUES(45045,NULL,'Mcville, ND',18751,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45046,NULL,'Mcville, ND 58254',18751,222,NULL,34,26002,0);
INSERT INTO "django_geo_db_location" VALUES(45047,NULL,'Maida, ND',18752,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45048,NULL,'Maida, ND 58255',18752,222,NULL,34,26003,0);
INSERT INTO "django_geo_db_location" VALUES(45049,NULL,'Manvel, ND',18753,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45050,NULL,'Manvel, ND 58256',18753,222,NULL,34,26004,0);
INSERT INTO "django_geo_db_location" VALUES(45051,NULL,'Mayville, ND',18754,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45052,NULL,'Mayville, ND 58257',18754,222,NULL,34,26005,0);
INSERT INTO "django_geo_db_location" VALUES(45053,NULL,'Mekinock, ND',18755,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45054,NULL,'Mekinock, ND 58258',18755,222,NULL,34,26006,0);
INSERT INTO "django_geo_db_location" VALUES(45055,NULL,'Michigan, ND',18756,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45056,NULL,'Michigan, ND 58259',18756,222,NULL,34,26007,0);
INSERT INTO "django_geo_db_location" VALUES(45057,NULL,'Milton, ND',18757,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45058,NULL,'Milton, ND 58260',18757,222,NULL,34,26008,0);
INSERT INTO "django_geo_db_location" VALUES(45059,NULL,'Minto, ND',18758,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45060,NULL,'Minto, ND 58261',18758,222,NULL,34,26009,0);
INSERT INTO "django_geo_db_location" VALUES(45061,NULL,'Mountain, ND',18759,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45062,NULL,'Mountain, ND 58262',18759,222,NULL,34,26010,0);
INSERT INTO "django_geo_db_location" VALUES(45063,NULL,'Neche, ND',18760,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45064,NULL,'Neche, ND 58265',18760,222,NULL,34,26011,0);
INSERT INTO "django_geo_db_location" VALUES(45065,NULL,'Niagara, ND',18761,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45066,NULL,'Niagara, ND 58266',18761,222,NULL,34,26012,0);
INSERT INTO "django_geo_db_location" VALUES(45067,NULL,'Northwood, ND',18762,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45068,NULL,'Northwood, ND 58267',18762,222,NULL,34,26013,0);
INSERT INTO "django_geo_db_location" VALUES(45069,NULL,'Osnabrock, ND',18763,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45070,NULL,'Osnabrock, ND 58269',18763,222,NULL,34,26014,0);
INSERT INTO "django_geo_db_location" VALUES(45071,NULL,'Park River, ND',18764,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45072,NULL,'Park River, ND 58270',18764,222,NULL,34,26015,0);
INSERT INTO "django_geo_db_location" VALUES(45073,NULL,'Pembina, ND',18765,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45074,NULL,'Pembina, ND 58271',18765,222,NULL,34,26016,0);
INSERT INTO "django_geo_db_location" VALUES(45075,NULL,'Petersburg, ND',18766,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45076,NULL,'Petersburg, ND 58272',18766,222,NULL,34,26017,0);
INSERT INTO "django_geo_db_location" VALUES(45077,NULL,'Pisek, ND',18767,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45078,NULL,'Pisek, ND 58273',18767,222,NULL,34,26018,0);
INSERT INTO "django_geo_db_location" VALUES(45079,NULL,'Portland, ND',18768,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45080,NULL,'Portland, ND 58274',18768,222,NULL,34,26019,0);
INSERT INTO "django_geo_db_location" VALUES(45081,NULL,'Reynolds, ND',18769,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45082,NULL,'Reynolds, ND 58275',18769,222,NULL,34,26020,0);
INSERT INTO "django_geo_db_location" VALUES(45083,NULL,'Saint Thomas, ND',18770,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45084,NULL,'Saint Thomas, ND 58276',18770,222,NULL,34,26021,0);
INSERT INTO "django_geo_db_location" VALUES(45085,NULL,'Sharon, ND',18771,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45086,NULL,'Sharon, ND 58277',18771,222,NULL,34,26022,0);
INSERT INTO "django_geo_db_location" VALUES(45087,NULL,'Thompson, ND',18772,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45088,NULL,'Thompson, ND 58278',18772,222,NULL,34,26023,0);
INSERT INTO "django_geo_db_location" VALUES(45089,NULL,'Wales, ND',18773,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45090,NULL,'Wales, ND 58281',18773,222,NULL,34,26024,0);
INSERT INTO "django_geo_db_location" VALUES(45091,NULL,'Walhalla, ND',18774,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45092,NULL,'Walhalla, ND 58282',18774,222,NULL,34,26025,0);
INSERT INTO "django_geo_db_location" VALUES(45093,NULL,'Farmington, ND',18775,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45094,NULL,'Farmington, ND 58293',18775,222,NULL,34,26026,0);
INSERT INTO "django_geo_db_location" VALUES(45095,NULL,'Poplar Grove, ND',18776,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45096,NULL,'Poplar Grove, ND 58300',18776,222,NULL,34,26027,0);
INSERT INTO "django_geo_db_location" VALUES(45097,NULL,'Devils Lake, ND',18777,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45098,NULL,'Devils Lake, ND 58301',18777,222,NULL,34,26028,0);
INSERT INTO "django_geo_db_location" VALUES(45099,NULL,'Agate, ND',18778,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45100,NULL,'Agate, ND 58310',18778,222,NULL,34,26029,0);
INSERT INTO "django_geo_db_location" VALUES(45101,NULL,'Alsen, ND',18779,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45102,NULL,'Alsen, ND 58311',18779,222,NULL,34,26030,0);
INSERT INTO "django_geo_db_location" VALUES(45103,NULL,'Balta, ND',18780,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45104,NULL,'Balta, ND 58313',18780,222,NULL,34,26031,0);
INSERT INTO "django_geo_db_location" VALUES(45105,NULL,'Belcourt, ND',18781,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45106,NULL,'Belcourt, ND 58316',18781,222,NULL,34,26032,0);
INSERT INTO "django_geo_db_location" VALUES(45107,NULL,'Bisbee, ND',18782,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45108,NULL,'Bisbee, ND 58317',18782,222,NULL,34,26033,0);
INSERT INTO "django_geo_db_location" VALUES(45109,NULL,'Bottineau, ND',18783,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45110,NULL,'Bottineau, ND 58318',18783,222,NULL,34,26034,0);
INSERT INTO "django_geo_db_location" VALUES(45111,NULL,'Bremen, ND',18784,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45112,NULL,'Bremen, ND 58319',18784,222,NULL,34,26035,0);
INSERT INTO "django_geo_db_location" VALUES(45113,NULL,'Brinsmade, ND',18785,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45114,NULL,'Brinsmade, ND 58320',18785,222,NULL,34,26036,0);
INSERT INTO "django_geo_db_location" VALUES(45115,NULL,'Brocket, ND',18786,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45116,NULL,'Brocket, ND 58321',18786,222,NULL,34,26037,0);
INSERT INTO "django_geo_db_location" VALUES(45117,NULL,'Calvin, ND',18787,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45118,NULL,'Calvin, ND 58323',18787,222,NULL,34,26038,0);
INSERT INTO "django_geo_db_location" VALUES(45119,NULL,'Cando, ND',18788,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45120,NULL,'Cando, ND 58324',18788,222,NULL,34,26039,0);
INSERT INTO "django_geo_db_location" VALUES(45121,NULL,'Churchs Ferry, ND',18789,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45122,NULL,'Churchs Ferry, ND 58325',18789,222,NULL,34,26040,0);
INSERT INTO "django_geo_db_location" VALUES(45123,NULL,'Crary, ND',18790,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45124,NULL,'Crary, ND 58327',18790,222,NULL,34,26041,0);
INSERT INTO "django_geo_db_location" VALUES(45125,NULL,'Dunseith, ND',18791,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45126,NULL,'Dunseith, ND 58329',18791,222,NULL,34,26042,0);
INSERT INTO "django_geo_db_location" VALUES(45127,NULL,'Edmore, ND',18792,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45128,NULL,'Edmore, ND 58330',18792,222,NULL,34,26043,0);
INSERT INTO "django_geo_db_location" VALUES(45129,NULL,'Egeland, ND',18793,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45130,NULL,'Egeland, ND 58331',18793,222,NULL,34,26044,0);
INSERT INTO "django_geo_db_location" VALUES(45131,NULL,'Esmond, ND',18794,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45132,NULL,'Esmond, ND 58332',18794,222,NULL,34,26045,0);
INSERT INTO "django_geo_db_location" VALUES(45133,NULL,'Sykeston, ND',18795,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45134,NULL,'Sykeston, ND 58333',18795,222,NULL,34,26046,0);
INSERT INTO "django_geo_db_location" VALUES(45135,NULL,'Fort Totten, ND',18796,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45136,NULL,'Fort Totten, ND 58335',18796,222,NULL,34,26047,0);
INSERT INTO "django_geo_db_location" VALUES(45137,NULL,'Hamberg, ND',18797,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45138,NULL,'Hamberg, ND 58337',18797,222,NULL,34,26048,0);
INSERT INTO "django_geo_db_location" VALUES(45139,NULL,'Hampden, ND',18798,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45140,NULL,'Hampden, ND 58338',18798,222,NULL,34,26049,0);
INSERT INTO "django_geo_db_location" VALUES(45141,NULL,'Hansboro, ND',18799,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45142,NULL,'Hansboro, ND 58339',18799,222,NULL,34,26050,0);
INSERT INTO "django_geo_db_location" VALUES(45143,NULL,'Harvey, ND',18800,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45144,NULL,'Harvey, ND 58341',18800,222,NULL,34,26051,0);
INSERT INTO "django_geo_db_location" VALUES(45145,NULL,'Knox, ND',18801,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45146,NULL,'Knox, ND 58343',18801,222,NULL,34,26052,0);
INSERT INTO "django_geo_db_location" VALUES(45147,NULL,'Lakota, ND',18802,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45148,NULL,'Lakota, ND 58344',18802,222,NULL,34,26053,0);
INSERT INTO "django_geo_db_location" VALUES(45149,NULL,'Lawton, ND',18803,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45150,NULL,'Lawton, ND 58345',18803,222,NULL,34,26054,0);
INSERT INTO "django_geo_db_location" VALUES(45151,NULL,'Leeds, ND',18804,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45152,NULL,'Leeds, ND 58346',18804,222,NULL,34,26055,0);
INSERT INTO "django_geo_db_location" VALUES(45153,NULL,'Maddock, ND',18805,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45154,NULL,'Maddock, ND 58348',18805,222,NULL,34,26056,0);
INSERT INTO "django_geo_db_location" VALUES(45155,NULL,'Minnewaukan, ND',18806,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45156,NULL,'Minnewaukan, ND 58351',18806,222,NULL,34,26057,0);
INSERT INTO "django_geo_db_location" VALUES(45157,NULL,'Munich, ND',18807,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45158,NULL,'Munich, ND 58352',18807,222,NULL,34,26058,0);
INSERT INTO "django_geo_db_location" VALUES(45159,NULL,'Mylo, ND',18808,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45160,NULL,'Mylo, ND 58353',18808,222,NULL,34,26059,0);
INSERT INTO "django_geo_db_location" VALUES(45161,NULL,'Nekoma, ND',18809,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45162,NULL,'Nekoma, ND 58355',18809,222,NULL,34,26060,0);
INSERT INTO "django_geo_db_location" VALUES(45163,NULL,'New Rockford, ND',18810,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45164,NULL,'New Rockford, ND 58356',18810,222,NULL,34,26061,0);
INSERT INTO "django_geo_db_location" VALUES(45165,NULL,'Oberon, ND',18811,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45166,NULL,'Oberon, ND 58357',18811,222,NULL,34,26062,0);
INSERT INTO "django_geo_db_location" VALUES(45167,NULL,'Fort Yates, ND',18812,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45168,NULL,'Fort Yates, ND 58358',18812,222,NULL,34,26063,0);
INSERT INTO "django_geo_db_location" VALUES(45169,NULL,'Orrin, ND',18813,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45170,NULL,'Orrin, ND 58359',18813,222,NULL,34,26064,0);
INSERT INTO "django_geo_db_location" VALUES(45171,NULL,'Pekin, ND',18814,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45172,NULL,'Pekin, ND 58361',18814,222,NULL,34,26065,0);
INSERT INTO "django_geo_db_location" VALUES(45173,NULL,'Penn, ND',18815,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45174,NULL,'Penn, ND 58362',18815,222,NULL,34,26066,0);
INSERT INTO "django_geo_db_location" VALUES(45175,NULL,'Perth, ND',18816,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45176,NULL,'Perth, ND 58363',18816,222,NULL,34,26067,0);
INSERT INTO "django_geo_db_location" VALUES(45177,NULL,'Rocklake, ND',18817,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45178,NULL,'Rocklake, ND 58365',18817,222,NULL,34,26068,0);
INSERT INTO "django_geo_db_location" VALUES(45179,NULL,'Rolette, ND',18818,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45180,NULL,'Rolette, ND 58366',18818,222,NULL,34,26069,0);
INSERT INTO "django_geo_db_location" VALUES(45181,NULL,'Rolla, ND',18819,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45182,NULL,'Rolla, ND 58367',18819,222,NULL,34,26070,0);
INSERT INTO "django_geo_db_location" VALUES(45183,NULL,'Rugby, ND',18820,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45184,NULL,'Rugby, ND 58368',18820,222,NULL,34,26071,0);
INSERT INTO "django_geo_db_location" VALUES(45185,NULL,'Saint John, ND',18821,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45186,NULL,'Saint John, ND 58369',18821,222,NULL,34,26072,0);
INSERT INTO "django_geo_db_location" VALUES(45187,NULL,'Saint Michael, ND',18822,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45188,NULL,'Saint Michael, ND 58370',18822,222,NULL,34,26073,0);
INSERT INTO "django_geo_db_location" VALUES(45189,NULL,'Grandfield, ND',18823,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45190,NULL,'Grandfield, ND 58371',18823,222,NULL,34,26074,0);
INSERT INTO "django_geo_db_location" VALUES(45191,NULL,'Sarles, ND',18824,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45192,NULL,'Sarles, ND 58372',18824,222,NULL,34,26075,0);
INSERT INTO "django_geo_db_location" VALUES(45193,NULL,'Sheyenne, ND',18825,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45194,NULL,'Sheyenne, ND 58374',18825,222,NULL,34,26076,0);
INSERT INTO "django_geo_db_location" VALUES(45195,NULL,'Starkweather, ND',18826,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45196,NULL,'Starkweather, ND 58377',18826,222,NULL,34,26077,0);
INSERT INTO "django_geo_db_location" VALUES(45197,NULL,'Tokio, ND',18827,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45198,NULL,'Tokio, ND 58379',18827,222,NULL,34,26078,0);
INSERT INTO "django_geo_db_location" VALUES(45199,NULL,'Tolna, ND',18828,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45200,NULL,'Tolna, ND 58380',18828,222,NULL,34,26079,0);
INSERT INTO "django_geo_db_location" VALUES(45201,NULL,'Warwick, ND',18829,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45202,NULL,'Warwick, ND 58381',18829,222,NULL,34,26080,0);
INSERT INTO "django_geo_db_location" VALUES(45203,NULL,'Webster, ND',18830,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45204,NULL,'Webster, ND 58382',18830,222,NULL,34,26081,0);
INSERT INTO "django_geo_db_location" VALUES(45205,NULL,'Willow City, ND',18831,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45206,NULL,'Willow City, ND 58384',18831,222,NULL,34,26082,0);
INSERT INTO "django_geo_db_location" VALUES(45207,NULL,'Wolford, ND',18832,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45208,NULL,'Wolford, ND 58385',18832,222,NULL,34,26083,0);
INSERT INTO "django_geo_db_location" VALUES(45209,NULL,'York, ND',18833,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45210,NULL,'York, ND 58386',18833,222,NULL,34,26084,0);
INSERT INTO "django_geo_db_location" VALUES(45211,NULL,'Jamestown, ND',18834,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45212,NULL,'Jamestown, ND 58401',18834,222,NULL,34,26085,0);
INSERT INTO "django_geo_db_location" VALUES(45213,NULL,'Jamestown, ND 58402',18834,222,NULL,34,26086,0);
INSERT INTO "django_geo_db_location" VALUES(45214,NULL,'Jamestown, ND 58405',18834,222,NULL,34,26087,0);
INSERT INTO "django_geo_db_location" VALUES(45215,NULL,'Ashley, ND',18835,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45216,NULL,'Ashley, ND 58413',18835,222,NULL,34,26088,0);
INSERT INTO "django_geo_db_location" VALUES(45217,NULL,'Berlin, ND',18836,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45218,NULL,'Berlin, ND 58415',18836,222,NULL,34,26089,0);
INSERT INTO "django_geo_db_location" VALUES(45219,NULL,'Binford, ND',18837,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45220,NULL,'Binford, ND 58416',18837,222,NULL,34,26090,0);
INSERT INTO "django_geo_db_location" VALUES(45221,NULL,'Bowdon, ND',18838,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45222,NULL,'Bowdon, ND 58418',18838,222,NULL,34,26091,0);
INSERT INTO "django_geo_db_location" VALUES(45223,NULL,'Buchanan, ND',18839,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45224,NULL,'Buchanan, ND 58420',18839,222,NULL,34,26092,0);
INSERT INTO "django_geo_db_location" VALUES(45225,NULL,'Carrington, ND',18840,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45226,NULL,'Carrington, ND 58421',18840,222,NULL,34,26093,0);
INSERT INTO "django_geo_db_location" VALUES(45227,NULL,'Cathay, ND',18841,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45228,NULL,'Cathay, ND 58422',18841,222,NULL,34,26094,0);
INSERT INTO "django_geo_db_location" VALUES(45229,NULL,'Chaseley, ND',18842,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45230,NULL,'Chaseley, ND 58423',18842,222,NULL,34,26095,0);
INSERT INTO "django_geo_db_location" VALUES(45231,NULL,'Cleveland, ND',18843,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45232,NULL,'Cleveland, ND 58424',18843,222,NULL,34,26096,0);
INSERT INTO "django_geo_db_location" VALUES(45233,NULL,'Cooperstown, ND',18844,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45234,NULL,'Cooperstown, ND 58425',18844,222,NULL,34,26097,0);
INSERT INTO "django_geo_db_location" VALUES(45235,NULL,'Courtenay, ND',18845,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45236,NULL,'Courtenay, ND 58426',18845,222,NULL,34,26098,0);
INSERT INTO "django_geo_db_location" VALUES(45237,NULL,'Dawson, ND',18846,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45238,NULL,'Dawson, ND 58428',18846,222,NULL,34,26099,0);
INSERT INTO "django_geo_db_location" VALUES(45239,NULL,'Dazey, ND',18847,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45240,NULL,'Dazey, ND 58429',18847,222,NULL,34,26100,0);
INSERT INTO "django_geo_db_location" VALUES(45241,NULL,'Denhoff, ND',18848,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45242,NULL,'Denhoff, ND 58430',18848,222,NULL,34,26101,0);
INSERT INTO "django_geo_db_location" VALUES(45243,NULL,'Dickey, ND',18849,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45244,NULL,'Dickey, ND 58431',18849,222,NULL,34,26102,0);
INSERT INTO "django_geo_db_location" VALUES(45245,NULL,'Eckelson, ND',18850,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45246,NULL,'Eckelson, ND 58432',18850,222,NULL,34,26103,0);
INSERT INTO "django_geo_db_location" VALUES(45247,NULL,'Edgeley, ND',18851,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45248,NULL,'Edgeley, ND 58433',18851,222,NULL,34,26104,0);
INSERT INTO "django_geo_db_location" VALUES(45249,NULL,'Ellendale, ND',18852,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45250,NULL,'Ellendale, ND 58436',18852,222,NULL,34,26105,0);
INSERT INTO "django_geo_db_location" VALUES(45251,NULL,'Fessenden, ND',18853,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45252,NULL,'Fessenden, ND 58438',18853,222,NULL,34,26106,0);
INSERT INTO "django_geo_db_location" VALUES(45253,NULL,'Forbes, ND',18854,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45254,NULL,'Forbes, ND 58439',18854,222,NULL,34,26107,0);
INSERT INTO "django_geo_db_location" VALUES(45255,NULL,'Fredonia, ND',18855,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45256,NULL,'Fredonia, ND 58440',18855,222,NULL,34,26108,0);
INSERT INTO "django_geo_db_location" VALUES(45257,NULL,'Fullerton, ND',18856,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45258,NULL,'Fullerton, ND 58441',18856,222,NULL,34,26109,0);
INSERT INTO "django_geo_db_location" VALUES(45259,NULL,'Gackle, ND',18857,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45260,NULL,'Gackle, ND 58442',18857,222,NULL,34,26110,0);
INSERT INTO "django_geo_db_location" VALUES(45261,NULL,'Glenfield, ND',18858,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45262,NULL,'Glenfield, ND 58443',18858,222,NULL,34,26111,0);
INSERT INTO "django_geo_db_location" VALUES(45263,NULL,'Goodrich, ND',18859,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45264,NULL,'Goodrich, ND 58444',18859,222,NULL,34,26112,0);
INSERT INTO "django_geo_db_location" VALUES(45265,NULL,'Grace City, ND',18860,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45266,NULL,'Grace City, ND 58445',18860,222,NULL,34,26113,0);
INSERT INTO "django_geo_db_location" VALUES(45267,NULL,'Hannaford, ND',18861,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45268,NULL,'Hannaford, ND 58448',18861,222,NULL,34,26114,0);
INSERT INTO "django_geo_db_location" VALUES(45269,NULL,'Hurdsfield, ND',18862,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45270,NULL,'Hurdsfield, ND 58451',18862,222,NULL,34,26115,0);
INSERT INTO "django_geo_db_location" VALUES(45271,NULL,'Jessie, ND',18863,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45272,NULL,'Jessie, ND 58452',18863,222,NULL,34,26116,0);
INSERT INTO "django_geo_db_location" VALUES(45273,NULL,'Jud, ND',18864,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45274,NULL,'Jud, ND 58454',18864,222,NULL,34,26117,0);
INSERT INTO "django_geo_db_location" VALUES(45275,NULL,'Kensal, ND',18865,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45276,NULL,'Kensal, ND 58455',18865,222,NULL,34,26118,0);
INSERT INTO "django_geo_db_location" VALUES(45277,NULL,'Kulm, ND',18866,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45278,NULL,'Kulm, ND 58456',18866,222,NULL,34,26119,0);
INSERT INTO "django_geo_db_location" VALUES(45279,NULL,'Lamoure, ND',18867,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45280,NULL,'Lamoure, ND 58458',18867,222,NULL,34,26120,0);
INSERT INTO "django_geo_db_location" VALUES(45281,NULL,'Lehr, ND',18868,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45282,NULL,'Lehr, ND 58460',18868,222,NULL,34,26121,0);
INSERT INTO "django_geo_db_location" VALUES(45283,NULL,'Litchville, ND',18869,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45284,NULL,'Litchville, ND 58461',18869,222,NULL,34,26122,0);
INSERT INTO "django_geo_db_location" VALUES(45285,NULL,'Mcclusky, ND',18870,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45286,NULL,'Mcclusky, ND 58463',18870,222,NULL,34,26123,0);
INSERT INTO "django_geo_db_location" VALUES(45287,NULL,'Mchenry, ND',18871,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45288,NULL,'Mchenry, ND 58464',18871,222,NULL,34,26124,0);
INSERT INTO "django_geo_db_location" VALUES(45289,NULL,'Marion, ND',18872,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45290,NULL,'Marion, ND 58466',18872,222,NULL,34,26125,0);
INSERT INTO "django_geo_db_location" VALUES(45291,NULL,'Medina, ND',18873,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45292,NULL,'Medina, ND 58467',18873,222,NULL,34,26126,0);
INSERT INTO "django_geo_db_location" VALUES(45293,NULL,'Montpelier, ND',18874,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45294,NULL,'Montpelier, ND 58472',18874,222,NULL,34,26127,0);
INSERT INTO "django_geo_db_location" VALUES(45295,NULL,'Oakes, ND',18875,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45296,NULL,'Oakes, ND 58474',18875,222,NULL,34,26128,0);
INSERT INTO "django_geo_db_location" VALUES(45297,NULL,'Pettibone, ND',18876,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45298,NULL,'Pettibone, ND 58475',18876,222,NULL,34,26129,0);
INSERT INTO "django_geo_db_location" VALUES(45299,NULL,'Pingree, ND',18877,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45300,NULL,'Pingree, ND 58476',18877,222,NULL,34,26130,0);
INSERT INTO "django_geo_db_location" VALUES(45301,NULL,'Regan, ND',18878,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45302,NULL,'Regan, ND 58477',18878,222,NULL,34,26131,0);
INSERT INTO "django_geo_db_location" VALUES(45303,NULL,'Robinson, ND',18879,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45304,NULL,'Robinson, ND 58478',18879,222,NULL,34,26132,0);
INSERT INTO "django_geo_db_location" VALUES(45305,NULL,'Rogers, ND',18880,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45306,NULL,'Rogers, ND 58479',18880,222,NULL,34,26133,0);
INSERT INTO "django_geo_db_location" VALUES(45307,NULL,'Sanborn, ND',18881,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45308,NULL,'Sanborn, ND 58480',18881,222,NULL,34,26134,0);
INSERT INTO "django_geo_db_location" VALUES(45309,NULL,'Spiritwood, ND',18882,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45310,NULL,'Spiritwood, ND 58481',18882,222,NULL,34,26135,0);
INSERT INTO "django_geo_db_location" VALUES(45311,NULL,'Steele, ND',18883,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45312,NULL,'Steele, ND 58482',18883,222,NULL,34,26136,0);
INSERT INTO "django_geo_db_location" VALUES(45313,NULL,'Streeter, ND',18884,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45314,NULL,'Streeter, ND 58483',18884,222,NULL,34,26137,0);
INSERT INTO "django_geo_db_location" VALUES(45315,NULL,'Sutton, ND',18885,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45316,NULL,'Sutton, ND 58484',18885,222,NULL,34,26138,0);
INSERT INTO "django_geo_db_location" VALUES(45317,NULL,'Sykeston, ND 58486',18795,222,NULL,34,26139,0);
INSERT INTO "django_geo_db_location" VALUES(45318,NULL,'Tappen, ND',18886,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45319,NULL,'Tappen, ND 58487',18886,222,NULL,34,26140,0);
INSERT INTO "django_geo_db_location" VALUES(45320,NULL,'Tuttle, ND',18887,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45321,NULL,'Tuttle, ND 58488',18887,222,NULL,34,26141,0);
INSERT INTO "django_geo_db_location" VALUES(45322,NULL,'Venturia, ND',18888,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45323,NULL,'Venturia, ND 58489',18888,222,NULL,34,26142,0);
INSERT INTO "django_geo_db_location" VALUES(45324,NULL,'Verona, ND',18889,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45325,NULL,'Verona, ND 58490',18889,222,NULL,34,26143,0);
INSERT INTO "django_geo_db_location" VALUES(45326,NULL,'Wimbledon, ND',18890,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45327,NULL,'Wimbledon, ND 58492',18890,222,NULL,34,26144,0);
INSERT INTO "django_geo_db_location" VALUES(45328,NULL,'Wing, ND',18891,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45329,NULL,'Wing, ND 58494',18891,222,NULL,34,26145,0);
INSERT INTO "django_geo_db_location" VALUES(45330,NULL,'Wishek, ND',18892,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45331,NULL,'Wishek, ND 58495',18892,222,NULL,34,26146,0);
INSERT INTO "django_geo_db_location" VALUES(45332,NULL,'Woodworth, ND',18893,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45333,NULL,'Woodworth, ND 58496',18893,222,NULL,34,26147,0);
INSERT INTO "django_geo_db_location" VALUES(45334,NULL,'Ypsilanti, ND',18894,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45335,NULL,'Ypsilanti, ND 58497',18894,222,NULL,34,26148,0);
INSERT INTO "django_geo_db_location" VALUES(45336,NULL,'Bismarck, ND',18895,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45337,NULL,'Bismarck, ND 58501',18895,222,NULL,34,26149,0);
INSERT INTO "django_geo_db_location" VALUES(45338,NULL,'Bismarck, ND 58502',18895,222,NULL,34,26150,0);
INSERT INTO "django_geo_db_location" VALUES(45339,NULL,'Bismarck, ND 58503',18895,222,NULL,34,26151,0);
INSERT INTO "django_geo_db_location" VALUES(45340,NULL,'Bismarck, ND 58504',18895,222,NULL,34,26152,0);
INSERT INTO "django_geo_db_location" VALUES(45341,NULL,'Bismarck, ND 58505',18895,222,NULL,34,26153,0);
INSERT INTO "django_geo_db_location" VALUES(45342,NULL,'Bismarck, ND 58506',18895,222,NULL,34,26154,0);
INSERT INTO "django_geo_db_location" VALUES(45343,NULL,'Bismarck, ND 58507',18895,222,NULL,34,26155,0);
INSERT INTO "django_geo_db_location" VALUES(45344,NULL,'Almont, ND',18896,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45345,NULL,'Almont, ND 58520',18896,222,NULL,34,26156,0);
INSERT INTO "django_geo_db_location" VALUES(45346,NULL,'Baldwin, ND',18897,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45347,NULL,'Baldwin, ND 58521',18897,222,NULL,34,26157,0);
INSERT INTO "django_geo_db_location" VALUES(45348,NULL,'Beulah, ND',18898,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45349,NULL,'Beulah, ND 58523',18898,222,NULL,34,26158,0);
INSERT INTO "django_geo_db_location" VALUES(45350,NULL,'Braddock, ND',18899,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45351,NULL,'Braddock, ND 58524',18899,222,NULL,34,26159,0);
INSERT INTO "django_geo_db_location" VALUES(45352,NULL,'Cannon Ball, ND',18900,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45353,NULL,'Cannon Ball, ND 58528',18900,222,NULL,34,26160,0);
INSERT INTO "django_geo_db_location" VALUES(45354,NULL,'Carson, ND',18901,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45355,NULL,'Carson, ND 58529',18901,222,NULL,34,26161,0);
INSERT INTO "django_geo_db_location" VALUES(45356,NULL,'Center, ND',18902,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45357,NULL,'Center, ND 58530',18902,222,NULL,34,26162,0);
INSERT INTO "django_geo_db_location" VALUES(45358,NULL,'Coleharbor, ND',18903,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45359,NULL,'Coleharbor, ND 58531',18903,222,NULL,34,26163,0);
INSERT INTO "django_geo_db_location" VALUES(45360,NULL,'Driscoll, ND',18904,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45361,NULL,'Driscoll, ND 58532',18904,222,NULL,34,26164,0);
INSERT INTO "django_geo_db_location" VALUES(45362,NULL,'Elgin, ND',18905,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45363,NULL,'Elgin, ND 58533',18905,222,NULL,34,26165,0);
INSERT INTO "django_geo_db_location" VALUES(45364,NULL,'Flasher, ND',18906,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45365,NULL,'Flasher, ND 58535',18906,222,NULL,34,26166,0);
INSERT INTO "django_geo_db_location" VALUES(45366,NULL,'Fort Yates, ND 58538',18812,222,NULL,34,26167,0);
INSERT INTO "django_geo_db_location" VALUES(45367,NULL,'Garrison, ND',18907,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45368,NULL,'Garrison, ND 58540',18907,222,NULL,34,26168,0);
INSERT INTO "django_geo_db_location" VALUES(45369,NULL,'Golden Valley, ND',18908,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45370,NULL,'Golden Valley, ND 58541',18908,222,NULL,34,26169,0);
INSERT INTO "django_geo_db_location" VALUES(45371,NULL,'Hague, ND',18909,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45372,NULL,'Hague, ND 58542',18909,222,NULL,34,26170,0);
INSERT INTO "django_geo_db_location" VALUES(45373,NULL,'Hazelton, ND',18910,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45374,NULL,'Hazelton, ND 58544',18910,222,NULL,34,26171,0);
INSERT INTO "django_geo_db_location" VALUES(45375,NULL,'Hazen, ND',18911,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45376,NULL,'Hazen, ND 58545',18911,222,NULL,34,26172,0);
INSERT INTO "django_geo_db_location" VALUES(45377,NULL,'Kintyre, ND',18912,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45378,NULL,'Kintyre, ND 58549',18912,222,NULL,34,26173,0);
INSERT INTO "django_geo_db_location" VALUES(45379,NULL,'Linton, ND',18913,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45380,NULL,'Linton, ND 58552',18913,222,NULL,34,26174,0);
INSERT INTO "django_geo_db_location" VALUES(45381,NULL,'Mckenzie, ND',18914,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45382,NULL,'Mckenzie, ND 58553',18914,222,NULL,34,26175,0);
INSERT INTO "django_geo_db_location" VALUES(45383,NULL,'Mandan, ND',18915,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45384,NULL,'Mandan, ND 58554',18915,222,NULL,34,26176,0);
INSERT INTO "django_geo_db_location" VALUES(45385,NULL,'Menoken, ND',18916,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45386,NULL,'Menoken, ND 58558',18916,222,NULL,34,26177,0);
INSERT INTO "django_geo_db_location" VALUES(45387,NULL,'Mercer, ND',18917,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45388,NULL,'Mercer, ND 58559',18917,222,NULL,34,26178,0);
INSERT INTO "django_geo_db_location" VALUES(45389,NULL,'Moffit, ND',18918,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45390,NULL,'Moffit, ND 58560',18918,222,NULL,34,26179,0);
INSERT INTO "django_geo_db_location" VALUES(45391,NULL,'Napoleon, ND',18919,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45392,NULL,'Napoleon, ND 58561',18919,222,NULL,34,26180,0);
INSERT INTO "django_geo_db_location" VALUES(45393,NULL,'New Leipzig, ND',18920,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45394,NULL,'New Leipzig, ND 58562',18920,222,NULL,34,26181,0);
INSERT INTO "django_geo_db_location" VALUES(45395,NULL,'New Salem, ND',18921,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45396,NULL,'New Salem, ND 58563',18921,222,NULL,34,26182,0);
INSERT INTO "django_geo_db_location" VALUES(45397,NULL,'Raleigh, ND',18922,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45398,NULL,'Raleigh, ND 58564',18922,222,NULL,34,26183,0);
INSERT INTO "django_geo_db_location" VALUES(45399,NULL,'Riverdale, ND',18923,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45400,NULL,'Riverdale, ND 58565',18923,222,NULL,34,26184,0);
INSERT INTO "django_geo_db_location" VALUES(45401,NULL,'Saint Anthony, ND',18924,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45402,NULL,'Saint Anthony, ND 58566',18924,222,NULL,34,26185,0);
INSERT INTO "django_geo_db_location" VALUES(45403,NULL,'Selfridge, ND',18925,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45404,NULL,'Selfridge, ND 58568',18925,222,NULL,34,26186,0);
INSERT INTO "django_geo_db_location" VALUES(45405,NULL,'Shields, ND',18926,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45406,NULL,'Shields, ND 58569',18926,222,NULL,34,26187,0);
INSERT INTO "django_geo_db_location" VALUES(45407,NULL,'Solen, ND',18927,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45408,NULL,'Solen, ND 58570',18927,222,NULL,34,26188,0);
INSERT INTO "django_geo_db_location" VALUES(45409,NULL,'Stanton, ND',18928,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45410,NULL,'Stanton, ND 58571',18928,222,NULL,34,26189,0);
INSERT INTO "django_geo_db_location" VALUES(45411,NULL,'Sterling, ND',18929,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45412,NULL,'Sterling, ND 58572',18929,222,NULL,34,26190,0);
INSERT INTO "django_geo_db_location" VALUES(45413,NULL,'Strasburg, ND',18930,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45414,NULL,'Strasburg, ND 58573',18930,222,NULL,34,26191,0);
INSERT INTO "django_geo_db_location" VALUES(45415,NULL,'Turtle Lake, ND',18931,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45416,NULL,'Turtle Lake, ND 58575',18931,222,NULL,34,26192,0);
INSERT INTO "django_geo_db_location" VALUES(45417,NULL,'Underwood, ND',18932,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45418,NULL,'Underwood, ND 58576',18932,222,NULL,34,26193,0);
INSERT INTO "django_geo_db_location" VALUES(45419,NULL,'Washburn, ND',18933,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45420,NULL,'Washburn, ND 58577',18933,222,NULL,34,26194,0);
INSERT INTO "django_geo_db_location" VALUES(45421,NULL,'Wilton, ND',18934,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45422,NULL,'Wilton, ND 58579',18934,222,NULL,34,26195,0);
INSERT INTO "django_geo_db_location" VALUES(45423,NULL,'Zap, ND',18935,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45424,NULL,'Zap, ND 58580',18935,222,NULL,34,26196,0);
INSERT INTO "django_geo_db_location" VALUES(45425,NULL,'Zeeland, ND',18936,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45426,NULL,'Zeeland, ND 58581',18936,222,NULL,34,26197,0);
INSERT INTO "django_geo_db_location" VALUES(45427,NULL,'Dickinson, ND',18937,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45428,NULL,'Dickinson, ND 58601',18937,222,NULL,34,26198,0);
INSERT INTO "django_geo_db_location" VALUES(45429,NULL,'Dickinson, ND 58602',18937,222,NULL,34,26199,0);
INSERT INTO "django_geo_db_location" VALUES(45430,NULL,'Amidon, ND',18938,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45431,NULL,'Amidon, ND 58620',18938,222,NULL,34,26200,0);
INSERT INTO "django_geo_db_location" VALUES(45432,NULL,'Beach, ND',18939,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45433,NULL,'Beach, ND 58621',18939,222,NULL,34,26201,0);
INSERT INTO "django_geo_db_location" VALUES(45434,NULL,'Belfield, ND',18940,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45435,NULL,'Belfield, ND 58622',18940,222,NULL,34,26202,0);
INSERT INTO "django_geo_db_location" VALUES(45436,NULL,'Bowman, ND',18941,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45437,NULL,'Bowman, ND 58623',18941,222,NULL,34,26203,0);
INSERT INTO "django_geo_db_location" VALUES(45438,NULL,'Dodge, ND',18942,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45439,NULL,'Dodge, ND 58625',18942,222,NULL,34,26204,0);
INSERT INTO "django_geo_db_location" VALUES(45440,NULL,'Dunn Center, ND',18943,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45441,NULL,'Dunn Center, ND 58626',18943,222,NULL,34,26205,0);
INSERT INTO "django_geo_db_location" VALUES(45442,NULL,'Fairfield, ND',18944,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45443,NULL,'Fairfield, ND 58627',18944,222,NULL,34,26206,0);
INSERT INTO "django_geo_db_location" VALUES(45444,NULL,'Gladstone, ND',18945,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45445,NULL,'Gladstone, ND 58630',18945,222,NULL,34,26207,0);
INSERT INTO "django_geo_db_location" VALUES(45446,NULL,'Glen Ullin, ND',18946,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45447,NULL,'Glen Ullin, ND 58631',18946,222,NULL,34,26208,0);
INSERT INTO "django_geo_db_location" VALUES(45448,NULL,'Golva, ND',18947,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45449,NULL,'Golva, ND 58632',18947,222,NULL,34,26209,0);
INSERT INTO "django_geo_db_location" VALUES(45450,NULL,'Grassy Butte, ND',18948,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45451,NULL,'Grassy Butte, ND 58634',18948,222,NULL,34,26210,0);
INSERT INTO "django_geo_db_location" VALUES(45452,NULL,'Halliday, ND',18949,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45453,NULL,'Halliday, ND 58636',18949,222,NULL,34,26211,0);
INSERT INTO "django_geo_db_location" VALUES(45454,NULL,'Hebron, ND',18950,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45455,NULL,'Hebron, ND 58638',18950,222,NULL,34,26212,0);
INSERT INTO "django_geo_db_location" VALUES(45456,NULL,'Hettinger, ND',18951,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45457,NULL,'Hettinger, ND 58639',18951,222,NULL,34,26213,0);
INSERT INTO "django_geo_db_location" VALUES(45458,NULL,'Killdeer, ND',18952,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45459,NULL,'Killdeer, ND 58640',18952,222,NULL,34,26214,0);
INSERT INTO "django_geo_db_location" VALUES(45460,NULL,'Lefor, ND',18953,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45461,NULL,'Lefor, ND 58641',18953,222,NULL,34,26215,0);
INSERT INTO "django_geo_db_location" VALUES(45462,NULL,'Manning, ND',18954,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45463,NULL,'Manning, ND 58642',18954,222,NULL,34,26216,0);
INSERT INTO "django_geo_db_location" VALUES(45464,NULL,'Marmarth, ND',18955,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45465,NULL,'Marmarth, ND 58643',18955,222,NULL,34,26217,0);
INSERT INTO "django_geo_db_location" VALUES(45466,NULL,'Marshall, ND',18956,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45467,NULL,'Marshall, ND 58644',18956,222,NULL,34,26218,0);
INSERT INTO "django_geo_db_location" VALUES(45468,NULL,'Medora, ND',18957,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45469,NULL,'Medora, ND 58645',18957,222,NULL,34,26219,0);
INSERT INTO "django_geo_db_location" VALUES(45470,NULL,'Mott, ND',18958,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45471,NULL,'Mott, ND 58646',18958,222,NULL,34,26220,0);
INSERT INTO "django_geo_db_location" VALUES(45472,NULL,'New England, ND',18959,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45473,NULL,'New England, ND 58647',18959,222,NULL,34,26221,0);
INSERT INTO "django_geo_db_location" VALUES(45474,NULL,'Reeder, ND',18960,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45475,NULL,'Reeder, ND 58649',18960,222,NULL,34,26222,0);
INSERT INTO "django_geo_db_location" VALUES(45476,NULL,'Regent, ND',18961,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45477,NULL,'Regent, ND 58650',18961,222,NULL,34,26223,0);
INSERT INTO "django_geo_db_location" VALUES(45478,NULL,'Rhame, ND',18962,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45479,NULL,'Rhame, ND 58651',18962,222,NULL,34,26224,0);
INSERT INTO "django_geo_db_location" VALUES(45480,NULL,'Richardton, ND',18963,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45481,NULL,'Richardton, ND 58652',18963,222,NULL,34,26225,0);
INSERT INTO "django_geo_db_location" VALUES(45482,NULL,'Scranton, ND',18964,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45483,NULL,'Scranton, ND 58653',18964,222,NULL,34,26226,0);
INSERT INTO "django_geo_db_location" VALUES(45484,NULL,'Sentinel Butte, ND',18965,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45485,NULL,'Sentinel Butte, ND 58654',18965,222,NULL,34,26227,0);
INSERT INTO "django_geo_db_location" VALUES(45486,NULL,'South Heart, ND',18966,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45487,NULL,'South Heart, ND 58655',18966,222,NULL,34,26228,0);
INSERT INTO "django_geo_db_location" VALUES(45488,NULL,'Taylor, ND',18967,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45489,NULL,'Taylor, ND 58656',18967,222,NULL,34,26229,0);
INSERT INTO "django_geo_db_location" VALUES(45490,NULL,'Dodge, ND 58673',18942,222,NULL,34,26230,0);
INSERT INTO "django_geo_db_location" VALUES(45491,NULL,'Minot, ND 58701',18656,222,NULL,34,26231,0);
INSERT INTO "django_geo_db_location" VALUES(45492,NULL,'Minot, ND 58702',18656,222,NULL,34,26232,0);
INSERT INTO "django_geo_db_location" VALUES(45493,NULL,'Minot, ND 58703',18656,222,NULL,34,26233,0);
INSERT INTO "django_geo_db_location" VALUES(45494,NULL,'Minot AFB, ND',18968,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45495,NULL,'Minot AFB, ND 58704',18968,222,NULL,34,26234,0);
INSERT INTO "django_geo_db_location" VALUES(45496,NULL,'Minot AFB, ND 58705',18968,222,NULL,34,26235,0);
INSERT INTO "django_geo_db_location" VALUES(45497,NULL,'Minot, ND 58707',18656,222,NULL,34,26236,0);
INSERT INTO "django_geo_db_location" VALUES(45498,NULL,'Anamoose, ND',18969,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45499,NULL,'Anamoose, ND 58710',18969,222,NULL,34,26237,0);
INSERT INTO "django_geo_db_location" VALUES(45500,NULL,'Antler, ND',18970,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45501,NULL,'Antler, ND 58711',18970,222,NULL,34,26238,0);
INSERT INTO "django_geo_db_location" VALUES(45502,NULL,'Balfour, ND',18971,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45503,NULL,'Balfour, ND 58712',18971,222,NULL,34,26239,0);
INSERT INTO "django_geo_db_location" VALUES(45504,NULL,'Bantry, ND',18972,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45505,NULL,'Bantry, ND 58713',18972,222,NULL,34,26240,0);
INSERT INTO "django_geo_db_location" VALUES(45506,NULL,'Benedict, ND',18973,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45507,NULL,'Benedict, ND 58716',18973,222,NULL,34,26241,0);
INSERT INTO "django_geo_db_location" VALUES(45508,NULL,'Berthold, ND',18974,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45509,NULL,'Berthold, ND 58718',18974,222,NULL,34,26242,0);
INSERT INTO "django_geo_db_location" VALUES(45510,NULL,'Bowbells, ND',18975,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45511,NULL,'Bowbells, ND 58721',18975,222,NULL,34,26243,0);
INSERT INTO "django_geo_db_location" VALUES(45512,NULL,'Burlington, ND',18976,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45513,NULL,'Burlington, ND 58722',18976,222,NULL,34,26244,0);
INSERT INTO "django_geo_db_location" VALUES(45514,NULL,'Butte, ND',18977,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45515,NULL,'Butte, ND 58723',18977,222,NULL,34,26245,0);
INSERT INTO "django_geo_db_location" VALUES(45516,NULL,'Carpio, ND',18978,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45517,NULL,'Carpio, ND 58725',18978,222,NULL,34,26246,0);
INSERT INTO "django_geo_db_location" VALUES(45518,NULL,'Columbus, ND',18979,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45519,NULL,'Columbus, ND 58727',18979,222,NULL,34,26247,0);
INSERT INTO "django_geo_db_location" VALUES(45520,NULL,'Crosby, ND',18980,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45521,NULL,'Crosby, ND 58730',18980,222,NULL,34,26248,0);
INSERT INTO "django_geo_db_location" VALUES(45522,NULL,'Deering, ND',18981,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45523,NULL,'Deering, ND 58731',18981,222,NULL,34,26249,0);
INSERT INTO "django_geo_db_location" VALUES(45524,NULL,'Des Lacs, ND',18982,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45525,NULL,'Des Lacs, ND 58733',18982,222,NULL,34,26250,0);
INSERT INTO "django_geo_db_location" VALUES(45526,NULL,'Donnybrook, ND',18983,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45527,NULL,'Donnybrook, ND 58734',18983,222,NULL,34,26251,0);
INSERT INTO "django_geo_db_location" VALUES(45528,NULL,'Douglas, ND',18984,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45529,NULL,'Douglas, ND 58735',18984,222,NULL,34,26252,0);
INSERT INTO "django_geo_db_location" VALUES(45530,NULL,'Drake, ND',18985,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45531,NULL,'Drake, ND 58736',18985,222,NULL,34,26253,0);
INSERT INTO "django_geo_db_location" VALUES(45532,NULL,'Flaxton, ND',18986,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45533,NULL,'Flaxton, ND 58737',18986,222,NULL,34,26254,0);
INSERT INTO "django_geo_db_location" VALUES(45534,NULL,'Glenburn, ND',18987,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45535,NULL,'Glenburn, ND 58740',18987,222,NULL,34,26255,0);
INSERT INTO "django_geo_db_location" VALUES(45536,NULL,'Granville, ND',18988,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45537,NULL,'Granville, ND 58741',18988,222,NULL,34,26256,0);
INSERT INTO "django_geo_db_location" VALUES(45538,NULL,'Karlsruhe, ND',18989,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45539,NULL,'Karlsruhe, ND 58744',18989,222,NULL,34,26257,0);
INSERT INTO "django_geo_db_location" VALUES(45540,NULL,'Kenmare, ND',18990,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45541,NULL,'Kenmare, ND 58746',18990,222,NULL,34,26258,0);
INSERT INTO "django_geo_db_location" VALUES(45542,NULL,'Kief, ND',18991,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45543,NULL,'Kief, ND 58747',18991,222,NULL,34,26259,0);
INSERT INTO "django_geo_db_location" VALUES(45544,NULL,'Kramer, ND',18992,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45545,NULL,'Kramer, ND 58748',18992,222,NULL,34,26260,0);
INSERT INTO "django_geo_db_location" VALUES(45546,NULL,'Lansford, ND',18993,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45547,NULL,'Lansford, ND 58750',18993,222,NULL,34,26261,0);
INSERT INTO "django_geo_db_location" VALUES(45548,NULL,'Lignite, ND',18994,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45549,NULL,'Lignite, ND 58752',18994,222,NULL,34,26262,0);
INSERT INTO "django_geo_db_location" VALUES(45550,NULL,'Mcgregor, ND',18995,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45551,NULL,'Mcgregor, ND 58755',18995,222,NULL,34,26263,0);
INSERT INTO "django_geo_db_location" VALUES(45552,NULL,'Makoti, ND',18996,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45553,NULL,'Makoti, ND 58756',18996,222,NULL,34,26264,0);
INSERT INTO "django_geo_db_location" VALUES(45554,NULL,'Mandaree, ND',18997,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45555,NULL,'Mandaree, ND 58757',18997,222,NULL,34,26265,0);
INSERT INTO "django_geo_db_location" VALUES(45556,NULL,'Martin, ND',18998,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45557,NULL,'Martin, ND 58758',18998,222,NULL,34,26266,0);
INSERT INTO "django_geo_db_location" VALUES(45558,NULL,'Max, ND',18999,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45559,NULL,'Max, ND 58759',18999,222,NULL,34,26267,0);
INSERT INTO "django_geo_db_location" VALUES(45560,NULL,'Maxbass, ND',19000,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45561,NULL,'Maxbass, ND 58760',19000,222,NULL,34,26268,0);
INSERT INTO "django_geo_db_location" VALUES(45562,NULL,'Mohall, ND',19001,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45563,NULL,'Mohall, ND 58761',19001,222,NULL,34,26269,0);
INSERT INTO "django_geo_db_location" VALUES(45564,NULL,'Newburg, ND',19002,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45565,NULL,'Newburg, ND 58762',19002,222,NULL,34,26270,0);
INSERT INTO "django_geo_db_location" VALUES(45566,NULL,'New Town, ND',19003,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45567,NULL,'New Town, ND 58763',19003,222,NULL,34,26271,0);
INSERT INTO "django_geo_db_location" VALUES(45568,NULL,'Clay, ND',19004,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45569,NULL,'Clay, ND 58764',19004,222,NULL,34,26272,0);
INSERT INTO "django_geo_db_location" VALUES(45570,NULL,'Noonan, ND',19005,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45571,NULL,'Noonan, ND 58765',19005,222,NULL,34,26273,0);
INSERT INTO "django_geo_db_location" VALUES(45572,NULL,'Norwich, ND',19006,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45573,NULL,'Norwich, ND 58768',19006,222,NULL,34,26274,0);
INSERT INTO "django_geo_db_location" VALUES(45574,NULL,'Palermo, ND',19007,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45575,NULL,'Palermo, ND 58769',19007,222,NULL,34,26275,0);
INSERT INTO "django_geo_db_location" VALUES(45576,NULL,'Parshall, ND',19008,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45577,NULL,'Parshall, ND 58770',19008,222,NULL,34,26276,0);
INSERT INTO "django_geo_db_location" VALUES(45578,NULL,'Plaza, ND',19009,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45579,NULL,'Plaza, ND 58771',19009,222,NULL,34,26277,0);
INSERT INTO "django_geo_db_location" VALUES(45580,NULL,'Portal, ND',19010,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45581,NULL,'Portal, ND 58772',19010,222,NULL,34,26278,0);
INSERT INTO "django_geo_db_location" VALUES(45582,NULL,'Powers Lake, ND',19011,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45583,NULL,'Powers Lake, ND 58773',19011,222,NULL,34,26279,0);
INSERT INTO "django_geo_db_location" VALUES(45584,NULL,'Roseglen, ND',19012,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45585,NULL,'Roseglen, ND 58775',19012,222,NULL,34,26280,0);
INSERT INTO "django_geo_db_location" VALUES(45586,NULL,'Ross, ND',19013,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45587,NULL,'Ross, ND 58776',19013,222,NULL,34,26281,0);
INSERT INTO "django_geo_db_location" VALUES(45588,NULL,'Ruso, ND',19014,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45589,NULL,'Ruso, ND 58778',19014,222,NULL,34,26282,0);
INSERT INTO "django_geo_db_location" VALUES(45590,NULL,'Ryder, ND',19015,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45591,NULL,'Ryder, ND 58779',19015,222,NULL,34,26283,0);
INSERT INTO "django_geo_db_location" VALUES(45592,NULL,'Sawyer, ND',19016,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45593,NULL,'Sawyer, ND 58781',19016,222,NULL,34,26284,0);
INSERT INTO "django_geo_db_location" VALUES(45594,NULL,'Sherwood, ND',19017,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45595,NULL,'Sherwood, ND 58782',19017,222,NULL,34,26285,0);
INSERT INTO "django_geo_db_location" VALUES(45596,NULL,'Souris, ND',19018,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45597,NULL,'Souris, ND 58783',19018,222,NULL,34,26286,0);
INSERT INTO "django_geo_db_location" VALUES(45598,NULL,'Stanley, ND',19019,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45599,NULL,'Stanley, ND 58784',19019,222,NULL,34,26287,0);
INSERT INTO "django_geo_db_location" VALUES(45600,NULL,'Surrey, ND',19020,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45601,NULL,'Surrey, ND 58785',19020,222,NULL,34,26288,0);
INSERT INTO "django_geo_db_location" VALUES(45602,NULL,'Tolley, ND',19021,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45603,NULL,'Tolley, ND 58787',19021,222,NULL,34,26289,0);
INSERT INTO "django_geo_db_location" VALUES(45604,NULL,'Towner, ND',19022,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45605,NULL,'Towner, ND 58788',19022,222,NULL,34,26290,0);
INSERT INTO "django_geo_db_location" VALUES(45606,NULL,'Upham, ND',19023,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45607,NULL,'Upham, ND 58789',19023,222,NULL,34,26291,0);
INSERT INTO "django_geo_db_location" VALUES(45608,NULL,'Velva, ND',19024,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45609,NULL,'Velva, ND 58790',19024,222,NULL,34,26292,0);
INSERT INTO "django_geo_db_location" VALUES(45610,NULL,'Voltaire, ND',19025,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45611,NULL,'Voltaire, ND 58792',19025,222,NULL,34,26293,0);
INSERT INTO "django_geo_db_location" VALUES(45612,NULL,'Westhope, ND',19026,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45613,NULL,'Westhope, ND 58793',19026,222,NULL,34,26294,0);
INSERT INTO "django_geo_db_location" VALUES(45614,NULL,'White Earth, ND',19027,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45615,NULL,'White Earth, ND 58794',19027,222,NULL,34,26295,0);
INSERT INTO "django_geo_db_location" VALUES(45616,NULL,'Wildrose, ND',19028,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45617,NULL,'Wildrose, ND 58795',19028,222,NULL,34,26296,0);
INSERT INTO "django_geo_db_location" VALUES(45618,NULL,'Williston, ND',19029,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45619,NULL,'Williston, ND 58801',19029,222,NULL,34,26297,0);
INSERT INTO "django_geo_db_location" VALUES(45620,NULL,'Williston, ND 58802',19029,222,NULL,34,26298,0);
INSERT INTO "django_geo_db_location" VALUES(45621,NULL,'Alamo, ND',19030,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45622,NULL,'Alamo, ND 58830',19030,222,NULL,34,26299,0);
INSERT INTO "django_geo_db_location" VALUES(45623,NULL,'Alexander, ND',19031,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45624,NULL,'Alexander, ND 58831',19031,222,NULL,34,26300,0);
INSERT INTO "django_geo_db_location" VALUES(45625,NULL,'Westby, ND',19032,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45626,NULL,'Westby, ND 58832',19032,222,NULL,34,26301,0);
INSERT INTO "django_geo_db_location" VALUES(45627,NULL,'Ambrose, ND',19033,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45628,NULL,'Ambrose, ND 58833',19033,222,NULL,34,26302,0);
INSERT INTO "django_geo_db_location" VALUES(45629,NULL,'Arnegard, ND',19034,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45630,NULL,'Arnegard, ND 58835',19034,222,NULL,34,26303,0);
INSERT INTO "django_geo_db_location" VALUES(45631,NULL,'Cartwright, ND',19035,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45632,NULL,'Cartwright, ND 58838',19035,222,NULL,34,26304,0);
INSERT INTO "django_geo_db_location" VALUES(45633,NULL,'Epping, ND',19036,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45634,NULL,'Epping, ND 58843',19036,222,NULL,34,26305,0);
INSERT INTO "django_geo_db_location" VALUES(45635,NULL,'Fortuna, ND',19037,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45636,NULL,'Fortuna, ND 58844',19037,222,NULL,34,26306,0);
INSERT INTO "django_geo_db_location" VALUES(45637,NULL,'Grenora, ND',19038,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45638,NULL,'Grenora, ND 58845',19038,222,NULL,34,26307,0);
INSERT INTO "django_geo_db_location" VALUES(45639,NULL,'Keene, ND',19039,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45640,NULL,'Keene, ND 58847',19039,222,NULL,34,26308,0);
INSERT INTO "django_geo_db_location" VALUES(45641,NULL,'Ray, ND',19040,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45642,NULL,'Ray, ND 58849',19040,222,NULL,34,26309,0);
INSERT INTO "django_geo_db_location" VALUES(45643,NULL,'Tioga, ND',19041,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45644,NULL,'Tioga, ND 58852',19041,222,NULL,34,26310,0);
INSERT INTO "django_geo_db_location" VALUES(45645,NULL,'Trenton, ND',19042,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45646,NULL,'Trenton, ND 58853',19042,222,NULL,34,26311,0);
INSERT INTO "django_geo_db_location" VALUES(45647,NULL,'Watford City, ND',19043,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45648,NULL,'Watford City, ND 58854',19043,222,NULL,34,26312,0);
INSERT INTO "django_geo_db_location" VALUES(45649,NULL,'Zahl, ND',19044,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45650,NULL,'Zahl, ND 58856',19044,222,NULL,34,26313,0);
INSERT INTO "django_geo_db_location" VALUES(45651,NULL,'Garrison, ND 58888',18907,222,NULL,34,26314,0);
INSERT INTO "django_geo_db_location" VALUES(45652,NULL,'Colquhoun, ND',19045,222,NULL,34,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45653,NULL,'Colquhoun, ND 58982',19045,222,NULL,34,26315,0);
INSERT INTO "django_geo_db_location" VALUES(45654,NULL,'Roundup, MT',19046,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45655,NULL,'Roundup, MT 59000',19046,222,NULL,26,26316,0);
INSERT INTO "django_geo_db_location" VALUES(45656,NULL,'Absarokee, MT',19047,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45657,NULL,'Absarokee, MT 59001',19047,222,NULL,26,26317,0);
INSERT INTO "django_geo_db_location" VALUES(45658,NULL,'Acton, MT',19048,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45659,NULL,'Acton, MT 59002',19048,222,NULL,26,26318,0);
INSERT INTO "django_geo_db_location" VALUES(45660,NULL,'Ashland, MT',19049,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45661,NULL,'Ashland, MT 59003',19049,222,NULL,26,26319,0);
INSERT INTO "django_geo_db_location" VALUES(45662,NULL,'Ashland, MT 59004',19049,222,NULL,26,26320,0);
INSERT INTO "django_geo_db_location" VALUES(45663,NULL,'Ballantine, MT',19050,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45664,NULL,'Ballantine, MT 59006',19050,222,NULL,26,26321,0);
INSERT INTO "django_geo_db_location" VALUES(45665,NULL,'Bearcreek, MT',19051,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45666,NULL,'Bearcreek, MT 59007',19051,222,NULL,26,26322,0);
INSERT INTO "django_geo_db_location" VALUES(45667,NULL,'Belfry, MT',19052,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45668,NULL,'Belfry, MT 59008',19052,222,NULL,26,26323,0);
INSERT INTO "django_geo_db_location" VALUES(45669,NULL,'Bighorn, MT',19053,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45670,NULL,'Bighorn, MT 59010',19053,222,NULL,26,26324,0);
INSERT INTO "django_geo_db_location" VALUES(45671,NULL,'Big Timber, MT',19054,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45672,NULL,'Big Timber, MT 59011',19054,222,NULL,26,26325,0);
INSERT INTO "django_geo_db_location" VALUES(45673,NULL,'Birney, MT',19055,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45674,NULL,'Birney, MT 59012',19055,222,NULL,26,26326,0);
INSERT INTO "django_geo_db_location" VALUES(45675,NULL,'Boyd, MT',19056,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45676,NULL,'Boyd, MT 59013',19056,222,NULL,26,26327,0);
INSERT INTO "django_geo_db_location" VALUES(45677,NULL,'Bridger, MT',19057,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45678,NULL,'Bridger, MT 59014',19057,222,NULL,26,26328,0);
INSERT INTO "django_geo_db_location" VALUES(45679,NULL,'Broadview, MT',19058,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45680,NULL,'Broadview, MT 59015',19058,222,NULL,26,26329,0);
INSERT INTO "django_geo_db_location" VALUES(45681,NULL,'Busby, MT',19059,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45682,NULL,'Busby, MT 59016',19059,222,NULL,26,26330,0);
INSERT INTO "django_geo_db_location" VALUES(45683,NULL,'Clyde Park, MT',19060,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45684,NULL,'Clyde Park, MT 59018',19060,222,NULL,26,26331,0);
INSERT INTO "django_geo_db_location" VALUES(45685,NULL,'Columbus, MT',19061,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45686,NULL,'Columbus, MT 59019',19061,222,NULL,26,26332,0);
INSERT INTO "django_geo_db_location" VALUES(45687,NULL,'Cooke City, MT',19062,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45688,NULL,'Cooke City, MT 59020',19062,222,NULL,26,26333,0);
INSERT INTO "django_geo_db_location" VALUES(45689,NULL,'Crow Agency, MT',19063,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45690,NULL,'Crow Agency, MT 59022',19063,222,NULL,26,26334,0);
INSERT INTO "django_geo_db_location" VALUES(45691,NULL,'Custer, MT',19064,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45692,NULL,'Custer, MT 59024',19064,222,NULL,26,26335,0);
INSERT INTO "django_geo_db_location" VALUES(45693,NULL,'Decker, MT',19065,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45694,NULL,'Decker, MT 59025',19065,222,NULL,26,26336,0);
INSERT INTO "django_geo_db_location" VALUES(45695,NULL,'Edgar, MT',19066,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45696,NULL,'Edgar, MT 59026',19066,222,NULL,26,26337,0);
INSERT INTO "django_geo_db_location" VALUES(45697,NULL,'Emigrant, MT',19067,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45698,NULL,'Emigrant, MT 59027',19067,222,NULL,26,26338,0);
INSERT INTO "django_geo_db_location" VALUES(45699,NULL,'Fishtail, MT',19068,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45700,NULL,'Fishtail, MT 59028',19068,222,NULL,26,26339,0);
INSERT INTO "django_geo_db_location" VALUES(45701,NULL,'Fromberg, MT',19069,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45702,NULL,'Fromberg, MT 59029',19069,222,NULL,26,26340,0);
INSERT INTO "django_geo_db_location" VALUES(45703,NULL,'Gardiner, MT',19070,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45704,NULL,'Gardiner, MT 59030',19070,222,NULL,26,26341,0);
INSERT INTO "django_geo_db_location" VALUES(45705,NULL,'Garryowen, MT',19071,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45706,NULL,'Garryowen, MT 59031',19071,222,NULL,26,26342,0);
INSERT INTO "django_geo_db_location" VALUES(45707,NULL,'Grass Range, MT',19072,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45708,NULL,'Grass Range, MT 59032',19072,222,NULL,26,26343,0);
INSERT INTO "django_geo_db_location" VALUES(45709,NULL,'Greycliff, MT',19073,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45710,NULL,'Greycliff, MT 59033',19073,222,NULL,26,26344,0);
INSERT INTO "django_geo_db_location" VALUES(45711,NULL,'Hardin, MT',19074,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45712,NULL,'Hardin, MT 59034',19074,222,NULL,26,26345,0);
INSERT INTO "django_geo_db_location" VALUES(45713,NULL,'Yellowtail, MT',19075,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45714,NULL,'Yellowtail, MT 59035',19075,222,NULL,26,26346,0);
INSERT INTO "django_geo_db_location" VALUES(45715,NULL,'Harlowton, MT',19076,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45716,NULL,'Harlowton, MT 59036',19076,222,NULL,26,26347,0);
INSERT INTO "django_geo_db_location" VALUES(45717,NULL,'Huntley, MT',19077,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45718,NULL,'Huntley, MT 59037',19077,222,NULL,26,26348,0);
INSERT INTO "django_geo_db_location" VALUES(45719,NULL,'Hysham, MT',19078,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45720,NULL,'Hysham, MT 59038',19078,222,NULL,26,26349,0);
INSERT INTO "django_geo_db_location" VALUES(45721,NULL,'Ingomar, MT',19079,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45722,NULL,'Ingomar, MT 59039',19079,222,NULL,26,26350,0);
INSERT INTO "django_geo_db_location" VALUES(45723,NULL,'Joliet, MT',19080,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45724,NULL,'Joliet, MT 59041',19080,222,NULL,26,26351,0);
INSERT INTO "django_geo_db_location" VALUES(45725,NULL,'Lame Deer, MT',19081,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45726,NULL,'Lame Deer, MT 59043',19081,222,NULL,26,26352,0);
INSERT INTO "django_geo_db_location" VALUES(45727,NULL,'Laurel, MT',19082,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45728,NULL,'Laurel, MT 59044',19082,222,NULL,26,26353,0);
INSERT INTO "django_geo_db_location" VALUES(45729,NULL,'Lavina, MT',19083,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45730,NULL,'Lavina, MT 59046',19083,222,NULL,26,26354,0);
INSERT INTO "django_geo_db_location" VALUES(45731,NULL,'Livingston, MT',19084,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45732,NULL,'Livingston, MT 59047',19084,222,NULL,26,26355,0);
INSERT INTO "django_geo_db_location" VALUES(45733,NULL,'Lodge Grass, MT',19085,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45734,NULL,'Lodge Grass, MT 59050',19085,222,NULL,26,26356,0);
INSERT INTO "django_geo_db_location" VALUES(45735,NULL,'McLeod, MT',19086,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45736,NULL,'McLeod, MT 59052',19086,222,NULL,26,26357,0);
INSERT INTO "django_geo_db_location" VALUES(45737,NULL,'Martinsdale, MT',19087,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45738,NULL,'Martinsdale, MT 59053',19087,222,NULL,26,26358,0);
INSERT INTO "django_geo_db_location" VALUES(45739,NULL,'Melstone, MT',19088,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45740,NULL,'Melstone, MT 59054',19088,222,NULL,26,26359,0);
INSERT INTO "django_geo_db_location" VALUES(45741,NULL,'Melville, MT',19089,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45742,NULL,'Melville, MT 59055',19089,222,NULL,26,26360,0);
INSERT INTO "django_geo_db_location" VALUES(45743,NULL,'Molt, MT',19090,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45744,NULL,'Molt, MT 59057',19090,222,NULL,26,26361,0);
INSERT INTO "django_geo_db_location" VALUES(45745,NULL,'Mosby, MT',19091,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45746,NULL,'Mosby, MT 59058',19091,222,NULL,26,26362,0);
INSERT INTO "django_geo_db_location" VALUES(45747,NULL,'Musselshell, MT',19092,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45748,NULL,'Musselshell, MT 59059',19092,222,NULL,26,26363,0);
INSERT INTO "django_geo_db_location" VALUES(45749,NULL,'Nye, MT',19093,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45750,NULL,'Nye, MT 59061',19093,222,NULL,26,26364,0);
INSERT INTO "django_geo_db_location" VALUES(45751,NULL,'Otter, MT',19094,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45752,NULL,'Otter, MT 59062',19094,222,NULL,26,26365,0);
INSERT INTO "django_geo_db_location" VALUES(45753,NULL,'Park City, MT',19095,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45754,NULL,'Park City, MT 59063',19095,222,NULL,26,26366,0);
INSERT INTO "django_geo_db_location" VALUES(45755,NULL,'Pompeys Pillar, MT',19096,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45756,NULL,'Pompeys Pillar, MT 59064',19096,222,NULL,26,26367,0);
INSERT INTO "django_geo_db_location" VALUES(45757,NULL,'Pray, MT',19097,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45758,NULL,'Pray, MT 59065',19097,222,NULL,26,26368,0);
INSERT INTO "django_geo_db_location" VALUES(45759,NULL,'Pryor, MT',19098,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45760,NULL,'Pryor, MT 59066',19098,222,NULL,26,26369,0);
INSERT INTO "django_geo_db_location" VALUES(45761,NULL,'Rapelje, MT',19099,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45762,NULL,'Rapelje, MT 59067',19099,222,NULL,26,26370,0);
INSERT INTO "django_geo_db_location" VALUES(45763,NULL,'Red Lodge, MT',19100,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45764,NULL,'Red Lodge, MT 59068',19100,222,NULL,26,26371,0);
INSERT INTO "django_geo_db_location" VALUES(45765,NULL,'Reed Point, MT',19101,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45766,NULL,'Reed Point, MT 59069',19101,222,NULL,26,26372,0);
INSERT INTO "django_geo_db_location" VALUES(45767,NULL,'Roberts, MT',19102,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45768,NULL,'Roberts, MT 59070',19102,222,NULL,26,26373,0);
INSERT INTO "django_geo_db_location" VALUES(45769,NULL,'Roscoe, MT',19103,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45770,NULL,'Roscoe, MT 59071',19103,222,NULL,26,26374,0);
INSERT INTO "django_geo_db_location" VALUES(45771,NULL,'Roundup, MT 59072',19046,222,NULL,26,26375,0);
INSERT INTO "django_geo_db_location" VALUES(45772,NULL,'Roundup, MT 59073',19046,222,NULL,26,26376,0);
INSERT INTO "django_geo_db_location" VALUES(45773,NULL,'Ryegate, MT',19104,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45774,NULL,'Ryegate, MT 59074',19104,222,NULL,26,26377,0);
INSERT INTO "django_geo_db_location" VALUES(45775,NULL,'Saint Xavier, MT',19105,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45776,NULL,'Saint Xavier, MT 59075',19105,222,NULL,26,26378,0);
INSERT INTO "django_geo_db_location" VALUES(45777,NULL,'Sanders, MT',19106,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45778,NULL,'Sanders, MT 59076',19106,222,NULL,26,26379,0);
INSERT INTO "django_geo_db_location" VALUES(45779,NULL,'Sand Springs, MT',19107,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45780,NULL,'Sand Springs, MT 59077',19107,222,NULL,26,26380,0);
INSERT INTO "django_geo_db_location" VALUES(45781,NULL,'Shawmut, MT',19108,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45782,NULL,'Shawmut, MT 59078',19108,222,NULL,26,26381,0);
INSERT INTO "django_geo_db_location" VALUES(45783,NULL,'Shepherd, MT',19109,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45784,NULL,'Shepherd, MT 59079',19109,222,NULL,26,26382,0);
INSERT INTO "django_geo_db_location" VALUES(45785,NULL,'Silver Gate, MT',19110,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45786,NULL,'Silver Gate, MT 59081',19110,222,NULL,26,26383,0);
INSERT INTO "django_geo_db_location" VALUES(45787,NULL,'Springdale, MT',19111,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45788,NULL,'Springdale, MT 59082',19111,222,NULL,26,26384,0);
INSERT INTO "django_geo_db_location" VALUES(45789,NULL,'Sumatra, MT',19112,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45790,NULL,'Sumatra, MT 59083',19112,222,NULL,26,26385,0);
INSERT INTO "django_geo_db_location" VALUES(45791,NULL,'Teigen, MT',19113,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45792,NULL,'Teigen, MT 59084',19113,222,NULL,26,26386,0);
INSERT INTO "django_geo_db_location" VALUES(45793,NULL,'Two Dot, MT',19114,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45794,NULL,'Two Dot, MT 59085',19114,222,NULL,26,26387,0);
INSERT INTO "django_geo_db_location" VALUES(45795,NULL,'Wilsall, MT',19115,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45796,NULL,'Wilsall, MT 59086',19115,222,NULL,26,26388,0);
INSERT INTO "django_geo_db_location" VALUES(45797,NULL,'Winnett, MT',19116,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45798,NULL,'Winnett, MT 59087',19116,222,NULL,26,26389,0);
INSERT INTO "django_geo_db_location" VALUES(45799,NULL,'Worden, MT',19117,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45800,NULL,'Worden, MT 59088',19117,222,NULL,26,26390,0);
INSERT INTO "django_geo_db_location" VALUES(45801,NULL,'Wyola, MT',19118,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45802,NULL,'Wyola, MT 59089',19118,222,NULL,26,26391,0);
INSERT INTO "django_geo_db_location" VALUES(45803,NULL,'Billings, MT',19119,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45804,NULL,'Billings, MT 59101',19119,222,NULL,26,26392,0);
INSERT INTO "django_geo_db_location" VALUES(45805,NULL,'Billings, MT 59102',19119,222,NULL,26,26393,0);
INSERT INTO "django_geo_db_location" VALUES(45806,NULL,'Billings, MT 59103',19119,222,NULL,26,26394,0);
INSERT INTO "django_geo_db_location" VALUES(45807,NULL,'Billings, MT 59104',19119,222,NULL,26,26395,0);
INSERT INTO "django_geo_db_location" VALUES(45808,NULL,'Billings, MT 59105',19119,222,NULL,26,26396,0);
INSERT INTO "django_geo_db_location" VALUES(45809,NULL,'Billings, MT 59106',19119,222,NULL,26,26397,0);
INSERT INTO "django_geo_db_location" VALUES(45810,NULL,'Billings, MT 59107',19119,222,NULL,26,26398,0);
INSERT INTO "django_geo_db_location" VALUES(45811,NULL,'Billings, MT 59108',19119,222,NULL,26,26399,0);
INSERT INTO "django_geo_db_location" VALUES(45812,NULL,'Billings, MT 59111',19119,222,NULL,26,26400,0);
INSERT INTO "django_geo_db_location" VALUES(45813,NULL,'Billings, MT 59112',19119,222,NULL,26,26401,0);
INSERT INTO "django_geo_db_location" VALUES(45814,NULL,'Billings, MT 59114',19119,222,NULL,26,26402,0);
INSERT INTO "django_geo_db_location" VALUES(45815,NULL,'Billings, MT 59115',19119,222,NULL,26,26403,0);
INSERT INTO "django_geo_db_location" VALUES(45816,NULL,'Billings, MT 59116',19119,222,NULL,26,26404,0);
INSERT INTO "django_geo_db_location" VALUES(45817,NULL,'Billings, MT 59117',19119,222,NULL,26,26405,0);
INSERT INTO "django_geo_db_location" VALUES(45818,NULL,'Wolf Point, MT',19120,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45819,NULL,'Wolf Point, MT 59201',19120,222,NULL,26,26406,0);
INSERT INTO "django_geo_db_location" VALUES(45820,NULL,'Antelope, MT',19121,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45821,NULL,'Antelope, MT 59211',19121,222,NULL,26,26407,0);
INSERT INTO "django_geo_db_location" VALUES(45822,NULL,'Bainville, MT',19122,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45823,NULL,'Bainville, MT 59212',19122,222,NULL,26,26408,0);
INSERT INTO "django_geo_db_location" VALUES(45824,NULL,'Brockton, MT',19123,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45825,NULL,'Brockton, MT 59213',19123,222,NULL,26,26409,0);
INSERT INTO "django_geo_db_location" VALUES(45826,NULL,'Brockway, MT',19124,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45827,NULL,'Brockway, MT 59214',19124,222,NULL,26,26410,0);
INSERT INTO "django_geo_db_location" VALUES(45828,NULL,'Circle, MT',19125,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45829,NULL,'Circle, MT 59215',19125,222,NULL,26,26411,0);
INSERT INTO "django_geo_db_location" VALUES(45830,NULL,'Crane, MT',19126,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45831,NULL,'Crane, MT 59217',19126,222,NULL,26,26412,0);
INSERT INTO "django_geo_db_location" VALUES(45832,NULL,'Culbertson, MT',19127,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45833,NULL,'Culbertson, MT 59218',19127,222,NULL,26,26413,0);
INSERT INTO "django_geo_db_location" VALUES(45834,NULL,'Dagmar, MT',19128,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45835,NULL,'Dagmar, MT 59219',19128,222,NULL,26,26414,0);
INSERT INTO "django_geo_db_location" VALUES(45836,NULL,'Fairview, MT',19129,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45837,NULL,'Fairview, MT 59221',19129,222,NULL,26,26415,0);
INSERT INTO "django_geo_db_location" VALUES(45838,NULL,'Flaxville, MT',19130,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45839,NULL,'Flaxville, MT 59222',19130,222,NULL,26,26416,0);
INSERT INTO "django_geo_db_location" VALUES(45840,NULL,'Fort Peck, MT',19131,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45841,NULL,'Fort Peck, MT 59223',19131,222,NULL,26,26417,0);
INSERT INTO "django_geo_db_location" VALUES(45842,NULL,'Frazer, MT',19132,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45843,NULL,'Frazer, MT 59225',19132,222,NULL,26,26418,0);
INSERT INTO "django_geo_db_location" VALUES(45844,NULL,'Froid, MT',19133,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45845,NULL,'Froid, MT 59226',19133,222,NULL,26,26419,0);
INSERT INTO "django_geo_db_location" VALUES(45846,NULL,'Glasgow, MT',19134,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45847,NULL,'Glasgow, MT 59230',19134,222,NULL,26,26420,0);
INSERT INTO "django_geo_db_location" VALUES(45848,NULL,'Saint Marie, MT',19135,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45849,NULL,'Saint Marie, MT 59231',19135,222,NULL,26,26421,0);
INSERT INTO "django_geo_db_location" VALUES(45850,NULL,'Glentana, MT',19136,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45851,NULL,'Glentana, MT 59240',19136,222,NULL,26,26422,0);
INSERT INTO "django_geo_db_location" VALUES(45852,NULL,'Hinsdale, MT',19137,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45853,NULL,'Hinsdale, MT 59241',19137,222,NULL,26,26423,0);
INSERT INTO "django_geo_db_location" VALUES(45854,NULL,'Homestead, MT',19138,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45855,NULL,'Homestead, MT 59242',19138,222,NULL,26,26424,0);
INSERT INTO "django_geo_db_location" VALUES(45856,NULL,'Lambert, MT',19139,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45857,NULL,'Lambert, MT 59243',19139,222,NULL,26,26425,0);
INSERT INTO "django_geo_db_location" VALUES(45858,NULL,'Larslan, MT',19140,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45859,NULL,'Larslan, MT 59244',19140,222,NULL,26,26426,0);
INSERT INTO "django_geo_db_location" VALUES(45860,NULL,'McCabe, MT',19141,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45861,NULL,'McCabe, MT 59245',19141,222,NULL,26,26427,0);
INSERT INTO "django_geo_db_location" VALUES(45862,NULL,'Medicine Lake, MT',19142,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45863,NULL,'Medicine Lake, MT 59247',19142,222,NULL,26,26428,0);
INSERT INTO "django_geo_db_location" VALUES(45864,NULL,'Nashua, MT',19143,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45865,NULL,'Nashua, MT 59248',19143,222,NULL,26,26429,0);
INSERT INTO "django_geo_db_location" VALUES(45866,NULL,'Opheim, MT',19144,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45867,NULL,'Opheim, MT 59250',19144,222,NULL,26,26430,0);
INSERT INTO "django_geo_db_location" VALUES(45868,NULL,'Outlook, MT',19145,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45869,NULL,'Outlook, MT 59252',19145,222,NULL,26,26431,0);
INSERT INTO "django_geo_db_location" VALUES(45870,NULL,'Peerless, MT',19146,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45871,NULL,'Peerless, MT 59253',19146,222,NULL,26,26432,0);
INSERT INTO "django_geo_db_location" VALUES(45872,NULL,'Plentywood, MT',19147,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45873,NULL,'Plentywood, MT 59254',19147,222,NULL,26,26433,0);
INSERT INTO "django_geo_db_location" VALUES(45874,NULL,'Poplar, MT',19148,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45875,NULL,'Poplar, MT 59255',19148,222,NULL,26,26434,0);
INSERT INTO "django_geo_db_location" VALUES(45876,NULL,'Raymond, MT',19149,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45877,NULL,'Raymond, MT 59256',19149,222,NULL,26,26435,0);
INSERT INTO "django_geo_db_location" VALUES(45878,NULL,'Redstone, MT',19150,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45879,NULL,'Redstone, MT 59257',19150,222,NULL,26,26436,0);
INSERT INTO "django_geo_db_location" VALUES(45880,NULL,'Reserve, MT',19151,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45881,NULL,'Reserve, MT 59258',19151,222,NULL,26,26437,0);
INSERT INTO "django_geo_db_location" VALUES(45882,NULL,'Richey, MT',19152,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45883,NULL,'Richey, MT 59259',19152,222,NULL,26,26438,0);
INSERT INTO "django_geo_db_location" VALUES(45884,NULL,'Richland, MT',19153,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45885,NULL,'Richland, MT 59260',19153,222,NULL,26,26439,0);
INSERT INTO "django_geo_db_location" VALUES(45886,NULL,'Saco, MT',19154,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45887,NULL,'Saco, MT 59261',19154,222,NULL,26,26440,0);
INSERT INTO "django_geo_db_location" VALUES(45888,NULL,'Savage, MT',19155,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45889,NULL,'Savage, MT 59262',19155,222,NULL,26,26441,0);
INSERT INTO "django_geo_db_location" VALUES(45890,NULL,'Scobey, MT',19156,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45891,NULL,'Scobey, MT 59263',19156,222,NULL,26,26442,0);
INSERT INTO "django_geo_db_location" VALUES(45892,NULL,'Sidney, MT',19157,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45893,NULL,'Sidney, MT 59270',19157,222,NULL,26,26443,0);
INSERT INTO "django_geo_db_location" VALUES(45894,NULL,'Vandalia, MT',19158,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45895,NULL,'Vandalia, MT 59273',19158,222,NULL,26,26444,0);
INSERT INTO "django_geo_db_location" VALUES(45896,NULL,'Vida, MT',19159,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45897,NULL,'Vida, MT 59274',19159,222,NULL,26,26445,0);
INSERT INTO "django_geo_db_location" VALUES(45898,NULL,'Westby, MT',19160,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45899,NULL,'Westby, MT 59275',19160,222,NULL,26,26446,0);
INSERT INTO "django_geo_db_location" VALUES(45900,NULL,'Whitetail, MT',19161,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45901,NULL,'Whitetail, MT 59276',19161,222,NULL,26,26447,0);
INSERT INTO "django_geo_db_location" VALUES(45902,NULL,'Miles City, MT',19162,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45903,NULL,'Miles City, MT 59301',19162,222,NULL,26,26448,0);
INSERT INTO "django_geo_db_location" VALUES(45904,NULL,'Alzada, MT',19163,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45905,NULL,'Alzada, MT 59311',19163,222,NULL,26,26449,0);
INSERT INTO "django_geo_db_location" VALUES(45906,NULL,'Angela, MT',19164,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45907,NULL,'Angela, MT 59312',19164,222,NULL,26,26450,0);
INSERT INTO "django_geo_db_location" VALUES(45908,NULL,'Baker, MT',19165,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45909,NULL,'Baker, MT 59313',19165,222,NULL,26,26451,0);
INSERT INTO "django_geo_db_location" VALUES(45910,NULL,'Biddle, MT',19166,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45911,NULL,'Biddle, MT 59314',19166,222,NULL,26,26452,0);
INSERT INTO "django_geo_db_location" VALUES(45912,NULL,'Bloomfield, MT',19167,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45913,NULL,'Bloomfield, MT 59315',19167,222,NULL,26,26453,0);
INSERT INTO "django_geo_db_location" VALUES(45914,NULL,'Boyes, MT',19168,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45915,NULL,'Boyes, MT 59316',19168,222,NULL,26,26454,0);
INSERT INTO "django_geo_db_location" VALUES(45916,NULL,'Broadus, MT',19169,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45917,NULL,'Broadus, MT 59317',19169,222,NULL,26,26455,0);
INSERT INTO "django_geo_db_location" VALUES(45918,NULL,'Brusett, MT',19170,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45919,NULL,'Brusett, MT 59318',19170,222,NULL,26,26456,0);
INSERT INTO "django_geo_db_location" VALUES(45920,NULL,'Capitol, MT',19171,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45921,NULL,'Capitol, MT 59319',19171,222,NULL,26,26457,0);
INSERT INTO "django_geo_db_location" VALUES(45922,NULL,'Cohagen, MT',19172,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45923,NULL,'Cohagen, MT 59322',19172,222,NULL,26,26458,0);
INSERT INTO "django_geo_db_location" VALUES(45924,NULL,'Colstrip, MT',19173,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45925,NULL,'Colstrip, MT 59323',19173,222,NULL,26,26459,0);
INSERT INTO "django_geo_db_location" VALUES(45926,NULL,'Ekalaka, MT',19174,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45927,NULL,'Ekalaka, MT 59324',19174,222,NULL,26,26460,0);
INSERT INTO "django_geo_db_location" VALUES(45928,NULL,'Fallon, MT',19175,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45929,NULL,'Fallon, MT 59326',19175,222,NULL,26,26461,0);
INSERT INTO "django_geo_db_location" VALUES(45930,NULL,'Forsyth, MT',19176,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45931,NULL,'Forsyth, MT 59327',19176,222,NULL,26,26462,0);
INSERT INTO "django_geo_db_location" VALUES(45932,NULL,'Glendive, MT',19177,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45933,NULL,'Glendive, MT 59330',19177,222,NULL,26,26463,0);
INSERT INTO "django_geo_db_location" VALUES(45934,NULL,'Hammond, MT',19178,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45935,NULL,'Hammond, MT 59332',19178,222,NULL,26,26464,0);
INSERT INTO "django_geo_db_location" VALUES(45936,NULL,'Hathaway, MT',19179,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45937,NULL,'Hathaway, MT 59333',19179,222,NULL,26,26465,0);
INSERT INTO "django_geo_db_location" VALUES(45938,NULL,'Ismay, MT',19180,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45939,NULL,'Ismay, MT 59336',19180,222,NULL,26,26466,0);
INSERT INTO "django_geo_db_location" VALUES(45940,NULL,'Jordan, MT',19181,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45941,NULL,'Jordan, MT 59337',19181,222,NULL,26,26467,0);
INSERT INTO "django_geo_db_location" VALUES(45942,NULL,'Kinsey, MT',19182,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45943,NULL,'Kinsey, MT 59338',19182,222,NULL,26,26468,0);
INSERT INTO "django_geo_db_location" VALUES(45944,NULL,'Lindsay, MT',19183,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45945,NULL,'Lindsay, MT 59339',19183,222,NULL,26,26469,0);
INSERT INTO "django_geo_db_location" VALUES(45946,NULL,'Mildred, MT',19184,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45947,NULL,'Mildred, MT 59341',19184,222,NULL,26,26470,0);
INSERT INTO "django_geo_db_location" VALUES(45948,NULL,'Olive, MT',19185,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45949,NULL,'Olive, MT 59343',19185,222,NULL,26,26471,0);
INSERT INTO "django_geo_db_location" VALUES(45950,NULL,'Plevna, MT',19186,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45951,NULL,'Plevna, MT 59344',19186,222,NULL,26,26472,0);
INSERT INTO "django_geo_db_location" VALUES(45952,NULL,'Powderville, MT',19187,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45953,NULL,'Powderville, MT 59345',19187,222,NULL,26,26473,0);
INSERT INTO "django_geo_db_location" VALUES(45954,NULL,'Rosebud, MT',19188,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45955,NULL,'Rosebud, MT 59347',19188,222,NULL,26,26474,0);
INSERT INTO "django_geo_db_location" VALUES(45956,NULL,'Sonnette, MT',19189,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45957,NULL,'Sonnette, MT 59348',19189,222,NULL,26,26475,0);
INSERT INTO "django_geo_db_location" VALUES(45958,NULL,'Terry, MT',19190,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45959,NULL,'Terry, MT 59349',19190,222,NULL,26,26476,0);
INSERT INTO "django_geo_db_location" VALUES(45960,NULL,'Volborg, MT',19191,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45961,NULL,'Volborg, MT 59351',19191,222,NULL,26,26477,0);
INSERT INTO "django_geo_db_location" VALUES(45962,NULL,'Wibaux, MT',19192,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45963,NULL,'Wibaux, MT 59353',19192,222,NULL,26,26478,0);
INSERT INTO "django_geo_db_location" VALUES(45964,NULL,'Willard, MT',19193,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45965,NULL,'Willard, MT 59354',19193,222,NULL,26,26479,0);
INSERT INTO "django_geo_db_location" VALUES(45966,NULL,'Shelby, MT',19194,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45967,NULL,'Shelby, MT 59400',19194,222,NULL,26,26480,0);
INSERT INTO "django_geo_db_location" VALUES(45968,NULL,'Great Falls, MT',19195,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45969,NULL,'Great Falls, MT 59401',19195,222,NULL,26,26481,0);
INSERT INTO "django_geo_db_location" VALUES(45970,NULL,'Malmstrom A F B, MT',19196,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45971,NULL,'Malmstrom A F B, MT 59402',19196,222,NULL,26,26482,0);
INSERT INTO "django_geo_db_location" VALUES(45972,NULL,'Great Falls, MT 59403',19195,222,NULL,26,26483,0);
INSERT INTO "django_geo_db_location" VALUES(45973,NULL,'Great Falls, MT 59404',19195,222,NULL,26,26484,0);
INSERT INTO "django_geo_db_location" VALUES(45974,NULL,'Great Falls, MT 59405',19195,222,NULL,26,26485,0);
INSERT INTO "django_geo_db_location" VALUES(45975,NULL,'Great Falls, MT 59406',19195,222,NULL,26,26486,0);
INSERT INTO "django_geo_db_location" VALUES(45976,NULL,'Augusta, MT',19197,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45977,NULL,'Augusta, MT 59410',19197,222,NULL,26,26487,0);
INSERT INTO "django_geo_db_location" VALUES(45978,NULL,'Babb, MT',19198,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45979,NULL,'Babb, MT 59411',19198,222,NULL,26,26488,0);
INSERT INTO "django_geo_db_location" VALUES(45980,NULL,'Belt, MT',19199,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45981,NULL,'Belt, MT 59412',19199,222,NULL,26,26489,0);
INSERT INTO "django_geo_db_location" VALUES(45982,NULL,'Black Eagle, MT',19200,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45983,NULL,'Black Eagle, MT 59414',19200,222,NULL,26,26490,0);
INSERT INTO "django_geo_db_location" VALUES(45984,NULL,'Brady, MT',19201,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45985,NULL,'Brady, MT 59416',19201,222,NULL,26,26491,0);
INSERT INTO "django_geo_db_location" VALUES(45986,NULL,'Browning, MT',19202,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45987,NULL,'Browning, MT 59417',19202,222,NULL,26,26492,0);
INSERT INTO "django_geo_db_location" VALUES(45988,NULL,'Buffalo, MT',19203,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45989,NULL,'Buffalo, MT 59418',19203,222,NULL,26,26493,0);
INSERT INTO "django_geo_db_location" VALUES(45990,NULL,'Bynum, MT',19204,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45991,NULL,'Bynum, MT 59419',19204,222,NULL,26,26494,0);
INSERT INTO "django_geo_db_location" VALUES(45992,NULL,'Carter, MT',19205,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45993,NULL,'Carter, MT 59420',19205,222,NULL,26,26495,0);
INSERT INTO "django_geo_db_location" VALUES(45994,NULL,'Cascade, MT',19206,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45995,NULL,'Cascade, MT 59421',19206,222,NULL,26,26496,0);
INSERT INTO "django_geo_db_location" VALUES(45996,NULL,'Choteau, MT',19207,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45997,NULL,'Choteau, MT 59422',19207,222,NULL,26,26497,0);
INSERT INTO "django_geo_db_location" VALUES(45998,NULL,'Coffee Creek, MT',19208,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(45999,NULL,'Coffee Creek, MT 59424',19208,222,NULL,26,26498,0);
INSERT INTO "django_geo_db_location" VALUES(46000,NULL,'Conrad, MT',19209,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46001,NULL,'Conrad, MT 59425',19209,222,NULL,26,26499,0);
INSERT INTO "django_geo_db_location" VALUES(46002,NULL,'Cut Bank, MT',19210,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46003,NULL,'Cut Bank, MT 59427',19210,222,NULL,26,26500,0);
INSERT INTO "django_geo_db_location" VALUES(46004,NULL,'Denton, MT',19211,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46005,NULL,'Denton, MT 59430',19211,222,NULL,26,26501,0);
INSERT INTO "django_geo_db_location" VALUES(46006,NULL,'Dupuyer, MT',19212,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46007,NULL,'Dupuyer, MT 59432',19212,222,NULL,26,26502,0);
INSERT INTO "django_geo_db_location" VALUES(46008,NULL,'Dutton, MT',19213,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46009,NULL,'Dutton, MT 59433',19213,222,NULL,26,26503,0);
INSERT INTO "django_geo_db_location" VALUES(46010,NULL,'East Glacier Park, MT',19214,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46011,NULL,'East Glacier Park, MT 59434',19214,222,NULL,26,26504,0);
INSERT INTO "django_geo_db_location" VALUES(46012,NULL,'Ethridge, MT',19215,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46013,NULL,'Ethridge, MT 59435',19215,222,NULL,26,26505,0);
INSERT INTO "django_geo_db_location" VALUES(46014,NULL,'Fairfield, MT',19216,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46015,NULL,'Fairfield, MT 59436',19216,222,NULL,26,26506,0);
INSERT INTO "django_geo_db_location" VALUES(46016,NULL,'Floweree, MT',19217,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46017,NULL,'Floweree, MT 59440',19217,222,NULL,26,26507,0);
INSERT INTO "django_geo_db_location" VALUES(46018,NULL,'Forestgrove, MT',19218,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46019,NULL,'Forestgrove, MT 59441',19218,222,NULL,26,26508,0);
INSERT INTO "django_geo_db_location" VALUES(46020,NULL,'Fort Benton, MT',19219,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46021,NULL,'Fort Benton, MT 59442',19219,222,NULL,26,26509,0);
INSERT INTO "django_geo_db_location" VALUES(46022,NULL,'Fort Shaw, MT',19220,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46023,NULL,'Fort Shaw, MT 59443',19220,222,NULL,26,26510,0);
INSERT INTO "django_geo_db_location" VALUES(46024,NULL,'Galata, MT',19221,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46025,NULL,'Galata, MT 59444',19221,222,NULL,26,26511,0);
INSERT INTO "django_geo_db_location" VALUES(46026,NULL,'Garneill, MT',19222,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46027,NULL,'Garneill, MT 59445',19222,222,NULL,26,26512,0);
INSERT INTO "django_geo_db_location" VALUES(46028,NULL,'Geraldine, MT',19223,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46029,NULL,'Geraldine, MT 59446',19223,222,NULL,26,26513,0);
INSERT INTO "django_geo_db_location" VALUES(46030,NULL,'Geyser, MT',19224,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46031,NULL,'Geyser, MT 59447',19224,222,NULL,26,26514,0);
INSERT INTO "django_geo_db_location" VALUES(46032,NULL,'Heart Butte, MT',19225,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46033,NULL,'Heart Butte, MT 59448',19225,222,NULL,26,26515,0);
INSERT INTO "django_geo_db_location" VALUES(46034,NULL,'Highwood, MT',19226,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46035,NULL,'Highwood, MT 59450',19226,222,NULL,26,26516,0);
INSERT INTO "django_geo_db_location" VALUES(46036,NULL,'Hilger, MT',19227,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46037,NULL,'Hilger, MT 59451',19227,222,NULL,26,26517,0);
INSERT INTO "django_geo_db_location" VALUES(46038,NULL,'Hobson, MT',19228,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46039,NULL,'Hobson, MT 59452',19228,222,NULL,26,26518,0);
INSERT INTO "django_geo_db_location" VALUES(46040,NULL,'Judith Gap, MT',19229,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46041,NULL,'Judith Gap, MT 59453',19229,222,NULL,26,26519,0);
INSERT INTO "django_geo_db_location" VALUES(46042,NULL,'Kevin, MT',19230,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46043,NULL,'Kevin, MT 59454',19230,222,NULL,26,26520,0);
INSERT INTO "django_geo_db_location" VALUES(46044,NULL,'Ledger, MT',19231,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46045,NULL,'Ledger, MT 59456',19231,222,NULL,26,26521,0);
INSERT INTO "django_geo_db_location" VALUES(46046,NULL,'Lewistown, MT',19232,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46047,NULL,'Lewistown, MT 59457',19232,222,NULL,26,26522,0);
INSERT INTO "django_geo_db_location" VALUES(46048,NULL,'Loma, MT',19233,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46049,NULL,'Loma, MT 59460',19233,222,NULL,26,26523,0);
INSERT INTO "django_geo_db_location" VALUES(46050,NULL,'Lothair, MT',19234,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46051,NULL,'Lothair, MT 59461',19234,222,NULL,26,26524,0);
INSERT INTO "django_geo_db_location" VALUES(46052,NULL,'Moccasin, MT',19235,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46053,NULL,'Moccasin, MT 59462',19235,222,NULL,26,26525,0);
INSERT INTO "django_geo_db_location" VALUES(46054,NULL,'Monarch, MT',19236,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46055,NULL,'Monarch, MT 59463',19236,222,NULL,26,26526,0);
INSERT INTO "django_geo_db_location" VALUES(46056,NULL,'Moore, MT',19237,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46057,NULL,'Moore, MT 59464',19237,222,NULL,26,26527,0);
INSERT INTO "django_geo_db_location" VALUES(46058,NULL,'Neihart, MT',19238,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46059,NULL,'Neihart, MT 59465',19238,222,NULL,26,26528,0);
INSERT INTO "django_geo_db_location" VALUES(46060,NULL,'Oilmont, MT',19239,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46061,NULL,'Oilmont, MT 59466',19239,222,NULL,26,26529,0);
INSERT INTO "django_geo_db_location" VALUES(46062,NULL,'Pendroy, MT',19240,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46063,NULL,'Pendroy, MT 59467',19240,222,NULL,26,26530,0);
INSERT INTO "django_geo_db_location" VALUES(46064,NULL,'Power, MT',19241,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46065,NULL,'Power, MT 59468',19241,222,NULL,26,26531,0);
INSERT INTO "django_geo_db_location" VALUES(46066,NULL,'Raynesford, MT',19242,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46067,NULL,'Raynesford, MT 59469',19242,222,NULL,26,26532,0);
INSERT INTO "django_geo_db_location" VALUES(46068,NULL,'Roy, MT',19243,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46069,NULL,'Roy, MT 59471',19243,222,NULL,26,26533,0);
INSERT INTO "django_geo_db_location" VALUES(46070,NULL,'Sand Coulee, MT',19244,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46071,NULL,'Sand Coulee, MT 59472',19244,222,NULL,26,26534,0);
INSERT INTO "django_geo_db_location" VALUES(46072,NULL,'Santa Rita, MT',19245,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46073,NULL,'Santa Rita, MT 59473',19245,222,NULL,26,26535,0);
INSERT INTO "django_geo_db_location" VALUES(46074,NULL,'Shelby, MT 59474',19194,222,NULL,26,26536,0);
INSERT INTO "django_geo_db_location" VALUES(46075,NULL,'Simms, MT',19246,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46076,NULL,'Simms, MT 59477',19246,222,NULL,26,26537,0);
INSERT INTO "django_geo_db_location" VALUES(46077,NULL,'Stanford, MT',19247,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46078,NULL,'Stanford, MT 59479',19247,222,NULL,26,26538,0);
INSERT INTO "django_geo_db_location" VALUES(46079,NULL,'Stockett, MT',19248,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46080,NULL,'Stockett, MT 59480',19248,222,NULL,26,26539,0);
INSERT INTO "django_geo_db_location" VALUES(46081,NULL,'Sunburst, MT',19249,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46082,NULL,'Sunburst, MT 59482',19249,222,NULL,26,26540,0);
INSERT INTO "django_geo_db_location" VALUES(46083,NULL,'Sun River, MT',19250,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46084,NULL,'Sun River, MT 59483',19250,222,NULL,26,26541,0);
INSERT INTO "django_geo_db_location" VALUES(46085,NULL,'Sweet Grass, MT',19251,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46086,NULL,'Sweet Grass, MT 59484',19251,222,NULL,26,26542,0);
INSERT INTO "django_geo_db_location" VALUES(46087,NULL,'Ulm, MT',19252,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46088,NULL,'Ulm, MT 59485',19252,222,NULL,26,26543,0);
INSERT INTO "django_geo_db_location" VALUES(46089,NULL,'Valier, MT',19253,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46090,NULL,'Valier, MT 59486',19253,222,NULL,26,26544,0);
INSERT INTO "django_geo_db_location" VALUES(46091,NULL,'Vaughn, MT',19254,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46092,NULL,'Vaughn, MT 59487',19254,222,NULL,26,26545,0);
INSERT INTO "django_geo_db_location" VALUES(46093,NULL,'Winifred, MT',19255,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46094,NULL,'Winifred, MT 59489',19255,222,NULL,26,26546,0);
INSERT INTO "django_geo_db_location" VALUES(46095,NULL,'Havre, MT',19256,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46096,NULL,'Havre, MT 59500',19256,222,NULL,26,26547,0);
INSERT INTO "django_geo_db_location" VALUES(46097,NULL,'Havre, MT 59501',19256,222,NULL,26,26548,0);
INSERT INTO "django_geo_db_location" VALUES(46098,NULL,'Big Sandy, MT',19257,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46099,NULL,'Big Sandy, MT 59520',19257,222,NULL,26,26549,0);
INSERT INTO "django_geo_db_location" VALUES(46100,NULL,'Box Elder, MT',19258,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46101,NULL,'Box Elder, MT 59521',19258,222,NULL,26,26550,0);
INSERT INTO "django_geo_db_location" VALUES(46102,NULL,'Chester, MT',19259,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46103,NULL,'Chester, MT 59522',19259,222,NULL,26,26551,0);
INSERT INTO "django_geo_db_location" VALUES(46104,NULL,'Chinook, MT',19260,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46105,NULL,'Chinook, MT 59523',19260,222,NULL,26,26552,0);
INSERT INTO "django_geo_db_location" VALUES(46106,NULL,'Dodson, MT',19261,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46107,NULL,'Dodson, MT 59524',19261,222,NULL,26,26553,0);
INSERT INTO "django_geo_db_location" VALUES(46108,NULL,'Gildford, MT',19262,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46109,NULL,'Gildford, MT 59525',19262,222,NULL,26,26554,0);
INSERT INTO "django_geo_db_location" VALUES(46110,NULL,'Harlem, MT',19263,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46111,NULL,'Harlem, MT 59526',19263,222,NULL,26,26555,0);
INSERT INTO "django_geo_db_location" VALUES(46112,NULL,'Hays, MT',19264,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46113,NULL,'Hays, MT 59527',19264,222,NULL,26,26556,0);
INSERT INTO "django_geo_db_location" VALUES(46114,NULL,'Hingham, MT',19265,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46115,NULL,'Hingham, MT 59528',19265,222,NULL,26,26557,0);
INSERT INTO "django_geo_db_location" VALUES(46116,NULL,'Hogeland, MT',19266,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46117,NULL,'Hogeland, MT 59529',19266,222,NULL,26,26558,0);
INSERT INTO "django_geo_db_location" VALUES(46118,NULL,'Inverness, MT',19267,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46119,NULL,'Inverness, MT 59530',19267,222,NULL,26,26559,0);
INSERT INTO "django_geo_db_location" VALUES(46120,NULL,'Joplin, MT',19268,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46121,NULL,'Joplin, MT 59531',19268,222,NULL,26,26560,0);
INSERT INTO "django_geo_db_location" VALUES(46122,NULL,'Kremlin, MT',19269,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46123,NULL,'Kremlin, MT 59532',19269,222,NULL,26,26561,0);
INSERT INTO "django_geo_db_location" VALUES(46124,NULL,'Lloyd, MT',19270,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46125,NULL,'Lloyd, MT 59535',19270,222,NULL,26,26562,0);
INSERT INTO "django_geo_db_location" VALUES(46126,NULL,'Loring, MT',19271,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46127,NULL,'Loring, MT 59537',19271,222,NULL,26,26563,0);
INSERT INTO "django_geo_db_location" VALUES(46128,NULL,'Malta, MT',19272,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46129,NULL,'Malta, MT 59538',19272,222,NULL,26,26564,0);
INSERT INTO "django_geo_db_location" VALUES(46130,NULL,'Rudyard, MT',19273,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46131,NULL,'Rudyard, MT 59540',19273,222,NULL,26,26565,0);
INSERT INTO "django_geo_db_location" VALUES(46132,NULL,'Turner, MT',19274,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46133,NULL,'Turner, MT 59542',19274,222,NULL,26,26566,0);
INSERT INTO "django_geo_db_location" VALUES(46134,NULL,'Whitewater, MT',19275,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46135,NULL,'Whitewater, MT 59544',19275,222,NULL,26,26567,0);
INSERT INTO "django_geo_db_location" VALUES(46136,NULL,'Whitlash, MT',19276,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46137,NULL,'Whitlash, MT 59545',19276,222,NULL,26,26568,0);
INSERT INTO "django_geo_db_location" VALUES(46138,NULL,'Zortman, MT',19277,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46139,NULL,'Zortman, MT 59546',19277,222,NULL,26,26569,0);
INSERT INTO "django_geo_db_location" VALUES(46140,NULL,'Zurich, MT',19278,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46141,NULL,'Zurich, MT 59547',19278,222,NULL,26,26570,0);
INSERT INTO "django_geo_db_location" VALUES(46142,NULL,'Helena, MT',19279,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46143,NULL,'Helena, MT 59601',19279,222,NULL,26,26571,0);
INSERT INTO "django_geo_db_location" VALUES(46144,NULL,'Helena, MT 59602',19279,222,NULL,26,26572,0);
INSERT INTO "django_geo_db_location" VALUES(46145,NULL,'Helena, MT 59604',19279,222,NULL,26,26573,0);
INSERT INTO "django_geo_db_location" VALUES(46146,NULL,'Helena, MT 59620',19279,222,NULL,26,26574,0);
INSERT INTO "django_geo_db_location" VALUES(46147,NULL,'Helena, MT 59623',19279,222,NULL,26,26575,0);
INSERT INTO "django_geo_db_location" VALUES(46148,NULL,'Helena, MT 59624',19279,222,NULL,26,26576,0);
INSERT INTO "django_geo_db_location" VALUES(46149,NULL,'Helena, MT 59625',19279,222,NULL,26,26577,0);
INSERT INTO "django_geo_db_location" VALUES(46150,NULL,'Helena, MT 59626',19279,222,NULL,26,26578,0);
INSERT INTO "django_geo_db_location" VALUES(46151,NULL,'Basin, MT',19280,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46152,NULL,'Basin, MT 59631',19280,222,NULL,26,26579,0);
INSERT INTO "django_geo_db_location" VALUES(46153,NULL,'Boulder, MT',19281,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46154,NULL,'Boulder, MT 59632',19281,222,NULL,26,26580,0);
INSERT INTO "django_geo_db_location" VALUES(46155,NULL,'Canyon Creek, MT',19282,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46156,NULL,'Canyon Creek, MT 59633',19282,222,NULL,26,26581,0);
INSERT INTO "django_geo_db_location" VALUES(46157,NULL,'Clancy, MT',19283,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46158,NULL,'Clancy, MT 59634',19283,222,NULL,26,26582,0);
INSERT INTO "django_geo_db_location" VALUES(46159,NULL,'East Helena, MT',19284,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46160,NULL,'East Helena, MT 59635',19284,222,NULL,26,26583,0);
INSERT INTO "django_geo_db_location" VALUES(46161,NULL,'Fort Harrison, MT',19285,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46162,NULL,'Fort Harrison, MT 59636',19285,222,NULL,26,26584,0);
INSERT INTO "django_geo_db_location" VALUES(46163,NULL,'Jefferson City, MT',19286,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46164,NULL,'Jefferson City, MT 59638',19286,222,NULL,26,26585,0);
INSERT INTO "django_geo_db_location" VALUES(46165,NULL,'Lincoln, MT',19287,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46166,NULL,'Lincoln, MT 59639',19287,222,NULL,26,26586,0);
INSERT INTO "django_geo_db_location" VALUES(46167,NULL,'Marysville, MT',19288,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46168,NULL,'Marysville, MT 59640',19288,222,NULL,26,26587,0);
INSERT INTO "django_geo_db_location" VALUES(46169,NULL,'Radersburg, MT',19289,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46170,NULL,'Radersburg, MT 59641',19289,222,NULL,26,26588,0);
INSERT INTO "django_geo_db_location" VALUES(46171,NULL,'Ringling, MT',19290,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46172,NULL,'Ringling, MT 59642',19290,222,NULL,26,26589,0);
INSERT INTO "django_geo_db_location" VALUES(46173,NULL,'Toston, MT',19291,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46174,NULL,'Toston, MT 59643',19291,222,NULL,26,26590,0);
INSERT INTO "django_geo_db_location" VALUES(46175,NULL,'Townsend, MT',19292,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46176,NULL,'Townsend, MT 59644',19292,222,NULL,26,26591,0);
INSERT INTO "django_geo_db_location" VALUES(46177,NULL,'White Sulphur Springs, MT',19293,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46178,NULL,'White Sulphur Springs, MT 59645',19293,222,NULL,26,26592,0);
INSERT INTO "django_geo_db_location" VALUES(46179,NULL,'Winston, MT',19294,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46180,NULL,'Winston, MT 59647',19294,222,NULL,26,26593,0);
INSERT INTO "django_geo_db_location" VALUES(46181,NULL,'Wolf Creek, MT',19295,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46182,NULL,'Wolf Creek, MT 59648',19295,222,NULL,26,26594,0);
INSERT INTO "django_geo_db_location" VALUES(46183,NULL,'Butte, MT',19296,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46184,NULL,'Butte, MT 59701',19296,222,NULL,26,26595,0);
INSERT INTO "django_geo_db_location" VALUES(46185,NULL,'Butte, MT 59702',19296,222,NULL,26,26596,0);
INSERT INTO "django_geo_db_location" VALUES(46186,NULL,'Butte, MT 59703',19296,222,NULL,26,26597,0);
INSERT INTO "django_geo_db_location" VALUES(46187,NULL,'Butte, MT 59707',19296,222,NULL,26,26598,0);
INSERT INTO "django_geo_db_location" VALUES(46188,NULL,'Alder, MT',19297,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46189,NULL,'Alder, MT 59710',19297,222,NULL,26,26599,0);
INSERT INTO "django_geo_db_location" VALUES(46190,NULL,'Anaconda, MT',19298,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46191,NULL,'Anaconda, MT 59711',19298,222,NULL,26,26600,0);
INSERT INTO "django_geo_db_location" VALUES(46192,NULL,'Avon, MT',19299,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46193,NULL,'Avon, MT 59713',19299,222,NULL,26,26601,0);
INSERT INTO "django_geo_db_location" VALUES(46194,NULL,'Belgrade, MT',19300,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46195,NULL,'Belgrade, MT 59714',19300,222,NULL,26,26602,0);
INSERT INTO "django_geo_db_location" VALUES(46196,NULL,'Bozeman, MT',19301,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46197,NULL,'Bozeman, MT 59715',19301,222,NULL,26,26603,0);
INSERT INTO "django_geo_db_location" VALUES(46198,NULL,'Big Sky, MT',19302,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46199,NULL,'Big Sky, MT 59716',19302,222,NULL,26,26604,0);
INSERT INTO "django_geo_db_location" VALUES(46200,NULL,'Bozeman, MT 59717',19301,222,NULL,26,26605,0);
INSERT INTO "django_geo_db_location" VALUES(46201,NULL,'Bozeman, MT 59718',19301,222,NULL,26,26606,0);
INSERT INTO "django_geo_db_location" VALUES(46202,NULL,'Bozeman, MT 59719',19301,222,NULL,26,26607,0);
INSERT INTO "django_geo_db_location" VALUES(46203,NULL,'Cameron, MT',19303,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46204,NULL,'Cameron, MT 59720',19303,222,NULL,26,26608,0);
INSERT INTO "django_geo_db_location" VALUES(46205,NULL,'Cardwell, MT',19304,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46206,NULL,'Cardwell, MT 59721',19304,222,NULL,26,26609,0);
INSERT INTO "django_geo_db_location" VALUES(46207,NULL,'Deer Lodge, MT',19305,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46208,NULL,'Deer Lodge, MT 59722',19305,222,NULL,26,26610,0);
INSERT INTO "django_geo_db_location" VALUES(46209,NULL,'Dell, MT',19306,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46210,NULL,'Dell, MT 59724',19306,222,NULL,26,26611,0);
INSERT INTO "django_geo_db_location" VALUES(46211,NULL,'Dillon, MT',19307,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46212,NULL,'Dillon, MT 59725',19307,222,NULL,26,26612,0);
INSERT INTO "django_geo_db_location" VALUES(46213,NULL,'Divide, MT',19308,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46214,NULL,'Divide, MT 59727',19308,222,NULL,26,26613,0);
INSERT INTO "django_geo_db_location" VALUES(46215,NULL,'Elliston, MT',19309,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46216,NULL,'Elliston, MT 59728',19309,222,NULL,26,26614,0);
INSERT INTO "django_geo_db_location" VALUES(46217,NULL,'Ennis, MT',19310,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46218,NULL,'Ennis, MT 59729',19310,222,NULL,26,26615,0);
INSERT INTO "django_geo_db_location" VALUES(46219,NULL,'Gallatin Gateway, MT',19311,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46220,NULL,'Gallatin Gateway, MT 59730',19311,222,NULL,26,26616,0);
INSERT INTO "django_geo_db_location" VALUES(46221,NULL,'Garrison, MT',19312,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46222,NULL,'Garrison, MT 59731',19312,222,NULL,26,26617,0);
INSERT INTO "django_geo_db_location" VALUES(46223,NULL,'Glen, MT',19313,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46224,NULL,'Glen, MT 59732',19313,222,NULL,26,26618,0);
INSERT INTO "django_geo_db_location" VALUES(46225,NULL,'Gold Creek, MT',19314,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46226,NULL,'Gold Creek, MT 59733',19314,222,NULL,26,26619,0);
INSERT INTO "django_geo_db_location" VALUES(46227,NULL,'Harrison, MT',19315,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46228,NULL,'Harrison, MT 59735',19315,222,NULL,26,26620,0);
INSERT INTO "django_geo_db_location" VALUES(46229,NULL,'Jackson, MT',19316,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46230,NULL,'Jackson, MT 59736',19316,222,NULL,26,26621,0);
INSERT INTO "django_geo_db_location" VALUES(46231,NULL,'Lima, MT',19317,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46232,NULL,'Lima, MT 59739',19317,222,NULL,26,26622,0);
INSERT INTO "django_geo_db_location" VALUES(46233,NULL,'McAllister, MT',19318,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46234,NULL,'McAllister, MT 59740',19318,222,NULL,26,26623,0);
INSERT INTO "django_geo_db_location" VALUES(46235,NULL,'Manhattan, MT',19319,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46236,NULL,'Manhattan, MT 59741',19319,222,NULL,26,26624,0);
INSERT INTO "django_geo_db_location" VALUES(46237,NULL,'Melrose, MT',19320,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46238,NULL,'Melrose, MT 59743',19320,222,NULL,26,26625,0);
INSERT INTO "django_geo_db_location" VALUES(46239,NULL,'Norris, MT',19321,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46240,NULL,'Norris, MT 59745',19321,222,NULL,26,26626,0);
INSERT INTO "django_geo_db_location" VALUES(46241,NULL,'Polaris, MT',19322,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46242,NULL,'Polaris, MT 59746',19322,222,NULL,26,26627,0);
INSERT INTO "django_geo_db_location" VALUES(46243,NULL,'Pony, MT',19323,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46244,NULL,'Pony, MT 59747',19323,222,NULL,26,26628,0);
INSERT INTO "django_geo_db_location" VALUES(46245,NULL,'Ramsay, MT',19324,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46246,NULL,'Ramsay, MT 59748',19324,222,NULL,26,26629,0);
INSERT INTO "django_geo_db_location" VALUES(46247,NULL,'Sheridan, MT',19325,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46248,NULL,'Sheridan, MT 59749',19325,222,NULL,26,26630,0);
INSERT INTO "django_geo_db_location" VALUES(46249,NULL,'Butte, MT 59750',19296,222,NULL,26,26631,0);
INSERT INTO "django_geo_db_location" VALUES(46250,NULL,'Silver Star, MT',19326,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46251,NULL,'Silver Star, MT 59751',19326,222,NULL,26,26632,0);
INSERT INTO "django_geo_db_location" VALUES(46252,NULL,'Three Forks, MT',19327,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46253,NULL,'Three Forks, MT 59752',19327,222,NULL,26,26633,0);
INSERT INTO "django_geo_db_location" VALUES(46254,NULL,'Twin Bridges, MT',19328,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46255,NULL,'Twin Bridges, MT 59754',19328,222,NULL,26,26634,0);
INSERT INTO "django_geo_db_location" VALUES(46256,NULL,'Virginia City, MT',19329,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46257,NULL,'Virginia City, MT 59755',19329,222,NULL,26,26635,0);
INSERT INTO "django_geo_db_location" VALUES(46258,NULL,'Warm Springs, MT',19330,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46259,NULL,'Warm Springs, MT 59756',19330,222,NULL,26,26636,0);
INSERT INTO "django_geo_db_location" VALUES(46260,NULL,'West Yellowstone, MT',19331,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46261,NULL,'West Yellowstone, MT 59758',19331,222,NULL,26,26637,0);
INSERT INTO "django_geo_db_location" VALUES(46262,NULL,'Whitehall, MT',19332,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46263,NULL,'Whitehall, MT 59759',19332,222,NULL,26,26638,0);
INSERT INTO "django_geo_db_location" VALUES(46264,NULL,'Willow Creek, MT',19333,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46265,NULL,'Willow Creek, MT 59760',19333,222,NULL,26,26639,0);
INSERT INTO "django_geo_db_location" VALUES(46266,NULL,'Wisdom, MT',19334,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46267,NULL,'Wisdom, MT 59761',19334,222,NULL,26,26640,0);
INSERT INTO "django_geo_db_location" VALUES(46268,NULL,'Wise River, MT',19335,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46269,NULL,'Wise River, MT 59762',19335,222,NULL,26,26641,0);
INSERT INTO "django_geo_db_location" VALUES(46270,NULL,'Bozeman, MT 59771',19301,222,NULL,26,26642,0);
INSERT INTO "django_geo_db_location" VALUES(46271,NULL,'Bozeman, MT 59772',19301,222,NULL,26,26643,0);
INSERT INTO "django_geo_db_location" VALUES(46272,NULL,'Bozeman, MT 59773',19301,222,NULL,26,26644,0);
INSERT INTO "django_geo_db_location" VALUES(46273,NULL,'Ennis, MT 59795',19310,222,NULL,26,26645,0);
INSERT INTO "django_geo_db_location" VALUES(46274,NULL,'West Yellowstone, MT 59798',19331,222,NULL,26,26646,0);
INSERT INTO "django_geo_db_location" VALUES(46275,NULL,'Missoula, MT',19336,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46276,NULL,'Missoula, MT 59801',19336,222,NULL,26,26647,0);
INSERT INTO "django_geo_db_location" VALUES(46277,NULL,'Missoula, MT 59802',19336,222,NULL,26,26648,0);
INSERT INTO "django_geo_db_location" VALUES(46278,NULL,'Missoula, MT 59803',19336,222,NULL,26,26649,0);
INSERT INTO "django_geo_db_location" VALUES(46279,NULL,'Missoula, MT 59804',19336,222,NULL,26,26650,0);
INSERT INTO "django_geo_db_location" VALUES(46280,NULL,'Missoula, MT 59806',19336,222,NULL,26,26651,0);
INSERT INTO "django_geo_db_location" VALUES(46281,NULL,'Missoula, MT 59807',19336,222,NULL,26,26652,0);
INSERT INTO "django_geo_db_location" VALUES(46282,NULL,'Missoula, MT 59808',19336,222,NULL,26,26653,0);
INSERT INTO "django_geo_db_location" VALUES(46283,NULL,'Missoula, MT 59812',19336,222,NULL,26,26654,0);
INSERT INTO "django_geo_db_location" VALUES(46284,NULL,'Four Corners, MT',19337,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46285,NULL,'Four Corners, MT 59817',19337,222,NULL,26,26655,0);
INSERT INTO "django_geo_db_location" VALUES(46286,NULL,'Alberton, MT',19338,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46287,NULL,'Alberton, MT 59820',19338,222,NULL,26,26656,0);
INSERT INTO "django_geo_db_location" VALUES(46288,NULL,'Arlee, MT',19339,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46289,NULL,'Arlee, MT 59821',19339,222,NULL,26,26657,0);
INSERT INTO "django_geo_db_location" VALUES(46290,NULL,'Bonner, MT',19340,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46291,NULL,'Bonner, MT 59823',19340,222,NULL,26,26658,0);
INSERT INTO "django_geo_db_location" VALUES(46292,NULL,'Charlo, MT',19341,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46293,NULL,'Charlo, MT 59824',19341,222,NULL,26,26659,0);
INSERT INTO "django_geo_db_location" VALUES(46294,NULL,'Clinton, MT',19342,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46295,NULL,'Clinton, MT 59825',19342,222,NULL,26,26660,0);
INSERT INTO "django_geo_db_location" VALUES(46296,NULL,'Condon, MT',19343,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46297,NULL,'Condon, MT 59826',19343,222,NULL,26,26661,0);
INSERT INTO "django_geo_db_location" VALUES(46298,NULL,'Conner, MT',19344,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46299,NULL,'Conner, MT 59827',19344,222,NULL,26,26662,0);
INSERT INTO "django_geo_db_location" VALUES(46300,NULL,'Corvallis, MT',19345,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46301,NULL,'Corvallis, MT 59828',19345,222,NULL,26,26663,0);
INSERT INTO "django_geo_db_location" VALUES(46302,NULL,'Darby, MT',19346,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46303,NULL,'Darby, MT 59829',19346,222,NULL,26,26664,0);
INSERT INTO "django_geo_db_location" VALUES(46304,NULL,'De Borgia, MT',19347,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46305,NULL,'De Borgia, MT 59830',19347,222,NULL,26,26665,0);
INSERT INTO "django_geo_db_location" VALUES(46306,NULL,'Dixon, MT',19348,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46307,NULL,'Dixon, MT 59831',19348,222,NULL,26,26666,0);
INSERT INTO "django_geo_db_location" VALUES(46308,NULL,'Drummond, MT',19349,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46309,NULL,'Drummond, MT 59832',19349,222,NULL,26,26667,0);
INSERT INTO "django_geo_db_location" VALUES(46310,NULL,'Florence, MT',19350,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46311,NULL,'Florence, MT 59833',19350,222,NULL,26,26668,0);
INSERT INTO "django_geo_db_location" VALUES(46312,NULL,'Frenchtown, MT',19351,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46313,NULL,'Frenchtown, MT 59834',19351,222,NULL,26,26669,0);
INSERT INTO "django_geo_db_location" VALUES(46314,NULL,'Grantsdale, MT',19352,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46315,NULL,'Grantsdale, MT 59835',19352,222,NULL,26,26670,0);
INSERT INTO "django_geo_db_location" VALUES(46316,NULL,'Greenough, MT',19353,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46317,NULL,'Greenough, MT 59836',19353,222,NULL,26,26671,0);
INSERT INTO "django_geo_db_location" VALUES(46318,NULL,'Hall, MT',19354,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46319,NULL,'Hall, MT 59837',19354,222,NULL,26,26672,0);
INSERT INTO "django_geo_db_location" VALUES(46320,NULL,'Hamilton, MT',19355,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46321,NULL,'Hamilton, MT 59840',19355,222,NULL,26,26673,0);
INSERT INTO "django_geo_db_location" VALUES(46322,NULL,'Pinesdale, MT',19356,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46323,NULL,'Pinesdale, MT 59841',19356,222,NULL,26,26674,0);
INSERT INTO "django_geo_db_location" VALUES(46324,NULL,'Haugan, MT',19357,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46325,NULL,'Haugan, MT 59842',19357,222,NULL,26,26675,0);
INSERT INTO "django_geo_db_location" VALUES(46326,NULL,'Helmville, MT',19358,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46327,NULL,'Helmville, MT 59843',19358,222,NULL,26,26676,0);
INSERT INTO "django_geo_db_location" VALUES(46328,NULL,'Heron, MT',19359,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46329,NULL,'Heron, MT 59844',19359,222,NULL,26,26677,0);
INSERT INTO "django_geo_db_location" VALUES(46330,NULL,'Hot Springs, MT',19360,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46331,NULL,'Hot Springs, MT 59845',19360,222,NULL,26,26678,0);
INSERT INTO "django_geo_db_location" VALUES(46332,NULL,'Huson, MT',19361,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46333,NULL,'Huson, MT 59846',19361,222,NULL,26,26679,0);
INSERT INTO "django_geo_db_location" VALUES(46334,NULL,'Lolo, MT',19362,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46335,NULL,'Lolo, MT 59847',19362,222,NULL,26,26680,0);
INSERT INTO "django_geo_db_location" VALUES(46336,NULL,'Lonepine, MT',19363,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46337,NULL,'Lonepine, MT 59848',19363,222,NULL,26,26681,0);
INSERT INTO "django_geo_db_location" VALUES(46338,NULL,'Milltown, MT',19364,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46339,NULL,'Milltown, MT 59851',19364,222,NULL,26,26682,0);
INSERT INTO "django_geo_db_location" VALUES(46340,NULL,'Noxon, MT',19365,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46341,NULL,'Noxon, MT 59853',19365,222,NULL,26,26683,0);
INSERT INTO "django_geo_db_location" VALUES(46342,NULL,'Ovando, MT',19366,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46343,NULL,'Ovando, MT 59854',19366,222,NULL,26,26684,0);
INSERT INTO "django_geo_db_location" VALUES(46344,NULL,'Pablo, MT',19367,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46345,NULL,'Pablo, MT 59855',19367,222,NULL,26,26685,0);
INSERT INTO "django_geo_db_location" VALUES(46346,NULL,'Paradise, MT',19368,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46347,NULL,'Paradise, MT 59856',19368,222,NULL,26,26686,0);
INSERT INTO "django_geo_db_location" VALUES(46348,NULL,'Philipsburg, MT',19369,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46349,NULL,'Philipsburg, MT 59858',19369,222,NULL,26,26687,0);
INSERT INTO "django_geo_db_location" VALUES(46350,NULL,'Plains, MT',19370,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46351,NULL,'Plains, MT 59859',19370,222,NULL,26,26688,0);
INSERT INTO "django_geo_db_location" VALUES(46352,NULL,'Polson, MT',19371,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46353,NULL,'Polson, MT 59860',19371,222,NULL,26,26689,0);
INSERT INTO "django_geo_db_location" VALUES(46354,NULL,'Ravalli, MT',19372,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46355,NULL,'Ravalli, MT 59863',19372,222,NULL,26,26690,0);
INSERT INTO "django_geo_db_location" VALUES(46356,NULL,'Ronan, MT',19373,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46357,NULL,'Ronan, MT 59864',19373,222,NULL,26,26691,0);
INSERT INTO "django_geo_db_location" VALUES(46358,NULL,'Saint Ignatius, MT',19374,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46359,NULL,'Saint Ignatius, MT 59865',19374,222,NULL,26,26692,0);
INSERT INTO "django_geo_db_location" VALUES(46360,NULL,'Saint Regis, MT',19375,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46361,NULL,'Saint Regis, MT 59866',19375,222,NULL,26,26693,0);
INSERT INTO "django_geo_db_location" VALUES(46362,NULL,'Saltese, MT',19376,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46363,NULL,'Saltese, MT 59867',19376,222,NULL,26,26694,0);
INSERT INTO "django_geo_db_location" VALUES(46364,NULL,'Seeley Lake, MT',19377,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46365,NULL,'Seeley Lake, MT 59868',19377,222,NULL,26,26695,0);
INSERT INTO "django_geo_db_location" VALUES(46366,NULL,'Stevensville, MT',19378,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46367,NULL,'Stevensville, MT 59870',19378,222,NULL,26,26696,0);
INSERT INTO "django_geo_db_location" VALUES(46368,NULL,'Sula, MT',19379,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46369,NULL,'Sula, MT 59871',19379,222,NULL,26,26697,0);
INSERT INTO "django_geo_db_location" VALUES(46370,NULL,'Superior, MT',19380,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46371,NULL,'Superior, MT 59872',19380,222,NULL,26,26698,0);
INSERT INTO "django_geo_db_location" VALUES(46372,NULL,'Thompson Falls, MT',19381,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46373,NULL,'Thompson Falls, MT 59873',19381,222,NULL,26,26699,0);
INSERT INTO "django_geo_db_location" VALUES(46374,NULL,'Trout Creek, MT',19382,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46375,NULL,'Trout Creek, MT 59874',19382,222,NULL,26,26700,0);
INSERT INTO "django_geo_db_location" VALUES(46376,NULL,'Victor, MT',19383,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46377,NULL,'Victor, MT 59875',19383,222,NULL,26,26701,0);
INSERT INTO "django_geo_db_location" VALUES(46378,NULL,'Kalispell, MT',19384,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46379,NULL,'Kalispell, MT 59901',19384,222,NULL,26,26702,0);
INSERT INTO "django_geo_db_location" VALUES(46380,NULL,'Kalispell, MT 59902',19384,222,NULL,26,26703,0);
INSERT INTO "django_geo_db_location" VALUES(46381,NULL,'Kalispell, MT 59903',19384,222,NULL,26,26704,0);
INSERT INTO "django_geo_db_location" VALUES(46382,NULL,'Kalispell, MT 59904',19384,222,NULL,26,26705,0);
INSERT INTO "django_geo_db_location" VALUES(46383,NULL,'Big Arm, MT',19385,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46384,NULL,'Big Arm, MT 59910',19385,222,NULL,26,26706,0);
INSERT INTO "django_geo_db_location" VALUES(46385,NULL,'Bigfork, MT',19386,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46386,NULL,'Bigfork, MT 59911',19386,222,NULL,26,26707,0);
INSERT INTO "django_geo_db_location" VALUES(46387,NULL,'Columbia Falls, MT',19387,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46388,NULL,'Columbia Falls, MT 59912',19387,222,NULL,26,26708,0);
INSERT INTO "django_geo_db_location" VALUES(46389,NULL,'Coram, MT',19388,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46390,NULL,'Coram, MT 59913',19388,222,NULL,26,26709,0);
INSERT INTO "django_geo_db_location" VALUES(46391,NULL,'Dayton, MT',19389,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46392,NULL,'Dayton, MT 59914',19389,222,NULL,26,26710,0);
INSERT INTO "django_geo_db_location" VALUES(46393,NULL,'Elmo, MT',19390,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46394,NULL,'Elmo, MT 59915',19390,222,NULL,26,26711,0);
INSERT INTO "django_geo_db_location" VALUES(46395,NULL,'Essex, MT',19391,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46396,NULL,'Essex, MT 59916',19391,222,NULL,26,26712,0);
INSERT INTO "django_geo_db_location" VALUES(46397,NULL,'Eureka, MT',19392,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46398,NULL,'Eureka, MT 59917',19392,222,NULL,26,26713,0);
INSERT INTO "django_geo_db_location" VALUES(46399,NULL,'Fortine, MT',19393,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46400,NULL,'Fortine, MT 59918',19393,222,NULL,26,26714,0);
INSERT INTO "django_geo_db_location" VALUES(46401,NULL,'Hungry Horse, MT',19394,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46402,NULL,'Hungry Horse, MT 59919',19394,222,NULL,26,26715,0);
INSERT INTO "django_geo_db_location" VALUES(46403,NULL,'Kila, MT',19395,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46404,NULL,'Kila, MT 59920',19395,222,NULL,26,26716,0);
INSERT INTO "django_geo_db_location" VALUES(46405,NULL,'Lake McDonald, MT',19396,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46406,NULL,'Lake McDonald, MT 59921',19396,222,NULL,26,26717,0);
INSERT INTO "django_geo_db_location" VALUES(46407,NULL,'Lakeside, MT',19397,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46408,NULL,'Lakeside, MT 59922',19397,222,NULL,26,26718,0);
INSERT INTO "django_geo_db_location" VALUES(46409,NULL,'Libby, MT',19398,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46410,NULL,'Libby, MT 59923',19398,222,NULL,26,26719,0);
INSERT INTO "django_geo_db_location" VALUES(46411,NULL,'Marion, MT',19399,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46412,NULL,'Marion, MT 59925',19399,222,NULL,26,26720,0);
INSERT INTO "django_geo_db_location" VALUES(46413,NULL,'Martin City, MT',19400,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46414,NULL,'Martin City, MT 59926',19400,222,NULL,26,26721,0);
INSERT INTO "django_geo_db_location" VALUES(46415,NULL,'Olney, MT',19401,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46416,NULL,'Olney, MT 59927',19401,222,NULL,26,26722,0);
INSERT INTO "django_geo_db_location" VALUES(46417,NULL,'Polebridge, MT',19402,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46418,NULL,'Polebridge, MT 59928',19402,222,NULL,26,26723,0);
INSERT INTO "django_geo_db_location" VALUES(46419,NULL,'Proctor, MT',19403,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46420,NULL,'Proctor, MT 59929',19403,222,NULL,26,26724,0);
INSERT INTO "django_geo_db_location" VALUES(46421,NULL,'Rexford, MT',19404,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46422,NULL,'Rexford, MT 59930',19404,222,NULL,26,26725,0);
INSERT INTO "django_geo_db_location" VALUES(46423,NULL,'Rollins, MT',19405,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46424,NULL,'Rollins, MT 59931',19405,222,NULL,26,26726,0);
INSERT INTO "django_geo_db_location" VALUES(46425,NULL,'Somers, MT',19406,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46426,NULL,'Somers, MT 59932',19406,222,NULL,26,26727,0);
INSERT INTO "django_geo_db_location" VALUES(46427,NULL,'Stryker, MT',19407,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46428,NULL,'Stryker, MT 59933',19407,222,NULL,26,26728,0);
INSERT INTO "django_geo_db_location" VALUES(46429,NULL,'Trego, MT',19408,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46430,NULL,'Trego, MT 59934',19408,222,NULL,26,26729,0);
INSERT INTO "django_geo_db_location" VALUES(46431,NULL,'Troy, MT',19409,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46432,NULL,'Troy, MT 59935',19409,222,NULL,26,26730,0);
INSERT INTO "django_geo_db_location" VALUES(46433,NULL,'West Glacier, MT',19410,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46434,NULL,'West Glacier, MT 59936',19410,222,NULL,26,26731,0);
INSERT INTO "django_geo_db_location" VALUES(46435,NULL,'Whitefish, MT',19411,222,NULL,26,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46436,NULL,'Whitefish, MT 59937',19411,222,NULL,26,26732,0);
INSERT INTO "django_geo_db_location" VALUES(46437,NULL,'Alden, IL',19412,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46438,NULL,'Alden, IL 60001',19412,222,NULL,17,26733,0);
INSERT INTO "django_geo_db_location" VALUES(46439,NULL,'Antioch, IL',19413,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46440,NULL,'Antioch, IL 60002',19413,222,NULL,17,26734,0);
INSERT INTO "django_geo_db_location" VALUES(46441,NULL,'Arlington Heights, IL',19414,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46442,NULL,'Arlington Heights, IL 60004',19414,222,NULL,17,26735,0);
INSERT INTO "django_geo_db_location" VALUES(46443,NULL,'Arlington Heights, IL 60005',19414,222,NULL,17,26736,0);
INSERT INTO "django_geo_db_location" VALUES(46444,NULL,'Arlington Heights, IL 60006',19414,222,NULL,17,26737,0);
INSERT INTO "django_geo_db_location" VALUES(46445,NULL,'Elk Grove Village, IL',19415,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46446,NULL,'Elk Grove Village, IL 60007',19415,222,NULL,17,26738,0);
INSERT INTO "django_geo_db_location" VALUES(46447,NULL,'Rolling Meadows, IL',19416,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46448,NULL,'Rolling Meadows, IL 60008',19416,222,NULL,17,26739,0);
INSERT INTO "django_geo_db_location" VALUES(46449,NULL,'Elk Grove Village, IL 60009',19415,222,NULL,17,26740,0);
INSERT INTO "django_geo_db_location" VALUES(46450,NULL,'Barrington, IL',19417,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46451,NULL,'Barrington, IL 60010',19417,222,NULL,17,26741,0);
INSERT INTO "django_geo_db_location" VALUES(46452,NULL,'Barrington, IL 60011',19417,222,NULL,17,26742,0);
INSERT INTO "django_geo_db_location" VALUES(46453,NULL,'Crystal Lake, IL',19418,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46454,NULL,'Crystal Lake, IL 60012',19418,222,NULL,17,26743,0);
INSERT INTO "django_geo_db_location" VALUES(46455,NULL,'Cary, IL',19419,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46456,NULL,'Cary, IL 60013',19419,222,NULL,17,26744,0);
INSERT INTO "django_geo_db_location" VALUES(46457,NULL,'Crystal Lake, IL 60014',19418,222,NULL,17,26745,0);
INSERT INTO "django_geo_db_location" VALUES(46458,NULL,'Deerfield, IL',19420,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46459,NULL,'Deerfield, IL 60015',19420,222,NULL,17,26746,0);
INSERT INTO "django_geo_db_location" VALUES(46460,NULL,'Des Plaines, IL',19421,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46461,NULL,'Des Plaines, IL 60016',19421,222,NULL,17,26747,0);
INSERT INTO "django_geo_db_location" VALUES(46462,NULL,'Des Plaines, IL 60017',19421,222,NULL,17,26748,0);
INSERT INTO "django_geo_db_location" VALUES(46463,NULL,'Des Plaines, IL 60018',19421,222,NULL,17,26749,0);
INSERT INTO "django_geo_db_location" VALUES(46464,NULL,'Des Plaines, IL 60019',19421,222,NULL,17,26750,0);
INSERT INTO "django_geo_db_location" VALUES(46465,NULL,'Fox Lake, IL',19422,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46466,NULL,'Fox Lake, IL 60020',19422,222,NULL,17,26751,0);
INSERT INTO "django_geo_db_location" VALUES(46467,NULL,'Fox River Grove, IL',19423,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46468,NULL,'Fox River Grove, IL 60021',19423,222,NULL,17,26752,0);
INSERT INTO "django_geo_db_location" VALUES(46469,NULL,'Glencoe, IL',19424,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46470,NULL,'Glencoe, IL 60022',19424,222,NULL,17,26753,0);
INSERT INTO "django_geo_db_location" VALUES(46471,NULL,'Glenview, IL',19425,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46472,NULL,'Glenview, IL 60025',19425,222,NULL,17,26754,0);
INSERT INTO "django_geo_db_location" VALUES(46473,NULL,'Glenview Nas, IL',19426,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46474,NULL,'Glenview Nas, IL 60026',19426,222,NULL,17,26755,0);
INSERT INTO "django_geo_db_location" VALUES(46475,NULL,'Golf, IL',19427,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46476,NULL,'Golf, IL 60029',19427,222,NULL,17,26756,0);
INSERT INTO "django_geo_db_location" VALUES(46477,NULL,'Grayslake, IL',19428,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46478,NULL,'Grayslake, IL 60030',19428,222,NULL,17,26757,0);
INSERT INTO "django_geo_db_location" VALUES(46479,NULL,'Gurnee, IL',19429,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46480,NULL,'Gurnee, IL 60031',19429,222,NULL,17,26758,0);
INSERT INTO "django_geo_db_location" VALUES(46481,NULL,'Harvard, IL',19430,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46482,NULL,'Harvard, IL 60033',19430,222,NULL,17,26759,0);
INSERT INTO "django_geo_db_location" VALUES(46483,NULL,'Hebron, IL',19431,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46484,NULL,'Hebron, IL 60034',19431,222,NULL,17,26760,0);
INSERT INTO "django_geo_db_location" VALUES(46485,NULL,'Highland Park, IL',19432,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46486,NULL,'Highland Park, IL 60035',19432,222,NULL,17,26761,0);
INSERT INTO "django_geo_db_location" VALUES(46487,NULL,'Fort Sheridan, IL',19433,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46488,NULL,'Fort Sheridan, IL 60037',19433,222,NULL,17,26762,0);
INSERT INTO "django_geo_db_location" VALUES(46489,NULL,'Palatine, IL',19434,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46490,NULL,'Palatine, IL 60038',19434,222,NULL,17,26763,0);
INSERT INTO "django_geo_db_location" VALUES(46491,NULL,'Crystal Lake, IL 60039',19418,222,NULL,17,26764,0);
INSERT INTO "django_geo_db_location" VALUES(46492,NULL,'Highwood, IL',19435,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46493,NULL,'Highwood, IL 60040',19435,222,NULL,17,26765,0);
INSERT INTO "django_geo_db_location" VALUES(46494,NULL,'Ingleside, IL',19436,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46495,NULL,'Ingleside, IL 60041',19436,222,NULL,17,26766,0);
INSERT INTO "django_geo_db_location" VALUES(46496,NULL,'Island Lake, IL',19437,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46497,NULL,'Island Lake, IL 60042',19437,222,NULL,17,26767,0);
INSERT INTO "django_geo_db_location" VALUES(46498,NULL,'Kenilworth, IL',19438,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46499,NULL,'Kenilworth, IL 60043',19438,222,NULL,17,26768,0);
INSERT INTO "django_geo_db_location" VALUES(46500,NULL,'Lake Bluff, IL',19439,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46501,NULL,'Lake Bluff, IL 60044',19439,222,NULL,17,26769,0);
INSERT INTO "django_geo_db_location" VALUES(46502,NULL,'Lake Forest, IL',19440,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46503,NULL,'Lake Forest, IL 60045',19440,222,NULL,17,26770,0);
INSERT INTO "django_geo_db_location" VALUES(46504,NULL,'Lake Villa, IL',19441,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46505,NULL,'Lake Villa, IL 60046',19441,222,NULL,17,26771,0);
INSERT INTO "django_geo_db_location" VALUES(46506,NULL,'Lake Zurich, IL',19442,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46507,NULL,'Lake Zurich, IL 60047',19442,222,NULL,17,26772,0);
INSERT INTO "django_geo_db_location" VALUES(46508,NULL,'Libertyville, IL',19443,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46509,NULL,'Libertyville, IL 60048',19443,222,NULL,17,26773,0);
INSERT INTO "django_geo_db_location" VALUES(46510,NULL,'Long Grove, IL',19444,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46511,NULL,'Long Grove, IL 60049',19444,222,NULL,17,26774,0);
INSERT INTO "django_geo_db_location" VALUES(46512,NULL,'Mchenry, IL',19445,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46513,NULL,'Mchenry, IL 60050',19445,222,NULL,17,26775,0);
INSERT INTO "django_geo_db_location" VALUES(46514,NULL,'Mchenry, IL 60051',19445,222,NULL,17,26776,0);
INSERT INTO "django_geo_db_location" VALUES(46515,NULL,'Morton Grove, IL',19446,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46516,NULL,'Morton Grove, IL 60053',19446,222,NULL,17,26777,0);
INSERT INTO "django_geo_db_location" VALUES(46517,NULL,'McHenry, IL',19447,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46518,NULL,'McHenry, IL 60054',19447,222,NULL,17,26778,0);
INSERT INTO "django_geo_db_location" VALUES(46519,NULL,'Palatine, IL 60055',19434,222,NULL,17,26779,0);
INSERT INTO "django_geo_db_location" VALUES(46520,NULL,'Mount Prospect, IL',19448,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46521,NULL,'Mount Prospect, IL 60056',19448,222,NULL,17,26780,0);
INSERT INTO "django_geo_db_location" VALUES(46522,NULL,'Mundelein, IL',19449,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46523,NULL,'Mundelein, IL 60060',19449,222,NULL,17,26781,0);
INSERT INTO "django_geo_db_location" VALUES(46524,NULL,'Vernon Hills, IL',19450,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46525,NULL,'Vernon Hills, IL 60061',19450,222,NULL,17,26782,0);
INSERT INTO "django_geo_db_location" VALUES(46526,NULL,'Northbrook, IL',19451,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46527,NULL,'Northbrook, IL 60062',19451,222,NULL,17,26783,0);
INSERT INTO "django_geo_db_location" VALUES(46528,NULL,'North Chicago, IL',19452,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46529,NULL,'North Chicago, IL 60064',19452,222,NULL,17,26784,0);
INSERT INTO "django_geo_db_location" VALUES(46530,NULL,'Northbrook, IL 60065',19451,222,NULL,17,26785,0);
INSERT INTO "django_geo_db_location" VALUES(46531,NULL,'Palatine, IL 60067',19434,222,NULL,17,26786,0);
INSERT INTO "django_geo_db_location" VALUES(46532,NULL,'Park Ridge, IL',19453,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46533,NULL,'Park Ridge, IL 60068',19453,222,NULL,17,26787,0);
INSERT INTO "django_geo_db_location" VALUES(46534,NULL,'Lincolnshire, IL',19454,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46535,NULL,'Lincolnshire, IL 60069',19454,222,NULL,17,26788,0);
INSERT INTO "django_geo_db_location" VALUES(46536,NULL,'Prospect Heights, IL',19455,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46537,NULL,'Prospect Heights, IL 60070',19455,222,NULL,17,26789,0);
INSERT INTO "django_geo_db_location" VALUES(46538,NULL,'Richmond, IL',19456,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46539,NULL,'Richmond, IL 60071',19456,222,NULL,17,26790,0);
INSERT INTO "django_geo_db_location" VALUES(46540,NULL,'Ringwood, IL',19457,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46541,NULL,'Ringwood, IL 60072',19457,222,NULL,17,26791,0);
INSERT INTO "django_geo_db_location" VALUES(46542,NULL,'Round Lake, IL',19458,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46543,NULL,'Round Lake, IL 60073',19458,222,NULL,17,26792,0);
INSERT INTO "django_geo_db_location" VALUES(46544,NULL,'Palatine, IL 60074',19434,222,NULL,17,26793,0);
INSERT INTO "django_geo_db_location" VALUES(46545,NULL,'Russell, IL',19459,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46546,NULL,'Russell, IL 60075',19459,222,NULL,17,26794,0);
INSERT INTO "django_geo_db_location" VALUES(46547,NULL,'Skokie, IL',19460,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46548,NULL,'Skokie, IL 60076',19460,222,NULL,17,26795,0);
INSERT INTO "django_geo_db_location" VALUES(46549,NULL,'Skokie, IL 60077',19460,222,NULL,17,26796,0);
INSERT INTO "django_geo_db_location" VALUES(46550,NULL,'Palatine, IL 60078',19434,222,NULL,17,26797,0);
INSERT INTO "django_geo_db_location" VALUES(46551,NULL,'Waukegan, IL',19461,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46552,NULL,'Waukegan, IL 60079',19461,222,NULL,17,26798,0);
INSERT INTO "django_geo_db_location" VALUES(46553,NULL,'Solon Mills, IL',19462,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46554,NULL,'Solon Mills, IL 60080',19462,222,NULL,17,26799,0);
INSERT INTO "django_geo_db_location" VALUES(46555,NULL,'Spring Grove, IL',19463,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46556,NULL,'Spring Grove, IL 60081',19463,222,NULL,17,26800,0);
INSERT INTO "django_geo_db_location" VALUES(46557,NULL,'Techny, IL',19464,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46558,NULL,'Techny, IL 60082',19464,222,NULL,17,26801,0);
INSERT INTO "django_geo_db_location" VALUES(46559,NULL,'Wadsworth, IL',19465,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46560,NULL,'Wadsworth, IL 60083',19465,222,NULL,17,26802,0);
INSERT INTO "django_geo_db_location" VALUES(46561,NULL,'Wauconda, IL',19466,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46562,NULL,'Wauconda, IL 60084',19466,222,NULL,17,26803,0);
INSERT INTO "django_geo_db_location" VALUES(46563,NULL,'Waukegan, IL 60085',19461,222,NULL,17,26804,0);
INSERT INTO "django_geo_db_location" VALUES(46564,NULL,'North Chicago, IL 60086',19452,222,NULL,17,26805,0);
INSERT INTO "django_geo_db_location" VALUES(46565,NULL,'Waukegan, IL 60087',19461,222,NULL,17,26806,0);
INSERT INTO "django_geo_db_location" VALUES(46566,NULL,'Great Lakes, IL',19467,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46567,NULL,'Great Lakes, IL 60088',19467,222,NULL,17,26807,0);
INSERT INTO "django_geo_db_location" VALUES(46568,NULL,'Buffalo Grove, IL',19468,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46569,NULL,'Buffalo Grove, IL 60089',19468,222,NULL,17,26808,0);
INSERT INTO "django_geo_db_location" VALUES(46570,NULL,'Wheeling, IL',19469,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46571,NULL,'Wheeling, IL 60090',19469,222,NULL,17,26809,0);
INSERT INTO "django_geo_db_location" VALUES(46572,NULL,'Wilmette, IL',19470,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46573,NULL,'Wilmette, IL 60091',19470,222,NULL,17,26810,0);
INSERT INTO "django_geo_db_location" VALUES(46574,NULL,'Libertyville, IL 60092',19443,222,NULL,17,26811,0);
INSERT INTO "django_geo_db_location" VALUES(46575,NULL,'Winnetka, IL',19471,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46576,NULL,'Winnetka, IL 60093',19471,222,NULL,17,26812,0);
INSERT INTO "django_geo_db_location" VALUES(46577,NULL,'Palatine, IL 60094',19434,222,NULL,17,26813,0);
INSERT INTO "django_geo_db_location" VALUES(46578,NULL,'Palatine, IL 60095',19434,222,NULL,17,26814,0);
INSERT INTO "django_geo_db_location" VALUES(46579,NULL,'Winthrop Harbor, IL',19472,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46580,NULL,'Winthrop Harbor, IL 60096',19472,222,NULL,17,26815,0);
INSERT INTO "django_geo_db_location" VALUES(46581,NULL,'Wonder Lake, IL',19473,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46582,NULL,'Wonder Lake, IL 60097',19473,222,NULL,17,26816,0);
INSERT INTO "django_geo_db_location" VALUES(46583,NULL,'Woodstock, IL',19474,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46584,NULL,'Woodstock, IL 60098',19474,222,NULL,17,26817,0);
INSERT INTO "django_geo_db_location" VALUES(46585,NULL,'Zion, IL',19475,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46586,NULL,'Zion, IL 60099',19475,222,NULL,17,26818,0);
INSERT INTO "django_geo_db_location" VALUES(46587,NULL,'Addison, IL',19476,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46588,NULL,'Addison, IL 60101',19476,222,NULL,17,26819,0);
INSERT INTO "django_geo_db_location" VALUES(46589,NULL,'Algonquin, IL',19477,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46590,NULL,'Algonquin, IL 60102',19477,222,NULL,17,26820,0);
INSERT INTO "django_geo_db_location" VALUES(46591,NULL,'Bartlett, IL',19478,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46592,NULL,'Bartlett, IL 60103',19478,222,NULL,17,26821,0);
INSERT INTO "django_geo_db_location" VALUES(46593,NULL,'Bellwood, IL',19479,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46594,NULL,'Bellwood, IL 60104',19479,222,NULL,17,26822,0);
INSERT INTO "django_geo_db_location" VALUES(46595,NULL,'Bensenville, IL',19480,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46596,NULL,'Bensenville, IL 60105',19480,222,NULL,17,26823,0);
INSERT INTO "django_geo_db_location" VALUES(46597,NULL,'Bensenville, IL 60106',19480,222,NULL,17,26824,0);
INSERT INTO "django_geo_db_location" VALUES(46598,NULL,'Streamwood, IL',19481,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46599,NULL,'Streamwood, IL 60107',19481,222,NULL,17,26825,0);
INSERT INTO "django_geo_db_location" VALUES(46600,NULL,'Bloomingdale, IL',19482,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46601,NULL,'Bloomingdale, IL 60108',19482,222,NULL,17,26826,0);
INSERT INTO "django_geo_db_location" VALUES(46602,NULL,'Burlington, IL',19483,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46603,NULL,'Burlington, IL 60109',19483,222,NULL,17,26827,0);
INSERT INTO "django_geo_db_location" VALUES(46604,NULL,'Carpentersville, IL',19484,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46605,NULL,'Carpentersville, IL 60110',19484,222,NULL,17,26828,0);
INSERT INTO "django_geo_db_location" VALUES(46606,NULL,'Clare, IL',19485,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46607,NULL,'Clare, IL 60111',19485,222,NULL,17,26829,0);
INSERT INTO "django_geo_db_location" VALUES(46608,NULL,'Cortland, IL',19486,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46609,NULL,'Cortland, IL 60112',19486,222,NULL,17,26830,0);
INSERT INTO "django_geo_db_location" VALUES(46610,NULL,'Creston, IL',19487,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46611,NULL,'Creston, IL 60113',19487,222,NULL,17,26831,0);
INSERT INTO "django_geo_db_location" VALUES(46612,NULL,'Addison, IL 60114',19476,222,NULL,17,26832,0);
INSERT INTO "django_geo_db_location" VALUES(46613,NULL,'Dekalb, IL',19488,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46614,NULL,'Dekalb, IL 60115',19488,222,NULL,17,26833,0);
INSERT INTO "django_geo_db_location" VALUES(46615,NULL,'Carol Stream, IL',19489,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46616,NULL,'Carol Stream, IL 60116',19489,222,NULL,17,26834,0);
INSERT INTO "django_geo_db_location" VALUES(46617,NULL,'Bloomingdale, IL 60117',19482,222,NULL,17,26835,0);
INSERT INTO "django_geo_db_location" VALUES(46618,NULL,'Dundee, IL',19490,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46619,NULL,'Dundee, IL 60118',19490,222,NULL,17,26836,0);
INSERT INTO "django_geo_db_location" VALUES(46620,NULL,'Elburn, IL',19491,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46621,NULL,'Elburn, IL 60119',19491,222,NULL,17,26837,0);
INSERT INTO "django_geo_db_location" VALUES(46622,NULL,'Elgin, IL',19492,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46623,NULL,'Elgin, IL 60120',19492,222,NULL,17,26838,0);
INSERT INTO "django_geo_db_location" VALUES(46624,NULL,'Elgin, IL 60121',19492,222,NULL,17,26839,0);
INSERT INTO "django_geo_db_location" VALUES(46625,NULL,'Elgin, IL 60122',19492,222,NULL,17,26840,0);
INSERT INTO "django_geo_db_location" VALUES(46626,NULL,'Elgin, IL 60123',19492,222,NULL,17,26841,0);
INSERT INTO "django_geo_db_location" VALUES(46627,NULL,'Carol Stream, IL 60125',19489,222,NULL,17,26842,0);
INSERT INTO "django_geo_db_location" VALUES(46628,NULL,'Elmhurst, IL',19493,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46629,NULL,'Elmhurst, IL 60126',19493,222,NULL,17,26843,0);
INSERT INTO "django_geo_db_location" VALUES(46630,NULL,'Milton, IL',19494,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46631,NULL,'Milton, IL 60127',19494,222,NULL,17,26844,0);
INSERT INTO "django_geo_db_location" VALUES(46632,NULL,'Carol Stream, IL 60128',19489,222,NULL,17,26845,0);
INSERT INTO "django_geo_db_location" VALUES(46633,NULL,'Esmond, IL',19495,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46634,NULL,'Esmond, IL 60129',19495,222,NULL,17,26846,0);
INSERT INTO "django_geo_db_location" VALUES(46635,NULL,'Forest Park, IL',19496,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46636,NULL,'Forest Park, IL 60130',19496,222,NULL,17,26847,0);
INSERT INTO "django_geo_db_location" VALUES(46637,NULL,'Franklin Park, IL',19497,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46638,NULL,'Franklin Park, IL 60131',19497,222,NULL,17,26848,0);
INSERT INTO "django_geo_db_location" VALUES(46639,NULL,'Carol Stream, IL 60132',19489,222,NULL,17,26849,0);
INSERT INTO "django_geo_db_location" VALUES(46640,NULL,'Hanover Park, IL',19498,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46641,NULL,'Hanover Park, IL 60133',19498,222,NULL,17,26850,0);
INSERT INTO "django_geo_db_location" VALUES(46642,NULL,'Geneva, IL',19499,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46643,NULL,'Geneva, IL 60134',19499,222,NULL,17,26851,0);
INSERT INTO "django_geo_db_location" VALUES(46644,NULL,'Genoa, IL',19500,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46645,NULL,'Genoa, IL 60135',19500,222,NULL,17,26852,0);
INSERT INTO "django_geo_db_location" VALUES(46646,NULL,'Gilberts, IL',19501,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46647,NULL,'Gilberts, IL 60136',19501,222,NULL,17,26853,0);
INSERT INTO "django_geo_db_location" VALUES(46648,NULL,'Glen Ellyn, IL',19502,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46649,NULL,'Glen Ellyn, IL 60137',19502,222,NULL,17,26854,0);
INSERT INTO "django_geo_db_location" VALUES(46650,NULL,'Glen Ellyn, IL 60138',19502,222,NULL,17,26855,0);
INSERT INTO "django_geo_db_location" VALUES(46651,NULL,'Glendale Heights, IL',19503,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46652,NULL,'Glendale Heights, IL 60139',19503,222,NULL,17,26856,0);
INSERT INTO "django_geo_db_location" VALUES(46653,NULL,'Hampshire, IL',19504,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46654,NULL,'Hampshire, IL 60140',19504,222,NULL,17,26857,0);
INSERT INTO "django_geo_db_location" VALUES(46655,NULL,'Hines, IL',19505,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46656,NULL,'Hines, IL 60141',19505,222,NULL,17,26858,0);
INSERT INTO "django_geo_db_location" VALUES(46657,NULL,'Huntley, IL',19506,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46658,NULL,'Huntley, IL 60142',19506,222,NULL,17,26859,0);
INSERT INTO "django_geo_db_location" VALUES(46659,NULL,'Itasca, IL',19507,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46660,NULL,'Itasca, IL 60143',19507,222,NULL,17,26860,0);
INSERT INTO "django_geo_db_location" VALUES(46661,NULL,'Kaneville, IL',19508,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46662,NULL,'Kaneville, IL 60144',19508,222,NULL,17,26861,0);
INSERT INTO "django_geo_db_location" VALUES(46663,NULL,'Kingston, IL',19509,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46664,NULL,'Kingston, IL 60145',19509,222,NULL,17,26862,0);
INSERT INTO "django_geo_db_location" VALUES(46665,NULL,'Kirkland, IL',19510,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46666,NULL,'Kirkland, IL 60146',19510,222,NULL,17,26863,0);
INSERT INTO "django_geo_db_location" VALUES(46667,NULL,'Lafox, IL',19511,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46668,NULL,'Lafox, IL 60147',19511,222,NULL,17,26864,0);
INSERT INTO "django_geo_db_location" VALUES(46669,NULL,'Lombard, IL',19512,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46670,NULL,'Lombard, IL 60148',19512,222,NULL,17,26865,0);
INSERT INTO "django_geo_db_location" VALUES(46671,NULL,'Dement, IL',19513,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46672,NULL,'Dement, IL 60149',19513,222,NULL,17,26866,0);
INSERT INTO "django_geo_db_location" VALUES(46673,NULL,'Malta, IL',19514,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46674,NULL,'Malta, IL 60150',19514,222,NULL,17,26867,0);
INSERT INTO "django_geo_db_location" VALUES(46675,NULL,'Maple Park, IL',19515,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46676,NULL,'Maple Park, IL 60151',19515,222,NULL,17,26868,0);
INSERT INTO "django_geo_db_location" VALUES(46677,NULL,'Marengo, IL',19516,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46678,NULL,'Marengo, IL 60152',19516,222,NULL,17,26869,0);
INSERT INTO "django_geo_db_location" VALUES(46679,NULL,'Maywood, IL',19517,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46680,NULL,'Maywood, IL 60153',19517,222,NULL,17,26870,0);
INSERT INTO "django_geo_db_location" VALUES(46681,NULL,'Westchester, IL',19518,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46682,NULL,'Westchester, IL 60154',19518,222,NULL,17,26871,0);
INSERT INTO "django_geo_db_location" VALUES(46683,NULL,'Broadview, IL',19519,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46684,NULL,'Broadview, IL 60155',19519,222,NULL,17,26872,0);
INSERT INTO "django_geo_db_location" VALUES(46685,NULL,'Lake in the Hills, IL',19520,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46686,NULL,'Lake in the Hills, IL 60156',19520,222,NULL,17,26873,0);
INSERT INTO "django_geo_db_location" VALUES(46687,NULL,'Medinah, IL',19521,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46688,NULL,'Medinah, IL 60157',19521,222,NULL,17,26874,0);
INSERT INTO "django_geo_db_location" VALUES(46689,NULL,'Schaumburg, IL',19522,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46690,NULL,'Schaumburg, IL 60159',19522,222,NULL,17,26875,0);
INSERT INTO "django_geo_db_location" VALUES(46691,NULL,'Melrose Park, IL',19523,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46692,NULL,'Melrose Park, IL 60160',19523,222,NULL,17,26876,0);
INSERT INTO "django_geo_db_location" VALUES(46693,NULL,'Melrose Park, IL 60161',19523,222,NULL,17,26877,0);
INSERT INTO "django_geo_db_location" VALUES(46694,NULL,'Hillside, IL',19524,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46695,NULL,'Hillside, IL 60162',19524,222,NULL,17,26878,0);
INSERT INTO "django_geo_db_location" VALUES(46696,NULL,'Berkeley, IL',19525,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46697,NULL,'Berkeley, IL 60163',19525,222,NULL,17,26879,0);
INSERT INTO "django_geo_db_location" VALUES(46698,NULL,'Melrose Park, IL 60164',19523,222,NULL,17,26880,0);
INSERT INTO "django_geo_db_location" VALUES(46699,NULL,'Stone Park, IL',19526,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46700,NULL,'Stone Park, IL 60165',19526,222,NULL,17,26881,0);
INSERT INTO "django_geo_db_location" VALUES(46701,NULL,'Schaumburg, IL 60168',19522,222,NULL,17,26882,0);
INSERT INTO "django_geo_db_location" VALUES(46702,NULL,'Plato Center, IL',19527,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46703,NULL,'Plato Center, IL 60170',19527,222,NULL,17,26883,0);
INSERT INTO "django_geo_db_location" VALUES(46704,NULL,'River Grove, IL',19528,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46705,NULL,'River Grove, IL 60171',19528,222,NULL,17,26884,0);
INSERT INTO "django_geo_db_location" VALUES(46706,NULL,'Roselle, IL',19529,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46707,NULL,'Roselle, IL 60172',19529,222,NULL,17,26885,0);
INSERT INTO "django_geo_db_location" VALUES(46708,NULL,'Schaumburg, IL 60173',19522,222,NULL,17,26886,0);
INSERT INTO "django_geo_db_location" VALUES(46709,NULL,'Saint Charles, IL',19530,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46710,NULL,'Saint Charles, IL 60174',19530,222,NULL,17,26887,0);
INSERT INTO "django_geo_db_location" VALUES(46711,NULL,'Saint Charles, IL 60175',19530,222,NULL,17,26888,0);
INSERT INTO "django_geo_db_location" VALUES(46712,NULL,'Schiller Park, IL',19531,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46713,NULL,'Schiller Park, IL 60176',19531,222,NULL,17,26889,0);
INSERT INTO "django_geo_db_location" VALUES(46714,NULL,'South Elgin, IL',19532,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46715,NULL,'South Elgin, IL 60177',19532,222,NULL,17,26890,0);
INSERT INTO "django_geo_db_location" VALUES(46716,NULL,'Sycamore, IL',19533,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46717,NULL,'Sycamore, IL 60178',19533,222,NULL,17,26891,0);
INSERT INTO "django_geo_db_location" VALUES(46718,NULL,'Hoffman Estates, IL',19534,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46719,NULL,'Hoffman Estates, IL 60179',19534,222,NULL,17,26892,0);
INSERT INTO "django_geo_db_location" VALUES(46720,NULL,'Union, IL',19535,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46721,NULL,'Union, IL 60180',19535,222,NULL,17,26893,0);
INSERT INTO "django_geo_db_location" VALUES(46722,NULL,'Villa Park, IL',19536,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46723,NULL,'Villa Park, IL 60181',19536,222,NULL,17,26894,0);
INSERT INTO "django_geo_db_location" VALUES(46724,NULL,'Virgil, IL',19537,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46725,NULL,'Virgil, IL 60182',19537,222,NULL,17,26895,0);
INSERT INTO "django_geo_db_location" VALUES(46726,NULL,'Wasco, IL',19538,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46727,NULL,'Wasco, IL 60183',19538,222,NULL,17,26896,0);
INSERT INTO "django_geo_db_location" VALUES(46728,NULL,'Wayne, IL',19539,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46729,NULL,'Wayne, IL 60184',19539,222,NULL,17,26897,0);
INSERT INTO "django_geo_db_location" VALUES(46730,NULL,'West Chicago, IL',19540,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46731,NULL,'West Chicago, IL 60185',19540,222,NULL,17,26898,0);
INSERT INTO "django_geo_db_location" VALUES(46732,NULL,'West Chicago, IL 60186',19540,222,NULL,17,26899,0);
INSERT INTO "django_geo_db_location" VALUES(46733,NULL,'Wheaton, IL',19541,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46734,NULL,'Wheaton, IL 60187',19541,222,NULL,17,26900,0);
INSERT INTO "django_geo_db_location" VALUES(46735,NULL,'Carol Stream, IL 60188',19489,222,NULL,17,26901,0);
INSERT INTO "django_geo_db_location" VALUES(46736,NULL,'Wheaton, IL 60189',19541,222,NULL,17,26902,0);
INSERT INTO "django_geo_db_location" VALUES(46737,NULL,'Winfield, IL',19542,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46738,NULL,'Winfield, IL 60190',19542,222,NULL,17,26903,0);
INSERT INTO "django_geo_db_location" VALUES(46739,NULL,'Wood Dale, IL',19543,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46740,NULL,'Wood Dale, IL 60191',19543,222,NULL,17,26904,0);
INSERT INTO "django_geo_db_location" VALUES(46741,NULL,'Schaumburg, IL 60192',19522,222,NULL,17,26905,0);
INSERT INTO "django_geo_db_location" VALUES(46742,NULL,'Schaumburg, IL 60193',19522,222,NULL,17,26906,0);
INSERT INTO "django_geo_db_location" VALUES(46743,NULL,'Schaumburg, IL 60194',19522,222,NULL,17,26907,0);
INSERT INTO "django_geo_db_location" VALUES(46744,NULL,'Schaumburg, IL 60195',19522,222,NULL,17,26908,0);
INSERT INTO "django_geo_db_location" VALUES(46745,NULL,'Schaumburg, IL 60196',19522,222,NULL,17,26909,0);
INSERT INTO "django_geo_db_location" VALUES(46746,NULL,'Carol Stream, IL 60197',19489,222,NULL,17,26910,0);
INSERT INTO "django_geo_db_location" VALUES(46747,NULL,'Carol Stream, IL 60198',19489,222,NULL,17,26911,0);
INSERT INTO "django_geo_db_location" VALUES(46748,NULL,'Carol Stream, IL 60199',19489,222,NULL,17,26912,0);
INSERT INTO "django_geo_db_location" VALUES(46749,NULL,'Evanston, IL',19544,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46750,NULL,'Evanston, IL 60201',19544,222,NULL,17,26913,0);
INSERT INTO "django_geo_db_location" VALUES(46751,NULL,'Evanston, IL 60202',19544,222,NULL,17,26914,0);
INSERT INTO "django_geo_db_location" VALUES(46752,NULL,'Evanston, IL 60203',19544,222,NULL,17,26915,0);
INSERT INTO "django_geo_db_location" VALUES(46753,NULL,'Evanston, IL 60204',19544,222,NULL,17,26916,0);
INSERT INTO "django_geo_db_location" VALUES(46754,NULL,'Evanston, IL 60208',19544,222,NULL,17,26917,0);
INSERT INTO "django_geo_db_location" VALUES(46755,NULL,'Evanston, IL 60209',19544,222,NULL,17,26918,0);
INSERT INTO "django_geo_db_location" VALUES(46756,NULL,'Oak Park, IL',19545,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46757,NULL,'Oak Park, IL 60301',19545,222,NULL,17,26919,0);
INSERT INTO "django_geo_db_location" VALUES(46758,NULL,'Oak Park, IL 60302',19545,222,NULL,17,26920,0);
INSERT INTO "django_geo_db_location" VALUES(46759,NULL,'Oak Park, IL 60303',19545,222,NULL,17,26921,0);
INSERT INTO "django_geo_db_location" VALUES(46760,NULL,'Oak Park, IL 60304',19545,222,NULL,17,26922,0);
INSERT INTO "django_geo_db_location" VALUES(46761,NULL,'River Forest, IL',19546,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46762,NULL,'River Forest, IL 60305',19546,222,NULL,17,26923,0);
INSERT INTO "django_geo_db_location" VALUES(46763,NULL,'River Forest, IL 60330',19546,222,NULL,17,26924,0);
INSERT INTO "django_geo_db_location" VALUES(46764,NULL,'Beecher, IL',19547,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46765,NULL,'Beecher, IL 60401',19547,222,NULL,17,26925,0);
INSERT INTO "django_geo_db_location" VALUES(46766,NULL,'Berwyn, IL',19548,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46767,NULL,'Berwyn, IL 60402',19548,222,NULL,17,26926,0);
INSERT INTO "django_geo_db_location" VALUES(46768,NULL,'Blue Island, IL',19549,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46769,NULL,'Blue Island, IL 60406',19549,222,NULL,17,26927,0);
INSERT INTO "django_geo_db_location" VALUES(46770,NULL,'Braceville, IL',19550,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46771,NULL,'Braceville, IL 60407',19550,222,NULL,17,26928,0);
INSERT INTO "django_geo_db_location" VALUES(46772,NULL,'Braidwood, IL',19551,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46773,NULL,'Braidwood, IL 60408',19551,222,NULL,17,26929,0);
INSERT INTO "django_geo_db_location" VALUES(46774,NULL,'Calumet City, IL',19552,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46775,NULL,'Calumet City, IL 60409',19552,222,NULL,17,26930,0);
INSERT INTO "django_geo_db_location" VALUES(46776,NULL,'Channahon, IL',19553,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46777,NULL,'Channahon, IL 60410',19553,222,NULL,17,26931,0);
INSERT INTO "django_geo_db_location" VALUES(46778,NULL,'Chicago Heights, IL',19554,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46779,NULL,'Chicago Heights, IL 60411',19554,222,NULL,17,26932,0);
INSERT INTO "django_geo_db_location" VALUES(46780,NULL,'Chicago Heights, IL 60412',19554,222,NULL,17,26933,0);
INSERT INTO "django_geo_db_location" VALUES(46781,NULL,'Chicago Ridge, IL',19555,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46782,NULL,'Chicago Ridge, IL 60415',19555,222,NULL,17,26934,0);
INSERT INTO "django_geo_db_location" VALUES(46783,NULL,'Coal City, IL',19556,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46784,NULL,'Coal City, IL 60416',19556,222,NULL,17,26935,0);
INSERT INTO "django_geo_db_location" VALUES(46785,NULL,'Crete, IL',19557,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46786,NULL,'Crete, IL 60417',19557,222,NULL,17,26936,0);
INSERT INTO "django_geo_db_location" VALUES(46787,NULL,'Dolton, IL',19558,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46788,NULL,'Dolton, IL 60419',19558,222,NULL,17,26937,0);
INSERT INTO "django_geo_db_location" VALUES(46789,NULL,'Dwight, IL',19559,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46790,NULL,'Dwight, IL 60420',19559,222,NULL,17,26938,0);
INSERT INTO "django_geo_db_location" VALUES(46791,NULL,'Elwood, IL',19560,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46792,NULL,'Elwood, IL 60421',19560,222,NULL,17,26939,0);
INSERT INTO "django_geo_db_location" VALUES(46793,NULL,'Flossmoor, IL',19561,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46794,NULL,'Flossmoor, IL 60422',19561,222,NULL,17,26940,0);
INSERT INTO "django_geo_db_location" VALUES(46795,NULL,'Frankfort, IL',19562,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46796,NULL,'Frankfort, IL 60423',19562,222,NULL,17,26941,0);
INSERT INTO "django_geo_db_location" VALUES(46797,NULL,'Gardner, IL',19563,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46798,NULL,'Gardner, IL 60424',19563,222,NULL,17,26942,0);
INSERT INTO "django_geo_db_location" VALUES(46799,NULL,'Glenwood, IL',19564,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46800,NULL,'Glenwood, IL 60425',19564,222,NULL,17,26943,0);
INSERT INTO "django_geo_db_location" VALUES(46801,NULL,'Harvey, IL',19565,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46802,NULL,'Harvey, IL 60426',19565,222,NULL,17,26944,0);
INSERT INTO "django_geo_db_location" VALUES(46803,NULL,'Hazel Crest, IL',19566,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46804,NULL,'Hazel Crest, IL 60429',19566,222,NULL,17,26945,0);
INSERT INTO "django_geo_db_location" VALUES(46805,NULL,'Homewood, IL',19567,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46806,NULL,'Homewood, IL 60430',19567,222,NULL,17,26946,0);
INSERT INTO "django_geo_db_location" VALUES(46807,NULL,'Joliet, IL',19568,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46808,NULL,'Joliet, IL 60431',19568,222,NULL,17,26947,0);
INSERT INTO "django_geo_db_location" VALUES(46809,NULL,'Joliet, IL 60432',19568,222,NULL,17,26948,0);
INSERT INTO "django_geo_db_location" VALUES(46810,NULL,'Joliet, IL 60433',19568,222,NULL,17,26949,0);
INSERT INTO "django_geo_db_location" VALUES(46811,NULL,'Joliet, IL 60434',19568,222,NULL,17,26950,0);
INSERT INTO "django_geo_db_location" VALUES(46812,NULL,'Joliet, IL 60435',19568,222,NULL,17,26951,0);
INSERT INTO "django_geo_db_location" VALUES(46813,NULL,'Joliet, IL 60436',19568,222,NULL,17,26952,0);
INSERT INTO "django_geo_db_location" VALUES(46814,NULL,'Kinsman, IL',19569,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46815,NULL,'Kinsman, IL 60437',19569,222,NULL,17,26953,0);
INSERT INTO "django_geo_db_location" VALUES(46816,NULL,'Lansing, IL',19570,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46817,NULL,'Lansing, IL 60438',19570,222,NULL,17,26954,0);
INSERT INTO "django_geo_db_location" VALUES(46818,NULL,'Lemont, IL',19571,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46819,NULL,'Lemont, IL 60439',19571,222,NULL,17,26955,0);
INSERT INTO "django_geo_db_location" VALUES(46820,NULL,'Bolingbrook, IL',19572,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46821,NULL,'Bolingbrook, IL 60440',19572,222,NULL,17,26956,0);
INSERT INTO "django_geo_db_location" VALUES(46822,NULL,'Lockport, IL',19573,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46823,NULL,'Lockport, IL 60441',19573,222,NULL,17,26957,0);
INSERT INTO "django_geo_db_location" VALUES(46824,NULL,'Manhattan, IL',19574,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46825,NULL,'Manhattan, IL 60442',19574,222,NULL,17,26958,0);
INSERT INTO "django_geo_db_location" VALUES(46826,NULL,'Matteson, IL',19575,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46827,NULL,'Matteson, IL 60443',19575,222,NULL,17,26959,0);
INSERT INTO "django_geo_db_location" VALUES(46828,NULL,'Mazon, IL',19576,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46829,NULL,'Mazon, IL 60444',19576,222,NULL,17,26960,0);
INSERT INTO "django_geo_db_location" VALUES(46830,NULL,'Midlothian, IL',19577,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46831,NULL,'Midlothian, IL 60445',19577,222,NULL,17,26961,0);
INSERT INTO "django_geo_db_location" VALUES(46832,NULL,'Romeoville, IL',19578,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46833,NULL,'Romeoville, IL 60446',19578,222,NULL,17,26962,0);
INSERT INTO "django_geo_db_location" VALUES(46834,NULL,'Minooka, IL',19579,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46835,NULL,'Minooka, IL 60447',19579,222,NULL,17,26963,0);
INSERT INTO "django_geo_db_location" VALUES(46836,NULL,'Mokena, IL',19580,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46837,NULL,'Mokena, IL 60448',19580,222,NULL,17,26964,0);
INSERT INTO "django_geo_db_location" VALUES(46838,NULL,'Monee, IL',19581,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46839,NULL,'Monee, IL 60449',19581,222,NULL,17,26965,0);
INSERT INTO "django_geo_db_location" VALUES(46840,NULL,'Morris, IL',19582,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46841,NULL,'Morris, IL 60450',19582,222,NULL,17,26966,0);
INSERT INTO "django_geo_db_location" VALUES(46842,NULL,'New Lenox, IL',19583,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46843,NULL,'New Lenox, IL 60451',19583,222,NULL,17,26967,0);
INSERT INTO "django_geo_db_location" VALUES(46844,NULL,'Oak Forest, IL',19584,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46845,NULL,'Oak Forest, IL 60452',19584,222,NULL,17,26968,0);
INSERT INTO "django_geo_db_location" VALUES(46846,NULL,'Oak Lawn, IL',19585,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46847,NULL,'Oak Lawn, IL 60453',19585,222,NULL,17,26969,0);
INSERT INTO "django_geo_db_location" VALUES(46848,NULL,'Oak Lawn, IL 60454',19585,222,NULL,17,26970,0);
INSERT INTO "django_geo_db_location" VALUES(46849,NULL,'Bridgeview, IL',19586,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46850,NULL,'Bridgeview, IL 60455',19586,222,NULL,17,26971,0);
INSERT INTO "django_geo_db_location" VALUES(46851,NULL,'Hometown, IL',19587,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46852,NULL,'Hometown, IL 60456',19587,222,NULL,17,26972,0);
INSERT INTO "django_geo_db_location" VALUES(46853,NULL,'Hickory Hills, IL',19588,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46854,NULL,'Hickory Hills, IL 60457',19588,222,NULL,17,26973,0);
INSERT INTO "django_geo_db_location" VALUES(46855,NULL,'Justice, IL',19589,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46856,NULL,'Justice, IL 60458',19589,222,NULL,17,26974,0);
INSERT INTO "django_geo_db_location" VALUES(46857,NULL,'Burbank, IL',19590,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46858,NULL,'Burbank, IL 60459',19590,222,NULL,17,26975,0);
INSERT INTO "django_geo_db_location" VALUES(46859,NULL,'Odell, IL',19591,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46860,NULL,'Odell, IL 60460',19591,222,NULL,17,26976,0);
INSERT INTO "django_geo_db_location" VALUES(46861,NULL,'Olympia Fields, IL',19592,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46862,NULL,'Olympia Fields, IL 60461',19592,222,NULL,17,26977,0);
INSERT INTO "django_geo_db_location" VALUES(46863,NULL,'Orland Park, IL',19593,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46864,NULL,'Orland Park, IL 60462',19593,222,NULL,17,26978,0);
INSERT INTO "django_geo_db_location" VALUES(46865,NULL,'Palos Heights, IL',19594,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46866,NULL,'Palos Heights, IL 60463',19594,222,NULL,17,26979,0);
INSERT INTO "django_geo_db_location" VALUES(46867,NULL,'Palos Park, IL',19595,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46868,NULL,'Palos Park, IL 60464',19595,222,NULL,17,26980,0);
INSERT INTO "django_geo_db_location" VALUES(46869,NULL,'Palos Hills, IL',19596,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46870,NULL,'Palos Hills, IL 60465',19596,222,NULL,17,26981,0);
INSERT INTO "django_geo_db_location" VALUES(46871,NULL,'Park Forest, IL',19597,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46872,NULL,'Park Forest, IL 60466',19597,222,NULL,17,26982,0);
INSERT INTO "django_geo_db_location" VALUES(46873,NULL,'Orland Park, IL 60467',19593,222,NULL,17,26983,0);
INSERT INTO "django_geo_db_location" VALUES(46874,NULL,'Peotone, IL',19598,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46875,NULL,'Peotone, IL 60468',19598,222,NULL,17,26984,0);
INSERT INTO "django_geo_db_location" VALUES(46876,NULL,'Posen, IL',19599,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46877,NULL,'Posen, IL 60469',19599,222,NULL,17,26985,0);
INSERT INTO "django_geo_db_location" VALUES(46878,NULL,'Ransom, IL',19600,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46879,NULL,'Ransom, IL 60470',19600,222,NULL,17,26986,0);
INSERT INTO "django_geo_db_location" VALUES(46880,NULL,'Richton Park, IL',19601,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46881,NULL,'Richton Park, IL 60471',19601,222,NULL,17,26987,0);
INSERT INTO "django_geo_db_location" VALUES(46882,NULL,'Robbins, IL',19602,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46883,NULL,'Robbins, IL 60472',19602,222,NULL,17,26988,0);
INSERT INTO "django_geo_db_location" VALUES(46884,NULL,'South Holland, IL',19603,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46885,NULL,'South Holland, IL 60473',19603,222,NULL,17,26989,0);
INSERT INTO "django_geo_db_location" VALUES(46886,NULL,'South Wilmington, IL',19604,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46887,NULL,'South Wilmington, IL 60474',19604,222,NULL,17,26990,0);
INSERT INTO "django_geo_db_location" VALUES(46888,NULL,'Steger, IL',19605,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46889,NULL,'Steger, IL 60475',19605,222,NULL,17,26991,0);
INSERT INTO "django_geo_db_location" VALUES(46890,NULL,'Thornton, IL',19606,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46891,NULL,'Thornton, IL 60476',19606,222,NULL,17,26992,0);
INSERT INTO "django_geo_db_location" VALUES(46892,NULL,'Tinley Park, IL',19607,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46893,NULL,'Tinley Park, IL 60477',19607,222,NULL,17,26993,0);
INSERT INTO "django_geo_db_location" VALUES(46894,NULL,'Country Club Hills, IL',19608,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46895,NULL,'Country Club Hills, IL 60478',19608,222,NULL,17,26994,0);
INSERT INTO "django_geo_db_location" VALUES(46896,NULL,'Verona, IL',19609,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46897,NULL,'Verona, IL 60479',19609,222,NULL,17,26995,0);
INSERT INTO "django_geo_db_location" VALUES(46898,NULL,'Willow Springs, IL',19610,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46899,NULL,'Willow Springs, IL 60480',19610,222,NULL,17,26996,0);
INSERT INTO "django_geo_db_location" VALUES(46900,NULL,'Wilmington, IL',19611,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46901,NULL,'Wilmington, IL 60481',19611,222,NULL,17,26997,0);
INSERT INTO "django_geo_db_location" VALUES(46902,NULL,'Worth, IL',19612,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46903,NULL,'Worth, IL 60482',19612,222,NULL,17,26998,0);
INSERT INTO "django_geo_db_location" VALUES(46904,NULL,'Bolingbrook, IL 60490',19572,222,NULL,17,26999,0);
INSERT INTO "django_geo_db_location" VALUES(46905,NULL,'Bedford Park, IL',19613,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46906,NULL,'Bedford Park, IL 60499',19613,222,NULL,17,27000,0);
INSERT INTO "django_geo_db_location" VALUES(46907,NULL,'Summit Argo, IL',19614,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46908,NULL,'Summit Argo, IL 60501',19614,222,NULL,17,27001,0);
INSERT INTO "django_geo_db_location" VALUES(46909,NULL,'Aurora, IL',19615,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46910,NULL,'Aurora, IL 60504',19615,222,NULL,17,27002,0);
INSERT INTO "django_geo_db_location" VALUES(46911,NULL,'Aurora, IL 60505',19615,222,NULL,17,27003,0);
INSERT INTO "django_geo_db_location" VALUES(46912,NULL,'Aurora, IL 60506',19615,222,NULL,17,27004,0);
INSERT INTO "django_geo_db_location" VALUES(46913,NULL,'Aurora, IL 60507',19615,222,NULL,17,27005,0);
INSERT INTO "django_geo_db_location" VALUES(46914,NULL,'Batavia, IL',19616,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46915,NULL,'Batavia, IL 60510',19616,222,NULL,17,27006,0);
INSERT INTO "django_geo_db_location" VALUES(46916,NULL,'Big Rock, IL',19617,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46917,NULL,'Big Rock, IL 60511',19617,222,NULL,17,27007,0);
INSERT INTO "django_geo_db_location" VALUES(46918,NULL,'Bristol, IL',19618,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46919,NULL,'Bristol, IL 60512',19618,222,NULL,17,27008,0);
INSERT INTO "django_geo_db_location" VALUES(46920,NULL,'Brookfield, IL',19619,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46921,NULL,'Brookfield, IL 60513',19619,222,NULL,17,27009,0);
INSERT INTO "django_geo_db_location" VALUES(46922,NULL,'Clarendon Hills, IL',19620,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46923,NULL,'Clarendon Hills, IL 60514',19620,222,NULL,17,27010,0);
INSERT INTO "django_geo_db_location" VALUES(46924,NULL,'Downers Grove, IL',19621,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46925,NULL,'Downers Grove, IL 60515',19621,222,NULL,17,27011,0);
INSERT INTO "django_geo_db_location" VALUES(46926,NULL,'Downers Grove, IL 60516',19621,222,NULL,17,27012,0);
INSERT INTO "django_geo_db_location" VALUES(46927,NULL,'Woodridge, IL',19622,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46928,NULL,'Woodridge, IL 60517',19622,222,NULL,17,27013,0);
INSERT INTO "django_geo_db_location" VALUES(46929,NULL,'Earlville, IL',19623,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46930,NULL,'Earlville, IL 60518',19623,222,NULL,17,27014,0);
INSERT INTO "django_geo_db_location" VALUES(46931,NULL,'Eola, IL',19624,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46932,NULL,'Eola, IL 60519',19624,222,NULL,17,27015,0);
INSERT INTO "django_geo_db_location" VALUES(46933,NULL,'Hinckley, IL',19625,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46934,NULL,'Hinckley, IL 60520',19625,222,NULL,17,27016,0);
INSERT INTO "django_geo_db_location" VALUES(46935,NULL,'Hinsdale, IL',19626,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46936,NULL,'Hinsdale, IL 60521',19626,222,NULL,17,27017,0);
INSERT INTO "django_geo_db_location" VALUES(46937,NULL,'Hinsdale, IL 60522',19626,222,NULL,17,27018,0);
INSERT INTO "django_geo_db_location" VALUES(46938,NULL,'Oak Brook, IL',19627,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46939,NULL,'Oak Brook, IL 60523',19627,222,NULL,17,27019,0);
INSERT INTO "django_geo_db_location" VALUES(46940,NULL,'La Grange, IL',19628,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46941,NULL,'La Grange, IL 60525',19628,222,NULL,17,27020,0);
INSERT INTO "django_geo_db_location" VALUES(46942,NULL,'La Grange Park, IL',19629,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46943,NULL,'La Grange Park, IL 60526',19629,222,NULL,17,27021,0);
INSERT INTO "django_geo_db_location" VALUES(46944,NULL,'Hinsdale, IL 60527',19626,222,NULL,17,27022,0);
INSERT INTO "django_geo_db_location" VALUES(46945,NULL,'Lee, IL',19630,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46946,NULL,'Lee, IL 60530',19630,222,NULL,17,27023,0);
INSERT INTO "django_geo_db_location" VALUES(46947,NULL,'Leland, IL',19631,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46948,NULL,'Leland, IL 60531',19631,222,NULL,17,27024,0);
INSERT INTO "django_geo_db_location" VALUES(46949,NULL,'Lisle, IL',19632,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46950,NULL,'Lisle, IL 60532',19632,222,NULL,17,27025,0);
INSERT INTO "django_geo_db_location" VALUES(46951,NULL,'Lyons, IL',19633,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46952,NULL,'Lyons, IL 60534',19633,222,NULL,17,27026,0);
INSERT INTO "django_geo_db_location" VALUES(46953,NULL,'Millbrook, IL',19634,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46954,NULL,'Millbrook, IL 60536',19634,222,NULL,17,27027,0);
INSERT INTO "django_geo_db_location" VALUES(46955,NULL,'Millington, IL',19635,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46956,NULL,'Millington, IL 60537',19635,222,NULL,17,27028,0);
INSERT INTO "django_geo_db_location" VALUES(46957,NULL,'Montgomery, IL',19636,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46958,NULL,'Montgomery, IL 60538',19636,222,NULL,17,27029,0);
INSERT INTO "django_geo_db_location" VALUES(46959,NULL,'Mooseheart, IL',19637,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46960,NULL,'Mooseheart, IL 60539',19637,222,NULL,17,27030,0);
INSERT INTO "django_geo_db_location" VALUES(46961,NULL,'Naperville, IL',19638,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46962,NULL,'Naperville, IL 60540',19638,222,NULL,17,27031,0);
INSERT INTO "django_geo_db_location" VALUES(46963,NULL,'Newark, IL',19639,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46964,NULL,'Newark, IL 60541',19639,222,NULL,17,27032,0);
INSERT INTO "django_geo_db_location" VALUES(46965,NULL,'North Aurora, IL',19640,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46966,NULL,'North Aurora, IL 60542',19640,222,NULL,17,27033,0);
INSERT INTO "django_geo_db_location" VALUES(46967,NULL,'Oswego, IL',19641,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46968,NULL,'Oswego, IL 60543',19641,222,NULL,17,27034,0);
INSERT INTO "django_geo_db_location" VALUES(46969,NULL,'Plainfield, IL',19642,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46970,NULL,'Plainfield, IL 60544',19642,222,NULL,17,27035,0);
INSERT INTO "django_geo_db_location" VALUES(46971,NULL,'Plano, IL',19643,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46972,NULL,'Plano, IL 60545',19643,222,NULL,17,27036,0);
INSERT INTO "django_geo_db_location" VALUES(46973,NULL,'Riverside, IL',19644,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46974,NULL,'Riverside, IL 60546',19644,222,NULL,17,27037,0);
INSERT INTO "django_geo_db_location" VALUES(46975,NULL,'Sandwich, IL',19645,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46976,NULL,'Sandwich, IL 60548',19645,222,NULL,17,27038,0);
INSERT INTO "django_geo_db_location" VALUES(46977,NULL,'Serena, IL',19646,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46978,NULL,'Serena, IL 60549',19646,222,NULL,17,27039,0);
INSERT INTO "django_geo_db_location" VALUES(46979,NULL,'Shabbona, IL',19647,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46980,NULL,'Shabbona, IL 60550',19647,222,NULL,17,27040,0);
INSERT INTO "django_geo_db_location" VALUES(46981,NULL,'Sheridan, IL',19648,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46982,NULL,'Sheridan, IL 60551',19648,222,NULL,17,27041,0);
INSERT INTO "django_geo_db_location" VALUES(46983,NULL,'Somonauk, IL',19649,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46984,NULL,'Somonauk, IL 60552',19649,222,NULL,17,27042,0);
INSERT INTO "django_geo_db_location" VALUES(46985,NULL,'Steward, IL',19650,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46986,NULL,'Steward, IL 60553',19650,222,NULL,17,27043,0);
INSERT INTO "django_geo_db_location" VALUES(46987,NULL,'Sugar Grove, IL',19651,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46988,NULL,'Sugar Grove, IL 60554',19651,222,NULL,17,27044,0);
INSERT INTO "django_geo_db_location" VALUES(46989,NULL,'Warrenville, IL',19652,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46990,NULL,'Warrenville, IL 60555',19652,222,NULL,17,27045,0);
INSERT INTO "django_geo_db_location" VALUES(46991,NULL,'Waterman, IL',19653,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46992,NULL,'Waterman, IL 60556',19653,222,NULL,17,27046,0);
INSERT INTO "django_geo_db_location" VALUES(46993,NULL,'Wedron, IL',19654,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46994,NULL,'Wedron, IL 60557',19654,222,NULL,17,27047,0);
INSERT INTO "django_geo_db_location" VALUES(46995,NULL,'Western Springs, IL',19655,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46996,NULL,'Western Springs, IL 60558',19655,222,NULL,17,27048,0);
INSERT INTO "django_geo_db_location" VALUES(46997,NULL,'Westmont, IL',19656,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(46998,NULL,'Westmont, IL 60559',19656,222,NULL,17,27049,0);
INSERT INTO "django_geo_db_location" VALUES(46999,NULL,'Yorkville, IL',19657,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47000,NULL,'Yorkville, IL 60560',19657,222,NULL,17,27050,0);
INSERT INTO "django_geo_db_location" VALUES(47001,NULL,'Darien, IL',19658,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47002,NULL,'Darien, IL 60561',19658,222,NULL,17,27051,0);
INSERT INTO "django_geo_db_location" VALUES(47003,NULL,'Naperville, IL 60563',19638,222,NULL,17,27052,0);
INSERT INTO "django_geo_db_location" VALUES(47004,NULL,'Naperville, IL 60564',19638,222,NULL,17,27053,0);
INSERT INTO "django_geo_db_location" VALUES(47005,NULL,'Naperville, IL 60565',19638,222,NULL,17,27054,0);
INSERT INTO "django_geo_db_location" VALUES(47006,NULL,'Naperville, IL 60566',19638,222,NULL,17,27055,0);
INSERT INTO "django_geo_db_location" VALUES(47007,NULL,'Naperville, IL 60567',19638,222,NULL,17,27056,0);
INSERT INTO "django_geo_db_location" VALUES(47008,NULL,'Aurora, IL 60568',19615,222,NULL,17,27057,0);
INSERT INTO "django_geo_db_location" VALUES(47009,NULL,'Hinsdale, IL 60570',19626,222,NULL,17,27058,0);
INSERT INTO "django_geo_db_location" VALUES(47010,NULL,'Aurora, IL 60572',19615,222,NULL,17,27059,0);
INSERT INTO "django_geo_db_location" VALUES(47011,NULL,'Fox Valley, IL',19659,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47012,NULL,'Fox Valley, IL 60597',19659,222,NULL,17,27060,0);
INSERT INTO "django_geo_db_location" VALUES(47013,NULL,'Aurora, IL 60598',19615,222,NULL,17,27061,0);
INSERT INTO "django_geo_db_location" VALUES(47014,NULL,'Fox Valley, IL 60599',19659,222,NULL,17,27062,0);
INSERT INTO "django_geo_db_location" VALUES(47015,NULL,'Chicago, IL',19660,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47016,NULL,'Chicago, IL 60601',19660,222,NULL,17,27063,0);
INSERT INTO "django_geo_db_location" VALUES(47017,NULL,'Chicago, IL 60602',19660,222,NULL,17,27064,0);
INSERT INTO "django_geo_db_location" VALUES(47018,NULL,'Chicago, IL 60603',19660,222,NULL,17,27065,0);
INSERT INTO "django_geo_db_location" VALUES(47019,NULL,'Chicago, IL 60604',19660,222,NULL,17,27066,0);
INSERT INTO "django_geo_db_location" VALUES(47020,NULL,'Chicago, IL 60605',19660,222,NULL,17,27067,0);
INSERT INTO "django_geo_db_location" VALUES(47021,NULL,'Chicago, IL 60606',19660,222,NULL,17,27068,0);
INSERT INTO "django_geo_db_location" VALUES(47022,NULL,'Chicago, IL 60607',19660,222,NULL,17,27069,0);
INSERT INTO "django_geo_db_location" VALUES(47023,NULL,'Chicago, IL 60608',19660,222,NULL,17,27070,0);
INSERT INTO "django_geo_db_location" VALUES(47024,NULL,'Chicago, IL 60609',19660,222,NULL,17,27071,0);
INSERT INTO "django_geo_db_location" VALUES(47025,NULL,'Chicago, IL 60610',19660,222,NULL,17,27072,0);
INSERT INTO "django_geo_db_location" VALUES(47026,NULL,'Chicago, IL 60611',19660,222,NULL,17,27073,0);
INSERT INTO "django_geo_db_location" VALUES(47027,NULL,'Chicago, IL 60612',19660,222,NULL,17,27074,0);
INSERT INTO "django_geo_db_location" VALUES(47028,NULL,'Chicago, IL 60613',19660,222,NULL,17,27075,0);
INSERT INTO "django_geo_db_location" VALUES(47029,NULL,'Chicago, IL 60614',19660,222,NULL,17,27076,0);
INSERT INTO "django_geo_db_location" VALUES(47030,NULL,'Chicago, IL 60615',19660,222,NULL,17,27077,0);
INSERT INTO "django_geo_db_location" VALUES(47031,NULL,'Chicago, IL 60616',19660,222,NULL,17,27078,0);
INSERT INTO "django_geo_db_location" VALUES(47032,NULL,'Chicago, IL 60617',19660,222,NULL,17,27079,0);
INSERT INTO "django_geo_db_location" VALUES(47033,NULL,'Chicago, IL 60618',19660,222,NULL,17,27080,0);
INSERT INTO "django_geo_db_location" VALUES(47034,NULL,'Chicago, IL 60619',19660,222,NULL,17,27081,0);
INSERT INTO "django_geo_db_location" VALUES(47035,NULL,'Chicago, IL 60620',19660,222,NULL,17,27082,0);
INSERT INTO "django_geo_db_location" VALUES(47036,NULL,'Chicago, IL 60621',19660,222,NULL,17,27083,0);
INSERT INTO "django_geo_db_location" VALUES(47037,NULL,'Chicago, IL 60622',19660,222,NULL,17,27084,0);
INSERT INTO "django_geo_db_location" VALUES(47038,NULL,'Chicago, IL 60623',19660,222,NULL,17,27085,0);
INSERT INTO "django_geo_db_location" VALUES(47039,NULL,'Chicago, IL 60624',19660,222,NULL,17,27086,0);
INSERT INTO "django_geo_db_location" VALUES(47040,NULL,'Chicago, IL 60625',19660,222,NULL,17,27087,0);
INSERT INTO "django_geo_db_location" VALUES(47041,NULL,'Chicago, IL 60626',19660,222,NULL,17,27088,0);
INSERT INTO "django_geo_db_location" VALUES(47042,NULL,'Chicago, IL 60628',19660,222,NULL,17,27089,0);
INSERT INTO "django_geo_db_location" VALUES(47043,NULL,'Chicago, IL 60629',19660,222,NULL,17,27090,0);
INSERT INTO "django_geo_db_location" VALUES(47044,NULL,'Chicago, IL 60630',19660,222,NULL,17,27091,0);
INSERT INTO "django_geo_db_location" VALUES(47045,NULL,'Chicago, IL 60631',19660,222,NULL,17,27092,0);
INSERT INTO "django_geo_db_location" VALUES(47046,NULL,'Chicago, IL 60632',19660,222,NULL,17,27093,0);
INSERT INTO "django_geo_db_location" VALUES(47047,NULL,'Chicago, IL 60633',19660,222,NULL,17,27094,0);
INSERT INTO "django_geo_db_location" VALUES(47048,NULL,'Chicago, IL 60634',19660,222,NULL,17,27095,0);
INSERT INTO "django_geo_db_location" VALUES(47049,NULL,'Chicago, IL 60636',19660,222,NULL,17,27096,0);
INSERT INTO "django_geo_db_location" VALUES(47050,NULL,'Chicago, IL 60637',19660,222,NULL,17,27097,0);
INSERT INTO "django_geo_db_location" VALUES(47051,NULL,'Chicago, IL 60638',19660,222,NULL,17,27098,0);
INSERT INTO "django_geo_db_location" VALUES(47052,NULL,'Chicago, IL 60639',19660,222,NULL,17,27099,0);
INSERT INTO "django_geo_db_location" VALUES(47053,NULL,'Chicago, IL 60640',19660,222,NULL,17,27100,0);
INSERT INTO "django_geo_db_location" VALUES(47054,NULL,'Chicago, IL 60641',19660,222,NULL,17,27101,0);
INSERT INTO "django_geo_db_location" VALUES(47055,NULL,'Chicago, IL 60643',19660,222,NULL,17,27102,0);
INSERT INTO "django_geo_db_location" VALUES(47056,NULL,'Chicago, IL 60644',19660,222,NULL,17,27103,0);
INSERT INTO "django_geo_db_location" VALUES(47057,NULL,'Chicago, IL 60645',19660,222,NULL,17,27104,0);
INSERT INTO "django_geo_db_location" VALUES(47058,NULL,'Chicago, IL 60646',19660,222,NULL,17,27105,0);
INSERT INTO "django_geo_db_location" VALUES(47059,NULL,'Chicago, IL 60647',19660,222,NULL,17,27106,0);
INSERT INTO "django_geo_db_location" VALUES(47060,NULL,'Peotone, IL 60648',19598,222,NULL,17,27107,0);
INSERT INTO "django_geo_db_location" VALUES(47061,NULL,'Chicago, IL 60649',19660,222,NULL,17,27108,0);
INSERT INTO "django_geo_db_location" VALUES(47062,NULL,'Chicago, IL 60650',19660,222,NULL,17,27109,0);
INSERT INTO "django_geo_db_location" VALUES(47063,NULL,'Chicago, IL 60651',19660,222,NULL,17,27110,0);
INSERT INTO "django_geo_db_location" VALUES(47064,NULL,'Chicago, IL 60652',19660,222,NULL,17,27111,0);
INSERT INTO "django_geo_db_location" VALUES(47065,NULL,'Chicago, IL 60653',19660,222,NULL,17,27112,0);
INSERT INTO "django_geo_db_location" VALUES(47066,NULL,'Chicago, IL 60654',19660,222,NULL,17,27113,0);
INSERT INTO "django_geo_db_location" VALUES(47067,NULL,'Chicago, IL 60655',19660,222,NULL,17,27114,0);
INSERT INTO "django_geo_db_location" VALUES(47068,NULL,'Chicago, IL 60656',19660,222,NULL,17,27115,0);
INSERT INTO "django_geo_db_location" VALUES(47069,NULL,'Chicago, IL 60657',19660,222,NULL,17,27116,0);
INSERT INTO "django_geo_db_location" VALUES(47070,NULL,'Chicago, IL 60659',19660,222,NULL,17,27117,0);
INSERT INTO "django_geo_db_location" VALUES(47071,NULL,'Chicago, IL 60660',19660,222,NULL,17,27118,0);
INSERT INTO "django_geo_db_location" VALUES(47072,NULL,'Chicago, IL 60661',19660,222,NULL,17,27119,0);
INSERT INTO "django_geo_db_location" VALUES(47073,NULL,'Chicago, IL 60663',19660,222,NULL,17,27120,0);
INSERT INTO "django_geo_db_location" VALUES(47074,NULL,'Chicago, IL 60664',19660,222,NULL,17,27121,0);
INSERT INTO "django_geo_db_location" VALUES(47075,NULL,'Chicago, IL 60665',19660,222,NULL,17,27122,0);
INSERT INTO "django_geo_db_location" VALUES(47076,NULL,'Amf Ohare, IL',19661,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47077,NULL,'Amf Ohare, IL 60666',19661,222,NULL,17,27123,0);
INSERT INTO "django_geo_db_location" VALUES(47078,NULL,'Chicago, IL 60667',19660,222,NULL,17,27124,0);
INSERT INTO "django_geo_db_location" VALUES(47079,NULL,'Chicago, IL 60668',19660,222,NULL,17,27125,0);
INSERT INTO "django_geo_db_location" VALUES(47080,NULL,'Chicago, IL 60669',19660,222,NULL,17,27126,0);
INSERT INTO "django_geo_db_location" VALUES(47081,NULL,'Chicago, IL 60670',19660,222,NULL,17,27127,0);
INSERT INTO "django_geo_db_location" VALUES(47082,NULL,'Chicago, IL 60671',19660,222,NULL,17,27128,0);
INSERT INTO "django_geo_db_location" VALUES(47083,NULL,'Chicago, IL 60672',19660,222,NULL,17,27129,0);
INSERT INTO "django_geo_db_location" VALUES(47084,NULL,'Chicago, IL 60673',19660,222,NULL,17,27130,0);
INSERT INTO "django_geo_db_location" VALUES(47085,NULL,'Chicago, IL 60674',19660,222,NULL,17,27131,0);
INSERT INTO "django_geo_db_location" VALUES(47086,NULL,'Chicago, IL 60675',19660,222,NULL,17,27132,0);
INSERT INTO "django_geo_db_location" VALUES(47087,NULL,'Chicago, IL 60677',19660,222,NULL,17,27133,0);
INSERT INTO "django_geo_db_location" VALUES(47088,NULL,'Chicago, IL 60678',19660,222,NULL,17,27134,0);
INSERT INTO "django_geo_db_location" VALUES(47089,NULL,'Chicago, IL 60679',19660,222,NULL,17,27135,0);
INSERT INTO "django_geo_db_location" VALUES(47090,NULL,'Chicago, IL 60680',19660,222,NULL,17,27136,0);
INSERT INTO "django_geo_db_location" VALUES(47091,NULL,'Chicago, IL 60681',19660,222,NULL,17,27137,0);
INSERT INTO "django_geo_db_location" VALUES(47092,NULL,'Chicago, IL 60683',19660,222,NULL,17,27138,0);
INSERT INTO "django_geo_db_location" VALUES(47093,NULL,'Chicago, IL 60684',19660,222,NULL,17,27139,0);
INSERT INTO "django_geo_db_location" VALUES(47094,NULL,'Chicago, IL 60685',19660,222,NULL,17,27140,0);
INSERT INTO "django_geo_db_location" VALUES(47095,NULL,'Chicago, IL 60687',19660,222,NULL,17,27141,0);
INSERT INTO "django_geo_db_location" VALUES(47096,NULL,'Chicago, IL 60690',19660,222,NULL,17,27142,0);
INSERT INTO "django_geo_db_location" VALUES(47097,NULL,'Chicago, IL 60691',19660,222,NULL,17,27143,0);
INSERT INTO "django_geo_db_location" VALUES(47098,NULL,'Chicago, IL 60692',19660,222,NULL,17,27144,0);
INSERT INTO "django_geo_db_location" VALUES(47099,NULL,'Chicago, IL 60693',19660,222,NULL,17,27145,0);
INSERT INTO "django_geo_db_location" VALUES(47100,NULL,'Chicago, IL 60694',19660,222,NULL,17,27146,0);
INSERT INTO "django_geo_db_location" VALUES(47101,NULL,'Chicago, IL 60697',19660,222,NULL,17,27147,0);
INSERT INTO "django_geo_db_location" VALUES(47102,NULL,'Chicago, IL 60699',19660,222,NULL,17,27148,0);
INSERT INTO "django_geo_db_location" VALUES(47103,NULL,'Chicago, IL 60701',19660,222,NULL,17,27149,0);
INSERT INTO "django_geo_db_location" VALUES(47104,NULL,'Harwood Heights, IL',19662,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47105,NULL,'Harwood Heights, IL 60706',19662,222,NULL,17,27150,0);
INSERT INTO "django_geo_db_location" VALUES(47106,NULL,'Elmwood Park, IL',19663,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47107,NULL,'Elmwood Park, IL 60707',19663,222,NULL,17,27151,0);
INSERT INTO "django_geo_db_location" VALUES(47108,NULL,'Lincolnwood, IL',19664,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47109,NULL,'Lincolnwood, IL 60712',19664,222,NULL,17,27152,0);
INSERT INTO "django_geo_db_location" VALUES(47110,NULL,'Niles, IL',19665,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47111,NULL,'Niles, IL 60714',19665,222,NULL,17,27153,0);
INSERT INTO "django_geo_db_location" VALUES(47112,NULL,'Alsip, IL',19666,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47113,NULL,'Alsip, IL 60803',19666,222,NULL,17,27154,0);
INSERT INTO "django_geo_db_location" VALUES(47114,NULL,'Cicero, IL',19667,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47115,NULL,'Cicero, IL 60804',19667,222,NULL,17,27155,0);
INSERT INTO "django_geo_db_location" VALUES(47116,NULL,'Evergreen Park, IL',19668,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47117,NULL,'Evergreen Park, IL 60805',19668,222,NULL,17,27156,0);
INSERT INTO "django_geo_db_location" VALUES(47118,NULL,'Riverdale, IL',19669,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47119,NULL,'Riverdale, IL 60827',19669,222,NULL,17,27157,0);
INSERT INTO "django_geo_db_location" VALUES(47120,NULL,'Kankakee, IL',19670,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47121,NULL,'Kankakee, IL 60901',19670,222,NULL,17,27158,0);
INSERT INTO "django_geo_db_location" VALUES(47122,NULL,'Kankakee, IL 60902',19670,222,NULL,17,27159,0);
INSERT INTO "django_geo_db_location" VALUES(47123,NULL,'Aroma Park, IL',19671,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47124,NULL,'Aroma Park, IL 60910',19671,222,NULL,17,27160,0);
INSERT INTO "django_geo_db_location" VALUES(47125,NULL,'Ashkum, IL',19672,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47126,NULL,'Ashkum, IL 60911',19672,222,NULL,17,27161,0);
INSERT INTO "django_geo_db_location" VALUES(47127,NULL,'Beaverville, IL',19673,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47128,NULL,'Beaverville, IL 60912',19673,222,NULL,17,27162,0);
INSERT INTO "django_geo_db_location" VALUES(47129,NULL,'Bonfield, IL',19674,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47130,NULL,'Bonfield, IL 60913',19674,222,NULL,17,27163,0);
INSERT INTO "django_geo_db_location" VALUES(47131,NULL,'Bourbonnais, IL',19675,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47132,NULL,'Bourbonnais, IL 60914',19675,222,NULL,17,27164,0);
INSERT INTO "django_geo_db_location" VALUES(47133,NULL,'Bradley, IL',19676,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47134,NULL,'Bradley, IL 60915',19676,222,NULL,17,27165,0);
INSERT INTO "django_geo_db_location" VALUES(47135,NULL,'Buckingham, IL',19677,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47136,NULL,'Buckingham, IL 60917',19677,222,NULL,17,27166,0);
INSERT INTO "django_geo_db_location" VALUES(47137,NULL,'Buckley, IL',19678,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47138,NULL,'Buckley, IL 60918',19678,222,NULL,17,27167,0);
INSERT INTO "django_geo_db_location" VALUES(47139,NULL,'Cabery, IL',19679,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47140,NULL,'Cabery, IL 60919',19679,222,NULL,17,27168,0);
INSERT INTO "django_geo_db_location" VALUES(47141,NULL,'Campus, IL',19680,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47142,NULL,'Campus, IL 60920',19680,222,NULL,17,27169,0);
INSERT INTO "django_geo_db_location" VALUES(47143,NULL,'Chatsworth, IL',19681,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47144,NULL,'Chatsworth, IL 60921',19681,222,NULL,17,27170,0);
INSERT INTO "django_geo_db_location" VALUES(47145,NULL,'Chebanse, IL',19682,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47146,NULL,'Chebanse, IL 60922',19682,222,NULL,17,27171,0);
INSERT INTO "django_geo_db_location" VALUES(47147,NULL,'Cissna Park, IL',19683,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47148,NULL,'Cissna Park, IL 60924',19683,222,NULL,17,27172,0);
INSERT INTO "django_geo_db_location" VALUES(47149,NULL,'Claytonville, IL',19684,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47150,NULL,'Claytonville, IL 60926',19684,222,NULL,17,27173,0);
INSERT INTO "django_geo_db_location" VALUES(47151,NULL,'Clifton, IL',19685,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47152,NULL,'Clifton, IL 60927',19685,222,NULL,17,27174,0);
INSERT INTO "django_geo_db_location" VALUES(47153,NULL,'Crescent City, IL',19686,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47154,NULL,'Crescent City, IL 60928',19686,222,NULL,17,27175,0);
INSERT INTO "django_geo_db_location" VALUES(47155,NULL,'Cullom, IL',19687,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47156,NULL,'Cullom, IL 60929',19687,222,NULL,17,27176,0);
INSERT INTO "django_geo_db_location" VALUES(47157,NULL,'Danforth, IL',19688,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47158,NULL,'Danforth, IL 60930',19688,222,NULL,17,27177,0);
INSERT INTO "django_geo_db_location" VALUES(47159,NULL,'Donovan, IL',19689,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47160,NULL,'Donovan, IL 60931',19689,222,NULL,17,27178,0);
INSERT INTO "django_geo_db_location" VALUES(47161,NULL,'East Lynn, IL',19690,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47162,NULL,'East Lynn, IL 60932',19690,222,NULL,17,27179,0);
INSERT INTO "django_geo_db_location" VALUES(47163,NULL,'Elliott, IL',19691,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47164,NULL,'Elliott, IL 60933',19691,222,NULL,17,27180,0);
INSERT INTO "django_geo_db_location" VALUES(47165,NULL,'Emington, IL',19692,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47166,NULL,'Emington, IL 60934',19692,222,NULL,17,27181,0);
INSERT INTO "django_geo_db_location" VALUES(47167,NULL,'Essex, IL',19693,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47168,NULL,'Essex, IL 60935',19693,222,NULL,17,27182,0);
INSERT INTO "django_geo_db_location" VALUES(47169,NULL,'Gibson City, IL',19694,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47170,NULL,'Gibson City, IL 60936',19694,222,NULL,17,27183,0);
INSERT INTO "django_geo_db_location" VALUES(47171,NULL,'Gilman, IL',19695,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47172,NULL,'Gilman, IL 60938',19695,222,NULL,17,27184,0);
INSERT INTO "django_geo_db_location" VALUES(47173,NULL,'Goodwine, IL',19696,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47174,NULL,'Goodwine, IL 60939',19696,222,NULL,17,27185,0);
INSERT INTO "django_geo_db_location" VALUES(47175,NULL,'Grant Park, IL',19697,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47176,NULL,'Grant Park, IL 60940',19697,222,NULL,17,27186,0);
INSERT INTO "django_geo_db_location" VALUES(47177,NULL,'Herscher, IL',19698,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47178,NULL,'Herscher, IL 60941',19698,222,NULL,17,27187,0);
INSERT INTO "django_geo_db_location" VALUES(47179,NULL,'Hoopeston, IL',19699,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47180,NULL,'Hoopeston, IL 60942',19699,222,NULL,17,27188,0);
INSERT INTO "django_geo_db_location" VALUES(47181,NULL,'Hopkins Park, IL',19700,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47182,NULL,'Hopkins Park, IL 60944',19700,222,NULL,17,27189,0);
INSERT INTO "django_geo_db_location" VALUES(47183,NULL,'Iroquois, IL',19701,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47184,NULL,'Iroquois, IL 60945',19701,222,NULL,17,27190,0);
INSERT INTO "django_geo_db_location" VALUES(47185,NULL,'Kempton, IL',19702,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47186,NULL,'Kempton, IL 60946',19702,222,NULL,17,27191,0);
INSERT INTO "django_geo_db_location" VALUES(47187,NULL,'Loda, IL',19703,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47188,NULL,'Loda, IL 60948',19703,222,NULL,17,27192,0);
INSERT INTO "django_geo_db_location" VALUES(47189,NULL,'Ludlow, IL',19704,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47190,NULL,'Ludlow, IL 60949',19704,222,NULL,17,27193,0);
INSERT INTO "django_geo_db_location" VALUES(47191,NULL,'Manteno, IL',19705,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47192,NULL,'Manteno, IL 60950',19705,222,NULL,17,27194,0);
INSERT INTO "django_geo_db_location" VALUES(47193,NULL,'Martinton, IL',19706,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47194,NULL,'Martinton, IL 60951',19706,222,NULL,17,27195,0);
INSERT INTO "django_geo_db_location" VALUES(47195,NULL,'Melvin, IL',19707,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47196,NULL,'Melvin, IL 60952',19707,222,NULL,17,27196,0);
INSERT INTO "django_geo_db_location" VALUES(47197,NULL,'Milford, IL',19708,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47198,NULL,'Milford, IL 60953',19708,222,NULL,17,27197,0);
INSERT INTO "django_geo_db_location" VALUES(47199,NULL,'Momence, IL',19709,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47200,NULL,'Momence, IL 60954',19709,222,NULL,17,27198,0);
INSERT INTO "django_geo_db_location" VALUES(47201,NULL,'Onarga, IL',19710,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47202,NULL,'Onarga, IL 60955',19710,222,NULL,17,27199,0);
INSERT INTO "django_geo_db_location" VALUES(47203,NULL,'Papineau, IL',19711,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47204,NULL,'Papineau, IL 60956',19711,222,NULL,17,27200,0);
INSERT INTO "django_geo_db_location" VALUES(47205,NULL,'Paxton, IL',19712,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47206,NULL,'Paxton, IL 60957',19712,222,NULL,17,27201,0);
INSERT INTO "django_geo_db_location" VALUES(47207,NULL,'Piper City, IL',19713,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47208,NULL,'Piper City, IL 60959',19713,222,NULL,17,27202,0);
INSERT INTO "django_geo_db_location" VALUES(47209,NULL,'Rankin, IL',19714,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47210,NULL,'Rankin, IL 60960',19714,222,NULL,17,27203,0);
INSERT INTO "django_geo_db_location" VALUES(47211,NULL,'Reddick, IL',19715,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47212,NULL,'Reddick, IL 60961',19715,222,NULL,17,27204,0);
INSERT INTO "django_geo_db_location" VALUES(47213,NULL,'Roberts, IL',19716,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47214,NULL,'Roberts, IL 60962',19716,222,NULL,17,27205,0);
INSERT INTO "django_geo_db_location" VALUES(47215,NULL,'Rossville, IL',19717,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47216,NULL,'Rossville, IL 60963',19717,222,NULL,17,27206,0);
INSERT INTO "django_geo_db_location" VALUES(47217,NULL,'Saint Anne, IL',19718,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47218,NULL,'Saint Anne, IL 60964',19718,222,NULL,17,27207,0);
INSERT INTO "django_geo_db_location" VALUES(47219,NULL,'Sheldon, IL',19719,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47220,NULL,'Sheldon, IL 60966',19719,222,NULL,17,27208,0);
INSERT INTO "django_geo_db_location" VALUES(47221,NULL,'Stockland, IL',19720,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47222,NULL,'Stockland, IL 60967',19720,222,NULL,17,27209,0);
INSERT INTO "django_geo_db_location" VALUES(47223,NULL,'Thawville, IL',19721,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47224,NULL,'Thawville, IL 60968',19721,222,NULL,17,27210,0);
INSERT INTO "django_geo_db_location" VALUES(47225,NULL,'Union Hill, IL',19722,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47226,NULL,'Union Hill, IL 60969',19722,222,NULL,17,27211,0);
INSERT INTO "django_geo_db_location" VALUES(47227,NULL,'Watseka, IL',19723,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47228,NULL,'Watseka, IL 60970',19723,222,NULL,17,27212,0);
INSERT INTO "django_geo_db_location" VALUES(47229,NULL,'Wellington, IL',19724,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47230,NULL,'Wellington, IL 60973',19724,222,NULL,17,27213,0);
INSERT INTO "django_geo_db_location" VALUES(47231,NULL,'Woodland, IL',19725,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47232,NULL,'Woodland, IL 60974',19725,222,NULL,17,27214,0);
INSERT INTO "django_geo_db_location" VALUES(47233,NULL,'Apple River, IL',19726,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47234,NULL,'Apple River, IL 61001',19726,222,NULL,17,27215,0);
INSERT INTO "django_geo_db_location" VALUES(47235,NULL,'Ashton, IL',19727,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47236,NULL,'Ashton, IL 61006',19727,222,NULL,17,27216,0);
INSERT INTO "django_geo_db_location" VALUES(47237,NULL,'Baileyville, IL',19728,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47238,NULL,'Baileyville, IL 61007',19728,222,NULL,17,27217,0);
INSERT INTO "django_geo_db_location" VALUES(47239,NULL,'Belvidere, IL',19729,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47240,NULL,'Belvidere, IL 61008',19729,222,NULL,17,27218,0);
INSERT INTO "django_geo_db_location" VALUES(47241,NULL,'Byron, IL',19730,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47242,NULL,'Byron, IL 61010',19730,222,NULL,17,27219,0);
INSERT INTO "django_geo_db_location" VALUES(47243,NULL,'Caledonia, IL',19731,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47244,NULL,'Caledonia, IL 61011',19731,222,NULL,17,27220,0);
INSERT INTO "django_geo_db_location" VALUES(47245,NULL,'Capron, IL',19732,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47246,NULL,'Capron, IL 61012',19732,222,NULL,17,27221,0);
INSERT INTO "django_geo_db_location" VALUES(47247,NULL,'Cedarville, IL',19733,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47248,NULL,'Cedarville, IL 61013',19733,222,NULL,17,27222,0);
INSERT INTO "django_geo_db_location" VALUES(47249,NULL,'Chadwick, IL',19734,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47250,NULL,'Chadwick, IL 61014',19734,222,NULL,17,27223,0);
INSERT INTO "django_geo_db_location" VALUES(47251,NULL,'Chana, IL',19735,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47252,NULL,'Chana, IL 61015',19735,222,NULL,17,27224,0);
INSERT INTO "django_geo_db_location" VALUES(47253,NULL,'Cherry Valley, IL',19736,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47254,NULL,'Cherry Valley, IL 61016',19736,222,NULL,17,27225,0);
INSERT INTO "django_geo_db_location" VALUES(47255,NULL,'Coleta, IL',19737,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47256,NULL,'Coleta, IL 61017',19737,222,NULL,17,27226,0);
INSERT INTO "django_geo_db_location" VALUES(47257,NULL,'Dakota, IL',19738,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47258,NULL,'Dakota, IL 61018',19738,222,NULL,17,27227,0);
INSERT INTO "django_geo_db_location" VALUES(47259,NULL,'Davis, IL',19739,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47260,NULL,'Davis, IL 61019',19739,222,NULL,17,27228,0);
INSERT INTO "django_geo_db_location" VALUES(47261,NULL,'Davis Junction, IL',19740,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47262,NULL,'Davis Junction, IL 61020',19740,222,NULL,17,27229,0);
INSERT INTO "django_geo_db_location" VALUES(47263,NULL,'Dixon, IL',19741,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47264,NULL,'Dixon, IL 61021',19741,222,NULL,17,27230,0);
INSERT INTO "django_geo_db_location" VALUES(47265,NULL,'Durand, IL',19742,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47266,NULL,'Durand, IL 61024',19742,222,NULL,17,27231,0);
INSERT INTO "django_geo_db_location" VALUES(47267,NULL,'East Dubuque, IL',19743,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47268,NULL,'East Dubuque, IL 61025',19743,222,NULL,17,27232,0);
INSERT INTO "django_geo_db_location" VALUES(47269,NULL,'Eleroy, IL',19744,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47270,NULL,'Eleroy, IL 61027',19744,222,NULL,17,27233,0);
INSERT INTO "django_geo_db_location" VALUES(47271,NULL,'Elizabeth, IL',19745,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47272,NULL,'Elizabeth, IL 61028',19745,222,NULL,17,27234,0);
INSERT INTO "django_geo_db_location" VALUES(47273,NULL,'Forreston, IL',19746,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47274,NULL,'Forreston, IL 61030',19746,222,NULL,17,27235,0);
INSERT INTO "django_geo_db_location" VALUES(47275,NULL,'Franklin Grove, IL',19747,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47276,NULL,'Franklin Grove, IL 61031',19747,222,NULL,17,27236,0);
INSERT INTO "django_geo_db_location" VALUES(47277,NULL,'Freeport, IL',19748,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47278,NULL,'Freeport, IL 61032',19748,222,NULL,17,27237,0);
INSERT INTO "django_geo_db_location" VALUES(47279,NULL,'Galena, IL',19749,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47280,NULL,'Galena, IL 61036',19749,222,NULL,17,27238,0);
INSERT INTO "django_geo_db_location" VALUES(47281,NULL,'Galt, IL',19750,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47282,NULL,'Galt, IL 61037',19750,222,NULL,17,27239,0);
INSERT INTO "django_geo_db_location" VALUES(47283,NULL,'Garden Prairie, IL',19751,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47284,NULL,'Garden Prairie, IL 61038',19751,222,NULL,17,27240,0);
INSERT INTO "django_geo_db_location" VALUES(47285,NULL,'German Valley, IL',19752,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47286,NULL,'German Valley, IL 61039',19752,222,NULL,17,27241,0);
INSERT INTO "django_geo_db_location" VALUES(47287,NULL,'Hanover, IL',19753,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47288,NULL,'Hanover, IL 61041',19753,222,NULL,17,27242,0);
INSERT INTO "django_geo_db_location" VALUES(47289,NULL,'Harmon, IL',19754,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47290,NULL,'Harmon, IL 61042',19754,222,NULL,17,27243,0);
INSERT INTO "django_geo_db_location" VALUES(47291,NULL,'Holcomb, IL',19755,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47292,NULL,'Holcomb, IL 61043',19755,222,NULL,17,27244,0);
INSERT INTO "django_geo_db_location" VALUES(47293,NULL,'Kent, IL',19756,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47294,NULL,'Kent, IL 61044',19756,222,NULL,17,27245,0);
INSERT INTO "django_geo_db_location" VALUES(47295,NULL,'Lanark, IL',19757,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47296,NULL,'Lanark, IL 61046',19757,222,NULL,17,27246,0);
INSERT INTO "django_geo_db_location" VALUES(47297,NULL,'Leaf River, IL',19758,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47298,NULL,'Leaf River, IL 61047',19758,222,NULL,17,27247,0);
INSERT INTO "django_geo_db_location" VALUES(47299,NULL,'Lena, IL',19759,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47300,NULL,'Lena, IL 61048',19759,222,NULL,17,27248,0);
INSERT INTO "django_geo_db_location" VALUES(47301,NULL,'Lindenwood, IL',19760,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47302,NULL,'Lindenwood, IL 61049',19760,222,NULL,17,27249,0);
INSERT INTO "django_geo_db_location" VALUES(47303,NULL,'McConnell, IL',19761,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47304,NULL,'McConnell, IL 61050',19761,222,NULL,17,27250,0);
INSERT INTO "django_geo_db_location" VALUES(47305,NULL,'Milledgeville, IL',19762,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47306,NULL,'Milledgeville, IL 61051',19762,222,NULL,17,27251,0);
INSERT INTO "django_geo_db_location" VALUES(47307,NULL,'Monroe Center, IL',19763,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47308,NULL,'Monroe Center, IL 61052',19763,222,NULL,17,27252,0);
INSERT INTO "django_geo_db_location" VALUES(47309,NULL,'Mount Carroll, IL',19764,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47310,NULL,'Mount Carroll, IL 61053',19764,222,NULL,17,27253,0);
INSERT INTO "django_geo_db_location" VALUES(47311,NULL,'Mount Morris, IL',19765,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47312,NULL,'Mount Morris, IL 61054',19765,222,NULL,17,27254,0);
INSERT INTO "django_geo_db_location" VALUES(47313,NULL,'Nachusa, IL',19766,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47314,NULL,'Nachusa, IL 61057',19766,222,NULL,17,27255,0);
INSERT INTO "django_geo_db_location" VALUES(47315,NULL,'Nelson, IL',19767,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47316,NULL,'Nelson, IL 61058',19767,222,NULL,17,27256,0);
INSERT INTO "django_geo_db_location" VALUES(47317,NULL,'Nora, IL',19768,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47318,NULL,'Nora, IL 61059',19768,222,NULL,17,27257,0);
INSERT INTO "django_geo_db_location" VALUES(47319,NULL,'Orangeville, IL',19769,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47320,NULL,'Orangeville, IL 61060',19769,222,NULL,17,27258,0);
INSERT INTO "django_geo_db_location" VALUES(47321,NULL,'Oregon, IL',19770,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47322,NULL,'Oregon, IL 61061',19770,222,NULL,17,27259,0);
INSERT INTO "django_geo_db_location" VALUES(47323,NULL,'Pearl City, IL',19771,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47324,NULL,'Pearl City, IL 61062',19771,222,NULL,17,27260,0);
INSERT INTO "django_geo_db_location" VALUES(47325,NULL,'Pecatonica, IL',19772,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47326,NULL,'Pecatonica, IL 61063',19772,222,NULL,17,27261,0);
INSERT INTO "django_geo_db_location" VALUES(47327,NULL,'Polo, IL',19773,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47328,NULL,'Polo, IL 61064',19773,222,NULL,17,27262,0);
INSERT INTO "django_geo_db_location" VALUES(47329,NULL,'Poplar Grove, IL',19774,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47330,NULL,'Poplar Grove, IL 61065',19774,222,NULL,17,27263,0);
INSERT INTO "django_geo_db_location" VALUES(47331,NULL,'Ridott, IL',19775,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47332,NULL,'Ridott, IL 61067',19775,222,NULL,17,27264,0);
INSERT INTO "django_geo_db_location" VALUES(47333,NULL,'Rochelle, IL',19776,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47334,NULL,'Rochelle, IL 61068',19776,222,NULL,17,27265,0);
INSERT INTO "django_geo_db_location" VALUES(47335,NULL,'Rock City, IL',19777,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47336,NULL,'Rock City, IL 61070',19777,222,NULL,17,27266,0);
INSERT INTO "django_geo_db_location" VALUES(47337,NULL,'Rock Falls, IL',19778,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47338,NULL,'Rock Falls, IL 61071',19778,222,NULL,17,27267,0);
INSERT INTO "django_geo_db_location" VALUES(47339,NULL,'Rockton, IL',19779,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47340,NULL,'Rockton, IL 61072',19779,222,NULL,17,27268,0);
INSERT INTO "django_geo_db_location" VALUES(47341,NULL,'Roscoe, IL',19780,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47342,NULL,'Roscoe, IL 61073',19780,222,NULL,17,27269,0);
INSERT INTO "django_geo_db_location" VALUES(47343,NULL,'Savanna, IL',19781,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47344,NULL,'Savanna, IL 61074',19781,222,NULL,17,27270,0);
INSERT INTO "django_geo_db_location" VALUES(47345,NULL,'Scales Mound, IL',19782,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47346,NULL,'Scales Mound, IL 61075',19782,222,NULL,17,27271,0);
INSERT INTO "django_geo_db_location" VALUES(47347,NULL,'Scioto Mills, IL',19783,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47348,NULL,'Scioto Mills, IL 61076',19783,222,NULL,17,27272,0);
INSERT INTO "django_geo_db_location" VALUES(47349,NULL,'Seward, IL',19784,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47350,NULL,'Seward, IL 61077',19784,222,NULL,17,27273,0);
INSERT INTO "django_geo_db_location" VALUES(47351,NULL,'Shannon, IL',19785,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47352,NULL,'Shannon, IL 61078',19785,222,NULL,17,27274,0);
INSERT INTO "django_geo_db_location" VALUES(47353,NULL,'Shirland, IL',19786,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47354,NULL,'Shirland, IL 61079',19786,222,NULL,17,27275,0);
INSERT INTO "django_geo_db_location" VALUES(47355,NULL,'South Beloit, IL',19787,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47356,NULL,'South Beloit, IL 61080',19787,222,NULL,17,27276,0);
INSERT INTO "django_geo_db_location" VALUES(47357,NULL,'Sterling, IL',19788,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47358,NULL,'Sterling, IL 61081',19788,222,NULL,17,27277,0);
INSERT INTO "django_geo_db_location" VALUES(47359,NULL,'Stillman Valley, IL',19789,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47360,NULL,'Stillman Valley, IL 61084',19789,222,NULL,17,27278,0);
INSERT INTO "django_geo_db_location" VALUES(47361,NULL,'Stockton, IL',19790,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47362,NULL,'Stockton, IL 61085',19790,222,NULL,17,27279,0);
INSERT INTO "django_geo_db_location" VALUES(47363,NULL,'Warren, IL',19791,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47364,NULL,'Warren, IL 61087',19791,222,NULL,17,27280,0);
INSERT INTO "django_geo_db_location" VALUES(47365,NULL,'Winnebago, IL',19792,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47366,NULL,'Winnebago, IL 61088',19792,222,NULL,17,27281,0);
INSERT INTO "django_geo_db_location" VALUES(47367,NULL,'Winslow, IL',19793,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47368,NULL,'Winslow, IL 61089',19793,222,NULL,17,27282,0);
INSERT INTO "django_geo_db_location" VALUES(47369,NULL,'Woosung, IL',19794,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47370,NULL,'Woosung, IL 61091',19794,222,NULL,17,27283,0);
INSERT INTO "django_geo_db_location" VALUES(47371,NULL,'Rockford, IL',19795,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47372,NULL,'Rockford, IL 61101',19795,222,NULL,17,27284,0);
INSERT INTO "django_geo_db_location" VALUES(47373,NULL,'Rockford, IL 61102',19795,222,NULL,17,27285,0);
INSERT INTO "django_geo_db_location" VALUES(47374,NULL,'Rockford, IL 61103',19795,222,NULL,17,27286,0);
INSERT INTO "django_geo_db_location" VALUES(47375,NULL,'Rockford, IL 61104',19795,222,NULL,17,27287,0);
INSERT INTO "django_geo_db_location" VALUES(47376,NULL,'Rockford, IL 61105',19795,222,NULL,17,27288,0);
INSERT INTO "django_geo_db_location" VALUES(47377,NULL,'Rockford, IL 61106',19795,222,NULL,17,27289,0);
INSERT INTO "django_geo_db_location" VALUES(47378,NULL,'Rockford, IL 61107',19795,222,NULL,17,27290,0);
INSERT INTO "django_geo_db_location" VALUES(47379,NULL,'Rockford, IL 61108',19795,222,NULL,17,27291,0);
INSERT INTO "django_geo_db_location" VALUES(47380,NULL,'Rockford, IL 61109',19795,222,NULL,17,27292,0);
INSERT INTO "django_geo_db_location" VALUES(47381,NULL,'Rockford, IL 61110',19795,222,NULL,17,27293,0);
INSERT INTO "django_geo_db_location" VALUES(47382,NULL,'Loves Park, IL',19796,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47383,NULL,'Loves Park, IL 61111',19796,222,NULL,17,27294,0);
INSERT INTO "django_geo_db_location" VALUES(47384,NULL,'Rockford, IL 61112',19795,222,NULL,17,27295,0);
INSERT INTO "django_geo_db_location" VALUES(47385,NULL,'Rockford, IL 61114',19795,222,NULL,17,27296,0);
INSERT INTO "django_geo_db_location" VALUES(47386,NULL,'Machesney Park, IL',19797,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47387,NULL,'Machesney Park, IL 61115',19797,222,NULL,17,27297,0);
INSERT INTO "django_geo_db_location" VALUES(47388,NULL,'Rockford, IL 61125',19795,222,NULL,17,27298,0);
INSERT INTO "django_geo_db_location" VALUES(47389,NULL,'Rockford, IL 61126',19795,222,NULL,17,27299,0);
INSERT INTO "django_geo_db_location" VALUES(47390,NULL,'Loves Park, IL 61130',19796,222,NULL,17,27300,0);
INSERT INTO "django_geo_db_location" VALUES(47391,NULL,'Loves Park, IL 61131',19796,222,NULL,17,27301,0);
INSERT INTO "django_geo_db_location" VALUES(47392,NULL,'Loves Park, IL 61132',19796,222,NULL,17,27302,0);
INSERT INTO "django_geo_db_location" VALUES(47393,NULL,'Rock Island, IL',19798,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47394,NULL,'Rock Island, IL 61201',19798,222,NULL,17,27303,0);
INSERT INTO "django_geo_db_location" VALUES(47395,NULL,'Rock Island, IL 61202',19798,222,NULL,17,27304,0);
INSERT INTO "django_geo_db_location" VALUES(47396,NULL,'Rock Island, IL 61204',19798,222,NULL,17,27305,0);
INSERT INTO "django_geo_db_location" VALUES(47397,NULL,'Rock Island, IL 61206',19798,222,NULL,17,27306,0);
INSERT INTO "django_geo_db_location" VALUES(47398,NULL,'Albany, IL',19799,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47399,NULL,'Albany, IL 61230',19799,222,NULL,17,27307,0);
INSERT INTO "django_geo_db_location" VALUES(47400,NULL,'Aledo, IL',19800,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47401,NULL,'Aledo, IL 61231',19800,222,NULL,17,27308,0);
INSERT INTO "django_geo_db_location" VALUES(47402,NULL,'Andalusia, IL',19801,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47403,NULL,'Andalusia, IL 61232',19801,222,NULL,17,27309,0);
INSERT INTO "django_geo_db_location" VALUES(47404,NULL,'Andover, IL',19802,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47405,NULL,'Andover, IL 61233',19802,222,NULL,17,27310,0);
INSERT INTO "django_geo_db_location" VALUES(47406,NULL,'Annawan, IL',19803,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47407,NULL,'Annawan, IL 61234',19803,222,NULL,17,27311,0);
INSERT INTO "django_geo_db_location" VALUES(47408,NULL,'Atkinson, IL',19804,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47409,NULL,'Atkinson, IL 61235',19804,222,NULL,17,27312,0);
INSERT INTO "django_geo_db_location" VALUES(47410,NULL,'Barstow, IL',19805,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47411,NULL,'Barstow, IL 61236',19805,222,NULL,17,27313,0);
INSERT INTO "django_geo_db_location" VALUES(47412,NULL,'Buffalo Prairie, IL',19806,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47413,NULL,'Buffalo Prairie, IL 61237',19806,222,NULL,17,27314,0);
INSERT INTO "django_geo_db_location" VALUES(47414,NULL,'Cambridge, IL',19807,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47415,NULL,'Cambridge, IL 61238',19807,222,NULL,17,27315,0);
INSERT INTO "django_geo_db_location" VALUES(47416,NULL,'Carbon Cliff, IL',19808,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47417,NULL,'Carbon Cliff, IL 61239',19808,222,NULL,17,27316,0);
INSERT INTO "django_geo_db_location" VALUES(47418,NULL,'Coal Valley, IL',19809,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47419,NULL,'Coal Valley, IL 61240',19809,222,NULL,17,27317,0);
INSERT INTO "django_geo_db_location" VALUES(47420,NULL,'Colona, IL',19810,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47421,NULL,'Colona, IL 61241',19810,222,NULL,17,27318,0);
INSERT INTO "django_geo_db_location" VALUES(47422,NULL,'Cordova, IL',19811,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47423,NULL,'Cordova, IL 61242',19811,222,NULL,17,27319,0);
INSERT INTO "django_geo_db_location" VALUES(47424,NULL,'Deer Grove, IL',19812,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47425,NULL,'Deer Grove, IL 61243',19812,222,NULL,17,27320,0);
INSERT INTO "django_geo_db_location" VALUES(47426,NULL,'East Moline, IL',19813,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47427,NULL,'East Moline, IL 61244',19813,222,NULL,17,27321,0);
INSERT INTO "django_geo_db_location" VALUES(47428,NULL,'Erie, IL',19814,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47429,NULL,'Erie, IL 61250',19814,222,NULL,17,27322,0);
INSERT INTO "django_geo_db_location" VALUES(47430,NULL,'Fenton, IL',19815,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47431,NULL,'Fenton, IL 61251',19815,222,NULL,17,27323,0);
INSERT INTO "django_geo_db_location" VALUES(47432,NULL,'Fulton, IL',19816,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47433,NULL,'Fulton, IL 61252',19816,222,NULL,17,27324,0);
INSERT INTO "django_geo_db_location" VALUES(47434,NULL,'Geneseo, IL',19817,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47435,NULL,'Geneseo, IL 61254',19817,222,NULL,17,27325,0);
INSERT INTO "django_geo_db_location" VALUES(47436,NULL,'Hampton, IL',19818,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47437,NULL,'Hampton, IL 61256',19818,222,NULL,17,27326,0);
INSERT INTO "django_geo_db_location" VALUES(47438,NULL,'Hillsdale, IL',19819,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47439,NULL,'Hillsdale, IL 61257',19819,222,NULL,17,27327,0);
INSERT INTO "django_geo_db_location" VALUES(47440,NULL,'Hooppole, IL',19820,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47441,NULL,'Hooppole, IL 61258',19820,222,NULL,17,27328,0);
INSERT INTO "django_geo_db_location" VALUES(47442,NULL,'Illinois City, IL',19821,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47443,NULL,'Illinois City, IL 61259',19821,222,NULL,17,27329,0);
INSERT INTO "django_geo_db_location" VALUES(47444,NULL,'Joy, IL',19822,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47445,NULL,'Joy, IL 61260',19822,222,NULL,17,27330,0);
INSERT INTO "django_geo_db_location" VALUES(47446,NULL,'Lyndon, IL',19823,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47447,NULL,'Lyndon, IL 61261',19823,222,NULL,17,27331,0);
INSERT INTO "django_geo_db_location" VALUES(47448,NULL,'Lynn Center, IL',19824,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47449,NULL,'Lynn Center, IL 61262',19824,222,NULL,17,27332,0);
INSERT INTO "django_geo_db_location" VALUES(47450,NULL,'Matherville, IL',19825,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47451,NULL,'Matherville, IL 61263',19825,222,NULL,17,27333,0);
INSERT INTO "django_geo_db_location" VALUES(47452,NULL,'Milan, IL',19826,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47453,NULL,'Milan, IL 61264',19826,222,NULL,17,27334,0);
INSERT INTO "django_geo_db_location" VALUES(47454,NULL,'Moline, IL',19827,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47455,NULL,'Moline, IL 61265',19827,222,NULL,17,27335,0);
INSERT INTO "django_geo_db_location" VALUES(47456,NULL,'Moline, IL 61266',19827,222,NULL,17,27336,0);
INSERT INTO "django_geo_db_location" VALUES(47457,NULL,'Morrison, IL',19828,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47458,NULL,'Morrison, IL 61270',19828,222,NULL,17,27337,0);
INSERT INTO "django_geo_db_location" VALUES(47459,NULL,'New Boston, IL',19829,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47460,NULL,'New Boston, IL 61272',19829,222,NULL,17,27338,0);
INSERT INTO "django_geo_db_location" VALUES(47461,NULL,'Orion, IL',19830,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47462,NULL,'Orion, IL 61273',19830,222,NULL,17,27339,0);
INSERT INTO "django_geo_db_location" VALUES(47463,NULL,'Osco, IL',19831,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47464,NULL,'Osco, IL 61274',19831,222,NULL,17,27340,0);
INSERT INTO "django_geo_db_location" VALUES(47465,NULL,'Port Byron, IL',19832,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47466,NULL,'Port Byron, IL 61275',19832,222,NULL,17,27341,0);
INSERT INTO "django_geo_db_location" VALUES(47467,NULL,'Preemption, IL',19833,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47468,NULL,'Preemption, IL 61276',19833,222,NULL,17,27342,0);
INSERT INTO "django_geo_db_location" VALUES(47469,NULL,'Prophetstown, IL',19834,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47470,NULL,'Prophetstown, IL 61277',19834,222,NULL,17,27343,0);
INSERT INTO "django_geo_db_location" VALUES(47471,NULL,'Rapids City, IL',19835,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47472,NULL,'Rapids City, IL 61278',19835,222,NULL,17,27344,0);
INSERT INTO "django_geo_db_location" VALUES(47473,NULL,'Reynolds, IL',19836,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47474,NULL,'Reynolds, IL 61279',19836,222,NULL,17,27345,0);
INSERT INTO "django_geo_db_location" VALUES(47475,NULL,'Sherrard, IL',19837,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47476,NULL,'Sherrard, IL 61281',19837,222,NULL,17,27346,0);
INSERT INTO "django_geo_db_location" VALUES(47477,NULL,'Silvis, IL',19838,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47478,NULL,'Silvis, IL 61282',19838,222,NULL,17,27347,0);
INSERT INTO "django_geo_db_location" VALUES(47479,NULL,'Tampico, IL',19839,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47480,NULL,'Tampico, IL 61283',19839,222,NULL,17,27348,0);
INSERT INTO "django_geo_db_location" VALUES(47481,NULL,'Taylor Ridge, IL',19840,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47482,NULL,'Taylor Ridge, IL 61284',19840,222,NULL,17,27349,0);
INSERT INTO "django_geo_db_location" VALUES(47483,NULL,'Thomson, IL',19841,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47484,NULL,'Thomson, IL 61285',19841,222,NULL,17,27350,0);
INSERT INTO "django_geo_db_location" VALUES(47485,NULL,'Rock Island, IL 61299',19798,222,NULL,17,27351,0);
INSERT INTO "django_geo_db_location" VALUES(47486,NULL,'La Salle, IL',19842,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47487,NULL,'La Salle, IL 61301',19842,222,NULL,17,27352,0);
INSERT INTO "django_geo_db_location" VALUES(47488,NULL,'Amboy, IL',19843,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47489,NULL,'Amboy, IL 61310',19843,222,NULL,17,27353,0);
INSERT INTO "django_geo_db_location" VALUES(47490,NULL,'Ancona, IL',19844,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47491,NULL,'Ancona, IL 61311',19844,222,NULL,17,27354,0);
INSERT INTO "django_geo_db_location" VALUES(47492,NULL,'Arlington, IL',19845,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47493,NULL,'Arlington, IL 61312',19845,222,NULL,17,27355,0);
INSERT INTO "django_geo_db_location" VALUES(47494,NULL,'Blackstone, IL',19846,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47495,NULL,'Blackstone, IL 61313',19846,222,NULL,17,27356,0);
INSERT INTO "django_geo_db_location" VALUES(47496,NULL,'Buda, IL',19847,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47497,NULL,'Buda, IL 61314',19847,222,NULL,17,27357,0);
INSERT INTO "django_geo_db_location" VALUES(47498,NULL,'Bureau, IL',19848,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47499,NULL,'Bureau, IL 61315',19848,222,NULL,17,27358,0);
INSERT INTO "django_geo_db_location" VALUES(47500,NULL,'Cedar Point, IL',19849,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47501,NULL,'Cedar Point, IL 61316',19849,222,NULL,17,27359,0);
INSERT INTO "django_geo_db_location" VALUES(47502,NULL,'Cherry, IL',19850,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47503,NULL,'Cherry, IL 61317',19850,222,NULL,17,27360,0);
INSERT INTO "django_geo_db_location" VALUES(47504,NULL,'Compton, IL',19851,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47505,NULL,'Compton, IL 61318',19851,222,NULL,17,27361,0);
INSERT INTO "django_geo_db_location" VALUES(47506,NULL,'Cornell, IL',19852,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47507,NULL,'Cornell, IL 61319',19852,222,NULL,17,27362,0);
INSERT INTO "django_geo_db_location" VALUES(47508,NULL,'Dalzell, IL',19853,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47509,NULL,'Dalzell, IL 61320',19853,222,NULL,17,27363,0);
INSERT INTO "django_geo_db_location" VALUES(47510,NULL,'Dana, IL',19854,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47511,NULL,'Dana, IL 61321',19854,222,NULL,17,27364,0);
INSERT INTO "django_geo_db_location" VALUES(47512,NULL,'Depue, IL',19855,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47513,NULL,'Depue, IL 61322',19855,222,NULL,17,27365,0);
INSERT INTO "django_geo_db_location" VALUES(47514,NULL,'Dover, IL',19856,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47515,NULL,'Dover, IL 61323',19856,222,NULL,17,27366,0);
INSERT INTO "django_geo_db_location" VALUES(47516,NULL,'Eldena, IL',19857,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47517,NULL,'Eldena, IL 61324',19857,222,NULL,17,27367,0);
INSERT INTO "django_geo_db_location" VALUES(47518,NULL,'Grand Ridge, IL',19858,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47519,NULL,'Grand Ridge, IL 61325',19858,222,NULL,17,27368,0);
INSERT INTO "django_geo_db_location" VALUES(47520,NULL,'Granville, IL',19859,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47521,NULL,'Granville, IL 61326',19859,222,NULL,17,27369,0);
INSERT INTO "django_geo_db_location" VALUES(47522,NULL,'Hennepin, IL',19860,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47523,NULL,'Hennepin, IL 61327',19860,222,NULL,17,27370,0);
INSERT INTO "django_geo_db_location" VALUES(47524,NULL,'Kasbeer, IL',19861,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47525,NULL,'Kasbeer, IL 61328',19861,222,NULL,17,27371,0);
INSERT INTO "django_geo_db_location" VALUES(47526,NULL,'Ladd, IL',19862,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47527,NULL,'Ladd, IL 61329',19862,222,NULL,17,27372,0);
INSERT INTO "django_geo_db_location" VALUES(47528,NULL,'La Moille, IL',19863,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47529,NULL,'La Moille, IL 61330',19863,222,NULL,17,27373,0);
INSERT INTO "django_geo_db_location" VALUES(47530,NULL,'Lee Center, IL',19864,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47531,NULL,'Lee Center, IL 61331',19864,222,NULL,17,27374,0);
INSERT INTO "django_geo_db_location" VALUES(47532,NULL,'Leonore, IL',19865,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47533,NULL,'Leonore, IL 61332',19865,222,NULL,17,27375,0);
INSERT INTO "django_geo_db_location" VALUES(47534,NULL,'Long Point, IL',19866,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47535,NULL,'Long Point, IL 61333',19866,222,NULL,17,27376,0);
INSERT INTO "django_geo_db_location" VALUES(47536,NULL,'Lostant, IL',19867,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47537,NULL,'Lostant, IL 61334',19867,222,NULL,17,27377,0);
INSERT INTO "django_geo_db_location" VALUES(47538,NULL,'McNabb, IL',19868,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47539,NULL,'McNabb, IL 61335',19868,222,NULL,17,27378,0);
INSERT INTO "django_geo_db_location" VALUES(47540,NULL,'Magnolia, IL',19869,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47541,NULL,'Magnolia, IL 61336',19869,222,NULL,17,27379,0);
INSERT INTO "django_geo_db_location" VALUES(47542,NULL,'Malden, IL',19870,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47543,NULL,'Malden, IL 61337',19870,222,NULL,17,27380,0);
INSERT INTO "django_geo_db_location" VALUES(47544,NULL,'Manlius, IL',19871,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47545,NULL,'Manlius, IL 61338',19871,222,NULL,17,27381,0);
INSERT INTO "django_geo_db_location" VALUES(47546,NULL,'Mark, IL',19872,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47547,NULL,'Mark, IL 61340',19872,222,NULL,17,27382,0);
INSERT INTO "django_geo_db_location" VALUES(47548,NULL,'Marseilles, IL',19873,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47549,NULL,'Marseilles, IL 61341',19873,222,NULL,17,27383,0);
INSERT INTO "django_geo_db_location" VALUES(47550,NULL,'Mendota, IL',19874,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47551,NULL,'Mendota, IL 61342',19874,222,NULL,17,27384,0);
INSERT INTO "django_geo_db_location" VALUES(47552,NULL,'Mineral, IL',19875,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47553,NULL,'Mineral, IL 61344',19875,222,NULL,17,27385,0);
INSERT INTO "django_geo_db_location" VALUES(47554,NULL,'Neponset, IL',19876,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47555,NULL,'Neponset, IL 61345',19876,222,NULL,17,27386,0);
INSERT INTO "django_geo_db_location" VALUES(47556,NULL,'New Bedford, IL',19877,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47557,NULL,'New Bedford, IL 61346',19877,222,NULL,17,27387,0);
INSERT INTO "django_geo_db_location" VALUES(47558,NULL,'Oglesby, IL',19878,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47559,NULL,'Oglesby, IL 61348',19878,222,NULL,17,27388,0);
INSERT INTO "django_geo_db_location" VALUES(47560,NULL,'Ohio, IL',19879,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47561,NULL,'Ohio, IL 61349',19879,222,NULL,17,27389,0);
INSERT INTO "django_geo_db_location" VALUES(47562,NULL,'Ottawa, IL',19880,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47563,NULL,'Ottawa, IL 61350',19880,222,NULL,17,27390,0);
INSERT INTO "django_geo_db_location" VALUES(47564,NULL,'Paw Paw, IL',19881,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47565,NULL,'Paw Paw, IL 61353',19881,222,NULL,17,27391,0);
INSERT INTO "django_geo_db_location" VALUES(47566,NULL,'Peru, IL',19882,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47567,NULL,'Peru, IL 61354',19882,222,NULL,17,27392,0);
INSERT INTO "django_geo_db_location" VALUES(47568,NULL,'Princeton, IL',19883,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47569,NULL,'Princeton, IL 61356',19883,222,NULL,17,27393,0);
INSERT INTO "django_geo_db_location" VALUES(47570,NULL,'Rutland, IL',19884,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47571,NULL,'Rutland, IL 61358',19884,222,NULL,17,27394,0);
INSERT INTO "django_geo_db_location" VALUES(47572,NULL,'Seatonville, IL',19885,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47573,NULL,'Seatonville, IL 61359',19885,222,NULL,17,27395,0);
INSERT INTO "django_geo_db_location" VALUES(47574,NULL,'Seneca, IL',19886,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47575,NULL,'Seneca, IL 61360',19886,222,NULL,17,27396,0);
INSERT INTO "django_geo_db_location" VALUES(47576,NULL,'Sheffield, IL',19887,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47577,NULL,'Sheffield, IL 61361',19887,222,NULL,17,27397,0);
INSERT INTO "django_geo_db_location" VALUES(47578,NULL,'Spring Valley, IL',19888,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47579,NULL,'Spring Valley, IL 61362',19888,222,NULL,17,27398,0);
INSERT INTO "django_geo_db_location" VALUES(47580,NULL,'Standard, IL',19889,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47581,NULL,'Standard, IL 61363',19889,222,NULL,17,27399,0);
INSERT INTO "django_geo_db_location" VALUES(47582,NULL,'Streator, IL',19890,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47583,NULL,'Streator, IL 61364',19890,222,NULL,17,27400,0);
INSERT INTO "django_geo_db_location" VALUES(47584,NULL,'Sublette, IL',19891,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47585,NULL,'Sublette, IL 61367',19891,222,NULL,17,27401,0);
INSERT INTO "django_geo_db_location" VALUES(47586,NULL,'Tiskilwa, IL',19892,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47587,NULL,'Tiskilwa, IL 61368',19892,222,NULL,17,27402,0);
INSERT INTO "django_geo_db_location" VALUES(47588,NULL,'Toluca, IL',19893,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47589,NULL,'Toluca, IL 61369',19893,222,NULL,17,27403,0);
INSERT INTO "django_geo_db_location" VALUES(47590,NULL,'Tonica, IL',19894,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47591,NULL,'Tonica, IL 61370',19894,222,NULL,17,27404,0);
INSERT INTO "django_geo_db_location" VALUES(47592,NULL,'Triumph, IL',19895,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47593,NULL,'Triumph, IL 61371',19895,222,NULL,17,27405,0);
INSERT INTO "django_geo_db_location" VALUES(47594,NULL,'Troy Grove, IL',19896,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47595,NULL,'Troy Grove, IL 61372',19896,222,NULL,17,27406,0);
INSERT INTO "django_geo_db_location" VALUES(47596,NULL,'Utica, IL',19897,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47597,NULL,'Utica, IL 61373',19897,222,NULL,17,27407,0);
INSERT INTO "django_geo_db_location" VALUES(47598,NULL,'Van Orin, IL',19898,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47599,NULL,'Van Orin, IL 61374',19898,222,NULL,17,27408,0);
INSERT INTO "django_geo_db_location" VALUES(47600,NULL,'Varna, IL',19899,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47601,NULL,'Varna, IL 61375',19899,222,NULL,17,27409,0);
INSERT INTO "django_geo_db_location" VALUES(47602,NULL,'Walnut, IL',19900,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47603,NULL,'Walnut, IL 61376',19900,222,NULL,17,27410,0);
INSERT INTO "django_geo_db_location" VALUES(47604,NULL,'Wenona, IL',19901,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47605,NULL,'Wenona, IL 61377',19901,222,NULL,17,27411,0);
INSERT INTO "django_geo_db_location" VALUES(47606,NULL,'West Brooklyn, IL',19902,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47607,NULL,'West Brooklyn, IL 61378',19902,222,NULL,17,27412,0);
INSERT INTO "django_geo_db_location" VALUES(47608,NULL,'Wyanet, IL',19903,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47609,NULL,'Wyanet, IL 61379',19903,222,NULL,17,27413,0);
INSERT INTO "django_geo_db_location" VALUES(47610,NULL,'Galesburg, IL',19904,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47611,NULL,'Galesburg, IL 61401',19904,222,NULL,17,27414,0);
INSERT INTO "django_geo_db_location" VALUES(47612,NULL,'Galesburg, IL 61402',19904,222,NULL,17,27415,0);
INSERT INTO "django_geo_db_location" VALUES(47613,NULL,'Abingdon, IL',19905,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47614,NULL,'Abingdon, IL 61410',19905,222,NULL,17,27416,0);
INSERT INTO "django_geo_db_location" VALUES(47615,NULL,'Adair, IL',19906,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47616,NULL,'Adair, IL 61411',19906,222,NULL,17,27417,0);
INSERT INTO "django_geo_db_location" VALUES(47617,NULL,'Alexis, IL',19907,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47618,NULL,'Alexis, IL 61412',19907,222,NULL,17,27418,0);
INSERT INTO "django_geo_db_location" VALUES(47619,NULL,'Alpha, IL',19908,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47620,NULL,'Alpha, IL 61413',19908,222,NULL,17,27419,0);
INSERT INTO "django_geo_db_location" VALUES(47621,NULL,'Altona, IL',19909,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47622,NULL,'Altona, IL 61414',19909,222,NULL,17,27420,0);
INSERT INTO "django_geo_db_location" VALUES(47623,NULL,'Avon, IL',19910,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47624,NULL,'Avon, IL 61415',19910,222,NULL,17,27421,0);
INSERT INTO "django_geo_db_location" VALUES(47625,NULL,'Bardolph, IL',19911,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47626,NULL,'Bardolph, IL 61416',19911,222,NULL,17,27422,0);
INSERT INTO "django_geo_db_location" VALUES(47627,NULL,'Berwick, IL',19912,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47628,NULL,'Berwick, IL 61417',19912,222,NULL,17,27423,0);
INSERT INTO "django_geo_db_location" VALUES(47629,NULL,'Biggsville, IL',19913,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47630,NULL,'Biggsville, IL 61418',19913,222,NULL,17,27424,0);
INSERT INTO "django_geo_db_location" VALUES(47631,NULL,'Bishop Hill, IL',19914,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47632,NULL,'Bishop Hill, IL 61419',19914,222,NULL,17,27425,0);
INSERT INTO "django_geo_db_location" VALUES(47633,NULL,'Blandinsville, IL',19915,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47634,NULL,'Blandinsville, IL 61420',19915,222,NULL,17,27426,0);
INSERT INTO "django_geo_db_location" VALUES(47635,NULL,'Bradford, IL',19916,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47636,NULL,'Bradford, IL 61421',19916,222,NULL,17,27427,0);
INSERT INTO "django_geo_db_location" VALUES(47637,NULL,'Bushnell, IL',19917,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47638,NULL,'Bushnell, IL 61422',19917,222,NULL,17,27428,0);
INSERT INTO "django_geo_db_location" VALUES(47639,NULL,'Cameron, IL',19918,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47640,NULL,'Cameron, IL 61423',19918,222,NULL,17,27429,0);
INSERT INTO "django_geo_db_location" VALUES(47641,NULL,'Camp Grove, IL',19919,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47642,NULL,'Camp Grove, IL 61424',19919,222,NULL,17,27430,0);
INSERT INTO "django_geo_db_location" VALUES(47643,NULL,'Carman, IL',19920,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47644,NULL,'Carman, IL 61425',19920,222,NULL,17,27431,0);
INSERT INTO "django_geo_db_location" VALUES(47645,NULL,'Castleton, IL',19921,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47646,NULL,'Castleton, IL 61426',19921,222,NULL,17,27432,0);
INSERT INTO "django_geo_db_location" VALUES(47647,NULL,'Cuba, IL',19922,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47648,NULL,'Cuba, IL 61427',19922,222,NULL,17,27433,0);
INSERT INTO "django_geo_db_location" VALUES(47649,NULL,'Dahinda, IL',19923,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47650,NULL,'Dahinda, IL 61428',19923,222,NULL,17,27434,0);
INSERT INTO "django_geo_db_location" VALUES(47651,NULL,'East Galesburg, IL',19924,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47652,NULL,'East Galesburg, IL 61430',19924,222,NULL,17,27435,0);
INSERT INTO "django_geo_db_location" VALUES(47653,NULL,'Ellisville, IL',19925,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47654,NULL,'Ellisville, IL 61431',19925,222,NULL,17,27436,0);
INSERT INTO "django_geo_db_location" VALUES(47655,NULL,'Fairview, IL',19926,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47656,NULL,'Fairview, IL 61432',19926,222,NULL,17,27437,0);
INSERT INTO "django_geo_db_location" VALUES(47657,NULL,'Fiatt, IL',19927,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47658,NULL,'Fiatt, IL 61433',19927,222,NULL,17,27438,0);
INSERT INTO "django_geo_db_location" VALUES(47659,NULL,'Galva, IL',19928,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47660,NULL,'Galva, IL 61434',19928,222,NULL,17,27439,0);
INSERT INTO "django_geo_db_location" VALUES(47661,NULL,'Gerlaw, IL',19929,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47662,NULL,'Gerlaw, IL 61435',19929,222,NULL,17,27440,0);
INSERT INTO "django_geo_db_location" VALUES(47663,NULL,'Gilson, IL',19930,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47664,NULL,'Gilson, IL 61436',19930,222,NULL,17,27441,0);
INSERT INTO "django_geo_db_location" VALUES(47665,NULL,'Gladstone, IL',19931,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47666,NULL,'Gladstone, IL 61437',19931,222,NULL,17,27442,0);
INSERT INTO "django_geo_db_location" VALUES(47667,NULL,'Good Hope, IL',19932,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47668,NULL,'Good Hope, IL 61438',19932,222,NULL,17,27443,0);
INSERT INTO "django_geo_db_location" VALUES(47669,NULL,'Henderson, IL',19933,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47670,NULL,'Henderson, IL 61439',19933,222,NULL,17,27444,0);
INSERT INTO "django_geo_db_location" VALUES(47671,NULL,'Industry, IL',19934,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47672,NULL,'Industry, IL 61440',19934,222,NULL,17,27445,0);
INSERT INTO "django_geo_db_location" VALUES(47673,NULL,'Ipava, IL',19935,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47674,NULL,'Ipava, IL 61441',19935,222,NULL,17,27446,0);
INSERT INTO "django_geo_db_location" VALUES(47675,NULL,'Keithsburg, IL',19936,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47676,NULL,'Keithsburg, IL 61442',19936,222,NULL,17,27447,0);
INSERT INTO "django_geo_db_location" VALUES(47677,NULL,'Kewanee, IL',19937,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47678,NULL,'Kewanee, IL 61443',19937,222,NULL,17,27448,0);
INSERT INTO "django_geo_db_location" VALUES(47679,NULL,'Kirkwood, IL',19938,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47680,NULL,'Kirkwood, IL 61447',19938,222,NULL,17,27449,0);
INSERT INTO "django_geo_db_location" VALUES(47681,NULL,'Knoxville, IL',19939,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47682,NULL,'Knoxville, IL 61448',19939,222,NULL,17,27450,0);
INSERT INTO "django_geo_db_location" VALUES(47683,NULL,'La Fayette, IL',19940,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47684,NULL,'La Fayette, IL 61449',19940,222,NULL,17,27451,0);
INSERT INTO "django_geo_db_location" VALUES(47685,NULL,'La Harpe, IL',19941,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47686,NULL,'La Harpe, IL 61450',19941,222,NULL,17,27452,0);
INSERT INTO "django_geo_db_location" VALUES(47687,NULL,'Laura, IL',19942,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47688,NULL,'Laura, IL 61451',19942,222,NULL,17,27453,0);
INSERT INTO "django_geo_db_location" VALUES(47689,NULL,'Littleton, IL',19943,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47690,NULL,'Littleton, IL 61452',19943,222,NULL,17,27454,0);
INSERT INTO "django_geo_db_location" VALUES(47691,NULL,'Little York, IL',19944,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47692,NULL,'Little York, IL 61453',19944,222,NULL,17,27455,0);
INSERT INTO "django_geo_db_location" VALUES(47693,NULL,'Lomax, IL',19945,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47694,NULL,'Lomax, IL 61454',19945,222,NULL,17,27456,0);
INSERT INTO "django_geo_db_location" VALUES(47695,NULL,'Macomb, IL',19946,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47696,NULL,'Macomb, IL 61455',19946,222,NULL,17,27457,0);
INSERT INTO "django_geo_db_location" VALUES(47697,NULL,'Lee, IL 61457',19630,222,NULL,17,27458,0);
INSERT INTO "django_geo_db_location" VALUES(47698,NULL,'Maquon, IL',19947,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47699,NULL,'Maquon, IL 61458',19947,222,NULL,17,27459,0);
INSERT INTO "django_geo_db_location" VALUES(47700,NULL,'Marietta, IL',19948,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47701,NULL,'Marietta, IL 61459',19948,222,NULL,17,27460,0);
INSERT INTO "django_geo_db_location" VALUES(47702,NULL,'Media, IL',19949,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47703,NULL,'Media, IL 61460',19949,222,NULL,17,27461,0);
INSERT INTO "django_geo_db_location" VALUES(47704,NULL,'Monmouth, IL',19950,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47705,NULL,'Monmouth, IL 61462',19950,222,NULL,17,27462,0);
INSERT INTO "django_geo_db_location" VALUES(47706,NULL,'New Windsor, IL',19951,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47707,NULL,'New Windsor, IL 61465',19951,222,NULL,17,27463,0);
INSERT INTO "django_geo_db_location" VALUES(47708,NULL,'North Henderson, IL',19952,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47709,NULL,'North Henderson, IL 61466',19952,222,NULL,17,27464,0);
INSERT INTO "django_geo_db_location" VALUES(47710,NULL,'Oneida, IL',19953,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47711,NULL,'Oneida, IL 61467',19953,222,NULL,17,27465,0);
INSERT INTO "django_geo_db_location" VALUES(47712,NULL,'Opheim, IL',19954,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47713,NULL,'Opheim, IL 61468',19954,222,NULL,17,27466,0);
INSERT INTO "django_geo_db_location" VALUES(47714,NULL,'Oquawka, IL',19955,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47715,NULL,'Oquawka, IL 61469',19955,222,NULL,17,27467,0);
INSERT INTO "django_geo_db_location" VALUES(47716,NULL,'Prairie City, IL',19956,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47717,NULL,'Prairie City, IL 61470',19956,222,NULL,17,27468,0);
INSERT INTO "django_geo_db_location" VALUES(47718,NULL,'Raritan, IL',19957,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47719,NULL,'Raritan, IL 61471',19957,222,NULL,17,27469,0);
INSERT INTO "django_geo_db_location" VALUES(47720,NULL,'Rio, IL',19958,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47721,NULL,'Rio, IL 61472',19958,222,NULL,17,27470,0);
INSERT INTO "django_geo_db_location" VALUES(47722,NULL,'Roseville, IL',19959,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47723,NULL,'Roseville, IL 61473',19959,222,NULL,17,27471,0);
INSERT INTO "django_geo_db_location" VALUES(47724,NULL,'Saint Augustine, IL',19960,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47725,NULL,'Saint Augustine, IL 61474',19960,222,NULL,17,27472,0);
INSERT INTO "django_geo_db_location" VALUES(47726,NULL,'Sciota, IL',19961,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47727,NULL,'Sciota, IL 61475',19961,222,NULL,17,27473,0);
INSERT INTO "django_geo_db_location" VALUES(47728,NULL,'Seaton, IL',19962,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47729,NULL,'Seaton, IL 61476',19962,222,NULL,17,27474,0);
INSERT INTO "django_geo_db_location" VALUES(47730,NULL,'Smithfield, IL',19963,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47731,NULL,'Smithfield, IL 61477',19963,222,NULL,17,27475,0);
INSERT INTO "django_geo_db_location" VALUES(47732,NULL,'Smithshire, IL',19964,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47733,NULL,'Smithshire, IL 61478',19964,222,NULL,17,27476,0);
INSERT INTO "django_geo_db_location" VALUES(47734,NULL,'Speer, IL',19965,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47735,NULL,'Speer, IL 61479',19965,222,NULL,17,27477,0);
INSERT INTO "django_geo_db_location" VALUES(47736,NULL,'Stronghurst, IL',19966,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47737,NULL,'Stronghurst, IL 61480',19966,222,NULL,17,27478,0);
INSERT INTO "django_geo_db_location" VALUES(47738,NULL,'Table Grove, IL',19967,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47739,NULL,'Table Grove, IL 61482',19967,222,NULL,17,27479,0);
INSERT INTO "django_geo_db_location" VALUES(47740,NULL,'Toulon, IL',19968,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47741,NULL,'Toulon, IL 61483',19968,222,NULL,17,27480,0);
INSERT INTO "django_geo_db_location" VALUES(47742,NULL,'Vermont, IL',19969,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47743,NULL,'Vermont, IL 61484',19969,222,NULL,17,27481,0);
INSERT INTO "django_geo_db_location" VALUES(47744,NULL,'Victoria, IL',19970,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47745,NULL,'Victoria, IL 61485',19970,222,NULL,17,27482,0);
INSERT INTO "django_geo_db_location" VALUES(47746,NULL,'Viola, IL',19971,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47747,NULL,'Viola, IL 61486',19971,222,NULL,17,27483,0);
INSERT INTO "django_geo_db_location" VALUES(47748,NULL,'Wataga, IL',19972,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47749,NULL,'Wataga, IL 61488',19972,222,NULL,17,27484,0);
INSERT INTO "django_geo_db_location" VALUES(47750,NULL,'Williamsfield, IL',19973,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47751,NULL,'Williamsfield, IL 61489',19973,222,NULL,17,27485,0);
INSERT INTO "django_geo_db_location" VALUES(47752,NULL,'Woodhull, IL',19974,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47753,NULL,'Woodhull, IL 61490',19974,222,NULL,17,27486,0);
INSERT INTO "django_geo_db_location" VALUES(47754,NULL,'Wyoming, IL',19975,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47755,NULL,'Wyoming, IL 61491',19975,222,NULL,17,27487,0);
INSERT INTO "django_geo_db_location" VALUES(47756,NULL,'Astoria, IL',19976,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47757,NULL,'Astoria, IL 61501',19976,222,NULL,17,27488,0);
INSERT INTO "django_geo_db_location" VALUES(47758,NULL,'Benson, IL',19977,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47759,NULL,'Benson, IL 61516',19977,222,NULL,17,27489,0);
INSERT INTO "django_geo_db_location" VALUES(47760,NULL,'Brimfield, IL',19978,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47761,NULL,'Brimfield, IL 61517',19978,222,NULL,17,27490,0);
INSERT INTO "django_geo_db_location" VALUES(47762,NULL,'Brimfield, IL 61518',19978,222,NULL,17,27491,0);
INSERT INTO "django_geo_db_location" VALUES(47763,NULL,'Bryant, IL',19979,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47764,NULL,'Bryant, IL 61519',19979,222,NULL,17,27492,0);
INSERT INTO "django_geo_db_location" VALUES(47765,NULL,'Canton, IL',19980,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47766,NULL,'Canton, IL 61520',19980,222,NULL,17,27493,0);
INSERT INTO "django_geo_db_location" VALUES(47767,NULL,'Chillicothe, IL',19981,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47768,NULL,'Chillicothe, IL 61523',19981,222,NULL,17,27494,0);
INSERT INTO "django_geo_db_location" VALUES(47769,NULL,'Dunfermline, IL',19982,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47770,NULL,'Dunfermline, IL 61524',19982,222,NULL,17,27495,0);
INSERT INTO "django_geo_db_location" VALUES(47771,NULL,'Dunlap, IL',19983,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47772,NULL,'Dunlap, IL 61525',19983,222,NULL,17,27496,0);
INSERT INTO "django_geo_db_location" VALUES(47773,NULL,'Edelstein, IL',19984,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47774,NULL,'Edelstein, IL 61526',19984,222,NULL,17,27497,0);
INSERT INTO "django_geo_db_location" VALUES(47775,NULL,'Edwards, IL',19985,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47776,NULL,'Edwards, IL 61528',19985,222,NULL,17,27498,0);
INSERT INTO "django_geo_db_location" VALUES(47777,NULL,'Elmwood, IL',19986,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47778,NULL,'Elmwood, IL 61529',19986,222,NULL,17,27499,0);
INSERT INTO "django_geo_db_location" VALUES(47779,NULL,'Eureka, IL',19987,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47780,NULL,'Eureka, IL 61530',19987,222,NULL,17,27500,0);
INSERT INTO "django_geo_db_location" VALUES(47781,NULL,'Farmington, IL',19988,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47782,NULL,'Farmington, IL 61531',19988,222,NULL,17,27501,0);
INSERT INTO "django_geo_db_location" VALUES(47783,NULL,'Forest City, IL',19989,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47784,NULL,'Forest City, IL 61532',19989,222,NULL,17,27502,0);
INSERT INTO "django_geo_db_location" VALUES(47785,NULL,'Glasford, IL',19990,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47786,NULL,'Glasford, IL 61533',19990,222,NULL,17,27503,0);
INSERT INTO "django_geo_db_location" VALUES(47787,NULL,'Green Valley, IL',19991,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47788,NULL,'Green Valley, IL 61534',19991,222,NULL,17,27504,0);
INSERT INTO "django_geo_db_location" VALUES(47789,NULL,'Groveland, IL',19992,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47790,NULL,'Groveland, IL 61535',19992,222,NULL,17,27505,0);
INSERT INTO "django_geo_db_location" VALUES(47791,NULL,'Hanna City, IL',19993,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47792,NULL,'Hanna City, IL 61536',19993,222,NULL,17,27506,0);
INSERT INTO "django_geo_db_location" VALUES(47793,NULL,'Henry, IL',19994,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47794,NULL,'Henry, IL 61537',19994,222,NULL,17,27507,0);
INSERT INTO "django_geo_db_location" VALUES(47795,NULL,'Kingston Mines, IL',19995,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47796,NULL,'Kingston Mines, IL 61539',19995,222,NULL,17,27508,0);
INSERT INTO "django_geo_db_location" VALUES(47797,NULL,'Lacon, IL',19996,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47798,NULL,'Lacon, IL 61540',19996,222,NULL,17,27509,0);
INSERT INTO "django_geo_db_location" VALUES(47799,NULL,'La Rose, IL',19997,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47800,NULL,'La Rose, IL 61541',19997,222,NULL,17,27510,0);
INSERT INTO "django_geo_db_location" VALUES(47801,NULL,'Lewistown, IL',19998,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47802,NULL,'Lewistown, IL 61542',19998,222,NULL,17,27511,0);
INSERT INTO "django_geo_db_location" VALUES(47803,NULL,'Liverpool, IL',19999,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47804,NULL,'Liverpool, IL 61543',19999,222,NULL,17,27512,0);
INSERT INTO "django_geo_db_location" VALUES(47805,NULL,'London Mills, IL',20000,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47806,NULL,'London Mills, IL 61544',20000,222,NULL,17,27513,0);
INSERT INTO "django_geo_db_location" VALUES(47807,NULL,'Lowpoint, IL',20001,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47808,NULL,'Lowpoint, IL 61545',20001,222,NULL,17,27514,0);
INSERT INTO "django_geo_db_location" VALUES(47809,NULL,'Manito, IL',20002,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47810,NULL,'Manito, IL 61546',20002,222,NULL,17,27515,0);
INSERT INTO "django_geo_db_location" VALUES(47811,NULL,'Mapleton, IL',20003,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47812,NULL,'Mapleton, IL 61547',20003,222,NULL,17,27516,0);
INSERT INTO "django_geo_db_location" VALUES(47813,NULL,'Metamora, IL',20004,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47814,NULL,'Metamora, IL 61548',20004,222,NULL,17,27517,0);
INSERT INTO "django_geo_db_location" VALUES(47815,NULL,'Morton, IL',20005,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47816,NULL,'Morton, IL 61550',20005,222,NULL,17,27518,0);
INSERT INTO "django_geo_db_location" VALUES(47817,NULL,'Mossville, IL',20006,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47818,NULL,'Mossville, IL 61552',20006,222,NULL,17,27519,0);
INSERT INTO "django_geo_db_location" VALUES(47819,NULL,'Norris, IL',20007,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47820,NULL,'Norris, IL 61553',20007,222,NULL,17,27520,0);
INSERT INTO "django_geo_db_location" VALUES(47821,NULL,'Pekin, IL',20008,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47822,NULL,'Pekin, IL 61554',20008,222,NULL,17,27521,0);
INSERT INTO "django_geo_db_location" VALUES(47823,NULL,'Pekin, IL 61555',20008,222,NULL,17,27522,0);
INSERT INTO "django_geo_db_location" VALUES(47824,NULL,'Pekin, IL 61558',20008,222,NULL,17,27523,0);
INSERT INTO "django_geo_db_location" VALUES(47825,NULL,'Princeville, IL',20009,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47826,NULL,'Princeville, IL 61559',20009,222,NULL,17,27524,0);
INSERT INTO "django_geo_db_location" VALUES(47827,NULL,'Putnam, IL',20010,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47828,NULL,'Putnam, IL 61560',20010,222,NULL,17,27525,0);
INSERT INTO "django_geo_db_location" VALUES(47829,NULL,'Roanoke, IL',20011,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47830,NULL,'Roanoke, IL 61561',20011,222,NULL,17,27526,0);
INSERT INTO "django_geo_db_location" VALUES(47831,NULL,'Rome, IL',20012,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47832,NULL,'Rome, IL 61562',20012,222,NULL,17,27527,0);
INSERT INTO "django_geo_db_location" VALUES(47833,NULL,'Saint David, IL',20013,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47834,NULL,'Saint David, IL 61563',20013,222,NULL,17,27528,0);
INSERT INTO "django_geo_db_location" VALUES(47835,NULL,'South Pekin, IL',20014,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47836,NULL,'South Pekin, IL 61564',20014,222,NULL,17,27529,0);
INSERT INTO "django_geo_db_location" VALUES(47837,NULL,'Sparland, IL',20015,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47838,NULL,'Sparland, IL 61565',20015,222,NULL,17,27530,0);
INSERT INTO "django_geo_db_location" VALUES(47839,NULL,'Topeka, IL',20016,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47840,NULL,'Topeka, IL 61567',20016,222,NULL,17,27531,0);
INSERT INTO "django_geo_db_location" VALUES(47841,NULL,'Tremont, IL',20017,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47842,NULL,'Tremont, IL 61568',20017,222,NULL,17,27532,0);
INSERT INTO "django_geo_db_location" VALUES(47843,NULL,'Trivoli, IL',20018,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47844,NULL,'Trivoli, IL 61569',20018,222,NULL,17,27533,0);
INSERT INTO "django_geo_db_location" VALUES(47845,NULL,'Washburn, IL',20019,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47846,NULL,'Washburn, IL 61570',20019,222,NULL,17,27534,0);
INSERT INTO "django_geo_db_location" VALUES(47847,NULL,'Washington, IL',20020,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47848,NULL,'Washington, IL 61571',20020,222,NULL,17,27535,0);
INSERT INTO "django_geo_db_location" VALUES(47849,NULL,'Yates City, IL',20021,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47850,NULL,'Yates City, IL 61572',20021,222,NULL,17,27536,0);
INSERT INTO "django_geo_db_location" VALUES(47851,NULL,'Richland, IL',20022,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47852,NULL,'Richland, IL 61576',20022,222,NULL,17,27537,0);
INSERT INTO "django_geo_db_location" VALUES(47853,NULL,'Vermont, IL 61584',19969,222,NULL,17,27538,0);
INSERT INTO "django_geo_db_location" VALUES(47854,NULL,'Garrett, IL',20023,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47855,NULL,'Garrett, IL 61593',20023,222,NULL,17,27539,0);
INSERT INTO "django_geo_db_location" VALUES(47856,NULL,'Peoria, IL',20024,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47857,NULL,'Peoria, IL 61601',20024,222,NULL,17,27540,0);
INSERT INTO "django_geo_db_location" VALUES(47858,NULL,'Peoria, IL 61602',20024,222,NULL,17,27541,0);
INSERT INTO "django_geo_db_location" VALUES(47859,NULL,'Peoria, IL 61603',20024,222,NULL,17,27542,0);
INSERT INTO "django_geo_db_location" VALUES(47860,NULL,'Peoria, IL 61604',20024,222,NULL,17,27543,0);
INSERT INTO "django_geo_db_location" VALUES(47861,NULL,'Peoria, IL 61605',20024,222,NULL,17,27544,0);
INSERT INTO "django_geo_db_location" VALUES(47862,NULL,'Peoria, IL 61606',20024,222,NULL,17,27545,0);
INSERT INTO "django_geo_db_location" VALUES(47863,NULL,'Peoria, IL 61607',20024,222,NULL,17,27546,0);
INSERT INTO "django_geo_db_location" VALUES(47864,NULL,'Creve Coeur, IL',20025,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47865,NULL,'Creve Coeur, IL 61610',20025,222,NULL,17,27547,0);
INSERT INTO "django_geo_db_location" VALUES(47866,NULL,'East Peoria, IL',20026,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47867,NULL,'East Peoria, IL 61611',20026,222,NULL,17,27548,0);
INSERT INTO "django_geo_db_location" VALUES(47868,NULL,'Peoria, IL 61612',20024,222,NULL,17,27549,0);
INSERT INTO "django_geo_db_location" VALUES(47869,NULL,'Peoria, IL 61613',20024,222,NULL,17,27550,0);
INSERT INTO "django_geo_db_location" VALUES(47870,NULL,'Peoria, IL 61614',20024,222,NULL,17,27551,0);
INSERT INTO "django_geo_db_location" VALUES(47871,NULL,'Peoria, IL 61615',20024,222,NULL,17,27552,0);
INSERT INTO "django_geo_db_location" VALUES(47872,NULL,'Peoria, IL 61616',20024,222,NULL,17,27553,0);
INSERT INTO "django_geo_db_location" VALUES(47873,NULL,'Peoria, IL 61625',20024,222,NULL,17,27554,0);
INSERT INTO "django_geo_db_location" VALUES(47874,NULL,'Peoria, IL 61628',20024,222,NULL,17,27555,0);
INSERT INTO "django_geo_db_location" VALUES(47875,NULL,'Peoria, IL 61629',20024,222,NULL,17,27556,0);
INSERT INTO "django_geo_db_location" VALUES(47876,NULL,'Peoria, IL 61630',20024,222,NULL,17,27557,0);
INSERT INTO "django_geo_db_location" VALUES(47877,NULL,'Peoria, IL 61632',20024,222,NULL,17,27558,0);
INSERT INTO "django_geo_db_location" VALUES(47878,NULL,'Peoria, IL 61633',20024,222,NULL,17,27559,0);
INSERT INTO "django_geo_db_location" VALUES(47879,NULL,'Peoria, IL 61634',20024,222,NULL,17,27560,0);
INSERT INTO "django_geo_db_location" VALUES(47880,NULL,'Peoria, IL 61635',20024,222,NULL,17,27561,0);
INSERT INTO "django_geo_db_location" VALUES(47881,NULL,'Peoria, IL 61636',20024,222,NULL,17,27562,0);
INSERT INTO "django_geo_db_location" VALUES(47882,NULL,'Peoria, IL 61637',20024,222,NULL,17,27563,0);
INSERT INTO "django_geo_db_location" VALUES(47883,NULL,'Peoria, IL 61638',20024,222,NULL,17,27564,0);
INSERT INTO "django_geo_db_location" VALUES(47884,NULL,'Peoria, IL 61639',20024,222,NULL,17,27565,0);
INSERT INTO "django_geo_db_location" VALUES(47885,NULL,'Peoria, IL 61640',20024,222,NULL,17,27566,0);
INSERT INTO "django_geo_db_location" VALUES(47886,NULL,'Peoria, IL 61641',20024,222,NULL,17,27567,0);
INSERT INTO "django_geo_db_location" VALUES(47887,NULL,'Peoria, IL 61643',20024,222,NULL,17,27568,0);
INSERT INTO "django_geo_db_location" VALUES(47888,NULL,'Peoria, IL 61644',20024,222,NULL,17,27569,0);
INSERT INTO "django_geo_db_location" VALUES(47889,NULL,'Peoria, IL 61650',20024,222,NULL,17,27570,0);
INSERT INTO "django_geo_db_location" VALUES(47890,NULL,'Peoria, IL 61651',20024,222,NULL,17,27571,0);
INSERT INTO "django_geo_db_location" VALUES(47891,NULL,'Peoria, IL 61652',20024,222,NULL,17,27572,0);
INSERT INTO "django_geo_db_location" VALUES(47892,NULL,'Peoria, IL 61653',20024,222,NULL,17,27573,0);
INSERT INTO "django_geo_db_location" VALUES(47893,NULL,'Peoria, IL 61654',20024,222,NULL,17,27574,0);
INSERT INTO "django_geo_db_location" VALUES(47894,NULL,'Peoria, IL 61655',20024,222,NULL,17,27575,0);
INSERT INTO "django_geo_db_location" VALUES(47895,NULL,'Peoria, IL 61656',20024,222,NULL,17,27576,0);
INSERT INTO "django_geo_db_location" VALUES(47896,NULL,'Carlock, IL',20027,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47897,NULL,'Carlock, IL 61675',20027,222,NULL,17,27577,0);
INSERT INTO "django_geo_db_location" VALUES(47898,NULL,'Bloomington, IL',20028,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47899,NULL,'Bloomington, IL 61701',20028,222,NULL,17,27578,0);
INSERT INTO "django_geo_db_location" VALUES(47900,NULL,'Bloomington, IL 61702',20028,222,NULL,17,27579,0);
INSERT INTO "django_geo_db_location" VALUES(47901,NULL,'Bloomington, IL 61704',20028,222,NULL,17,27580,0);
INSERT INTO "django_geo_db_location" VALUES(47902,NULL,'Bloomington, IL 61709',20028,222,NULL,17,27581,0);
INSERT INTO "django_geo_db_location" VALUES(47903,NULL,'Bloomington, IL 61710',20028,222,NULL,17,27582,0);
INSERT INTO "django_geo_db_location" VALUES(47904,NULL,'Anchor, IL',20029,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47905,NULL,'Anchor, IL 61720',20029,222,NULL,17,27583,0);
INSERT INTO "django_geo_db_location" VALUES(47906,NULL,'Armington, IL',20030,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47907,NULL,'Armington, IL 61721',20030,222,NULL,17,27584,0);
INSERT INTO "django_geo_db_location" VALUES(47908,NULL,'Arrowsmith, IL',20031,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47909,NULL,'Arrowsmith, IL 61722',20031,222,NULL,17,27585,0);
INSERT INTO "django_geo_db_location" VALUES(47910,NULL,'Atlanta, IL',20032,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47911,NULL,'Atlanta, IL 61723',20032,222,NULL,17,27586,0);
INSERT INTO "django_geo_db_location" VALUES(47912,NULL,'Bellflower, IL',20033,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47913,NULL,'Bellflower, IL 61724',20033,222,NULL,17,27587,0);
INSERT INTO "django_geo_db_location" VALUES(47914,NULL,'Carlock, IL 61725',20027,222,NULL,17,27588,0);
INSERT INTO "django_geo_db_location" VALUES(47915,NULL,'Chenoa, IL',20034,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47916,NULL,'Chenoa, IL 61726',20034,222,NULL,17,27589,0);
INSERT INTO "django_geo_db_location" VALUES(47917,NULL,'Clinton, IL',20035,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47918,NULL,'Clinton, IL 61727',20035,222,NULL,17,27590,0);
INSERT INTO "django_geo_db_location" VALUES(47919,NULL,'Colfax, IL',20036,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47920,NULL,'Colfax, IL 61728',20036,222,NULL,17,27591,0);
INSERT INTO "django_geo_db_location" VALUES(47921,NULL,'Congerville, IL',20037,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47922,NULL,'Congerville, IL 61729',20037,222,NULL,17,27592,0);
INSERT INTO "django_geo_db_location" VALUES(47923,NULL,'Cooksville, IL',20038,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47924,NULL,'Cooksville, IL 61730',20038,222,NULL,17,27593,0);
INSERT INTO "django_geo_db_location" VALUES(47925,NULL,'Cropsey, IL',20039,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47926,NULL,'Cropsey, IL 61731',20039,222,NULL,17,27594,0);
INSERT INTO "django_geo_db_location" VALUES(47927,NULL,'Danvers, IL',20040,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47928,NULL,'Danvers, IL 61732',20040,222,NULL,17,27595,0);
INSERT INTO "django_geo_db_location" VALUES(47929,NULL,'Deer Creek, IL',20041,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47930,NULL,'Deer Creek, IL 61733',20041,222,NULL,17,27596,0);
INSERT INTO "django_geo_db_location" VALUES(47931,NULL,'Delavan, IL',20042,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47932,NULL,'Delavan, IL 61734',20042,222,NULL,17,27597,0);
INSERT INTO "django_geo_db_location" VALUES(47933,NULL,'Dewitt, IL',20043,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47934,NULL,'Dewitt, IL 61735',20043,222,NULL,17,27598,0);
INSERT INTO "django_geo_db_location" VALUES(47935,NULL,'Downs, IL',20044,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47936,NULL,'Downs, IL 61736',20044,222,NULL,17,27599,0);
INSERT INTO "django_geo_db_location" VALUES(47937,NULL,'Ellsworth, IL',20045,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47938,NULL,'Ellsworth, IL 61737',20045,222,NULL,17,27600,0);
INSERT INTO "django_geo_db_location" VALUES(47939,NULL,'El Paso, IL',20046,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47940,NULL,'El Paso, IL 61738',20046,222,NULL,17,27601,0);
INSERT INTO "django_geo_db_location" VALUES(47941,NULL,'Fairbury, IL',20047,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47942,NULL,'Fairbury, IL 61739',20047,222,NULL,17,27602,0);
INSERT INTO "django_geo_db_location" VALUES(47943,NULL,'Flanagan, IL',20048,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47944,NULL,'Flanagan, IL 61740',20048,222,NULL,17,27603,0);
INSERT INTO "django_geo_db_location" VALUES(47945,NULL,'Forrest, IL',20049,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47946,NULL,'Forrest, IL 61741',20049,222,NULL,17,27604,0);
INSERT INTO "django_geo_db_location" VALUES(47947,NULL,'Goodfield, IL',20050,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47948,NULL,'Goodfield, IL 61742',20050,222,NULL,17,27605,0);
INSERT INTO "django_geo_db_location" VALUES(47949,NULL,'Graymont, IL',20051,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47950,NULL,'Graymont, IL 61743',20051,222,NULL,17,27606,0);
INSERT INTO "django_geo_db_location" VALUES(47951,NULL,'Gridley, IL',20052,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47952,NULL,'Gridley, IL 61744',20052,222,NULL,17,27607,0);
INSERT INTO "django_geo_db_location" VALUES(47953,NULL,'Heyworth, IL',20053,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47954,NULL,'Heyworth, IL 61745',20053,222,NULL,17,27608,0);
INSERT INTO "django_geo_db_location" VALUES(47955,NULL,'Hopedale, IL',20054,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47956,NULL,'Hopedale, IL 61747',20054,222,NULL,17,27609,0);
INSERT INTO "django_geo_db_location" VALUES(47957,NULL,'Hudson, IL',20055,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47958,NULL,'Hudson, IL 61748',20055,222,NULL,17,27610,0);
INSERT INTO "django_geo_db_location" VALUES(47959,NULL,'Kenney, IL',20056,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47960,NULL,'Kenney, IL 61749',20056,222,NULL,17,27611,0);
INSERT INTO "django_geo_db_location" VALUES(47961,NULL,'Lane, IL',20057,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47962,NULL,'Lane, IL 61750',20057,222,NULL,17,27612,0);
INSERT INTO "django_geo_db_location" VALUES(47963,NULL,'Lawndale, IL',20058,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47964,NULL,'Lawndale, IL 61751',20058,222,NULL,17,27613,0);
INSERT INTO "django_geo_db_location" VALUES(47965,NULL,'Le Roy, IL',20059,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47966,NULL,'Le Roy, IL 61752',20059,222,NULL,17,27614,0);
INSERT INTO "django_geo_db_location" VALUES(47967,NULL,'Lexington, IL',20060,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47968,NULL,'Lexington, IL 61753',20060,222,NULL,17,27615,0);
INSERT INTO "django_geo_db_location" VALUES(47969,NULL,'McLean, IL',20061,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47970,NULL,'McLean, IL 61754',20061,222,NULL,17,27616,0);
INSERT INTO "django_geo_db_location" VALUES(47971,NULL,'Mackinaw, IL',20062,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47972,NULL,'Mackinaw, IL 61755',20062,222,NULL,17,27617,0);
INSERT INTO "django_geo_db_location" VALUES(47973,NULL,'Maroa, IL',20063,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47974,NULL,'Maroa, IL 61756',20063,222,NULL,17,27618,0);
INSERT INTO "django_geo_db_location" VALUES(47975,NULL,'Merna, IL',20064,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47976,NULL,'Merna, IL 61758',20064,222,NULL,17,27619,0);
INSERT INTO "django_geo_db_location" VALUES(47977,NULL,'Minier, IL',20065,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47978,NULL,'Minier, IL 61759',20065,222,NULL,17,27620,0);
INSERT INTO "django_geo_db_location" VALUES(47979,NULL,'Minonk, IL',20066,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47980,NULL,'Minonk, IL 61760',20066,222,NULL,17,27621,0);
INSERT INTO "django_geo_db_location" VALUES(47981,NULL,'Normal, IL',20067,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47982,NULL,'Normal, IL 61761',20067,222,NULL,17,27622,0);
INSERT INTO "django_geo_db_location" VALUES(47983,NULL,'Pontiac, IL',20068,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47984,NULL,'Pontiac, IL 61764',20068,222,NULL,17,27623,0);
INSERT INTO "django_geo_db_location" VALUES(47985,NULL,'Towanda, IL',20069,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47986,NULL,'Towanda, IL 61766',20069,222,NULL,17,27624,0);
INSERT INTO "django_geo_db_location" VALUES(47987,NULL,'Saunemin, IL',20070,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47988,NULL,'Saunemin, IL 61769',20070,222,NULL,17,27625,0);
INSERT INTO "django_geo_db_location" VALUES(47989,NULL,'Saybrook, IL',20071,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47990,NULL,'Saybrook, IL 61770',20071,222,NULL,17,27626,0);
INSERT INTO "django_geo_db_location" VALUES(47991,NULL,'Secor, IL',20072,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47992,NULL,'Secor, IL 61771',20072,222,NULL,17,27627,0);
INSERT INTO "django_geo_db_location" VALUES(47993,NULL,'Shirley, IL',20073,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47994,NULL,'Shirley, IL 61772',20073,222,NULL,17,27628,0);
INSERT INTO "django_geo_db_location" VALUES(47995,NULL,'Sibley, IL',20074,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47996,NULL,'Sibley, IL 61773',20074,222,NULL,17,27629,0);
INSERT INTO "django_geo_db_location" VALUES(47997,NULL,'Stanford, IL',20075,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(47998,NULL,'Stanford, IL 61774',20075,222,NULL,17,27630,0);
INSERT INTO "django_geo_db_location" VALUES(47999,NULL,'Strawn, IL',20076,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48000,NULL,'Strawn, IL 61775',20076,222,NULL,17,27631,0);
INSERT INTO "django_geo_db_location" VALUES(48001,NULL,'Towanda, IL 61776',20069,222,NULL,17,27632,0);
INSERT INTO "django_geo_db_location" VALUES(48002,NULL,'Wapella, IL',20077,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48003,NULL,'Wapella, IL 61777',20077,222,NULL,17,27633,0);
INSERT INTO "django_geo_db_location" VALUES(48004,NULL,'Waynesville, IL',20078,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48005,NULL,'Waynesville, IL 61778',20078,222,NULL,17,27634,0);
INSERT INTO "django_geo_db_location" VALUES(48006,NULL,'Normal, IL 61790',20067,222,NULL,17,27635,0);
INSERT INTO "django_geo_db_location" VALUES(48007,NULL,'Bloomington, IL 61791',20028,222,NULL,17,27636,0);
INSERT INTO "django_geo_db_location" VALUES(48008,NULL,'Bloomington, IL 61799',20028,222,NULL,17,27637,0);
INSERT INTO "django_geo_db_location" VALUES(48009,NULL,'Urbana, IL',20079,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48010,NULL,'Urbana, IL 61801',20079,222,NULL,17,27638,0);
INSERT INTO "django_geo_db_location" VALUES(48011,NULL,'Urbana, IL 61802',20079,222,NULL,17,27639,0);
INSERT INTO "django_geo_db_location" VALUES(48012,NULL,'Urbana, IL 61803',20079,222,NULL,17,27640,0);
INSERT INTO "django_geo_db_location" VALUES(48013,NULL,'Allerton, IL',20080,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48014,NULL,'Allerton, IL 61810',20080,222,NULL,17,27641,0);
INSERT INTO "django_geo_db_location" VALUES(48015,NULL,'Alvin, IL',20081,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48016,NULL,'Alvin, IL 61811',20081,222,NULL,17,27642,0);
INSERT INTO "django_geo_db_location" VALUES(48017,NULL,'Armstrong, IL',20082,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48018,NULL,'Armstrong, IL 61812',20082,222,NULL,17,27643,0);
INSERT INTO "django_geo_db_location" VALUES(48019,NULL,'Bement, IL',20083,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48020,NULL,'Bement, IL 61813',20083,222,NULL,17,27644,0);
INSERT INTO "django_geo_db_location" VALUES(48021,NULL,'Bismarck, IL',20084,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48022,NULL,'Bismarck, IL 61814',20084,222,NULL,17,27645,0);
INSERT INTO "django_geo_db_location" VALUES(48023,NULL,'Bondville, IL',20085,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48024,NULL,'Bondville, IL 61815',20085,222,NULL,17,27646,0);
INSERT INTO "django_geo_db_location" VALUES(48025,NULL,'Broadlands, IL',20086,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48026,NULL,'Broadlands, IL 61816',20086,222,NULL,17,27647,0);
INSERT INTO "django_geo_db_location" VALUES(48027,NULL,'Catlin, IL',20087,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48028,NULL,'Catlin, IL 61817',20087,222,NULL,17,27648,0);
INSERT INTO "django_geo_db_location" VALUES(48029,NULL,'Cerro Gordo, IL',20088,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48030,NULL,'Cerro Gordo, IL 61818',20088,222,NULL,17,27649,0);
INSERT INTO "django_geo_db_location" VALUES(48031,NULL,'Bryant, IL 61819',19979,222,NULL,17,27650,0);
INSERT INTO "django_geo_db_location" VALUES(48032,NULL,'Champaign, IL',20089,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48033,NULL,'Champaign, IL 61820',20089,222,NULL,17,27651,0);
INSERT INTO "django_geo_db_location" VALUES(48034,NULL,'Champaign, IL 61821',20089,222,NULL,17,27652,0);
INSERT INTO "django_geo_db_location" VALUES(48035,NULL,'Champaign, IL 61822',20089,222,NULL,17,27653,0);
INSERT INTO "django_geo_db_location" VALUES(48036,NULL,'Champaign, IL 61824',20089,222,NULL,17,27654,0);
INSERT INTO "django_geo_db_location" VALUES(48037,NULL,'Champaign, IL 61825',20089,222,NULL,17,27655,0);
INSERT INTO "django_geo_db_location" VALUES(48038,NULL,'Champaign, IL 61826',20089,222,NULL,17,27656,0);
INSERT INTO "django_geo_db_location" VALUES(48039,NULL,'Cisco, IL',20090,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48040,NULL,'Cisco, IL 61830',20090,222,NULL,17,27657,0);
INSERT INTO "django_geo_db_location" VALUES(48041,NULL,'Collison, IL',20091,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48042,NULL,'Collison, IL 61831',20091,222,NULL,17,27658,0);
INSERT INTO "django_geo_db_location" VALUES(48043,NULL,'Danville, IL',20092,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48044,NULL,'Danville, IL 61832',20092,222,NULL,17,27659,0);
INSERT INTO "django_geo_db_location" VALUES(48045,NULL,'Tilton, IL',20093,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48046,NULL,'Tilton, IL 61833',20093,222,NULL,17,27660,0);
INSERT INTO "django_geo_db_location" VALUES(48047,NULL,'Danville, IL 61834',20092,222,NULL,17,27661,0);
INSERT INTO "django_geo_db_location" VALUES(48048,NULL,'De Land, IL',20094,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48049,NULL,'De Land, IL 61839',20094,222,NULL,17,27662,0);
INSERT INTO "django_geo_db_location" VALUES(48050,NULL,'Dewey, IL',20095,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48051,NULL,'Dewey, IL 61840',20095,222,NULL,17,27663,0);
INSERT INTO "django_geo_db_location" VALUES(48052,NULL,'Fairmount, IL',20096,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48053,NULL,'Fairmount, IL 61841',20096,222,NULL,17,27664,0);
INSERT INTO "django_geo_db_location" VALUES(48054,NULL,'Farmer City, IL',20097,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48055,NULL,'Farmer City, IL 61842',20097,222,NULL,17,27665,0);
INSERT INTO "django_geo_db_location" VALUES(48056,NULL,'Fisher, IL',20098,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48057,NULL,'Fisher, IL 61843',20098,222,NULL,17,27666,0);
INSERT INTO "django_geo_db_location" VALUES(48058,NULL,'Fithian, IL',20099,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48059,NULL,'Fithian, IL 61844',20099,222,NULL,17,27667,0);
INSERT INTO "django_geo_db_location" VALUES(48060,NULL,'Foosland, IL',20100,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48061,NULL,'Foosland, IL 61845',20100,222,NULL,17,27668,0);
INSERT INTO "django_geo_db_location" VALUES(48062,NULL,'Georgetown, IL',20101,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48063,NULL,'Georgetown, IL 61846',20101,222,NULL,17,27669,0);
INSERT INTO "django_geo_db_location" VALUES(48064,NULL,'Gifford, IL',20102,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48065,NULL,'Gifford, IL 61847',20102,222,NULL,17,27670,0);
INSERT INTO "django_geo_db_location" VALUES(48066,NULL,'Henning, IL',20103,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48067,NULL,'Henning, IL 61848',20103,222,NULL,17,27671,0);
INSERT INTO "django_geo_db_location" VALUES(48068,NULL,'Homer, IL',20104,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48069,NULL,'Homer, IL 61849',20104,222,NULL,17,27672,0);
INSERT INTO "django_geo_db_location" VALUES(48070,NULL,'Indianola, IL',20105,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48071,NULL,'Indianola, IL 61850',20105,222,NULL,17,27673,0);
INSERT INTO "django_geo_db_location" VALUES(48072,NULL,'Ivesdale, IL',20106,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48073,NULL,'Ivesdale, IL 61851',20106,222,NULL,17,27674,0);
INSERT INTO "django_geo_db_location" VALUES(48074,NULL,'Longview, IL',20107,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48075,NULL,'Longview, IL 61852',20107,222,NULL,17,27675,0);
INSERT INTO "django_geo_db_location" VALUES(48076,NULL,'Mahomet, IL',20108,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48077,NULL,'Mahomet, IL 61853',20108,222,NULL,17,27676,0);
INSERT INTO "django_geo_db_location" VALUES(48078,NULL,'Mansfield, IL',20109,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48079,NULL,'Mansfield, IL 61854',20109,222,NULL,17,27677,0);
INSERT INTO "django_geo_db_location" VALUES(48080,NULL,'Milmine, IL',20110,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48081,NULL,'Milmine, IL 61855',20110,222,NULL,17,27678,0);
INSERT INTO "django_geo_db_location" VALUES(48082,NULL,'Monticello, IL',20111,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48083,NULL,'Monticello, IL 61856',20111,222,NULL,17,27679,0);
INSERT INTO "django_geo_db_location" VALUES(48084,NULL,'Muncie, IL',20112,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48085,NULL,'Muncie, IL 61857',20112,222,NULL,17,27680,0);
INSERT INTO "django_geo_db_location" VALUES(48086,NULL,'Oakwood, IL',20113,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48087,NULL,'Oakwood, IL 61858',20113,222,NULL,17,27681,0);
INSERT INTO "django_geo_db_location" VALUES(48088,NULL,'Ogden, IL',20114,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48089,NULL,'Ogden, IL 61859',20114,222,NULL,17,27682,0);
INSERT INTO "django_geo_db_location" VALUES(48090,NULL,'Penfield, IL',20115,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48091,NULL,'Penfield, IL 61862',20115,222,NULL,17,27683,0);
INSERT INTO "django_geo_db_location" VALUES(48092,NULL,'Pesotum, IL',20116,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48093,NULL,'Pesotum, IL 61863',20116,222,NULL,17,27684,0);
INSERT INTO "django_geo_db_location" VALUES(48094,NULL,'Philo, IL',20117,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48095,NULL,'Philo, IL 61864',20117,222,NULL,17,27685,0);
INSERT INTO "django_geo_db_location" VALUES(48096,NULL,'Potomac, IL',20118,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48097,NULL,'Potomac, IL 61865',20118,222,NULL,17,27686,0);
INSERT INTO "django_geo_db_location" VALUES(48098,NULL,'Rantoul, IL',20119,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48099,NULL,'Rantoul, IL 61866',20119,222,NULL,17,27687,0);
INSERT INTO "django_geo_db_location" VALUES(48100,NULL,'Ridge Farm, IL',20120,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48101,NULL,'Ridge Farm, IL 61870',20120,222,NULL,17,27688,0);
INSERT INTO "django_geo_db_location" VALUES(48102,NULL,'Royal, IL',20121,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48103,NULL,'Royal, IL 61871',20121,222,NULL,17,27689,0);
INSERT INTO "django_geo_db_location" VALUES(48104,NULL,'Sadorus, IL',20122,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48105,NULL,'Sadorus, IL 61872',20122,222,NULL,17,27690,0);
INSERT INTO "django_geo_db_location" VALUES(48106,NULL,'Saint Joseph, IL',20123,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48107,NULL,'Saint Joseph, IL 61873',20123,222,NULL,17,27691,0);
INSERT INTO "django_geo_db_location" VALUES(48108,NULL,'Savoy, IL',20124,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48109,NULL,'Savoy, IL 61874',20124,222,NULL,17,27692,0);
INSERT INTO "django_geo_db_location" VALUES(48110,NULL,'Seymour, IL',20125,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48111,NULL,'Seymour, IL 61875',20125,222,NULL,17,27693,0);
INSERT INTO "django_geo_db_location" VALUES(48112,NULL,'Sidell, IL',20126,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48113,NULL,'Sidell, IL 61876',20126,222,NULL,17,27694,0);
INSERT INTO "django_geo_db_location" VALUES(48114,NULL,'Sidney, IL',20127,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48115,NULL,'Sidney, IL 61877',20127,222,NULL,17,27695,0);
INSERT INTO "django_geo_db_location" VALUES(48116,NULL,'Thomasboro, IL',20128,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48117,NULL,'Thomasboro, IL 61878',20128,222,NULL,17,27696,0);
INSERT INTO "django_geo_db_location" VALUES(48118,NULL,'Tolono, IL',20129,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48119,NULL,'Tolono, IL 61880',20129,222,NULL,17,27697,0);
INSERT INTO "django_geo_db_location" VALUES(48120,NULL,'Weldon, IL',20130,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48121,NULL,'Weldon, IL 61882',20130,222,NULL,17,27698,0);
INSERT INTO "django_geo_db_location" VALUES(48122,NULL,'Westville, IL',20131,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48123,NULL,'Westville, IL 61883',20131,222,NULL,17,27699,0);
INSERT INTO "django_geo_db_location" VALUES(48124,NULL,'White Heath, IL',20132,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48125,NULL,'White Heath, IL 61884',20132,222,NULL,17,27700,0);
INSERT INTO "django_geo_db_location" VALUES(48126,NULL,'Bloomington, IL 61901',20028,222,NULL,17,27701,0);
INSERT INTO "django_geo_db_location" VALUES(48127,NULL,'Arcola, IL',20133,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48128,NULL,'Arcola, IL 61910',20133,222,NULL,17,27702,0);
INSERT INTO "django_geo_db_location" VALUES(48129,NULL,'Arthur, IL',20134,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48130,NULL,'Arthur, IL 61911',20134,222,NULL,17,27703,0);
INSERT INTO "django_geo_db_location" VALUES(48131,NULL,'Ashmore, IL',20135,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48132,NULL,'Ashmore, IL 61912',20135,222,NULL,17,27704,0);
INSERT INTO "django_geo_db_location" VALUES(48133,NULL,'Atwood, IL',20136,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48134,NULL,'Atwood, IL 61913',20136,222,NULL,17,27705,0);
INSERT INTO "django_geo_db_location" VALUES(48135,NULL,'Bethany, IL',20137,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48136,NULL,'Bethany, IL 61914',20137,222,NULL,17,27706,0);
INSERT INTO "django_geo_db_location" VALUES(48137,NULL,'Brocton, IL',20138,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48138,NULL,'Brocton, IL 61917',20138,222,NULL,17,27707,0);
INSERT INTO "django_geo_db_location" VALUES(48139,NULL,'Camargo, IL',20139,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48140,NULL,'Camargo, IL 61919',20139,222,NULL,17,27708,0);
INSERT INTO "django_geo_db_location" VALUES(48141,NULL,'Charleston, IL',20140,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48142,NULL,'Charleston, IL 61920',20140,222,NULL,17,27709,0);
INSERT INTO "django_geo_db_location" VALUES(48143,NULL,'Chrisman, IL',20141,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48144,NULL,'Chrisman, IL 61924',20141,222,NULL,17,27710,0);
INSERT INTO "django_geo_db_location" VALUES(48145,NULL,'Dalton City, IL',20142,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48146,NULL,'Dalton City, IL 61925',20142,222,NULL,17,27711,0);
INSERT INTO "django_geo_db_location" VALUES(48147,NULL,'Gays, IL',20143,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48148,NULL,'Gays, IL 61928',20143,222,NULL,17,27712,0);
INSERT INTO "django_geo_db_location" VALUES(48149,NULL,'Hammond, IL',20144,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48150,NULL,'Hammond, IL 61929',20144,222,NULL,17,27713,0);
INSERT INTO "django_geo_db_location" VALUES(48151,NULL,'Hindsboro, IL',20145,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48152,NULL,'Hindsboro, IL 61930',20145,222,NULL,17,27714,0);
INSERT INTO "django_geo_db_location" VALUES(48153,NULL,'Humboldt, IL',20146,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48154,NULL,'Humboldt, IL 61931',20146,222,NULL,17,27715,0);
INSERT INTO "django_geo_db_location" VALUES(48155,NULL,'Hume, IL',20147,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48156,NULL,'Hume, IL 61932',20147,222,NULL,17,27716,0);
INSERT INTO "django_geo_db_location" VALUES(48157,NULL,'Kansas, IL',20148,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48158,NULL,'Kansas, IL 61933',20148,222,NULL,17,27717,0);
INSERT INTO "django_geo_db_location" VALUES(48159,NULL,'La Place, IL',20149,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48160,NULL,'La Place, IL 61936',20149,222,NULL,17,27718,0);
INSERT INTO "django_geo_db_location" VALUES(48161,NULL,'Lovington, IL',20150,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48162,NULL,'Lovington, IL 61937',20150,222,NULL,17,27719,0);
INSERT INTO "django_geo_db_location" VALUES(48163,NULL,'Mattoon, IL',20151,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48164,NULL,'Mattoon, IL 61938',20151,222,NULL,17,27720,0);
INSERT INTO "django_geo_db_location" VALUES(48165,NULL,'Metcalf, IL',20152,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48166,NULL,'Metcalf, IL 61940',20152,222,NULL,17,27721,0);
INSERT INTO "django_geo_db_location" VALUES(48167,NULL,'Murdock, IL',20153,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48168,NULL,'Murdock, IL 61941',20153,222,NULL,17,27722,0);
INSERT INTO "django_geo_db_location" VALUES(48169,NULL,'Newman, IL',20154,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48170,NULL,'Newman, IL 61942',20154,222,NULL,17,27723,0);
INSERT INTO "django_geo_db_location" VALUES(48171,NULL,'Oakland, IL',20155,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48172,NULL,'Oakland, IL 61943',20155,222,NULL,17,27724,0);
INSERT INTO "django_geo_db_location" VALUES(48173,NULL,'Paris, IL',20156,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48174,NULL,'Paris, IL 61944',20156,222,NULL,17,27725,0);
INSERT INTO "django_geo_db_location" VALUES(48175,NULL,'Redmon, IL',20157,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48176,NULL,'Redmon, IL 61949',20157,222,NULL,17,27726,0);
INSERT INTO "django_geo_db_location" VALUES(48177,NULL,'Sullivan, IL',20158,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48178,NULL,'Sullivan, IL 61951',20158,222,NULL,17,27727,0);
INSERT INTO "django_geo_db_location" VALUES(48179,NULL,'Tuscola, IL',20159,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48180,NULL,'Tuscola, IL 61953',20159,222,NULL,17,27728,0);
INSERT INTO "django_geo_db_location" VALUES(48181,NULL,'Vermilion, IL',20160,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48182,NULL,'Vermilion, IL 61955',20160,222,NULL,17,27729,0);
INSERT INTO "django_geo_db_location" VALUES(48183,NULL,'Villa Grove, IL',20161,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48184,NULL,'Villa Grove, IL 61956',20161,222,NULL,17,27730,0);
INSERT INTO "django_geo_db_location" VALUES(48185,NULL,'Windsor, IL',20162,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48186,NULL,'Windsor, IL 61957',20162,222,NULL,17,27731,0);
INSERT INTO "django_geo_db_location" VALUES(48187,NULL,'Alhambra, IL',20163,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48188,NULL,'Alhambra, IL 62001',20163,222,NULL,17,27732,0);
INSERT INTO "django_geo_db_location" VALUES(48189,NULL,'Alton, IL',20164,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48190,NULL,'Alton, IL 62002',20164,222,NULL,17,27733,0);
INSERT INTO "django_geo_db_location" VALUES(48191,NULL,'Medora, IL',20165,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48192,NULL,'Medora, IL 62003',20165,222,NULL,17,27734,0);
INSERT INTO "django_geo_db_location" VALUES(48193,NULL,'Batchtown, IL',20166,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48194,NULL,'Batchtown, IL 62006',20166,222,NULL,17,27735,0);
INSERT INTO "django_geo_db_location" VALUES(48195,NULL,'Benld, IL',20167,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48196,NULL,'Benld, IL 62009',20167,222,NULL,17,27736,0);
INSERT INTO "django_geo_db_location" VALUES(48197,NULL,'Bethalto, IL',20168,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48198,NULL,'Bethalto, IL 62010',20168,222,NULL,17,27737,0);
INSERT INTO "django_geo_db_location" VALUES(48199,NULL,'Bingham, IL',20169,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48200,NULL,'Bingham, IL 62011',20169,222,NULL,17,27738,0);
INSERT INTO "django_geo_db_location" VALUES(48201,NULL,'Brighton, IL',20170,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48202,NULL,'Brighton, IL 62012',20170,222,NULL,17,27739,0);
INSERT INTO "django_geo_db_location" VALUES(48203,NULL,'Brussels, IL',20171,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48204,NULL,'Brussels, IL 62013',20171,222,NULL,17,27740,0);
INSERT INTO "django_geo_db_location" VALUES(48205,NULL,'Bunker Hill, IL',20172,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48206,NULL,'Bunker Hill, IL 62014',20172,222,NULL,17,27741,0);
INSERT INTO "django_geo_db_location" VALUES(48207,NULL,'Butler, IL',20173,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48208,NULL,'Butler, IL 62015',20173,222,NULL,17,27742,0);
INSERT INTO "django_geo_db_location" VALUES(48209,NULL,'Carrollton, IL',20174,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48210,NULL,'Carrollton, IL 62016',20174,222,NULL,17,27743,0);
INSERT INTO "django_geo_db_location" VALUES(48211,NULL,'Coffeen, IL',20175,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48212,NULL,'Coffeen, IL 62017',20175,222,NULL,17,27744,0);
INSERT INTO "django_geo_db_location" VALUES(48213,NULL,'Cottage Hills, IL',20176,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48214,NULL,'Cottage Hills, IL 62018',20176,222,NULL,17,27745,0);
INSERT INTO "django_geo_db_location" VALUES(48215,NULL,'Donnellson, IL',20177,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48216,NULL,'Donnellson, IL 62019',20177,222,NULL,17,27746,0);
INSERT INTO "django_geo_db_location" VALUES(48217,NULL,'Dorsey, IL',20178,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48218,NULL,'Dorsey, IL 62021',20178,222,NULL,17,27747,0);
INSERT INTO "django_geo_db_location" VALUES(48219,NULL,'Dow, IL',20179,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48220,NULL,'Dow, IL 62022',20179,222,NULL,17,27748,0);
INSERT INTO "django_geo_db_location" VALUES(48221,NULL,'Eagarville, IL',20180,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48222,NULL,'Eagarville, IL 62023',20180,222,NULL,17,27749,0);
INSERT INTO "django_geo_db_location" VALUES(48223,NULL,'East Alton, IL',20181,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48224,NULL,'East Alton, IL 62024',20181,222,NULL,17,27750,0);
INSERT INTO "django_geo_db_location" VALUES(48225,NULL,'Edwardsville, IL',20182,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48226,NULL,'Edwardsville, IL 62025',20182,222,NULL,17,27751,0);
INSERT INTO "django_geo_db_location" VALUES(48227,NULL,'Edwardsville, IL 62026',20182,222,NULL,17,27752,0);
INSERT INTO "django_geo_db_location" VALUES(48228,NULL,'Eldred, IL',20183,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48229,NULL,'Eldred, IL 62027',20183,222,NULL,17,27753,0);
INSERT INTO "django_geo_db_location" VALUES(48230,NULL,'Elsah, IL',20184,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48231,NULL,'Elsah, IL 62028',20184,222,NULL,17,27754,0);
INSERT INTO "django_geo_db_location" VALUES(48232,NULL,'Fidelity, IL',20185,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48233,NULL,'Fidelity, IL 62030',20185,222,NULL,17,27755,0);
INSERT INTO "django_geo_db_location" VALUES(48234,NULL,'Fieldon, IL',20186,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48235,NULL,'Fieldon, IL 62031',20186,222,NULL,17,27756,0);
INSERT INTO "django_geo_db_location" VALUES(48236,NULL,'Fillmore, IL',20187,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48237,NULL,'Fillmore, IL 62032',20187,222,NULL,17,27757,0);
INSERT INTO "django_geo_db_location" VALUES(48238,NULL,'Gillespie, IL',20188,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48239,NULL,'Gillespie, IL 62033',20188,222,NULL,17,27758,0);
INSERT INTO "django_geo_db_location" VALUES(48240,NULL,'Glen Carbon, IL',20189,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48241,NULL,'Glen Carbon, IL 62034',20189,222,NULL,17,27759,0);
INSERT INTO "django_geo_db_location" VALUES(48242,NULL,'Godfrey, IL',20190,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48243,NULL,'Godfrey, IL 62035',20190,222,NULL,17,27760,0);
INSERT INTO "django_geo_db_location" VALUES(48244,NULL,'Golden Eagle, IL',20191,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48245,NULL,'Golden Eagle, IL 62036',20191,222,NULL,17,27761,0);
INSERT INTO "django_geo_db_location" VALUES(48246,NULL,'Grafton, IL',20192,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48247,NULL,'Grafton, IL 62037',20192,222,NULL,17,27762,0);
INSERT INTO "django_geo_db_location" VALUES(48248,NULL,'Granite City, IL',20193,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48249,NULL,'Granite City, IL 62040',20193,222,NULL,17,27763,0);
INSERT INTO "django_geo_db_location" VALUES(48250,NULL,'Brushy Mound, IL',20194,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48251,NULL,'Brushy Mound, IL 62043',20194,222,NULL,17,27764,0);
INSERT INTO "django_geo_db_location" VALUES(48252,NULL,'Greenfield, IL',20195,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48253,NULL,'Greenfield, IL 62044',20195,222,NULL,17,27765,0);
INSERT INTO "django_geo_db_location" VALUES(48254,NULL,'Hamburg, IL',20196,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48255,NULL,'Hamburg, IL 62045',20196,222,NULL,17,27766,0);
INSERT INTO "django_geo_db_location" VALUES(48256,NULL,'Hamel, IL',20197,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48257,NULL,'Hamel, IL 62046',20197,222,NULL,17,27767,0);
INSERT INTO "django_geo_db_location" VALUES(48258,NULL,'Hardin, IL',20198,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48259,NULL,'Hardin, IL 62047',20198,222,NULL,17,27768,0);
INSERT INTO "django_geo_db_location" VALUES(48260,NULL,'Hartford, IL',20199,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48261,NULL,'Hartford, IL 62048',20199,222,NULL,17,27769,0);
INSERT INTO "django_geo_db_location" VALUES(48262,NULL,'Hillsboro, IL',20200,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48263,NULL,'Hillsboro, IL 62049',20200,222,NULL,17,27770,0);
INSERT INTO "django_geo_db_location" VALUES(48264,NULL,'Hillview, IL',20201,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48265,NULL,'Hillview, IL 62050',20201,222,NULL,17,27771,0);
INSERT INTO "django_geo_db_location" VALUES(48266,NULL,'Irving, IL',20202,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48267,NULL,'Irving, IL 62051',20202,222,NULL,17,27772,0);
INSERT INTO "django_geo_db_location" VALUES(48268,NULL,'Jerseyville, IL',20203,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48269,NULL,'Jerseyville, IL 62052',20203,222,NULL,17,27773,0);
INSERT INTO "django_geo_db_location" VALUES(48270,NULL,'Kampsville, IL',20204,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48271,NULL,'Kampsville, IL 62053',20204,222,NULL,17,27774,0);
INSERT INTO "django_geo_db_location" VALUES(48272,NULL,'Kane, IL',20205,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48273,NULL,'Kane, IL 62054',20205,222,NULL,17,27775,0);
INSERT INTO "django_geo_db_location" VALUES(48274,NULL,'Litchfield, IL',20206,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48275,NULL,'Litchfield, IL 62056',20206,222,NULL,17,27776,0);
INSERT INTO "django_geo_db_location" VALUES(48276,NULL,'Livingston, IL',20207,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48277,NULL,'Livingston, IL 62058',20207,222,NULL,17,27777,0);
INSERT INTO "django_geo_db_location" VALUES(48278,NULL,'Lovejoy, IL',20208,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48279,NULL,'Lovejoy, IL 62059',20208,222,NULL,17,27778,0);
INSERT INTO "django_geo_db_location" VALUES(48280,NULL,'Madison, IL',20209,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48281,NULL,'Madison, IL 62060',20209,222,NULL,17,27779,0);
INSERT INTO "django_geo_db_location" VALUES(48282,NULL,'Marine, IL',20210,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48283,NULL,'Marine, IL 62061',20210,222,NULL,17,27780,0);
INSERT INTO "django_geo_db_location" VALUES(48284,NULL,'Maryville, IL',20211,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48285,NULL,'Maryville, IL 62062',20211,222,NULL,17,27781,0);
INSERT INTO "django_geo_db_location" VALUES(48286,NULL,'Medora, IL 62063',20165,222,NULL,17,27782,0);
INSERT INTO "django_geo_db_location" VALUES(48287,NULL,'Michael, IL',20212,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48288,NULL,'Michael, IL 62065',20212,222,NULL,17,27783,0);
INSERT INTO "django_geo_db_location" VALUES(48289,NULL,'Moro, IL',20213,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48290,NULL,'Moro, IL 62067',20213,222,NULL,17,27784,0);
INSERT INTO "django_geo_db_location" VALUES(48291,NULL,'Mount Olive, IL',20214,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48292,NULL,'Mount Olive, IL 62069',20214,222,NULL,17,27785,0);
INSERT INTO "django_geo_db_location" VALUES(48293,NULL,'Mozier, IL',20215,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48294,NULL,'Mozier, IL 62070',20215,222,NULL,17,27786,0);
INSERT INTO "django_geo_db_location" VALUES(48295,NULL,'National Stock Yards, IL',20216,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48296,NULL,'National Stock Yards, IL 62071',20216,222,NULL,17,27787,0);
INSERT INTO "django_geo_db_location" VALUES(48297,NULL,'New Douglas, IL',20217,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48298,NULL,'New Douglas, IL 62074',20217,222,NULL,17,27788,0);
INSERT INTO "django_geo_db_location" VALUES(48299,NULL,'Nokomis, IL',20218,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48300,NULL,'Nokomis, IL 62075',20218,222,NULL,17,27789,0);
INSERT INTO "django_geo_db_location" VALUES(48301,NULL,'Ohlman, IL',20219,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48302,NULL,'Ohlman, IL 62076',20219,222,NULL,17,27790,0);
INSERT INTO "django_geo_db_location" VALUES(48303,NULL,'Panama, IL',20220,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48304,NULL,'Panama, IL 62077',20220,222,NULL,17,27791,0);
INSERT INTO "django_geo_db_location" VALUES(48305,NULL,'Patterson, IL',20221,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48306,NULL,'Patterson, IL 62078',20221,222,NULL,17,27792,0);
INSERT INTO "django_geo_db_location" VALUES(48307,NULL,'Piasa, IL',20222,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48308,NULL,'Piasa, IL 62079',20222,222,NULL,17,27793,0);
INSERT INTO "django_geo_db_location" VALUES(48309,NULL,'Ramsey, IL',20223,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48310,NULL,'Ramsey, IL 62080',20223,222,NULL,17,27794,0);
INSERT INTO "django_geo_db_location" VALUES(48311,NULL,'Rockbridge, IL',20224,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48312,NULL,'Rockbridge, IL 62081',20224,222,NULL,17,27795,0);
INSERT INTO "django_geo_db_location" VALUES(48313,NULL,'Roodhouse, IL',20225,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48314,NULL,'Roodhouse, IL 62082',20225,222,NULL,17,27796,0);
INSERT INTO "django_geo_db_location" VALUES(48315,NULL,'Rosamond, IL',20226,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48316,NULL,'Rosamond, IL 62083',20226,222,NULL,17,27797,0);
INSERT INTO "django_geo_db_location" VALUES(48317,NULL,'Roxana, IL',20227,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48318,NULL,'Roxana, IL 62084',20227,222,NULL,17,27798,0);
INSERT INTO "django_geo_db_location" VALUES(48319,NULL,'Sawyerville, IL',20228,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48320,NULL,'Sawyerville, IL 62085',20228,222,NULL,17,27799,0);
INSERT INTO "django_geo_db_location" VALUES(48321,NULL,'Sorento, IL',20229,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48322,NULL,'Sorento, IL 62086',20229,222,NULL,17,27800,0);
INSERT INTO "django_geo_db_location" VALUES(48323,NULL,'South Roxana, IL',20230,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48324,NULL,'South Roxana, IL 62087',20230,222,NULL,17,27801,0);
INSERT INTO "django_geo_db_location" VALUES(48325,NULL,'Staunton, IL',20231,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48326,NULL,'Staunton, IL 62088',20231,222,NULL,17,27802,0);
INSERT INTO "django_geo_db_location" VALUES(48327,NULL,'Taylor Springs, IL',20232,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48328,NULL,'Taylor Springs, IL 62089',20232,222,NULL,17,27803,0);
INSERT INTO "django_geo_db_location" VALUES(48329,NULL,'Venice, IL',20233,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48330,NULL,'Venice, IL 62090',20233,222,NULL,17,27804,0);
INSERT INTO "django_geo_db_location" VALUES(48331,NULL,'Walshville, IL',20234,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48332,NULL,'Walshville, IL 62091',20234,222,NULL,17,27805,0);
INSERT INTO "django_geo_db_location" VALUES(48333,NULL,'White Hall, IL',20235,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48334,NULL,'White Hall, IL 62092',20235,222,NULL,17,27806,0);
INSERT INTO "django_geo_db_location" VALUES(48335,NULL,'Wilsonville, IL',20236,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48336,NULL,'Wilsonville, IL 62093',20236,222,NULL,17,27807,0);
INSERT INTO "django_geo_db_location" VALUES(48337,NULL,'Witt, IL',20237,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48338,NULL,'Witt, IL 62094',20237,222,NULL,17,27808,0);
INSERT INTO "django_geo_db_location" VALUES(48339,NULL,'Wood River, IL',20238,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48340,NULL,'Wood River, IL 62095',20238,222,NULL,17,27809,0);
INSERT INTO "django_geo_db_location" VALUES(48341,NULL,'Worden, IL',20239,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48342,NULL,'Worden, IL 62097',20239,222,NULL,17,27810,0);
INSERT INTO "django_geo_db_location" VALUES(48343,NULL,'Wrights, IL',20240,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48344,NULL,'Wrights, IL 62098',20240,222,NULL,17,27811,0);
INSERT INTO "django_geo_db_location" VALUES(48345,NULL,'East Saint Louis, IL',20241,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48346,NULL,'East Saint Louis, IL 62201',20241,222,NULL,17,27812,0);
INSERT INTO "django_geo_db_location" VALUES(48347,NULL,'East Saint Louis, IL 62202',20241,222,NULL,17,27813,0);
INSERT INTO "django_geo_db_location" VALUES(48348,NULL,'East Saint Louis, IL 62203',20241,222,NULL,17,27814,0);
INSERT INTO "django_geo_db_location" VALUES(48349,NULL,'East Saint Louis, IL 62204',20241,222,NULL,17,27815,0);
INSERT INTO "django_geo_db_location" VALUES(48350,NULL,'East Saint Louis, IL 62205',20241,222,NULL,17,27816,0);
INSERT INTO "django_geo_db_location" VALUES(48351,NULL,'East Saint Louis, IL 62206',20241,222,NULL,17,27817,0);
INSERT INTO "django_geo_db_location" VALUES(48352,NULL,'East Saint Louis, IL 62207',20241,222,NULL,17,27818,0);
INSERT INTO "django_geo_db_location" VALUES(48353,NULL,'Fairview Heights, IL',20242,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48354,NULL,'Fairview Heights, IL 62208',20242,222,NULL,17,27819,0);
INSERT INTO "django_geo_db_location" VALUES(48355,NULL,'Addieville, IL',20243,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48356,NULL,'Addieville, IL 62214',20243,222,NULL,17,27820,0);
INSERT INTO "django_geo_db_location" VALUES(48357,NULL,'Albers, IL',20244,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48358,NULL,'Albers, IL 62215',20244,222,NULL,17,27821,0);
INSERT INTO "django_geo_db_location" VALUES(48359,NULL,'Aviston, IL',20245,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48360,NULL,'Aviston, IL 62216',20245,222,NULL,17,27822,0);
INSERT INTO "django_geo_db_location" VALUES(48361,NULL,'Baldwin, IL',20246,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48362,NULL,'Baldwin, IL 62217',20246,222,NULL,17,27823,0);
INSERT INTO "django_geo_db_location" VALUES(48363,NULL,'Bartelso, IL',20247,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48364,NULL,'Bartelso, IL 62218',20247,222,NULL,17,27824,0);
INSERT INTO "django_geo_db_location" VALUES(48365,NULL,'Beckemeyer, IL',20248,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48366,NULL,'Beckemeyer, IL 62219',20248,222,NULL,17,27825,0);
INSERT INTO "django_geo_db_location" VALUES(48367,NULL,'Belleville, IL',20249,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48368,NULL,'Belleville, IL 62220',20249,222,NULL,17,27826,0);
INSERT INTO "django_geo_db_location" VALUES(48369,NULL,'Belleville, IL 62221',20249,222,NULL,17,27827,0);
INSERT INTO "django_geo_db_location" VALUES(48370,NULL,'Belleville, IL 62222',20249,222,NULL,17,27828,0);
INSERT INTO "django_geo_db_location" VALUES(48371,NULL,'Belleville, IL 62223',20249,222,NULL,17,27829,0);
INSERT INTO "django_geo_db_location" VALUES(48372,NULL,'Mascoutah, IL',20250,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48373,NULL,'Mascoutah, IL 62224',20250,222,NULL,17,27830,0);
INSERT INTO "django_geo_db_location" VALUES(48374,NULL,'Scott Air Force Base, IL',20251,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48375,NULL,'Scott Air Force Base, IL 62225',20251,222,NULL,17,27831,0);
INSERT INTO "django_geo_db_location" VALUES(48376,NULL,'Belleville, IL 62226',20249,222,NULL,17,27832,0);
INSERT INTO "django_geo_db_location" VALUES(48377,NULL,'Breese, IL',20252,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48378,NULL,'Breese, IL 62230',20252,222,NULL,17,27833,0);
INSERT INTO "django_geo_db_location" VALUES(48379,NULL,'Carlyle, IL',20253,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48380,NULL,'Carlyle, IL 62231',20253,222,NULL,17,27834,0);
INSERT INTO "django_geo_db_location" VALUES(48381,NULL,'Caseyville, IL',20254,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48382,NULL,'Caseyville, IL 62232',20254,222,NULL,17,27835,0);
INSERT INTO "django_geo_db_location" VALUES(48383,NULL,'Chester, IL',20255,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48384,NULL,'Chester, IL 62233',20255,222,NULL,17,27836,0);
INSERT INTO "django_geo_db_location" VALUES(48385,NULL,'Collinsville, IL',20256,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48386,NULL,'Collinsville, IL 62234',20256,222,NULL,17,27837,0);
INSERT INTO "django_geo_db_location" VALUES(48387,NULL,'Columbia, IL',20257,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48388,NULL,'Columbia, IL 62236',20257,222,NULL,17,27838,0);
INSERT INTO "django_geo_db_location" VALUES(48389,NULL,'Coulterville, IL',20258,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48390,NULL,'Coulterville, IL 62237',20258,222,NULL,17,27839,0);
INSERT INTO "django_geo_db_location" VALUES(48391,NULL,'Cutler, IL',20259,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48392,NULL,'Cutler, IL 62238',20259,222,NULL,17,27840,0);
INSERT INTO "django_geo_db_location" VALUES(48393,NULL,'Dupo, IL',20260,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48394,NULL,'Dupo, IL 62239',20260,222,NULL,17,27841,0);
INSERT INTO "django_geo_db_location" VALUES(48395,NULL,'East Carondelet, IL',20261,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48396,NULL,'East Carondelet, IL 62240',20261,222,NULL,17,27842,0);
INSERT INTO "django_geo_db_location" VALUES(48397,NULL,'Ellis Grove, IL',20262,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48398,NULL,'Ellis Grove, IL 62241',20262,222,NULL,17,27843,0);
INSERT INTO "django_geo_db_location" VALUES(48399,NULL,'Evansville, IL',20263,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48400,NULL,'Evansville, IL 62242',20263,222,NULL,17,27844,0);
INSERT INTO "django_geo_db_location" VALUES(48401,NULL,'Freeburg, IL',20264,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48402,NULL,'Freeburg, IL 62243',20264,222,NULL,17,27845,0);
INSERT INTO "django_geo_db_location" VALUES(48403,NULL,'Fults, IL',20265,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48404,NULL,'Fults, IL 62244',20265,222,NULL,17,27846,0);
INSERT INTO "django_geo_db_location" VALUES(48405,NULL,'Germantown, IL',20266,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48406,NULL,'Germantown, IL 62245',20266,222,NULL,17,27847,0);
INSERT INTO "django_geo_db_location" VALUES(48407,NULL,'Greenville, IL',20267,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48408,NULL,'Greenville, IL 62246',20267,222,NULL,17,27848,0);
INSERT INTO "django_geo_db_location" VALUES(48409,NULL,'Hagarstown, IL',20268,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48410,NULL,'Hagarstown, IL 62247',20268,222,NULL,17,27849,0);
INSERT INTO "django_geo_db_location" VALUES(48411,NULL,'Hecker, IL',20269,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48412,NULL,'Hecker, IL 62248',20269,222,NULL,17,27850,0);
INSERT INTO "django_geo_db_location" VALUES(48413,NULL,'Highland, IL',20270,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48414,NULL,'Highland, IL 62249',20270,222,NULL,17,27851,0);
INSERT INTO "django_geo_db_location" VALUES(48415,NULL,'Hoffman, IL',20271,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48416,NULL,'Hoffman, IL 62250',20271,222,NULL,17,27852,0);
INSERT INTO "django_geo_db_location" VALUES(48417,NULL,'Huey, IL',20272,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48418,NULL,'Huey, IL 62252',20272,222,NULL,17,27853,0);
INSERT INTO "django_geo_db_location" VALUES(48419,NULL,'Keyesport, IL',20273,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48420,NULL,'Keyesport, IL 62253',20273,222,NULL,17,27854,0);
INSERT INTO "django_geo_db_location" VALUES(48421,NULL,'Lebanon, IL',20274,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48422,NULL,'Lebanon, IL 62254',20274,222,NULL,17,27855,0);
INSERT INTO "django_geo_db_location" VALUES(48423,NULL,'Lenzburg, IL',20275,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48424,NULL,'Lenzburg, IL 62255',20275,222,NULL,17,27856,0);
INSERT INTO "django_geo_db_location" VALUES(48425,NULL,'Maeystown, IL',20276,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48426,NULL,'Maeystown, IL 62256',20276,222,NULL,17,27857,0);
INSERT INTO "django_geo_db_location" VALUES(48427,NULL,'Marissa, IL',20277,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48428,NULL,'Marissa, IL 62257',20277,222,NULL,17,27858,0);
INSERT INTO "django_geo_db_location" VALUES(48429,NULL,'Mascoutah, IL 62258',20250,222,NULL,17,27859,0);
INSERT INTO "django_geo_db_location" VALUES(48430,NULL,'Menard, IL',20278,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48431,NULL,'Menard, IL 62259',20278,222,NULL,17,27860,0);
INSERT INTO "django_geo_db_location" VALUES(48432,NULL,'Millstadt, IL',20279,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48433,NULL,'Millstadt, IL 62260',20279,222,NULL,17,27861,0);
INSERT INTO "django_geo_db_location" VALUES(48434,NULL,'Modoc, IL',20280,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48435,NULL,'Modoc, IL 62261',20280,222,NULL,17,27862,0);
INSERT INTO "django_geo_db_location" VALUES(48436,NULL,'Mulberry Grove, IL',20281,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48437,NULL,'Mulberry Grove, IL 62262',20281,222,NULL,17,27863,0);
INSERT INTO "django_geo_db_location" VALUES(48438,NULL,'Nashville, IL',20282,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48439,NULL,'Nashville, IL 62263',20282,222,NULL,17,27864,0);
INSERT INTO "django_geo_db_location" VALUES(48440,NULL,'New Athens, IL',20283,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48441,NULL,'New Athens, IL 62264',20283,222,NULL,17,27865,0);
INSERT INTO "django_geo_db_location" VALUES(48442,NULL,'New Baden, IL',20284,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48443,NULL,'New Baden, IL 62265',20284,222,NULL,17,27866,0);
INSERT INTO "django_geo_db_location" VALUES(48444,NULL,'New Memphis, IL',20285,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48445,NULL,'New Memphis, IL 62266',20285,222,NULL,17,27867,0);
INSERT INTO "django_geo_db_location" VALUES(48446,NULL,'Oakdale, IL',20286,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48447,NULL,'Oakdale, IL 62268',20286,222,NULL,17,27868,0);
INSERT INTO "django_geo_db_location" VALUES(48448,NULL,'O Fallon, IL',20287,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48449,NULL,'O Fallon, IL 62269',20287,222,NULL,17,27869,0);
INSERT INTO "django_geo_db_location" VALUES(48450,NULL,'Dupo, IL 62270',20260,222,NULL,17,27870,0);
INSERT INTO "django_geo_db_location" VALUES(48451,NULL,'Okawville, IL',20288,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48452,NULL,'Okawville, IL 62271',20288,222,NULL,17,27871,0);
INSERT INTO "django_geo_db_location" VALUES(48453,NULL,'Percy, IL',20289,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48454,NULL,'Percy, IL 62272',20289,222,NULL,17,27872,0);
INSERT INTO "django_geo_db_location" VALUES(48455,NULL,'Pierron, IL',20290,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48456,NULL,'Pierron, IL 62273',20290,222,NULL,17,27873,0);
INSERT INTO "django_geo_db_location" VALUES(48457,NULL,'Pinckneyville, IL',20291,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48458,NULL,'Pinckneyville, IL 62274',20291,222,NULL,17,27874,0);
INSERT INTO "django_geo_db_location" VALUES(48459,NULL,'Pocahontas, IL',20292,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48460,NULL,'Pocahontas, IL 62275',20292,222,NULL,17,27875,0);
INSERT INTO "django_geo_db_location" VALUES(48461,NULL,'Prairie Du Rocher, IL',20293,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48462,NULL,'Prairie Du Rocher, IL 62277',20293,222,NULL,17,27876,0);
INSERT INTO "django_geo_db_location" VALUES(48463,NULL,'Red Bud, IL',20294,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48464,NULL,'Red Bud, IL 62278',20294,222,NULL,17,27877,0);
INSERT INTO "django_geo_db_location" VALUES(48465,NULL,'Renault, IL',20295,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48466,NULL,'Renault, IL 62279',20295,222,NULL,17,27878,0);
INSERT INTO "django_geo_db_location" VALUES(48467,NULL,'Rockwood, IL',20296,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48468,NULL,'Rockwood, IL 62280',20296,222,NULL,17,27879,0);
INSERT INTO "django_geo_db_location" VALUES(48469,NULL,'Saint Jacob, IL',20297,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48470,NULL,'Saint Jacob, IL 62281',20297,222,NULL,17,27880,0);
INSERT INTO "django_geo_db_location" VALUES(48471,NULL,'Saint Libory, IL',20298,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48472,NULL,'Saint Libory, IL 62282',20298,222,NULL,17,27881,0);
INSERT INTO "django_geo_db_location" VALUES(48473,NULL,'Shattuc, IL',20299,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48474,NULL,'Shattuc, IL 62283',20299,222,NULL,17,27882,0);
INSERT INTO "django_geo_db_location" VALUES(48475,NULL,'Smithboro, IL',20300,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48476,NULL,'Smithboro, IL 62284',20300,222,NULL,17,27883,0);
INSERT INTO "django_geo_db_location" VALUES(48477,NULL,'Smithton, IL',20301,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48478,NULL,'Smithton, IL 62285',20301,222,NULL,17,27884,0);
INSERT INTO "django_geo_db_location" VALUES(48479,NULL,'Sparta, IL',20302,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48480,NULL,'Sparta, IL 62286',20302,222,NULL,17,27885,0);
INSERT INTO "django_geo_db_location" VALUES(48481,NULL,'Steeleville, IL',20303,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48482,NULL,'Steeleville, IL 62288',20303,222,NULL,17,27886,0);
INSERT INTO "django_geo_db_location" VALUES(48483,NULL,'Summerfield, IL',20304,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48484,NULL,'Summerfield, IL 62289',20304,222,NULL,17,27887,0);
INSERT INTO "django_geo_db_location" VALUES(48485,NULL,'Tilden, IL',20305,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48486,NULL,'Tilden, IL 62292',20305,222,NULL,17,27888,0);
INSERT INTO "django_geo_db_location" VALUES(48487,NULL,'Trenton, IL',20306,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48488,NULL,'Trenton, IL 62293',20306,222,NULL,17,27889,0);
INSERT INTO "django_geo_db_location" VALUES(48489,NULL,'Troy, IL',20307,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48490,NULL,'Troy, IL 62294',20307,222,NULL,17,27890,0);
INSERT INTO "django_geo_db_location" VALUES(48491,NULL,'Valmeyer, IL',20308,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48492,NULL,'Valmeyer, IL 62295',20308,222,NULL,17,27891,0);
INSERT INTO "django_geo_db_location" VALUES(48493,NULL,'Walsh, IL',20309,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48494,NULL,'Walsh, IL 62297',20309,222,NULL,17,27892,0);
INSERT INTO "django_geo_db_location" VALUES(48495,NULL,'Waterloo, IL',20310,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48496,NULL,'Waterloo, IL 62298',20310,222,NULL,17,27893,0);
INSERT INTO "django_geo_db_location" VALUES(48497,NULL,'Quincy, IL',20311,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48498,NULL,'Quincy, IL 62301',20311,222,NULL,17,27894,0);
INSERT INTO "django_geo_db_location" VALUES(48499,NULL,'Quincy, IL 62305',20311,222,NULL,17,27895,0);
INSERT INTO "django_geo_db_location" VALUES(48500,NULL,'Quincy, IL 62306',20311,222,NULL,17,27896,0);
INSERT INTO "django_geo_db_location" VALUES(48501,NULL,'Adrian, IL',20312,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48502,NULL,'Adrian, IL 62310',20312,222,NULL,17,27897,0);
INSERT INTO "django_geo_db_location" VALUES(48503,NULL,'Augusta, IL',20313,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48504,NULL,'Augusta, IL 62311',20313,222,NULL,17,27898,0);
INSERT INTO "django_geo_db_location" VALUES(48505,NULL,'Barry, IL',20314,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48506,NULL,'Barry, IL 62312',20314,222,NULL,17,27899,0);
INSERT INTO "django_geo_db_location" VALUES(48507,NULL,'Basco, IL',20315,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48508,NULL,'Basco, IL 62313',20315,222,NULL,17,27900,0);
INSERT INTO "django_geo_db_location" VALUES(48509,NULL,'Baylis, IL',20316,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48510,NULL,'Baylis, IL 62314',20316,222,NULL,17,27901,0);
INSERT INTO "django_geo_db_location" VALUES(48511,NULL,'Bowen, IL',20317,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48512,NULL,'Bowen, IL 62316',20317,222,NULL,17,27902,0);
INSERT INTO "django_geo_db_location" VALUES(48513,NULL,'Burnside, IL',20318,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48514,NULL,'Burnside, IL 62318',20318,222,NULL,17,27903,0);
INSERT INTO "django_geo_db_location" VALUES(48515,NULL,'Camden, IL',20319,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48516,NULL,'Camden, IL 62319',20319,222,NULL,17,27904,0);
INSERT INTO "django_geo_db_location" VALUES(48517,NULL,'Camp Point, IL',20320,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48518,NULL,'Camp Point, IL 62320',20320,222,NULL,17,27905,0);
INSERT INTO "django_geo_db_location" VALUES(48519,NULL,'Carthage, IL',20321,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48520,NULL,'Carthage, IL 62321',20321,222,NULL,17,27906,0);
INSERT INTO "django_geo_db_location" VALUES(48521,NULL,'Chambersburg, IL',20322,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48522,NULL,'Chambersburg, IL 62323',20322,222,NULL,17,27907,0);
INSERT INTO "django_geo_db_location" VALUES(48523,NULL,'Clayton, IL',20323,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48524,NULL,'Clayton, IL 62324',20323,222,NULL,17,27908,0);
INSERT INTO "django_geo_db_location" VALUES(48525,NULL,'Coatsburg, IL',20324,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48526,NULL,'Coatsburg, IL 62325',20324,222,NULL,17,27909,0);
INSERT INTO "django_geo_db_location" VALUES(48527,NULL,'Colchester, IL',20325,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48528,NULL,'Colchester, IL 62326',20325,222,NULL,17,27910,0);
INSERT INTO "django_geo_db_location" VALUES(48529,NULL,'Colusa, IL',20326,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48530,NULL,'Colusa, IL 62329',20326,222,NULL,17,27911,0);
INSERT INTO "django_geo_db_location" VALUES(48531,NULL,'Dallas City, IL',20327,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48532,NULL,'Dallas City, IL 62330',20327,222,NULL,17,27912,0);
INSERT INTO "django_geo_db_location" VALUES(48533,NULL,'Elvaston, IL',20328,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48534,NULL,'Elvaston, IL 62334',20328,222,NULL,17,27913,0);
INSERT INTO "django_geo_db_location" VALUES(48535,NULL,'Ferris, IL',20329,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48536,NULL,'Ferris, IL 62336',20329,222,NULL,17,27914,0);
INSERT INTO "django_geo_db_location" VALUES(48537,NULL,'Fowler, IL',20330,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48538,NULL,'Fowler, IL 62338',20330,222,NULL,17,27915,0);
INSERT INTO "django_geo_db_location" VALUES(48539,NULL,'Golden, IL',20331,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48540,NULL,'Golden, IL 62339',20331,222,NULL,17,27916,0);
INSERT INTO "django_geo_db_location" VALUES(48541,NULL,'Griggsville, IL',20332,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48542,NULL,'Griggsville, IL 62340',20332,222,NULL,17,27917,0);
INSERT INTO "django_geo_db_location" VALUES(48543,NULL,'Hamilton, IL',20333,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48544,NULL,'Hamilton, IL 62341',20333,222,NULL,17,27918,0);
INSERT INTO "django_geo_db_location" VALUES(48545,NULL,'Hull, IL',20334,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48546,NULL,'Hull, IL 62343',20334,222,NULL,17,27919,0);
INSERT INTO "django_geo_db_location" VALUES(48547,NULL,'Huntsville, IL',20335,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48548,NULL,'Huntsville, IL 62344',20335,222,NULL,17,27920,0);
INSERT INTO "django_geo_db_location" VALUES(48549,NULL,'Kinderhook, IL',20336,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48550,NULL,'Kinderhook, IL 62345',20336,222,NULL,17,27921,0);
INSERT INTO "django_geo_db_location" VALUES(48551,NULL,'La Prairie, IL',20337,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48552,NULL,'La Prairie, IL 62346',20337,222,NULL,17,27922,0);
INSERT INTO "django_geo_db_location" VALUES(48553,NULL,'Liberty, IL',20338,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48554,NULL,'Liberty, IL 62347',20338,222,NULL,17,27923,0);
INSERT INTO "django_geo_db_location" VALUES(48555,NULL,'Lima, IL',20339,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48556,NULL,'Lima, IL 62348',20339,222,NULL,17,27924,0);
INSERT INTO "django_geo_db_location" VALUES(48557,NULL,'Loraine, IL',20340,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48558,NULL,'Loraine, IL 62349',20340,222,NULL,17,27925,0);
INSERT INTO "django_geo_db_location" VALUES(48559,NULL,'Mendon, IL',20341,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48560,NULL,'Mendon, IL 62351',20341,222,NULL,17,27926,0);
INSERT INTO "django_geo_db_location" VALUES(48561,NULL,'Milton, IL 62352',19494,222,NULL,17,27927,0);
INSERT INTO "django_geo_db_location" VALUES(48562,NULL,'Mount Sterling, IL',20342,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48563,NULL,'Mount Sterling, IL 62353',20342,222,NULL,17,27928,0);
INSERT INTO "django_geo_db_location" VALUES(48564,NULL,'Nauvoo, IL',20343,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48565,NULL,'Nauvoo, IL 62354',20343,222,NULL,17,27929,0);
INSERT INTO "django_geo_db_location" VALUES(48566,NULL,'Nebo, IL',20344,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48567,NULL,'Nebo, IL 62355',20344,222,NULL,17,27930,0);
INSERT INTO "django_geo_db_location" VALUES(48568,NULL,'New Canton, IL',20345,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48569,NULL,'New Canton, IL 62356',20345,222,NULL,17,27931,0);
INSERT INTO "django_geo_db_location" VALUES(48570,NULL,'New Salem, IL',20346,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48571,NULL,'New Salem, IL 62357',20346,222,NULL,17,27932,0);
INSERT INTO "django_geo_db_location" VALUES(48572,NULL,'Niota, IL',20347,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48573,NULL,'Niota, IL 62358',20347,222,NULL,17,27933,0);
INSERT INTO "django_geo_db_location" VALUES(48574,NULL,'Paloma, IL',20348,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48575,NULL,'Paloma, IL 62359',20348,222,NULL,17,27934,0);
INSERT INTO "django_geo_db_location" VALUES(48576,NULL,'Payson, IL',20349,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48577,NULL,'Payson, IL 62360',20349,222,NULL,17,27935,0);
INSERT INTO "django_geo_db_location" VALUES(48578,NULL,'Pearl, IL',20350,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48579,NULL,'Pearl, IL 62361',20350,222,NULL,17,27936,0);
INSERT INTO "django_geo_db_location" VALUES(48580,NULL,'Perry, IL',20351,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48581,NULL,'Perry, IL 62362',20351,222,NULL,17,27937,0);
INSERT INTO "django_geo_db_location" VALUES(48582,NULL,'Pittsfield, IL',20352,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48583,NULL,'Pittsfield, IL 62363',20352,222,NULL,17,27938,0);
INSERT INTO "django_geo_db_location" VALUES(48584,NULL,'Plainville, IL',20353,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48585,NULL,'Plainville, IL 62365',20353,222,NULL,17,27939,0);
INSERT INTO "django_geo_db_location" VALUES(48586,NULL,'Pleasant Hill, IL',20354,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48587,NULL,'Pleasant Hill, IL 62366',20354,222,NULL,17,27940,0);
INSERT INTO "django_geo_db_location" VALUES(48588,NULL,'Plymouth, IL',20355,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48589,NULL,'Plymouth, IL 62367',20355,222,NULL,17,27941,0);
INSERT INTO "django_geo_db_location" VALUES(48590,NULL,'Rockport, IL',20356,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48591,NULL,'Rockport, IL 62370',20356,222,NULL,17,27942,0);
INSERT INTO "django_geo_db_location" VALUES(48592,NULL,'Sutter, IL',20357,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48593,NULL,'Sutter, IL 62373',20357,222,NULL,17,27943,0);
INSERT INTO "django_geo_db_location" VALUES(48594,NULL,'Tennessee, IL',20358,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48595,NULL,'Tennessee, IL 62374',20358,222,NULL,17,27944,0);
INSERT INTO "django_geo_db_location" VALUES(48596,NULL,'Timewell, IL',20359,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48597,NULL,'Timewell, IL 62375',20359,222,NULL,17,27945,0);
INSERT INTO "django_geo_db_location" VALUES(48598,NULL,'Ursa, IL',20360,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48599,NULL,'Ursa, IL 62376',20360,222,NULL,17,27946,0);
INSERT INTO "django_geo_db_location" VALUES(48600,NULL,'Versailles, IL',20361,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48601,NULL,'Versailles, IL 62378',20361,222,NULL,17,27947,0);
INSERT INTO "django_geo_db_location" VALUES(48602,NULL,'Warsaw, IL',20362,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48603,NULL,'Warsaw, IL 62379',20362,222,NULL,17,27948,0);
INSERT INTO "django_geo_db_location" VALUES(48604,NULL,'West Point, IL',20363,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48605,NULL,'West Point, IL 62380',20363,222,NULL,17,27949,0);
INSERT INTO "django_geo_db_location" VALUES(48606,NULL,'Equality, IL',20364,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48607,NULL,'Equality, IL 62394',20364,222,NULL,17,27950,0);
INSERT INTO "django_geo_db_location" VALUES(48608,NULL,'Effingham, IL',20365,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48609,NULL,'Effingham, IL 62401',20365,222,NULL,17,27951,0);
INSERT INTO "django_geo_db_location" VALUES(48610,NULL,'Summit, IL',20366,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48611,NULL,'Summit, IL 62407',20366,222,NULL,17,27952,0);
INSERT INTO "django_geo_db_location" VALUES(48612,NULL,'Allendale, IL',20367,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48613,NULL,'Allendale, IL 62410',20367,222,NULL,17,27953,0);
INSERT INTO "django_geo_db_location" VALUES(48614,NULL,'Altamont, IL',20368,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48615,NULL,'Altamont, IL 62411',20368,222,NULL,17,27954,0);
INSERT INTO "django_geo_db_location" VALUES(48616,NULL,'Annapolis, IL',20369,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48617,NULL,'Annapolis, IL 62413',20369,222,NULL,17,27955,0);
INSERT INTO "django_geo_db_location" VALUES(48618,NULL,'Beecher City, IL',20370,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48619,NULL,'Beecher City, IL 62414',20370,222,NULL,17,27956,0);
INSERT INTO "django_geo_db_location" VALUES(48620,NULL,'Birds, IL',20371,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48621,NULL,'Birds, IL 62415',20371,222,NULL,17,27957,0);
INSERT INTO "django_geo_db_location" VALUES(48622,NULL,'Bridgeport, IL',20372,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48623,NULL,'Bridgeport, IL 62417',20372,222,NULL,17,27958,0);
INSERT INTO "django_geo_db_location" VALUES(48624,NULL,'Brownstown, IL',20373,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48625,NULL,'Brownstown, IL 62418',20373,222,NULL,17,27959,0);
INSERT INTO "django_geo_db_location" VALUES(48626,NULL,'Calhoun, IL',20374,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48627,NULL,'Calhoun, IL 62419',20374,222,NULL,17,27960,0);
INSERT INTO "django_geo_db_location" VALUES(48628,NULL,'Casey, IL',20375,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48629,NULL,'Casey, IL 62420',20375,222,NULL,17,27961,0);
INSERT INTO "django_geo_db_location" VALUES(48630,NULL,'Claremont, IL',20376,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48631,NULL,'Claremont, IL 62421',20376,222,NULL,17,27962,0);
INSERT INTO "django_geo_db_location" VALUES(48632,NULL,'Cowden, IL',20377,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48633,NULL,'Cowden, IL 62422',20377,222,NULL,17,27963,0);
INSERT INTO "django_geo_db_location" VALUES(48634,NULL,'Dennison, IL',20378,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48635,NULL,'Dennison, IL 62423',20378,222,NULL,17,27964,0);
INSERT INTO "django_geo_db_location" VALUES(48636,NULL,'Dieterich, IL',20379,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48637,NULL,'Dieterich, IL 62424',20379,222,NULL,17,27965,0);
INSERT INTO "django_geo_db_location" VALUES(48638,NULL,'Dundas, IL',20380,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48639,NULL,'Dundas, IL 62425',20380,222,NULL,17,27966,0);
INSERT INTO "django_geo_db_location" VALUES(48640,NULL,'Edgewood, IL',20381,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48641,NULL,'Edgewood, IL 62426',20381,222,NULL,17,27967,0);
INSERT INTO "django_geo_db_location" VALUES(48642,NULL,'Flat Rock, IL',20382,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48643,NULL,'Flat Rock, IL 62427',20382,222,NULL,17,27968,0);
INSERT INTO "django_geo_db_location" VALUES(48644,NULL,'Greenup, IL',20383,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48645,NULL,'Greenup, IL 62428',20383,222,NULL,17,27969,0);
INSERT INTO "django_geo_db_location" VALUES(48646,NULL,'Herrick, IL',20384,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48647,NULL,'Herrick, IL 62431',20384,222,NULL,17,27970,0);
INSERT INTO "django_geo_db_location" VALUES(48648,NULL,'Hidalgo, IL',20385,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48649,NULL,'Hidalgo, IL 62432',20385,222,NULL,17,27971,0);
INSERT INTO "django_geo_db_location" VALUES(48650,NULL,'Hutsonville, IL',20386,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48651,NULL,'Hutsonville, IL 62433',20386,222,NULL,17,27972,0);
INSERT INTO "django_geo_db_location" VALUES(48652,NULL,'Ingraham, IL',20387,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48653,NULL,'Ingraham, IL 62434',20387,222,NULL,17,27973,0);
INSERT INTO "django_geo_db_location" VALUES(48654,NULL,'Janesville, IL',20388,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48655,NULL,'Janesville, IL 62435',20388,222,NULL,17,27974,0);
INSERT INTO "django_geo_db_location" VALUES(48656,NULL,'Jewett, IL',20389,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48657,NULL,'Jewett, IL 62436',20389,222,NULL,17,27975,0);
INSERT INTO "django_geo_db_location" VALUES(48658,NULL,'Lakewood, IL',20390,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48659,NULL,'Lakewood, IL 62438',20390,222,NULL,17,27976,0);
INSERT INTO "django_geo_db_location" VALUES(48660,NULL,'Lawrenceville, IL',20391,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48661,NULL,'Lawrenceville, IL 62439',20391,222,NULL,17,27977,0);
INSERT INTO "django_geo_db_location" VALUES(48662,NULL,'Lerna, IL',20392,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48663,NULL,'Lerna, IL 62440',20392,222,NULL,17,27978,0);
INSERT INTO "django_geo_db_location" VALUES(48664,NULL,'Marshall, IL',20393,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48665,NULL,'Marshall, IL 62441',20393,222,NULL,17,27979,0);
INSERT INTO "django_geo_db_location" VALUES(48666,NULL,'Martinsville, IL',20394,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48667,NULL,'Martinsville, IL 62442',20394,222,NULL,17,27980,0);
INSERT INTO "django_geo_db_location" VALUES(48668,NULL,'Mason, IL',20395,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48669,NULL,'Mason, IL 62443',20395,222,NULL,17,27981,0);
INSERT INTO "django_geo_db_location" VALUES(48670,NULL,'Mode, IL',20396,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48671,NULL,'Mode, IL 62444',20396,222,NULL,17,27982,0);
INSERT INTO "django_geo_db_location" VALUES(48672,NULL,'Montrose, IL',20397,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48673,NULL,'Montrose, IL 62445',20397,222,NULL,17,27983,0);
INSERT INTO "django_geo_db_location" VALUES(48674,NULL,'Mount Erie, IL',20398,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48675,NULL,'Mount Erie, IL 62446',20398,222,NULL,17,27984,0);
INSERT INTO "django_geo_db_location" VALUES(48676,NULL,'Neoga, IL',20399,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48677,NULL,'Neoga, IL 62447',20399,222,NULL,17,27985,0);
INSERT INTO "django_geo_db_location" VALUES(48678,NULL,'Newton, IL',20400,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48679,NULL,'Newton, IL 62448',20400,222,NULL,17,27986,0);
INSERT INTO "django_geo_db_location" VALUES(48680,NULL,'Oblong, IL',20401,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48681,NULL,'Oblong, IL 62449',20401,222,NULL,17,27987,0);
INSERT INTO "django_geo_db_location" VALUES(48682,NULL,'Olney, IL',20402,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48683,NULL,'Olney, IL 62450',20402,222,NULL,17,27988,0);
INSERT INTO "django_geo_db_location" VALUES(48684,NULL,'Palestine, IL',20403,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48685,NULL,'Palestine, IL 62451',20403,222,NULL,17,27989,0);
INSERT INTO "django_geo_db_location" VALUES(48686,NULL,'Parkersburg, IL',20404,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48687,NULL,'Parkersburg, IL 62452',20404,222,NULL,17,27990,0);
INSERT INTO "django_geo_db_location" VALUES(48688,NULL,'Robinson, IL',20405,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48689,NULL,'Robinson, IL 62454',20405,222,NULL,17,27991,0);
INSERT INTO "django_geo_db_location" VALUES(48690,NULL,'Saint Elmo, IL',20406,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48691,NULL,'Saint Elmo, IL 62458',20406,222,NULL,17,27992,0);
INSERT INTO "django_geo_db_location" VALUES(48692,NULL,'Sainte Marie, IL',20407,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48693,NULL,'Sainte Marie, IL 62459',20407,222,NULL,17,27993,0);
INSERT INTO "django_geo_db_location" VALUES(48694,NULL,'Saint Francisville, IL',20408,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48695,NULL,'Saint Francisville, IL 62460',20408,222,NULL,17,27994,0);
INSERT INTO "django_geo_db_location" VALUES(48696,NULL,'Shumway, IL',20409,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48697,NULL,'Shumway, IL 62461',20409,222,NULL,17,27995,0);
INSERT INTO "django_geo_db_location" VALUES(48698,NULL,'Sigel, IL',20410,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48699,NULL,'Sigel, IL 62462',20410,222,NULL,17,27996,0);
INSERT INTO "django_geo_db_location" VALUES(48700,NULL,'Stewardson, IL',20411,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48701,NULL,'Stewardson, IL 62463',20411,222,NULL,17,27997,0);
INSERT INTO "django_geo_db_location" VALUES(48702,NULL,'Stoy, IL',20412,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48703,NULL,'Stoy, IL 62464',20412,222,NULL,17,27998,0);
INSERT INTO "django_geo_db_location" VALUES(48704,NULL,'Strasburg, IL',20413,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48705,NULL,'Strasburg, IL 62465',20413,222,NULL,17,27999,0);
INSERT INTO "django_geo_db_location" VALUES(48706,NULL,'Sumner, IL',20414,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48707,NULL,'Sumner, IL 62466',20414,222,NULL,17,28000,0);
INSERT INTO "django_geo_db_location" VALUES(48708,NULL,'Teutopolis, IL',20415,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48709,NULL,'Teutopolis, IL 62467',20415,222,NULL,17,28001,0);
INSERT INTO "django_geo_db_location" VALUES(48710,NULL,'Toledo, IL',20416,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48711,NULL,'Toledo, IL 62468',20416,222,NULL,17,28002,0);
INSERT INTO "django_geo_db_location" VALUES(48712,NULL,'Trilla, IL',20417,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48713,NULL,'Trilla, IL 62469',20417,222,NULL,17,28003,0);
INSERT INTO "django_geo_db_location" VALUES(48714,NULL,'Vandalia, IL',20418,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48715,NULL,'Vandalia, IL 62471',20418,222,NULL,17,28004,0);
INSERT INTO "django_geo_db_location" VALUES(48716,NULL,'Watson, IL',20419,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48717,NULL,'Watson, IL 62473',20419,222,NULL,17,28005,0);
INSERT INTO "django_geo_db_location" VALUES(48718,NULL,'Westfield, IL',20420,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48719,NULL,'Westfield, IL 62474',20420,222,NULL,17,28006,0);
INSERT INTO "django_geo_db_location" VALUES(48720,NULL,'West Liberty, IL',20421,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48721,NULL,'West Liberty, IL 62475',20421,222,NULL,17,28007,0);
INSERT INTO "django_geo_db_location" VALUES(48722,NULL,'West Salem, IL',20422,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48723,NULL,'West Salem, IL 62476',20422,222,NULL,17,28008,0);
INSERT INTO "django_geo_db_location" VALUES(48724,NULL,'West Union, IL',20423,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48725,NULL,'West Union, IL 62477',20423,222,NULL,17,28009,0);
INSERT INTO "django_geo_db_location" VALUES(48726,NULL,'West York, IL',20424,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48727,NULL,'West York, IL 62478',20424,222,NULL,17,28010,0);
INSERT INTO "django_geo_db_location" VALUES(48728,NULL,'Wheeler, IL',20425,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48729,NULL,'Wheeler, IL 62479',20425,222,NULL,17,28011,0);
INSERT INTO "django_geo_db_location" VALUES(48730,NULL,'Willow Hill, IL',20426,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48731,NULL,'Willow Hill, IL 62480',20426,222,NULL,17,28012,0);
INSERT INTO "django_geo_db_location" VALUES(48732,NULL,'Yale, IL',20427,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48733,NULL,'Yale, IL 62481',20427,222,NULL,17,28013,0);
INSERT INTO "django_geo_db_location" VALUES(48734,NULL,'Argenta, IL',20428,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48735,NULL,'Argenta, IL 62501',20428,222,NULL,17,28014,0);
INSERT INTO "django_geo_db_location" VALUES(48736,NULL,'Assumption, IL',20429,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48737,NULL,'Assumption, IL 62510',20429,222,NULL,17,28015,0);
INSERT INTO "django_geo_db_location" VALUES(48738,NULL,'Atwater, IL',20430,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48739,NULL,'Atwater, IL 62511',20430,222,NULL,17,28016,0);
INSERT INTO "django_geo_db_location" VALUES(48740,NULL,'Beason, IL',20431,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48741,NULL,'Beason, IL 62512',20431,222,NULL,17,28017,0);
INSERT INTO "django_geo_db_location" VALUES(48742,NULL,'Blue Mound, IL',20432,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48743,NULL,'Blue Mound, IL 62513',20432,222,NULL,17,28018,0);
INSERT INTO "django_geo_db_location" VALUES(48744,NULL,'Boody, IL',20433,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48745,NULL,'Boody, IL 62514',20433,222,NULL,17,28019,0);
INSERT INTO "django_geo_db_location" VALUES(48746,NULL,'Buffalo, IL',20434,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48747,NULL,'Buffalo, IL 62515',20434,222,NULL,17,28020,0);
INSERT INTO "django_geo_db_location" VALUES(48748,NULL,'Bulpitt, IL',20435,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48749,NULL,'Bulpitt, IL 62517',20435,222,NULL,17,28021,0);
INSERT INTO "django_geo_db_location" VALUES(48750,NULL,'Chestnut, IL',20436,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48751,NULL,'Chestnut, IL 62518',20436,222,NULL,17,28022,0);
INSERT INTO "django_geo_db_location" VALUES(48752,NULL,'Cornland, IL',20437,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48753,NULL,'Cornland, IL 62519',20437,222,NULL,17,28023,0);
INSERT INTO "django_geo_db_location" VALUES(48754,NULL,'Dawson, IL',20438,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48755,NULL,'Dawson, IL 62520',20438,222,NULL,17,28024,0);
INSERT INTO "django_geo_db_location" VALUES(48756,NULL,'Decatur, IL',20439,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48757,NULL,'Decatur, IL 62521',20439,222,NULL,17,28025,0);
INSERT INTO "django_geo_db_location" VALUES(48758,NULL,'Decatur, IL 62522',20439,222,NULL,17,28026,0);
INSERT INTO "django_geo_db_location" VALUES(48759,NULL,'Decatur, IL 62523',20439,222,NULL,17,28027,0);
INSERT INTO "django_geo_db_location" VALUES(48760,NULL,'Decatur, IL 62524',20439,222,NULL,17,28028,0);
INSERT INTO "django_geo_db_location" VALUES(48761,NULL,'Decatur, IL 62525',20439,222,NULL,17,28029,0);
INSERT INTO "django_geo_db_location" VALUES(48762,NULL,'Decatur, IL 62526',20439,222,NULL,17,28030,0);
INSERT INTO "django_geo_db_location" VALUES(48763,NULL,'Decatur, IL 62527',20439,222,NULL,17,28031,0);
INSERT INTO "django_geo_db_location" VALUES(48764,NULL,'Divernon, IL',20440,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48765,NULL,'Divernon, IL 62530',20440,222,NULL,17,28032,0);
INSERT INTO "django_geo_db_location" VALUES(48766,NULL,'Edinburg, IL',20441,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48767,NULL,'Edinburg, IL 62531',20441,222,NULL,17,28033,0);
INSERT INTO "django_geo_db_location" VALUES(48768,NULL,'Elwin, IL',20442,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48769,NULL,'Elwin, IL 62532',20442,222,NULL,17,28034,0);
INSERT INTO "django_geo_db_location" VALUES(48770,NULL,'Farmersville, IL',20443,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48771,NULL,'Farmersville, IL 62533',20443,222,NULL,17,28035,0);
INSERT INTO "django_geo_db_location" VALUES(48772,NULL,'Findlay, IL',20444,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48773,NULL,'Findlay, IL 62534',20444,222,NULL,17,28036,0);
INSERT INTO "django_geo_db_location" VALUES(48774,NULL,'Forsyth, IL',20445,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48775,NULL,'Forsyth, IL 62535',20445,222,NULL,17,28037,0);
INSERT INTO "django_geo_db_location" VALUES(48776,NULL,'Glenarm, IL',20446,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48777,NULL,'Glenarm, IL 62536',20446,222,NULL,17,28038,0);
INSERT INTO "django_geo_db_location" VALUES(48778,NULL,'Harristown, IL',20447,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48779,NULL,'Harristown, IL 62537',20447,222,NULL,17,28039,0);
INSERT INTO "django_geo_db_location" VALUES(48780,NULL,'Harvel, IL',20448,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48781,NULL,'Harvel, IL 62538',20448,222,NULL,17,28040,0);
INSERT INTO "django_geo_db_location" VALUES(48782,NULL,'Illiopolis, IL',20449,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48783,NULL,'Illiopolis, IL 62539',20449,222,NULL,17,28041,0);
INSERT INTO "django_geo_db_location" VALUES(48784,NULL,'Kincaid, IL',20450,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48785,NULL,'Kincaid, IL 62540',20450,222,NULL,17,28042,0);
INSERT INTO "django_geo_db_location" VALUES(48786,NULL,'Lake Fork, IL',20451,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48787,NULL,'Lake Fork, IL 62541',20451,222,NULL,17,28043,0);
INSERT INTO "django_geo_db_location" VALUES(48788,NULL,'Latham, IL',20452,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48789,NULL,'Latham, IL 62543',20452,222,NULL,17,28044,0);
INSERT INTO "django_geo_db_location" VALUES(48790,NULL,'Macon, IL',20453,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48791,NULL,'Macon, IL 62544',20453,222,NULL,17,28045,0);
INSERT INTO "django_geo_db_location" VALUES(48792,NULL,'Mechanicsburg, IL',20454,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48793,NULL,'Mechanicsburg, IL 62545',20454,222,NULL,17,28046,0);
INSERT INTO "django_geo_db_location" VALUES(48794,NULL,'Morrisonville, IL',20455,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48795,NULL,'Morrisonville, IL 62546',20455,222,NULL,17,28047,0);
INSERT INTO "django_geo_db_location" VALUES(48796,NULL,'Mount Auburn, IL',20456,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48797,NULL,'Mount Auburn, IL 62547',20456,222,NULL,17,28048,0);
INSERT INTO "django_geo_db_location" VALUES(48798,NULL,'Mount Pulaski, IL',20457,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48799,NULL,'Mount Pulaski, IL 62548',20457,222,NULL,17,28049,0);
INSERT INTO "django_geo_db_location" VALUES(48800,NULL,'Mt Zion, IL',20458,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48801,NULL,'Mt Zion, IL 62549',20458,222,NULL,17,28050,0);
INSERT INTO "django_geo_db_location" VALUES(48802,NULL,'Moweaqua, IL',20459,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48803,NULL,'Moweaqua, IL 62550',20459,222,NULL,17,28051,0);
INSERT INTO "django_geo_db_location" VALUES(48804,NULL,'Niantic, IL',20460,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48805,NULL,'Niantic, IL 62551',20460,222,NULL,17,28052,0);
INSERT INTO "django_geo_db_location" VALUES(48806,NULL,'Oakley, IL',20461,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48807,NULL,'Oakley, IL 62552',20461,222,NULL,17,28053,0);
INSERT INTO "django_geo_db_location" VALUES(48808,NULL,'Oconee, IL',20462,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48809,NULL,'Oconee, IL 62553',20462,222,NULL,17,28054,0);
INSERT INTO "django_geo_db_location" VALUES(48810,NULL,'Oreana, IL',20463,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48811,NULL,'Oreana, IL 62554',20463,222,NULL,17,28055,0);
INSERT INTO "django_geo_db_location" VALUES(48812,NULL,'Owaneco, IL',20464,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48813,NULL,'Owaneco, IL 62555',20464,222,NULL,17,28056,0);
INSERT INTO "django_geo_db_location" VALUES(48814,NULL,'Palmer, IL',20465,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48815,NULL,'Palmer, IL 62556',20465,222,NULL,17,28057,0);
INSERT INTO "django_geo_db_location" VALUES(48816,NULL,'Pana, IL',20466,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48817,NULL,'Pana, IL 62557',20466,222,NULL,17,28058,0);
INSERT INTO "django_geo_db_location" VALUES(48818,NULL,'Pawnee, IL',20467,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48819,NULL,'Pawnee, IL 62558',20467,222,NULL,17,28059,0);
INSERT INTO "django_geo_db_location" VALUES(48820,NULL,'Raymond, IL',20468,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48821,NULL,'Raymond, IL 62560',20468,222,NULL,17,28060,0);
INSERT INTO "django_geo_db_location" VALUES(48822,NULL,'Riverton, IL',20469,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48823,NULL,'Riverton, IL 62561',20469,222,NULL,17,28061,0);
INSERT INTO "django_geo_db_location" VALUES(48824,NULL,'Rochester, IL',20470,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48825,NULL,'Rochester, IL 62563',20470,222,NULL,17,28062,0);
INSERT INTO "django_geo_db_location" VALUES(48826,NULL,'Shelbyville, IL',20471,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48827,NULL,'Shelbyville, IL 62565',20471,222,NULL,17,28063,0);
INSERT INTO "django_geo_db_location" VALUES(48828,NULL,'Stonington, IL',20472,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48829,NULL,'Stonington, IL 62567',20472,222,NULL,17,28064,0);
INSERT INTO "django_geo_db_location" VALUES(48830,NULL,'Taylorville, IL',20473,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48831,NULL,'Taylorville, IL 62568',20473,222,NULL,17,28065,0);
INSERT INTO "django_geo_db_location" VALUES(48832,NULL,'Tovey, IL',20474,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48833,NULL,'Tovey, IL 62570',20474,222,NULL,17,28066,0);
INSERT INTO "django_geo_db_location" VALUES(48834,NULL,'Tower Hill, IL',20475,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48835,NULL,'Tower Hill, IL 62571',20475,222,NULL,17,28067,0);
INSERT INTO "django_geo_db_location" VALUES(48836,NULL,'Waggoner, IL',20476,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48837,NULL,'Waggoner, IL 62572',20476,222,NULL,17,28068,0);
INSERT INTO "django_geo_db_location" VALUES(48838,NULL,'Warrensburg, IL',20477,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48839,NULL,'Warrensburg, IL 62573',20477,222,NULL,17,28069,0);
INSERT INTO "django_geo_db_location" VALUES(48840,NULL,'Alexander, IL',20478,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48841,NULL,'Alexander, IL 62601',20478,222,NULL,17,28070,0);
INSERT INTO "django_geo_db_location" VALUES(48842,NULL,'Emden, IL',20479,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48843,NULL,'Emden, IL 62605',20479,222,NULL,17,28071,0);
INSERT INTO "django_geo_db_location" VALUES(48844,NULL,'Alsey, IL',20480,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48845,NULL,'Alsey, IL 62610',20480,222,NULL,17,28072,0);
INSERT INTO "django_geo_db_location" VALUES(48846,NULL,'Arenzville, IL',20481,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48847,NULL,'Arenzville, IL 62611',20481,222,NULL,17,28073,0);
INSERT INTO "django_geo_db_location" VALUES(48848,NULL,'Ashland, IL',20482,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48849,NULL,'Ashland, IL 62612',20482,222,NULL,17,28074,0);
INSERT INTO "django_geo_db_location" VALUES(48850,NULL,'Athens, IL',20483,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48851,NULL,'Athens, IL 62613',20483,222,NULL,17,28075,0);
INSERT INTO "django_geo_db_location" VALUES(48852,NULL,'Auburn, IL',20484,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48853,NULL,'Auburn, IL 62615',20484,222,NULL,17,28076,0);
INSERT INTO "django_geo_db_location" VALUES(48854,NULL,'Philadelphia, IL',20485,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48855,NULL,'Philadelphia, IL 62616',20485,222,NULL,17,28077,0);
INSERT INTO "django_geo_db_location" VALUES(48856,NULL,'Bath, IL',20486,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48857,NULL,'Bath, IL 62617',20486,222,NULL,17,28078,0);
INSERT INTO "django_geo_db_location" VALUES(48858,NULL,'Beardstown, IL',20487,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48859,NULL,'Beardstown, IL 62618',20487,222,NULL,17,28079,0);
INSERT INTO "django_geo_db_location" VALUES(48860,NULL,'Bluffs, IL',20488,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48861,NULL,'Bluffs, IL 62621',20488,222,NULL,17,28080,0);
INSERT INTO "django_geo_db_location" VALUES(48862,NULL,'Bluff Springs, IL',20489,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48863,NULL,'Bluff Springs, IL 62622',20489,222,NULL,17,28081,0);
INSERT INTO "django_geo_db_location" VALUES(48864,NULL,'Oakford, IL',20490,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48865,NULL,'Oakford, IL 62623',20490,222,NULL,17,28082,0);
INSERT INTO "django_geo_db_location" VALUES(48866,NULL,'Browning, IL',20491,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48867,NULL,'Browning, IL 62624',20491,222,NULL,17,28083,0);
INSERT INTO "django_geo_db_location" VALUES(48868,NULL,'Cantrall, IL',20492,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48869,NULL,'Cantrall, IL 62625',20492,222,NULL,17,28084,0);
INSERT INTO "django_geo_db_location" VALUES(48870,NULL,'Carlinville, IL',20493,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48871,NULL,'Carlinville, IL 62626',20493,222,NULL,17,28085,0);
INSERT INTO "django_geo_db_location" VALUES(48872,NULL,'Chandlerville, IL',20494,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48873,NULL,'Chandlerville, IL 62627',20494,222,NULL,17,28086,0);
INSERT INTO "django_geo_db_location" VALUES(48874,NULL,'Chapin, IL',20495,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48875,NULL,'Chapin, IL 62628',20495,222,NULL,17,28087,0);
INSERT INTO "django_geo_db_location" VALUES(48876,NULL,'Chatham, IL',20496,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48877,NULL,'Chatham, IL 62629',20496,222,NULL,17,28088,0);
INSERT INTO "django_geo_db_location" VALUES(48878,NULL,'Chesterfield, IL',20497,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48879,NULL,'Chesterfield, IL 62630',20497,222,NULL,17,28089,0);
INSERT INTO "django_geo_db_location" VALUES(48880,NULL,'Concord, IL',20498,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48881,NULL,'Concord, IL 62631',20498,222,NULL,17,28090,0);
INSERT INTO "django_geo_db_location" VALUES(48882,NULL,'Easton, IL',20499,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48883,NULL,'Easton, IL 62633',20499,222,NULL,17,28091,0);
INSERT INTO "django_geo_db_location" VALUES(48884,NULL,'Elkhart, IL',20500,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48885,NULL,'Elkhart, IL 62634',20500,222,NULL,17,28092,0);
INSERT INTO "django_geo_db_location" VALUES(48886,NULL,'Emden, IL 62635',20479,222,NULL,17,28093,0);
INSERT INTO "django_geo_db_location" VALUES(48887,NULL,'Franklin, IL',20501,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48888,NULL,'Franklin, IL 62638',20501,222,NULL,17,28094,0);
INSERT INTO "django_geo_db_location" VALUES(48889,NULL,'Frederick, IL',20502,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48890,NULL,'Frederick, IL 62639',20502,222,NULL,17,28095,0);
INSERT INTO "django_geo_db_location" VALUES(48891,NULL,'Girard, IL',20503,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48892,NULL,'Girard, IL 62640',20503,222,NULL,17,28096,0);
INSERT INTO "django_geo_db_location" VALUES(48893,NULL,'Greenview, IL',20504,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48894,NULL,'Greenview, IL 62642',20504,222,NULL,17,28097,0);
INSERT INTO "django_geo_db_location" VALUES(48895,NULL,'Hartsburg, IL',20505,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48896,NULL,'Hartsburg, IL 62643',20505,222,NULL,17,28098,0);
INSERT INTO "django_geo_db_location" VALUES(48897,NULL,'Havana, IL',20506,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48898,NULL,'Havana, IL 62644',20506,222,NULL,17,28099,0);
INSERT INTO "django_geo_db_location" VALUES(48899,NULL,'Herrin, IL',20507,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48900,NULL,'Herrin, IL 62648',20507,222,NULL,17,28100,0);
INSERT INTO "django_geo_db_location" VALUES(48901,NULL,'Hettick, IL',20508,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48902,NULL,'Hettick, IL 62649',20508,222,NULL,17,28101,0);
INSERT INTO "django_geo_db_location" VALUES(48903,NULL,'Jacksonville, IL',20509,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48904,NULL,'Jacksonville, IL 62650',20509,222,NULL,17,28102,0);
INSERT INTO "django_geo_db_location" VALUES(48905,NULL,'Jacksonville, IL 62651',20509,222,NULL,17,28103,0);
INSERT INTO "django_geo_db_location" VALUES(48906,NULL,'Milton, IL 62652',19494,222,NULL,17,28104,0);
INSERT INTO "django_geo_db_location" VALUES(48907,NULL,'Kilbourne, IL',20510,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48908,NULL,'Kilbourne, IL 62655',20510,222,NULL,17,28105,0);
INSERT INTO "django_geo_db_location" VALUES(48909,NULL,'Lincoln, IL',20511,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48910,NULL,'Lincoln, IL 62656',20511,222,NULL,17,28106,0);
INSERT INTO "django_geo_db_location" VALUES(48911,NULL,'Lincoln''S New Salem, IL',20512,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48912,NULL,'Lincoln''S New Salem, IL 62659',20512,222,NULL,17,28107,0);
INSERT INTO "django_geo_db_location" VALUES(48913,NULL,'Literberry, IL',20513,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48914,NULL,'Literberry, IL 62660',20513,222,NULL,17,28108,0);
INSERT INTO "django_geo_db_location" VALUES(48915,NULL,'Loami, IL',20514,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48916,NULL,'Loami, IL 62661',20514,222,NULL,17,28109,0);
INSERT INTO "django_geo_db_location" VALUES(48917,NULL,'Lowder, IL',20515,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48918,NULL,'Lowder, IL 62662',20515,222,NULL,17,28110,0);
INSERT INTO "django_geo_db_location" VALUES(48919,NULL,'Manchester, IL',20516,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48920,NULL,'Manchester, IL 62663',20516,222,NULL,17,28111,0);
INSERT INTO "django_geo_db_location" VALUES(48921,NULL,'Mason City, IL',20517,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48922,NULL,'Mason City, IL 62664',20517,222,NULL,17,28112,0);
INSERT INTO "django_geo_db_location" VALUES(48923,NULL,'Meredosia, IL',20518,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48924,NULL,'Meredosia, IL 62665',20518,222,NULL,17,28113,0);
INSERT INTO "django_geo_db_location" VALUES(48925,NULL,'Middletown, IL',20519,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48926,NULL,'Middletown, IL 62666',20519,222,NULL,17,28114,0);
INSERT INTO "django_geo_db_location" VALUES(48927,NULL,'Modesto, IL',20520,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48928,NULL,'Modesto, IL 62667',20520,222,NULL,17,28115,0);
INSERT INTO "django_geo_db_location" VALUES(48929,NULL,'Murrayville, IL',20521,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48930,NULL,'Murrayville, IL 62668',20521,222,NULL,17,28116,0);
INSERT INTO "django_geo_db_location" VALUES(48931,NULL,'New Berlin, IL',20522,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48932,NULL,'New Berlin, IL 62670',20522,222,NULL,17,28117,0);
INSERT INTO "django_geo_db_location" VALUES(48933,NULL,'New Holland, IL',20523,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48934,NULL,'New Holland, IL 62671',20523,222,NULL,17,28118,0);
INSERT INTO "django_geo_db_location" VALUES(48935,NULL,'Nilwood, IL',20524,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48936,NULL,'Nilwood, IL 62672',20524,222,NULL,17,28119,0);
INSERT INTO "django_geo_db_location" VALUES(48937,NULL,'Oakford, IL 62673',20490,222,NULL,17,28120,0);
INSERT INTO "django_geo_db_location" VALUES(48938,NULL,'Palmyra, IL',20525,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48939,NULL,'Palmyra, IL 62674',20525,222,NULL,17,28121,0);
INSERT INTO "django_geo_db_location" VALUES(48940,NULL,'Petersburg, IL',20526,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48941,NULL,'Petersburg, IL 62675',20526,222,NULL,17,28122,0);
INSERT INTO "django_geo_db_location" VALUES(48942,NULL,'Hillyard, IL',20527,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48943,NULL,'Hillyard, IL 62676',20527,222,NULL,17,28123,0);
INSERT INTO "django_geo_db_location" VALUES(48944,NULL,'Pleasant Plains, IL',20528,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48945,NULL,'Pleasant Plains, IL 62677',20528,222,NULL,17,28124,0);
INSERT INTO "django_geo_db_location" VALUES(48946,NULL,'Rushville, IL',20529,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48947,NULL,'Rushville, IL 62681',20529,222,NULL,17,28125,0);
INSERT INTO "django_geo_db_location" VALUES(48948,NULL,'San Jose, IL',20530,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48949,NULL,'San Jose, IL 62682',20530,222,NULL,17,28126,0);
INSERT INTO "django_geo_db_location" VALUES(48950,NULL,'Scottville, IL',20531,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48951,NULL,'Scottville, IL 62683',20531,222,NULL,17,28127,0);
INSERT INTO "django_geo_db_location" VALUES(48952,NULL,'Sherman, IL',20532,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48953,NULL,'Sherman, IL 62684',20532,222,NULL,17,28128,0);
INSERT INTO "django_geo_db_location" VALUES(48954,NULL,'Shipman, IL',20533,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48955,NULL,'Shipman, IL 62685',20533,222,NULL,17,28129,0);
INSERT INTO "django_geo_db_location" VALUES(48956,NULL,'Standard City, IL',20534,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48957,NULL,'Standard City, IL 62686',20534,222,NULL,17,28130,0);
INSERT INTO "django_geo_db_location" VALUES(48958,NULL,'Tallula, IL',20535,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48959,NULL,'Tallula, IL 62688',20535,222,NULL,17,28131,0);
INSERT INTO "django_geo_db_location" VALUES(48960,NULL,'Thayer, IL',20536,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48961,NULL,'Thayer, IL 62689',20536,222,NULL,17,28132,0);
INSERT INTO "django_geo_db_location" VALUES(48962,NULL,'Virden, IL',20537,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48963,NULL,'Virden, IL 62690',20537,222,NULL,17,28133,0);
INSERT INTO "django_geo_db_location" VALUES(48964,NULL,'Virginia, IL',20538,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48965,NULL,'Virginia, IL 62691',20538,222,NULL,17,28134,0);
INSERT INTO "django_geo_db_location" VALUES(48966,NULL,'Waverly, IL',20539,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48967,NULL,'Waverly, IL 62692',20539,222,NULL,17,28135,0);
INSERT INTO "django_geo_db_location" VALUES(48968,NULL,'Williamsville, IL',20540,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48969,NULL,'Williamsville, IL 62693',20540,222,NULL,17,28136,0);
INSERT INTO "django_geo_db_location" VALUES(48970,NULL,'Winchester, IL',20541,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48971,NULL,'Winchester, IL 62694',20541,222,NULL,17,28137,0);
INSERT INTO "django_geo_db_location" VALUES(48972,NULL,'Woodson, IL',20542,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48973,NULL,'Woodson, IL 62695',20542,222,NULL,17,28138,0);
INSERT INTO "django_geo_db_location" VALUES(48974,NULL,'Springfield, IL',20543,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(48975,NULL,'Springfield, IL 62701',20543,222,NULL,17,28139,0);
INSERT INTO "django_geo_db_location" VALUES(48976,NULL,'Springfield, IL 62702',20543,222,NULL,17,28140,0);
INSERT INTO "django_geo_db_location" VALUES(48977,NULL,'Springfield, IL 62703',20543,222,NULL,17,28141,0);
INSERT INTO "django_geo_db_location" VALUES(48978,NULL,'Springfield, IL 62704',20543,222,NULL,17,28142,0);
INSERT INTO "django_geo_db_location" VALUES(48979,NULL,'Springfield, IL 62705',20543,222,NULL,17,28143,0);
INSERT INTO "django_geo_db_location" VALUES(48980,NULL,'Springfield, IL 62706',20543,222,NULL,17,28144,0);
INSERT INTO "django_geo_db_location" VALUES(48981,NULL,'Springfield, IL 62707',20543,222,NULL,17,28145,0);
INSERT INTO "django_geo_db_location" VALUES(48982,NULL,'Springfield, IL 62708',20543,222,NULL,17,28146,0);
INSERT INTO "django_geo_db_location" VALUES(48983,NULL,'Springfield, IL 62709',20543,222,NULL,17,28147,0);
INSERT INTO "django_geo_db_location" VALUES(48984,NULL,'Springfield, IL 62713',20543,222,NULL,17,28148,0);
INSERT INTO "django_geo_db_location" VALUES(48985,NULL,'Springfield, IL 62715',20543,222,NULL,17,28149,0);
INSERT INTO "django_geo_db_location" VALUES(48986,NULL,'Springfield, IL 62716',20543,222,NULL,17,28150,0);
INSERT INTO "django_geo_db_location" VALUES(48987,NULL,'Springfield, IL 62718',20543,222,NULL,17,28151,0);
INSERT INTO "django_geo_db_location" VALUES(48988,NULL,'Springfield, IL 62719',20543,222,NULL,17,28152,0);
INSERT INTO "django_geo_db_location" VALUES(48989,NULL,'Springfield, IL 62720',20543,222,NULL,17,28153,0);
INSERT INTO "django_geo_db_location" VALUES(48990,NULL,'Springfield, IL 62721',20543,222,NULL,17,28154,0);
INSERT INTO "django_geo_db_location" VALUES(48991,NULL,'Springfield, IL 62722',20543,222,NULL,17,28155,0);
INSERT INTO "django_geo_db_location" VALUES(48992,NULL,'Springfield, IL 62723',20543,222,NULL,17,28156,0);
INSERT INTO "django_geo_db_location" VALUES(48993,NULL,'Springfield, IL 62726',20543,222,NULL,17,28157,0);
INSERT INTO "django_geo_db_location" VALUES(48994,NULL,'Springfield, IL 62736',20543,222,NULL,17,28158,0);
INSERT INTO "django_geo_db_location" VALUES(48995,NULL,'Springfield, IL 62739',20543,222,NULL,17,28159,0);
INSERT INTO "django_geo_db_location" VALUES(48996,NULL,'Springfield, IL 62746',20543,222,NULL,17,28160,0);
INSERT INTO "django_geo_db_location" VALUES(48997,NULL,'Springfield, IL 62756',20543,222,NULL,17,28161,0);
INSERT INTO "django_geo_db_location" VALUES(48998,NULL,'Springfield, IL 62757',20543,222,NULL,17,28162,0);
INSERT INTO "django_geo_db_location" VALUES(48999,NULL,'Springfield, IL 62761',20543,222,NULL,17,28163,0);
INSERT INTO "django_geo_db_location" VALUES(49000,NULL,'Springfield, IL 62762',20543,222,NULL,17,28164,0);
INSERT INTO "django_geo_db_location" VALUES(49001,NULL,'Springfield, IL 62763',20543,222,NULL,17,28165,0);
INSERT INTO "django_geo_db_location" VALUES(49002,NULL,'Springfield, IL 62764',20543,222,NULL,17,28166,0);
INSERT INTO "django_geo_db_location" VALUES(49003,NULL,'Springfield, IL 62765',20543,222,NULL,17,28167,0);
INSERT INTO "django_geo_db_location" VALUES(49004,NULL,'Springfield, IL 62766',20543,222,NULL,17,28168,0);
INSERT INTO "django_geo_db_location" VALUES(49005,NULL,'Springfield, IL 62767',20543,222,NULL,17,28169,0);
INSERT INTO "django_geo_db_location" VALUES(49006,NULL,'Springfield, IL 62769',20543,222,NULL,17,28170,0);
INSERT INTO "django_geo_db_location" VALUES(49007,NULL,'Springfield, IL 62776',20543,222,NULL,17,28171,0);
INSERT INTO "django_geo_db_location" VALUES(49008,NULL,'Springfield, IL 62777',20543,222,NULL,17,28172,0);
INSERT INTO "django_geo_db_location" VALUES(49009,NULL,'Springfield, IL 62781',20543,222,NULL,17,28173,0);
INSERT INTO "django_geo_db_location" VALUES(49010,NULL,'Springfield, IL 62786',20543,222,NULL,17,28174,0);
INSERT INTO "django_geo_db_location" VALUES(49011,NULL,'Springfield, IL 62791',20543,222,NULL,17,28175,0);
INSERT INTO "django_geo_db_location" VALUES(49012,NULL,'Ullin, IL',20544,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49013,NULL,'Ullin, IL 62792',20544,222,NULL,17,28176,0);
INSERT INTO "django_geo_db_location" VALUES(49014,NULL,'Springfield, IL 62794',20543,222,NULL,17,28177,0);
INSERT INTO "django_geo_db_location" VALUES(49015,NULL,'Springfield, IL 62796',20543,222,NULL,17,28178,0);
INSERT INTO "django_geo_db_location" VALUES(49016,NULL,'Centralia, IL',20545,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49017,NULL,'Centralia, IL 62801',20545,222,NULL,17,28179,0);
INSERT INTO "django_geo_db_location" VALUES(49018,NULL,'Hoyleton, IL',20546,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49019,NULL,'Hoyleton, IL 62803',20546,222,NULL,17,28180,0);
INSERT INTO "django_geo_db_location" VALUES(49020,NULL,'Akin, IL',20547,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49021,NULL,'Akin, IL 62805',20547,222,NULL,17,28181,0);
INSERT INTO "django_geo_db_location" VALUES(49022,NULL,'Albion, IL',20548,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49023,NULL,'Albion, IL 62806',20548,222,NULL,17,28182,0);
INSERT INTO "django_geo_db_location" VALUES(49024,NULL,'Alma, IL',20549,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49025,NULL,'Alma, IL 62807',20549,222,NULL,17,28183,0);
INSERT INTO "django_geo_db_location" VALUES(49026,NULL,'Ashley, IL',20550,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49027,NULL,'Ashley, IL 62808',20550,222,NULL,17,28184,0);
INSERT INTO "django_geo_db_location" VALUES(49028,NULL,'Barnhill, IL',20551,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49029,NULL,'Barnhill, IL 62809',20551,222,NULL,17,28185,0);
INSERT INTO "django_geo_db_location" VALUES(49030,NULL,'Belle Rive, IL',20552,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49031,NULL,'Belle Rive, IL 62810',20552,222,NULL,17,28186,0);
INSERT INTO "django_geo_db_location" VALUES(49032,NULL,'Bellmont, IL',20553,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49033,NULL,'Bellmont, IL 62811',20553,222,NULL,17,28187,0);
INSERT INTO "django_geo_db_location" VALUES(49034,NULL,'Benton, IL',20554,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49035,NULL,'Benton, IL 62812',20554,222,NULL,17,28188,0);
INSERT INTO "django_geo_db_location" VALUES(49036,NULL,'Bluford, IL',20555,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49037,NULL,'Bluford, IL 62814',20555,222,NULL,17,28189,0);
INSERT INTO "django_geo_db_location" VALUES(49038,NULL,'Bone Gap, IL',20556,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49039,NULL,'Bone Gap, IL 62815',20556,222,NULL,17,28190,0);
INSERT INTO "django_geo_db_location" VALUES(49040,NULL,'Bonnie, IL',20557,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49041,NULL,'Bonnie, IL 62816',20557,222,NULL,17,28191,0);
INSERT INTO "django_geo_db_location" VALUES(49042,NULL,'Broughton, IL',20558,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49043,NULL,'Broughton, IL 62817',20558,222,NULL,17,28192,0);
INSERT INTO "django_geo_db_location" VALUES(49044,NULL,'Browns, IL',20559,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49045,NULL,'Browns, IL 62818',20559,222,NULL,17,28193,0);
INSERT INTO "django_geo_db_location" VALUES(49046,NULL,'Buckner, IL',20560,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49047,NULL,'Buckner, IL 62819',20560,222,NULL,17,28194,0);
INSERT INTO "django_geo_db_location" VALUES(49048,NULL,'Burnt Prairie, IL',20561,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49049,NULL,'Burnt Prairie, IL 62820',20561,222,NULL,17,28195,0);
INSERT INTO "django_geo_db_location" VALUES(49050,NULL,'Carmi, IL',20562,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49051,NULL,'Carmi, IL 62821',20562,222,NULL,17,28196,0);
INSERT INTO "django_geo_db_location" VALUES(49052,NULL,'Christopher, IL',20563,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49053,NULL,'Christopher, IL 62822',20563,222,NULL,17,28197,0);
INSERT INTO "django_geo_db_location" VALUES(49054,NULL,'Cisne, IL',20564,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49055,NULL,'Cisne, IL 62823',20564,222,NULL,17,28198,0);
INSERT INTO "django_geo_db_location" VALUES(49056,NULL,'Clay City, IL',20565,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49057,NULL,'Clay City, IL 62824',20565,222,NULL,17,28199,0);
INSERT INTO "django_geo_db_location" VALUES(49058,NULL,'Coello, IL',20566,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49059,NULL,'Coello, IL 62825',20566,222,NULL,17,28200,0);
INSERT INTO "django_geo_db_location" VALUES(49060,NULL,'Crossville, IL',20567,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49061,NULL,'Crossville, IL 62827',20567,222,NULL,17,28201,0);
INSERT INTO "django_geo_db_location" VALUES(49062,NULL,'Dahlgren, IL',20568,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49063,NULL,'Dahlgren, IL 62828',20568,222,NULL,17,28202,0);
INSERT INTO "django_geo_db_location" VALUES(49064,NULL,'Dale, IL',20569,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49065,NULL,'Dale, IL 62829',20569,222,NULL,17,28203,0);
INSERT INTO "django_geo_db_location" VALUES(49066,NULL,'Dix, IL',20570,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49067,NULL,'Dix, IL 62830',20570,222,NULL,17,28204,0);
INSERT INTO "django_geo_db_location" VALUES(49068,NULL,'Du Bois, IL',20571,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49069,NULL,'Du Bois, IL 62831',20571,222,NULL,17,28205,0);
INSERT INTO "django_geo_db_location" VALUES(49070,NULL,'Du Quoin, IL',20572,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49071,NULL,'Du Quoin, IL 62832',20572,222,NULL,17,28206,0);
INSERT INTO "django_geo_db_location" VALUES(49072,NULL,'Ellery, IL',20573,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49073,NULL,'Ellery, IL 62833',20573,222,NULL,17,28207,0);
INSERT INTO "django_geo_db_location" VALUES(49074,NULL,'Emma, IL',20574,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49075,NULL,'Emma, IL 62834',20574,222,NULL,17,28208,0);
INSERT INTO "django_geo_db_location" VALUES(49076,NULL,'Enfield, IL',20575,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49077,NULL,'Enfield, IL 62835',20575,222,NULL,17,28209,0);
INSERT INTO "django_geo_db_location" VALUES(49078,NULL,'Ewing, IL',20576,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49079,NULL,'Ewing, IL 62836',20576,222,NULL,17,28210,0);
INSERT INTO "django_geo_db_location" VALUES(49080,NULL,'Fairfield, IL',20577,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49081,NULL,'Fairfield, IL 62837',20577,222,NULL,17,28211,0);
INSERT INTO "django_geo_db_location" VALUES(49082,NULL,'Farina, IL',20578,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49083,NULL,'Farina, IL 62838',20578,222,NULL,17,28212,0);
INSERT INTO "django_geo_db_location" VALUES(49084,NULL,'Flora, IL',20579,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49085,NULL,'Flora, IL 62839',20579,222,NULL,17,28213,0);
INSERT INTO "django_geo_db_location" VALUES(49086,NULL,'Frankfort Heights, IL',20580,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49087,NULL,'Frankfort Heights, IL 62840',20580,222,NULL,17,28214,0);
INSERT INTO "django_geo_db_location" VALUES(49088,NULL,'Freeman Spur, IL',20581,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49089,NULL,'Freeman Spur, IL 62841',20581,222,NULL,17,28215,0);
INSERT INTO "django_geo_db_location" VALUES(49090,NULL,'Geff, IL',20582,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49091,NULL,'Geff, IL 62842',20582,222,NULL,17,28216,0);
INSERT INTO "django_geo_db_location" VALUES(49092,NULL,'Golden Gate, IL',20583,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49093,NULL,'Golden Gate, IL 62843',20583,222,NULL,17,28217,0);
INSERT INTO "django_geo_db_location" VALUES(49094,NULL,'Grayville, IL',20584,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49095,NULL,'Grayville, IL 62844',20584,222,NULL,17,28218,0);
INSERT INTO "django_geo_db_location" VALUES(49096,NULL,'Herald, IL',20585,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49097,NULL,'Herald, IL 62845',20585,222,NULL,17,28219,0);
INSERT INTO "django_geo_db_location" VALUES(49098,NULL,'Ina, IL',20586,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49099,NULL,'Ina, IL 62846',20586,222,NULL,17,28220,0);
INSERT INTO "django_geo_db_location" VALUES(49100,NULL,'Iola, IL',20587,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49101,NULL,'Iola, IL 62847',20587,222,NULL,17,28221,0);
INSERT INTO "django_geo_db_location" VALUES(49102,NULL,'Irvington, IL',20588,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49103,NULL,'Irvington, IL 62848',20588,222,NULL,17,28222,0);
INSERT INTO "django_geo_db_location" VALUES(49104,NULL,'Iuka, IL',20589,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49105,NULL,'Iuka, IL 62849',20589,222,NULL,17,28223,0);
INSERT INTO "django_geo_db_location" VALUES(49106,NULL,'Johnsonville, IL',20590,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49107,NULL,'Johnsonville, IL 62850',20590,222,NULL,17,28224,0);
INSERT INTO "django_geo_db_location" VALUES(49108,NULL,'Keenes, IL',20591,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49109,NULL,'Keenes, IL 62851',20591,222,NULL,17,28225,0);
INSERT INTO "django_geo_db_location" VALUES(49110,NULL,'Keensburg, IL',20592,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49111,NULL,'Keensburg, IL 62852',20592,222,NULL,17,28226,0);
INSERT INTO "django_geo_db_location" VALUES(49112,NULL,'Kell, IL',20593,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49113,NULL,'Kell, IL 62853',20593,222,NULL,17,28227,0);
INSERT INTO "django_geo_db_location" VALUES(49114,NULL,'Kinmundy, IL',20594,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49115,NULL,'Kinmundy, IL 62854',20594,222,NULL,17,28228,0);
INSERT INTO "django_geo_db_location" VALUES(49116,NULL,'Lancaster, IL',20595,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49117,NULL,'Lancaster, IL 62855',20595,222,NULL,17,28229,0);
INSERT INTO "django_geo_db_location" VALUES(49118,NULL,'Logan, IL',20596,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49119,NULL,'Logan, IL 62856',20596,222,NULL,17,28230,0);
INSERT INTO "django_geo_db_location" VALUES(49120,NULL,'Loogootee, IL',20597,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49121,NULL,'Loogootee, IL 62857',20597,222,NULL,17,28231,0);
INSERT INTO "django_geo_db_location" VALUES(49122,NULL,'Louisville, IL',20598,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49123,NULL,'Louisville, IL 62858',20598,222,NULL,17,28232,0);
INSERT INTO "django_geo_db_location" VALUES(49124,NULL,'McLeansboro, IL',20599,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49125,NULL,'McLeansboro, IL 62859',20599,222,NULL,17,28233,0);
INSERT INTO "django_geo_db_location" VALUES(49126,NULL,'Macedonia, IL',20600,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49127,NULL,'Macedonia, IL 62860',20600,222,NULL,17,28234,0);
INSERT INTO "django_geo_db_location" VALUES(49128,NULL,'Maunie, IL',20601,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49129,NULL,'Maunie, IL 62861',20601,222,NULL,17,28235,0);
INSERT INTO "django_geo_db_location" VALUES(49130,NULL,'Mill Shoals, IL',20602,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49131,NULL,'Mill Shoals, IL 62862',20602,222,NULL,17,28236,0);
INSERT INTO "django_geo_db_location" VALUES(49132,NULL,'Mount Carmel, IL',20603,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49133,NULL,'Mount Carmel, IL 62863',20603,222,NULL,17,28237,0);
INSERT INTO "django_geo_db_location" VALUES(49134,NULL,'Mount Vernon, IL',20604,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49135,NULL,'Mount Vernon, IL 62864',20604,222,NULL,17,28238,0);
INSERT INTO "django_geo_db_location" VALUES(49136,NULL,'Mulkeytown, IL',20605,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49137,NULL,'Mulkeytown, IL 62865',20605,222,NULL,17,28239,0);
INSERT INTO "django_geo_db_location" VALUES(49138,NULL,'Nason, IL',20606,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49139,NULL,'Nason, IL 62866',20606,222,NULL,17,28240,0);
INSERT INTO "django_geo_db_location" VALUES(49140,NULL,'New Haven, IL',20607,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49141,NULL,'New Haven, IL 62867',20607,222,NULL,17,28241,0);
INSERT INTO "django_geo_db_location" VALUES(49142,NULL,'Noble, IL',20608,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49143,NULL,'Noble, IL 62868',20608,222,NULL,17,28242,0);
INSERT INTO "django_geo_db_location" VALUES(49144,NULL,'Norris City, IL',20609,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49145,NULL,'Norris City, IL 62869',20609,222,NULL,17,28243,0);
INSERT INTO "django_geo_db_location" VALUES(49146,NULL,'Odin, IL',20610,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49147,NULL,'Odin, IL 62870',20610,222,NULL,17,28244,0);
INSERT INTO "django_geo_db_location" VALUES(49148,NULL,'Omaha, IL',20611,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49149,NULL,'Omaha, IL 62871',20611,222,NULL,17,28245,0);
INSERT INTO "django_geo_db_location" VALUES(49150,NULL,'Opdyke, IL',20612,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49151,NULL,'Opdyke, IL 62872',20612,222,NULL,17,28246,0);
INSERT INTO "django_geo_db_location" VALUES(49152,NULL,'Orient, IL',20613,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49153,NULL,'Orient, IL 62874',20613,222,NULL,17,28247,0);
INSERT INTO "django_geo_db_location" VALUES(49154,NULL,'Patoka, IL',20614,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49155,NULL,'Patoka, IL 62875',20614,222,NULL,17,28248,0);
INSERT INTO "django_geo_db_location" VALUES(49156,NULL,'Radom, IL',20615,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49157,NULL,'Radom, IL 62876',20615,222,NULL,17,28249,0);
INSERT INTO "django_geo_db_location" VALUES(49158,NULL,'Richview, IL',20616,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49159,NULL,'Richview, IL 62877',20616,222,NULL,17,28250,0);
INSERT INTO "django_geo_db_location" VALUES(49160,NULL,'Rinard, IL',20617,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49161,NULL,'Rinard, IL 62878',20617,222,NULL,17,28251,0);
INSERT INTO "django_geo_db_location" VALUES(49162,NULL,'Sailor Springs, IL',20618,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49163,NULL,'Sailor Springs, IL 62879',20618,222,NULL,17,28252,0);
INSERT INTO "django_geo_db_location" VALUES(49164,NULL,'Saint Peter, IL',20619,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49165,NULL,'Saint Peter, IL 62880',20619,222,NULL,17,28253,0);
INSERT INTO "django_geo_db_location" VALUES(49166,NULL,'Salem, IL',20620,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49167,NULL,'Salem, IL 62881',20620,222,NULL,17,28254,0);
INSERT INTO "django_geo_db_location" VALUES(49168,NULL,'Sandoval, IL',20621,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49169,NULL,'Sandoval, IL 62882',20621,222,NULL,17,28255,0);
INSERT INTO "django_geo_db_location" VALUES(49170,NULL,'Scheller, IL',20622,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49171,NULL,'Scheller, IL 62883',20622,222,NULL,17,28256,0);
INSERT INTO "django_geo_db_location" VALUES(49172,NULL,'Sesser, IL',20623,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49173,NULL,'Sesser, IL 62884',20623,222,NULL,17,28257,0);
INSERT INTO "django_geo_db_location" VALUES(49174,NULL,'Shobonier, IL',20624,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49175,NULL,'Shobonier, IL 62885',20624,222,NULL,17,28258,0);
INSERT INTO "django_geo_db_location" VALUES(49176,NULL,'Sims, IL',20625,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49177,NULL,'Sims, IL 62886',20625,222,NULL,17,28259,0);
INSERT INTO "django_geo_db_location" VALUES(49178,NULL,'Springerton, IL',20626,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49179,NULL,'Springerton, IL 62887',20626,222,NULL,17,28260,0);
INSERT INTO "django_geo_db_location" VALUES(49180,NULL,'Tamaroa, IL',20627,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49181,NULL,'Tamaroa, IL 62888',20627,222,NULL,17,28261,0);
INSERT INTO "django_geo_db_location" VALUES(49182,NULL,'Texico, IL',20628,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49183,NULL,'Texico, IL 62889',20628,222,NULL,17,28262,0);
INSERT INTO "django_geo_db_location" VALUES(49184,NULL,'Thompsonville, IL',20629,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49185,NULL,'Thompsonville, IL 62890',20629,222,NULL,17,28263,0);
INSERT INTO "django_geo_db_location" VALUES(49186,NULL,'Valier, IL',20630,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49187,NULL,'Valier, IL 62891',20630,222,NULL,17,28264,0);
INSERT INTO "django_geo_db_location" VALUES(49188,NULL,'Vernon, IL',20631,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49189,NULL,'Vernon, IL 62892',20631,222,NULL,17,28265,0);
INSERT INTO "django_geo_db_location" VALUES(49190,NULL,'Walnut Hill, IL',20632,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49191,NULL,'Walnut Hill, IL 62893',20632,222,NULL,17,28266,0);
INSERT INTO "django_geo_db_location" VALUES(49192,NULL,'Waltonville, IL',20633,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49193,NULL,'Waltonville, IL 62894',20633,222,NULL,17,28267,0);
INSERT INTO "django_geo_db_location" VALUES(49194,NULL,'Wayne City, IL',20634,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49195,NULL,'Wayne City, IL 62895',20634,222,NULL,17,28268,0);
INSERT INTO "django_geo_db_location" VALUES(49196,NULL,'West Frankfort, IL',20635,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49197,NULL,'West Frankfort, IL 62896',20635,222,NULL,17,28269,0);
INSERT INTO "django_geo_db_location" VALUES(49198,NULL,'Whittington, IL',20636,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49199,NULL,'Whittington, IL 62897',20636,222,NULL,17,28270,0);
INSERT INTO "django_geo_db_location" VALUES(49200,NULL,'Woodlawn, IL',20637,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49201,NULL,'Woodlawn, IL 62898',20637,222,NULL,17,28271,0);
INSERT INTO "django_geo_db_location" VALUES(49202,NULL,'Xenia, IL',20638,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49203,NULL,'Xenia, IL 62899',20638,222,NULL,17,28272,0);
INSERT INTO "django_geo_db_location" VALUES(49204,NULL,'Carbondale, IL',20639,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49205,NULL,'Carbondale, IL 62901',20639,222,NULL,17,28273,0);
INSERT INTO "django_geo_db_location" VALUES(49206,NULL,'Carbondale, IL 62902',20639,222,NULL,17,28274,0);
INSERT INTO "django_geo_db_location" VALUES(49207,NULL,'Carbondale, IL 62903',20639,222,NULL,17,28275,0);
INSERT INTO "django_geo_db_location" VALUES(49208,NULL,'Alto Pass, IL',20640,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49209,NULL,'Alto Pass, IL 62905',20640,222,NULL,17,28276,0);
INSERT INTO "django_geo_db_location" VALUES(49210,NULL,'Anna, IL',20641,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49211,NULL,'Anna, IL 62906',20641,222,NULL,17,28277,0);
INSERT INTO "django_geo_db_location" VALUES(49212,NULL,'Ava, IL',20642,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49213,NULL,'Ava, IL 62907',20642,222,NULL,17,28278,0);
INSERT INTO "django_geo_db_location" VALUES(49214,NULL,'Belknap, IL',20643,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49215,NULL,'Belknap, IL 62908',20643,222,NULL,17,28279,0);
INSERT INTO "django_geo_db_location" VALUES(49216,NULL,'Boles, IL',20644,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49217,NULL,'Boles, IL 62909',20644,222,NULL,17,28280,0);
INSERT INTO "django_geo_db_location" VALUES(49218,NULL,'Brookport, IL',20645,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49219,NULL,'Brookport, IL 62910',20645,222,NULL,17,28281,0);
INSERT INTO "django_geo_db_location" VALUES(49220,NULL,'Buncombe, IL',20646,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49221,NULL,'Buncombe, IL 62912',20646,222,NULL,17,28282,0);
INSERT INTO "django_geo_db_location" VALUES(49222,NULL,'Cache, IL',20647,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49223,NULL,'Cache, IL 62913',20647,222,NULL,17,28283,0);
INSERT INTO "django_geo_db_location" VALUES(49224,NULL,'Cairo, IL',20648,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49225,NULL,'Cairo, IL 62914',20648,222,NULL,17,28284,0);
INSERT INTO "django_geo_db_location" VALUES(49226,NULL,'Cambria, IL',20649,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49227,NULL,'Cambria, IL 62915',20649,222,NULL,17,28285,0);
INSERT INTO "django_geo_db_location" VALUES(49228,NULL,'Campbell Hill, IL',20650,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49229,NULL,'Campbell Hill, IL 62916',20650,222,NULL,17,28286,0);
INSERT INTO "django_geo_db_location" VALUES(49230,NULL,'Carrier Mills, IL',20651,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49231,NULL,'Carrier Mills, IL 62917',20651,222,NULL,17,28287,0);
INSERT INTO "django_geo_db_location" VALUES(49232,NULL,'Carterville, IL',20652,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49233,NULL,'Carterville, IL 62918',20652,222,NULL,17,28288,0);
INSERT INTO "django_geo_db_location" VALUES(49234,NULL,'Cave In Rock, IL',20653,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49235,NULL,'Cave In Rock, IL 62919',20653,222,NULL,17,28289,0);
INSERT INTO "django_geo_db_location" VALUES(49236,NULL,'Cobden, IL',20654,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49237,NULL,'Cobden, IL 62920',20654,222,NULL,17,28290,0);
INSERT INTO "django_geo_db_location" VALUES(49238,NULL,'Colp, IL',20655,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49239,NULL,'Colp, IL 62921',20655,222,NULL,17,28291,0);
INSERT INTO "django_geo_db_location" VALUES(49240,NULL,'Creal Springs, IL',20656,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49241,NULL,'Creal Springs, IL 62922',20656,222,NULL,17,28292,0);
INSERT INTO "django_geo_db_location" VALUES(49242,NULL,'Cypress, IL',20657,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49243,NULL,'Cypress, IL 62923',20657,222,NULL,17,28293,0);
INSERT INTO "django_geo_db_location" VALUES(49244,NULL,'De Soto, IL',20658,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49245,NULL,'De Soto, IL 62924',20658,222,NULL,17,28294,0);
INSERT INTO "django_geo_db_location" VALUES(49246,NULL,'Dongola, IL',20659,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49247,NULL,'Dongola, IL 62926',20659,222,NULL,17,28295,0);
INSERT INTO "django_geo_db_location" VALUES(49248,NULL,'Dowell, IL',20660,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49249,NULL,'Dowell, IL 62927',20660,222,NULL,17,28296,0);
INSERT INTO "django_geo_db_location" VALUES(49250,NULL,'Eddyville, IL',20661,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49251,NULL,'Eddyville, IL 62928',20661,222,NULL,17,28297,0);
INSERT INTO "django_geo_db_location" VALUES(49252,NULL,'Eldorado, IL',20662,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49253,NULL,'Eldorado, IL 62930',20662,222,NULL,17,28298,0);
INSERT INTO "django_geo_db_location" VALUES(49254,NULL,'Elizabethtown, IL',20663,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49255,NULL,'Elizabethtown, IL 62931',20663,222,NULL,17,28299,0);
INSERT INTO "django_geo_db_location" VALUES(49256,NULL,'Elkville, IL',20664,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49257,NULL,'Elkville, IL 62932',20664,222,NULL,17,28300,0);
INSERT INTO "django_geo_db_location" VALUES(49258,NULL,'Energy, IL',20665,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49259,NULL,'Energy, IL 62933',20665,222,NULL,17,28301,0);
INSERT INTO "django_geo_db_location" VALUES(49260,NULL,'Equality, IL 62934',20364,222,NULL,17,28302,0);
INSERT INTO "django_geo_db_location" VALUES(49261,NULL,'Galatia, IL',20666,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49262,NULL,'Galatia, IL 62935',20666,222,NULL,17,28303,0);
INSERT INTO "django_geo_db_location" VALUES(49263,NULL,'Golconda, IL',20667,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49264,NULL,'Golconda, IL 62938',20667,222,NULL,17,28304,0);
INSERT INTO "django_geo_db_location" VALUES(49265,NULL,'Goreville, IL',20668,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49266,NULL,'Goreville, IL 62939',20668,222,NULL,17,28305,0);
INSERT INTO "django_geo_db_location" VALUES(49267,NULL,'Gorham, IL',20669,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49268,NULL,'Gorham, IL 62940',20669,222,NULL,17,28306,0);
INSERT INTO "django_geo_db_location" VALUES(49269,NULL,'Grand Chain, IL',20670,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49270,NULL,'Grand Chain, IL 62941',20670,222,NULL,17,28307,0);
INSERT INTO "django_geo_db_location" VALUES(49271,NULL,'Grand Tower, IL',20671,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49272,NULL,'Grand Tower, IL 62942',20671,222,NULL,17,28308,0);
INSERT INTO "django_geo_db_location" VALUES(49273,NULL,'Grantsburg, IL',20672,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49274,NULL,'Grantsburg, IL 62943',20672,222,NULL,17,28309,0);
INSERT INTO "django_geo_db_location" VALUES(49275,NULL,'Hamletsburg, IL',20673,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49276,NULL,'Hamletsburg, IL 62944',20673,222,NULL,17,28310,0);
INSERT INTO "django_geo_db_location" VALUES(49277,NULL,'Harrisburg, IL',20674,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49278,NULL,'Harrisburg, IL 62946',20674,222,NULL,17,28311,0);
INSERT INTO "django_geo_db_location" VALUES(49279,NULL,'Herod, IL',20675,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49280,NULL,'Herod, IL 62947',20675,222,NULL,17,28312,0);
INSERT INTO "django_geo_db_location" VALUES(49281,NULL,'Herrin, IL 62948',20507,222,NULL,17,28313,0);
INSERT INTO "django_geo_db_location" VALUES(49282,NULL,'Hurst, IL',20676,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49283,NULL,'Hurst, IL 62949',20676,222,NULL,17,28314,0);
INSERT INTO "django_geo_db_location" VALUES(49284,NULL,'Jacob, IL',20677,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49285,NULL,'Jacob, IL 62950',20677,222,NULL,17,28315,0);
INSERT INTO "django_geo_db_location" VALUES(49286,NULL,'Johnston City, IL',20678,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49287,NULL,'Johnston City, IL 62951',20678,222,NULL,17,28316,0);
INSERT INTO "django_geo_db_location" VALUES(49288,NULL,'Jonesboro, IL',20679,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49289,NULL,'Jonesboro, IL 62952',20679,222,NULL,17,28317,0);
INSERT INTO "django_geo_db_location" VALUES(49290,NULL,'Joppa, IL',20680,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49291,NULL,'Joppa, IL 62953',20680,222,NULL,17,28318,0);
INSERT INTO "django_geo_db_location" VALUES(49292,NULL,'Junction, IL',20681,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49293,NULL,'Junction, IL 62954',20681,222,NULL,17,28319,0);
INSERT INTO "django_geo_db_location" VALUES(49294,NULL,'Karbers Ridge, IL',20682,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49295,NULL,'Karbers Ridge, IL 62955',20682,222,NULL,17,28320,0);
INSERT INTO "django_geo_db_location" VALUES(49296,NULL,'Karnak, IL',20683,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49297,NULL,'Karnak, IL 62956',20683,222,NULL,17,28321,0);
INSERT INTO "django_geo_db_location" VALUES(49298,NULL,'McClure, IL',20684,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49299,NULL,'McClure, IL 62957',20684,222,NULL,17,28322,0);
INSERT INTO "django_geo_db_location" VALUES(49300,NULL,'Makanda, IL',20685,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49301,NULL,'Makanda, IL 62958',20685,222,NULL,17,28323,0);
INSERT INTO "django_geo_db_location" VALUES(49302,NULL,'Marion, IL',20686,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49303,NULL,'Marion, IL 62959',20686,222,NULL,17,28324,0);
INSERT INTO "django_geo_db_location" VALUES(49304,NULL,'Metropolis, IL',20687,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49305,NULL,'Metropolis, IL 62960',20687,222,NULL,17,28325,0);
INSERT INTO "django_geo_db_location" VALUES(49306,NULL,'Millcreek, IL',20688,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49307,NULL,'Millcreek, IL 62961',20688,222,NULL,17,28326,0);
INSERT INTO "django_geo_db_location" VALUES(49308,NULL,'Miller City, IL',20689,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49309,NULL,'Miller City, IL 62962',20689,222,NULL,17,28327,0);
INSERT INTO "django_geo_db_location" VALUES(49310,NULL,'Mound City, IL',20690,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49311,NULL,'Mound City, IL 62963',20690,222,NULL,17,28328,0);
INSERT INTO "django_geo_db_location" VALUES(49312,NULL,'Mounds, IL',20691,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49313,NULL,'Mounds, IL 62964',20691,222,NULL,17,28329,0);
INSERT INTO "django_geo_db_location" VALUES(49314,NULL,'Muddy, IL',20692,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49315,NULL,'Muddy, IL 62965',20692,222,NULL,17,28330,0);
INSERT INTO "django_geo_db_location" VALUES(49316,NULL,'Murphysboro, IL',20693,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49317,NULL,'Murphysboro, IL 62966',20693,222,NULL,17,28331,0);
INSERT INTO "django_geo_db_location" VALUES(49318,NULL,'New Burnside, IL',20694,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49319,NULL,'New Burnside, IL 62967',20694,222,NULL,17,28332,0);
INSERT INTO "django_geo_db_location" VALUES(49320,NULL,'Olive Branch, IL',20695,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49321,NULL,'Olive Branch, IL 62969',20695,222,NULL,17,28333,0);
INSERT INTO "django_geo_db_location" VALUES(49322,NULL,'Olmsted, IL',20696,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49323,NULL,'Olmsted, IL 62970',20696,222,NULL,17,28334,0);
INSERT INTO "django_geo_db_location" VALUES(49324,NULL,'Oraville, IL',20697,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49325,NULL,'Oraville, IL 62971',20697,222,NULL,17,28335,0);
INSERT INTO "django_geo_db_location" VALUES(49326,NULL,'Ozark, IL',20698,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49327,NULL,'Ozark, IL 62972',20698,222,NULL,17,28336,0);
INSERT INTO "django_geo_db_location" VALUES(49328,NULL,'Perks, IL',20699,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49329,NULL,'Perks, IL 62973',20699,222,NULL,17,28337,0);
INSERT INTO "django_geo_db_location" VALUES(49330,NULL,'Pittsburg, IL',20700,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49331,NULL,'Pittsburg, IL 62974',20700,222,NULL,17,28338,0);
INSERT INTO "django_geo_db_location" VALUES(49332,NULL,'Pomona, IL',20701,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49333,NULL,'Pomona, IL 62975',20701,222,NULL,17,28339,0);
INSERT INTO "django_geo_db_location" VALUES(49334,NULL,'Pulaski, IL',20702,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49335,NULL,'Pulaski, IL 62976',20702,222,NULL,17,28340,0);
INSERT INTO "django_geo_db_location" VALUES(49336,NULL,'Raleigh, IL',20703,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49337,NULL,'Raleigh, IL 62977',20703,222,NULL,17,28341,0);
INSERT INTO "django_geo_db_location" VALUES(49338,NULL,'Ridgway, IL',20704,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49339,NULL,'Ridgway, IL 62979',20704,222,NULL,17,28342,0);
INSERT INTO "django_geo_db_location" VALUES(49340,NULL,'Rosiclare, IL',20705,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49341,NULL,'Rosiclare, IL 62982',20705,222,NULL,17,28343,0);
INSERT INTO "django_geo_db_location" VALUES(49342,NULL,'Royalton, IL',20706,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49343,NULL,'Royalton, IL 62983',20706,222,NULL,17,28344,0);
INSERT INTO "django_geo_db_location" VALUES(49344,NULL,'Shawneetown, IL',20707,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49345,NULL,'Shawneetown, IL 62984',20707,222,NULL,17,28345,0);
INSERT INTO "django_geo_db_location" VALUES(49346,NULL,'Simpson, IL',20708,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49347,NULL,'Simpson, IL 62985',20708,222,NULL,17,28346,0);
INSERT INTO "django_geo_db_location" VALUES(49348,NULL,'Stonefort, IL',20709,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49349,NULL,'Stonefort, IL 62987',20709,222,NULL,17,28347,0);
INSERT INTO "django_geo_db_location" VALUES(49350,NULL,'Tamms, IL',20710,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49351,NULL,'Tamms, IL 62988',20710,222,NULL,17,28348,0);
INSERT INTO "django_geo_db_location" VALUES(49352,NULL,'Thebes, IL',20711,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49353,NULL,'Thebes, IL 62990',20711,222,NULL,17,28349,0);
INSERT INTO "django_geo_db_location" VALUES(49354,NULL,'Tunnel Hill, IL',20712,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49355,NULL,'Tunnel Hill, IL 62991',20712,222,NULL,17,28350,0);
INSERT INTO "django_geo_db_location" VALUES(49356,NULL,'Ullin, IL 62992',20544,222,NULL,17,28351,0);
INSERT INTO "django_geo_db_location" VALUES(49357,NULL,'Unity, IL',20713,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49358,NULL,'Unity, IL 62993',20713,222,NULL,17,28352,0);
INSERT INTO "django_geo_db_location" VALUES(49359,NULL,'Vergennes, IL',20714,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49360,NULL,'Vergennes, IL 62994',20714,222,NULL,17,28353,0);
INSERT INTO "django_geo_db_location" VALUES(49361,NULL,'Vienna, IL',20715,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49362,NULL,'Vienna, IL 62995',20715,222,NULL,17,28354,0);
INSERT INTO "django_geo_db_location" VALUES(49363,NULL,'Villa Ridge, IL',20716,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49364,NULL,'Villa Ridge, IL 62996',20716,222,NULL,17,28355,0);
INSERT INTO "django_geo_db_location" VALUES(49365,NULL,'Willisville, IL',20717,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49366,NULL,'Willisville, IL 62997',20717,222,NULL,17,28356,0);
INSERT INTO "django_geo_db_location" VALUES(49367,NULL,'Wolf Lake, IL',20718,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49368,NULL,'Wolf Lake, IL 62998',20718,222,NULL,17,28357,0);
INSERT INTO "django_geo_db_location" VALUES(49369,NULL,'Zeigler, IL',20719,222,NULL,17,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49370,NULL,'Zeigler, IL 62999',20719,222,NULL,17,28358,0);
INSERT INTO "django_geo_db_location" VALUES(49371,NULL,'Allenton, MO',20720,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49372,NULL,'Allenton, MO 63001',20720,222,NULL,43,28359,0);
INSERT INTO "django_geo_db_location" VALUES(49373,NULL,'Chesterfield, MO',20721,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49374,NULL,'Chesterfield, MO 63005',20721,222,NULL,43,28360,0);
INSERT INTO "django_geo_db_location" VALUES(49375,NULL,'Chesterfield, MO 63006',20721,222,NULL,43,28361,0);
INSERT INTO "django_geo_db_location" VALUES(49376,NULL,'Arnold, MO',20722,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49377,NULL,'Arnold, MO 63010',20722,222,NULL,43,28362,0);
INSERT INTO "django_geo_db_location" VALUES(49378,NULL,'Ballwin, MO',20723,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49379,NULL,'Ballwin, MO 63011',20723,222,NULL,43,28363,0);
INSERT INTO "django_geo_db_location" VALUES(49380,NULL,'Barnhart, MO',20724,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49381,NULL,'Barnhart, MO 63012',20724,222,NULL,43,28364,0);
INSERT INTO "django_geo_db_location" VALUES(49382,NULL,'Beaufort, MO',20725,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49383,NULL,'Beaufort, MO 63013',20725,222,NULL,43,28365,0);
INSERT INTO "django_geo_db_location" VALUES(49384,NULL,'Berger, MO',20726,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49385,NULL,'Berger, MO 63014',20726,222,NULL,43,28366,0);
INSERT INTO "django_geo_db_location" VALUES(49386,NULL,'Catawissa, MO',20727,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49387,NULL,'Catawissa, MO 63015',20727,222,NULL,43,28367,0);
INSERT INTO "django_geo_db_location" VALUES(49388,NULL,'Cedar Hill, MO',20728,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49389,NULL,'Cedar Hill, MO 63016',20728,222,NULL,43,28368,0);
INSERT INTO "django_geo_db_location" VALUES(49390,NULL,'Chesterfield, MO 63017',20721,222,NULL,43,28369,0);
INSERT INTO "django_geo_db_location" VALUES(49391,NULL,'Crystal City, MO',20729,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49392,NULL,'Crystal City, MO 63019',20729,222,NULL,43,28370,0);
INSERT INTO "django_geo_db_location" VALUES(49393,NULL,'De Soto, MO',20730,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49394,NULL,'De Soto, MO 63020',20730,222,NULL,43,28371,0);
INSERT INTO "django_geo_db_location" VALUES(49395,NULL,'Ballwin, MO 63021',20723,222,NULL,43,28372,0);
INSERT INTO "django_geo_db_location" VALUES(49396,NULL,'Ballwin, MO 63022',20723,222,NULL,43,28373,0);
INSERT INTO "django_geo_db_location" VALUES(49397,NULL,'Dittmer, MO',20731,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49398,NULL,'Dittmer, MO 63023',20731,222,NULL,43,28374,0);
INSERT INTO "django_geo_db_location" VALUES(49399,NULL,'Ballwin, MO 63024',20723,222,NULL,43,28375,0);
INSERT INTO "django_geo_db_location" VALUES(49400,NULL,'Eureka, MO',20732,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49401,NULL,'Eureka, MO 63025',20732,222,NULL,43,28376,0);
INSERT INTO "django_geo_db_location" VALUES(49402,NULL,'Fenton, MO',20733,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49403,NULL,'Fenton, MO 63026',20733,222,NULL,43,28377,0);
INSERT INTO "django_geo_db_location" VALUES(49404,NULL,'Festus, MO',20734,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49405,NULL,'Festus, MO 63028',20734,222,NULL,43,28378,0);
INSERT INTO "django_geo_db_location" VALUES(49406,NULL,'Fletcher, MO',20735,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49407,NULL,'Fletcher, MO 63030',20735,222,NULL,43,28379,0);
INSERT INTO "django_geo_db_location" VALUES(49408,NULL,'Florissant, MO',20736,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49409,NULL,'Florissant, MO 63031',20736,222,NULL,43,28380,0);
INSERT INTO "django_geo_db_location" VALUES(49410,NULL,'Florissant, MO 63032',20736,222,NULL,43,28381,0);
INSERT INTO "django_geo_db_location" VALUES(49411,NULL,'Florissant, MO 63033',20736,222,NULL,43,28382,0);
INSERT INTO "django_geo_db_location" VALUES(49412,NULL,'Florissant, MO 63034',20736,222,NULL,43,28383,0);
INSERT INTO "django_geo_db_location" VALUES(49413,NULL,'French Village, MO',20737,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49414,NULL,'French Village, MO 63036',20737,222,NULL,43,28384,0);
INSERT INTO "django_geo_db_location" VALUES(49415,NULL,'Gerald, MO',20738,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49416,NULL,'Gerald, MO 63037',20738,222,NULL,43,28385,0);
INSERT INTO "django_geo_db_location" VALUES(49417,NULL,'Glencoe, MO',20739,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49418,NULL,'Glencoe, MO 63038',20739,222,NULL,43,28386,0);
INSERT INTO "django_geo_db_location" VALUES(49419,NULL,'Gray Summit, MO',20740,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49420,NULL,'Gray Summit, MO 63039',20740,222,NULL,43,28387,0);
INSERT INTO "django_geo_db_location" VALUES(49421,NULL,'Grover, MO',20741,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49422,NULL,'Grover, MO 63040',20741,222,NULL,43,28388,0);
INSERT INTO "django_geo_db_location" VALUES(49423,NULL,'Grubville, MO',20742,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49424,NULL,'Grubville, MO 63041',20742,222,NULL,43,28389,0);
INSERT INTO "django_geo_db_location" VALUES(49425,NULL,'Hazelwood, MO',20743,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49426,NULL,'Hazelwood, MO 63042',20743,222,NULL,43,28390,0);
INSERT INTO "django_geo_db_location" VALUES(49427,NULL,'Maryland Heights, MO',20744,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49428,NULL,'Maryland Heights, MO 63043',20744,222,NULL,43,28391,0);
INSERT INTO "django_geo_db_location" VALUES(49429,NULL,'Bridgeton, MO',20745,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49430,NULL,'Bridgeton, MO 63044',20745,222,NULL,43,28392,0);
INSERT INTO "django_geo_db_location" VALUES(49431,NULL,'Earth City, MO',20746,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49432,NULL,'Earth City, MO 63045',20746,222,NULL,43,28393,0);
INSERT INTO "django_geo_db_location" VALUES(49433,NULL,'Hematite, MO',20747,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49434,NULL,'Hematite, MO 63047',20747,222,NULL,43,28394,0);
INSERT INTO "django_geo_db_location" VALUES(49435,NULL,'Herculaneum, MO',20748,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49436,NULL,'Herculaneum, MO 63048',20748,222,NULL,43,28395,0);
INSERT INTO "django_geo_db_location" VALUES(49437,NULL,'High Ridge, MO',20749,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49438,NULL,'High Ridge, MO 63049',20749,222,NULL,43,28396,0);
INSERT INTO "django_geo_db_location" VALUES(49439,NULL,'Hillsboro, MO',20750,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49440,NULL,'Hillsboro, MO 63050',20750,222,NULL,43,28397,0);
INSERT INTO "django_geo_db_location" VALUES(49441,NULL,'House Springs, MO',20751,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49442,NULL,'House Springs, MO 63051',20751,222,NULL,43,28398,0);
INSERT INTO "django_geo_db_location" VALUES(49443,NULL,'Imperial, MO',20752,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49444,NULL,'Imperial, MO 63052',20752,222,NULL,43,28399,0);
INSERT INTO "django_geo_db_location" VALUES(49445,NULL,'Kimmswick, MO',20753,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49446,NULL,'Kimmswick, MO 63053',20753,222,NULL,43,28400,0);
INSERT INTO "django_geo_db_location" VALUES(49447,NULL,'Labadie, MO',20754,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49448,NULL,'Labadie, MO 63055',20754,222,NULL,43,28401,0);
INSERT INTO "django_geo_db_location" VALUES(49449,NULL,'Leslie, MO',20755,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49450,NULL,'Leslie, MO 63056',20755,222,NULL,43,28402,0);
INSERT INTO "django_geo_db_location" VALUES(49451,NULL,'Liguori, MO',20756,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49452,NULL,'Liguori, MO 63057',20756,222,NULL,43,28403,0);
INSERT INTO "django_geo_db_location" VALUES(49453,NULL,'Lonedell, MO',20757,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49454,NULL,'Lonedell, MO 63060',20757,222,NULL,43,28404,0);
INSERT INTO "django_geo_db_location" VALUES(49455,NULL,'Luebbering, MO',20758,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49456,NULL,'Luebbering, MO 63061',20758,222,NULL,43,28405,0);
INSERT INTO "django_geo_db_location" VALUES(49457,NULL,'Mapaville, MO',20759,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49458,NULL,'Mapaville, MO 63065',20759,222,NULL,43,28406,0);
INSERT INTO "django_geo_db_location" VALUES(49459,NULL,'Morse Mill, MO',20760,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49460,NULL,'Morse Mill, MO 63066',20760,222,NULL,43,28407,0);
INSERT INTO "django_geo_db_location" VALUES(49461,NULL,'New Haven, MO',20761,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49462,NULL,'New Haven, MO 63068',20761,222,NULL,43,28408,0);
INSERT INTO "django_geo_db_location" VALUES(49463,NULL,'Pacific, MO',20762,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49464,NULL,'Pacific, MO 63069',20762,222,NULL,43,28409,0);
INSERT INTO "django_geo_db_location" VALUES(49465,NULL,'Pevely, MO',20763,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49466,NULL,'Pevely, MO 63070',20763,222,NULL,43,28410,0);
INSERT INTO "django_geo_db_location" VALUES(49467,NULL,'Richwoods, MO',20764,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49468,NULL,'Richwoods, MO 63071',20764,222,NULL,43,28411,0);
INSERT INTO "django_geo_db_location" VALUES(49469,NULL,'Robertsville, MO',20765,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49470,NULL,'Robertsville, MO 63072',20765,222,NULL,43,28412,0);
INSERT INTO "django_geo_db_location" VALUES(49471,NULL,'Saint Albans, MO',20766,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49472,NULL,'Saint Albans, MO 63073',20766,222,NULL,43,28413,0);
INSERT INTO "django_geo_db_location" VALUES(49473,NULL,'Saint Ann, MO',20767,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49474,NULL,'Saint Ann, MO 63074',20767,222,NULL,43,28414,0);
INSERT INTO "django_geo_db_location" VALUES(49475,NULL,'Saint Clair, MO',20768,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49476,NULL,'Saint Clair, MO 63077',20768,222,NULL,43,28415,0);
INSERT INTO "django_geo_db_location" VALUES(49477,NULL,'Stanton, MO',20769,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49478,NULL,'Stanton, MO 63079',20769,222,NULL,43,28416,0);
INSERT INTO "django_geo_db_location" VALUES(49479,NULL,'Sullivan, MO',20770,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49480,NULL,'Sullivan, MO 63080',20770,222,NULL,43,28417,0);
INSERT INTO "django_geo_db_location" VALUES(49481,NULL,'Union, MO',20771,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49482,NULL,'Union, MO 63084',20771,222,NULL,43,28418,0);
INSERT INTO "django_geo_db_location" VALUES(49483,NULL,'Valles Mines, MO',20772,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49484,NULL,'Valles Mines, MO 63087',20772,222,NULL,43,28419,0);
INSERT INTO "django_geo_db_location" VALUES(49485,NULL,'Valley Park, MO',20773,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49486,NULL,'Valley Park, MO 63088',20773,222,NULL,43,28420,0);
INSERT INTO "django_geo_db_location" VALUES(49487,NULL,'Villa Ridge, MO',20774,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49488,NULL,'Villa Ridge, MO 63089',20774,222,NULL,43,28421,0);
INSERT INTO "django_geo_db_location" VALUES(49489,NULL,'Washington, MO',20775,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49490,NULL,'Washington, MO 63090',20775,222,NULL,43,28422,0);
INSERT INTO "django_geo_db_location" VALUES(49491,NULL,'Rosebud, MO',20776,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49492,NULL,'Rosebud, MO 63091',20776,222,NULL,43,28423,0);
INSERT INTO "django_geo_db_location" VALUES(49493,NULL,'Fenton, MO 63099',20733,222,NULL,43,28424,0);
INSERT INTO "django_geo_db_location" VALUES(49494,NULL,'Saint Louis, MO',20777,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49495,NULL,'Saint Louis, MO 63101',20777,222,NULL,43,28425,0);
INSERT INTO "django_geo_db_location" VALUES(49496,NULL,'Saint Louis, MO 63102',20777,222,NULL,43,28426,0);
INSERT INTO "django_geo_db_location" VALUES(49497,NULL,'Saint Louis, MO 63103',20777,222,NULL,43,28427,0);
INSERT INTO "django_geo_db_location" VALUES(49498,NULL,'Saint Louis, MO 63104',20777,222,NULL,43,28428,0);
INSERT INTO "django_geo_db_location" VALUES(49499,NULL,'Saint Louis, MO 63105',20777,222,NULL,43,28429,0);
INSERT INTO "django_geo_db_location" VALUES(49500,NULL,'Saint Louis, MO 63106',20777,222,NULL,43,28430,0);
INSERT INTO "django_geo_db_location" VALUES(49501,NULL,'Saint Louis, MO 63107',20777,222,NULL,43,28431,0);
INSERT INTO "django_geo_db_location" VALUES(49502,NULL,'Saint Louis, MO 63108',20777,222,NULL,43,28432,0);
INSERT INTO "django_geo_db_location" VALUES(49503,NULL,'Saint Louis, MO 63109',20777,222,NULL,43,28433,0);
INSERT INTO "django_geo_db_location" VALUES(49504,NULL,'Saint Louis, MO 63110',20777,222,NULL,43,28434,0);
INSERT INTO "django_geo_db_location" VALUES(49505,NULL,'Saint Louis, MO 63111',20777,222,NULL,43,28435,0);
INSERT INTO "django_geo_db_location" VALUES(49506,NULL,'Saint Louis, MO 63112',20777,222,NULL,43,28436,0);
INSERT INTO "django_geo_db_location" VALUES(49507,NULL,'Saint Louis, MO 63113',20777,222,NULL,43,28437,0);
INSERT INTO "django_geo_db_location" VALUES(49508,NULL,'Saint Louis, MO 63114',20777,222,NULL,43,28438,0);
INSERT INTO "django_geo_db_location" VALUES(49509,NULL,'Saint Louis, MO 63115',20777,222,NULL,43,28439,0);
INSERT INTO "django_geo_db_location" VALUES(49510,NULL,'Saint Louis, MO 63116',20777,222,NULL,43,28440,0);
INSERT INTO "django_geo_db_location" VALUES(49511,NULL,'Saint Louis, MO 63117',20777,222,NULL,43,28441,0);
INSERT INTO "django_geo_db_location" VALUES(49512,NULL,'Saint Louis, MO 63118',20777,222,NULL,43,28442,0);
INSERT INTO "django_geo_db_location" VALUES(49513,NULL,'Saint Louis, MO 63119',20777,222,NULL,43,28443,0);
INSERT INTO "django_geo_db_location" VALUES(49514,NULL,'Saint Louis, MO 63120',20777,222,NULL,43,28444,0);
INSERT INTO "django_geo_db_location" VALUES(49515,NULL,'Saint Louis, MO 63121',20777,222,NULL,43,28445,0);
INSERT INTO "django_geo_db_location" VALUES(49516,NULL,'Saint Louis, MO 63122',20777,222,NULL,43,28446,0);
INSERT INTO "django_geo_db_location" VALUES(49517,NULL,'Saint Louis, MO 63123',20777,222,NULL,43,28447,0);
INSERT INTO "django_geo_db_location" VALUES(49518,NULL,'Saint Louis, MO 63124',20777,222,NULL,43,28448,0);
INSERT INTO "django_geo_db_location" VALUES(49519,NULL,'Saint Louis, MO 63125',20777,222,NULL,43,28449,0);
INSERT INTO "django_geo_db_location" VALUES(49520,NULL,'Saint Louis, MO 63126',20777,222,NULL,43,28450,0);
INSERT INTO "django_geo_db_location" VALUES(49521,NULL,'Saint Louis, MO 63127',20777,222,NULL,43,28451,0);
INSERT INTO "django_geo_db_location" VALUES(49522,NULL,'Saint Louis, MO 63128',20777,222,NULL,43,28452,0);
INSERT INTO "django_geo_db_location" VALUES(49523,NULL,'Saint Louis, MO 63129',20777,222,NULL,43,28453,0);
INSERT INTO "django_geo_db_location" VALUES(49524,NULL,'Saint Louis, MO 63130',20777,222,NULL,43,28454,0);
INSERT INTO "django_geo_db_location" VALUES(49525,NULL,'Saint Louis, MO 63131',20777,222,NULL,43,28455,0);
INSERT INTO "django_geo_db_location" VALUES(49526,NULL,'Saint Louis, MO 63132',20777,222,NULL,43,28456,0);
INSERT INTO "django_geo_db_location" VALUES(49527,NULL,'Saint Louis, MO 63133',20777,222,NULL,43,28457,0);
INSERT INTO "django_geo_db_location" VALUES(49528,NULL,'Saint Louis, MO 63134',20777,222,NULL,43,28458,0);
INSERT INTO "django_geo_db_location" VALUES(49529,NULL,'Saint Louis, MO 63135',20777,222,NULL,43,28459,0);
INSERT INTO "django_geo_db_location" VALUES(49530,NULL,'Saint Louis, MO 63136',20777,222,NULL,43,28460,0);
INSERT INTO "django_geo_db_location" VALUES(49531,NULL,'Saint Louis, MO 63137',20777,222,NULL,43,28461,0);
INSERT INTO "django_geo_db_location" VALUES(49532,NULL,'Saint Louis, MO 63138',20777,222,NULL,43,28462,0);
INSERT INTO "django_geo_db_location" VALUES(49533,NULL,'Saint Louis, MO 63139',20777,222,NULL,43,28463,0);
INSERT INTO "django_geo_db_location" VALUES(49534,NULL,'Saint Louis, MO 63140',20777,222,NULL,43,28464,0);
INSERT INTO "django_geo_db_location" VALUES(49535,NULL,'Saint Louis, MO 63141',20777,222,NULL,43,28465,0);
INSERT INTO "django_geo_db_location" VALUES(49536,NULL,'Saint Louis, MO 63143',20777,222,NULL,43,28466,0);
INSERT INTO "django_geo_db_location" VALUES(49537,NULL,'Saint Louis, MO 63144',20777,222,NULL,43,28467,0);
INSERT INTO "django_geo_db_location" VALUES(49538,NULL,'Saint Louis, MO 63145',20777,222,NULL,43,28468,0);
INSERT INTO "django_geo_db_location" VALUES(49539,NULL,'Saint Louis, MO 63146',20777,222,NULL,43,28469,0);
INSERT INTO "django_geo_db_location" VALUES(49540,NULL,'Saint Louis, MO 63147',20777,222,NULL,43,28470,0);
INSERT INTO "django_geo_db_location" VALUES(49541,NULL,'Saint Louis, MO 63150',20777,222,NULL,43,28471,0);
INSERT INTO "django_geo_db_location" VALUES(49542,NULL,'Saint Louis, MO 63151',20777,222,NULL,43,28472,0);
INSERT INTO "django_geo_db_location" VALUES(49543,NULL,'Saint Louis, MO 63153',20777,222,NULL,43,28473,0);
INSERT INTO "django_geo_db_location" VALUES(49544,NULL,'Saint Louis, MO 63155',20777,222,NULL,43,28474,0);
INSERT INTO "django_geo_db_location" VALUES(49545,NULL,'Saint Louis, MO 63156',20777,222,NULL,43,28475,0);
INSERT INTO "django_geo_db_location" VALUES(49546,NULL,'Saint Louis, MO 63157',20777,222,NULL,43,28476,0);
INSERT INTO "django_geo_db_location" VALUES(49547,NULL,'Saint Louis, MO 63158',20777,222,NULL,43,28477,0);
INSERT INTO "django_geo_db_location" VALUES(49548,NULL,'Saint Louis, MO 63160',20777,222,NULL,43,28478,0);
INSERT INTO "django_geo_db_location" VALUES(49549,NULL,'Saint Louis, MO 63163',20777,222,NULL,43,28479,0);
INSERT INTO "django_geo_db_location" VALUES(49550,NULL,'Saint Louis, MO 63164',20777,222,NULL,43,28480,0);
INSERT INTO "django_geo_db_location" VALUES(49551,NULL,'Saint Louis, MO 63166',20777,222,NULL,43,28481,0);
INSERT INTO "django_geo_db_location" VALUES(49552,NULL,'Saint Louis, MO 63167',20777,222,NULL,43,28482,0);
INSERT INTO "django_geo_db_location" VALUES(49553,NULL,'Saint Louis, MO 63169',20777,222,NULL,43,28483,0);
INSERT INTO "django_geo_db_location" VALUES(49554,NULL,'Saint Louis, MO 63171',20777,222,NULL,43,28484,0);
INSERT INTO "django_geo_db_location" VALUES(49555,NULL,'Saint Louis, MO 63177',20777,222,NULL,43,28485,0);
INSERT INTO "django_geo_db_location" VALUES(49556,NULL,'Saint Louis, MO 63178',20777,222,NULL,43,28486,0);
INSERT INTO "django_geo_db_location" VALUES(49557,NULL,'Saint Louis, MO 63179',20777,222,NULL,43,28487,0);
INSERT INTO "django_geo_db_location" VALUES(49558,NULL,'Saint Louis, MO 63180',20777,222,NULL,43,28488,0);
INSERT INTO "django_geo_db_location" VALUES(49559,NULL,'Saint Louis, MO 63182',20777,222,NULL,43,28489,0);
INSERT INTO "django_geo_db_location" VALUES(49560,NULL,'Saint Louis, MO 63188',20777,222,NULL,43,28490,0);
INSERT INTO "django_geo_db_location" VALUES(49561,NULL,'Saint Louis, MO 63195',20777,222,NULL,43,28491,0);
INSERT INTO "django_geo_db_location" VALUES(49562,NULL,'Saint Louis, MO 63196',20777,222,NULL,43,28492,0);
INSERT INTO "django_geo_db_location" VALUES(49563,NULL,'Saint Louis, MO 63197',20777,222,NULL,43,28493,0);
INSERT INTO "django_geo_db_location" VALUES(49564,NULL,'Saint Louis, MO 63198',20777,222,NULL,43,28494,0);
INSERT INTO "django_geo_db_location" VALUES(49565,NULL,'Saint Louis, MO 63199',20777,222,NULL,43,28495,0);
INSERT INTO "django_geo_db_location" VALUES(49566,NULL,'Saint Charles, MO',20778,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49567,NULL,'Saint Charles, MO 63301',20778,222,NULL,43,28496,0);
INSERT INTO "django_geo_db_location" VALUES(49568,NULL,'Saint Charles, MO 63302',20778,222,NULL,43,28497,0);
INSERT INTO "django_geo_db_location" VALUES(49569,NULL,'Saint Charles, MO 63303',20778,222,NULL,43,28498,0);
INSERT INTO "django_geo_db_location" VALUES(49570,NULL,'Saint Charles, MO 63304',20778,222,NULL,43,28499,0);
INSERT INTO "django_geo_db_location" VALUES(49571,NULL,'Annada, MO',20779,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49572,NULL,'Annada, MO 63330',20779,222,NULL,43,28500,0);
INSERT INTO "django_geo_db_location" VALUES(49573,NULL,'Augusta, MO',20780,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49574,NULL,'Augusta, MO 63332',20780,222,NULL,43,28501,0);
INSERT INTO "django_geo_db_location" VALUES(49575,NULL,'Bellflower, MO',20781,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49576,NULL,'Bellflower, MO 63333',20781,222,NULL,43,28502,0);
INSERT INTO "django_geo_db_location" VALUES(49577,NULL,'Bowling Green, MO',20782,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49578,NULL,'Bowling Green, MO 63334',20782,222,NULL,43,28503,0);
INSERT INTO "django_geo_db_location" VALUES(49579,NULL,'Clarksville, MO',20783,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49580,NULL,'Clarksville, MO 63336',20783,222,NULL,43,28504,0);
INSERT INTO "django_geo_db_location" VALUES(49581,NULL,'Cottleville, MO',20784,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49582,NULL,'Cottleville, MO 63338',20784,222,NULL,43,28505,0);
INSERT INTO "django_geo_db_location" VALUES(49583,NULL,'Curryville, MO',20785,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49584,NULL,'Curryville, MO 63339',20785,222,NULL,43,28506,0);
INSERT INTO "django_geo_db_location" VALUES(49585,NULL,'Defiance, MO',20786,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49586,NULL,'Defiance, MO 63341',20786,222,NULL,43,28507,0);
INSERT INTO "django_geo_db_location" VALUES(49587,NULL,'Dutzow, MO',20787,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49588,NULL,'Dutzow, MO 63342',20787,222,NULL,43,28508,0);
INSERT INTO "django_geo_db_location" VALUES(49589,NULL,'Elsberry, MO',20788,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49590,NULL,'Elsberry, MO 63343',20788,222,NULL,43,28509,0);
INSERT INTO "django_geo_db_location" VALUES(49591,NULL,'Eolia, MO',20789,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49592,NULL,'Eolia, MO 63344',20789,222,NULL,43,28510,0);
INSERT INTO "django_geo_db_location" VALUES(49593,NULL,'Farber, MO',20790,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49594,NULL,'Farber, MO 63345',20790,222,NULL,43,28511,0);
INSERT INTO "django_geo_db_location" VALUES(49595,NULL,'Flinthill, MO',20791,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49596,NULL,'Flinthill, MO 63346',20791,222,NULL,43,28512,0);
INSERT INTO "django_geo_db_location" VALUES(49597,NULL,'Foley, MO',20792,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49598,NULL,'Foley, MO 63347',20792,222,NULL,43,28513,0);
INSERT INTO "django_geo_db_location" VALUES(49599,NULL,'Foristell, MO',20793,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49600,NULL,'Foristell, MO 63348',20793,222,NULL,43,28514,0);
INSERT INTO "django_geo_db_location" VALUES(49601,NULL,'Hawk Point, MO',20794,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49602,NULL,'Hawk Point, MO 63349',20794,222,NULL,43,28515,0);
INSERT INTO "django_geo_db_location" VALUES(49603,NULL,'High Hill, MO',20795,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49604,NULL,'High Hill, MO 63350',20795,222,NULL,43,28516,0);
INSERT INTO "django_geo_db_location" VALUES(49605,NULL,'Jonesburg, MO',20796,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49606,NULL,'Jonesburg, MO 63351',20796,222,NULL,43,28517,0);
INSERT INTO "django_geo_db_location" VALUES(49607,NULL,'Laddonia, MO',20797,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49608,NULL,'Laddonia, MO 63352',20797,222,NULL,43,28518,0);
INSERT INTO "django_geo_db_location" VALUES(49609,NULL,'Louisiana, MO',20798,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49610,NULL,'Louisiana, MO 63353',20798,222,NULL,43,28519,0);
INSERT INTO "django_geo_db_location" VALUES(49611,NULL,'Marthasville, MO',20799,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49612,NULL,'Marthasville, MO 63357',20799,222,NULL,43,28520,0);
INSERT INTO "django_geo_db_location" VALUES(49613,NULL,'Middletown, MO',20800,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49614,NULL,'Middletown, MO 63359',20800,222,NULL,43,28521,0);
INSERT INTO "django_geo_db_location" VALUES(49615,NULL,'Montgomery City, MO',20801,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49616,NULL,'Montgomery City, MO 63361',20801,222,NULL,43,28522,0);
INSERT INTO "django_geo_db_location" VALUES(49617,NULL,'Moscow Mills, MO',20802,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49618,NULL,'Moscow Mills, MO 63362',20802,222,NULL,43,28523,0);
INSERT INTO "django_geo_db_location" VALUES(49619,NULL,'New Florence, MO',20803,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49620,NULL,'New Florence, MO 63363',20803,222,NULL,43,28524,0);
INSERT INTO "django_geo_db_location" VALUES(49621,NULL,'New Melle, MO',20804,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49622,NULL,'New Melle, MO 63365',20804,222,NULL,43,28525,0);
INSERT INTO "django_geo_db_location" VALUES(49623,NULL,'O Fallon, MO',20805,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49624,NULL,'O Fallon, MO 63366',20805,222,NULL,43,28526,0);
INSERT INTO "django_geo_db_location" VALUES(49625,NULL,'Lake Saint Louis, MO',20806,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49626,NULL,'Lake Saint Louis, MO 63367',20806,222,NULL,43,28527,0);
INSERT INTO "django_geo_db_location" VALUES(49627,NULL,'Old Monroe, MO',20807,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49628,NULL,'Old Monroe, MO 63369',20807,222,NULL,43,28528,0);
INSERT INTO "django_geo_db_location" VALUES(49629,NULL,'Olney, MO',20808,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49630,NULL,'Olney, MO 63370',20808,222,NULL,43,28529,0);
INSERT INTO "django_geo_db_location" VALUES(49631,NULL,'Paynesville, MO',20809,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49632,NULL,'Paynesville, MO 63371',20809,222,NULL,43,28530,0);
INSERT INTO "django_geo_db_location" VALUES(49633,NULL,'Portage Des Sioux, MO',20810,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49634,NULL,'Portage Des Sioux, MO 63373',20810,222,NULL,43,28531,0);
INSERT INTO "django_geo_db_location" VALUES(49635,NULL,'Perryville, MO',20811,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49636,NULL,'Perryville, MO 63375',20811,222,NULL,43,28532,0);
INSERT INTO "django_geo_db_location" VALUES(49637,NULL,'Saint Peters, MO',20812,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49638,NULL,'Saint Peters, MO 63376',20812,222,NULL,43,28533,0);
INSERT INTO "django_geo_db_location" VALUES(49639,NULL,'Silex, MO',20813,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49640,NULL,'Silex, MO 63377',20813,222,NULL,43,28534,0);
INSERT INTO "django_geo_db_location" VALUES(49641,NULL,'Treloar, MO',20814,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49642,NULL,'Treloar, MO 63378',20814,222,NULL,43,28535,0);
INSERT INTO "django_geo_db_location" VALUES(49643,NULL,'Troy, MO',20815,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49644,NULL,'Troy, MO 63379',20815,222,NULL,43,28536,0);
INSERT INTO "django_geo_db_location" VALUES(49645,NULL,'Truxton, MO',20816,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49646,NULL,'Truxton, MO 63381',20816,222,NULL,43,28537,0);
INSERT INTO "django_geo_db_location" VALUES(49647,NULL,'Vandalia, MO',20817,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49648,NULL,'Vandalia, MO 63382',20817,222,NULL,43,28538,0);
INSERT INTO "django_geo_db_location" VALUES(49649,NULL,'Warrenton, MO',20818,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49650,NULL,'Warrenton, MO 63383',20818,222,NULL,43,28539,0);
INSERT INTO "django_geo_db_location" VALUES(49651,NULL,'Wellsville, MO',20819,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49652,NULL,'Wellsville, MO 63384',20819,222,NULL,43,28540,0);
INSERT INTO "django_geo_db_location" VALUES(49653,NULL,'Wentzville, MO',20820,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49654,NULL,'Wentzville, MO 63385',20820,222,NULL,43,28541,0);
INSERT INTO "django_geo_db_location" VALUES(49655,NULL,'West Alton, MO',20821,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49656,NULL,'West Alton, MO 63386',20821,222,NULL,43,28542,0);
INSERT INTO "django_geo_db_location" VALUES(49657,NULL,'Whiteside, MO',20822,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49658,NULL,'Whiteside, MO 63387',20822,222,NULL,43,28543,0);
INSERT INTO "django_geo_db_location" VALUES(49659,NULL,'Williamsburg, MO',20823,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49660,NULL,'Williamsburg, MO 63388',20823,222,NULL,43,28544,0);
INSERT INTO "django_geo_db_location" VALUES(49661,NULL,'Winfield, MO',20824,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49662,NULL,'Winfield, MO 63389',20824,222,NULL,43,28545,0);
INSERT INTO "django_geo_db_location" VALUES(49663,NULL,'Wright City, MO',20825,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49664,NULL,'Wright City, MO 63390',20825,222,NULL,43,28546,0);
INSERT INTO "django_geo_db_location" VALUES(49665,NULL,'Hannibal, MO',20826,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49666,NULL,'Hannibal, MO 63401',20826,222,NULL,43,28547,0);
INSERT INTO "django_geo_db_location" VALUES(49667,NULL,'Alexandria, MO',20827,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49668,NULL,'Alexandria, MO 63430',20827,222,NULL,43,28548,0);
INSERT INTO "django_geo_db_location" VALUES(49669,NULL,'Anabel, MO',20828,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49670,NULL,'Anabel, MO 63431',20828,222,NULL,43,28549,0);
INSERT INTO "django_geo_db_location" VALUES(49671,NULL,'Arbela, MO',20829,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49672,NULL,'Arbela, MO 63432',20829,222,NULL,43,28550,0);
INSERT INTO "django_geo_db_location" VALUES(49673,NULL,'Ashburn, MO',20830,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49674,NULL,'Ashburn, MO 63433',20830,222,NULL,43,28551,0);
INSERT INTO "django_geo_db_location" VALUES(49675,NULL,'Bethel, MO',20831,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49676,NULL,'Bethel, MO 63434',20831,222,NULL,43,28552,0);
INSERT INTO "django_geo_db_location" VALUES(49677,NULL,'Canton, MO',20832,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49678,NULL,'Canton, MO 63435',20832,222,NULL,43,28553,0);
INSERT INTO "django_geo_db_location" VALUES(49679,NULL,'Center, MO',20833,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49680,NULL,'Center, MO 63436',20833,222,NULL,43,28554,0);
INSERT INTO "django_geo_db_location" VALUES(49681,NULL,'Clarence, MO',20834,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49682,NULL,'Clarence, MO 63437',20834,222,NULL,43,28555,0);
INSERT INTO "django_geo_db_location" VALUES(49683,NULL,'Durham, MO',20835,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49684,NULL,'Durham, MO 63438',20835,222,NULL,43,28556,0);
INSERT INTO "django_geo_db_location" VALUES(49685,NULL,'Emden, MO',20836,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49686,NULL,'Emden, MO 63439',20836,222,NULL,43,28557,0);
INSERT INTO "django_geo_db_location" VALUES(49687,NULL,'Ewing, MO',20837,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49688,NULL,'Ewing, MO 63440',20837,222,NULL,43,28558,0);
INSERT INTO "django_geo_db_location" VALUES(49689,NULL,'Frankford, MO',20838,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49690,NULL,'Frankford, MO 63441',20838,222,NULL,43,28559,0);
INSERT INTO "django_geo_db_location" VALUES(49691,NULL,'Granger, MO',20839,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49692,NULL,'Granger, MO 63442',20839,222,NULL,43,28560,0);
INSERT INTO "django_geo_db_location" VALUES(49693,NULL,'Hunnewell, MO',20840,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49694,NULL,'Hunnewell, MO 63443',20840,222,NULL,43,28561,0);
INSERT INTO "django_geo_db_location" VALUES(49695,NULL,'Kahoka, MO',20841,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49696,NULL,'Kahoka, MO 63445',20841,222,NULL,43,28562,0);
INSERT INTO "django_geo_db_location" VALUES(49697,NULL,'Knox City, MO',20842,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49698,NULL,'Knox City, MO 63446',20842,222,NULL,43,28563,0);
INSERT INTO "django_geo_db_location" VALUES(49699,NULL,'La Belle, MO',20843,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49700,NULL,'La Belle, MO 63447',20843,222,NULL,43,28564,0);
INSERT INTO "django_geo_db_location" VALUES(49701,NULL,'La Grange, MO',20844,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49702,NULL,'La Grange, MO 63448',20844,222,NULL,43,28565,0);
INSERT INTO "django_geo_db_location" VALUES(49703,NULL,'Lentner, MO',20845,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49704,NULL,'Lentner, MO 63450',20845,222,NULL,43,28566,0);
INSERT INTO "django_geo_db_location" VALUES(49705,NULL,'Leonard, MO',20846,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49706,NULL,'Leonard, MO 63451',20846,222,NULL,43,28567,0);
INSERT INTO "django_geo_db_location" VALUES(49707,NULL,'Lewistown, MO',20847,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49708,NULL,'Lewistown, MO 63452',20847,222,NULL,43,28568,0);
INSERT INTO "django_geo_db_location" VALUES(49709,NULL,'Luray, MO',20848,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49710,NULL,'Luray, MO 63453',20848,222,NULL,43,28569,0);
INSERT INTO "django_geo_db_location" VALUES(49711,NULL,'Maywood, MO',20849,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49712,NULL,'Maywood, MO 63454',20849,222,NULL,43,28570,0);
INSERT INTO "django_geo_db_location" VALUES(49713,NULL,'Monroe City, MO',20850,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49714,NULL,'Monroe City, MO 63456',20850,222,NULL,43,28571,0);
INSERT INTO "django_geo_db_location" VALUES(49715,NULL,'Monticello, MO',20851,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49716,NULL,'Monticello, MO 63457',20851,222,NULL,43,28572,0);
INSERT INTO "django_geo_db_location" VALUES(49717,NULL,'Newark, MO',20852,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49718,NULL,'Newark, MO 63458',20852,222,NULL,43,28573,0);
INSERT INTO "django_geo_db_location" VALUES(49719,NULL,'New London, MO',20853,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49720,NULL,'New London, MO 63459',20853,222,NULL,43,28574,0);
INSERT INTO "django_geo_db_location" VALUES(49721,NULL,'Novelty, MO',20854,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49722,NULL,'Novelty, MO 63460',20854,222,NULL,43,28575,0);
INSERT INTO "django_geo_db_location" VALUES(49723,NULL,'Palmyra, MO',20855,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49724,NULL,'Palmyra, MO 63461',20855,222,NULL,43,28576,0);
INSERT INTO "django_geo_db_location" VALUES(49725,NULL,'Perry, MO',20856,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49726,NULL,'Perry, MO 63462',20856,222,NULL,43,28577,0);
INSERT INTO "django_geo_db_location" VALUES(49727,NULL,'Philadelphia, MO',20857,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49728,NULL,'Philadelphia, MO 63463',20857,222,NULL,43,28578,0);
INSERT INTO "django_geo_db_location" VALUES(49729,NULL,'Plevna, MO',20858,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49730,NULL,'Plevna, MO 63464',20858,222,NULL,43,28579,0);
INSERT INTO "django_geo_db_location" VALUES(49731,NULL,'Revere, MO',20859,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49732,NULL,'Revere, MO 63465',20859,222,NULL,43,28580,0);
INSERT INTO "django_geo_db_location" VALUES(49733,NULL,'Saint Patrick, MO',20860,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49734,NULL,'Saint Patrick, MO 63466',20860,222,NULL,43,28581,0);
INSERT INTO "django_geo_db_location" VALUES(49735,NULL,'Saverton, MO',20861,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49736,NULL,'Saverton, MO 63467',20861,222,NULL,43,28582,0);
INSERT INTO "django_geo_db_location" VALUES(49737,NULL,'Shelbina, MO',20862,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49738,NULL,'Shelbina, MO 63468',20862,222,NULL,43,28583,0);
INSERT INTO "django_geo_db_location" VALUES(49739,NULL,'Shelbyville, MO',20863,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49740,NULL,'Shelbyville, MO 63469',20863,222,NULL,43,28584,0);
INSERT INTO "django_geo_db_location" VALUES(49741,NULL,'Taylor, MO',20864,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49742,NULL,'Taylor, MO 63471',20864,222,NULL,43,28585,0);
INSERT INTO "django_geo_db_location" VALUES(49743,NULL,'Wayland, MO',20865,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49744,NULL,'Wayland, MO 63472',20865,222,NULL,43,28586,0);
INSERT INTO "django_geo_db_location" VALUES(49745,NULL,'Williamstown, MO',20866,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49746,NULL,'Williamstown, MO 63473',20866,222,NULL,43,28587,0);
INSERT INTO "django_geo_db_location" VALUES(49747,NULL,'Wyaconda, MO',20867,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49748,NULL,'Wyaconda, MO 63474',20867,222,NULL,43,28588,0);
INSERT INTO "django_geo_db_location" VALUES(49749,NULL,'La Belle, MO 63477',20843,222,NULL,43,28589,0);
INSERT INTO "django_geo_db_location" VALUES(49750,NULL,'Kirksville, MO',20868,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49751,NULL,'Kirksville, MO 63501',20868,222,NULL,43,28590,0);
INSERT INTO "django_geo_db_location" VALUES(49752,NULL,'Atlanta, MO',20869,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49753,NULL,'Atlanta, MO 63530',20869,222,NULL,43,28591,0);
INSERT INTO "django_geo_db_location" VALUES(49754,NULL,'Baring, MO',20870,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49755,NULL,'Baring, MO 63531',20870,222,NULL,43,28592,0);
INSERT INTO "django_geo_db_location" VALUES(49756,NULL,'Bevier, MO',20871,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49757,NULL,'Bevier, MO 63532',20871,222,NULL,43,28593,0);
INSERT INTO "django_geo_db_location" VALUES(49758,NULL,'Brashear, MO',20872,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49759,NULL,'Brashear, MO 63533',20872,222,NULL,43,28594,0);
INSERT INTO "django_geo_db_location" VALUES(49760,NULL,'Callao, MO',20873,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49761,NULL,'Callao, MO 63534',20873,222,NULL,43,28595,0);
INSERT INTO "django_geo_db_location" VALUES(49762,NULL,'Coatsville, MO',20874,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49763,NULL,'Coatsville, MO 63535',20874,222,NULL,43,28596,0);
INSERT INTO "django_geo_db_location" VALUES(49764,NULL,'Downing, MO',20875,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49765,NULL,'Downing, MO 63536',20875,222,NULL,43,28597,0);
INSERT INTO "django_geo_db_location" VALUES(49766,NULL,'Edina, MO',20876,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49767,NULL,'Edina, MO 63537',20876,222,NULL,43,28598,0);
INSERT INTO "django_geo_db_location" VALUES(49768,NULL,'Elmer, MO',20877,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49769,NULL,'Elmer, MO 63538',20877,222,NULL,43,28599,0);
INSERT INTO "django_geo_db_location" VALUES(49770,NULL,'Ethel, MO',20878,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49771,NULL,'Ethel, MO 63539',20878,222,NULL,43,28600,0);
INSERT INTO "django_geo_db_location" VALUES(49772,NULL,'Gibbs, MO',20879,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49773,NULL,'Gibbs, MO 63540',20879,222,NULL,43,28601,0);
INSERT INTO "django_geo_db_location" VALUES(49774,NULL,'Glenwood, MO',20880,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49775,NULL,'Glenwood, MO 63541',20880,222,NULL,43,28602,0);
INSERT INTO "django_geo_db_location" VALUES(49776,NULL,'Gorin, MO',20881,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49777,NULL,'Gorin, MO 63543',20881,222,NULL,43,28603,0);
INSERT INTO "django_geo_db_location" VALUES(49778,NULL,'Green Castle, MO',20882,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49779,NULL,'Green Castle, MO 63544',20882,222,NULL,43,28604,0);
INSERT INTO "django_geo_db_location" VALUES(49780,NULL,'Green City, MO',20883,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49781,NULL,'Green City, MO 63545',20883,222,NULL,43,28605,0);
INSERT INTO "django_geo_db_location" VALUES(49782,NULL,'Greentop, MO',20884,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49783,NULL,'Greentop, MO 63546',20884,222,NULL,43,28606,0);
INSERT INTO "django_geo_db_location" VALUES(49784,NULL,'Hurdland, MO',20885,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49785,NULL,'Hurdland, MO 63547',20885,222,NULL,43,28607,0);
INSERT INTO "django_geo_db_location" VALUES(49786,NULL,'Lancaster, MO',20886,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49787,NULL,'Lancaster, MO 63548',20886,222,NULL,43,28608,0);
INSERT INTO "django_geo_db_location" VALUES(49788,NULL,'La Plata, MO',20887,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49789,NULL,'La Plata, MO 63549',20887,222,NULL,43,28609,0);
INSERT INTO "django_geo_db_location" VALUES(49790,NULL,'Livonia, MO',20888,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49791,NULL,'Livonia, MO 63551',20888,222,NULL,43,28610,0);
INSERT INTO "django_geo_db_location" VALUES(49792,NULL,'Macon, MO',20889,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49793,NULL,'Macon, MO 63552',20889,222,NULL,43,28611,0);
INSERT INTO "django_geo_db_location" VALUES(49794,NULL,'Memphis, MO',20890,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49795,NULL,'Memphis, MO 63555',20890,222,NULL,43,28612,0);
INSERT INTO "django_geo_db_location" VALUES(49796,NULL,'Milan, MO',20891,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49797,NULL,'Milan, MO 63556',20891,222,NULL,43,28613,0);
INSERT INTO "django_geo_db_location" VALUES(49798,NULL,'New Boston, MO',20892,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49799,NULL,'New Boston, MO 63557',20892,222,NULL,43,28614,0);
INSERT INTO "django_geo_db_location" VALUES(49800,NULL,'New Cambria, MO',20893,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49801,NULL,'New Cambria, MO 63558',20893,222,NULL,43,28615,0);
INSERT INTO "django_geo_db_location" VALUES(49802,NULL,'Novinger, MO',20894,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49803,NULL,'Novinger, MO 63559',20894,222,NULL,43,28616,0);
INSERT INTO "django_geo_db_location" VALUES(49804,NULL,'Pollock, MO',20895,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49805,NULL,'Pollock, MO 63560',20895,222,NULL,43,28617,0);
INSERT INTO "django_geo_db_location" VALUES(49806,NULL,'Queen City, MO',20896,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49807,NULL,'Queen City, MO 63561',20896,222,NULL,43,28618,0);
INSERT INTO "django_geo_db_location" VALUES(49808,NULL,'Rutledge, MO',20897,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49809,NULL,'Rutledge, MO 63563',20897,222,NULL,43,28619,0);
INSERT INTO "django_geo_db_location" VALUES(49810,NULL,'Unionville, MO',20898,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49811,NULL,'Unionville, MO 63565',20898,222,NULL,43,28620,0);
INSERT INTO "django_geo_db_location" VALUES(49812,NULL,'Winigan, MO',20899,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49813,NULL,'Winigan, MO 63566',20899,222,NULL,43,28621,0);
INSERT INTO "django_geo_db_location" VALUES(49814,NULL,'Worthington, MO',20900,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49815,NULL,'Worthington, MO 63567',20900,222,NULL,43,28622,0);
INSERT INTO "django_geo_db_location" VALUES(49816,NULL,'Clay, MO',20901,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49817,NULL,'Clay, MO 63588',20901,222,NULL,43,28623,0);
INSERT INTO "django_geo_db_location" VALUES(49818,NULL,'Park Hills, MO',20902,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49819,NULL,'Park Hills, MO 63601',20902,222,NULL,43,28624,0);
INSERT INTO "django_geo_db_location" VALUES(49820,NULL,'Annapolis, MO',20903,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49821,NULL,'Annapolis, MO 63620',20903,222,NULL,43,28625,0);
INSERT INTO "django_geo_db_location" VALUES(49822,NULL,'Arcadia, MO',20904,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49823,NULL,'Arcadia, MO 63621',20904,222,NULL,43,28626,0);
INSERT INTO "django_geo_db_location" VALUES(49824,NULL,'Belgrade, MO',20905,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49825,NULL,'Belgrade, MO 63622',20905,222,NULL,43,28627,0);
INSERT INTO "django_geo_db_location" VALUES(49826,NULL,'Belleview, MO',20906,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49827,NULL,'Belleview, MO 63623',20906,222,NULL,43,28628,0);
INSERT INTO "django_geo_db_location" VALUES(49828,NULL,'Bismarck, MO',20907,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49829,NULL,'Bismarck, MO 63624',20907,222,NULL,43,28629,0);
INSERT INTO "django_geo_db_location" VALUES(49830,NULL,'Black, MO',20908,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49831,NULL,'Black, MO 63625',20908,222,NULL,43,28630,0);
INSERT INTO "django_geo_db_location" VALUES(49832,NULL,'Blackwell, MO',20909,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49833,NULL,'Blackwell, MO 63626',20909,222,NULL,43,28631,0);
INSERT INTO "django_geo_db_location" VALUES(49834,NULL,'Bloomsdale, MO',20910,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49835,NULL,'Bloomsdale, MO 63627',20910,222,NULL,43,28632,0);
INSERT INTO "django_geo_db_location" VALUES(49836,NULL,'Bonne Terre, MO',20911,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49837,NULL,'Bonne Terre, MO 63628',20911,222,NULL,43,28633,0);
INSERT INTO "django_geo_db_location" VALUES(49838,NULL,'Bunker, MO',20912,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49839,NULL,'Bunker, MO 63629',20912,222,NULL,43,28634,0);
INSERT INTO "django_geo_db_location" VALUES(49840,NULL,'Cadet, MO',20913,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49841,NULL,'Cadet, MO 63630',20913,222,NULL,43,28635,0);
INSERT INTO "django_geo_db_location" VALUES(49842,NULL,'Caledonia, MO',20914,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49843,NULL,'Caledonia, MO 63631',20914,222,NULL,43,28636,0);
INSERT INTO "django_geo_db_location" VALUES(49844,NULL,'Cascade, MO',20915,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49845,NULL,'Cascade, MO 63632',20915,222,NULL,43,28637,0);
INSERT INTO "django_geo_db_location" VALUES(49846,NULL,'Centerville, MO',20916,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49847,NULL,'Centerville, MO 63633',20916,222,NULL,43,28638,0);
INSERT INTO "django_geo_db_location" VALUES(49848,NULL,'Des Arc, MO',20917,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49849,NULL,'Des Arc, MO 63636',20917,222,NULL,43,28639,0);
INSERT INTO "django_geo_db_location" VALUES(49850,NULL,'Doe Run, MO',20918,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49851,NULL,'Doe Run, MO 63637',20918,222,NULL,43,28640,0);
INSERT INTO "django_geo_db_location" VALUES(49852,NULL,'Ellington, MO',20919,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49853,NULL,'Ellington, MO 63638',20919,222,NULL,43,28641,0);
INSERT INTO "django_geo_db_location" VALUES(49854,NULL,'Farmington, MO',20920,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49855,NULL,'Farmington, MO 63640',20920,222,NULL,43,28642,0);
INSERT INTO "django_geo_db_location" VALUES(49856,NULL,'Fredericktown, MO',20921,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49857,NULL,'Fredericktown, MO 63645',20921,222,NULL,43,28643,0);
INSERT INTO "django_geo_db_location" VALUES(49858,NULL,'Glover, MO',20922,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49859,NULL,'Glover, MO 63646',20922,222,NULL,43,28644,0);
INSERT INTO "django_geo_db_location" VALUES(49860,NULL,'Irondale, MO',20923,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49861,NULL,'Irondale, MO 63648',20923,222,NULL,43,28645,0);
INSERT INTO "django_geo_db_location" VALUES(49862,NULL,'Ironton, MO',20924,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49863,NULL,'Ironton, MO 63650',20924,222,NULL,43,28646,0);
INSERT INTO "django_geo_db_location" VALUES(49864,NULL,'Knob Lick, MO',20925,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49865,NULL,'Knob Lick, MO 63651',20925,222,NULL,43,28647,0);
INSERT INTO "django_geo_db_location" VALUES(49866,NULL,'Leadwood, MO',20926,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49867,NULL,'Leadwood, MO 63653',20926,222,NULL,43,28648,0);
INSERT INTO "django_geo_db_location" VALUES(49868,NULL,'Lesterville, MO',20927,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49869,NULL,'Lesterville, MO 63654',20927,222,NULL,43,28649,0);
INSERT INTO "django_geo_db_location" VALUES(49870,NULL,'Marquand, MO',20928,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49871,NULL,'Marquand, MO 63655',20928,222,NULL,43,28650,0);
INSERT INTO "django_geo_db_location" VALUES(49872,NULL,'Middle Brook, MO',20929,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49873,NULL,'Middle Brook, MO 63656',20929,222,NULL,43,28651,0);
INSERT INTO "django_geo_db_location" VALUES(49874,NULL,'Mineral Point, MO',20930,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49875,NULL,'Mineral Point, MO 63660',20930,222,NULL,43,28652,0);
INSERT INTO "django_geo_db_location" VALUES(49876,NULL,'New Offenburg, MO',20931,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49877,NULL,'New Offenburg, MO 63661',20931,222,NULL,43,28653,0);
INSERT INTO "django_geo_db_location" VALUES(49878,NULL,'Patton, MO',20932,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49879,NULL,'Patton, MO 63662',20932,222,NULL,43,28654,0);
INSERT INTO "django_geo_db_location" VALUES(49880,NULL,'Pilot Knob, MO',20933,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49881,NULL,'Pilot Knob, MO 63663',20933,222,NULL,43,28655,0);
INSERT INTO "django_geo_db_location" VALUES(49882,NULL,'Potosi, MO',20934,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49883,NULL,'Potosi, MO 63664',20934,222,NULL,43,28656,0);
INSERT INTO "django_geo_db_location" VALUES(49884,NULL,'Redford, MO',20935,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49885,NULL,'Redford, MO 63665',20935,222,NULL,43,28657,0);
INSERT INTO "django_geo_db_location" VALUES(49886,NULL,'Reynolds, MO',20936,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49887,NULL,'Reynolds, MO 63666',20936,222,NULL,43,28658,0);
INSERT INTO "django_geo_db_location" VALUES(49888,NULL,'Sainte Genevieve, MO',20937,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49889,NULL,'Sainte Genevieve, MO 63670',20937,222,NULL,43,28659,0);
INSERT INTO "django_geo_db_location" VALUES(49890,NULL,'Saint Mary, MO',20938,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49891,NULL,'Saint Mary, MO 63673',20938,222,NULL,43,28660,0);
INSERT INTO "django_geo_db_location" VALUES(49892,NULL,'Tiff, MO',20939,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49893,NULL,'Tiff, MO 63674',20939,222,NULL,43,28661,0);
INSERT INTO "django_geo_db_location" VALUES(49894,NULL,'Vulcan, MO',20940,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49895,NULL,'Vulcan, MO 63675',20940,222,NULL,43,28662,0);
INSERT INTO "django_geo_db_location" VALUES(49896,NULL,'Cape Girardeau, MO',20941,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49897,NULL,'Cape Girardeau, MO 63701',20941,222,NULL,43,28663,0);
INSERT INTO "django_geo_db_location" VALUES(49898,NULL,'Cape Girardeau, MO 63702',20941,222,NULL,43,28664,0);
INSERT INTO "django_geo_db_location" VALUES(49899,NULL,'Cape Girardeau, MO 63703',20941,222,NULL,43,28665,0);
INSERT INTO "django_geo_db_location" VALUES(49900,NULL,'Cape Girardeau, MO 63705',20941,222,NULL,43,28666,0);
INSERT INTO "django_geo_db_location" VALUES(49901,NULL,'Advance, MO',20942,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49902,NULL,'Advance, MO 63730',20942,222,NULL,43,28667,0);
INSERT INTO "django_geo_db_location" VALUES(49903,NULL,'Altenburg, MO',20943,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49904,NULL,'Altenburg, MO 63732',20943,222,NULL,43,28668,0);
INSERT INTO "django_geo_db_location" VALUES(49905,NULL,'Bell City, MO',20944,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49906,NULL,'Bell City, MO 63735',20944,222,NULL,43,28669,0);
INSERT INTO "django_geo_db_location" VALUES(49907,NULL,'Benton, MO',20945,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49908,NULL,'Benton, MO 63736',20945,222,NULL,43,28670,0);
INSERT INTO "django_geo_db_location" VALUES(49909,NULL,'Brazeau, MO',20946,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49910,NULL,'Brazeau, MO 63737',20946,222,NULL,43,28671,0);
INSERT INTO "django_geo_db_location" VALUES(49911,NULL,'Brownwood, MO',20947,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49912,NULL,'Brownwood, MO 63738',20947,222,NULL,43,28672,0);
INSERT INTO "django_geo_db_location" VALUES(49913,NULL,'Burfordville, MO',20948,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49914,NULL,'Burfordville, MO 63739',20948,222,NULL,43,28673,0);
INSERT INTO "django_geo_db_location" VALUES(49915,NULL,'Chaffee, MO',20949,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49916,NULL,'Chaffee, MO 63740',20949,222,NULL,43,28674,0);
INSERT INTO "django_geo_db_location" VALUES(49917,NULL,'Commerce, MO',20950,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49918,NULL,'Commerce, MO 63742',20950,222,NULL,43,28675,0);
INSERT INTO "django_geo_db_location" VALUES(49919,NULL,'Daisy, MO',20951,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49920,NULL,'Daisy, MO 63743',20951,222,NULL,43,28676,0);
INSERT INTO "django_geo_db_location" VALUES(49921,NULL,'Delta, MO',20952,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49922,NULL,'Delta, MO 63744',20952,222,NULL,43,28677,0);
INSERT INTO "django_geo_db_location" VALUES(49923,NULL,'Dutchtown, MO',20953,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49924,NULL,'Dutchtown, MO 63745',20953,222,NULL,43,28678,0);
INSERT INTO "django_geo_db_location" VALUES(49925,NULL,'Farrar, MO',20954,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49926,NULL,'Farrar, MO 63746',20954,222,NULL,43,28679,0);
INSERT INTO "django_geo_db_location" VALUES(49927,NULL,'Friedheim, MO',20955,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49928,NULL,'Friedheim, MO 63747',20955,222,NULL,43,28680,0);
INSERT INTO "django_geo_db_location" VALUES(49929,NULL,'Frohna, MO',20956,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49930,NULL,'Frohna, MO 63748',20956,222,NULL,43,28681,0);
INSERT INTO "django_geo_db_location" VALUES(49931,NULL,'Gipsy, MO',20957,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49932,NULL,'Gipsy, MO 63750',20957,222,NULL,43,28682,0);
INSERT INTO "django_geo_db_location" VALUES(49933,NULL,'Glenallen, MO',20958,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49934,NULL,'Glenallen, MO 63751',20958,222,NULL,43,28683,0);
INSERT INTO "django_geo_db_location" VALUES(49935,NULL,'Gordonville, MO',20959,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49936,NULL,'Gordonville, MO 63752',20959,222,NULL,43,28684,0);
INSERT INTO "django_geo_db_location" VALUES(49937,NULL,'Grassy, MO',20960,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49938,NULL,'Grassy, MO 63753',20960,222,NULL,43,28685,0);
INSERT INTO "django_geo_db_location" VALUES(49939,NULL,'Jackson, MO',20961,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49940,NULL,'Jackson, MO 63755',20961,222,NULL,43,28686,0);
INSERT INTO "django_geo_db_location" VALUES(49941,NULL,'Kelso, MO',20962,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49942,NULL,'Kelso, MO 63758',20962,222,NULL,43,28687,0);
INSERT INTO "django_geo_db_location" VALUES(49943,NULL,'Leopold, MO',20963,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49944,NULL,'Leopold, MO 63760',20963,222,NULL,43,28688,0);
INSERT INTO "django_geo_db_location" VALUES(49945,NULL,'McGee, MO',20964,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49946,NULL,'McGee, MO 63763',20964,222,NULL,43,28689,0);
INSERT INTO "django_geo_db_location" VALUES(49947,NULL,'Marble Hill, MO',20965,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49948,NULL,'Marble Hill, MO 63764',20965,222,NULL,43,28690,0);
INSERT INTO "django_geo_db_location" VALUES(49949,NULL,'Millersville, MO',20966,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49950,NULL,'Millersville, MO 63766',20966,222,NULL,43,28691,0);
INSERT INTO "django_geo_db_location" VALUES(49951,NULL,'Morley, MO',20967,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49952,NULL,'Morley, MO 63767',20967,222,NULL,43,28692,0);
INSERT INTO "django_geo_db_location" VALUES(49953,NULL,'Oak Ridge, MO',20968,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49954,NULL,'Oak Ridge, MO 63769',20968,222,NULL,43,28693,0);
INSERT INTO "django_geo_db_location" VALUES(49955,NULL,'Old Appleton, MO',20969,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49956,NULL,'Old Appleton, MO 63770',20969,222,NULL,43,28694,0);
INSERT INTO "django_geo_db_location" VALUES(49957,NULL,'Oran, MO',20970,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49958,NULL,'Oran, MO 63771',20970,222,NULL,43,28695,0);
INSERT INTO "django_geo_db_location" VALUES(49959,NULL,'Painton, MO',20971,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49960,NULL,'Painton, MO 63772',20971,222,NULL,43,28696,0);
INSERT INTO "django_geo_db_location" VALUES(49961,NULL,'Perkins, MO',20972,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49962,NULL,'Perkins, MO 63774',20972,222,NULL,43,28697,0);
INSERT INTO "django_geo_db_location" VALUES(49963,NULL,'Perryville, MO 63775',20811,222,NULL,43,28698,0);
INSERT INTO "django_geo_db_location" VALUES(49964,NULL,'McBride, MO',20973,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49965,NULL,'McBride, MO 63776',20973,222,NULL,43,28699,0);
INSERT INTO "django_geo_db_location" VALUES(49966,NULL,'Pocahontas, MO',20974,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49967,NULL,'Pocahontas, MO 63779',20974,222,NULL,43,28700,0);
INSERT INTO "django_geo_db_location" VALUES(49968,NULL,'Scott City, MO',20975,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49969,NULL,'Scott City, MO 63780',20975,222,NULL,43,28701,0);
INSERT INTO "django_geo_db_location" VALUES(49970,NULL,'Sedgewickville, MO',20976,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49971,NULL,'Sedgewickville, MO 63781',20976,222,NULL,43,28702,0);
INSERT INTO "django_geo_db_location" VALUES(49972,NULL,'Sturdivant, MO',20977,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49973,NULL,'Sturdivant, MO 63782',20977,222,NULL,43,28703,0);
INSERT INTO "django_geo_db_location" VALUES(49974,NULL,'Uniontown, MO',20978,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49975,NULL,'Uniontown, MO 63783',20978,222,NULL,43,28704,0);
INSERT INTO "django_geo_db_location" VALUES(49976,NULL,'Vanduser, MO',20979,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49977,NULL,'Vanduser, MO 63784',20979,222,NULL,43,28705,0);
INSERT INTO "django_geo_db_location" VALUES(49978,NULL,'Whitewater, MO',20980,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49979,NULL,'Whitewater, MO 63785',20980,222,NULL,43,28706,0);
INSERT INTO "django_geo_db_location" VALUES(49980,NULL,'Zalma, MO',20981,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49981,NULL,'Zalma, MO 63787',20981,222,NULL,43,28707,0);
INSERT INTO "django_geo_db_location" VALUES(49982,NULL,'Sikeston, MO',20982,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49983,NULL,'Sikeston, MO 63801',20982,222,NULL,43,28708,0);
INSERT INTO "django_geo_db_location" VALUES(49984,NULL,'Blodgett, MO',20983,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49985,NULL,'Blodgett, MO 63804',20983,222,NULL,43,28709,0);
INSERT INTO "django_geo_db_location" VALUES(49986,NULL,'Anniston, MO',20984,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49987,NULL,'Anniston, MO 63820',20984,222,NULL,43,28710,0);
INSERT INTO "django_geo_db_location" VALUES(49988,NULL,'Arbyrd, MO',20985,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49989,NULL,'Arbyrd, MO 63821',20985,222,NULL,43,28711,0);
INSERT INTO "django_geo_db_location" VALUES(49990,NULL,'Bernie, MO',20986,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49991,NULL,'Bernie, MO 63822',20986,222,NULL,43,28712,0);
INSERT INTO "django_geo_db_location" VALUES(49992,NULL,'Bertrand, MO',20987,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49993,NULL,'Bertrand, MO 63823',20987,222,NULL,43,28713,0);
INSERT INTO "django_geo_db_location" VALUES(49994,NULL,'Blodgett, MO 63824',20983,222,NULL,43,28714,0);
INSERT INTO "django_geo_db_location" VALUES(49995,NULL,'Bloomfield, MO',20988,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49996,NULL,'Bloomfield, MO 63825',20988,222,NULL,43,28715,0);
INSERT INTO "django_geo_db_location" VALUES(49997,NULL,'Braggadocio, MO',20989,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(49998,NULL,'Braggadocio, MO 63826',20989,222,NULL,43,28716,0);
INSERT INTO "django_geo_db_location" VALUES(49999,NULL,'Bragg City, MO',20990,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50000,NULL,'Bragg City, MO 63827',20990,222,NULL,43,28717,0);
INSERT INTO "django_geo_db_location" VALUES(50001,NULL,'Canalou, MO',20991,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50002,NULL,'Canalou, MO 63828',20991,222,NULL,43,28718,0);
INSERT INTO "django_geo_db_location" VALUES(50003,NULL,'Cardwell, MO',20992,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50004,NULL,'Cardwell, MO 63829',20992,222,NULL,43,28719,0);
INSERT INTO "django_geo_db_location" VALUES(50005,NULL,'Caruthersville, MO',20993,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50006,NULL,'Caruthersville, MO 63830',20993,222,NULL,43,28720,0);
INSERT INTO "django_geo_db_location" VALUES(50007,NULL,'Wyatt, MO',20994,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50008,NULL,'Wyatt, MO 63832',20994,222,NULL,43,28721,0);
INSERT INTO "django_geo_db_location" VALUES(50009,NULL,'Catron, MO',20995,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50010,NULL,'Catron, MO 63833',20995,222,NULL,43,28722,0);
INSERT INTO "django_geo_db_location" VALUES(50011,NULL,'Charleston, MO',20996,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50012,NULL,'Charleston, MO 63834',20996,222,NULL,43,28723,0);
INSERT INTO "django_geo_db_location" VALUES(50013,NULL,'Clarkton, MO',20997,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50014,NULL,'Clarkton, MO 63837',20997,222,NULL,43,28724,0);
INSERT INTO "django_geo_db_location" VALUES(50015,NULL,'Conran, MO',20998,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50016,NULL,'Conran, MO 63838',20998,222,NULL,43,28725,0);
INSERT INTO "django_geo_db_location" VALUES(50017,NULL,'Cooter, MO',20999,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50018,NULL,'Cooter, MO 63839',20999,222,NULL,43,28726,0);
INSERT INTO "django_geo_db_location" VALUES(50019,NULL,'Deering, MO',21000,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50020,NULL,'Deering, MO 63840',21000,222,NULL,43,28727,0);
INSERT INTO "django_geo_db_location" VALUES(50021,NULL,'Dexter, MO',21001,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50022,NULL,'Dexter, MO 63841',21001,222,NULL,43,28728,0);
INSERT INTO "django_geo_db_location" VALUES(50023,NULL,'East Prairie, MO',21002,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50024,NULL,'East Prairie, MO 63845',21002,222,NULL,43,28729,0);
INSERT INTO "django_geo_db_location" VALUES(50025,NULL,'Essex, MO',21003,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50026,NULL,'Essex, MO 63846',21003,222,NULL,43,28730,0);
INSERT INTO "django_geo_db_location" VALUES(50027,NULL,'Gibson, MO',21004,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50028,NULL,'Gibson, MO 63847',21004,222,NULL,43,28731,0);
INSERT INTO "django_geo_db_location" VALUES(50029,NULL,'Gideon, MO',21005,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50030,NULL,'Gideon, MO 63848',21005,222,NULL,43,28732,0);
INSERT INTO "django_geo_db_location" VALUES(50031,NULL,'Gobler, MO',21006,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50032,NULL,'Gobler, MO 63849',21006,222,NULL,43,28733,0);
INSERT INTO "django_geo_db_location" VALUES(50033,NULL,'Grayridge, MO',21007,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50034,NULL,'Grayridge, MO 63850',21007,222,NULL,43,28734,0);
INSERT INTO "django_geo_db_location" VALUES(50035,NULL,'Hayti, MO',21008,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50036,NULL,'Hayti, MO 63851',21008,222,NULL,43,28735,0);
INSERT INTO "django_geo_db_location" VALUES(50037,NULL,'Holcomb, MO',21009,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50038,NULL,'Holcomb, MO 63852',21009,222,NULL,43,28736,0);
INSERT INTO "django_geo_db_location" VALUES(50039,NULL,'Holland, MO',21010,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50040,NULL,'Holland, MO 63853',21010,222,NULL,43,28737,0);
INSERT INTO "django_geo_db_location" VALUES(50041,NULL,'Hornersville, MO',21011,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50042,NULL,'Hornersville, MO 63855',21011,222,NULL,43,28738,0);
INSERT INTO "django_geo_db_location" VALUES(50043,NULL,'Kennett, MO',21012,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50044,NULL,'Kennett, MO 63857',21012,222,NULL,43,28739,0);
INSERT INTO "django_geo_db_location" VALUES(50045,NULL,'Independence, MO',21013,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50046,NULL,'Independence, MO 63859',21013,222,NULL,43,28740,0);
INSERT INTO "django_geo_db_location" VALUES(50047,NULL,'Kewanee, MO',21014,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50048,NULL,'Kewanee, MO 63860',21014,222,NULL,43,28741,0);
INSERT INTO "django_geo_db_location" VALUES(50049,NULL,'Lilbourn, MO',21015,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50050,NULL,'Lilbourn, MO 63862',21015,222,NULL,43,28742,0);
INSERT INTO "django_geo_db_location" VALUES(50051,NULL,'Malden, MO',21016,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50052,NULL,'Malden, MO 63863',21016,222,NULL,43,28743,0);
INSERT INTO "django_geo_db_location" VALUES(50053,NULL,'Marston, MO',21017,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50054,NULL,'Marston, MO 63866',21017,222,NULL,43,28744,0);
INSERT INTO "django_geo_db_location" VALUES(50055,NULL,'Matthews, MO',21018,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50056,NULL,'Matthews, MO 63867',21018,222,NULL,43,28745,0);
INSERT INTO "django_geo_db_location" VALUES(50057,NULL,'Morehouse, MO',21019,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50058,NULL,'Morehouse, MO 63868',21019,222,NULL,43,28746,0);
INSERT INTO "django_geo_db_location" VALUES(50059,NULL,'New Madrid, MO',21020,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50060,NULL,'New Madrid, MO 63869',21020,222,NULL,43,28747,0);
INSERT INTO "django_geo_db_location" VALUES(50061,NULL,'Parma, MO',21021,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50062,NULL,'Parma, MO 63870',21021,222,NULL,43,28748,0);
INSERT INTO "django_geo_db_location" VALUES(50063,NULL,'Pascola, MO',21022,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50064,NULL,'Pascola, MO 63871',21022,222,NULL,43,28749,0);
INSERT INTO "django_geo_db_location" VALUES(50065,NULL,'Clay, MO 63872',20901,222,NULL,43,28750,0);
INSERT INTO "django_geo_db_location" VALUES(50066,NULL,'Portageville, MO',21023,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50067,NULL,'Portageville, MO 63873',21023,222,NULL,43,28751,0);
INSERT INTO "django_geo_db_location" VALUES(50068,NULL,'Risco, MO',21024,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50069,NULL,'Risco, MO 63874',21024,222,NULL,43,28752,0);
INSERT INTO "django_geo_db_location" VALUES(50070,NULL,'Rives, MO',21025,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50071,NULL,'Rives, MO 63875',21025,222,NULL,43,28753,0);
INSERT INTO "django_geo_db_location" VALUES(50072,NULL,'Senath, MO',21026,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50073,NULL,'Senath, MO 63876',21026,222,NULL,43,28754,0);
INSERT INTO "django_geo_db_location" VALUES(50074,NULL,'Steele, MO',21027,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50075,NULL,'Steele, MO 63877',21027,222,NULL,43,28755,0);
INSERT INTO "django_geo_db_location" VALUES(50076,NULL,'Tallapoosa, MO',21028,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50077,NULL,'Tallapoosa, MO 63878',21028,222,NULL,43,28756,0);
INSERT INTO "django_geo_db_location" VALUES(50078,NULL,'Wardell, MO',21029,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50079,NULL,'Wardell, MO 63879',21029,222,NULL,43,28757,0);
INSERT INTO "django_geo_db_location" VALUES(50080,NULL,'Whiteoak, MO',21030,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50081,NULL,'Whiteoak, MO 63880',21030,222,NULL,43,28758,0);
INSERT INTO "django_geo_db_location" VALUES(50082,NULL,'Wolf Island, MO',21031,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50083,NULL,'Wolf Island, MO 63881',21031,222,NULL,43,28759,0);
INSERT INTO "django_geo_db_location" VALUES(50084,NULL,'Wyatt, MO 63882',20994,222,NULL,43,28760,0);
INSERT INTO "django_geo_db_location" VALUES(50085,NULL,'Poplar Bluff, MO',21032,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50086,NULL,'Poplar Bluff, MO 63901',21032,222,NULL,43,28761,0);
INSERT INTO "django_geo_db_location" VALUES(50087,NULL,'Poplar Bluff, MO 63902',21032,222,NULL,43,28762,0);
INSERT INTO "django_geo_db_location" VALUES(50088,NULL,'Briar, MO',21033,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50089,NULL,'Briar, MO 63931',21033,222,NULL,43,28763,0);
INSERT INTO "django_geo_db_location" VALUES(50090,NULL,'Broseley, MO',21034,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50091,NULL,'Broseley, MO 63932',21034,222,NULL,43,28764,0);
INSERT INTO "django_geo_db_location" VALUES(50092,NULL,'Campbell, MO',21035,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50093,NULL,'Campbell, MO 63933',21035,222,NULL,43,28765,0);
INSERT INTO "django_geo_db_location" VALUES(50094,NULL,'Clubb, MO',21036,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50095,NULL,'Clubb, MO 63934',21036,222,NULL,43,28766,0);
INSERT INTO "django_geo_db_location" VALUES(50096,NULL,'Doniphan, MO',21037,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50097,NULL,'Doniphan, MO 63935',21037,222,NULL,43,28767,0);
INSERT INTO "django_geo_db_location" VALUES(50098,NULL,'Dudley, MO',21038,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50099,NULL,'Dudley, MO 63936',21038,222,NULL,43,28768,0);
INSERT INTO "django_geo_db_location" VALUES(50100,NULL,'Ellsinore, MO',21039,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50101,NULL,'Ellsinore, MO 63937',21039,222,NULL,43,28769,0);
INSERT INTO "django_geo_db_location" VALUES(50102,NULL,'Fagus, MO',21040,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50103,NULL,'Fagus, MO 63938',21040,222,NULL,43,28770,0);
INSERT INTO "django_geo_db_location" VALUES(50104,NULL,'Fairdealing, MO',21041,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50105,NULL,'Fairdealing, MO 63939',21041,222,NULL,43,28771,0);
INSERT INTO "django_geo_db_location" VALUES(50106,NULL,'Fisk, MO',21042,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50107,NULL,'Fisk, MO 63940',21042,222,NULL,43,28772,0);
INSERT INTO "django_geo_db_location" VALUES(50108,NULL,'Fremont, MO',21043,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50109,NULL,'Fremont, MO 63941',21043,222,NULL,43,28773,0);
INSERT INTO "django_geo_db_location" VALUES(50110,NULL,'Gatewood, MO',21044,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50111,NULL,'Gatewood, MO 63942',21044,222,NULL,43,28774,0);
INSERT INTO "django_geo_db_location" VALUES(50112,NULL,'Grandin, MO',21045,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50113,NULL,'Grandin, MO 63943',21045,222,NULL,43,28775,0);
INSERT INTO "django_geo_db_location" VALUES(50114,NULL,'Greenville, MO',21046,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50115,NULL,'Greenville, MO 63944',21046,222,NULL,43,28776,0);
INSERT INTO "django_geo_db_location" VALUES(50116,NULL,'Harviell, MO',21047,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50117,NULL,'Harviell, MO 63945',21047,222,NULL,43,28777,0);
INSERT INTO "django_geo_db_location" VALUES(50118,NULL,'Hiram, MO',21048,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50119,NULL,'Hiram, MO 63947',21048,222,NULL,43,28778,0);
INSERT INTO "django_geo_db_location" VALUES(50120,NULL,'Lodi, MO',21049,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50121,NULL,'Lodi, MO 63950',21049,222,NULL,43,28779,0);
INSERT INTO "django_geo_db_location" VALUES(50122,NULL,'Lowndes, MO',21050,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50123,NULL,'Lowndes, MO 63951',21050,222,NULL,43,28780,0);
INSERT INTO "django_geo_db_location" VALUES(50124,NULL,'Mill Spring, MO',21051,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50125,NULL,'Mill Spring, MO 63952',21051,222,NULL,43,28781,0);
INSERT INTO "django_geo_db_location" VALUES(50126,NULL,'Naylor, MO',21052,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50127,NULL,'Naylor, MO 63953',21052,222,NULL,43,28782,0);
INSERT INTO "django_geo_db_location" VALUES(50128,NULL,'Neelyville, MO',21053,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50129,NULL,'Neelyville, MO 63954',21053,222,NULL,43,28783,0);
INSERT INTO "django_geo_db_location" VALUES(50130,NULL,'Oxly, MO',21054,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50131,NULL,'Oxly, MO 63955',21054,222,NULL,43,28784,0);
INSERT INTO "django_geo_db_location" VALUES(50132,NULL,'Patterson, MO',21055,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50133,NULL,'Patterson, MO 63956',21055,222,NULL,43,28785,0);
INSERT INTO "django_geo_db_location" VALUES(50134,NULL,'Piedmont, MO',21056,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50135,NULL,'Piedmont, MO 63957',21056,222,NULL,43,28786,0);
INSERT INTO "django_geo_db_location" VALUES(50136,NULL,'Puxico, MO',21057,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50137,NULL,'Puxico, MO 63960',21057,222,NULL,43,28787,0);
INSERT INTO "django_geo_db_location" VALUES(50138,NULL,'Qulin, MO',21058,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50139,NULL,'Qulin, MO 63961',21058,222,NULL,43,28788,0);
INSERT INTO "django_geo_db_location" VALUES(50140,NULL,'Rombauer, MO',21059,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50141,NULL,'Rombauer, MO 63962',21059,222,NULL,43,28789,0);
INSERT INTO "django_geo_db_location" VALUES(50142,NULL,'Shook, MO',21060,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50143,NULL,'Shook, MO 63963',21060,222,NULL,43,28790,0);
INSERT INTO "django_geo_db_location" VALUES(50144,NULL,'Silva, MO',21061,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50145,NULL,'Silva, MO 63964',21061,222,NULL,43,28791,0);
INSERT INTO "django_geo_db_location" VALUES(50146,NULL,'Van Buren, MO',21062,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50147,NULL,'Van Buren, MO 63965',21062,222,NULL,43,28792,0);
INSERT INTO "django_geo_db_location" VALUES(50148,NULL,'Wappapello, MO',21063,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50149,NULL,'Wappapello, MO 63966',21063,222,NULL,43,28793,0);
INSERT INTO "django_geo_db_location" VALUES(50150,NULL,'Williamsville, MO',21064,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50151,NULL,'Williamsville, MO 63967',21064,222,NULL,43,28794,0);
INSERT INTO "django_geo_db_location" VALUES(50152,NULL,'Alma, MO',21065,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50153,NULL,'Alma, MO 64001',21065,222,NULL,43,28795,0);
INSERT INTO "django_geo_db_location" VALUES(50154,NULL,'Bates City, MO',21066,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50155,NULL,'Bates City, MO 64011',21066,222,NULL,43,28796,0);
INSERT INTO "django_geo_db_location" VALUES(50156,NULL,'Belton, MO',21067,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50157,NULL,'Belton, MO 64012',21067,222,NULL,43,28797,0);
INSERT INTO "django_geo_db_location" VALUES(50158,NULL,'Blue Springs, MO',21068,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50159,NULL,'Blue Springs, MO 64013',21068,222,NULL,43,28798,0);
INSERT INTO "django_geo_db_location" VALUES(50160,NULL,'Blue Springs, MO 64014',21068,222,NULL,43,28799,0);
INSERT INTO "django_geo_db_location" VALUES(50161,NULL,'Blue Springs, MO 64015',21068,222,NULL,43,28800,0);
INSERT INTO "django_geo_db_location" VALUES(50162,NULL,'Buckner, MO',21069,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50163,NULL,'Buckner, MO 64016',21069,222,NULL,43,28801,0);
INSERT INTO "django_geo_db_location" VALUES(50164,NULL,'Camden, MO',21070,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50165,NULL,'Camden, MO 64017',21070,222,NULL,43,28802,0);
INSERT INTO "django_geo_db_location" VALUES(50166,NULL,'Camden Point, MO',21071,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50167,NULL,'Camden Point, MO 64018',21071,222,NULL,43,28803,0);
INSERT INTO "django_geo_db_location" VALUES(50168,NULL,'Centerview, MO',21072,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50169,NULL,'Centerview, MO 64019',21072,222,NULL,43,28804,0);
INSERT INTO "django_geo_db_location" VALUES(50170,NULL,'Concordia, MO',21073,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50171,NULL,'Concordia, MO 64020',21073,222,NULL,43,28805,0);
INSERT INTO "django_geo_db_location" VALUES(50172,NULL,'Corder, MO',21074,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50173,NULL,'Corder, MO 64021',21074,222,NULL,43,28806,0);
INSERT INTO "django_geo_db_location" VALUES(50174,NULL,'Dover, MO',21075,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50175,NULL,'Dover, MO 64022',21075,222,NULL,43,28807,0);
INSERT INTO "django_geo_db_location" VALUES(50176,NULL,'Excelsior Springs, MO',21076,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50177,NULL,'Excelsior Springs, MO 64024',21076,222,NULL,43,28808,0);
INSERT INTO "django_geo_db_location" VALUES(50178,NULL,'Farley, MO',21077,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50179,NULL,'Farley, MO 64028',21077,222,NULL,43,28809,0);
INSERT INTO "django_geo_db_location" VALUES(50180,NULL,'Grain Valley, MO',21078,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50181,NULL,'Grain Valley, MO 64029',21078,222,NULL,43,28810,0);
INSERT INTO "django_geo_db_location" VALUES(50182,NULL,'Grandview, MO',21079,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50183,NULL,'Grandview, MO 64030',21079,222,NULL,43,28811,0);
INSERT INTO "django_geo_db_location" VALUES(50184,NULL,'Greenwood, MO',21080,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50185,NULL,'Greenwood, MO 64034',21080,222,NULL,43,28812,0);
INSERT INTO "django_geo_db_location" VALUES(50186,NULL,'Hardin, MO',21081,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50187,NULL,'Hardin, MO 64035',21081,222,NULL,43,28813,0);
INSERT INTO "django_geo_db_location" VALUES(50188,NULL,'Henrietta, MO',21082,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50189,NULL,'Henrietta, MO 64036',21082,222,NULL,43,28814,0);
INSERT INTO "django_geo_db_location" VALUES(50190,NULL,'Higginsville, MO',21083,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50191,NULL,'Higginsville, MO 64037',21083,222,NULL,43,28815,0);
INSERT INTO "django_geo_db_location" VALUES(50192,NULL,'Holden, MO',21084,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50193,NULL,'Holden, MO 64040',21084,222,NULL,43,28816,0);
INSERT INTO "django_geo_db_location" VALUES(50194,NULL,'Holt, MO',21085,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50195,NULL,'Holt, MO 64048',21085,222,NULL,43,28817,0);
INSERT INTO "django_geo_db_location" VALUES(50196,NULL,'Independence, MO 64050',21013,222,NULL,43,28818,0);
INSERT INTO "django_geo_db_location" VALUES(50197,NULL,'Independence, MO 64051',21013,222,NULL,43,28819,0);
INSERT INTO "django_geo_db_location" VALUES(50198,NULL,'Independence, MO 64052',21013,222,NULL,43,28820,0);
INSERT INTO "django_geo_db_location" VALUES(50199,NULL,'Independence, MO 64053',21013,222,NULL,43,28821,0);
INSERT INTO "django_geo_db_location" VALUES(50200,NULL,'Independence, MO 64054',21013,222,NULL,43,28822,0);
INSERT INTO "django_geo_db_location" VALUES(50201,NULL,'Independence, MO 64055',21013,222,NULL,43,28823,0);
INSERT INTO "django_geo_db_location" VALUES(50202,NULL,'Independence, MO 64056',21013,222,NULL,43,28824,0);
INSERT INTO "django_geo_db_location" VALUES(50203,NULL,'Independence, MO 64057',21013,222,NULL,43,28825,0);
INSERT INTO "django_geo_db_location" VALUES(50204,NULL,'Independence, MO 64058',21013,222,NULL,43,28826,0);
INSERT INTO "django_geo_db_location" VALUES(50205,NULL,'Kearney, MO',21086,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50206,NULL,'Kearney, MO 64060',21086,222,NULL,43,28827,0);
INSERT INTO "django_geo_db_location" VALUES(50207,NULL,'Kingsville, MO',21087,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50208,NULL,'Kingsville, MO 64061',21087,222,NULL,43,28828,0);
INSERT INTO "django_geo_db_location" VALUES(50209,NULL,'Lawson, MO',21088,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50210,NULL,'Lawson, MO 64062',21088,222,NULL,43,28829,0);
INSERT INTO "django_geo_db_location" VALUES(50211,NULL,'Lees Summit, MO',21089,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50212,NULL,'Lees Summit, MO 64063',21089,222,NULL,43,28830,0);
INSERT INTO "django_geo_db_location" VALUES(50213,NULL,'Lees Summit, MO 64064',21089,222,NULL,43,28831,0);
INSERT INTO "django_geo_db_location" VALUES(50214,NULL,'Lees Summit, MO 64065',21089,222,NULL,43,28832,0);
INSERT INTO "django_geo_db_location" VALUES(50215,NULL,'Levasy, MO',21090,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50216,NULL,'Levasy, MO 64066',21090,222,NULL,43,28833,0);
INSERT INTO "django_geo_db_location" VALUES(50217,NULL,'Lexington, MO',21091,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50218,NULL,'Lexington, MO 64067',21091,222,NULL,43,28834,0);
INSERT INTO "django_geo_db_location" VALUES(50219,NULL,'Liberty, MO',21092,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50220,NULL,'Liberty, MO 64068',21092,222,NULL,43,28835,0);
INSERT INTO "django_geo_db_location" VALUES(50221,NULL,'Liberty, MO 64069',21092,222,NULL,43,28836,0);
INSERT INTO "django_geo_db_location" VALUES(50222,NULL,'Lone Jack, MO',21093,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50223,NULL,'Lone Jack, MO 64070',21093,222,NULL,43,28837,0);
INSERT INTO "django_geo_db_location" VALUES(50224,NULL,'Mayview, MO',21094,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50225,NULL,'Mayview, MO 64071',21094,222,NULL,43,28838,0);
INSERT INTO "django_geo_db_location" VALUES(50226,NULL,'Missouri City, MO',21095,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50227,NULL,'Missouri City, MO 64072',21095,222,NULL,43,28839,0);
INSERT INTO "django_geo_db_location" VALUES(50228,NULL,'Mosby, MO',21096,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50229,NULL,'Mosby, MO 64073',21096,222,NULL,43,28840,0);
INSERT INTO "django_geo_db_location" VALUES(50230,NULL,'Napoleon, MO',21097,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50231,NULL,'Napoleon, MO 64074',21097,222,NULL,43,28841,0);
INSERT INTO "django_geo_db_location" VALUES(50232,NULL,'Oak Grove, MO',21098,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50233,NULL,'Oak Grove, MO 64075',21098,222,NULL,43,28842,0);
INSERT INTO "django_geo_db_location" VALUES(50234,NULL,'Odessa, MO',21099,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50235,NULL,'Odessa, MO 64076',21099,222,NULL,43,28843,0);
INSERT INTO "django_geo_db_location" VALUES(50236,NULL,'Orrick, MO',21100,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50237,NULL,'Orrick, MO 64077',21100,222,NULL,43,28844,0);
INSERT INTO "django_geo_db_location" VALUES(50238,NULL,'Peculiar, MO',21101,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50239,NULL,'Peculiar, MO 64078',21101,222,NULL,43,28845,0);
INSERT INTO "django_geo_db_location" VALUES(50240,NULL,'Platte City, MO',21102,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50241,NULL,'Platte City, MO 64079',21102,222,NULL,43,28846,0);
INSERT INTO "django_geo_db_location" VALUES(50242,NULL,'Pleasant Hill, MO',21103,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50243,NULL,'Pleasant Hill, MO 64080',21103,222,NULL,43,28847,0);
INSERT INTO "django_geo_db_location" VALUES(50244,NULL,'Lees Summit, MO 64081',21089,222,NULL,43,28848,0);
INSERT INTO "django_geo_db_location" VALUES(50245,NULL,'Lees Summit, MO 64082',21089,222,NULL,43,28849,0);
INSERT INTO "django_geo_db_location" VALUES(50246,NULL,'Raymore, MO',21104,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50247,NULL,'Raymore, MO 64083',21104,222,NULL,43,28850,0);
INSERT INTO "django_geo_db_location" VALUES(50248,NULL,'Rayville, MO',21105,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50249,NULL,'Rayville, MO 64084',21105,222,NULL,43,28851,0);
INSERT INTO "django_geo_db_location" VALUES(50250,NULL,'Richmond, MO',21106,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50251,NULL,'Richmond, MO 64085',21106,222,NULL,43,28852,0);
INSERT INTO "django_geo_db_location" VALUES(50252,NULL,'Lees Summit, MO 64086',21089,222,NULL,43,28853,0);
INSERT INTO "django_geo_db_location" VALUES(50253,NULL,'Liberty, MO 64087',21092,222,NULL,43,28854,0);
INSERT INTO "django_geo_db_location" VALUES(50254,NULL,'Sibley, MO',21107,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50255,NULL,'Sibley, MO 64088',21107,222,NULL,43,28855,0);
INSERT INTO "django_geo_db_location" VALUES(50256,NULL,'Smithville, MO',21108,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50257,NULL,'Smithville, MO 64089',21108,222,NULL,43,28856,0);
INSERT INTO "django_geo_db_location" VALUES(50258,NULL,'Strasburg, MO',21109,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50259,NULL,'Strasburg, MO 64090',21109,222,NULL,43,28857,0);
INSERT INTO "django_geo_db_location" VALUES(50260,NULL,'Waldron, MO',21110,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50261,NULL,'Waldron, MO 64092',21110,222,NULL,43,28858,0);
INSERT INTO "django_geo_db_location" VALUES(50262,NULL,'Warrensburg, MO',21111,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50263,NULL,'Warrensburg, MO 64093',21111,222,NULL,43,28859,0);
INSERT INTO "django_geo_db_location" VALUES(50264,NULL,'Waverly, MO',21112,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50265,NULL,'Waverly, MO 64096',21112,222,NULL,43,28860,0);
INSERT INTO "django_geo_db_location" VALUES(50266,NULL,'Wellington, MO',21113,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50267,NULL,'Wellington, MO 64097',21113,222,NULL,43,28861,0);
INSERT INTO "django_geo_db_location" VALUES(50268,NULL,'Weston, MO',21114,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50269,NULL,'Weston, MO 64098',21114,222,NULL,43,28862,0);
INSERT INTO "django_geo_db_location" VALUES(50270,NULL,'Kansas City, MO',21115,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50271,NULL,'Kansas City, MO 64101',21115,222,NULL,43,28863,0);
INSERT INTO "django_geo_db_location" VALUES(50272,NULL,'Kansas City, MO 64102',21115,222,NULL,43,28864,0);
INSERT INTO "django_geo_db_location" VALUES(50273,NULL,'Kansas City, MO 64105',21115,222,NULL,43,28865,0);
INSERT INTO "django_geo_db_location" VALUES(50274,NULL,'Kansas City, MO 64106',21115,222,NULL,43,28866,0);
INSERT INTO "django_geo_db_location" VALUES(50275,NULL,'Kansas City, MO 64108',21115,222,NULL,43,28867,0);
INSERT INTO "django_geo_db_location" VALUES(50276,NULL,'Kansas City, MO 64109',21115,222,NULL,43,28868,0);
INSERT INTO "django_geo_db_location" VALUES(50277,NULL,'Kansas City, MO 64110',21115,222,NULL,43,28869,0);
INSERT INTO "django_geo_db_location" VALUES(50278,NULL,'Kansas City, MO 64111',21115,222,NULL,43,28870,0);
INSERT INTO "django_geo_db_location" VALUES(50279,NULL,'Kansas City, MO 64112',21115,222,NULL,43,28871,0);
INSERT INTO "django_geo_db_location" VALUES(50280,NULL,'Kansas City, MO 64113',21115,222,NULL,43,28872,0);
INSERT INTO "django_geo_db_location" VALUES(50281,NULL,'Kansas City, MO 64114',21115,222,NULL,43,28873,0);
INSERT INTO "django_geo_db_location" VALUES(50282,NULL,'Kansas City, MO 64116',21115,222,NULL,43,28874,0);
INSERT INTO "django_geo_db_location" VALUES(50283,NULL,'Kansas City, MO 64117',21115,222,NULL,43,28875,0);
INSERT INTO "django_geo_db_location" VALUES(50284,NULL,'Kansas City, MO 64118',21115,222,NULL,43,28876,0);
INSERT INTO "django_geo_db_location" VALUES(50285,NULL,'Kansas City, MO 64119',21115,222,NULL,43,28877,0);
INSERT INTO "django_geo_db_location" VALUES(50286,NULL,'Kansas City, MO 64120',21115,222,NULL,43,28878,0);
INSERT INTO "django_geo_db_location" VALUES(50287,NULL,'Kansas City, MO 64121',21115,222,NULL,43,28879,0);
INSERT INTO "django_geo_db_location" VALUES(50288,NULL,'Kansas City, MO 64123',21115,222,NULL,43,28880,0);
INSERT INTO "django_geo_db_location" VALUES(50289,NULL,'Kansas City, MO 64124',21115,222,NULL,43,28881,0);
INSERT INTO "django_geo_db_location" VALUES(50290,NULL,'Kansas City, MO 64125',21115,222,NULL,43,28882,0);
INSERT INTO "django_geo_db_location" VALUES(50291,NULL,'Kansas City, MO 64126',21115,222,NULL,43,28883,0);
INSERT INTO "django_geo_db_location" VALUES(50292,NULL,'Kansas City, MO 64127',21115,222,NULL,43,28884,0);
INSERT INTO "django_geo_db_location" VALUES(50293,NULL,'Kansas City, MO 64128',21115,222,NULL,43,28885,0);
INSERT INTO "django_geo_db_location" VALUES(50294,NULL,'Kansas City, MO 64129',21115,222,NULL,43,28886,0);
INSERT INTO "django_geo_db_location" VALUES(50295,NULL,'Kansas City, MO 64130',21115,222,NULL,43,28887,0);
INSERT INTO "django_geo_db_location" VALUES(50296,NULL,'Kansas City, MO 64131',21115,222,NULL,43,28888,0);
INSERT INTO "django_geo_db_location" VALUES(50297,NULL,'Kansas City, MO 64132',21115,222,NULL,43,28889,0);
INSERT INTO "django_geo_db_location" VALUES(50298,NULL,'Kansas City, MO 64133',21115,222,NULL,43,28890,0);
INSERT INTO "django_geo_db_location" VALUES(50299,NULL,'Kansas City, MO 64134',21115,222,NULL,43,28891,0);
INSERT INTO "django_geo_db_location" VALUES(50300,NULL,'Kansas City, MO 64136',21115,222,NULL,43,28892,0);
INSERT INTO "django_geo_db_location" VALUES(50301,NULL,'Kansas City, MO 64137',21115,222,NULL,43,28893,0);
INSERT INTO "django_geo_db_location" VALUES(50302,NULL,'Kansas City, MO 64138',21115,222,NULL,43,28894,0);
INSERT INTO "django_geo_db_location" VALUES(50303,NULL,'Kansas City, MO 64139',21115,222,NULL,43,28895,0);
INSERT INTO "django_geo_db_location" VALUES(50304,NULL,'Kansas City, MO 64141',21115,222,NULL,43,28896,0);
INSERT INTO "django_geo_db_location" VALUES(50305,NULL,'Kansas City, MO 64142',21115,222,NULL,43,28897,0);
INSERT INTO "django_geo_db_location" VALUES(50306,NULL,'Kansas City, MO 64144',21115,222,NULL,43,28898,0);
INSERT INTO "django_geo_db_location" VALUES(50307,NULL,'Kansas City, MO 64145',21115,222,NULL,43,28899,0);
INSERT INTO "django_geo_db_location" VALUES(50308,NULL,'Kansas City, MO 64146',21115,222,NULL,43,28900,0);
INSERT INTO "django_geo_db_location" VALUES(50309,NULL,'Kansas City, MO 64147',21115,222,NULL,43,28901,0);
INSERT INTO "django_geo_db_location" VALUES(50310,NULL,'Kansas City, MO 64148',21115,222,NULL,43,28902,0);
INSERT INTO "django_geo_db_location" VALUES(50311,NULL,'Kansas City, MO 64149',21115,222,NULL,43,28903,0);
INSERT INTO "django_geo_db_location" VALUES(50312,NULL,'Riverside, MO',21116,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50313,NULL,'Riverside, MO 64150',21116,222,NULL,43,28904,0);
INSERT INTO "django_geo_db_location" VALUES(50314,NULL,'Kansas City, MO 64151',21115,222,NULL,43,28905,0);
INSERT INTO "django_geo_db_location" VALUES(50315,NULL,'Kansas City, MO 64152',21115,222,NULL,43,28906,0);
INSERT INTO "django_geo_db_location" VALUES(50316,NULL,'Kansas City, MO 64153',21115,222,NULL,43,28907,0);
INSERT INTO "django_geo_db_location" VALUES(50317,NULL,'Kansas City, MO 64154',21115,222,NULL,43,28908,0);
INSERT INTO "django_geo_db_location" VALUES(50318,NULL,'Kansas City, MO 64155',21115,222,NULL,43,28909,0);
INSERT INTO "django_geo_db_location" VALUES(50319,NULL,'Kansas City, MO 64156',21115,222,NULL,43,28910,0);
INSERT INTO "django_geo_db_location" VALUES(50320,NULL,'Kansas City, MO 64157',21115,222,NULL,43,28911,0);
INSERT INTO "django_geo_db_location" VALUES(50321,NULL,'Kansas City, MO 64158',21115,222,NULL,43,28912,0);
INSERT INTO "django_geo_db_location" VALUES(50322,NULL,'Kansas City, MO 64160',21115,222,NULL,43,28913,0);
INSERT INTO "django_geo_db_location" VALUES(50323,NULL,'Kansas City, MO 64161',21115,222,NULL,43,28914,0);
INSERT INTO "django_geo_db_location" VALUES(50324,NULL,'Kansas City, MO 64163',21115,222,NULL,43,28915,0);
INSERT INTO "django_geo_db_location" VALUES(50325,NULL,'Kansas City, MO 64164',21115,222,NULL,43,28916,0);
INSERT INTO "django_geo_db_location" VALUES(50326,NULL,'Kansas City, MO 64165',21115,222,NULL,43,28917,0);
INSERT INTO "django_geo_db_location" VALUES(50327,NULL,'Kansas City, MO 64166',21115,222,NULL,43,28918,0);
INSERT INTO "django_geo_db_location" VALUES(50328,NULL,'Kansas City, MO 64167',21115,222,NULL,43,28919,0);
INSERT INTO "django_geo_db_location" VALUES(50329,NULL,'Kansas City, MO 64168',21115,222,NULL,43,28920,0);
INSERT INTO "django_geo_db_location" VALUES(50330,NULL,'Kansas City, MO 64170',21115,222,NULL,43,28921,0);
INSERT INTO "django_geo_db_location" VALUES(50331,NULL,'Kansas City, MO 64171',21115,222,NULL,43,28922,0);
INSERT INTO "django_geo_db_location" VALUES(50332,NULL,'Kansas City, MO 64172',21115,222,NULL,43,28923,0);
INSERT INTO "django_geo_db_location" VALUES(50333,NULL,'Kansas City, MO 64173',21115,222,NULL,43,28924,0);
INSERT INTO "django_geo_db_location" VALUES(50334,NULL,'Kansas City, MO 64179',21115,222,NULL,43,28925,0);
INSERT INTO "django_geo_db_location" VALUES(50335,NULL,'Kansas City, MO 64180',21115,222,NULL,43,28926,0);
INSERT INTO "django_geo_db_location" VALUES(50336,NULL,'Kansas City, MO 64183',21115,222,NULL,43,28927,0);
INSERT INTO "django_geo_db_location" VALUES(50337,NULL,'Kansas City, MO 64184',21115,222,NULL,43,28928,0);
INSERT INTO "django_geo_db_location" VALUES(50338,NULL,'Kansas City, MO 64185',21115,222,NULL,43,28929,0);
INSERT INTO "django_geo_db_location" VALUES(50339,NULL,'Kansas City, MO 64187',21115,222,NULL,43,28930,0);
INSERT INTO "django_geo_db_location" VALUES(50340,NULL,'Kansas City, MO 64188',21115,222,NULL,43,28931,0);
INSERT INTO "django_geo_db_location" VALUES(50341,NULL,'Kansas City, MO 64189',21115,222,NULL,43,28932,0);
INSERT INTO "django_geo_db_location" VALUES(50342,NULL,'Kansas City, MO 64190',21115,222,NULL,43,28933,0);
INSERT INTO "django_geo_db_location" VALUES(50343,NULL,'Kansas City, MO 64191',21115,222,NULL,43,28934,0);
INSERT INTO "django_geo_db_location" VALUES(50344,NULL,'Kansas City, MO 64192',21115,222,NULL,43,28935,0);
INSERT INTO "django_geo_db_location" VALUES(50345,NULL,'Kansas City, MO 64193',21115,222,NULL,43,28936,0);
INSERT INTO "django_geo_db_location" VALUES(50346,NULL,'Kansas City, MO 64194',21115,222,NULL,43,28937,0);
INSERT INTO "django_geo_db_location" VALUES(50347,NULL,'Kansas City, MO 64195',21115,222,NULL,43,28938,0);
INSERT INTO "django_geo_db_location" VALUES(50348,NULL,'Kansas City, MO 64196',21115,222,NULL,43,28939,0);
INSERT INTO "django_geo_db_location" VALUES(50349,NULL,'Kansas City, MO 64197',21115,222,NULL,43,28940,0);
INSERT INTO "django_geo_db_location" VALUES(50350,NULL,'Kansas City, MO 64198',21115,222,NULL,43,28941,0);
INSERT INTO "django_geo_db_location" VALUES(50351,NULL,'Kansas City, MO 64199',21115,222,NULL,43,28942,0);
INSERT INTO "django_geo_db_location" VALUES(50352,NULL,'Agency, MO',21117,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50353,NULL,'Agency, MO 64401',21117,222,NULL,43,28943,0);
INSERT INTO "django_geo_db_location" VALUES(50354,NULL,'Albany, MO',21118,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50355,NULL,'Albany, MO 64402',21118,222,NULL,43,28944,0);
INSERT INTO "django_geo_db_location" VALUES(50356,NULL,'Allendale, MO',21119,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50357,NULL,'Allendale, MO 64420',21119,222,NULL,43,28945,0);
INSERT INTO "django_geo_db_location" VALUES(50358,NULL,'Amazonia, MO',21120,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50359,NULL,'Amazonia, MO 64421',21120,222,NULL,43,28946,0);
INSERT INTO "django_geo_db_location" VALUES(50360,NULL,'Amity, MO',21121,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50361,NULL,'Amity, MO 64422',21121,222,NULL,43,28947,0);
INSERT INTO "django_geo_db_location" VALUES(50362,NULL,'Barnard, MO',21122,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50363,NULL,'Barnard, MO 64423',21122,222,NULL,43,28948,0);
INSERT INTO "django_geo_db_location" VALUES(50364,NULL,'Bethany, MO',21123,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50365,NULL,'Bethany, MO 64424',21123,222,NULL,43,28949,0);
INSERT INTO "django_geo_db_location" VALUES(50366,NULL,'Blythedale, MO',21124,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50367,NULL,'Blythedale, MO 64426',21124,222,NULL,43,28950,0);
INSERT INTO "django_geo_db_location" VALUES(50368,NULL,'Bolckow, MO',21125,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50369,NULL,'Bolckow, MO 64427',21125,222,NULL,43,28951,0);
INSERT INTO "django_geo_db_location" VALUES(50370,NULL,'Burlington Junction, MO',21126,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50371,NULL,'Burlington Junction, MO 64428',21126,222,NULL,43,28952,0);
INSERT INTO "django_geo_db_location" VALUES(50372,NULL,'Cameron, MO',21127,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50373,NULL,'Cameron, MO 64429',21127,222,NULL,43,28953,0);
INSERT INTO "django_geo_db_location" VALUES(50374,NULL,'Clarksdale, MO',21128,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50375,NULL,'Clarksdale, MO 64430',21128,222,NULL,43,28954,0);
INSERT INTO "django_geo_db_location" VALUES(50376,NULL,'Clearmont, MO',21129,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50377,NULL,'Clearmont, MO 64431',21129,222,NULL,43,28955,0);
INSERT INTO "django_geo_db_location" VALUES(50378,NULL,'Clyde, MO',21130,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50379,NULL,'Clyde, MO 64432',21130,222,NULL,43,28956,0);
INSERT INTO "django_geo_db_location" VALUES(50380,NULL,'Conception, MO',21131,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50381,NULL,'Conception, MO 64433',21131,222,NULL,43,28957,0);
INSERT INTO "django_geo_db_location" VALUES(50382,NULL,'Conception Junction, MO',21132,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50383,NULL,'Conception Junction, MO 64434',21132,222,NULL,43,28958,0);
INSERT INTO "django_geo_db_location" VALUES(50384,NULL,'Cosby, MO',21133,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50385,NULL,'Cosby, MO 64436',21133,222,NULL,43,28959,0);
INSERT INTO "django_geo_db_location" VALUES(50386,NULL,'Craig, MO',21134,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50387,NULL,'Craig, MO 64437',21134,222,NULL,43,28960,0);
INSERT INTO "django_geo_db_location" VALUES(50388,NULL,'Darlington, MO',21135,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50389,NULL,'Darlington, MO 64438',21135,222,NULL,43,28961,0);
INSERT INTO "django_geo_db_location" VALUES(50390,NULL,'Dearborn, MO',21136,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50391,NULL,'Dearborn, MO 64439',21136,222,NULL,43,28962,0);
INSERT INTO "django_geo_db_location" VALUES(50392,NULL,'De Kalb, MO',21137,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50393,NULL,'De Kalb, MO 64440',21137,222,NULL,43,28963,0);
INSERT INTO "django_geo_db_location" VALUES(50394,NULL,'Denver, MO',21138,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50395,NULL,'Denver, MO 64441',21138,222,NULL,43,28964,0);
INSERT INTO "django_geo_db_location" VALUES(50396,NULL,'Eagleville, MO',21139,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50397,NULL,'Eagleville, MO 64442',21139,222,NULL,43,28965,0);
INSERT INTO "django_geo_db_location" VALUES(50398,NULL,'Easton, MO',21140,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50399,NULL,'Easton, MO 64443',21140,222,NULL,43,28966,0);
INSERT INTO "django_geo_db_location" VALUES(50400,NULL,'Edgerton, MO',21141,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50401,NULL,'Edgerton, MO 64444',21141,222,NULL,43,28967,0);
INSERT INTO "django_geo_db_location" VALUES(50402,NULL,'Elmo, MO',21142,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50403,NULL,'Elmo, MO 64445',21142,222,NULL,43,28968,0);
INSERT INTO "django_geo_db_location" VALUES(50404,NULL,'Fairfax, MO',21143,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50405,NULL,'Fairfax, MO 64446',21143,222,NULL,43,28969,0);
INSERT INTO "django_geo_db_location" VALUES(50406,NULL,'Fairport, MO',21144,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50407,NULL,'Fairport, MO 64447',21144,222,NULL,43,28970,0);
INSERT INTO "django_geo_db_location" VALUES(50408,NULL,'Faucett, MO',21145,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50409,NULL,'Faucett, MO 64448',21145,222,NULL,43,28971,0);
INSERT INTO "django_geo_db_location" VALUES(50410,NULL,'Fillmore, MO',21146,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50411,NULL,'Fillmore, MO 64449',21146,222,NULL,43,28972,0);
INSERT INTO "django_geo_db_location" VALUES(50412,NULL,'Forest City, MO',21147,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50413,NULL,'Forest City, MO 64451',21147,222,NULL,43,28973,0);
INSERT INTO "django_geo_db_location" VALUES(50414,NULL,'Gentry, MO',21148,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50415,NULL,'Gentry, MO 64453',21148,222,NULL,43,28974,0);
INSERT INTO "django_geo_db_location" VALUES(50416,NULL,'Gower, MO',21149,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50417,NULL,'Gower, MO 64454',21149,222,NULL,43,28975,0);
INSERT INTO "django_geo_db_location" VALUES(50418,NULL,'Graham, MO',21150,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50419,NULL,'Graham, MO 64455',21150,222,NULL,43,28976,0);
INSERT INTO "django_geo_db_location" VALUES(50420,NULL,'Grant City, MO',21151,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50421,NULL,'Grant City, MO 64456',21151,222,NULL,43,28977,0);
INSERT INTO "django_geo_db_location" VALUES(50422,NULL,'Guilford, MO',21152,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50423,NULL,'Guilford, MO 64457',21152,222,NULL,43,28978,0);
INSERT INTO "django_geo_db_location" VALUES(50424,NULL,'Hatfield, MO',21153,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50425,NULL,'Hatfield, MO 64458',21153,222,NULL,43,28979,0);
INSERT INTO "django_geo_db_location" VALUES(50426,NULL,'Helena, MO',21154,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50427,NULL,'Helena, MO 64459',21154,222,NULL,43,28980,0);
INSERT INTO "django_geo_db_location" VALUES(50428,NULL,'Hopkins, MO',21155,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50429,NULL,'Hopkins, MO 64461',21155,222,NULL,43,28981,0);
INSERT INTO "django_geo_db_location" VALUES(50430,NULL,'King City, MO',21156,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50431,NULL,'King City, MO 64463',21156,222,NULL,43,28982,0);
INSERT INTO "django_geo_db_location" VALUES(50432,NULL,'Polk, MO',21157,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50433,NULL,'Polk, MO 64464',21157,222,NULL,43,28983,0);
INSERT INTO "django_geo_db_location" VALUES(50434,NULL,'Lathrop, MO',21158,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50435,NULL,'Lathrop, MO 64465',21158,222,NULL,43,28984,0);
INSERT INTO "django_geo_db_location" VALUES(50436,NULL,'Maitland, MO',21159,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50437,NULL,'Maitland, MO 64466',21159,222,NULL,43,28985,0);
INSERT INTO "django_geo_db_location" VALUES(50438,NULL,'Martinsville, MO',21160,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50439,NULL,'Martinsville, MO 64467',21160,222,NULL,43,28986,0);
INSERT INTO "django_geo_db_location" VALUES(50440,NULL,'Maryville, MO',21161,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50441,NULL,'Maryville, MO 64468',21161,222,NULL,43,28987,0);
INSERT INTO "django_geo_db_location" VALUES(50442,NULL,'Maysville, MO',21162,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50443,NULL,'Maysville, MO 64469',21162,222,NULL,43,28988,0);
INSERT INTO "django_geo_db_location" VALUES(50444,NULL,'Mound City, MO',21163,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50445,NULL,'Mound City, MO 64470',21163,222,NULL,43,28989,0);
INSERT INTO "django_geo_db_location" VALUES(50446,NULL,'New Hampton, MO',21164,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50447,NULL,'New Hampton, MO 64471',21164,222,NULL,43,28990,0);
INSERT INTO "django_geo_db_location" VALUES(50448,NULL,'Oregon, MO',21165,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50449,NULL,'Oregon, MO 64473',21165,222,NULL,43,28991,0);
INSERT INTO "django_geo_db_location" VALUES(50450,NULL,'Osborn, MO',21166,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50451,NULL,'Osborn, MO 64474',21166,222,NULL,43,28992,0);
INSERT INTO "django_geo_db_location" VALUES(50452,NULL,'Parnell, MO',21167,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50453,NULL,'Parnell, MO 64475',21167,222,NULL,43,28993,0);
INSERT INTO "django_geo_db_location" VALUES(50454,NULL,'Pickering, MO',21168,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50455,NULL,'Pickering, MO 64476',21168,222,NULL,43,28994,0);
INSERT INTO "django_geo_db_location" VALUES(50456,NULL,'Plattsburg, MO',21169,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50457,NULL,'Plattsburg, MO 64477',21169,222,NULL,43,28995,0);
INSERT INTO "django_geo_db_location" VALUES(50458,NULL,'Quitman, MO',21170,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50459,NULL,'Quitman, MO 64478',21170,222,NULL,43,28996,0);
INSERT INTO "django_geo_db_location" VALUES(50460,NULL,'Ravenwood, MO',21171,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50461,NULL,'Ravenwood, MO 64479',21171,222,NULL,43,28997,0);
INSERT INTO "django_geo_db_location" VALUES(50462,NULL,'Rea, MO',21172,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50463,NULL,'Rea, MO 64480',21172,222,NULL,43,28998,0);
INSERT INTO "django_geo_db_location" VALUES(50464,NULL,'Ridgeway, MO',21173,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50465,NULL,'Ridgeway, MO 64481',21173,222,NULL,43,28999,0);
INSERT INTO "django_geo_db_location" VALUES(50466,NULL,'Rock Port, MO',21174,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50467,NULL,'Rock Port, MO 64482',21174,222,NULL,43,29000,0);
INSERT INTO "django_geo_db_location" VALUES(50468,NULL,'Rosendale, MO',21175,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50469,NULL,'Rosendale, MO 64483',21175,222,NULL,43,29001,0);
INSERT INTO "django_geo_db_location" VALUES(50470,NULL,'Rushville, MO',21176,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50471,NULL,'Rushville, MO 64484',21176,222,NULL,43,29002,0);
INSERT INTO "django_geo_db_location" VALUES(50472,NULL,'Savannah, MO',21177,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50473,NULL,'Savannah, MO 64485',21177,222,NULL,43,29003,0);
INSERT INTO "django_geo_db_location" VALUES(50474,NULL,'Sheridan, MO',21178,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50475,NULL,'Sheridan, MO 64486',21178,222,NULL,43,29004,0);
INSERT INTO "django_geo_db_location" VALUES(50476,NULL,'Skidmore, MO',21179,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50477,NULL,'Skidmore, MO 64487',21179,222,NULL,43,29005,0);
INSERT INTO "django_geo_db_location" VALUES(50478,NULL,'Stanberry, MO',21180,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50479,NULL,'Stanberry, MO 64489',21180,222,NULL,43,29006,0);
INSERT INTO "django_geo_db_location" VALUES(50480,NULL,'Stewartsville, MO',21181,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50481,NULL,'Stewartsville, MO 64490',21181,222,NULL,43,29007,0);
INSERT INTO "django_geo_db_location" VALUES(50482,NULL,'Tarkio, MO',21182,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50483,NULL,'Tarkio, MO 64491',21182,222,NULL,43,29008,0);
INSERT INTO "django_geo_db_location" VALUES(50484,NULL,'Trimble, MO',21183,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50485,NULL,'Trimble, MO 64492',21183,222,NULL,43,29009,0);
INSERT INTO "django_geo_db_location" VALUES(50486,NULL,'Turney, MO',21184,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50487,NULL,'Turney, MO 64493',21184,222,NULL,43,29010,0);
INSERT INTO "django_geo_db_location" VALUES(50488,NULL,'Union Star, MO',21185,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50489,NULL,'Union Star, MO 64494',21185,222,NULL,43,29011,0);
INSERT INTO "django_geo_db_location" VALUES(50490,NULL,'Watson, MO',21186,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50491,NULL,'Watson, MO 64496',21186,222,NULL,43,29012,0);
INSERT INTO "django_geo_db_location" VALUES(50492,NULL,'Weatherby, MO',21187,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50493,NULL,'Weatherby, MO 64497',21187,222,NULL,43,29013,0);
INSERT INTO "django_geo_db_location" VALUES(50494,NULL,'Westboro, MO',21188,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50495,NULL,'Westboro, MO 64498',21188,222,NULL,43,29014,0);
INSERT INTO "django_geo_db_location" VALUES(50496,NULL,'Worth, MO',21189,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50497,NULL,'Worth, MO 64499',21189,222,NULL,43,29015,0);
INSERT INTO "django_geo_db_location" VALUES(50498,NULL,'Saint Joseph, MO',21190,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50499,NULL,'Saint Joseph, MO 64501',21190,222,NULL,43,29016,0);
INSERT INTO "django_geo_db_location" VALUES(50500,NULL,'Saint Joseph, MO 64502',21190,222,NULL,43,29017,0);
INSERT INTO "django_geo_db_location" VALUES(50501,NULL,'Saint Joseph, MO 64503',21190,222,NULL,43,29018,0);
INSERT INTO "django_geo_db_location" VALUES(50502,NULL,'Saint Joseph, MO 64504',21190,222,NULL,43,29019,0);
INSERT INTO "django_geo_db_location" VALUES(50503,NULL,'Saint Joseph, MO 64505',21190,222,NULL,43,29020,0);
INSERT INTO "django_geo_db_location" VALUES(50504,NULL,'Saint Joseph, MO 64506',21190,222,NULL,43,29021,0);
INSERT INTO "django_geo_db_location" VALUES(50505,NULL,'Saint Joseph, MO 64507',21190,222,NULL,43,29022,0);
INSERT INTO "django_geo_db_location" VALUES(50506,NULL,'Saint Joseph, MO 64508',21190,222,NULL,43,29023,0);
INSERT INTO "django_geo_db_location" VALUES(50507,NULL,'Blue Mound, MO',21191,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50508,NULL,'Blue Mound, MO 64600',21191,222,NULL,43,29024,0);
INSERT INTO "django_geo_db_location" VALUES(50509,NULL,'Chillicothe, MO',21192,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50510,NULL,'Chillicothe, MO 64601',21192,222,NULL,43,29025,0);
INSERT INTO "django_geo_db_location" VALUES(50511,NULL,'Altamont, MO',21193,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50512,NULL,'Altamont, MO 64620',21193,222,NULL,43,29026,0);
INSERT INTO "django_geo_db_location" VALUES(50513,NULL,'Fairview, MO',21194,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50514,NULL,'Fairview, MO 64621',21194,222,NULL,43,29027,0);
INSERT INTO "django_geo_db_location" VALUES(50515,NULL,'Bogard, MO',21195,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50516,NULL,'Bogard, MO 64622',21195,222,NULL,43,29028,0);
INSERT INTO "django_geo_db_location" VALUES(50517,NULL,'Bosworth, MO',21196,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50518,NULL,'Bosworth, MO 64623',21196,222,NULL,43,29029,0);
INSERT INTO "django_geo_db_location" VALUES(50519,NULL,'Braymer, MO',21197,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50520,NULL,'Braymer, MO 64624',21197,222,NULL,43,29030,0);
INSERT INTO "django_geo_db_location" VALUES(50521,NULL,'Breckenridge, MO',21198,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50522,NULL,'Breckenridge, MO 64625',21198,222,NULL,43,29031,0);
INSERT INTO "django_geo_db_location" VALUES(50523,NULL,'Brookfield, MO',21199,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50524,NULL,'Brookfield, MO 64628',21199,222,NULL,43,29032,0);
INSERT INTO "django_geo_db_location" VALUES(50525,NULL,'Braymer, MO 64629',21197,222,NULL,43,29033,0);
INSERT INTO "django_geo_db_location" VALUES(50526,NULL,'Browning, MO',21200,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50527,NULL,'Browning, MO 64630',21200,222,NULL,43,29034,0);
INSERT INTO "django_geo_db_location" VALUES(50528,NULL,'Bucklin, MO',21201,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50529,NULL,'Bucklin, MO 64631',21201,222,NULL,43,29035,0);
INSERT INTO "django_geo_db_location" VALUES(50530,NULL,'Cainsville, MO',21202,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50531,NULL,'Cainsville, MO 64632',21202,222,NULL,43,29036,0);
INSERT INTO "django_geo_db_location" VALUES(50532,NULL,'Carrollton, MO',21203,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50533,NULL,'Carrollton, MO 64633',21203,222,NULL,43,29037,0);
INSERT INTO "django_geo_db_location" VALUES(50534,NULL,'Chula, MO',21204,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50535,NULL,'Chula, MO 64635',21204,222,NULL,43,29038,0);
INSERT INTO "django_geo_db_location" VALUES(50536,NULL,'Coffey, MO',21205,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50537,NULL,'Coffey, MO 64636',21205,222,NULL,43,29039,0);
INSERT INTO "django_geo_db_location" VALUES(50538,NULL,'Cowgill, MO',21206,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50539,NULL,'Cowgill, MO 64637',21206,222,NULL,43,29040,0);
INSERT INTO "django_geo_db_location" VALUES(50540,NULL,'Dawn, MO',21207,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50541,NULL,'Dawn, MO 64638',21207,222,NULL,43,29041,0);
INSERT INTO "django_geo_db_location" VALUES(50542,NULL,'De Witt, MO',21208,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50543,NULL,'De Witt, MO 64639',21208,222,NULL,43,29042,0);
INSERT INTO "django_geo_db_location" VALUES(50544,NULL,'Gallatin, MO',21209,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50545,NULL,'Gallatin, MO 64640',21209,222,NULL,43,29043,0);
INSERT INTO "django_geo_db_location" VALUES(50546,NULL,'Galt, MO',21210,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50547,NULL,'Galt, MO 64641',21210,222,NULL,43,29044,0);
INSERT INTO "django_geo_db_location" VALUES(50548,NULL,'Gilman City, MO',21211,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50549,NULL,'Gilman City, MO 64642',21211,222,NULL,43,29045,0);
INSERT INTO "django_geo_db_location" VALUES(50550,NULL,'Hale, MO',21212,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50551,NULL,'Hale, MO 64643',21212,222,NULL,43,29046,0);
INSERT INTO "django_geo_db_location" VALUES(50552,NULL,'Hamilton, MO',21213,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50553,NULL,'Hamilton, MO 64644',21213,222,NULL,43,29047,0);
INSERT INTO "django_geo_db_location" VALUES(50554,NULL,'Harris, MO',21214,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50555,NULL,'Harris, MO 64645',21214,222,NULL,43,29048,0);
INSERT INTO "django_geo_db_location" VALUES(50556,NULL,'Humphreys, MO',21215,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50557,NULL,'Humphreys, MO 64646',21215,222,NULL,43,29049,0);
INSERT INTO "django_geo_db_location" VALUES(50558,NULL,'Jameson, MO',21216,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50559,NULL,'Jameson, MO 64647',21216,222,NULL,43,29050,0);
INSERT INTO "django_geo_db_location" VALUES(50560,NULL,'Jamesport, MO',21217,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50561,NULL,'Jamesport, MO 64648',21217,222,NULL,43,29051,0);
INSERT INTO "django_geo_db_location" VALUES(50562,NULL,'Kidder, MO',21218,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50563,NULL,'Kidder, MO 64649',21218,222,NULL,43,29052,0);
INSERT INTO "django_geo_db_location" VALUES(50564,NULL,'Kingston, MO',21219,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50565,NULL,'Kingston, MO 64650',21219,222,NULL,43,29053,0);
INSERT INTO "django_geo_db_location" VALUES(50566,NULL,'Laclede, MO',21220,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50567,NULL,'Laclede, MO 64651',21220,222,NULL,43,29054,0);
INSERT INTO "django_geo_db_location" VALUES(50568,NULL,'Laredo, MO',21221,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50569,NULL,'Laredo, MO 64652',21221,222,NULL,43,29055,0);
INSERT INTO "django_geo_db_location" VALUES(50570,NULL,'Linneus, MO',21222,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50571,NULL,'Linneus, MO 64653',21222,222,NULL,43,29056,0);
INSERT INTO "django_geo_db_location" VALUES(50572,NULL,'Lock Springs, MO',21223,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50573,NULL,'Lock Springs, MO 64654',21223,222,NULL,43,29057,0);
INSERT INTO "django_geo_db_location" VALUES(50574,NULL,'Lucerne, MO',21224,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50575,NULL,'Lucerne, MO 64655',21224,222,NULL,43,29058,0);
INSERT INTO "django_geo_db_location" VALUES(50576,NULL,'Ludlow, MO',21225,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50577,NULL,'Ludlow, MO 64656',21225,222,NULL,43,29059,0);
INSERT INTO "django_geo_db_location" VALUES(50578,NULL,'McFall, MO',21226,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50579,NULL,'McFall, MO 64657',21226,222,NULL,43,29060,0);
INSERT INTO "django_geo_db_location" VALUES(50580,NULL,'Marceline, MO',21227,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50581,NULL,'Marceline, MO 64658',21227,222,NULL,43,29061,0);
INSERT INTO "django_geo_db_location" VALUES(50582,NULL,'Meadville, MO',21228,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50583,NULL,'Meadville, MO 64659',21228,222,NULL,43,29062,0);
INSERT INTO "django_geo_db_location" VALUES(50584,NULL,'Mendon, MO',21229,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50585,NULL,'Mendon, MO 64660',21229,222,NULL,43,29063,0);
INSERT INTO "django_geo_db_location" VALUES(50586,NULL,'Mercer, MO',21230,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50587,NULL,'Mercer, MO 64661',21230,222,NULL,43,29064,0);
INSERT INTO "django_geo_db_location" VALUES(50588,NULL,'Mooresville, MO',21231,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50589,NULL,'Mooresville, MO 64664',21231,222,NULL,43,29065,0);
INSERT INTO "django_geo_db_location" VALUES(50590,NULL,'Mount Moriah, MO',21232,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50591,NULL,'Mount Moriah, MO 64665',21232,222,NULL,43,29066,0);
INSERT INTO "django_geo_db_location" VALUES(50592,NULL,'Newtown, MO',21233,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50593,NULL,'Newtown, MO 64667',21233,222,NULL,43,29067,0);
INSERT INTO "django_geo_db_location" VALUES(50594,NULL,'Norborne, MO',21234,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50595,NULL,'Norborne, MO 64668',21234,222,NULL,43,29068,0);
INSERT INTO "django_geo_db_location" VALUES(50596,NULL,'Pattonsburg, MO',21235,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50597,NULL,'Pattonsburg, MO 64670',21235,222,NULL,43,29069,0);
INSERT INTO "django_geo_db_location" VALUES(50598,NULL,'Polo, MO',21236,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50599,NULL,'Polo, MO 64671',21236,222,NULL,43,29070,0);
INSERT INTO "django_geo_db_location" VALUES(50600,NULL,'Powersville, MO',21237,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50601,NULL,'Powersville, MO 64672',21237,222,NULL,43,29071,0);
INSERT INTO "django_geo_db_location" VALUES(50602,NULL,'Princeton, MO',21238,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50603,NULL,'Princeton, MO 64673',21238,222,NULL,43,29072,0);
INSERT INTO "django_geo_db_location" VALUES(50604,NULL,'Purdin, MO',21239,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50605,NULL,'Purdin, MO 64674',21239,222,NULL,43,29073,0);
INSERT INTO "django_geo_db_location" VALUES(50606,NULL,'Rothville, MO',21240,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50607,NULL,'Rothville, MO 64676',21240,222,NULL,43,29074,0);
INSERT INTO "django_geo_db_location" VALUES(50608,NULL,'Purdin, MO 64677',21239,222,NULL,43,29075,0);
INSERT INTO "django_geo_db_location" VALUES(50609,NULL,'Spickard, MO',21241,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50610,NULL,'Spickard, MO 64679',21241,222,NULL,43,29076,0);
INSERT INTO "django_geo_db_location" VALUES(50611,NULL,'Stet, MO',21242,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50612,NULL,'Stet, MO 64680',21242,222,NULL,43,29077,0);
INSERT INTO "django_geo_db_location" VALUES(50613,NULL,'Sumner, MO',21243,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50614,NULL,'Sumner, MO 64681',21243,222,NULL,43,29078,0);
INSERT INTO "django_geo_db_location" VALUES(50615,NULL,'Tina, MO',21244,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50616,NULL,'Tina, MO 64682',21244,222,NULL,43,29079,0);
INSERT INTO "django_geo_db_location" VALUES(50617,NULL,'Trenton, MO',21245,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50618,NULL,'Trenton, MO 64683',21245,222,NULL,43,29080,0);
INSERT INTO "django_geo_db_location" VALUES(50619,NULL,'Utica, MO',21246,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50620,NULL,'Utica, MO 64686',21246,222,NULL,43,29081,0);
INSERT INTO "django_geo_db_location" VALUES(50621,NULL,'Wakenda, MO',21247,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50622,NULL,'Wakenda, MO 64687',21247,222,NULL,43,29082,0);
INSERT INTO "django_geo_db_location" VALUES(50623,NULL,'Wheeling, MO',21248,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50624,NULL,'Wheeling, MO 64688',21248,222,NULL,43,29083,0);
INSERT INTO "django_geo_db_location" VALUES(50625,NULL,'Winston, MO',21249,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50626,NULL,'Winston, MO 64689',21249,222,NULL,43,29084,0);
INSERT INTO "django_geo_db_location" VALUES(50627,NULL,'Harrisonville, MO',21250,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50628,NULL,'Harrisonville, MO 64701',21250,222,NULL,43,29085,0);
INSERT INTO "django_geo_db_location" VALUES(50629,NULL,'Adrian, MO',21251,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50630,NULL,'Adrian, MO 64720',21251,222,NULL,43,29086,0);
INSERT INTO "django_geo_db_location" VALUES(50631,NULL,'Amoret, MO',21252,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50632,NULL,'Amoret, MO 64722',21252,222,NULL,43,29087,0);
INSERT INTO "django_geo_db_location" VALUES(50633,NULL,'Amsterdam, MO',21253,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50634,NULL,'Amsterdam, MO 64723',21253,222,NULL,43,29088,0);
INSERT INTO "django_geo_db_location" VALUES(50635,NULL,'Appleton City, MO',21254,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50636,NULL,'Appleton City, MO 64724',21254,222,NULL,43,29089,0);
INSERT INTO "django_geo_db_location" VALUES(50637,NULL,'Archie, MO',21255,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50638,NULL,'Archie, MO 64725',21255,222,NULL,43,29090,0);
INSERT INTO "django_geo_db_location" VALUES(50639,NULL,'Blairstown, MO',21256,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50640,NULL,'Blairstown, MO 64726',21256,222,NULL,43,29091,0);
INSERT INTO "django_geo_db_location" VALUES(50641,NULL,'Bronaugh, MO',21257,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50642,NULL,'Bronaugh, MO 64728',21257,222,NULL,43,29092,0);
INSERT INTO "django_geo_db_location" VALUES(50643,NULL,'Butler, MO',21258,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50644,NULL,'Butler, MO 64730',21258,222,NULL,43,29093,0);
INSERT INTO "django_geo_db_location" VALUES(50645,NULL,'Chilhowee, MO',21259,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50646,NULL,'Chilhowee, MO 64733',21259,222,NULL,43,29094,0);
INSERT INTO "django_geo_db_location" VALUES(50647,NULL,'Cleveland, MO',21260,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50648,NULL,'Cleveland, MO 64734',21260,222,NULL,43,29095,0);
INSERT INTO "django_geo_db_location" VALUES(50649,NULL,'Clinton, MO',21261,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50650,NULL,'Clinton, MO 64735',21261,222,NULL,43,29096,0);
INSERT INTO "django_geo_db_location" VALUES(50651,NULL,'Collins, MO',21262,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50652,NULL,'Collins, MO 64738',21262,222,NULL,43,29097,0);
INSERT INTO "django_geo_db_location" VALUES(50653,NULL,'Creighton, MO',21263,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50654,NULL,'Creighton, MO 64739',21263,222,NULL,43,29098,0);
INSERT INTO "django_geo_db_location" VALUES(50655,NULL,'Deepwater, MO',21264,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50656,NULL,'Deepwater, MO 64740',21264,222,NULL,43,29099,0);
INSERT INTO "django_geo_db_location" VALUES(50657,NULL,'Deerfield, MO',21265,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50658,NULL,'Deerfield, MO 64741',21265,222,NULL,43,29100,0);
INSERT INTO "django_geo_db_location" VALUES(50659,NULL,'Drexel, MO',21266,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50660,NULL,'Drexel, MO 64742',21266,222,NULL,43,29101,0);
INSERT INTO "django_geo_db_location" VALUES(50661,NULL,'East Lynne, MO',21267,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50662,NULL,'East Lynne, MO 64743',21267,222,NULL,43,29102,0);
INSERT INTO "django_geo_db_location" VALUES(50663,NULL,'El Dorado Springs, MO',21268,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50664,NULL,'El Dorado Springs, MO 64744',21268,222,NULL,43,29103,0);
INSERT INTO "django_geo_db_location" VALUES(50665,NULL,'Foster, MO',21269,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50666,NULL,'Foster, MO 64745',21269,222,NULL,43,29104,0);
INSERT INTO "django_geo_db_location" VALUES(50667,NULL,'Freeman, MO',21270,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50668,NULL,'Freeman, MO 64746',21270,222,NULL,43,29105,0);
INSERT INTO "django_geo_db_location" VALUES(50669,NULL,'Garden City, MO',21271,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50670,NULL,'Garden City, MO 64747',21271,222,NULL,43,29106,0);
INSERT INTO "django_geo_db_location" VALUES(50671,NULL,'Golden City, MO',21272,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50672,NULL,'Golden City, MO 64748',21272,222,NULL,43,29107,0);
INSERT INTO "django_geo_db_location" VALUES(50673,NULL,'Harwood, MO',21273,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50674,NULL,'Harwood, MO 64750',21273,222,NULL,43,29108,0);
INSERT INTO "django_geo_db_location" VALUES(50675,NULL,'Horton, MO',21274,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50676,NULL,'Horton, MO 64751',21274,222,NULL,43,29109,0);
INSERT INTO "django_geo_db_location" VALUES(50677,NULL,'Hume, MO',21275,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50678,NULL,'Hume, MO 64752',21275,222,NULL,43,29110,0);
INSERT INTO "django_geo_db_location" VALUES(50679,NULL,'Jasper, MO',21276,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50680,NULL,'Jasper, MO 64755',21276,222,NULL,43,29111,0);
INSERT INTO "django_geo_db_location" VALUES(50681,NULL,'Jerico Springs, MO',21277,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50682,NULL,'Jerico Springs, MO 64756',21277,222,NULL,43,29112,0);
INSERT INTO "django_geo_db_location" VALUES(50683,NULL,'Lamar, MO',21278,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50684,NULL,'Lamar, MO 64759',21278,222,NULL,43,29113,0);
INSERT INTO "django_geo_db_location" VALUES(50685,NULL,'Leeton, MO',21279,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50686,NULL,'Leeton, MO 64761',21279,222,NULL,43,29114,0);
INSERT INTO "django_geo_db_location" VALUES(50687,NULL,'Liberal, MO',21280,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50688,NULL,'Liberal, MO 64762',21280,222,NULL,43,29115,0);
INSERT INTO "django_geo_db_location" VALUES(50689,NULL,'Lowry City, MO',21281,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50690,NULL,'Lowry City, MO 64763',21281,222,NULL,43,29116,0);
INSERT INTO "django_geo_db_location" VALUES(50691,NULL,'Metz, MO',21282,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50692,NULL,'Metz, MO 64765',21282,222,NULL,43,29117,0);
INSERT INTO "django_geo_db_location" VALUES(50693,NULL,'Milford, MO',21283,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50694,NULL,'Milford, MO 64766',21283,222,NULL,43,29118,0);
INSERT INTO "django_geo_db_location" VALUES(50695,NULL,'Milo, MO',21284,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50696,NULL,'Milo, MO 64767',21284,222,NULL,43,29119,0);
INSERT INTO "django_geo_db_location" VALUES(50697,NULL,'Mindenmines, MO',21285,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50698,NULL,'Mindenmines, MO 64769',21285,222,NULL,43,29120,0);
INSERT INTO "django_geo_db_location" VALUES(50699,NULL,'Montrose, MO',21286,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50700,NULL,'Montrose, MO 64770',21286,222,NULL,43,29121,0);
INSERT INTO "django_geo_db_location" VALUES(50701,NULL,'Moundville, MO',21287,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50702,NULL,'Moundville, MO 64771',21287,222,NULL,43,29122,0);
INSERT INTO "django_geo_db_location" VALUES(50703,NULL,'Nevada, MO',21288,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50704,NULL,'Nevada, MO 64772',21288,222,NULL,43,29123,0);
INSERT INTO "django_geo_db_location" VALUES(50705,NULL,'Osceola, MO',21289,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50706,NULL,'Osceola, MO 64776',21289,222,NULL,43,29124,0);
INSERT INTO "django_geo_db_location" VALUES(50707,NULL,'Passaic, MO',21290,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50708,NULL,'Passaic, MO 64777',21290,222,NULL,43,29125,0);
INSERT INTO "django_geo_db_location" VALUES(50709,NULL,'Richards, MO',21291,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50710,NULL,'Richards, MO 64778',21291,222,NULL,43,29126,0);
INSERT INTO "django_geo_db_location" VALUES(50711,NULL,'Rich Hill, MO',21292,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50712,NULL,'Rich Hill, MO 64779',21292,222,NULL,43,29127,0);
INSERT INTO "django_geo_db_location" VALUES(50713,NULL,'Rockville, MO',21293,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50714,NULL,'Rockville, MO 64780',21293,222,NULL,43,29128,0);
INSERT INTO "django_geo_db_location" VALUES(50715,NULL,'Roscoe, MO',21294,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50716,NULL,'Roscoe, MO 64781',21294,222,NULL,43,29129,0);
INSERT INTO "django_geo_db_location" VALUES(50717,NULL,'Schell City, MO',21295,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50718,NULL,'Schell City, MO 64783',21295,222,NULL,43,29130,0);
INSERT INTO "django_geo_db_location" VALUES(50719,NULL,'Sheldon, MO',21296,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50720,NULL,'Sheldon, MO 64784',21296,222,NULL,43,29131,0);
INSERT INTO "django_geo_db_location" VALUES(50721,NULL,'Urich, MO',21297,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50722,NULL,'Urich, MO 64788',21297,222,NULL,43,29132,0);
INSERT INTO "django_geo_db_location" VALUES(50723,NULL,'Vista, MO',21298,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50724,NULL,'Vista, MO 64789',21298,222,NULL,43,29133,0);
INSERT INTO "django_geo_db_location" VALUES(50725,NULL,'Walker, MO',21299,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50726,NULL,'Walker, MO 64790',21299,222,NULL,43,29134,0);
INSERT INTO "django_geo_db_location" VALUES(50727,NULL,'Joplin, MO',21300,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50728,NULL,'Joplin, MO 64801',21300,222,NULL,43,29135,0);
INSERT INTO "django_geo_db_location" VALUES(50729,NULL,'Joplin, MO 64802',21300,222,NULL,43,29136,0);
INSERT INTO "django_geo_db_location" VALUES(50730,NULL,'Joplin, MO 64803',21300,222,NULL,43,29137,0);
INSERT INTO "django_geo_db_location" VALUES(50731,NULL,'Joplin, MO 64804',21300,222,NULL,43,29138,0);
INSERT INTO "django_geo_db_location" VALUES(50732,NULL,'Goodman, MO',21301,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50733,NULL,'Goodman, MO 64810',21301,222,NULL,43,29139,0);
INSERT INTO "django_geo_db_location" VALUES(50734,NULL,'Alba, MO',21302,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50735,NULL,'Alba, MO 64830',21302,222,NULL,43,29140,0);
INSERT INTO "django_geo_db_location" VALUES(50736,NULL,'Anderson, MO',21303,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50737,NULL,'Anderson, MO 64831',21303,222,NULL,43,29141,0);
INSERT INTO "django_geo_db_location" VALUES(50738,NULL,'Asbury, MO',21304,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50739,NULL,'Asbury, MO 64832',21304,222,NULL,43,29142,0);
INSERT INTO "django_geo_db_location" VALUES(50740,NULL,'Avilla, MO',21305,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50741,NULL,'Avilla, MO 64833',21305,222,NULL,43,29143,0);
INSERT INTO "django_geo_db_location" VALUES(50742,NULL,'Carl Junction, MO',21306,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50743,NULL,'Carl Junction, MO 64834',21306,222,NULL,43,29144,0);
INSERT INTO "django_geo_db_location" VALUES(50744,NULL,'Carterville, MO',21307,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50745,NULL,'Carterville, MO 64835',21307,222,NULL,43,29145,0);
INSERT INTO "django_geo_db_location" VALUES(50746,NULL,'Carthage, MO',21308,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50747,NULL,'Carthage, MO 64836',21308,222,NULL,43,29146,0);
INSERT INTO "django_geo_db_location" VALUES(50748,NULL,'Diamond, MO',21309,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50749,NULL,'Diamond, MO 64840',21309,222,NULL,43,29147,0);
INSERT INTO "django_geo_db_location" VALUES(50750,NULL,'Duenweg, MO',21310,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50751,NULL,'Duenweg, MO 64841',21310,222,NULL,43,29148,0);
INSERT INTO "django_geo_db_location" VALUES(50752,NULL,'Fairview, MO 64842',21194,222,NULL,43,29149,0);
INSERT INTO "django_geo_db_location" VALUES(50753,NULL,'Goodman, MO 64843',21301,222,NULL,43,29150,0);
INSERT INTO "django_geo_db_location" VALUES(50754,NULL,'Granby, MO',21311,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50755,NULL,'Granby, MO 64844',21311,222,NULL,43,29151,0);
INSERT INTO "django_geo_db_location" VALUES(50756,NULL,'Lanagan, MO',21312,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50757,NULL,'Lanagan, MO 64847',21312,222,NULL,43,29152,0);
INSERT INTO "django_geo_db_location" VALUES(50758,NULL,'La Russell, MO',21313,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50759,NULL,'La Russell, MO 64848',21313,222,NULL,43,29153,0);
INSERT INTO "django_geo_db_location" VALUES(50760,NULL,'Neck City, MO',21314,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50761,NULL,'Neck City, MO 64849',21314,222,NULL,43,29154,0);
INSERT INTO "django_geo_db_location" VALUES(50762,NULL,'Neosho, MO',21315,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50763,NULL,'Neosho, MO 64850',21315,222,NULL,43,29155,0);
INSERT INTO "django_geo_db_location" VALUES(50764,NULL,'Newtonia, MO',21316,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50765,NULL,'Newtonia, MO 64853',21316,222,NULL,43,29156,0);
INSERT INTO "django_geo_db_location" VALUES(50766,NULL,'Noel, MO',21317,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50767,NULL,'Noel, MO 64854',21317,222,NULL,43,29157,0);
INSERT INTO "django_geo_db_location" VALUES(50768,NULL,'Oronogo, MO',21318,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50769,NULL,'Oronogo, MO 64855',21318,222,NULL,43,29158,0);
INSERT INTO "django_geo_db_location" VALUES(50770,NULL,'Pineville, MO',21319,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50771,NULL,'Pineville, MO 64856',21319,222,NULL,43,29159,0);
INSERT INTO "django_geo_db_location" VALUES(50772,NULL,'Purcell, MO',21320,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50773,NULL,'Purcell, MO 64857',21320,222,NULL,43,29160,0);
INSERT INTO "django_geo_db_location" VALUES(50774,NULL,'Racine, MO',21321,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50775,NULL,'Racine, MO 64858',21321,222,NULL,43,29161,0);
INSERT INTO "django_geo_db_location" VALUES(50776,NULL,'Reeds, MO',21322,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50777,NULL,'Reeds, MO 64859',21322,222,NULL,43,29162,0);
INSERT INTO "django_geo_db_location" VALUES(50778,NULL,'Rocky Comfort, MO',21323,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50779,NULL,'Rocky Comfort, MO 64861',21323,222,NULL,43,29163,0);
INSERT INTO "django_geo_db_location" VALUES(50780,NULL,'Sarcoxie, MO',21324,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50781,NULL,'Sarcoxie, MO 64862',21324,222,NULL,43,29164,0);
INSERT INTO "django_geo_db_location" VALUES(50782,NULL,'South West City, MO',21325,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50783,NULL,'South West City, MO 64863',21325,222,NULL,43,29165,0);
INSERT INTO "django_geo_db_location" VALUES(50784,NULL,'Saginaw, MO',21326,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50785,NULL,'Saginaw, MO 64864',21326,222,NULL,43,29166,0);
INSERT INTO "django_geo_db_location" VALUES(50786,NULL,'Seneca, MO',21327,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50787,NULL,'Seneca, MO 64865',21327,222,NULL,43,29167,0);
INSERT INTO "django_geo_db_location" VALUES(50788,NULL,'Stark City, MO',21328,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50789,NULL,'Stark City, MO 64866',21328,222,NULL,43,29168,0);
INSERT INTO "django_geo_db_location" VALUES(50790,NULL,'Stella, MO',21329,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50791,NULL,'Stella, MO 64867',21329,222,NULL,43,29169,0);
INSERT INTO "django_geo_db_location" VALUES(50792,NULL,'Tiff City, MO',21330,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50793,NULL,'Tiff City, MO 64868',21330,222,NULL,43,29170,0);
INSERT INTO "django_geo_db_location" VALUES(50794,NULL,'Waco, MO',21331,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50795,NULL,'Waco, MO 64869',21331,222,NULL,43,29171,0);
INSERT INTO "django_geo_db_location" VALUES(50796,NULL,'Webb City, MO',21332,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50797,NULL,'Webb City, MO 64870',21332,222,NULL,43,29172,0);
INSERT INTO "django_geo_db_location" VALUES(50798,NULL,'Wentworth, MO',21333,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50799,NULL,'Wentworth, MO 64873',21333,222,NULL,43,29173,0);
INSERT INTO "django_geo_db_location" VALUES(50800,NULL,'Wheaton, MO',21334,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50801,NULL,'Wheaton, MO 64874',21334,222,NULL,43,29174,0);
INSERT INTO "django_geo_db_location" VALUES(50802,NULL,'Washington, MO 64930',20775,222,NULL,43,29175,0);
INSERT INTO "django_geo_db_location" VALUES(50803,NULL,'Kansas City, MO 64944',21115,222,NULL,43,29176,0);
INSERT INTO "django_geo_db_location" VALUES(50804,NULL,'Kansas City, MO 64999',21115,222,NULL,43,29177,0);
INSERT INTO "django_geo_db_location" VALUES(50805,NULL,'Argyle, MO',21335,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50806,NULL,'Argyle, MO 65001',21335,222,NULL,43,29178,0);
INSERT INTO "django_geo_db_location" VALUES(50807,NULL,'Ashland, MO',21336,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50808,NULL,'Ashland, MO 65010',21336,222,NULL,43,29179,0);
INSERT INTO "django_geo_db_location" VALUES(50809,NULL,'Barnett, MO',21337,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50810,NULL,'Barnett, MO 65011',21337,222,NULL,43,29180,0);
INSERT INTO "django_geo_db_location" VALUES(50811,NULL,'Belle, MO',21338,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50812,NULL,'Belle, MO 65013',21338,222,NULL,43,29181,0);
INSERT INTO "django_geo_db_location" VALUES(50813,NULL,'Bland, MO',21339,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50814,NULL,'Bland, MO 65014',21339,222,NULL,43,29182,0);
INSERT INTO "django_geo_db_location" VALUES(50815,NULL,'Bonnots Mill, MO',21340,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50816,NULL,'Bonnots Mill, MO 65016',21340,222,NULL,43,29183,0);
INSERT INTO "django_geo_db_location" VALUES(50817,NULL,'Brumley, MO',21341,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50818,NULL,'Brumley, MO 65017',21341,222,NULL,43,29184,0);
INSERT INTO "django_geo_db_location" VALUES(50819,NULL,'California, MO',21342,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50820,NULL,'California, MO 65018',21342,222,NULL,43,29185,0);
INSERT INTO "django_geo_db_location" VALUES(50821,NULL,'Camdenton, MO',21343,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50822,NULL,'Camdenton, MO 65020',21343,222,NULL,43,29186,0);
INSERT INTO "django_geo_db_location" VALUES(50823,NULL,'Cedar City, MO',21344,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50824,NULL,'Cedar City, MO 65022',21344,222,NULL,43,29187,0);
INSERT INTO "django_geo_db_location" VALUES(50825,NULL,'Centertown, MO',21345,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50826,NULL,'Centertown, MO 65023',21345,222,NULL,43,29188,0);
INSERT INTO "django_geo_db_location" VALUES(50827,NULL,'Chamois, MO',21346,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50828,NULL,'Chamois, MO 65024',21346,222,NULL,43,29189,0);
INSERT INTO "django_geo_db_location" VALUES(50829,NULL,'Clarksburg, MO',21347,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50830,NULL,'Clarksburg, MO 65025',21347,222,NULL,43,29190,0);
INSERT INTO "django_geo_db_location" VALUES(50831,NULL,'Eldon, MO',21348,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50832,NULL,'Eldon, MO 65026',21348,222,NULL,43,29191,0);
INSERT INTO "django_geo_db_location" VALUES(50833,NULL,'Etterville, MO',21349,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50834,NULL,'Etterville, MO 65031',21349,222,NULL,43,29192,0);
INSERT INTO "django_geo_db_location" VALUES(50835,NULL,'Eugene, MO',21350,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50836,NULL,'Eugene, MO 65032',21350,222,NULL,43,29193,0);
INSERT INTO "django_geo_db_location" VALUES(50837,NULL,'Fortuna, MO',21351,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50838,NULL,'Fortuna, MO 65034',21351,222,NULL,43,29194,0);
INSERT INTO "django_geo_db_location" VALUES(50839,NULL,'Freeburg, MO',21352,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50840,NULL,'Freeburg, MO 65035',21352,222,NULL,43,29195,0);
INSERT INTO "django_geo_db_location" VALUES(50841,NULL,'Gasconade, MO',21353,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50842,NULL,'Gasconade, MO 65036',21353,222,NULL,43,29196,0);
INSERT INTO "django_geo_db_location" VALUES(50843,NULL,'Gravois Mills, MO',21354,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50844,NULL,'Gravois Mills, MO 65037',21354,222,NULL,43,29197,0);
INSERT INTO "django_geo_db_location" VALUES(50845,NULL,'Laurie, MO',21355,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50846,NULL,'Laurie, MO 65038',21355,222,NULL,43,29198,0);
INSERT INTO "django_geo_db_location" VALUES(50847,NULL,'Hartsburg, MO',21356,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50848,NULL,'Hartsburg, MO 65039',21356,222,NULL,43,29199,0);
INSERT INTO "django_geo_db_location" VALUES(50849,NULL,'Henley, MO',21357,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50850,NULL,'Henley, MO 65040',21357,222,NULL,43,29200,0);
INSERT INTO "django_geo_db_location" VALUES(50851,NULL,'Hermann, MO',21358,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50852,NULL,'Hermann, MO 65041',21358,222,NULL,43,29201,0);
INSERT INTO "django_geo_db_location" VALUES(50853,NULL,'High Point, MO',21359,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50854,NULL,'High Point, MO 65042',21359,222,NULL,43,29202,0);
INSERT INTO "django_geo_db_location" VALUES(50855,NULL,'Holts Summit, MO',21360,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50856,NULL,'Holts Summit, MO 65043',21360,222,NULL,43,29203,0);
INSERT INTO "django_geo_db_location" VALUES(50857,NULL,'Jamestown, MO',21361,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50858,NULL,'Jamestown, MO 65046',21361,222,NULL,43,29204,0);
INSERT INTO "django_geo_db_location" VALUES(50859,NULL,'Kaiser, MO',21362,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50860,NULL,'Kaiser, MO 65047',21362,222,NULL,43,29205,0);
INSERT INTO "django_geo_db_location" VALUES(50861,NULL,'Koeltztown, MO',21363,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50862,NULL,'Koeltztown, MO 65048',21363,222,NULL,43,29206,0);
INSERT INTO "django_geo_db_location" VALUES(50863,NULL,'Lake Ozark, MO',21364,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50864,NULL,'Lake Ozark, MO 65049',21364,222,NULL,43,29207,0);
INSERT INTO "django_geo_db_location" VALUES(50865,NULL,'Latham, MO',21365,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50866,NULL,'Latham, MO 65050',21365,222,NULL,43,29208,0);
INSERT INTO "django_geo_db_location" VALUES(50867,NULL,'Linn, MO',21366,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50868,NULL,'Linn, MO 65051',21366,222,NULL,43,29209,0);
INSERT INTO "django_geo_db_location" VALUES(50869,NULL,'Linn Creek, MO',21367,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50870,NULL,'Linn Creek, MO 65052',21367,222,NULL,43,29210,0);
INSERT INTO "django_geo_db_location" VALUES(50871,NULL,'Lohman, MO',21368,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50872,NULL,'Lohman, MO 65053',21368,222,NULL,43,29211,0);
INSERT INTO "django_geo_db_location" VALUES(50873,NULL,'Loose Creek, MO',21369,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50874,NULL,'Loose Creek, MO 65054',21369,222,NULL,43,29212,0);
INSERT INTO "django_geo_db_location" VALUES(50875,NULL,'McGirk, MO',21370,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50876,NULL,'McGirk, MO 65055',21370,222,NULL,43,29213,0);
INSERT INTO "django_geo_db_location" VALUES(50877,NULL,'Meta, MO',21371,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50878,NULL,'Meta, MO 65058',21371,222,NULL,43,29214,0);
INSERT INTO "django_geo_db_location" VALUES(50879,NULL,'Mokane, MO',21372,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50880,NULL,'Mokane, MO 65059',21372,222,NULL,43,29215,0);
INSERT INTO "django_geo_db_location" VALUES(50881,NULL,'Morrison, MO',21373,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50882,NULL,'Morrison, MO 65061',21373,222,NULL,43,29216,0);
INSERT INTO "django_geo_db_location" VALUES(50883,NULL,'Mount Sterling, MO',21374,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50884,NULL,'Mount Sterling, MO 65062',21374,222,NULL,43,29217,0);
INSERT INTO "django_geo_db_location" VALUES(50885,NULL,'New Bloomfield, MO',21375,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50886,NULL,'New Bloomfield, MO 65063',21375,222,NULL,43,29218,0);
INSERT INTO "django_geo_db_location" VALUES(50887,NULL,'Olean, MO',21376,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50888,NULL,'Olean, MO 65064',21376,222,NULL,43,29219,0);
INSERT INTO "django_geo_db_location" VALUES(50889,NULL,'Osage Beach, MO',21377,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50890,NULL,'Osage Beach, MO 65065',21377,222,NULL,43,29220,0);
INSERT INTO "django_geo_db_location" VALUES(50891,NULL,'Owensville, MO',21378,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50892,NULL,'Owensville, MO 65066',21378,222,NULL,43,29221,0);
INSERT INTO "django_geo_db_location" VALUES(50893,NULL,'Portland, MO',21379,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50894,NULL,'Portland, MO 65067',21379,222,NULL,43,29222,0);
INSERT INTO "django_geo_db_location" VALUES(50895,NULL,'Prairie Home, MO',21380,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50896,NULL,'Prairie Home, MO 65068',21380,222,NULL,43,29223,0);
INSERT INTO "django_geo_db_location" VALUES(50897,NULL,'Rhineland, MO',21381,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50898,NULL,'Rhineland, MO 65069',21381,222,NULL,43,29224,0);
INSERT INTO "django_geo_db_location" VALUES(50899,NULL,'Rocky Mount, MO',21382,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50900,NULL,'Rocky Mount, MO 65072',21382,222,NULL,43,29225,0);
INSERT INTO "django_geo_db_location" VALUES(50901,NULL,'Russellville, MO',21383,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50902,NULL,'Russellville, MO 65074',21383,222,NULL,43,29226,0);
INSERT INTO "django_geo_db_location" VALUES(50903,NULL,'Saint Elizabeth, MO',21384,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50904,NULL,'Saint Elizabeth, MO 65075',21384,222,NULL,43,29227,0);
INSERT INTO "django_geo_db_location" VALUES(50905,NULL,'Saint Thomas, MO',21385,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50906,NULL,'Saint Thomas, MO 65076',21385,222,NULL,43,29228,0);
INSERT INTO "django_geo_db_location" VALUES(50907,NULL,'Steedman, MO',21386,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50908,NULL,'Steedman, MO 65077',21386,222,NULL,43,29229,0);
INSERT INTO "django_geo_db_location" VALUES(50909,NULL,'Stover, MO',21387,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50910,NULL,'Stover, MO 65078',21387,222,NULL,43,29230,0);
INSERT INTO "django_geo_db_location" VALUES(50911,NULL,'Sunrise Beach, MO',21388,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50912,NULL,'Sunrise Beach, MO 65079',21388,222,NULL,43,29231,0);
INSERT INTO "django_geo_db_location" VALUES(50913,NULL,'Tebbetts, MO',21389,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50914,NULL,'Tebbetts, MO 65080',21389,222,NULL,43,29232,0);
INSERT INTO "django_geo_db_location" VALUES(50915,NULL,'Tipton, MO',21390,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50916,NULL,'Tipton, MO 65081',21390,222,NULL,43,29233,0);
INSERT INTO "django_geo_db_location" VALUES(50917,NULL,'Tuscumbia, MO',21391,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50918,NULL,'Tuscumbia, MO 65082',21391,222,NULL,43,29234,0);
INSERT INTO "django_geo_db_location" VALUES(50919,NULL,'Ulman, MO',21392,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50920,NULL,'Ulman, MO 65083',21392,222,NULL,43,29235,0);
INSERT INTO "django_geo_db_location" VALUES(50921,NULL,'Versailles, MO',21393,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50922,NULL,'Versailles, MO 65084',21393,222,NULL,43,29236,0);
INSERT INTO "django_geo_db_location" VALUES(50923,NULL,'Westphalia, MO',21394,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50924,NULL,'Westphalia, MO 65085',21394,222,NULL,43,29237,0);
INSERT INTO "django_geo_db_location" VALUES(50925,NULL,'Jefferson City, MO',21395,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50926,NULL,'Jefferson City, MO 65101',21395,222,NULL,43,29238,0);
INSERT INTO "django_geo_db_location" VALUES(50927,NULL,'Jefferson City, MO 65102',21395,222,NULL,43,29239,0);
INSERT INTO "django_geo_db_location" VALUES(50928,NULL,'Jefferson City, MO 65103',21395,222,NULL,43,29240,0);
INSERT INTO "django_geo_db_location" VALUES(50929,NULL,'Jefferson City, MO 65104',21395,222,NULL,43,29241,0);
INSERT INTO "django_geo_db_location" VALUES(50930,NULL,'Jefferson City, MO 65105',21395,222,NULL,43,29242,0);
INSERT INTO "django_geo_db_location" VALUES(50931,NULL,'Jefferson City, MO 65106',21395,222,NULL,43,29243,0);
INSERT INTO "django_geo_db_location" VALUES(50932,NULL,'Jefferson City, MO 65107',21395,222,NULL,43,29244,0);
INSERT INTO "django_geo_db_location" VALUES(50933,NULL,'Jefferson City, MO 65108',21395,222,NULL,43,29245,0);
INSERT INTO "django_geo_db_location" VALUES(50934,NULL,'Jefferson City, MO 65109',21395,222,NULL,43,29246,0);
INSERT INTO "django_geo_db_location" VALUES(50935,NULL,'Jefferson City, MO 65110',21395,222,NULL,43,29247,0);
INSERT INTO "django_geo_db_location" VALUES(50936,NULL,'Jefferson City, MO 65111',21395,222,NULL,43,29248,0);
INSERT INTO "django_geo_db_location" VALUES(50937,NULL,'Columbia, MO',21396,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50938,NULL,'Columbia, MO 65201',21396,222,NULL,43,29249,0);
INSERT INTO "django_geo_db_location" VALUES(50939,NULL,'Columbia, MO 65202',21396,222,NULL,43,29250,0);
INSERT INTO "django_geo_db_location" VALUES(50940,NULL,'Columbia, MO 65203',21396,222,NULL,43,29251,0);
INSERT INTO "django_geo_db_location" VALUES(50941,NULL,'Columbia, MO 65205',21396,222,NULL,43,29252,0);
INSERT INTO "django_geo_db_location" VALUES(50942,NULL,'Columbia, MO 65211',21396,222,NULL,43,29253,0);
INSERT INTO "django_geo_db_location" VALUES(50943,NULL,'Columbia, MO 65212',21396,222,NULL,43,29254,0);
INSERT INTO "django_geo_db_location" VALUES(50944,NULL,'Columbia, MO 65215',21396,222,NULL,43,29255,0);
INSERT INTO "django_geo_db_location" VALUES(50945,NULL,'Columbia, MO 65216',21396,222,NULL,43,29256,0);
INSERT INTO "django_geo_db_location" VALUES(50946,NULL,'Columbia, MO 65217',21396,222,NULL,43,29257,0);
INSERT INTO "django_geo_db_location" VALUES(50947,NULL,'Columbia, MO 65218',21396,222,NULL,43,29258,0);
INSERT INTO "django_geo_db_location" VALUES(50948,NULL,'Armstrong, MO',21397,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50949,NULL,'Armstrong, MO 65230',21397,222,NULL,43,29259,0);
INSERT INTO "django_geo_db_location" VALUES(50950,NULL,'Auxvasse, MO',21398,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50951,NULL,'Auxvasse, MO 65231',21398,222,NULL,43,29260,0);
INSERT INTO "django_geo_db_location" VALUES(50952,NULL,'Benton City, MO',21399,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50953,NULL,'Benton City, MO 65232',21399,222,NULL,43,29261,0);
INSERT INTO "django_geo_db_location" VALUES(50954,NULL,'Boonville, MO',21400,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50955,NULL,'Boonville, MO 65233',21400,222,NULL,43,29262,0);
INSERT INTO "django_geo_db_location" VALUES(50956,NULL,'Brunswick, MO',21401,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50957,NULL,'Brunswick, MO 65236',21401,222,NULL,43,29263,0);
INSERT INTO "django_geo_db_location" VALUES(50958,NULL,'Bunceton, MO',21402,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50959,NULL,'Bunceton, MO 65237',21402,222,NULL,43,29264,0);
INSERT INTO "django_geo_db_location" VALUES(50960,NULL,'Cairo, MO',21403,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50961,NULL,'Cairo, MO 65239',21403,222,NULL,43,29265,0);
INSERT INTO "django_geo_db_location" VALUES(50962,NULL,'Centralia, MO',21404,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50963,NULL,'Centralia, MO 65240',21404,222,NULL,43,29266,0);
INSERT INTO "django_geo_db_location" VALUES(50964,NULL,'Clark, MO',21405,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50965,NULL,'Clark, MO 65243',21405,222,NULL,43,29267,0);
INSERT INTO "django_geo_db_location" VALUES(50966,NULL,'Clifton Hill, MO',21406,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50967,NULL,'Clifton Hill, MO 65244',21406,222,NULL,43,29268,0);
INSERT INTO "django_geo_db_location" VALUES(50968,NULL,'Dalton, MO',21407,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50969,NULL,'Dalton, MO 65246',21407,222,NULL,43,29269,0);
INSERT INTO "django_geo_db_location" VALUES(50970,NULL,'Excello, MO',21408,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50971,NULL,'Excello, MO 65247',21408,222,NULL,43,29270,0);
INSERT INTO "django_geo_db_location" VALUES(50972,NULL,'Fayette, MO',21409,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50973,NULL,'Fayette, MO 65248',21409,222,NULL,43,29271,0);
INSERT INTO "django_geo_db_location" VALUES(50974,NULL,'Franklin, MO',21410,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50975,NULL,'Franklin, MO 65250',21410,222,NULL,43,29272,0);
INSERT INTO "django_geo_db_location" VALUES(50976,NULL,'Fulton, MO',21411,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50977,NULL,'Fulton, MO 65251',21411,222,NULL,43,29273,0);
INSERT INTO "django_geo_db_location" VALUES(50978,NULL,'Glasgow, MO',21412,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50979,NULL,'Glasgow, MO 65254',21412,222,NULL,43,29274,0);
INSERT INTO "django_geo_db_location" VALUES(50980,NULL,'Hallsville, MO',21413,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50981,NULL,'Hallsville, MO 65255',21413,222,NULL,43,29275,0);
INSERT INTO "django_geo_db_location" VALUES(50982,NULL,'Harrisburg, MO',21414,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50983,NULL,'Harrisburg, MO 65256',21414,222,NULL,43,29276,0);
INSERT INTO "django_geo_db_location" VALUES(50984,NULL,'Higbee, MO',21415,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50985,NULL,'Higbee, MO 65257',21415,222,NULL,43,29277,0);
INSERT INTO "django_geo_db_location" VALUES(50986,NULL,'Holliday, MO',21416,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50987,NULL,'Holliday, MO 65258',21416,222,NULL,43,29278,0);
INSERT INTO "django_geo_db_location" VALUES(50988,NULL,'Huntsville, MO',21417,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50989,NULL,'Huntsville, MO 65259',21417,222,NULL,43,29279,0);
INSERT INTO "django_geo_db_location" VALUES(50990,NULL,'Jacksonville, MO',21418,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50991,NULL,'Jacksonville, MO 65260',21418,222,NULL,43,29280,0);
INSERT INTO "django_geo_db_location" VALUES(50992,NULL,'Keytesville, MO',21419,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50993,NULL,'Keytesville, MO 65261',21419,222,NULL,43,29281,0);
INSERT INTO "django_geo_db_location" VALUES(50994,NULL,'Kingdom City, MO',21420,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50995,NULL,'Kingdom City, MO 65262',21420,222,NULL,43,29282,0);
INSERT INTO "django_geo_db_location" VALUES(50996,NULL,'Madison, MO',21421,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50997,NULL,'Madison, MO 65263',21421,222,NULL,43,29283,0);
INSERT INTO "django_geo_db_location" VALUES(50998,NULL,'Martinsburg, MO',21422,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(50999,NULL,'Martinsburg, MO 65264',21422,222,NULL,43,29284,0);
INSERT INTO "django_geo_db_location" VALUES(51000,NULL,'Mexico, MO',21423,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51001,NULL,'Mexico, MO 65265',21423,222,NULL,43,29285,0);
INSERT INTO "django_geo_db_location" VALUES(51002,NULL,'Moberly, MO',21424,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51003,NULL,'Moberly, MO 65270',21424,222,NULL,43,29286,0);
INSERT INTO "django_geo_db_location" VALUES(51004,NULL,'New Franklin, MO',21425,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51005,NULL,'New Franklin, MO 65274',21425,222,NULL,43,29287,0);
INSERT INTO "django_geo_db_location" VALUES(51006,NULL,'Paris, MO',21426,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51007,NULL,'Paris, MO 65275',21426,222,NULL,43,29288,0);
INSERT INTO "django_geo_db_location" VALUES(51008,NULL,'Pilot Grove, MO',21427,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51009,NULL,'Pilot Grove, MO 65276',21427,222,NULL,43,29289,0);
INSERT INTO "django_geo_db_location" VALUES(51010,NULL,'Renick, MO',21428,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51011,NULL,'Renick, MO 65278',21428,222,NULL,43,29290,0);
INSERT INTO "django_geo_db_location" VALUES(51012,NULL,'Rocheport, MO',21429,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51013,NULL,'Rocheport, MO 65279',21429,222,NULL,43,29291,0);
INSERT INTO "django_geo_db_location" VALUES(51014,NULL,'Rush Hill, MO',21430,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51015,NULL,'Rush Hill, MO 65280',21430,222,NULL,43,29292,0);
INSERT INTO "django_geo_db_location" VALUES(51016,NULL,'Salisbury, MO',21431,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51017,NULL,'Salisbury, MO 65281',21431,222,NULL,43,29293,0);
INSERT INTO "django_geo_db_location" VALUES(51018,NULL,'Santa Fe, MO',21432,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51019,NULL,'Santa Fe, MO 65282',21432,222,NULL,43,29294,0);
INSERT INTO "django_geo_db_location" VALUES(51020,NULL,'Stoutsville, MO',21433,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51021,NULL,'Stoutsville, MO 65283',21433,222,NULL,43,29295,0);
INSERT INTO "django_geo_db_location" VALUES(51022,NULL,'Sturgeon, MO',21434,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51023,NULL,'Sturgeon, MO 65284',21434,222,NULL,43,29296,0);
INSERT INTO "django_geo_db_location" VALUES(51024,NULL,'Thompson, MO',21435,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51025,NULL,'Thompson, MO 65285',21435,222,NULL,43,29297,0);
INSERT INTO "django_geo_db_location" VALUES(51026,NULL,'Triplett, MO',21436,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51027,NULL,'Triplett, MO 65286',21436,222,NULL,43,29298,0);
INSERT INTO "django_geo_db_location" VALUES(51028,NULL,'Wooldridge, MO',21437,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51029,NULL,'Wooldridge, MO 65287',21437,222,NULL,43,29299,0);
INSERT INTO "django_geo_db_location" VALUES(51030,NULL,'Mid Missouri, MO',21438,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51031,NULL,'Mid Missouri, MO 65299',21438,222,NULL,43,29300,0);
INSERT INTO "django_geo_db_location" VALUES(51032,NULL,'Sedalia, MO',21439,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51033,NULL,'Sedalia, MO 65301',21439,222,NULL,43,29301,0);
INSERT INTO "django_geo_db_location" VALUES(51034,NULL,'Sedalia, MO 65302',21439,222,NULL,43,29302,0);
INSERT INTO "django_geo_db_location" VALUES(51035,NULL,'Whiteman Air Force Base, MO',21440,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51036,NULL,'Whiteman Air Force Base, MO 65305',21440,222,NULL,43,29303,0);
INSERT INTO "django_geo_db_location" VALUES(51037,NULL,'Arrow Rock, MO',21441,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51038,NULL,'Arrow Rock, MO 65320',21441,222,NULL,43,29304,0);
INSERT INTO "django_geo_db_location" VALUES(51039,NULL,'Blackburn, MO',21442,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51040,NULL,'Blackburn, MO 65321',21442,222,NULL,43,29305,0);
INSERT INTO "django_geo_db_location" VALUES(51041,NULL,'Blackwater, MO',21443,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51042,NULL,'Blackwater, MO 65322',21443,222,NULL,43,29306,0);
INSERT INTO "django_geo_db_location" VALUES(51043,NULL,'Calhoun, MO',21444,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51044,NULL,'Calhoun, MO 65323',21444,222,NULL,43,29307,0);
INSERT INTO "django_geo_db_location" VALUES(51045,NULL,'Climax Springs, MO',21445,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51046,NULL,'Climax Springs, MO 65324',21445,222,NULL,43,29308,0);
INSERT INTO "django_geo_db_location" VALUES(51047,NULL,'Cole Camp, MO',21446,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51048,NULL,'Cole Camp, MO 65325',21446,222,NULL,43,29309,0);
INSERT INTO "django_geo_db_location" VALUES(51049,NULL,'Edwards, MO',21447,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51050,NULL,'Edwards, MO 65326',21447,222,NULL,43,29310,0);
INSERT INTO "django_geo_db_location" VALUES(51051,NULL,'Emma, MO',21448,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51052,NULL,'Emma, MO 65327',21448,222,NULL,43,29311,0);
INSERT INTO "django_geo_db_location" VALUES(51053,NULL,'Florence, MO',21449,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51054,NULL,'Florence, MO 65329',21449,222,NULL,43,29312,0);
INSERT INTO "django_geo_db_location" VALUES(51055,NULL,'Gilliam, MO',21450,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51056,NULL,'Gilliam, MO 65330',21450,222,NULL,43,29313,0);
INSERT INTO "django_geo_db_location" VALUES(51057,NULL,'Green Ridge, MO',21451,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51058,NULL,'Green Ridge, MO 65332',21451,222,NULL,43,29314,0);
INSERT INTO "django_geo_db_location" VALUES(51059,NULL,'Houstonia, MO',21452,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51060,NULL,'Houstonia, MO 65333',21452,222,NULL,43,29315,0);
INSERT INTO "django_geo_db_location" VALUES(51061,NULL,'Hughesville, MO',21453,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51062,NULL,'Hughesville, MO 65334',21453,222,NULL,43,29316,0);
INSERT INTO "django_geo_db_location" VALUES(51063,NULL,'Ionia, MO',21454,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51064,NULL,'Ionia, MO 65335',21454,222,NULL,43,29317,0);
INSERT INTO "django_geo_db_location" VALUES(51065,NULL,'Knob Noster, MO',21455,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51066,NULL,'Knob Noster, MO 65336',21455,222,NULL,43,29318,0);
INSERT INTO "django_geo_db_location" VALUES(51067,NULL,'La Monte, MO',21456,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51068,NULL,'La Monte, MO 65337',21456,222,NULL,43,29319,0);
INSERT INTO "django_geo_db_location" VALUES(51069,NULL,'Lincoln, MO',21457,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51070,NULL,'Lincoln, MO 65338',21457,222,NULL,43,29320,0);
INSERT INTO "django_geo_db_location" VALUES(51071,NULL,'Malta Bend, MO',21458,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51072,NULL,'Malta Bend, MO 65339',21458,222,NULL,43,29321,0);
INSERT INTO "django_geo_db_location" VALUES(51073,NULL,'Marshall, MO',21459,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51074,NULL,'Marshall, MO 65340',21459,222,NULL,43,29322,0);
INSERT INTO "django_geo_db_location" VALUES(51075,NULL,'Miami, MO',21460,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51076,NULL,'Miami, MO 65344',21460,222,NULL,43,29323,0);
INSERT INTO "django_geo_db_location" VALUES(51077,NULL,'Mora, MO',21461,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51078,NULL,'Mora, MO 65345',21461,222,NULL,43,29324,0);
INSERT INTO "django_geo_db_location" VALUES(51079,NULL,'Nelson, MO',21462,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51080,NULL,'Nelson, MO 65347',21462,222,NULL,43,29325,0);
INSERT INTO "django_geo_db_location" VALUES(51081,NULL,'Otterville, MO',21463,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51082,NULL,'Otterville, MO 65348',21463,222,NULL,43,29326,0);
INSERT INTO "django_geo_db_location" VALUES(51083,NULL,'Slater, MO',21464,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51084,NULL,'Slater, MO 65349',21464,222,NULL,43,29327,0);
INSERT INTO "django_geo_db_location" VALUES(51085,NULL,'Smithton, MO',21465,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51086,NULL,'Smithton, MO 65350',21465,222,NULL,43,29328,0);
INSERT INTO "django_geo_db_location" VALUES(51087,NULL,'Sweet Springs, MO',21466,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51088,NULL,'Sweet Springs, MO 65351',21466,222,NULL,43,29329,0);
INSERT INTO "django_geo_db_location" VALUES(51089,NULL,'Syracuse, MO',21467,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51090,NULL,'Syracuse, MO 65354',21467,222,NULL,43,29330,0);
INSERT INTO "django_geo_db_location" VALUES(51091,NULL,'Warsaw, MO',21468,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51092,NULL,'Warsaw, MO 65355',21468,222,NULL,43,29331,0);
INSERT INTO "django_geo_db_location" VALUES(51093,NULL,'Windsor, MO',21469,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51094,NULL,'Windsor, MO 65360',21469,222,NULL,43,29332,0);
INSERT INTO "django_geo_db_location" VALUES(51095,NULL,'Rolla, MO',21470,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51096,NULL,'Rolla, MO 65401',21470,222,NULL,43,29333,0);
INSERT INTO "django_geo_db_location" VALUES(51097,NULL,'Rolla, MO 65402',21470,222,NULL,43,29334,0);
INSERT INTO "django_geo_db_location" VALUES(51098,NULL,'Rolla, MO 65409',21470,222,NULL,43,29335,0);
INSERT INTO "django_geo_db_location" VALUES(51099,NULL,'Cuba, MO',21471,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51100,NULL,'Cuba, MO 65432',21471,222,NULL,43,29336,0);
INSERT INTO "django_geo_db_location" VALUES(51101,NULL,'Bendavis, MO',21472,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51102,NULL,'Bendavis, MO 65433',21472,222,NULL,43,29337,0);
INSERT INTO "django_geo_db_location" VALUES(51103,NULL,'Beulah, MO',21473,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51104,NULL,'Beulah, MO 65436',21473,222,NULL,43,29338,0);
INSERT INTO "django_geo_db_location" VALUES(51105,NULL,'Birch Tree, MO',21474,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51106,NULL,'Birch Tree, MO 65438',21474,222,NULL,43,29339,0);
INSERT INTO "django_geo_db_location" VALUES(51107,NULL,'Bixby, MO',21475,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51108,NULL,'Bixby, MO 65439',21475,222,NULL,43,29340,0);
INSERT INTO "django_geo_db_location" VALUES(51109,NULL,'Boss, MO',21476,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51110,NULL,'Boss, MO 65440',21476,222,NULL,43,29341,0);
INSERT INTO "django_geo_db_location" VALUES(51111,NULL,'Bourbon, MO',21477,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51112,NULL,'Bourbon, MO 65441',21477,222,NULL,43,29342,0);
INSERT INTO "django_geo_db_location" VALUES(51113,NULL,'Brinktown, MO',21478,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51114,NULL,'Brinktown, MO 65443',21478,222,NULL,43,29343,0);
INSERT INTO "django_geo_db_location" VALUES(51115,NULL,'Bucyrus, MO',21479,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51116,NULL,'Bucyrus, MO 65444',21479,222,NULL,43,29344,0);
INSERT INTO "django_geo_db_location" VALUES(51117,NULL,'Cherryville, MO',21480,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51118,NULL,'Cherryville, MO 65446',21480,222,NULL,43,29345,0);
INSERT INTO "django_geo_db_location" VALUES(51119,NULL,'Cook Station, MO',21481,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51120,NULL,'Cook Station, MO 65449',21481,222,NULL,43,29346,0);
INSERT INTO "django_geo_db_location" VALUES(51121,NULL,'Crocker, MO',21482,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51122,NULL,'Crocker, MO 65452',21482,222,NULL,43,29347,0);
INSERT INTO "django_geo_db_location" VALUES(51123,NULL,'Cuba, MO 65453',21471,222,NULL,43,29348,0);
INSERT INTO "django_geo_db_location" VALUES(51124,NULL,'Davisville, MO',21483,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51125,NULL,'Davisville, MO 65456',21483,222,NULL,43,29349,0);
INSERT INTO "django_geo_db_location" VALUES(51126,NULL,'Devils Elbow, MO',21484,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51127,NULL,'Devils Elbow, MO 65457',21484,222,NULL,43,29350,0);
INSERT INTO "django_geo_db_location" VALUES(51128,NULL,'Dixon, MO',21485,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51129,NULL,'Dixon, MO 65459',21485,222,NULL,43,29351,0);
INSERT INTO "django_geo_db_location" VALUES(51130,NULL,'Duke, MO',21486,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51131,NULL,'Duke, MO 65461',21486,222,NULL,43,29352,0);
INSERT INTO "django_geo_db_location" VALUES(51132,NULL,'Edgar Springs, MO',21487,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51133,NULL,'Edgar Springs, MO 65462',21487,222,NULL,43,29353,0);
INSERT INTO "django_geo_db_location" VALUES(51134,NULL,'Eldridge, MO',21488,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51135,NULL,'Eldridge, MO 65463',21488,222,NULL,43,29354,0);
INSERT INTO "django_geo_db_location" VALUES(51136,NULL,'Elk Creek, MO',21489,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51137,NULL,'Elk Creek, MO 65464',21489,222,NULL,43,29355,0);
INSERT INTO "django_geo_db_location" VALUES(51138,NULL,'Eminence, MO',21490,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51139,NULL,'Eminence, MO 65466',21490,222,NULL,43,29356,0);
INSERT INTO "django_geo_db_location" VALUES(51140,NULL,'Eunice, MO',21491,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51141,NULL,'Eunice, MO 65468',21491,222,NULL,43,29357,0);
INSERT INTO "django_geo_db_location" VALUES(51142,NULL,'Falcon, MO',21492,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51143,NULL,'Falcon, MO 65470',21492,222,NULL,43,29358,0);
INSERT INTO "django_geo_db_location" VALUES(51144,NULL,'Fort Leonard Wood, MO',21493,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51145,NULL,'Fort Leonard Wood, MO 65473',21493,222,NULL,43,29359,0);
INSERT INTO "django_geo_db_location" VALUES(51146,NULL,'Hartshorn, MO',21494,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51147,NULL,'Hartshorn, MO 65479',21494,222,NULL,43,29360,0);
INSERT INTO "django_geo_db_location" VALUES(51148,NULL,'Houston, MO',21495,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51149,NULL,'Houston, MO 65483',21495,222,NULL,43,29361,0);
INSERT INTO "django_geo_db_location" VALUES(51150,NULL,'Huggins, MO',21496,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51151,NULL,'Huggins, MO 65484',21496,222,NULL,43,29362,0);
INSERT INTO "django_geo_db_location" VALUES(51152,NULL,'Iberia, MO',21497,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51153,NULL,'Iberia, MO 65486',21497,222,NULL,43,29363,0);
INSERT INTO "django_geo_db_location" VALUES(51154,NULL,'Dixon, MO 65495',21485,222,NULL,43,29364,0);
INSERT INTO "django_geo_db_location" VALUES(51155,NULL,'Jadwin, MO',21498,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51156,NULL,'Jadwin, MO 65501',21498,222,NULL,43,29365,0);
INSERT INTO "django_geo_db_location" VALUES(51157,NULL,'Jerome, MO',21499,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51158,NULL,'Jerome, MO 65529',21499,222,NULL,43,29366,0);
INSERT INTO "django_geo_db_location" VALUES(51159,NULL,'Gilliam, MO 65530',21450,222,NULL,43,29367,0);
INSERT INTO "django_geo_db_location" VALUES(51160,NULL,'Lake Spring, MO',21500,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51161,NULL,'Lake Spring, MO 65532',21500,222,NULL,43,29368,0);
INSERT INTO "django_geo_db_location" VALUES(51162,NULL,'Laquey, MO',21501,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51163,NULL,'Laquey, MO 65534',21501,222,NULL,43,29369,0);
INSERT INTO "django_geo_db_location" VALUES(51164,NULL,'Leasburg, MO',21502,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51165,NULL,'Leasburg, MO 65535',21502,222,NULL,43,29370,0);
INSERT INTO "django_geo_db_location" VALUES(51166,NULL,'Lebanon, MO',21503,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51167,NULL,'Lebanon, MO 65536',21503,222,NULL,43,29371,0);
INSERT INTO "django_geo_db_location" VALUES(51168,NULL,'Lecoma, MO',21504,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51169,NULL,'Lecoma, MO 65540',21504,222,NULL,43,29372,0);
INSERT INTO "django_geo_db_location" VALUES(51170,NULL,'Lenox, MO',21505,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51171,NULL,'Lenox, MO 65541',21505,222,NULL,43,29373,0);
INSERT INTO "django_geo_db_location" VALUES(51172,NULL,'Licking, MO',21506,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51173,NULL,'Licking, MO 65542',21506,222,NULL,43,29374,0);
INSERT INTO "django_geo_db_location" VALUES(51174,NULL,'Lynchburg, MO',21507,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51175,NULL,'Lynchburg, MO 65543',21507,222,NULL,43,29375,0);
INSERT INTO "django_geo_db_location" VALUES(51176,NULL,'Montier, MO',21508,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51177,NULL,'Montier, MO 65546',21508,222,NULL,43,29376,0);
INSERT INTO "django_geo_db_location" VALUES(51178,NULL,'Mountain View, MO',21509,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51179,NULL,'Mountain View, MO 65548',21509,222,NULL,43,29377,0);
INSERT INTO "django_geo_db_location" VALUES(51180,NULL,'Newburg, MO',21510,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51181,NULL,'Newburg, MO 65550',21510,222,NULL,43,29378,0);
INSERT INTO "django_geo_db_location" VALUES(51182,NULL,'Plato, MO',21511,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51183,NULL,'Plato, MO 65552',21511,222,NULL,43,29379,0);
INSERT INTO "django_geo_db_location" VALUES(51184,NULL,'Raymondville, MO',21512,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51185,NULL,'Raymondville, MO 65555',21512,222,NULL,43,29380,0);
INSERT INTO "django_geo_db_location" VALUES(51186,NULL,'Richland, MO',21513,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51187,NULL,'Richland, MO 65556',21513,222,NULL,43,29381,0);
INSERT INTO "django_geo_db_location" VALUES(51188,NULL,'Roby, MO',21514,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51189,NULL,'Roby, MO 65557',21514,222,NULL,43,29382,0);
INSERT INTO "django_geo_db_location" VALUES(51190,NULL,'Saint James, MO',21515,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51191,NULL,'Saint James, MO 65559',21515,222,NULL,43,29383,0);
INSERT INTO "django_geo_db_location" VALUES(51192,NULL,'Salem, MO',21516,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51193,NULL,'Salem, MO 65560',21516,222,NULL,43,29384,0);
INSERT INTO "django_geo_db_location" VALUES(51194,NULL,'Solo, MO',21517,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51195,NULL,'Solo, MO 65564',21517,222,NULL,43,29385,0);
INSERT INTO "django_geo_db_location" VALUES(51196,NULL,'Steelville, MO',21518,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51197,NULL,'Steelville, MO 65565',21518,222,NULL,43,29386,0);
INSERT INTO "django_geo_db_location" VALUES(51198,NULL,'Viburnum, MO',21519,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51199,NULL,'Viburnum, MO 65566',21519,222,NULL,43,29387,0);
INSERT INTO "django_geo_db_location" VALUES(51200,NULL,'Stoutland, MO',21520,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51201,NULL,'Stoutland, MO 65567',21520,222,NULL,43,29388,0);
INSERT INTO "django_geo_db_location" VALUES(51202,NULL,'Success, MO',21521,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51203,NULL,'Success, MO 65570',21521,222,NULL,43,29389,0);
INSERT INTO "django_geo_db_location" VALUES(51204,NULL,'Summersville, MO',21522,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51205,NULL,'Summersville, MO 65571',21522,222,NULL,43,29390,0);
INSERT INTO "django_geo_db_location" VALUES(51206,NULL,'Swedeborg, MO',21523,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51207,NULL,'Swedeborg, MO 65572',21523,222,NULL,43,29391,0);
INSERT INTO "django_geo_db_location" VALUES(51208,NULL,'Teresita, MO',21524,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51209,NULL,'Teresita, MO 65573',21524,222,NULL,43,29392,0);
INSERT INTO "django_geo_db_location" VALUES(51210,NULL,'West Plains, MO',21525,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51211,NULL,'West Plains, MO 65575',21525,222,NULL,43,29393,0);
INSERT INTO "django_geo_db_location" VALUES(51212,NULL,'Vichy, MO',21526,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51213,NULL,'Vichy, MO 65580',21526,222,NULL,43,29394,0);
INSERT INTO "django_geo_db_location" VALUES(51214,NULL,'Vienna, MO',21527,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51215,NULL,'Vienna, MO 65582',21527,222,NULL,43,29395,0);
INSERT INTO "django_geo_db_location" VALUES(51216,NULL,'Waynesville, MO',21528,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51217,NULL,'Waynesville, MO 65583',21528,222,NULL,43,29396,0);
INSERT INTO "django_geo_db_location" VALUES(51218,NULL,'St. Robert, MO',21529,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51219,NULL,'St. Robert, MO 65584',21529,222,NULL,43,29397,0);
INSERT INTO "django_geo_db_location" VALUES(51220,NULL,'Wesco, MO',21530,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51221,NULL,'Wesco, MO 65586',21530,222,NULL,43,29398,0);
INSERT INTO "django_geo_db_location" VALUES(51222,NULL,'Waynesville, MO 65587',21528,222,NULL,43,29399,0);
INSERT INTO "django_geo_db_location" VALUES(51223,NULL,'Winona, MO',21531,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51224,NULL,'Winona, MO 65588',21531,222,NULL,43,29400,0);
INSERT INTO "django_geo_db_location" VALUES(51225,NULL,'Yukon, MO',21532,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51226,NULL,'Yukon, MO 65589',21532,222,NULL,43,29401,0);
INSERT INTO "django_geo_db_location" VALUES(51227,NULL,'Long Lane, MO',21533,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51228,NULL,'Long Lane, MO 65590',21533,222,NULL,43,29402,0);
INSERT INTO "django_geo_db_location" VALUES(51229,NULL,'Montreal, MO',21534,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51230,NULL,'Montreal, MO 65591',21534,222,NULL,43,29403,0);
INSERT INTO "django_geo_db_location" VALUES(51231,NULL,'Aldrich, MO',21535,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51232,NULL,'Aldrich, MO 65601',21535,222,NULL,43,29404,0);
INSERT INTO "django_geo_db_location" VALUES(51233,NULL,'Springfield, MO',21536,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51234,NULL,'Springfield, MO 65602',21536,222,NULL,43,29405,0);
INSERT INTO "django_geo_db_location" VALUES(51235,NULL,'Arcola, MO',21537,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51236,NULL,'Arcola, MO 65603',21537,222,NULL,43,29406,0);
INSERT INTO "django_geo_db_location" VALUES(51237,NULL,'Ash Grove, MO',21538,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51238,NULL,'Ash Grove, MO 65604',21538,222,NULL,43,29407,0);
INSERT INTO "django_geo_db_location" VALUES(51239,NULL,'Aurora, MO',21539,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51240,NULL,'Aurora, MO 65605',21539,222,NULL,43,29408,0);
INSERT INTO "django_geo_db_location" VALUES(51241,NULL,'Alton, MO',21540,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51242,NULL,'Alton, MO 65606',21540,222,NULL,43,29409,0);
INSERT INTO "django_geo_db_location" VALUES(51243,NULL,'Caplinger Mills, MO',21541,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51244,NULL,'Caplinger Mills, MO 65607',21541,222,NULL,43,29410,0);
INSERT INTO "django_geo_db_location" VALUES(51245,NULL,'Ava, MO',21542,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51246,NULL,'Ava, MO 65608',21542,222,NULL,43,29411,0);
INSERT INTO "django_geo_db_location" VALUES(51247,NULL,'Bakersfield, MO',21543,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51248,NULL,'Bakersfield, MO 65609',21543,222,NULL,43,29412,0);
INSERT INTO "django_geo_db_location" VALUES(51249,NULL,'Billings, MO',21544,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51250,NULL,'Billings, MO 65610',21544,222,NULL,43,29413,0);
INSERT INTO "django_geo_db_location" VALUES(51251,NULL,'Blue Eye, MO',21545,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51252,NULL,'Blue Eye, MO 65611',21545,222,NULL,43,29414,0);
INSERT INTO "django_geo_db_location" VALUES(51253,NULL,'Bois D Arc, MO',21546,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51254,NULL,'Bois D Arc, MO 65612',21546,222,NULL,43,29415,0);
INSERT INTO "django_geo_db_location" VALUES(51255,NULL,'Bolivar, MO',21547,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51256,NULL,'Bolivar, MO 65613',21547,222,NULL,43,29416,0);
INSERT INTO "django_geo_db_location" VALUES(51257,NULL,'Bradleyville, MO',21548,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51258,NULL,'Bradleyville, MO 65614',21548,222,NULL,43,29417,0);
INSERT INTO "django_geo_db_location" VALUES(51259,NULL,'Branson, MO',21549,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51260,NULL,'Branson, MO 65615',21549,222,NULL,43,29418,0);
INSERT INTO "django_geo_db_location" VALUES(51261,NULL,'Branson, MO 65616',21549,222,NULL,43,29419,0);
INSERT INTO "django_geo_db_location" VALUES(51262,NULL,'Brighton, MO',21550,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51263,NULL,'Brighton, MO 65617',21550,222,NULL,43,29420,0);
INSERT INTO "django_geo_db_location" VALUES(51264,NULL,'Brixey, MO',21551,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51265,NULL,'Brixey, MO 65618',21551,222,NULL,43,29421,0);
INSERT INTO "django_geo_db_location" VALUES(51266,NULL,'Brookline Station, MO',21552,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51267,NULL,'Brookline Station, MO 65619',21552,222,NULL,43,29422,0);
INSERT INTO "django_geo_db_location" VALUES(51268,NULL,'Bruner, MO',21553,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51269,NULL,'Bruner, MO 65620',21553,222,NULL,43,29423,0);
INSERT INTO "django_geo_db_location" VALUES(51270,NULL,'Buffalo, MO',21554,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51271,NULL,'Buffalo, MO 65622',21554,222,NULL,43,29424,0);
INSERT INTO "django_geo_db_location" VALUES(51272,NULL,'Butterfield, MO',21555,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51273,NULL,'Butterfield, MO 65623',21555,222,NULL,43,29425,0);
INSERT INTO "django_geo_db_location" VALUES(51274,NULL,'Cape Fair, MO',21556,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51275,NULL,'Cape Fair, MO 65624',21556,222,NULL,43,29426,0);
INSERT INTO "django_geo_db_location" VALUES(51276,NULL,'Cassville, MO',21557,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51277,NULL,'Cassville, MO 65625',21557,222,NULL,43,29427,0);
INSERT INTO "django_geo_db_location" VALUES(51278,NULL,'Caulfield, MO',21558,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51279,NULL,'Caulfield, MO 65626',21558,222,NULL,43,29428,0);
INSERT INTO "django_geo_db_location" VALUES(51280,NULL,'Cedarcreek, MO',21559,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51281,NULL,'Cedarcreek, MO 65627',21559,222,NULL,43,29429,0);
INSERT INTO "django_geo_db_location" VALUES(51282,NULL,'Chadwick, MO',21560,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51283,NULL,'Chadwick, MO 65629',21560,222,NULL,43,29430,0);
INSERT INTO "django_geo_db_location" VALUES(51284,NULL,'Chestnutridge, MO',21561,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51285,NULL,'Chestnutridge, MO 65630',21561,222,NULL,43,29431,0);
INSERT INTO "django_geo_db_location" VALUES(51286,NULL,'Clever, MO',21562,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51287,NULL,'Clever, MO 65631',21562,222,NULL,43,29432,0);
INSERT INTO "django_geo_db_location" VALUES(51288,NULL,'Conway, MO',21563,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51289,NULL,'Conway, MO 65632',21563,222,NULL,43,29433,0);
INSERT INTO "django_geo_db_location" VALUES(51290,NULL,'Crane, MO',21564,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51291,NULL,'Crane, MO 65633',21564,222,NULL,43,29434,0);
INSERT INTO "django_geo_db_location" VALUES(51292,NULL,'Cross Timbers, MO',21565,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51293,NULL,'Cross Timbers, MO 65634',21565,222,NULL,43,29435,0);
INSERT INTO "django_geo_db_location" VALUES(51294,NULL,'Dadeville, MO',21566,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51295,NULL,'Dadeville, MO 65635',21566,222,NULL,43,29436,0);
INSERT INTO "django_geo_db_location" VALUES(51296,NULL,'Diggins, MO',21567,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51297,NULL,'Diggins, MO 65636',21567,222,NULL,43,29437,0);
INSERT INTO "django_geo_db_location" VALUES(51298,NULL,'Dora, MO',21568,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51299,NULL,'Dora, MO 65637',21568,222,NULL,43,29438,0);
INSERT INTO "django_geo_db_location" VALUES(51300,NULL,'Drury, MO',21569,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51301,NULL,'Drury, MO 65638',21569,222,NULL,43,29439,0);
INSERT INTO "django_geo_db_location" VALUES(51302,NULL,'Dunnegan, MO',21570,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51303,NULL,'Dunnegan, MO 65640',21570,222,NULL,43,29440,0);
INSERT INTO "django_geo_db_location" VALUES(51304,NULL,'Eagle Rock, MO',21571,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51305,NULL,'Eagle Rock, MO 65641',21571,222,NULL,43,29441,0);
INSERT INTO "django_geo_db_location" VALUES(51306,NULL,'Elkland, MO',21572,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51307,NULL,'Elkland, MO 65644',21572,222,NULL,43,29442,0);
INSERT INTO "django_geo_db_location" VALUES(51308,NULL,'Eudora, MO',21573,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51309,NULL,'Eudora, MO 65645',21573,222,NULL,43,29443,0);
INSERT INTO "django_geo_db_location" VALUES(51310,NULL,'Everton, MO',21574,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51311,NULL,'Everton, MO 65646',21574,222,NULL,43,29444,0);
INSERT INTO "django_geo_db_location" VALUES(51312,NULL,'Exeter, MO',21575,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51313,NULL,'Exeter, MO 65647',21575,222,NULL,43,29445,0);
INSERT INTO "django_geo_db_location" VALUES(51314,NULL,'Fair Grove, MO',21576,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51315,NULL,'Fair Grove, MO 65648',21576,222,NULL,43,29446,0);
INSERT INTO "django_geo_db_location" VALUES(51316,NULL,'Fair Play, MO',21577,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51317,NULL,'Fair Play, MO 65649',21577,222,NULL,43,29447,0);
INSERT INTO "django_geo_db_location" VALUES(51318,NULL,'Flemington, MO',21578,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51319,NULL,'Flemington, MO 65650',21578,222,NULL,43,29448,0);
INSERT INTO "django_geo_db_location" VALUES(51320,NULL,'Fordland, MO',21579,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51321,NULL,'Fordland, MO 65652',21579,222,NULL,43,29449,0);
INSERT INTO "django_geo_db_location" VALUES(51322,NULL,'Forsyth, MO',21580,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51323,NULL,'Forsyth, MO 65653',21580,222,NULL,43,29450,0);
INSERT INTO "django_geo_db_location" VALUES(51324,NULL,'Freistatt, MO',21581,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51325,NULL,'Freistatt, MO 65654',21581,222,NULL,43,29451,0);
INSERT INTO "django_geo_db_location" VALUES(51326,NULL,'Gainesville, MO',21582,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51327,NULL,'Gainesville, MO 65655',21582,222,NULL,43,29452,0);
INSERT INTO "django_geo_db_location" VALUES(51328,NULL,'Galena, MO',21583,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51329,NULL,'Galena, MO 65656',21583,222,NULL,43,29453,0);
INSERT INTO "django_geo_db_location" VALUES(51330,NULL,'Garrison, MO',21584,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51331,NULL,'Garrison, MO 65657',21584,222,NULL,43,29454,0);
INSERT INTO "django_geo_db_location" VALUES(51332,NULL,'Golden, MO',21585,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51333,NULL,'Golden, MO 65658',21585,222,NULL,43,29455,0);
INSERT INTO "django_geo_db_location" VALUES(51334,NULL,'Goodson, MO',21586,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51335,NULL,'Goodson, MO 65659',21586,222,NULL,43,29456,0);
INSERT INTO "django_geo_db_location" VALUES(51336,NULL,'Graff, MO',21587,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51337,NULL,'Graff, MO 65660',21587,222,NULL,43,29457,0);
INSERT INTO "django_geo_db_location" VALUES(51338,NULL,'Greenfield, MO',21588,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51339,NULL,'Greenfield, MO 65661',21588,222,NULL,43,29458,0);
INSERT INTO "django_geo_db_location" VALUES(51340,NULL,'Grovespring, MO',21589,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51341,NULL,'Grovespring, MO 65662',21589,222,NULL,43,29459,0);
INSERT INTO "django_geo_db_location" VALUES(51342,NULL,'Half Way, MO',21590,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51343,NULL,'Half Way, MO 65663',21590,222,NULL,43,29460,0);
INSERT INTO "django_geo_db_location" VALUES(51344,NULL,'Halltown, MO',21591,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51345,NULL,'Halltown, MO 65664',21591,222,NULL,43,29461,0);
INSERT INTO "django_geo_db_location" VALUES(51346,NULL,'Hardenville, MO',21592,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51347,NULL,'Hardenville, MO 65666',21592,222,NULL,43,29462,0);
INSERT INTO "django_geo_db_location" VALUES(51348,NULL,'Hartville, MO',21593,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51349,NULL,'Hartville, MO 65667',21593,222,NULL,43,29463,0);
INSERT INTO "django_geo_db_location" VALUES(51350,NULL,'Hermitage, MO',21594,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51351,NULL,'Hermitage, MO 65668',21594,222,NULL,43,29464,0);
INSERT INTO "django_geo_db_location" VALUES(51352,NULL,'Highlandville, MO',21595,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51353,NULL,'Highlandville, MO 65669',21595,222,NULL,43,29465,0);
INSERT INTO "django_geo_db_location" VALUES(51354,NULL,'Hollister, MO',21596,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51355,NULL,'Hollister, MO 65672',21596,222,NULL,43,29466,0);
INSERT INTO "django_geo_db_location" VALUES(51356,NULL,'Hollister, MO 65673',21596,222,NULL,43,29467,0);
INSERT INTO "django_geo_db_location" VALUES(51357,NULL,'Humansville, MO',21597,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51358,NULL,'Humansville, MO 65674',21597,222,NULL,43,29468,0);
INSERT INTO "django_geo_db_location" VALUES(51359,NULL,'Hurley, MO',21598,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51360,NULL,'Hurley, MO 65675',21598,222,NULL,43,29469,0);
INSERT INTO "django_geo_db_location" VALUES(51361,NULL,'Isabella, MO',21599,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51362,NULL,'Isabella, MO 65676',21599,222,NULL,43,29470,0);
INSERT INTO "django_geo_db_location" VALUES(51363,NULL,'Kirbyville, MO',21600,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51364,NULL,'Kirbyville, MO 65679',21600,222,NULL,43,29471,0);
INSERT INTO "django_geo_db_location" VALUES(51365,NULL,'Kissee Mills, MO',21601,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51366,NULL,'Kissee Mills, MO 65680',21601,222,NULL,43,29472,0);
INSERT INTO "django_geo_db_location" VALUES(51367,NULL,'Lampe, MO',21602,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51368,NULL,'Lampe, MO 65681',21602,222,NULL,43,29473,0);
INSERT INTO "django_geo_db_location" VALUES(51369,NULL,'Lockwood, MO',21603,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51370,NULL,'Lockwood, MO 65682',21603,222,NULL,43,29474,0);
INSERT INTO "django_geo_db_location" VALUES(51371,NULL,'Morris, MO',21604,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51372,NULL,'Morris, MO 65684',21604,222,NULL,43,29475,0);
INSERT INTO "django_geo_db_location" VALUES(51373,NULL,'Louisburg, MO',21605,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51374,NULL,'Louisburg, MO 65685',21605,222,NULL,43,29476,0);
INSERT INTO "django_geo_db_location" VALUES(51375,NULL,'Kimberling City, MO',21606,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51376,NULL,'Kimberling City, MO 65686',21606,222,NULL,43,29477,0);
INSERT INTO "django_geo_db_location" VALUES(51377,NULL,'Brandsville, MO',21607,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51378,NULL,'Brandsville, MO 65688',21607,222,NULL,43,29478,0);
INSERT INTO "django_geo_db_location" VALUES(51379,NULL,'Cabool, MO',21608,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51380,NULL,'Cabool, MO 65689',21608,222,NULL,43,29479,0);
INSERT INTO "django_geo_db_location" VALUES(51381,NULL,'Couch, MO',21609,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51382,NULL,'Couch, MO 65690',21609,222,NULL,43,29480,0);
INSERT INTO "django_geo_db_location" VALUES(51383,NULL,'Koshkonong, MO',21610,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51384,NULL,'Koshkonong, MO 65692',21610,222,NULL,43,29481,0);
INSERT INTO "django_geo_db_location" VALUES(51385,NULL,'McClurg, MO',21611,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51386,NULL,'McClurg, MO 65701',21611,222,NULL,43,29482,0);
INSERT INTO "django_geo_db_location" VALUES(51387,NULL,'Macomb, MO',21612,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51388,NULL,'Macomb, MO 65702',21612,222,NULL,43,29483,0);
INSERT INTO "django_geo_db_location" VALUES(51389,NULL,'Mansfield, MO',21613,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51390,NULL,'Mansfield, MO 65704',21613,222,NULL,43,29484,0);
INSERT INTO "django_geo_db_location" VALUES(51391,NULL,'Marionville, MO',21614,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51392,NULL,'Marionville, MO 65705',21614,222,NULL,43,29485,0);
INSERT INTO "django_geo_db_location" VALUES(51393,NULL,'Marshfield, MO',21615,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51394,NULL,'Marshfield, MO 65706',21615,222,NULL,43,29486,0);
INSERT INTO "django_geo_db_location" VALUES(51395,NULL,'Miller, MO',21616,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51396,NULL,'Miller, MO 65707',21616,222,NULL,43,29487,0);
INSERT INTO "django_geo_db_location" VALUES(51397,NULL,'Monett, MO',21617,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51398,NULL,'Monett, MO 65708',21617,222,NULL,43,29488,0);
INSERT INTO "django_geo_db_location" VALUES(51399,NULL,'Morrisville, MO',21618,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51400,NULL,'Morrisville, MO 65710',21618,222,NULL,43,29489,0);
INSERT INTO "django_geo_db_location" VALUES(51401,NULL,'Mountain Grove, MO',21619,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51402,NULL,'Mountain Grove, MO 65711',21619,222,NULL,43,29490,0);
INSERT INTO "django_geo_db_location" VALUES(51403,NULL,'Mount Vernon, MO',21620,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51404,NULL,'Mount Vernon, MO 65712',21620,222,NULL,43,29491,0);
INSERT INTO "django_geo_db_location" VALUES(51405,NULL,'Niangua, MO',21621,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51406,NULL,'Niangua, MO 65713',21621,222,NULL,43,29492,0);
INSERT INTO "django_geo_db_location" VALUES(51407,NULL,'Nixa, MO',21622,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51408,NULL,'Nixa, MO 65714',21622,222,NULL,43,29493,0);
INSERT INTO "django_geo_db_location" VALUES(51409,NULL,'Noble, MO',21623,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51410,NULL,'Noble, MO 65715',21623,222,NULL,43,29494,0);
INSERT INTO "django_geo_db_location" VALUES(51411,NULL,'Norwood, MO',21624,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51412,NULL,'Norwood, MO 65717',21624,222,NULL,43,29495,0);
INSERT INTO "django_geo_db_location" VALUES(51413,NULL,'Oldfield, MO',21625,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51414,NULL,'Oldfield, MO 65720',21625,222,NULL,43,29496,0);
INSERT INTO "django_geo_db_location" VALUES(51415,NULL,'Ozark, MO',21626,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51416,NULL,'Ozark, MO 65721',21626,222,NULL,43,29497,0);
INSERT INTO "django_geo_db_location" VALUES(51417,NULL,'Phillipsburg, MO',21627,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51418,NULL,'Phillipsburg, MO 65722',21627,222,NULL,43,29498,0);
INSERT INTO "django_geo_db_location" VALUES(51419,NULL,'Pierce City, MO',21628,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51420,NULL,'Pierce City, MO 65723',21628,222,NULL,43,29499,0);
INSERT INTO "django_geo_db_location" VALUES(51421,NULL,'Pittsburg, MO',21629,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51422,NULL,'Pittsburg, MO 65724',21629,222,NULL,43,29500,0);
INSERT INTO "django_geo_db_location" VALUES(51423,NULL,'Pleasant Hope, MO',21630,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51424,NULL,'Pleasant Hope, MO 65725',21630,222,NULL,43,29501,0);
INSERT INTO "django_geo_db_location" VALUES(51425,NULL,'Point Lookout, MO',21631,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51426,NULL,'Point Lookout, MO 65726',21631,222,NULL,43,29502,0);
INSERT INTO "django_geo_db_location" VALUES(51427,NULL,'Polk, MO 65727',21157,222,NULL,43,29503,0);
INSERT INTO "django_geo_db_location" VALUES(51428,NULL,'Ponce De Leon, MO',21632,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51429,NULL,'Ponce De Leon, MO 65728',21632,222,NULL,43,29504,0);
INSERT INTO "django_geo_db_location" VALUES(51430,NULL,'Pontiac, MO',21633,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51431,NULL,'Pontiac, MO 65729',21633,222,NULL,43,29505,0);
INSERT INTO "django_geo_db_location" VALUES(51432,NULL,'Powell, MO',21634,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51433,NULL,'Powell, MO 65730',21634,222,NULL,43,29506,0);
INSERT INTO "django_geo_db_location" VALUES(51434,NULL,'Powersite, MO',21635,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51435,NULL,'Powersite, MO 65731',21635,222,NULL,43,29507,0);
INSERT INTO "django_geo_db_location" VALUES(51436,NULL,'Preston, MO',21636,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51437,NULL,'Preston, MO 65732',21636,222,NULL,43,29508,0);
INSERT INTO "django_geo_db_location" VALUES(51438,NULL,'Protem, AR',21637,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51439,NULL,'Protem, AR 65733',21637,222,NULL,4,29509,0);
INSERT INTO "django_geo_db_location" VALUES(51440,NULL,'Purdy, MO',21638,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51441,NULL,'Purdy, MO 65734',21638,222,NULL,43,29510,0);
INSERT INTO "django_geo_db_location" VALUES(51442,NULL,'Quincy, MO',21639,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51443,NULL,'Quincy, MO 65735',21639,222,NULL,43,29511,0);
INSERT INTO "django_geo_db_location" VALUES(51444,NULL,'Reeds Spring, MO',21640,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51445,NULL,'Reeds Spring, MO 65737',21640,222,NULL,43,29512,0);
INSERT INTO "django_geo_db_location" VALUES(51446,NULL,'Republic, MO',21641,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51447,NULL,'Republic, MO 65738',21641,222,NULL,43,29513,0);
INSERT INTO "django_geo_db_location" VALUES(51448,NULL,'Ridgedale, MO',21642,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51449,NULL,'Ridgedale, MO 65739',21642,222,NULL,43,29514,0);
INSERT INTO "django_geo_db_location" VALUES(51450,NULL,'Rockaway Beach, MO',21643,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51451,NULL,'Rockaway Beach, MO 65740',21643,222,NULL,43,29515,0);
INSERT INTO "django_geo_db_location" VALUES(51452,NULL,'Rockbridge, MO',21644,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51453,NULL,'Rockbridge, MO 65741',21644,222,NULL,43,29516,0);
INSERT INTO "django_geo_db_location" VALUES(51454,NULL,'Rogersville, MO',21645,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51455,NULL,'Rogersville, MO 65742',21645,222,NULL,43,29517,0);
INSERT INTO "django_geo_db_location" VALUES(51456,NULL,'Rueter, MO',21646,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51457,NULL,'Rueter, MO 65744',21646,222,NULL,43,29518,0);
INSERT INTO "django_geo_db_location" VALUES(51458,NULL,'Seligman, MO',21647,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51459,NULL,'Seligman, MO 65745',21647,222,NULL,43,29519,0);
INSERT INTO "django_geo_db_location" VALUES(51460,NULL,'Seymour, MO',21648,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51461,NULL,'Seymour, MO 65746',21648,222,NULL,43,29520,0);
INSERT INTO "django_geo_db_location" VALUES(51462,NULL,'Shell Knob, MO',21649,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51463,NULL,'Shell Knob, MO 65747',21649,222,NULL,43,29521,0);
INSERT INTO "django_geo_db_location" VALUES(51464,NULL,'South Greenfield, MO',21650,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51465,NULL,'South Greenfield, MO 65752',21650,222,NULL,43,29522,0);
INSERT INTO "django_geo_db_location" VALUES(51466,NULL,'Sparta, MO',21651,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51467,NULL,'Sparta, MO 65753',21651,222,NULL,43,29523,0);
INSERT INTO "django_geo_db_location" VALUES(51468,NULL,'Spokane, MO',21652,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51469,NULL,'Spokane, MO 65754',21652,222,NULL,43,29524,0);
INSERT INTO "django_geo_db_location" VALUES(51470,NULL,'Squires, MO',21653,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51471,NULL,'Squires, MO 65755',21653,222,NULL,43,29525,0);
INSERT INTO "django_geo_db_location" VALUES(51472,NULL,'Stotts City, MO',21654,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51473,NULL,'Stotts City, MO 65756',21654,222,NULL,43,29526,0);
INSERT INTO "django_geo_db_location" VALUES(51474,NULL,'Strafford, MO',21655,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51475,NULL,'Strafford, MO 65757',21655,222,NULL,43,29527,0);
INSERT INTO "django_geo_db_location" VALUES(51476,NULL,'Taneyville, MO',21656,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51477,NULL,'Taneyville, MO 65759',21656,222,NULL,43,29528,0);
INSERT INTO "django_geo_db_location" VALUES(51478,NULL,'Tecumseh, MO',21657,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51479,NULL,'Tecumseh, MO 65760',21657,222,NULL,43,29529,0);
INSERT INTO "django_geo_db_location" VALUES(51480,NULL,'Theodosia, AR',21658,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51481,NULL,'Theodosia, AR 65761',21658,222,NULL,4,29530,0);
INSERT INTO "django_geo_db_location" VALUES(51482,NULL,'Thornfield, MO',21659,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51483,NULL,'Thornfield, MO 65762',21659,222,NULL,43,29531,0);
INSERT INTO "django_geo_db_location" VALUES(51484,NULL,'Tunas, MO',21660,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51485,NULL,'Tunas, MO 65764',21660,222,NULL,43,29532,0);
INSERT INTO "django_geo_db_location" VALUES(51486,NULL,'Turners, MO',21661,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51487,NULL,'Turners, MO 65765',21661,222,NULL,43,29533,0);
INSERT INTO "django_geo_db_location" VALUES(51488,NULL,'Udall, MO',21662,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51489,NULL,'Udall, MO 65766',21662,222,NULL,43,29534,0);
INSERT INTO "django_geo_db_location" VALUES(51490,NULL,'Urbana, MO',21663,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51491,NULL,'Urbana, MO 65767',21663,222,NULL,43,29535,0);
INSERT INTO "django_geo_db_location" VALUES(51492,NULL,'Vanzant, MO',21664,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51493,NULL,'Vanzant, MO 65768',21664,222,NULL,43,29536,0);
INSERT INTO "django_geo_db_location" VALUES(51494,NULL,'Verona, MO',21665,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51495,NULL,'Verona, MO 65769',21665,222,NULL,43,29537,0);
INSERT INTO "django_geo_db_location" VALUES(51496,NULL,'Walnut Grove, MO',21666,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51497,NULL,'Walnut Grove, MO 65770',21666,222,NULL,43,29538,0);
INSERT INTO "django_geo_db_location" VALUES(51498,NULL,'Walnut Shade, MO',21667,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51499,NULL,'Walnut Shade, MO 65771',21667,222,NULL,43,29539,0);
INSERT INTO "django_geo_db_location" VALUES(51500,NULL,'Washburn, MO',21668,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51501,NULL,'Washburn, MO 65772',21668,222,NULL,43,29540,0);
INSERT INTO "django_geo_db_location" VALUES(51502,NULL,'Wasola, MO',21669,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51503,NULL,'Wasola, MO 65773',21669,222,NULL,43,29541,0);
INSERT INTO "django_geo_db_location" VALUES(51504,NULL,'Weaubleau, MO',21670,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51505,NULL,'Weaubleau, MO 65774',21670,222,NULL,43,29542,0);
INSERT INTO "django_geo_db_location" VALUES(51506,NULL,'West Plains, MO 65775',21525,222,NULL,43,29543,0);
INSERT INTO "django_geo_db_location" VALUES(51507,NULL,'South Fork, MO',21671,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51508,NULL,'South Fork, MO 65776',21671,222,NULL,43,29544,0);
INSERT INTO "django_geo_db_location" VALUES(51509,NULL,'Moody, MO',21672,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51510,NULL,'Moody, MO 65777',21672,222,NULL,43,29545,0);
INSERT INTO "django_geo_db_location" VALUES(51511,NULL,'Myrtle, MO',21673,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51512,NULL,'Myrtle, MO 65778',21673,222,NULL,43,29546,0);
INSERT INTO "django_geo_db_location" VALUES(51513,NULL,'Wheatland, MO',21674,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51514,NULL,'Wheatland, MO 65779',21674,222,NULL,43,29547,0);
INSERT INTO "django_geo_db_location" VALUES(51515,NULL,'Willard, MO',21675,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51516,NULL,'Willard, MO 65781',21675,222,NULL,43,29548,0);
INSERT INTO "django_geo_db_location" VALUES(51517,NULL,'Windyville, MO',21676,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51518,NULL,'Windyville, MO 65783',21676,222,NULL,43,29549,0);
INSERT INTO "django_geo_db_location" VALUES(51519,NULL,'Zanoni, MO',21677,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51520,NULL,'Zanoni, MO 65784',21677,222,NULL,43,29550,0);
INSERT INTO "django_geo_db_location" VALUES(51521,NULL,'Stockton, MO',21678,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51522,NULL,'Stockton, MO 65785',21678,222,NULL,43,29551,0);
INSERT INTO "django_geo_db_location" VALUES(51523,NULL,'Macks Creek, MO',21679,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51524,NULL,'Macks Creek, MO 65786',21679,222,NULL,43,29552,0);
INSERT INTO "django_geo_db_location" VALUES(51525,NULL,'Roach, MO',21680,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51526,NULL,'Roach, MO 65787',21680,222,NULL,43,29553,0);
INSERT INTO "django_geo_db_location" VALUES(51527,NULL,'Peace Valley, MO',21681,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51528,NULL,'Peace Valley, MO 65788',21681,222,NULL,43,29554,0);
INSERT INTO "django_geo_db_location" VALUES(51529,NULL,'Pomona, MO',21682,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51530,NULL,'Pomona, MO 65789',21682,222,NULL,43,29555,0);
INSERT INTO "django_geo_db_location" VALUES(51531,NULL,'Pottersville, MO',21683,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51532,NULL,'Pottersville, MO 65790',21683,222,NULL,43,29556,0);
INSERT INTO "django_geo_db_location" VALUES(51533,NULL,'Thayer, MO',21684,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51534,NULL,'Thayer, MO 65791',21684,222,NULL,43,29557,0);
INSERT INTO "django_geo_db_location" VALUES(51535,NULL,'Willow Springs, MO',21685,222,NULL,43,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51536,NULL,'Willow Springs, MO 65793',21685,222,NULL,43,29558,0);
INSERT INTO "django_geo_db_location" VALUES(51537,NULL,'Springfield, MO 65801',21536,222,NULL,43,29559,0);
INSERT INTO "django_geo_db_location" VALUES(51538,NULL,'Springfield, MO 65802',21536,222,NULL,43,29560,0);
INSERT INTO "django_geo_db_location" VALUES(51539,NULL,'Springfield, MO 65803',21536,222,NULL,43,29561,0);
INSERT INTO "django_geo_db_location" VALUES(51540,NULL,'Springfield, MO 65804',21536,222,NULL,43,29562,0);
INSERT INTO "django_geo_db_location" VALUES(51541,NULL,'Springfield, MO 65805',21536,222,NULL,43,29563,0);
INSERT INTO "django_geo_db_location" VALUES(51542,NULL,'Springfield, MO 65806',21536,222,NULL,43,29564,0);
INSERT INTO "django_geo_db_location" VALUES(51543,NULL,'Springfield, MO 65807',21536,222,NULL,43,29565,0);
INSERT INTO "django_geo_db_location" VALUES(51544,NULL,'Springfield, MO 65808',21536,222,NULL,43,29566,0);
INSERT INTO "django_geo_db_location" VALUES(51545,NULL,'Springfield, MO 65809',21536,222,NULL,43,29567,0);
INSERT INTO "django_geo_db_location" VALUES(51546,NULL,'Springfield, MO 65810',21536,222,NULL,43,29568,0);
INSERT INTO "django_geo_db_location" VALUES(51547,NULL,'Springfield, MO 65814',21536,222,NULL,43,29569,0);
INSERT INTO "django_geo_db_location" VALUES(51548,NULL,'Springfield, MO 65817',21536,222,NULL,43,29570,0);
INSERT INTO "django_geo_db_location" VALUES(51549,NULL,'Springfield, MO 65890',21536,222,NULL,43,29571,0);
INSERT INTO "django_geo_db_location" VALUES(51550,NULL,'Springfield, MO 65898',21536,222,NULL,43,29572,0);
INSERT INTO "django_geo_db_location" VALUES(51551,NULL,'Springfield, MO 65899',21536,222,NULL,43,29573,0);
INSERT INTO "django_geo_db_location" VALUES(51552,NULL,'Atchison, KS',21686,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51553,NULL,'Atchison, KS 66002',21686,222,NULL,20,29574,0);
INSERT INTO "django_geo_db_location" VALUES(51554,NULL,'Baldwin City, KS',21687,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51555,NULL,'Baldwin City, KS 66006',21687,222,NULL,20,29575,0);
INSERT INTO "django_geo_db_location" VALUES(51556,NULL,'Basehor, KS',21688,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51557,NULL,'Basehor, KS 66007',21688,222,NULL,20,29576,0);
INSERT INTO "django_geo_db_location" VALUES(51558,NULL,'Bendena, KS',21689,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51559,NULL,'Bendena, KS 66008',21689,222,NULL,20,29577,0);
INSERT INTO "django_geo_db_location" VALUES(51560,NULL,'Blue Mound, KS',21690,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51561,NULL,'Blue Mound, KS 66010',21690,222,NULL,20,29578,0);
INSERT INTO "django_geo_db_location" VALUES(51562,NULL,'Bonner Springs, KS',21691,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51563,NULL,'Bonner Springs, KS 66012',21691,222,NULL,20,29579,0);
INSERT INTO "django_geo_db_location" VALUES(51564,NULL,'Bucyrus, KS',21692,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51565,NULL,'Bucyrus, KS 66013',21692,222,NULL,20,29580,0);
INSERT INTO "django_geo_db_location" VALUES(51566,NULL,'Centerville, KS',21693,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51567,NULL,'Centerville, KS 66014',21693,222,NULL,20,29581,0);
INSERT INTO "django_geo_db_location" VALUES(51568,NULL,'Colony, KS',21694,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51569,NULL,'Colony, KS 66015',21694,222,NULL,20,29582,0);
INSERT INTO "django_geo_db_location" VALUES(51570,NULL,'Cummings, KS',21695,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51571,NULL,'Cummings, KS 66016',21695,222,NULL,20,29583,0);
INSERT INTO "django_geo_db_location" VALUES(51572,NULL,'Denton, KS',21696,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51573,NULL,'Denton, KS 66017',21696,222,NULL,20,29584,0);
INSERT INTO "django_geo_db_location" VALUES(51574,NULL,'De Soto, KS',21697,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51575,NULL,'De Soto, KS 66018',21697,222,NULL,20,29585,0);
INSERT INTO "django_geo_db_location" VALUES(51576,NULL,'Clearview City, KS',21698,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51577,NULL,'Clearview City, KS 66019',21698,222,NULL,20,29586,0);
INSERT INTO "django_geo_db_location" VALUES(51578,NULL,'Easton, KS',21699,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51579,NULL,'Easton, KS 66020',21699,222,NULL,20,29587,0);
INSERT INTO "django_geo_db_location" VALUES(51580,NULL,'Edgerton, KS',21700,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51581,NULL,'Edgerton, KS 66021',21700,222,NULL,20,29588,0);
INSERT INTO "django_geo_db_location" VALUES(51582,NULL,'Effingham, KS',21701,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51583,NULL,'Effingham, KS 66023',21701,222,NULL,20,29589,0);
INSERT INTO "django_geo_db_location" VALUES(51584,NULL,'Elwood, KS',21702,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51585,NULL,'Elwood, KS 66024',21702,222,NULL,20,29590,0);
INSERT INTO "django_geo_db_location" VALUES(51586,NULL,'Eudora, KS',21703,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51587,NULL,'Eudora, KS 66025',21703,222,NULL,20,29591,0);
INSERT INTO "django_geo_db_location" VALUES(51588,NULL,'Fontana, KS',21704,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51589,NULL,'Fontana, KS 66026',21704,222,NULL,20,29592,0);
INSERT INTO "django_geo_db_location" VALUES(51590,NULL,'Fort Leavenworth, KS',21705,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51591,NULL,'Fort Leavenworth, KS 66027',21705,222,NULL,20,29593,0);
INSERT INTO "django_geo_db_location" VALUES(51592,NULL,'Gardner, KS',21706,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51593,NULL,'Gardner, KS 66030',21706,222,NULL,20,29594,0);
INSERT INTO "django_geo_db_location" VALUES(51594,NULL,'New Century, KS',21707,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51595,NULL,'New Century, KS 66031',21707,222,NULL,20,29595,0);
INSERT INTO "django_geo_db_location" VALUES(51596,NULL,'Garnett, KS',21708,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51597,NULL,'Garnett, KS 66032',21708,222,NULL,20,29596,0);
INSERT INTO "django_geo_db_location" VALUES(51598,NULL,'Greeley, KS',21709,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51599,NULL,'Greeley, KS 66033',21709,222,NULL,20,29597,0);
INSERT INTO "django_geo_db_location" VALUES(51600,NULL,'Highland, KS',21710,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51601,NULL,'Highland, KS 66035',21710,222,NULL,20,29598,0);
INSERT INTO "django_geo_db_location" VALUES(51602,NULL,'Hillsdale, KS',21711,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51603,NULL,'Hillsdale, KS 66036',21711,222,NULL,20,29599,0);
INSERT INTO "django_geo_db_location" VALUES(51604,NULL,'Kincaid, KS',21712,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51605,NULL,'Kincaid, KS 66039',21712,222,NULL,20,29600,0);
INSERT INTO "django_geo_db_location" VALUES(51606,NULL,'La Cygne, KS',21713,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51607,NULL,'La Cygne, KS 66040',21713,222,NULL,20,29601,0);
INSERT INTO "django_geo_db_location" VALUES(51608,NULL,'Lancaster, KS',21714,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51609,NULL,'Lancaster, KS 66041',21714,222,NULL,20,29602,0);
INSERT INTO "django_geo_db_location" VALUES(51610,NULL,'Lane, KS',21715,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51611,NULL,'Lane, KS 66042',21715,222,NULL,20,29603,0);
INSERT INTO "django_geo_db_location" VALUES(51612,NULL,'Lansing, KS',21716,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51613,NULL,'Lansing, KS 66043',21716,222,NULL,20,29604,0);
INSERT INTO "django_geo_db_location" VALUES(51614,NULL,'Lawrence, KS',21717,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51615,NULL,'Lawrence, KS 66044',21717,222,NULL,20,29605,0);
INSERT INTO "django_geo_db_location" VALUES(51616,NULL,'Lawrence, KS 66045',21717,222,NULL,20,29606,0);
INSERT INTO "django_geo_db_location" VALUES(51617,NULL,'Lawrence, KS 66046',21717,222,NULL,20,29607,0);
INSERT INTO "django_geo_db_location" VALUES(51618,NULL,'Lawrence, KS 66047',21717,222,NULL,20,29608,0);
INSERT INTO "django_geo_db_location" VALUES(51619,NULL,'Leavenworth, KS',21718,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51620,NULL,'Leavenworth, KS 66048',21718,222,NULL,20,29609,0);
INSERT INTO "django_geo_db_location" VALUES(51621,NULL,'Lawrence, KS 66049',21717,222,NULL,20,29610,0);
INSERT INTO "django_geo_db_location" VALUES(51622,NULL,'Lecompton, KS',21719,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51623,NULL,'Lecompton, KS 66050',21719,222,NULL,20,29611,0);
INSERT INTO "django_geo_db_location" VALUES(51624,NULL,'Olathe, KS',21720,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51625,NULL,'Olathe, KS 66051',21720,222,NULL,20,29612,0);
INSERT INTO "django_geo_db_location" VALUES(51626,NULL,'Linwood, KS',21721,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51627,NULL,'Linwood, KS 66052',21721,222,NULL,20,29613,0);
INSERT INTO "django_geo_db_location" VALUES(51628,NULL,'Louisburg, KS',21722,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51629,NULL,'Louisburg, KS 66053',21722,222,NULL,20,29614,0);
INSERT INTO "django_geo_db_location" VALUES(51630,NULL,'McLouth, KS',21723,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51631,NULL,'McLouth, KS 66054',21723,222,NULL,20,29615,0);
INSERT INTO "django_geo_db_location" VALUES(51632,NULL,'Mound City, KS',21724,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51633,NULL,'Mound City, KS 66056',21724,222,NULL,20,29616,0);
INSERT INTO "django_geo_db_location" VALUES(51634,NULL,'Muscotah, KS',21725,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51635,NULL,'Muscotah, KS 66058',21725,222,NULL,20,29617,0);
INSERT INTO "django_geo_db_location" VALUES(51636,NULL,'Nortonville, KS',21726,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51637,NULL,'Nortonville, KS 66060',21726,222,NULL,20,29618,0);
INSERT INTO "django_geo_db_location" VALUES(51638,NULL,'Olathe, KS 66061',21720,222,NULL,20,29619,0);
INSERT INTO "django_geo_db_location" VALUES(51639,NULL,'Olathe, KS 66062',21720,222,NULL,20,29620,0);
INSERT INTO "django_geo_db_location" VALUES(51640,NULL,'Olathe, KS 66063',21720,222,NULL,20,29621,0);
INSERT INTO "django_geo_db_location" VALUES(51641,NULL,'Osawatomie, KS',21727,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51642,NULL,'Osawatomie, KS 66064',21727,222,NULL,20,29622,0);
INSERT INTO "django_geo_db_location" VALUES(51643,NULL,'Oskaloosa, KS',21728,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51644,NULL,'Oskaloosa, KS 66066',21728,222,NULL,20,29623,0);
INSERT INTO "django_geo_db_location" VALUES(51645,NULL,'Ottawa, KS',21729,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51646,NULL,'Ottawa, KS 66067',21729,222,NULL,20,29624,0);
INSERT INTO "django_geo_db_location" VALUES(51647,NULL,'Ozawkie, KS',21730,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51648,NULL,'Ozawkie, KS 66070',21730,222,NULL,20,29625,0);
INSERT INTO "django_geo_db_location" VALUES(51649,NULL,'Paola, KS',21731,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51650,NULL,'Paola, KS 66071',21731,222,NULL,20,29626,0);
INSERT INTO "django_geo_db_location" VALUES(51651,NULL,'Parker, KS',21732,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51652,NULL,'Parker, KS 66072',21732,222,NULL,20,29627,0);
INSERT INTO "django_geo_db_location" VALUES(51653,NULL,'Perry, KS',21733,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51654,NULL,'Perry, KS 66073',21733,222,NULL,20,29628,0);
INSERT INTO "django_geo_db_location" VALUES(51655,NULL,'Pleasanton, KS',21734,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51656,NULL,'Pleasanton, KS 66075',21734,222,NULL,20,29629,0);
INSERT INTO "django_geo_db_location" VALUES(51657,NULL,'Pomona, KS',21735,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51658,NULL,'Pomona, KS 66076',21735,222,NULL,20,29630,0);
INSERT INTO "django_geo_db_location" VALUES(51659,NULL,'Potter, KS',21736,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51660,NULL,'Potter, KS 66077',21736,222,NULL,20,29631,0);
INSERT INTO "django_geo_db_location" VALUES(51661,NULL,'Princeton, KS',21737,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51662,NULL,'Princeton, KS 66078',21737,222,NULL,20,29632,0);
INSERT INTO "django_geo_db_location" VALUES(51663,NULL,'Rantoul, KS',21738,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51664,NULL,'Rantoul, KS 66079',21738,222,NULL,20,29633,0);
INSERT INTO "django_geo_db_location" VALUES(51665,NULL,'Richmond, KS',21739,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51666,NULL,'Richmond, KS 66080',21739,222,NULL,20,29634,0);
INSERT INTO "django_geo_db_location" VALUES(51667,NULL,'Wolf River, KS',21740,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51668,NULL,'Wolf River, KS 66081',21740,222,NULL,20,29635,0);
INSERT INTO "django_geo_db_location" VALUES(51669,NULL,'Spring Hill, KS',21741,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51670,NULL,'Spring Hill, KS 66083',21741,222,NULL,20,29636,0);
INSERT INTO "django_geo_db_location" VALUES(51671,NULL,'Stilwell, KS',21742,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51672,NULL,'Stilwell, KS 66085',21742,222,NULL,20,29637,0);
INSERT INTO "django_geo_db_location" VALUES(51673,NULL,'Tonganoxie, KS',21743,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51674,NULL,'Tonganoxie, KS 66086',21743,222,NULL,20,29638,0);
INSERT INTO "django_geo_db_location" VALUES(51675,NULL,'Troy, KS',21744,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51676,NULL,'Troy, KS 66087',21744,222,NULL,20,29639,0);
INSERT INTO "django_geo_db_location" VALUES(51677,NULL,'Valley Falls, KS',21745,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51678,NULL,'Valley Falls, KS 66088',21745,222,NULL,20,29640,0);
INSERT INTO "django_geo_db_location" VALUES(51679,NULL,'Wathena, KS',21746,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51680,NULL,'Wathena, KS 66090',21746,222,NULL,20,29641,0);
INSERT INTO "django_geo_db_location" VALUES(51681,NULL,'Welda, KS',21747,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51682,NULL,'Welda, KS 66091',21747,222,NULL,20,29642,0);
INSERT INTO "django_geo_db_location" VALUES(51683,NULL,'Wellsville, KS',21748,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51684,NULL,'Wellsville, KS 66092',21748,222,NULL,20,29643,0);
INSERT INTO "django_geo_db_location" VALUES(51685,NULL,'Westphalia, KS',21749,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51686,NULL,'Westphalia, KS 66093',21749,222,NULL,20,29644,0);
INSERT INTO "django_geo_db_location" VALUES(51687,NULL,'White Cloud, KS',21750,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51688,NULL,'White Cloud, KS 66094',21750,222,NULL,20,29645,0);
INSERT INTO "django_geo_db_location" VALUES(51689,NULL,'Williamsburg, KS',21751,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51690,NULL,'Williamsburg, KS 66095',21751,222,NULL,20,29646,0);
INSERT INTO "django_geo_db_location" VALUES(51691,NULL,'Winchester, KS',21752,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51692,NULL,'Winchester, KS 66097',21752,222,NULL,20,29647,0);
INSERT INTO "django_geo_db_location" VALUES(51693,NULL,'Kansas City, KS',21753,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51694,NULL,'Kansas City, KS 66101',21753,222,NULL,20,29648,0);
INSERT INTO "django_geo_db_location" VALUES(51695,NULL,'Kansas City, KS 66102',21753,222,NULL,20,29649,0);
INSERT INTO "django_geo_db_location" VALUES(51696,NULL,'Kansas City, KS 66103',21753,222,NULL,20,29650,0);
INSERT INTO "django_geo_db_location" VALUES(51697,NULL,'Kansas City, KS 66104',21753,222,NULL,20,29651,0);
INSERT INTO "django_geo_db_location" VALUES(51698,NULL,'Kansas City, KS 66105',21753,222,NULL,20,29652,0);
INSERT INTO "django_geo_db_location" VALUES(51699,NULL,'Kansas City, KS 66106',21753,222,NULL,20,29653,0);
INSERT INTO "django_geo_db_location" VALUES(51700,NULL,'Kansas City, KS 66109',21753,222,NULL,20,29654,0);
INSERT INTO "django_geo_db_location" VALUES(51701,NULL,'Kansas City, KS 66110',21753,222,NULL,20,29655,0);
INSERT INTO "django_geo_db_location" VALUES(51702,NULL,'Kansas City, KS 66111',21753,222,NULL,20,29656,0);
INSERT INTO "django_geo_db_location" VALUES(51703,NULL,'Kansas City, KS 66112',21753,222,NULL,20,29657,0);
INSERT INTO "django_geo_db_location" VALUES(51704,NULL,'Edwardsville, KS',21754,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51705,NULL,'Edwardsville, KS 66113',21754,222,NULL,20,29658,0);
INSERT INTO "django_geo_db_location" VALUES(51706,NULL,'Kansas City, KS 66115',21753,222,NULL,20,29659,0);
INSERT INTO "django_geo_db_location" VALUES(51707,NULL,'Kansas City, KS 66117',21753,222,NULL,20,29660,0);
INSERT INTO "django_geo_db_location" VALUES(51708,NULL,'Kansas City, KS 66118',21753,222,NULL,20,29661,0);
INSERT INTO "django_geo_db_location" VALUES(51709,NULL,'Kansas City, KS 66119',21753,222,NULL,20,29662,0);
INSERT INTO "django_geo_db_location" VALUES(51710,NULL,'Centralia, KS',21755,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51711,NULL,'Centralia, KS 66145',21755,222,NULL,20,29663,0);
INSERT INTO "django_geo_db_location" VALUES(51712,NULL,'Morrill, KS',21756,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51713,NULL,'Morrill, KS 66151',21756,222,NULL,20,29664,0);
INSERT INTO "django_geo_db_location" VALUES(51714,NULL,'Kansas City, KS 66160',21753,222,NULL,20,29665,0);
INSERT INTO "django_geo_db_location" VALUES(51715,NULL,'Shawnee Mission, KS',21757,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51716,NULL,'Shawnee Mission, KS 66201',21757,222,NULL,20,29666,0);
INSERT INTO "django_geo_db_location" VALUES(51717,NULL,'Shawnee Mission, KS 66202',21757,222,NULL,20,29667,0);
INSERT INTO "django_geo_db_location" VALUES(51718,NULL,'Shawnee Mission, KS 66203',21757,222,NULL,20,29668,0);
INSERT INTO "django_geo_db_location" VALUES(51719,NULL,'Shawnee Mission, KS 66204',21757,222,NULL,20,29669,0);
INSERT INTO "django_geo_db_location" VALUES(51720,NULL,'Shawnee Mission, KS 66205',21757,222,NULL,20,29670,0);
INSERT INTO "django_geo_db_location" VALUES(51721,NULL,'Shawnee Mission, KS 66206',21757,222,NULL,20,29671,0);
INSERT INTO "django_geo_db_location" VALUES(51722,NULL,'Shawnee Mission, KS 66207',21757,222,NULL,20,29672,0);
INSERT INTO "django_geo_db_location" VALUES(51723,NULL,'Shawnee Mission, KS 66208',21757,222,NULL,20,29673,0);
INSERT INTO "django_geo_db_location" VALUES(51724,NULL,'Shawnee Mission, KS 66209',21757,222,NULL,20,29674,0);
INSERT INTO "django_geo_db_location" VALUES(51725,NULL,'Shawnee Mission, KS 66210',21757,222,NULL,20,29675,0);
INSERT INTO "django_geo_db_location" VALUES(51726,NULL,'Shawnee Mission, KS 66211',21757,222,NULL,20,29676,0);
INSERT INTO "django_geo_db_location" VALUES(51727,NULL,'Shawnee Mission, KS 66212',21757,222,NULL,20,29677,0);
INSERT INTO "django_geo_db_location" VALUES(51728,NULL,'Shawnee Mission, KS 66213',21757,222,NULL,20,29678,0);
INSERT INTO "django_geo_db_location" VALUES(51729,NULL,'Shawnee Mission, KS 66214',21757,222,NULL,20,29679,0);
INSERT INTO "django_geo_db_location" VALUES(51730,NULL,'Shawnee Mission, KS 66215',21757,222,NULL,20,29680,0);
INSERT INTO "django_geo_db_location" VALUES(51731,NULL,'Shawnee Mission, KS 66216',21757,222,NULL,20,29681,0);
INSERT INTO "django_geo_db_location" VALUES(51732,NULL,'Shawnee Mission, KS 66217',21757,222,NULL,20,29682,0);
INSERT INTO "django_geo_db_location" VALUES(51733,NULL,'Shawnee Mission, KS 66218',21757,222,NULL,20,29683,0);
INSERT INTO "django_geo_db_location" VALUES(51734,NULL,'Shawnee Mission, KS 66219',21757,222,NULL,20,29684,0);
INSERT INTO "django_geo_db_location" VALUES(51735,NULL,'Shawnee Mission, KS 66220',21757,222,NULL,20,29685,0);
INSERT INTO "django_geo_db_location" VALUES(51736,NULL,'Shawnee Mission, KS 66221',21757,222,NULL,20,29686,0);
INSERT INTO "django_geo_db_location" VALUES(51737,NULL,'Shawnee Mission, KS 66222',21757,222,NULL,20,29687,0);
INSERT INTO "django_geo_db_location" VALUES(51738,NULL,'Shawnee Mission, KS 66223',21757,222,NULL,20,29688,0);
INSERT INTO "django_geo_db_location" VALUES(51739,NULL,'Shawnee Mission, KS 66224',21757,222,NULL,20,29689,0);
INSERT INTO "django_geo_db_location" VALUES(51740,NULL,'Shawnee Mission, KS 66225',21757,222,NULL,20,29690,0);
INSERT INTO "django_geo_db_location" VALUES(51741,NULL,'Shawnee Mission, KS 66226',21757,222,NULL,20,29691,0);
INSERT INTO "django_geo_db_location" VALUES(51742,NULL,'Shawnee Mission, KS 66227',21757,222,NULL,20,29692,0);
INSERT INTO "django_geo_db_location" VALUES(51743,NULL,'Shawnee Mission, KS 66250',21757,222,NULL,20,29693,0);
INSERT INTO "django_geo_db_location" VALUES(51744,NULL,'Shawnee Mission, KS 66251',21757,222,NULL,20,29694,0);
INSERT INTO "django_geo_db_location" VALUES(51745,NULL,'Shawnee Mission, KS 66276',21757,222,NULL,20,29695,0);
INSERT INTO "django_geo_db_location" VALUES(51746,NULL,'Shawnee Mission, KS 66279',21757,222,NULL,20,29696,0);
INSERT INTO "django_geo_db_location" VALUES(51747,NULL,'Shawnee Mission, KS 66282',21757,222,NULL,20,29697,0);
INSERT INTO "django_geo_db_location" VALUES(51748,NULL,'Shawnee Mission, KS 66283',21757,222,NULL,20,29698,0);
INSERT INTO "django_geo_db_location" VALUES(51749,NULL,'Shawnee Mission, KS 66285',21757,222,NULL,20,29699,0);
INSERT INTO "django_geo_db_location" VALUES(51750,NULL,'Shawnee Mission, KS 66286',21757,222,NULL,20,29700,0);
INSERT INTO "django_geo_db_location" VALUES(51751,NULL,'Robinson, KS',21758,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51752,NULL,'Robinson, KS 66352',21758,222,NULL,20,29701,0);
INSERT INTO "django_geo_db_location" VALUES(51753,NULL,'Lincoln, KS',21759,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51754,NULL,'Lincoln, KS 66356',21759,222,NULL,20,29702,0);
INSERT INTO "django_geo_db_location" VALUES(51755,NULL,'Alma, KS',21760,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51756,NULL,'Alma, KS 66401',21760,222,NULL,20,29703,0);
INSERT INTO "django_geo_db_location" VALUES(51757,NULL,'Auburn, KS',21761,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51758,NULL,'Auburn, KS 66402',21761,222,NULL,20,29704,0);
INSERT INTO "django_geo_db_location" VALUES(51759,NULL,'Axtell, KS',21762,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51760,NULL,'Axtell, KS 66403',21762,222,NULL,20,29705,0);
INSERT INTO "django_geo_db_location" VALUES(51761,NULL,'Baileyville, KS',21763,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51762,NULL,'Baileyville, KS 66404',21763,222,NULL,20,29706,0);
INSERT INTO "django_geo_db_location" VALUES(51763,NULL,'Beattie, KS',21764,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51764,NULL,'Beattie, KS 66406',21764,222,NULL,20,29707,0);
INSERT INTO "django_geo_db_location" VALUES(51765,NULL,'Belvue, KS',21765,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51766,NULL,'Belvue, KS 66407',21765,222,NULL,20,29708,0);
INSERT INTO "django_geo_db_location" VALUES(51767,NULL,'Bern, KS',21766,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51768,NULL,'Bern, KS 66408',21766,222,NULL,20,29709,0);
INSERT INTO "django_geo_db_location" VALUES(51769,NULL,'Berryton, KS',21767,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51770,NULL,'Berryton, KS 66409',21767,222,NULL,20,29710,0);
INSERT INTO "django_geo_db_location" VALUES(51771,NULL,'Blue Rapids, KS',21768,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51772,NULL,'Blue Rapids, KS 66411',21768,222,NULL,20,29711,0);
INSERT INTO "django_geo_db_location" VALUES(51773,NULL,'Bremen, KS',21769,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51774,NULL,'Bremen, KS 66412',21769,222,NULL,20,29712,0);
INSERT INTO "django_geo_db_location" VALUES(51775,NULL,'Burlingame, KS',21770,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51776,NULL,'Burlingame, KS 66413',21770,222,NULL,20,29713,0);
INSERT INTO "django_geo_db_location" VALUES(51777,NULL,'Carbondale, KS',21771,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51778,NULL,'Carbondale, KS 66414',21771,222,NULL,20,29714,0);
INSERT INTO "django_geo_db_location" VALUES(51779,NULL,'Centralia, KS 66415',21755,222,NULL,20,29715,0);
INSERT INTO "django_geo_db_location" VALUES(51780,NULL,'Circleville, KS',21772,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51781,NULL,'Circleville, KS 66416',21772,222,NULL,20,29716,0);
INSERT INTO "django_geo_db_location" VALUES(51782,NULL,'Corning, KS',21773,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51783,NULL,'Corning, KS 66417',21773,222,NULL,20,29717,0);
INSERT INTO "django_geo_db_location" VALUES(51784,NULL,'Delia, KS',21774,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51785,NULL,'Delia, KS 66418',21774,222,NULL,20,29718,0);
INSERT INTO "django_geo_db_location" VALUES(51786,NULL,'Denison, KS',21775,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51787,NULL,'Denison, KS 66419',21775,222,NULL,20,29719,0);
INSERT INTO "django_geo_db_location" VALUES(51788,NULL,'Dover, KS',21776,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51789,NULL,'Dover, KS 66420',21776,222,NULL,20,29720,0);
INSERT INTO "django_geo_db_location" VALUES(51790,NULL,'Emmett, KS',21777,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51791,NULL,'Emmett, KS 66422',21777,222,NULL,20,29721,0);
INSERT INTO "django_geo_db_location" VALUES(51792,NULL,'Eskridge, KS',21778,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51793,NULL,'Eskridge, KS 66423',21778,222,NULL,20,29722,0);
INSERT INTO "django_geo_db_location" VALUES(51794,NULL,'Everest, KS',21779,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51795,NULL,'Everest, KS 66424',21779,222,NULL,20,29723,0);
INSERT INTO "django_geo_db_location" VALUES(51796,NULL,'Fairview, KS',21780,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51797,NULL,'Fairview, KS 66425',21780,222,NULL,20,29724,0);
INSERT INTO "django_geo_db_location" VALUES(51798,NULL,'Fostoria, KS',21781,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51799,NULL,'Fostoria, KS 66426',21781,222,NULL,20,29725,0);
INSERT INTO "django_geo_db_location" VALUES(51800,NULL,'Frankfort, KS',21782,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51801,NULL,'Frankfort, KS 66427',21782,222,NULL,20,29726,0);
INSERT INTO "django_geo_db_location" VALUES(51802,NULL,'Goff, KS',21783,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51803,NULL,'Goff, KS 66428',21783,222,NULL,20,29727,0);
INSERT INTO "django_geo_db_location" VALUES(51804,NULL,'Grantville, KS',21784,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51805,NULL,'Grantville, KS 66429',21784,222,NULL,20,29728,0);
INSERT INTO "django_geo_db_location" VALUES(51806,NULL,'Harveyville, KS',21785,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51807,NULL,'Harveyville, KS 66431',21785,222,NULL,20,29729,0);
INSERT INTO "django_geo_db_location" VALUES(51808,NULL,'Havensville, KS',21786,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51809,NULL,'Havensville, KS 66432',21786,222,NULL,20,29730,0);
INSERT INTO "django_geo_db_location" VALUES(51810,NULL,'Hiawatha, KS',21787,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51811,NULL,'Hiawatha, KS 66434',21787,222,NULL,20,29731,0);
INSERT INTO "django_geo_db_location" VALUES(51812,NULL,'Holton, KS',21788,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51813,NULL,'Holton, KS 66436',21788,222,NULL,20,29732,0);
INSERT INTO "django_geo_db_location" VALUES(51814,NULL,'Home, KS',21789,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51815,NULL,'Home, KS 66438',21789,222,NULL,20,29733,0);
INSERT INTO "django_geo_db_location" VALUES(51816,NULL,'Horton, KS',21790,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51817,NULL,'Horton, KS 66439',21790,222,NULL,20,29734,0);
INSERT INTO "django_geo_db_location" VALUES(51818,NULL,'Hoyt, KS',21791,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51819,NULL,'Hoyt, KS 66440',21791,222,NULL,20,29735,0);
INSERT INTO "django_geo_db_location" VALUES(51820,NULL,'Junction City, KS',21792,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51821,NULL,'Junction City, KS 66441',21792,222,NULL,20,29736,0);
INSERT INTO "django_geo_db_location" VALUES(51822,NULL,'Fort Riley, KS',21793,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51823,NULL,'Fort Riley, KS 66442',21793,222,NULL,20,29737,0);
INSERT INTO "django_geo_db_location" VALUES(51824,NULL,'Leonardville, KS',21794,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51825,NULL,'Leonardville, KS 66449',21794,222,NULL,20,29738,0);
INSERT INTO "django_geo_db_location" VALUES(51826,NULL,'Louisville, KS',21795,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51827,NULL,'Louisville, KS 66450',21795,222,NULL,20,29739,0);
INSERT INTO "django_geo_db_location" VALUES(51828,NULL,'Lyndon, KS',21796,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51829,NULL,'Lyndon, KS 66451',21796,222,NULL,20,29740,0);
INSERT INTO "django_geo_db_location" VALUES(51830,NULL,'Weir, KS',21797,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51831,NULL,'Weir, KS 66481',21797,222,NULL,20,29741,0);
INSERT INTO "django_geo_db_location" VALUES(51832,NULL,'McFarland, KS',21798,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51833,NULL,'McFarland, KS 66501',21798,222,NULL,20,29742,0);
INSERT INTO "django_geo_db_location" VALUES(51834,NULL,'Manhattan, KS',21799,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51835,NULL,'Manhattan, KS 66502',21799,222,NULL,20,29743,0);
INSERT INTO "django_geo_db_location" VALUES(51836,NULL,'Manhattan, KS 66503',21799,222,NULL,20,29744,0);
INSERT INTO "django_geo_db_location" VALUES(51837,NULL,'Manhattan, KS 66505',21799,222,NULL,20,29745,0);
INSERT INTO "django_geo_db_location" VALUES(51838,NULL,'Manhattan, KS 66506',21799,222,NULL,20,29746,0);
INSERT INTO "django_geo_db_location" VALUES(51839,NULL,'Maple Hill, KS',21800,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51840,NULL,'Maple Hill, KS 66507',21800,222,NULL,20,29747,0);
INSERT INTO "django_geo_db_location" VALUES(51841,NULL,'Marysville, KS',21801,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51842,NULL,'Marysville, KS 66508',21801,222,NULL,20,29748,0);
INSERT INTO "django_geo_db_location" VALUES(51843,NULL,'Mayetta, KS',21802,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51844,NULL,'Mayetta, KS 66509',21802,222,NULL,20,29749,0);
INSERT INTO "django_geo_db_location" VALUES(51845,NULL,'Melvern, KS',21803,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51846,NULL,'Melvern, KS 66510',21803,222,NULL,20,29750,0);
INSERT INTO "django_geo_db_location" VALUES(51847,NULL,'Meriden, KS',21804,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51848,NULL,'Meriden, KS 66512',21804,222,NULL,20,29751,0);
INSERT INTO "django_geo_db_location" VALUES(51849,NULL,'Milford, KS',21805,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51850,NULL,'Milford, KS 66514',21805,222,NULL,20,29752,0);
INSERT INTO "django_geo_db_location" VALUES(51851,NULL,'Morrill, KS 66515',21756,222,NULL,20,29753,0);
INSERT INTO "django_geo_db_location" VALUES(51852,NULL,'Netawaka, KS',21806,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51853,NULL,'Netawaka, KS 66516',21806,222,NULL,20,29754,0);
INSERT INTO "django_geo_db_location" VALUES(51854,NULL,'Ogden, KS',21807,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51855,NULL,'Ogden, KS 66517',21807,222,NULL,20,29755,0);
INSERT INTO "django_geo_db_location" VALUES(51856,NULL,'Oketo, KS',21808,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51857,NULL,'Oketo, KS 66518',21808,222,NULL,20,29756,0);
INSERT INTO "django_geo_db_location" VALUES(51858,NULL,'Olsburg, KS',21809,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51859,NULL,'Olsburg, KS 66520',21809,222,NULL,20,29757,0);
INSERT INTO "django_geo_db_location" VALUES(51860,NULL,'Onaga, KS',21810,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51861,NULL,'Onaga, KS 66521',21810,222,NULL,20,29758,0);
INSERT INTO "django_geo_db_location" VALUES(51862,NULL,'Oneida, KS',21811,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51863,NULL,'Oneida, KS 66522',21811,222,NULL,20,29759,0);
INSERT INTO "django_geo_db_location" VALUES(51864,NULL,'Osage City, KS',21812,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51865,NULL,'Osage City, KS 66523',21812,222,NULL,20,29760,0);
INSERT INTO "django_geo_db_location" VALUES(51866,NULL,'Overbrook, KS',21813,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51867,NULL,'Overbrook, KS 66524',21813,222,NULL,20,29761,0);
INSERT INTO "django_geo_db_location" VALUES(51868,NULL,'Paxico, KS',21814,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51869,NULL,'Paxico, KS 66526',21814,222,NULL,20,29762,0);
INSERT INTO "django_geo_db_location" VALUES(51870,NULL,'Powhattan, KS',21815,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51871,NULL,'Powhattan, KS 66527',21815,222,NULL,20,29763,0);
INSERT INTO "django_geo_db_location" VALUES(51872,NULL,'Quenemo, KS',21816,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51873,NULL,'Quenemo, KS 66528',21816,222,NULL,20,29764,0);
INSERT INTO "django_geo_db_location" VALUES(51874,NULL,'Riley, KS',21817,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51875,NULL,'Riley, KS 66531',21817,222,NULL,20,29765,0);
INSERT INTO "django_geo_db_location" VALUES(51876,NULL,'Robinson, KS 66532',21758,222,NULL,20,29766,0);
INSERT INTO "django_geo_db_location" VALUES(51877,NULL,'Rossville, KS',21818,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51878,NULL,'Rossville, KS 66533',21818,222,NULL,20,29767,0);
INSERT INTO "django_geo_db_location" VALUES(51879,NULL,'Sabetha, KS',21819,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51880,NULL,'Sabetha, KS 66534',21819,222,NULL,20,29768,0);
INSERT INTO "django_geo_db_location" VALUES(51881,NULL,'Saint George, KS',21820,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51882,NULL,'Saint George, KS 66535',21820,222,NULL,20,29769,0);
INSERT INTO "django_geo_db_location" VALUES(51883,NULL,'Saint Marys, KS',21821,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51884,NULL,'Saint Marys, KS 66536',21821,222,NULL,20,29770,0);
INSERT INTO "django_geo_db_location" VALUES(51885,NULL,'Scranton, KS',21822,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51886,NULL,'Scranton, KS 66537',21822,222,NULL,20,29771,0);
INSERT INTO "django_geo_db_location" VALUES(51887,NULL,'Seneca, KS',21823,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51888,NULL,'Seneca, KS 66538',21823,222,NULL,20,29772,0);
INSERT INTO "django_geo_db_location" VALUES(51889,NULL,'Silver Lake, KS',21824,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51890,NULL,'Silver Lake, KS 66539',21824,222,NULL,20,29773,0);
INSERT INTO "django_geo_db_location" VALUES(51891,NULL,'Soldier, KS',21825,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51892,NULL,'Soldier, KS 66540',21825,222,NULL,20,29774,0);
INSERT INTO "django_geo_db_location" VALUES(51893,NULL,'Summerfield, KS',21826,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51894,NULL,'Summerfield, KS 66541',21826,222,NULL,20,29775,0);
INSERT INTO "django_geo_db_location" VALUES(51895,NULL,'Tecumseh, KS',21827,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51896,NULL,'Tecumseh, KS 66542',21827,222,NULL,20,29776,0);
INSERT INTO "django_geo_db_location" VALUES(51897,NULL,'Vassar, KS',21828,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51898,NULL,'Vassar, KS 66543',21828,222,NULL,20,29777,0);
INSERT INTO "django_geo_db_location" VALUES(51899,NULL,'Vermillion, KS',21829,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51900,NULL,'Vermillion, KS 66544',21829,222,NULL,20,29778,0);
INSERT INTO "django_geo_db_location" VALUES(51901,NULL,'Wakarusa, KS',21830,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51902,NULL,'Wakarusa, KS 66546',21830,222,NULL,20,29779,0);
INSERT INTO "django_geo_db_location" VALUES(51903,NULL,'Wamego, KS',21831,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51904,NULL,'Wamego, KS 66547',21831,222,NULL,20,29780,0);
INSERT INTO "django_geo_db_location" VALUES(51905,NULL,'Waterville, KS',21832,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51906,NULL,'Waterville, KS 66548',21832,222,NULL,20,29781,0);
INSERT INTO "django_geo_db_location" VALUES(51907,NULL,'Westmoreland, KS',21833,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51908,NULL,'Westmoreland, KS 66549',21833,222,NULL,20,29782,0);
INSERT INTO "django_geo_db_location" VALUES(51909,NULL,'Wetmore, KS',21834,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51910,NULL,'Wetmore, KS 66550',21834,222,NULL,20,29783,0);
INSERT INTO "django_geo_db_location" VALUES(51911,NULL,'Wheaton, KS',21835,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51912,NULL,'Wheaton, KS 66551',21835,222,NULL,20,29784,0);
INSERT INTO "django_geo_db_location" VALUES(51913,NULL,'Whiting, KS',21836,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51914,NULL,'Whiting, KS 66552',21836,222,NULL,20,29785,0);
INSERT INTO "django_geo_db_location" VALUES(51915,NULL,'Randolph, KS',21837,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51916,NULL,'Randolph, KS 66554',21837,222,NULL,20,29786,0);
INSERT INTO "django_geo_db_location" VALUES(51917,NULL,'Marysville, KS 66555',21801,222,NULL,20,29787,0);
INSERT INTO "django_geo_db_location" VALUES(51918,NULL,'Topeka, KS',21838,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51919,NULL,'Topeka, KS 66601',21838,222,NULL,20,29788,0);
INSERT INTO "django_geo_db_location" VALUES(51920,NULL,'Topeka, KS 66603',21838,222,NULL,20,29789,0);
INSERT INTO "django_geo_db_location" VALUES(51921,NULL,'Topeka, KS 66604',21838,222,NULL,20,29790,0);
INSERT INTO "django_geo_db_location" VALUES(51922,NULL,'Topeka, KS 66605',21838,222,NULL,20,29791,0);
INSERT INTO "django_geo_db_location" VALUES(51923,NULL,'Topeka, KS 66606',21838,222,NULL,20,29792,0);
INSERT INTO "django_geo_db_location" VALUES(51924,NULL,'Topeka, KS 66607',21838,222,NULL,20,29793,0);
INSERT INTO "django_geo_db_location" VALUES(51925,NULL,'Topeka, KS 66608',21838,222,NULL,20,29794,0);
INSERT INTO "django_geo_db_location" VALUES(51926,NULL,'Topeka, KS 66609',21838,222,NULL,20,29795,0);
INSERT INTO "django_geo_db_location" VALUES(51927,NULL,'Topeka, KS 66610',21838,222,NULL,20,29796,0);
INSERT INTO "django_geo_db_location" VALUES(51928,NULL,'Topeka, KS 66611',21838,222,NULL,20,29797,0);
INSERT INTO "django_geo_db_location" VALUES(51929,NULL,'Topeka, KS 66612',21838,222,NULL,20,29798,0);
INSERT INTO "django_geo_db_location" VALUES(51930,NULL,'Topeka, KS 66614',21838,222,NULL,20,29799,0);
INSERT INTO "django_geo_db_location" VALUES(51931,NULL,'Topeka, KS 66615',21838,222,NULL,20,29800,0);
INSERT INTO "django_geo_db_location" VALUES(51932,NULL,'Topeka, KS 66616',21838,222,NULL,20,29801,0);
INSERT INTO "django_geo_db_location" VALUES(51933,NULL,'Topeka, KS 66617',21838,222,NULL,20,29802,0);
INSERT INTO "django_geo_db_location" VALUES(51934,NULL,'Topeka, KS 66618',21838,222,NULL,20,29803,0);
INSERT INTO "django_geo_db_location" VALUES(51935,NULL,'Topeka, KS 66619',21838,222,NULL,20,29804,0);
INSERT INTO "django_geo_db_location" VALUES(51936,NULL,'Topeka, KS 66620',21838,222,NULL,20,29805,0);
INSERT INTO "django_geo_db_location" VALUES(51937,NULL,'Topeka, KS 66621',21838,222,NULL,20,29806,0);
INSERT INTO "django_geo_db_location" VALUES(51938,NULL,'Topeka, KS 66622',21838,222,NULL,20,29807,0);
INSERT INTO "django_geo_db_location" VALUES(51939,NULL,'Topeka, KS 66624',21838,222,NULL,20,29808,0);
INSERT INTO "django_geo_db_location" VALUES(51940,NULL,'Topeka, KS 66625',21838,222,NULL,20,29809,0);
INSERT INTO "django_geo_db_location" VALUES(51941,NULL,'Topeka, KS 66626',21838,222,NULL,20,29810,0);
INSERT INTO "django_geo_db_location" VALUES(51942,NULL,'Topeka, KS 66628',21838,222,NULL,20,29811,0);
INSERT INTO "django_geo_db_location" VALUES(51943,NULL,'Topeka, KS 66629',21838,222,NULL,20,29812,0);
INSERT INTO "django_geo_db_location" VALUES(51944,NULL,'Topeka, KS 66634',21838,222,NULL,20,29813,0);
INSERT INTO "django_geo_db_location" VALUES(51945,NULL,'St. George, KS',21839,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51946,NULL,'St. George, KS 66635',21839,222,NULL,20,29814,0);
INSERT INTO "django_geo_db_location" VALUES(51947,NULL,'Topeka, KS 66636',21838,222,NULL,20,29815,0);
INSERT INTO "django_geo_db_location" VALUES(51948,NULL,'Topeka, KS 66637',21838,222,NULL,20,29816,0);
INSERT INTO "django_geo_db_location" VALUES(51949,NULL,'Topeka, KS 66638',21838,222,NULL,20,29817,0);
INSERT INTO "django_geo_db_location" VALUES(51950,NULL,'Topeka, KS 66642',21838,222,NULL,20,29818,0);
INSERT INTO "django_geo_db_location" VALUES(51951,NULL,'Topeka, KS 66647',21838,222,NULL,20,29819,0);
INSERT INTO "django_geo_db_location" VALUES(51952,NULL,'Powhattan, KS 66650',21815,222,NULL,20,29820,0);
INSERT INTO "django_geo_db_location" VALUES(51953,NULL,'Topeka, KS 66652',21838,222,NULL,20,29821,0);
INSERT INTO "django_geo_db_location" VALUES(51954,NULL,'Topeka, KS 66653',21838,222,NULL,20,29822,0);
INSERT INTO "django_geo_db_location" VALUES(51955,NULL,'Topeka, KS 66658',21838,222,NULL,20,29823,0);
INSERT INTO "django_geo_db_location" VALUES(51956,NULL,'Topeka, KS 66667',21838,222,NULL,20,29824,0);
INSERT INTO "django_geo_db_location" VALUES(51957,NULL,'Topeka, KS 66675',21838,222,NULL,20,29825,0);
INSERT INTO "django_geo_db_location" VALUES(51958,NULL,'Topeka, KS 66683',21838,222,NULL,20,29826,0);
INSERT INTO "django_geo_db_location" VALUES(51959,NULL,'Topeka, KS 66686',21838,222,NULL,20,29827,0);
INSERT INTO "django_geo_db_location" VALUES(51960,NULL,'Topeka, KS 66692',21838,222,NULL,20,29828,0);
INSERT INTO "django_geo_db_location" VALUES(51961,NULL,'Topeka, KS 66699',21838,222,NULL,20,29829,0);
INSERT INTO "django_geo_db_location" VALUES(51962,NULL,'Fort Scott, KS',21840,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51963,NULL,'Fort Scott, KS 66701',21840,222,NULL,20,29830,0);
INSERT INTO "django_geo_db_location" VALUES(51964,NULL,'Altoona, KS',21841,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51965,NULL,'Altoona, KS 66710',21841,222,NULL,20,29831,0);
INSERT INTO "django_geo_db_location" VALUES(51966,NULL,'Arcadia, KS',21842,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51967,NULL,'Arcadia, KS 66711',21842,222,NULL,20,29832,0);
INSERT INTO "django_geo_db_location" VALUES(51968,NULL,'Arma, KS',21843,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51969,NULL,'Arma, KS 66712',21843,222,NULL,20,29833,0);
INSERT INTO "django_geo_db_location" VALUES(51970,NULL,'Baxter Springs, KS',21844,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51971,NULL,'Baxter Springs, KS 66713',21844,222,NULL,20,29834,0);
INSERT INTO "django_geo_db_location" VALUES(51972,NULL,'Benedict, KS',21845,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51973,NULL,'Benedict, KS 66714',21845,222,NULL,20,29835,0);
INSERT INTO "django_geo_db_location" VALUES(51974,NULL,'Bronson, KS',21846,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51975,NULL,'Bronson, KS 66716',21846,222,NULL,20,29836,0);
INSERT INTO "django_geo_db_location" VALUES(51976,NULL,'Buffalo, KS',21847,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51977,NULL,'Buffalo, KS 66717',21847,222,NULL,20,29837,0);
INSERT INTO "django_geo_db_location" VALUES(51978,NULL,'Chanute, KS',21848,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51979,NULL,'Chanute, KS 66720',21848,222,NULL,20,29838,0);
INSERT INTO "django_geo_db_location" VALUES(51980,NULL,'Lincoln, KS 66721',21759,222,NULL,20,29839,0);
INSERT INTO "django_geo_db_location" VALUES(51981,NULL,'Cherokee, KS',21849,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51982,NULL,'Cherokee, KS 66724',21849,222,NULL,20,29840,0);
INSERT INTO "django_geo_db_location" VALUES(51983,NULL,'Columbus, KS',21850,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51984,NULL,'Columbus, KS 66725',21850,222,NULL,20,29841,0);
INSERT INTO "django_geo_db_location" VALUES(51985,NULL,'Coyville, KS',21851,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51986,NULL,'Coyville, KS 66727',21851,222,NULL,20,29842,0);
INSERT INTO "django_geo_db_location" VALUES(51987,NULL,'Crestline, KS',21852,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51988,NULL,'Crestline, KS 66728',21852,222,NULL,20,29843,0);
INSERT INTO "django_geo_db_location" VALUES(51989,NULL,'Elsmore, KS',21853,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51990,NULL,'Elsmore, KS 66732',21853,222,NULL,20,29844,0);
INSERT INTO "django_geo_db_location" VALUES(51991,NULL,'Erie, KS',21854,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51992,NULL,'Erie, KS 66733',21854,222,NULL,20,29845,0);
INSERT INTO "django_geo_db_location" VALUES(51993,NULL,'Farlington, KS',21855,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51994,NULL,'Farlington, KS 66734',21855,222,NULL,20,29846,0);
INSERT INTO "django_geo_db_location" VALUES(51995,NULL,'Franklin, KS',21856,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51996,NULL,'Franklin, KS 66735',21856,222,NULL,20,29847,0);
INSERT INTO "django_geo_db_location" VALUES(51997,NULL,'Fredonia, KS',21857,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(51998,NULL,'Fredonia, KS 66736',21857,222,NULL,20,29848,0);
INSERT INTO "django_geo_db_location" VALUES(51999,NULL,'Fulton, KS',21858,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52000,NULL,'Fulton, KS 66738',21858,222,NULL,20,29849,0);
INSERT INTO "django_geo_db_location" VALUES(52001,NULL,'Galena, KS',21859,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52002,NULL,'Galena, KS 66739',21859,222,NULL,20,29850,0);
INSERT INTO "django_geo_db_location" VALUES(52003,NULL,'Galesburg, KS',21860,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52004,NULL,'Galesburg, KS 66740',21860,222,NULL,20,29851,0);
INSERT INTO "django_geo_db_location" VALUES(52005,NULL,'Arcadia, KS 66741',21842,222,NULL,20,29852,0);
INSERT INTO "django_geo_db_location" VALUES(52006,NULL,'Gas, KS',21861,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52007,NULL,'Gas, KS 66742',21861,222,NULL,20,29853,0);
INSERT INTO "django_geo_db_location" VALUES(52008,NULL,'Girard, KS',21862,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52009,NULL,'Girard, KS 66743',21862,222,NULL,20,29854,0);
INSERT INTO "django_geo_db_location" VALUES(52010,NULL,'Hepler, KS',21863,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52011,NULL,'Hepler, KS 66746',21863,222,NULL,20,29855,0);
INSERT INTO "django_geo_db_location" VALUES(52012,NULL,'Neodesha, KS',21864,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52013,NULL,'Neodesha, KS 66747',21864,222,NULL,20,29856,0);
INSERT INTO "django_geo_db_location" VALUES(52014,NULL,'Humboldt, KS',21865,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52015,NULL,'Humboldt, KS 66748',21865,222,NULL,20,29857,0);
INSERT INTO "django_geo_db_location" VALUES(52016,NULL,'Iola, KS',21866,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52017,NULL,'Iola, KS 66749',21866,222,NULL,20,29858,0);
INSERT INTO "django_geo_db_location" VALUES(52018,NULL,'La Harpe, KS',21867,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52019,NULL,'La Harpe, KS 66751',21867,222,NULL,20,29859,0);
INSERT INTO "django_geo_db_location" VALUES(52020,NULL,'Ross, KS',21868,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52021,NULL,'Ross, KS 66752',21868,222,NULL,20,29860,0);
INSERT INTO "django_geo_db_location" VALUES(52022,NULL,'McCune, KS',21869,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52023,NULL,'McCune, KS 66753',21869,222,NULL,20,29861,0);
INSERT INTO "django_geo_db_location" VALUES(52024,NULL,'Mapleton, KS',21870,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52025,NULL,'Mapleton, KS 66754',21870,222,NULL,20,29862,0);
INSERT INTO "django_geo_db_location" VALUES(52026,NULL,'Moran, KS',21871,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52027,NULL,'Moran, KS 66755',21871,222,NULL,20,29863,0);
INSERT INTO "django_geo_db_location" VALUES(52028,NULL,'Mulberry, KS',21872,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52029,NULL,'Mulberry, KS 66756',21872,222,NULL,20,29864,0);
INSERT INTO "django_geo_db_location" VALUES(52030,NULL,'Neodesha, KS 66757',21864,222,NULL,20,29865,0);
INSERT INTO "django_geo_db_location" VALUES(52031,NULL,'Neosho Falls, KS',21873,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52032,NULL,'Neosho Falls, KS 66758',21873,222,NULL,20,29866,0);
INSERT INTO "django_geo_db_location" VALUES(52033,NULL,'New Albany, KS',21874,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52034,NULL,'New Albany, KS 66759',21874,222,NULL,20,29867,0);
INSERT INTO "django_geo_db_location" VALUES(52035,NULL,'Opolis, KS',21875,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52036,NULL,'Opolis, KS 66760',21875,222,NULL,20,29868,0);
INSERT INTO "django_geo_db_location" VALUES(52037,NULL,'Piqua, KS',21876,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52038,NULL,'Piqua, KS 66761',21876,222,NULL,20,29869,0);
INSERT INTO "django_geo_db_location" VALUES(52039,NULL,'Pittsburg, KS',21877,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52040,NULL,'Pittsburg, KS 66762',21877,222,NULL,20,29870,0);
INSERT INTO "django_geo_db_location" VALUES(52041,NULL,'Frontenac, KS',21878,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52042,NULL,'Frontenac, KS 66763',21878,222,NULL,20,29871,0);
INSERT INTO "django_geo_db_location" VALUES(52043,NULL,'Prescott, KS',21879,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52044,NULL,'Prescott, KS 66767',21879,222,NULL,20,29872,0);
INSERT INTO "django_geo_db_location" VALUES(52045,NULL,'Redfield, KS',21880,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52046,NULL,'Redfield, KS 66769',21880,222,NULL,20,29873,0);
INSERT INTO "django_geo_db_location" VALUES(52047,NULL,'Riverton, KS',21881,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52048,NULL,'Riverton, KS 66770',21881,222,NULL,20,29874,0);
INSERT INTO "django_geo_db_location" VALUES(52049,NULL,'Saint Paul, KS',21882,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52050,NULL,'Saint Paul, KS 66771',21882,222,NULL,20,29875,0);
INSERT INTO "django_geo_db_location" VALUES(52051,NULL,'Savonburg, KS',21883,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52052,NULL,'Savonburg, KS 66772',21883,222,NULL,20,29876,0);
INSERT INTO "django_geo_db_location" VALUES(52053,NULL,'Scammon, KS',21884,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52054,NULL,'Scammon, KS 66773',21884,222,NULL,20,29877,0);
INSERT INTO "django_geo_db_location" VALUES(52055,NULL,'Stark, KS',21885,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52056,NULL,'Stark, KS 66775',21885,222,NULL,20,29878,0);
INSERT INTO "django_geo_db_location" VALUES(52057,NULL,'Thayer, KS',21886,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52058,NULL,'Thayer, KS 66776',21886,222,NULL,20,29879,0);
INSERT INTO "django_geo_db_location" VALUES(52059,NULL,'Toronto, KS',21887,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52060,NULL,'Toronto, KS 66777',21887,222,NULL,20,29880,0);
INSERT INTO "django_geo_db_location" VALUES(52061,NULL,'Treece, KS',21888,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52062,NULL,'Treece, KS 66778',21888,222,NULL,20,29881,0);
INSERT INTO "django_geo_db_location" VALUES(52063,NULL,'Uniontown, KS',21889,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52064,NULL,'Uniontown, KS 66779',21889,222,NULL,20,29882,0);
INSERT INTO "django_geo_db_location" VALUES(52065,NULL,'Walnut, KS',21890,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52066,NULL,'Walnut, KS 66780',21890,222,NULL,20,29883,0);
INSERT INTO "django_geo_db_location" VALUES(52067,NULL,'Weir, KS 66781',21797,222,NULL,20,29884,0);
INSERT INTO "django_geo_db_location" VALUES(52068,NULL,'West Mineral, KS',21891,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52069,NULL,'West Mineral, KS 66782',21891,222,NULL,20,29885,0);
INSERT INTO "django_geo_db_location" VALUES(52070,NULL,'Yates Center, KS',21892,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52071,NULL,'Yates Center, KS 66783',21892,222,NULL,20,29886,0);
INSERT INTO "django_geo_db_location" VALUES(52072,NULL,'Emporia, KS',21893,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52073,NULL,'Emporia, KS 66801',21893,222,NULL,20,29887,0);
INSERT INTO "django_geo_db_location" VALUES(52074,NULL,'Bern, KS 66804',21766,222,NULL,20,29888,0);
INSERT INTO "django_geo_db_location" VALUES(52075,NULL,'Admire, KS',21894,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52076,NULL,'Admire, KS 66830',21894,222,NULL,20,29889,0);
INSERT INTO "django_geo_db_location" VALUES(52077,NULL,'Allen, KS',21895,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52078,NULL,'Allen, KS 66833',21895,222,NULL,20,29890,0);
INSERT INTO "django_geo_db_location" VALUES(52079,NULL,'Alta Vista, KS',21896,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52080,NULL,'Alta Vista, KS 66834',21896,222,NULL,20,29891,0);
INSERT INTO "django_geo_db_location" VALUES(52081,NULL,'Americus, KS',21897,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52082,NULL,'Americus, KS 66835',21897,222,NULL,20,29892,0);
INSERT INTO "django_geo_db_location" VALUES(52083,NULL,'Burdick, KS',21898,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52084,NULL,'Burdick, KS 66838',21898,222,NULL,20,29893,0);
INSERT INTO "django_geo_db_location" VALUES(52085,NULL,'Burlington, KS',21899,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52086,NULL,'Burlington, KS 66839',21899,222,NULL,20,29894,0);
INSERT INTO "django_geo_db_location" VALUES(52087,NULL,'Burns, KS',21900,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52088,NULL,'Burns, KS 66840',21900,222,NULL,20,29895,0);
INSERT INTO "django_geo_db_location" VALUES(52089,NULL,'Cassoday, KS',21901,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52090,NULL,'Cassoday, KS 66842',21901,222,NULL,20,29896,0);
INSERT INTO "django_geo_db_location" VALUES(52091,NULL,'Cedar Point, KS',21902,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52092,NULL,'Cedar Point, KS 66843',21902,222,NULL,20,29897,0);
INSERT INTO "django_geo_db_location" VALUES(52093,NULL,'Cottonwood Falls, KS',21903,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52094,NULL,'Cottonwood Falls, KS 66845',21903,222,NULL,20,29898,0);
INSERT INTO "django_geo_db_location" VALUES(52095,NULL,'Council Grove, KS',21904,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52096,NULL,'Council Grove, KS 66846',21904,222,NULL,20,29899,0);
INSERT INTO "django_geo_db_location" VALUES(52097,NULL,'Dwight, KS',21905,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52098,NULL,'Dwight, KS 66849',21905,222,NULL,20,29900,0);
INSERT INTO "django_geo_db_location" VALUES(52099,NULL,'Elmdale, KS',21906,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52100,NULL,'Elmdale, KS 66850',21906,222,NULL,20,29901,0);
INSERT INTO "django_geo_db_location" VALUES(52101,NULL,'Florence, KS',21907,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52102,NULL,'Florence, KS 66851',21907,222,NULL,20,29902,0);
INSERT INTO "django_geo_db_location" VALUES(52103,NULL,'Gridley, KS',21908,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52104,NULL,'Gridley, KS 66852',21908,222,NULL,20,29903,0);
INSERT INTO "django_geo_db_location" VALUES(52105,NULL,'Hamilton, KS',21909,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52106,NULL,'Hamilton, KS 66853',21909,222,NULL,20,29904,0);
INSERT INTO "django_geo_db_location" VALUES(52107,NULL,'Hartford, KS',21910,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52108,NULL,'Hartford, KS 66854',21910,222,NULL,20,29905,0);
INSERT INTO "django_geo_db_location" VALUES(52109,NULL,'Lamont, KS',21911,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52110,NULL,'Lamont, KS 66855',21911,222,NULL,20,29906,0);
INSERT INTO "django_geo_db_location" VALUES(52111,NULL,'Lebo, KS',21912,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52112,NULL,'Lebo, KS 66856',21912,222,NULL,20,29907,0);
INSERT INTO "django_geo_db_location" VALUES(52113,NULL,'Le Roy, KS',21913,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52114,NULL,'Le Roy, KS 66857',21913,222,NULL,20,29908,0);
INSERT INTO "django_geo_db_location" VALUES(52115,NULL,'Lincolnville, KS',21914,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52116,NULL,'Lincolnville, KS 66858',21914,222,NULL,20,29909,0);
INSERT INTO "django_geo_db_location" VALUES(52117,NULL,'Lost Springs, KS',21915,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52118,NULL,'Lost Springs, KS 66859',21915,222,NULL,20,29910,0);
INSERT INTO "django_geo_db_location" VALUES(52119,NULL,'Madison, KS',21916,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52120,NULL,'Madison, KS 66860',21916,222,NULL,20,29911,0);
INSERT INTO "django_geo_db_location" VALUES(52121,NULL,'Marion, KS',21917,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52122,NULL,'Marion, KS 66861',21917,222,NULL,20,29912,0);
INSERT INTO "django_geo_db_location" VALUES(52123,NULL,'Matfield Green, KS',21918,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52124,NULL,'Matfield Green, KS 66862',21918,222,NULL,20,29913,0);
INSERT INTO "django_geo_db_location" VALUES(52125,NULL,'Neal, KS',21919,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52126,NULL,'Neal, KS 66863',21919,222,NULL,20,29914,0);
INSERT INTO "django_geo_db_location" VALUES(52127,NULL,'Neosho Rapids, KS',21920,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52128,NULL,'Neosho Rapids, KS 66864',21920,222,NULL,20,29915,0);
INSERT INTO "django_geo_db_location" VALUES(52129,NULL,'Olpe, KS',21921,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52130,NULL,'Olpe, KS 66865',21921,222,NULL,20,29916,0);
INSERT INTO "django_geo_db_location" VALUES(52131,NULL,'Peabody, KS',21922,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52132,NULL,'Peabody, KS 66866',21922,222,NULL,20,29917,0);
INSERT INTO "django_geo_db_location" VALUES(52133,NULL,'Reading, KS',21923,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52134,NULL,'Reading, KS 66868',21923,222,NULL,20,29918,0);
INSERT INTO "django_geo_db_location" VALUES(52135,NULL,'Strong City, KS',21924,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52136,NULL,'Strong City, KS 66869',21924,222,NULL,20,29919,0);
INSERT INTO "django_geo_db_location" VALUES(52137,NULL,'Virgil, KS',21925,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52138,NULL,'Virgil, KS 66870',21925,222,NULL,20,29920,0);
INSERT INTO "django_geo_db_location" VALUES(52139,NULL,'Waverly, KS',21926,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52140,NULL,'Waverly, KS 66871',21926,222,NULL,20,29921,0);
INSERT INTO "django_geo_db_location" VALUES(52141,NULL,'White City, KS',21927,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52142,NULL,'White City, KS 66872',21927,222,NULL,20,29922,0);
INSERT INTO "django_geo_db_location" VALUES(52143,NULL,'Wilsey, KS',21928,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52144,NULL,'Wilsey, KS 66873',21928,222,NULL,20,29923,0);
INSERT INTO "django_geo_db_location" VALUES(52145,NULL,'Concordia, KS',21929,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52146,NULL,'Concordia, KS 66901',21929,222,NULL,20,29924,0);
INSERT INTO "django_geo_db_location" VALUES(52147,NULL,'Agenda, KS',21930,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52148,NULL,'Agenda, KS 66930',21930,222,NULL,20,29925,0);
INSERT INTO "django_geo_db_location" VALUES(52149,NULL,'Athol, KS',21931,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52150,NULL,'Athol, KS 66932',21931,222,NULL,20,29926,0);
INSERT INTO "django_geo_db_location" VALUES(52151,NULL,'Barnes, KS',21932,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52152,NULL,'Barnes, KS 66933',21932,222,NULL,20,29927,0);
INSERT INTO "django_geo_db_location" VALUES(52153,NULL,'Belleville, KS',21933,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52154,NULL,'Belleville, KS 66935',21933,222,NULL,20,29928,0);
INSERT INTO "django_geo_db_location" VALUES(52155,NULL,'Burr Oak, KS',21934,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52156,NULL,'Burr Oak, KS 66936',21934,222,NULL,20,29929,0);
INSERT INTO "django_geo_db_location" VALUES(52157,NULL,'Clifton, KS',21935,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52158,NULL,'Clifton, KS 66937',21935,222,NULL,20,29930,0);
INSERT INTO "django_geo_db_location" VALUES(52159,NULL,'Clyde, KS',21936,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52160,NULL,'Clyde, KS 66938',21936,222,NULL,20,29931,0);
INSERT INTO "django_geo_db_location" VALUES(52161,NULL,'Courtland, KS',21937,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52162,NULL,'Courtland, KS 66939',21937,222,NULL,20,29932,0);
INSERT INTO "django_geo_db_location" VALUES(52163,NULL,'Cuba, KS',21938,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52164,NULL,'Cuba, KS 66940',21938,222,NULL,20,29933,0);
INSERT INTO "django_geo_db_location" VALUES(52165,NULL,'Esbon, KS',21939,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52166,NULL,'Esbon, KS 66941',21939,222,NULL,20,29934,0);
INSERT INTO "django_geo_db_location" VALUES(52167,NULL,'Formoso, KS',21940,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52168,NULL,'Formoso, KS 66942',21940,222,NULL,20,29935,0);
INSERT INTO "django_geo_db_location" VALUES(52169,NULL,'Greenleaf, KS',21941,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52170,NULL,'Greenleaf, KS 66943',21941,222,NULL,20,29936,0);
INSERT INTO "django_geo_db_location" VALUES(52171,NULL,'Haddam, KS',21942,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52172,NULL,'Haddam, KS 66944',21942,222,NULL,20,29937,0);
INSERT INTO "django_geo_db_location" VALUES(52173,NULL,'Hanover, KS',21943,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52174,NULL,'Hanover, KS 66945',21943,222,NULL,20,29938,0);
INSERT INTO "django_geo_db_location" VALUES(52175,NULL,'Hollenberg, KS',21944,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52176,NULL,'Hollenberg, KS 66946',21944,222,NULL,20,29939,0);
INSERT INTO "django_geo_db_location" VALUES(52177,NULL,'Jamestown, KS',21945,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52178,NULL,'Jamestown, KS 66948',21945,222,NULL,20,29940,0);
INSERT INTO "django_geo_db_location" VALUES(52179,NULL,'Jewell, KS',21946,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52180,NULL,'Jewell, KS 66949',21946,222,NULL,20,29941,0);
INSERT INTO "django_geo_db_location" VALUES(52181,NULL,'Kensington, KS',21947,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52182,NULL,'Kensington, KS 66951',21947,222,NULL,20,29942,0);
INSERT INTO "django_geo_db_location" VALUES(52183,NULL,'Lebanon, KS',21948,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52184,NULL,'Lebanon, KS 66952',21948,222,NULL,20,29943,0);
INSERT INTO "django_geo_db_location" VALUES(52185,NULL,'Linn, KS',21949,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52186,NULL,'Linn, KS 66953',21949,222,NULL,20,29944,0);
INSERT INTO "django_geo_db_location" VALUES(52187,NULL,'Mahaska, KS',21950,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52188,NULL,'Mahaska, KS 66955',21950,222,NULL,20,29945,0);
INSERT INTO "django_geo_db_location" VALUES(52189,NULL,'Mankato, KS',21951,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52190,NULL,'Mankato, KS 66956',21951,222,NULL,20,29946,0);
INSERT INTO "django_geo_db_location" VALUES(52191,NULL,'Morrowville, KS',21952,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52192,NULL,'Morrowville, KS 66958',21952,222,NULL,20,29947,0);
INSERT INTO "django_geo_db_location" VALUES(52193,NULL,'Munden, KS',21953,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52194,NULL,'Munden, KS 66959',21953,222,NULL,20,29948,0);
INSERT INTO "django_geo_db_location" VALUES(52195,NULL,'Narka, KS',21954,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52196,NULL,'Narka, KS 66960',21954,222,NULL,20,29949,0);
INSERT INTO "django_geo_db_location" VALUES(52197,NULL,'Norway, KS',21955,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52198,NULL,'Norway, KS 66961',21955,222,NULL,20,29950,0);
INSERT INTO "django_geo_db_location" VALUES(52199,NULL,'Palmer, KS',21956,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52200,NULL,'Palmer, KS 66962',21956,222,NULL,20,29951,0);
INSERT INTO "django_geo_db_location" VALUES(52201,NULL,'Randall, KS',21957,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52202,NULL,'Randall, KS 66963',21957,222,NULL,20,29952,0);
INSERT INTO "django_geo_db_location" VALUES(52203,NULL,'Republic, KS',21958,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52204,NULL,'Republic, KS 66964',21958,222,NULL,20,29953,0);
INSERT INTO "django_geo_db_location" VALUES(52205,NULL,'Scandia, KS',21959,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52206,NULL,'Scandia, KS 66966',21959,222,NULL,20,29954,0);
INSERT INTO "django_geo_db_location" VALUES(52207,NULL,'Smith Center, KS',21960,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52208,NULL,'Smith Center, KS 66967',21960,222,NULL,20,29955,0);
INSERT INTO "django_geo_db_location" VALUES(52209,NULL,'Washington, KS',21961,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52210,NULL,'Washington, KS 66968',21961,222,NULL,20,29956,0);
INSERT INTO "django_geo_db_location" VALUES(52211,NULL,'Scandia, KS 66969',21959,222,NULL,20,29957,0);
INSERT INTO "django_geo_db_location" VALUES(52212,NULL,'Webber, KS',21962,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52213,NULL,'Webber, KS 66970',21962,222,NULL,20,29958,0);
INSERT INTO "django_geo_db_location" VALUES(52214,NULL,'Buffalo, KS 66998',21847,222,NULL,20,29959,0);
INSERT INTO "django_geo_db_location" VALUES(52215,NULL,'Andale, KS',21963,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52216,NULL,'Andale, KS 67001',21963,222,NULL,20,29960,0);
INSERT INTO "django_geo_db_location" VALUES(52217,NULL,'Andover, KS',21964,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52218,NULL,'Andover, KS 67002',21964,222,NULL,20,29961,0);
INSERT INTO "django_geo_db_location" VALUES(52219,NULL,'Anthony, KS',21965,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52220,NULL,'Anthony, KS 67003',21965,222,NULL,20,29962,0);
INSERT INTO "django_geo_db_location" VALUES(52221,NULL,'Argonia, KS',21966,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52222,NULL,'Argonia, KS 67004',21966,222,NULL,20,29963,0);
INSERT INTO "django_geo_db_location" VALUES(52223,NULL,'Arkansas City, KS',21967,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52224,NULL,'Arkansas City, KS 67005',21967,222,NULL,20,29964,0);
INSERT INTO "django_geo_db_location" VALUES(52225,NULL,'Atlanta, KS',21968,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52226,NULL,'Atlanta, KS 67008',21968,222,NULL,20,29965,0);
INSERT INTO "django_geo_db_location" VALUES(52227,NULL,'Attica, KS',21969,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52228,NULL,'Attica, KS 67009',21969,222,NULL,20,29966,0);
INSERT INTO "django_geo_db_location" VALUES(52229,NULL,'Augusta, KS',21970,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52230,NULL,'Augusta, KS 67010',21970,222,NULL,20,29967,0);
INSERT INTO "django_geo_db_location" VALUES(52231,NULL,'Beaumont, KS',21971,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52232,NULL,'Beaumont, KS 67012',21971,222,NULL,20,29968,0);
INSERT INTO "django_geo_db_location" VALUES(52233,NULL,'Belle Plaine, KS',21972,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52234,NULL,'Belle Plaine, KS 67013',21972,222,NULL,20,29969,0);
INSERT INTO "django_geo_db_location" VALUES(52235,NULL,'Bentley, KS',21973,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52236,NULL,'Bentley, KS 67016',21973,222,NULL,20,29970,0);
INSERT INTO "django_geo_db_location" VALUES(52237,NULL,'Benton, KS',21974,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52238,NULL,'Benton, KS 67017',21974,222,NULL,20,29971,0);
INSERT INTO "django_geo_db_location" VALUES(52239,NULL,'Bluff City, KS',21975,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52240,NULL,'Bluff City, KS 67018',21975,222,NULL,20,29972,0);
INSERT INTO "django_geo_db_location" VALUES(52241,NULL,'Burden, KS',21976,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52242,NULL,'Burden, KS 67019',21976,222,NULL,20,29973,0);
INSERT INTO "django_geo_db_location" VALUES(52243,NULL,'Burrton, KS',21977,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52244,NULL,'Burrton, KS 67020',21977,222,NULL,20,29974,0);
INSERT INTO "django_geo_db_location" VALUES(52245,NULL,'Byers, KS',21978,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52246,NULL,'Byers, KS 67021',21978,222,NULL,20,29975,0);
INSERT INTO "django_geo_db_location" VALUES(52247,NULL,'Caldwell, KS',21979,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52248,NULL,'Caldwell, KS 67022',21979,222,NULL,20,29976,0);
INSERT INTO "django_geo_db_location" VALUES(52249,NULL,'Cambridge, KS',21980,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52250,NULL,'Cambridge, KS 67023',21980,222,NULL,20,29977,0);
INSERT INTO "django_geo_db_location" VALUES(52251,NULL,'Cedar Vale, KS',21981,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52252,NULL,'Cedar Vale, KS 67024',21981,222,NULL,20,29978,0);
INSERT INTO "django_geo_db_location" VALUES(52253,NULL,'Cheney, KS',21982,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52254,NULL,'Cheney, KS 67025',21982,222,NULL,20,29979,0);
INSERT INTO "django_geo_db_location" VALUES(52255,NULL,'Clearwater, KS',21983,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52256,NULL,'Clearwater, KS 67026',21983,222,NULL,20,29980,0);
INSERT INTO "django_geo_db_location" VALUES(52257,NULL,'Coats, KS',21984,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52258,NULL,'Coats, KS 67028',21984,222,NULL,20,29981,0);
INSERT INTO "django_geo_db_location" VALUES(52259,NULL,'Coldwater, KS',21985,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52260,NULL,'Coldwater, KS 67029',21985,222,NULL,20,29982,0);
INSERT INTO "django_geo_db_location" VALUES(52261,NULL,'Colwich, KS',21986,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52262,NULL,'Colwich, KS 67030',21986,222,NULL,20,29983,0);
INSERT INTO "django_geo_db_location" VALUES(52263,NULL,'Conway Springs, KS',21987,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52264,NULL,'Conway Springs, KS 67031',21987,222,NULL,20,29984,0);
INSERT INTO "django_geo_db_location" VALUES(52265,NULL,'Richland, KS',21988,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52266,NULL,'Richland, KS 67033',21988,222,NULL,20,29985,0);
INSERT INTO "django_geo_db_location" VALUES(52267,NULL,'Cunningham, KS',21989,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52268,NULL,'Cunningham, KS 67035',21989,222,NULL,20,29986,0);
INSERT INTO "django_geo_db_location" VALUES(52269,NULL,'Danville, KS',21990,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52270,NULL,'Danville, KS 67036',21990,222,NULL,20,29987,0);
INSERT INTO "django_geo_db_location" VALUES(52271,NULL,'Derby, KS',21991,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52272,NULL,'Derby, KS 67037',21991,222,NULL,20,29988,0);
INSERT INTO "django_geo_db_location" VALUES(52273,NULL,'Dexter, KS',21992,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52274,NULL,'Dexter, KS 67038',21992,222,NULL,20,29989,0);
INSERT INTO "django_geo_db_location" VALUES(52275,NULL,'Douglass, KS',21993,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52276,NULL,'Douglass, KS 67039',21993,222,NULL,20,29990,0);
INSERT INTO "django_geo_db_location" VALUES(52277,NULL,'Elbing, KS',21994,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52278,NULL,'Elbing, KS 67041',21994,222,NULL,20,29991,0);
INSERT INTO "django_geo_db_location" VALUES(52279,NULL,'El Dorado, KS',21995,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52280,NULL,'El Dorado, KS 67042',21995,222,NULL,20,29992,0);
INSERT INTO "django_geo_db_location" VALUES(52281,NULL,'Eureka, KS',21996,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52282,NULL,'Eureka, KS 67045',21996,222,NULL,20,29993,0);
INSERT INTO "django_geo_db_location" VALUES(52283,NULL,'Fall River, KS',21997,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52284,NULL,'Fall River, KS 67047',21997,222,NULL,20,29994,0);
INSERT INTO "django_geo_db_location" VALUES(52285,NULL,'Freeport, KS',21998,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52286,NULL,'Freeport, KS 67049',21998,222,NULL,20,29995,0);
INSERT INTO "django_geo_db_location" VALUES(52287,NULL,'Garden Plain, KS',21999,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52288,NULL,'Garden Plain, KS 67050',21999,222,NULL,20,29996,0);
INSERT INTO "django_geo_db_location" VALUES(52289,NULL,'Geuda Springs, KS',22000,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52290,NULL,'Geuda Springs, KS 67051',22000,222,NULL,20,29997,0);
INSERT INTO "django_geo_db_location" VALUES(52291,NULL,'Goddard, KS',22001,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52292,NULL,'Goddard, KS 67052',22001,222,NULL,20,29998,0);
INSERT INTO "django_geo_db_location" VALUES(52293,NULL,'Goessel, KS',22002,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52294,NULL,'Goessel, KS 67053',22002,222,NULL,20,29999,0);
INSERT INTO "django_geo_db_location" VALUES(52295,NULL,'Greensburg, KS',22003,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52296,NULL,'Greensburg, KS 67054',22003,222,NULL,20,30000,0);
INSERT INTO "django_geo_db_location" VALUES(52297,NULL,'Greenwich, KS',22004,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52298,NULL,'Greenwich, KS 67055',22004,222,NULL,20,30001,0);
INSERT INTO "django_geo_db_location" VALUES(52299,NULL,'Halstead, KS',22005,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52300,NULL,'Halstead, KS 67056',22005,222,NULL,20,30002,0);
INSERT INTO "django_geo_db_location" VALUES(52301,NULL,'Hardtner, KS',22006,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52302,NULL,'Hardtner, KS 67057',22006,222,NULL,20,30003,0);
INSERT INTO "django_geo_db_location" VALUES(52303,NULL,'Harper, KS',22007,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52304,NULL,'Harper, KS 67058',22007,222,NULL,20,30004,0);
INSERT INTO "django_geo_db_location" VALUES(52305,NULL,'Haviland, KS',22008,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52306,NULL,'Haviland, KS 67059',22008,222,NULL,20,30005,0);
INSERT INTO "django_geo_db_location" VALUES(52307,NULL,'Haysville, KS',22009,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52308,NULL,'Haysville, KS 67060',22009,222,NULL,20,30006,0);
INSERT INTO "django_geo_db_location" VALUES(52309,NULL,'Hazelton, KS',22010,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52310,NULL,'Hazelton, KS 67061',22010,222,NULL,20,30007,0);
INSERT INTO "django_geo_db_location" VALUES(52311,NULL,'Hesston, KS',22011,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52312,NULL,'Hesston, KS 67062',22011,222,NULL,20,30008,0);
INSERT INTO "django_geo_db_location" VALUES(52313,NULL,'Hillsboro, KS',22012,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52314,NULL,'Hillsboro, KS 67063',22012,222,NULL,20,30009,0);
INSERT INTO "django_geo_db_location" VALUES(52315,NULL,'Isabel, KS',22013,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52316,NULL,'Isabel, KS 67065',22013,222,NULL,20,30010,0);
INSERT INTO "django_geo_db_location" VALUES(52317,NULL,'Iuka, KS',22014,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52318,NULL,'Iuka, KS 67066',22014,222,NULL,20,30011,0);
INSERT INTO "django_geo_db_location" VALUES(52319,NULL,'Kechi, KS',22015,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52320,NULL,'Kechi, KS 67067',22015,222,NULL,20,30012,0);
INSERT INTO "django_geo_db_location" VALUES(52321,NULL,'Kingman, KS',22016,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52322,NULL,'Kingman, KS 67068',22016,222,NULL,20,30013,0);
INSERT INTO "django_geo_db_location" VALUES(52323,NULL,'Ninnescah, KS',22017,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52324,NULL,'Ninnescah, KS 67069',22017,222,NULL,20,30014,0);
INSERT INTO "django_geo_db_location" VALUES(52325,NULL,'Kiowa, KS',22018,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52326,NULL,'Kiowa, KS 67070',22018,222,NULL,20,30015,0);
INSERT INTO "django_geo_db_location" VALUES(52327,NULL,'Lake City, KS',22019,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52328,NULL,'Lake City, KS 67071',22019,222,NULL,20,30016,0);
INSERT INTO "django_geo_db_location" VALUES(52329,NULL,'Latham, KS',22020,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52330,NULL,'Latham, KS 67072',22020,222,NULL,20,30017,0);
INSERT INTO "django_geo_db_location" VALUES(52331,NULL,'Lehigh, KS',22021,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52332,NULL,'Lehigh, KS 67073',22021,222,NULL,20,30018,0);
INSERT INTO "django_geo_db_location" VALUES(52333,NULL,'Leon, KS',22022,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52334,NULL,'Leon, KS 67074',22022,222,NULL,20,30019,0);
INSERT INTO "django_geo_db_location" VALUES(52335,NULL,'Maize, KS',22023,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52336,NULL,'Maize, KS 67101',22023,222,NULL,20,30020,0);
INSERT INTO "django_geo_db_location" VALUES(52337,NULL,'Maple City, KS',22024,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52338,NULL,'Maple City, KS 67102',22024,222,NULL,20,30021,0);
INSERT INTO "django_geo_db_location" VALUES(52339,NULL,'Mayfield, KS',22025,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52340,NULL,'Mayfield, KS 67103',22025,222,NULL,20,30022,0);
INSERT INTO "django_geo_db_location" VALUES(52341,NULL,'Medicine Lodge, KS',22026,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52342,NULL,'Medicine Lodge, KS 67104',22026,222,NULL,20,30023,0);
INSERT INTO "django_geo_db_location" VALUES(52343,NULL,'Milan, KS',22027,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52344,NULL,'Milan, KS 67105',22027,222,NULL,20,30024,0);
INSERT INTO "django_geo_db_location" VALUES(52345,NULL,'Milton, KS',22028,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52346,NULL,'Milton, KS 67106',22028,222,NULL,20,30025,0);
INSERT INTO "django_geo_db_location" VALUES(52347,NULL,'Moundridge, KS',22029,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52348,NULL,'Moundridge, KS 67107',22029,222,NULL,20,30026,0);
INSERT INTO "django_geo_db_location" VALUES(52349,NULL,'Mount Hope, KS',22030,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52350,NULL,'Mount Hope, KS 67108',22030,222,NULL,20,30027,0);
INSERT INTO "django_geo_db_location" VALUES(52351,NULL,'Mullinville, KS',22031,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52352,NULL,'Mullinville, KS 67109',22031,222,NULL,20,30028,0);
INSERT INTO "django_geo_db_location" VALUES(52353,NULL,'Mulvane, KS',22032,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52354,NULL,'Mulvane, KS 67110',22032,222,NULL,20,30029,0);
INSERT INTO "django_geo_db_location" VALUES(52355,NULL,'Murdock, KS',22033,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52356,NULL,'Murdock, KS 67111',22033,222,NULL,20,30030,0);
INSERT INTO "django_geo_db_location" VALUES(52357,NULL,'Nashville, KS',22034,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52358,NULL,'Nashville, KS 67112',22034,222,NULL,20,30031,0);
INSERT INTO "django_geo_db_location" VALUES(52359,NULL,'Newton, KS',22035,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52360,NULL,'Newton, KS 67114',22035,222,NULL,20,30032,0);
INSERT INTO "django_geo_db_location" VALUES(52361,NULL,'North Newton, KS',22036,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52362,NULL,'North Newton, KS 67117',22036,222,NULL,20,30033,0);
INSERT INTO "django_geo_db_location" VALUES(52363,NULL,'Norwich, KS',22037,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52364,NULL,'Norwich, KS 67118',22037,222,NULL,20,30034,0);
INSERT INTO "django_geo_db_location" VALUES(52365,NULL,'Oxford, KS',22038,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52366,NULL,'Oxford, KS 67119',22038,222,NULL,20,30035,0);
INSERT INTO "django_geo_db_location" VALUES(52367,NULL,'Peck, KS',22039,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52368,NULL,'Peck, KS 67120',22039,222,NULL,20,30036,0);
INSERT INTO "django_geo_db_location" VALUES(52369,NULL,'Piedmont, KS',22040,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52370,NULL,'Piedmont, KS 67122',22040,222,NULL,20,30037,0);
INSERT INTO "django_geo_db_location" VALUES(52371,NULL,'Potwin, KS',22041,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52372,NULL,'Potwin, KS 67123',22041,222,NULL,20,30038,0);
INSERT INTO "django_geo_db_location" VALUES(52373,NULL,'Pratt, KS',22042,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52374,NULL,'Pratt, KS 67124',22042,222,NULL,20,30039,0);
INSERT INTO "django_geo_db_location" VALUES(52375,NULL,'Protection, KS',22043,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52376,NULL,'Protection, KS 67127',22043,222,NULL,20,30040,0);
INSERT INTO "django_geo_db_location" VALUES(52377,NULL,'Rago, KS',22044,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52378,NULL,'Rago, KS 67128',22044,222,NULL,20,30041,0);
INSERT INTO "django_geo_db_location" VALUES(52379,NULL,'Rock, KS',22045,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52380,NULL,'Rock, KS 67131',22045,222,NULL,20,30042,0);
INSERT INTO "django_geo_db_location" VALUES(52381,NULL,'Rosalia, KS',22046,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52382,NULL,'Rosalia, KS 67132',22046,222,NULL,20,30043,0);
INSERT INTO "django_geo_db_location" VALUES(52383,NULL,'Rose Hill, KS',22047,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52384,NULL,'Rose Hill, KS 67133',22047,222,NULL,20,30044,0);
INSERT INTO "django_geo_db_location" VALUES(52385,NULL,'Sawyer, KS',22048,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52386,NULL,'Sawyer, KS 67134',22048,222,NULL,20,30045,0);
INSERT INTO "django_geo_db_location" VALUES(52387,NULL,'Sedgwick, KS',22049,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52388,NULL,'Sedgwick, KS 67135',22049,222,NULL,20,30046,0);
INSERT INTO "django_geo_db_location" VALUES(52389,NULL,'Severy, KS',22050,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52390,NULL,'Severy, KS 67137',22050,222,NULL,20,30047,0);
INSERT INTO "django_geo_db_location" VALUES(52391,NULL,'Sharon, KS',22051,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52392,NULL,'Sharon, KS 67138',22051,222,NULL,20,30048,0);
INSERT INTO "django_geo_db_location" VALUES(52393,NULL,'South Haven, KS',22052,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52394,NULL,'South Haven, KS 67140',22052,222,NULL,20,30049,0);
INSERT INTO "django_geo_db_location" VALUES(52395,NULL,'Spivey, KS',22053,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52396,NULL,'Spivey, KS 67142',22053,222,NULL,20,30050,0);
INSERT INTO "django_geo_db_location" VALUES(52397,NULL,'Sun City, KS',22054,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52398,NULL,'Sun City, KS 67143',22054,222,NULL,20,30051,0);
INSERT INTO "django_geo_db_location" VALUES(52399,NULL,'Towanda, KS',22055,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52400,NULL,'Towanda, KS 67144',22055,222,NULL,20,30052,0);
INSERT INTO "django_geo_db_location" VALUES(52401,NULL,'Udall, KS',22056,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52402,NULL,'Udall, KS 67146',22056,222,NULL,20,30053,0);
INSERT INTO "django_geo_db_location" VALUES(52403,NULL,'Valley Center, KS',22057,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52404,NULL,'Valley Center, KS 67147',22057,222,NULL,20,30054,0);
INSERT INTO "django_geo_db_location" VALUES(52405,NULL,'Viola, KS',22058,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52406,NULL,'Viola, KS 67149',22058,222,NULL,20,30055,0);
INSERT INTO "django_geo_db_location" VALUES(52407,NULL,'Waldron, KS',22059,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52408,NULL,'Waldron, KS 67150',22059,222,NULL,20,30056,0);
INSERT INTO "django_geo_db_location" VALUES(52409,NULL,'Walton, KS',22060,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52410,NULL,'Walton, KS 67151',22060,222,NULL,20,30057,0);
INSERT INTO "django_geo_db_location" VALUES(52411,NULL,'Wellington, KS',22061,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52412,NULL,'Wellington, KS 67152',22061,222,NULL,20,30058,0);
INSERT INTO "django_geo_db_location" VALUES(52413,NULL,'Whitewater, KS',22062,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52414,NULL,'Whitewater, KS 67154',22062,222,NULL,20,30059,0);
INSERT INTO "django_geo_db_location" VALUES(52415,NULL,'Wilmore, KS',22063,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52416,NULL,'Wilmore, KS 67155',22063,222,NULL,20,30060,0);
INSERT INTO "django_geo_db_location" VALUES(52417,NULL,'Winfield, KS',22064,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52418,NULL,'Winfield, KS 67156',22064,222,NULL,20,30061,0);
INSERT INTO "django_geo_db_location" VALUES(52419,NULL,'Zenda, KS',22065,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52420,NULL,'Zenda, KS 67159',22065,222,NULL,20,30062,0);
INSERT INTO "django_geo_db_location" VALUES(52421,NULL,'Wichita, KS',22066,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52422,NULL,'Wichita, KS 67201',22066,222,NULL,20,30063,0);
INSERT INTO "django_geo_db_location" VALUES(52423,NULL,'Wichita, KS 67202',22066,222,NULL,20,30064,0);
INSERT INTO "django_geo_db_location" VALUES(52424,NULL,'Wichita, KS 67203',22066,222,NULL,20,30065,0);
INSERT INTO "django_geo_db_location" VALUES(52425,NULL,'Wichita, KS 67204',22066,222,NULL,20,30066,0);
INSERT INTO "django_geo_db_location" VALUES(52426,NULL,'Wichita, KS 67205',22066,222,NULL,20,30067,0);
INSERT INTO "django_geo_db_location" VALUES(52427,NULL,'Wichita, KS 67206',22066,222,NULL,20,30068,0);
INSERT INTO "django_geo_db_location" VALUES(52428,NULL,'Wichita, KS 67207',22066,222,NULL,20,30069,0);
INSERT INTO "django_geo_db_location" VALUES(52429,NULL,'Wichita, KS 67208',22066,222,NULL,20,30070,0);
INSERT INTO "django_geo_db_location" VALUES(52430,NULL,'Wichita, KS 67209',22066,222,NULL,20,30071,0);
INSERT INTO "django_geo_db_location" VALUES(52431,NULL,'Wichita, KS 67210',22066,222,NULL,20,30072,0);
INSERT INTO "django_geo_db_location" VALUES(52432,NULL,'Wichita, KS 67211',22066,222,NULL,20,30073,0);
INSERT INTO "django_geo_db_location" VALUES(52433,NULL,'Wichita, KS 67212',22066,222,NULL,20,30074,0);
INSERT INTO "django_geo_db_location" VALUES(52434,NULL,'Wichita, KS 67213',22066,222,NULL,20,30075,0);
INSERT INTO "django_geo_db_location" VALUES(52435,NULL,'Wichita, KS 67214',22066,222,NULL,20,30076,0);
INSERT INTO "django_geo_db_location" VALUES(52436,NULL,'Wichita, KS 67215',22066,222,NULL,20,30077,0);
INSERT INTO "django_geo_db_location" VALUES(52437,NULL,'Wichita, KS 67216',22066,222,NULL,20,30078,0);
INSERT INTO "django_geo_db_location" VALUES(52438,NULL,'Wichita, KS 67217',22066,222,NULL,20,30079,0);
INSERT INTO "django_geo_db_location" VALUES(52439,NULL,'Wichita, KS 67218',22066,222,NULL,20,30080,0);
INSERT INTO "django_geo_db_location" VALUES(52440,NULL,'Wichita, KS 67219',22066,222,NULL,20,30081,0);
INSERT INTO "django_geo_db_location" VALUES(52441,NULL,'Wichita, KS 67220',22066,222,NULL,20,30082,0);
INSERT INTO "django_geo_db_location" VALUES(52442,NULL,'McConnell A F B, KS',22067,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52443,NULL,'McConnell A F B, KS 67221',22067,222,NULL,20,30083,0);
INSERT INTO "django_geo_db_location" VALUES(52444,NULL,'Wichita, KS 67222',22066,222,NULL,20,30084,0);
INSERT INTO "django_geo_db_location" VALUES(52445,NULL,'Wichita, KS 67223',22066,222,NULL,20,30085,0);
INSERT INTO "django_geo_db_location" VALUES(52446,NULL,'Wichita, KS 67226',22066,222,NULL,20,30086,0);
INSERT INTO "django_geo_db_location" VALUES(52447,NULL,'Wichita, KS 67227',22066,222,NULL,20,30087,0);
INSERT INTO "django_geo_db_location" VALUES(52448,NULL,'Wichita, KS 67228',22066,222,NULL,20,30088,0);
INSERT INTO "django_geo_db_location" VALUES(52449,NULL,'Wichita, KS 67230',22066,222,NULL,20,30089,0);
INSERT INTO "django_geo_db_location" VALUES(52450,NULL,'Wichita, KS 67231',22066,222,NULL,20,30090,0);
INSERT INTO "django_geo_db_location" VALUES(52451,NULL,'Wichita, KS 67232',22066,222,NULL,20,30091,0);
INSERT INTO "django_geo_db_location" VALUES(52452,NULL,'Wichita, KS 67233',22066,222,NULL,20,30092,0);
INSERT INTO "django_geo_db_location" VALUES(52453,NULL,'Wichita, KS 67235',22066,222,NULL,20,30093,0);
INSERT INTO "django_geo_db_location" VALUES(52454,NULL,'Wichita, KS 67236',22066,222,NULL,20,30094,0);
INSERT INTO "django_geo_db_location" VALUES(52455,NULL,'Wichita, KS 67251',22066,222,NULL,20,30095,0);
INSERT INTO "django_geo_db_location" VALUES(52456,NULL,'Wichita, KS 67256',22066,222,NULL,20,30096,0);
INSERT INTO "django_geo_db_location" VALUES(52457,NULL,'Wichita, KS 67257',22066,222,NULL,20,30097,0);
INSERT INTO "django_geo_db_location" VALUES(52458,NULL,'Wichita, KS 67259',22066,222,NULL,20,30098,0);
INSERT INTO "django_geo_db_location" VALUES(52459,NULL,'Wichita, KS 67260',22066,222,NULL,20,30099,0);
INSERT INTO "django_geo_db_location" VALUES(52460,NULL,'Wichita, KS 67275',22066,222,NULL,20,30100,0);
INSERT INTO "django_geo_db_location" VALUES(52461,NULL,'Wichita, KS 67276',22066,222,NULL,20,30101,0);
INSERT INTO "django_geo_db_location" VALUES(52462,NULL,'Wichita, KS 67277',22066,222,NULL,20,30102,0);
INSERT INTO "django_geo_db_location" VALUES(52463,NULL,'Wichita, KS 67278',22066,222,NULL,20,30103,0);
INSERT INTO "django_geo_db_location" VALUES(52464,NULL,'Independence, KS',22068,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52465,NULL,'Independence, KS 67301',22068,222,NULL,20,30104,0);
INSERT INTO "django_geo_db_location" VALUES(52466,NULL,'Altamont, KS',22069,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52467,NULL,'Altamont, KS 67330',22069,222,NULL,20,30105,0);
INSERT INTO "django_geo_db_location" VALUES(52468,NULL,'Bartlett, KS',22070,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52469,NULL,'Bartlett, KS 67332',22070,222,NULL,20,30106,0);
INSERT INTO "django_geo_db_location" VALUES(52470,NULL,'Caney, KS',22071,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52471,NULL,'Caney, KS 67333',22071,222,NULL,20,30107,0);
INSERT INTO "django_geo_db_location" VALUES(52472,NULL,'Chautauqua, KS',22072,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52473,NULL,'Chautauqua, KS 67334',22072,222,NULL,20,30108,0);
INSERT INTO "django_geo_db_location" VALUES(52474,NULL,'Cherryvale, KS',22073,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52475,NULL,'Cherryvale, KS 67335',22073,222,NULL,20,30109,0);
INSERT INTO "django_geo_db_location" VALUES(52476,NULL,'Chetopa, KS',22074,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52477,NULL,'Chetopa, KS 67336',22074,222,NULL,20,30110,0);
INSERT INTO "django_geo_db_location" VALUES(52478,NULL,'Coffeyville, KS',22075,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52479,NULL,'Coffeyville, KS 67337',22075,222,NULL,20,30111,0);
INSERT INTO "django_geo_db_location" VALUES(52480,NULL,'Howard, KS',22076,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52481,NULL,'Howard, KS 67339',22076,222,NULL,20,30112,0);
INSERT INTO "django_geo_db_location" VALUES(52482,NULL,'Dearing, KS',22077,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52483,NULL,'Dearing, KS 67340',22077,222,NULL,20,30113,0);
INSERT INTO "django_geo_db_location" VALUES(52484,NULL,'Dennis, KS',22078,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52485,NULL,'Dennis, KS 67341',22078,222,NULL,20,30114,0);
INSERT INTO "django_geo_db_location" VALUES(52486,NULL,'Edna, KS',22079,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52487,NULL,'Edna, KS 67342',22079,222,NULL,20,30115,0);
INSERT INTO "django_geo_db_location" VALUES(52488,NULL,'Elk City, KS',22080,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52489,NULL,'Elk City, KS 67344',22080,222,NULL,20,30116,0);
INSERT INTO "django_geo_db_location" VALUES(52490,NULL,'Elk Falls, KS',22081,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52491,NULL,'Elk Falls, KS 67345',22081,222,NULL,20,30117,0);
INSERT INTO "django_geo_db_location" VALUES(52492,NULL,'Grenola, KS',22082,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52493,NULL,'Grenola, KS 67346',22082,222,NULL,20,30118,0);
INSERT INTO "django_geo_db_location" VALUES(52494,NULL,'Havana, KS',22083,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52495,NULL,'Havana, KS 67347',22083,222,NULL,20,30119,0);
INSERT INTO "django_geo_db_location" VALUES(52496,NULL,'Howard, KS 67349',22076,222,NULL,20,30120,0);
INSERT INTO "django_geo_db_location" VALUES(52497,NULL,'Liberty, KS',22084,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52498,NULL,'Liberty, KS 67351',22084,222,NULL,20,30121,0);
INSERT INTO "django_geo_db_location" VALUES(52499,NULL,'Longton, KS',22085,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52500,NULL,'Longton, KS 67352',22085,222,NULL,20,30122,0);
INSERT INTO "django_geo_db_location" VALUES(52501,NULL,'Moline, KS',22086,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52502,NULL,'Moline, KS 67353',22086,222,NULL,20,30123,0);
INSERT INTO "django_geo_db_location" VALUES(52503,NULL,'Mound Valley, KS',22087,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52504,NULL,'Mound Valley, KS 67354',22087,222,NULL,20,30124,0);
INSERT INTO "django_geo_db_location" VALUES(52505,NULL,'Niotaze, KS',22088,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52506,NULL,'Niotaze, KS 67355',22088,222,NULL,20,30125,0);
INSERT INTO "django_geo_db_location" VALUES(52507,NULL,'Oswego, KS',22089,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52508,NULL,'Oswego, KS 67356',22089,222,NULL,20,30126,0);
INSERT INTO "django_geo_db_location" VALUES(52509,NULL,'Parsons, KS',22090,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52510,NULL,'Parsons, KS 67357',22090,222,NULL,20,30127,0);
INSERT INTO "django_geo_db_location" VALUES(52511,NULL,'Peru, KS',22091,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52512,NULL,'Peru, KS 67360',22091,222,NULL,20,30128,0);
INSERT INTO "django_geo_db_location" VALUES(52513,NULL,'Sedan, KS',22092,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52514,NULL,'Sedan, KS 67361',22092,222,NULL,20,30129,0);
INSERT INTO "django_geo_db_location" VALUES(52515,NULL,'Sycamore, KS',22093,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52516,NULL,'Sycamore, KS 67363',22093,222,NULL,20,30130,0);
INSERT INTO "django_geo_db_location" VALUES(52517,NULL,'Tyro, KS',22094,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52518,NULL,'Tyro, KS 67364',22094,222,NULL,20,30131,0);
INSERT INTO "django_geo_db_location" VALUES(52519,NULL,'Salina, KS',22095,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52520,NULL,'Salina, KS 67401',22095,222,NULL,20,30132,0);
INSERT INTO "django_geo_db_location" VALUES(52521,NULL,'Salina, KS 67402',22095,222,NULL,20,30133,0);
INSERT INTO "django_geo_db_location" VALUES(52522,NULL,'Abilene, KS',22096,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52523,NULL,'Abilene, KS 67410',22096,222,NULL,20,30134,0);
INSERT INTO "django_geo_db_location" VALUES(52524,NULL,'Fairview, KS 67411',21780,222,NULL,20,30135,0);
INSERT INTO "django_geo_db_location" VALUES(52525,NULL,'Assaria, KS',22097,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52526,NULL,'Assaria, KS 67416',22097,222,NULL,20,30136,0);
INSERT INTO "django_geo_db_location" VALUES(52527,NULL,'Aurora, KS',22098,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52528,NULL,'Aurora, KS 67417',22098,222,NULL,20,30137,0);
INSERT INTO "django_geo_db_location" VALUES(52529,NULL,'Barnard, KS',22099,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52530,NULL,'Barnard, KS 67418',22099,222,NULL,20,30138,0);
INSERT INTO "django_geo_db_location" VALUES(52531,NULL,'Union, KS',22100,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52532,NULL,'Union, KS 67419',22100,222,NULL,20,30139,0);
INSERT INTO "django_geo_db_location" VALUES(52533,NULL,'Beloit, KS',22101,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52534,NULL,'Beloit, KS 67420',22101,222,NULL,20,30140,0);
INSERT INTO "django_geo_db_location" VALUES(52535,NULL,'Bennington, KS',22102,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52536,NULL,'Bennington, KS 67422',22102,222,NULL,20,30141,0);
INSERT INTO "django_geo_db_location" VALUES(52537,NULL,'Beverly, KS',22103,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52538,NULL,'Beverly, KS 67423',22103,222,NULL,20,30142,0);
INSERT INTO "django_geo_db_location" VALUES(52539,NULL,'Brookville, KS',22104,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52540,NULL,'Brookville, KS 67425',22104,222,NULL,20,30143,0);
INSERT INTO "django_geo_db_location" VALUES(52541,NULL,'Bushton, KS',22105,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52542,NULL,'Bushton, KS 67427',22105,222,NULL,20,30144,0);
INSERT INTO "django_geo_db_location" VALUES(52543,NULL,'Canton, KS',22106,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52544,NULL,'Canton, KS 67428',22106,222,NULL,20,30145,0);
INSERT INTO "django_geo_db_location" VALUES(52545,NULL,'Cawker City, KS',22107,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52546,NULL,'Cawker City, KS 67430',22107,222,NULL,20,30146,0);
INSERT INTO "django_geo_db_location" VALUES(52547,NULL,'Chapman, KS',22108,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52548,NULL,'Chapman, KS 67431',22108,222,NULL,20,30147,0);
INSERT INTO "django_geo_db_location" VALUES(52549,NULL,'Clay Center, KS',22109,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52550,NULL,'Clay Center, KS 67432',22109,222,NULL,20,30148,0);
INSERT INTO "django_geo_db_location" VALUES(52551,NULL,'Sedan, KS 67435',22092,222,NULL,20,30149,0);
INSERT INTO "django_geo_db_location" VALUES(52552,NULL,'Delphos, KS',22110,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52553,NULL,'Delphos, KS 67436',22110,222,NULL,20,30150,0);
INSERT INTO "django_geo_db_location" VALUES(52554,NULL,'Downs, KS',22111,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52555,NULL,'Downs, KS 67437',22111,222,NULL,20,30151,0);
INSERT INTO "django_geo_db_location" VALUES(52556,NULL,'Durham, KS',22112,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52557,NULL,'Durham, KS 67438',22112,222,NULL,20,30152,0);
INSERT INTO "django_geo_db_location" VALUES(52558,NULL,'Ellsworth, KS',22113,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52559,NULL,'Ellsworth, KS 67439',22113,222,NULL,20,30153,0);
INSERT INTO "django_geo_db_location" VALUES(52560,NULL,'Enterprise, KS',22114,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52561,NULL,'Enterprise, KS 67441',22114,222,NULL,20,30154,0);
INSERT INTO "django_geo_db_location" VALUES(52562,NULL,'Falun, KS',22115,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52563,NULL,'Falun, KS 67442',22115,222,NULL,20,30155,0);
INSERT INTO "django_geo_db_location" VALUES(52564,NULL,'Galva, KS',22116,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52565,NULL,'Galva, KS 67443',22116,222,NULL,20,30156,0);
INSERT INTO "django_geo_db_location" VALUES(52566,NULL,'Geneseo, KS',22117,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52567,NULL,'Geneseo, KS 67444',22117,222,NULL,20,30157,0);
INSERT INTO "django_geo_db_location" VALUES(52568,NULL,'Glasco, KS',22118,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52569,NULL,'Glasco, KS 67445',22118,222,NULL,20,30158,0);
INSERT INTO "django_geo_db_location" VALUES(52570,NULL,'Glen Elder, KS',22119,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52571,NULL,'Glen Elder, KS 67446',22119,222,NULL,20,30159,0);
INSERT INTO "django_geo_db_location" VALUES(52572,NULL,'Green, KS',22120,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52573,NULL,'Green, KS 67447',22120,222,NULL,20,30160,0);
INSERT INTO "django_geo_db_location" VALUES(52574,NULL,'Gypsum, KS',22121,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52575,NULL,'Gypsum, KS 67448',22121,222,NULL,20,30161,0);
INSERT INTO "django_geo_db_location" VALUES(52576,NULL,'Herington, KS',22122,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52577,NULL,'Herington, KS 67449',22122,222,NULL,20,30162,0);
INSERT INTO "django_geo_db_location" VALUES(52578,NULL,'Holyrood, KS',22123,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52579,NULL,'Holyrood, KS 67450',22123,222,NULL,20,30163,0);
INSERT INTO "django_geo_db_location" VALUES(52580,NULL,'Hope, KS',22124,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52581,NULL,'Hope, KS 67451',22124,222,NULL,20,30164,0);
INSERT INTO "django_geo_db_location" VALUES(52582,NULL,'Hunter, KS',22125,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52583,NULL,'Hunter, KS 67452',22125,222,NULL,20,30165,0);
INSERT INTO "django_geo_db_location" VALUES(52584,NULL,'Kanopolis, KS',22126,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52585,NULL,'Kanopolis, KS 67454',22126,222,NULL,20,30166,0);
INSERT INTO "django_geo_db_location" VALUES(52586,NULL,'Lincoln, KS 67455',21759,222,NULL,20,30167,0);
INSERT INTO "django_geo_db_location" VALUES(52587,NULL,'Lindsborg, KS',22127,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52588,NULL,'Lindsborg, KS 67456',22127,222,NULL,20,30168,0);
INSERT INTO "django_geo_db_location" VALUES(52589,NULL,'Little River, KS',22128,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52590,NULL,'Little River, KS 67457',22128,222,NULL,20,30169,0);
INSERT INTO "django_geo_db_location" VALUES(52591,NULL,'Longford, KS',22129,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52592,NULL,'Longford, KS 67458',22129,222,NULL,20,30170,0);
INSERT INTO "django_geo_db_location" VALUES(52593,NULL,'Lorraine, KS',22130,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52594,NULL,'Lorraine, KS 67459',22130,222,NULL,20,30171,0);
INSERT INTO "django_geo_db_location" VALUES(52595,NULL,'Mcpherson, KS',22131,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52596,NULL,'Mcpherson, KS 67460',22131,222,NULL,20,30172,0);
INSERT INTO "django_geo_db_location" VALUES(52597,NULL,'Marquette, KS',22132,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52598,NULL,'Marquette, KS 67464',22132,222,NULL,20,30173,0);
INSERT INTO "django_geo_db_location" VALUES(52599,NULL,'Miltonvale, KS',22133,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52600,NULL,'Miltonvale, KS 67466',22133,222,NULL,20,30174,0);
INSERT INTO "django_geo_db_location" VALUES(52601,NULL,'Minneapolis, KS',22134,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52602,NULL,'Minneapolis, KS 67467',22134,222,NULL,20,30175,0);
INSERT INTO "django_geo_db_location" VALUES(52603,NULL,'Morganville, KS',22135,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52604,NULL,'Morganville, KS 67468',22135,222,NULL,20,30176,0);
INSERT INTO "django_geo_db_location" VALUES(52605,NULL,'New Cambria, KS',22136,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52606,NULL,'New Cambria, KS 67470',22136,222,NULL,20,30177,0);
INSERT INTO "django_geo_db_location" VALUES(52607,NULL,'Chapman, KS 67472',22108,222,NULL,20,30178,0);
INSERT INTO "django_geo_db_location" VALUES(52608,NULL,'Osborne, KS',22137,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52609,NULL,'Osborne, KS 67473',22137,222,NULL,20,30179,0);
INSERT INTO "django_geo_db_location" VALUES(52610,NULL,'Portis, KS',22138,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52611,NULL,'Portis, KS 67474',22138,222,NULL,20,30180,0);
INSERT INTO "django_geo_db_location" VALUES(52612,NULL,'Ramona, KS',22139,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52613,NULL,'Ramona, KS 67475',22139,222,NULL,20,30181,0);
INSERT INTO "django_geo_db_location" VALUES(52614,NULL,'Roxbury, KS',22140,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52615,NULL,'Roxbury, KS 67476',22140,222,NULL,20,30182,0);
INSERT INTO "django_geo_db_location" VALUES(52616,NULL,'Simpson, KS',22141,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52617,NULL,'Simpson, KS 67478',22141,222,NULL,20,30183,0);
INSERT INTO "django_geo_db_location" VALUES(52618,NULL,'Smolan, KS',22142,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52619,NULL,'Smolan, KS 67479',22142,222,NULL,20,30184,0);
INSERT INTO "django_geo_db_location" VALUES(52620,NULL,'Solomon, KS',22143,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52621,NULL,'Solomon, KS 67480',22143,222,NULL,20,30185,0);
INSERT INTO "django_geo_db_location" VALUES(52622,NULL,'Sylvan Grove, KS',22144,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52623,NULL,'Sylvan Grove, KS 67481',22144,222,NULL,20,30186,0);
INSERT INTO "django_geo_db_location" VALUES(52624,NULL,'Talmage, KS',22145,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52625,NULL,'Talmage, KS 67482',22145,222,NULL,20,30187,0);
INSERT INTO "django_geo_db_location" VALUES(52626,NULL,'Tampa, KS',22146,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52627,NULL,'Tampa, KS 67483',22146,222,NULL,20,30188,0);
INSERT INTO "django_geo_db_location" VALUES(52628,NULL,'Tescott, KS',22147,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52629,NULL,'Tescott, KS 67484',22147,222,NULL,20,30189,0);
INSERT INTO "django_geo_db_location" VALUES(52630,NULL,'Tipton, KS',22148,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52631,NULL,'Tipton, KS 67485',22148,222,NULL,20,30190,0);
INSERT INTO "django_geo_db_location" VALUES(52632,NULL,'Wakefield, KS',22149,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52633,NULL,'Wakefield, KS 67487',22149,222,NULL,20,30191,0);
INSERT INTO "django_geo_db_location" VALUES(52634,NULL,'Durham, KS 67488',22112,222,NULL,20,30192,0);
INSERT INTO "django_geo_db_location" VALUES(52635,NULL,'Wilson, KS',22150,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52636,NULL,'Wilson, KS 67490',22150,222,NULL,20,30193,0);
INSERT INTO "django_geo_db_location" VALUES(52637,NULL,'Windom, KS',22151,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52638,NULL,'Windom, KS 67491',22151,222,NULL,20,30194,0);
INSERT INTO "django_geo_db_location" VALUES(52639,NULL,'Woodbine, KS',22152,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52640,NULL,'Woodbine, KS 67492',22152,222,NULL,20,30195,0);
INSERT INTO "django_geo_db_location" VALUES(52641,NULL,'Tipton, KS 67495',22148,222,NULL,20,30196,0);
INSERT INTO "django_geo_db_location" VALUES(52642,NULL,'Hutchinson, KS',22153,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52643,NULL,'Hutchinson, KS 67501',22153,222,NULL,20,30197,0);
INSERT INTO "django_geo_db_location" VALUES(52644,NULL,'Hutchinson, KS 67502',22153,222,NULL,20,30198,0);
INSERT INTO "django_geo_db_location" VALUES(52645,NULL,'Hutchinson, KS 67504',22153,222,NULL,20,30199,0);
INSERT INTO "django_geo_db_location" VALUES(52646,NULL,'South Hutchinson, KS',22154,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52647,NULL,'South Hutchinson, KS 67505',22154,222,NULL,20,30200,0);
INSERT INTO "django_geo_db_location" VALUES(52648,NULL,'Abbyville, KS',22155,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52649,NULL,'Abbyville, KS 67510',22155,222,NULL,20,30201,0);
INSERT INTO "django_geo_db_location" VALUES(52650,NULL,'Albert, KS',22156,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52651,NULL,'Albert, KS 67511',22156,222,NULL,20,30202,0);
INSERT INTO "django_geo_db_location" VALUES(52652,NULL,'Alden, KS',22157,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52653,NULL,'Alden, KS 67512',22157,222,NULL,20,30203,0);
INSERT INTO "django_geo_db_location" VALUES(52654,NULL,'Alexander, KS',22158,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52655,NULL,'Alexander, KS 67513',22158,222,NULL,20,30204,0);
INSERT INTO "django_geo_db_location" VALUES(52656,NULL,'Arlington, KS',22159,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52657,NULL,'Arlington, KS 67514',22159,222,NULL,20,30205,0);
INSERT INTO "django_geo_db_location" VALUES(52658,NULL,'Arnold, KS',22160,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52659,NULL,'Arnold, KS 67515',22160,222,NULL,20,30206,0);
INSERT INTO "django_geo_db_location" VALUES(52660,NULL,'Bazine, KS',22161,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52661,NULL,'Bazine, KS 67516',22161,222,NULL,20,30207,0);
INSERT INTO "django_geo_db_location" VALUES(52662,NULL,'Beeler, KS',22162,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52663,NULL,'Beeler, KS 67518',22162,222,NULL,20,30208,0);
INSERT INTO "django_geo_db_location" VALUES(52664,NULL,'Belpre, KS',22163,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52665,NULL,'Belpre, KS 67519',22163,222,NULL,20,30209,0);
INSERT INTO "django_geo_db_location" VALUES(52666,NULL,'Bison, KS',22164,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52667,NULL,'Bison, KS 67520',22164,222,NULL,20,30210,0);
INSERT INTO "django_geo_db_location" VALUES(52668,NULL,'Brownell, KS',22165,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52669,NULL,'Brownell, KS 67521',22165,222,NULL,20,30211,0);
INSERT INTO "django_geo_db_location" VALUES(52670,NULL,'Buhler, KS',22166,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52671,NULL,'Buhler, KS 67522',22166,222,NULL,20,30212,0);
INSERT INTO "django_geo_db_location" VALUES(52672,NULL,'Burdett, KS',22167,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52673,NULL,'Burdett, KS 67523',22167,222,NULL,20,30213,0);
INSERT INTO "django_geo_db_location" VALUES(52674,NULL,'Chase, KS',22168,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52675,NULL,'Chase, KS 67524',22168,222,NULL,20,30214,0);
INSERT INTO "django_geo_db_location" VALUES(52676,NULL,'Claflin, KS',22169,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52677,NULL,'Claflin, KS 67525',22169,222,NULL,20,30215,0);
INSERT INTO "django_geo_db_location" VALUES(52678,NULL,'Ellinwood, KS',22170,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52679,NULL,'Ellinwood, KS 67526',22170,222,NULL,20,30216,0);
INSERT INTO "django_geo_db_location" VALUES(52680,NULL,'Garfield, KS',22171,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52681,NULL,'Garfield, KS 67529',22171,222,NULL,20,30217,0);
INSERT INTO "django_geo_db_location" VALUES(52682,NULL,'Great Bend, KS',22172,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52683,NULL,'Great Bend, KS 67530',22172,222,NULL,20,30218,0);
INSERT INTO "django_geo_db_location" VALUES(52684,NULL,'Haven, KS',22173,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52685,NULL,'Haven, KS 67543',22173,222,NULL,20,30219,0);
INSERT INTO "django_geo_db_location" VALUES(52686,NULL,'Hoisington, KS',22174,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52687,NULL,'Hoisington, KS 67544',22174,222,NULL,20,30220,0);
INSERT INTO "django_geo_db_location" VALUES(52688,NULL,'Hudson, KS',22175,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52689,NULL,'Hudson, KS 67545',22175,222,NULL,20,30221,0);
INSERT INTO "django_geo_db_location" VALUES(52690,NULL,'Inman, KS',22176,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52691,NULL,'Inman, KS 67546',22176,222,NULL,20,30222,0);
INSERT INTO "django_geo_db_location" VALUES(52692,NULL,'Kinsley, KS',22177,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52693,NULL,'Kinsley, KS 67547',22177,222,NULL,20,30223,0);
INSERT INTO "django_geo_db_location" VALUES(52694,NULL,'La Crosse, KS',22178,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52695,NULL,'La Crosse, KS 67548',22178,222,NULL,20,30224,0);
INSERT INTO "django_geo_db_location" VALUES(52696,NULL,'Larned, KS',22179,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52697,NULL,'Larned, KS 67550',22179,222,NULL,20,30225,0);
INSERT INTO "django_geo_db_location" VALUES(52698,NULL,'Lewis, KS',22180,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52699,NULL,'Lewis, KS 67552',22180,222,NULL,20,30226,0);
INSERT INTO "django_geo_db_location" VALUES(52700,NULL,'Liebenthal, KS',22181,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52701,NULL,'Liebenthal, KS 67553',22181,222,NULL,20,30227,0);
INSERT INTO "django_geo_db_location" VALUES(52702,NULL,'Lyons, KS',22182,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52703,NULL,'Lyons, KS 67554',22182,222,NULL,20,30228,0);
INSERT INTO "django_geo_db_location" VALUES(52704,NULL,'McCracken, KS',22183,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52705,NULL,'McCracken, KS 67556',22183,222,NULL,20,30229,0);
INSERT INTO "django_geo_db_location" VALUES(52706,NULL,'Macksville, KS',22184,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52707,NULL,'Macksville, KS 67557',22184,222,NULL,20,30230,0);
INSERT INTO "django_geo_db_location" VALUES(52708,NULL,'Nekoma, KS',22185,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52709,NULL,'Nekoma, KS 67559',22185,222,NULL,20,30231,0);
INSERT INTO "django_geo_db_location" VALUES(52710,NULL,'Ness City, KS',22186,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52711,NULL,'Ness City, KS 67560',22186,222,NULL,20,30232,0);
INSERT INTO "django_geo_db_location" VALUES(52712,NULL,'Nickerson, KS',22187,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52713,NULL,'Nickerson, KS 67561',22187,222,NULL,20,30233,0);
INSERT INTO "django_geo_db_location" VALUES(52714,NULL,'Offerle, KS',22188,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52715,NULL,'Offerle, KS 67563',22188,222,NULL,20,30234,0);
INSERT INTO "django_geo_db_location" VALUES(52716,NULL,'Olmitz, KS',22189,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52717,NULL,'Olmitz, KS 67564',22189,222,NULL,20,30235,0);
INSERT INTO "django_geo_db_location" VALUES(52718,NULL,'Otis, KS',22190,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52719,NULL,'Otis, KS 67565',22190,222,NULL,20,30236,0);
INSERT INTO "django_geo_db_location" VALUES(52720,NULL,'Partridge, KS',22191,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52721,NULL,'Partridge, KS 67566',22191,222,NULL,20,30237,0);
INSERT INTO "django_geo_db_location" VALUES(52722,NULL,'Pawnee Rock, KS',22192,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52723,NULL,'Pawnee Rock, KS 67567',22192,222,NULL,20,30238,0);
INSERT INTO "django_geo_db_location" VALUES(52724,NULL,'Plevna, KS',22193,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52725,NULL,'Plevna, KS 67568',22193,222,NULL,20,30239,0);
INSERT INTO "django_geo_db_location" VALUES(52726,NULL,'Pretty Prairie, KS',22194,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52727,NULL,'Pretty Prairie, KS 67570',22194,222,NULL,20,30240,0);
INSERT INTO "django_geo_db_location" VALUES(52728,NULL,'Ransom, KS',22195,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52729,NULL,'Ransom, KS 67572',22195,222,NULL,20,30241,0);
INSERT INTO "django_geo_db_location" VALUES(52730,NULL,'Raymond, KS',22196,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52731,NULL,'Raymond, KS 67573',22196,222,NULL,20,30242,0);
INSERT INTO "django_geo_db_location" VALUES(52732,NULL,'Rozel, KS',22197,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52733,NULL,'Rozel, KS 67574',22197,222,NULL,20,30243,0);
INSERT INTO "django_geo_db_location" VALUES(52734,NULL,'Rush Center, KS',22198,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52735,NULL,'Rush Center, KS 67575',22198,222,NULL,20,30244,0);
INSERT INTO "django_geo_db_location" VALUES(52736,NULL,'Saint John, KS',22199,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52737,NULL,'Saint John, KS 67576',22199,222,NULL,20,30245,0);
INSERT INTO "django_geo_db_location" VALUES(52738,NULL,'Stafford, KS',22200,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52739,NULL,'Stafford, KS 67578',22200,222,NULL,20,30246,0);
INSERT INTO "django_geo_db_location" VALUES(52740,NULL,'Sterling, KS',22201,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52741,NULL,'Sterling, KS 67579',22201,222,NULL,20,30247,0);
INSERT INTO "django_geo_db_location" VALUES(52742,NULL,'Sylvia, KS',22202,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52743,NULL,'Sylvia, KS 67581',22202,222,NULL,20,30248,0);
INSERT INTO "django_geo_db_location" VALUES(52744,NULL,'Turon, KS',22203,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52745,NULL,'Turon, KS 67583',22203,222,NULL,20,30249,0);
INSERT INTO "django_geo_db_location" VALUES(52746,NULL,'Utica, KS',22204,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52747,NULL,'Utica, KS 67584',22204,222,NULL,20,30250,0);
INSERT INTO "django_geo_db_location" VALUES(52748,NULL,'Yoder, KS',22205,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52749,NULL,'Yoder, KS 67585',22205,222,NULL,20,30251,0);
INSERT INTO "django_geo_db_location" VALUES(52750,NULL,'Hays, KS',22206,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52751,NULL,'Hays, KS 67601',22206,222,NULL,20,30252,0);
INSERT INTO "django_geo_db_location" VALUES(52752,NULL,'Agra, KS',22207,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52753,NULL,'Agra, KS 67621',22207,222,NULL,20,30253,0);
INSERT INTO "django_geo_db_location" VALUES(52754,NULL,'Almena, KS',22208,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52755,NULL,'Almena, KS 67622',22208,222,NULL,20,30254,0);
INSERT INTO "django_geo_db_location" VALUES(52756,NULL,'Alton, KS',22209,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52757,NULL,'Alton, KS 67623',22209,222,NULL,20,30255,0);
INSERT INTO "django_geo_db_location" VALUES(52758,NULL,'Bogue, KS',22210,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52759,NULL,'Bogue, KS 67625',22210,222,NULL,20,30256,0);
INSERT INTO "django_geo_db_location" VALUES(52760,NULL,'Bunker Hill, KS',22211,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52761,NULL,'Bunker Hill, KS 67626',22211,222,NULL,20,30257,0);
INSERT INTO "django_geo_db_location" VALUES(52762,NULL,'Catharine, KS',22212,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52763,NULL,'Catharine, KS 67627',22212,222,NULL,20,30258,0);
INSERT INTO "django_geo_db_location" VALUES(52764,NULL,'Cedar, KS',22213,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52765,NULL,'Cedar, KS 67628',22213,222,NULL,20,30259,0);
INSERT INTO "django_geo_db_location" VALUES(52766,NULL,'Clayton, KS',22214,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52767,NULL,'Clayton, KS 67629',22214,222,NULL,20,30260,0);
INSERT INTO "django_geo_db_location" VALUES(52768,NULL,'Belleville, KS 67630',21933,222,NULL,20,30261,0);
INSERT INTO "django_geo_db_location" VALUES(52769,NULL,'Collyer, KS',22215,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52770,NULL,'Collyer, KS 67631',22215,222,NULL,20,30262,0);
INSERT INTO "django_geo_db_location" VALUES(52771,NULL,'Damar, KS',22216,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52772,NULL,'Damar, KS 67632',22216,222,NULL,20,30263,0);
INSERT INTO "django_geo_db_location" VALUES(52773,NULL,'Dorrance, KS',22217,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52774,NULL,'Dorrance, KS 67634',22217,222,NULL,20,30264,0);
INSERT INTO "django_geo_db_location" VALUES(52775,NULL,'Dresden, KS',22218,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52776,NULL,'Dresden, KS 67635',22218,222,NULL,20,30265,0);
INSERT INTO "django_geo_db_location" VALUES(52777,NULL,'Ellis, KS',22219,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52778,NULL,'Ellis, KS 67637',22219,222,NULL,20,30266,0);
INSERT INTO "django_geo_db_location" VALUES(52779,NULL,'Gaylord, KS',22220,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52780,NULL,'Gaylord, KS 67638',22220,222,NULL,20,30267,0);
INSERT INTO "django_geo_db_location" VALUES(52781,NULL,'Glade, KS',22221,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52782,NULL,'Glade, KS 67639',22221,222,NULL,20,30268,0);
INSERT INTO "django_geo_db_location" VALUES(52783,NULL,'Gorham, KS',22222,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52784,NULL,'Gorham, KS 67640',22222,222,NULL,20,30269,0);
INSERT INTO "django_geo_db_location" VALUES(52785,NULL,'Hill City, KS',22223,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52786,NULL,'Hill City, KS 67642',22223,222,NULL,20,30270,0);
INSERT INTO "django_geo_db_location" VALUES(52787,NULL,'Jennings, KS',22224,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52788,NULL,'Jennings, KS 67643',22224,222,NULL,20,30271,0);
INSERT INTO "django_geo_db_location" VALUES(52789,NULL,'Kirwin, KS',22225,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52790,NULL,'Kirwin, KS 67644',22225,222,NULL,20,30272,0);
INSERT INTO "django_geo_db_location" VALUES(52791,NULL,'Lenora, KS',22226,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52792,NULL,'Lenora, KS 67645',22226,222,NULL,20,30273,0);
INSERT INTO "django_geo_db_location" VALUES(52793,NULL,'Logan, KS',22227,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52794,NULL,'Logan, KS 67646',22227,222,NULL,20,30274,0);
INSERT INTO "django_geo_db_location" VALUES(52795,NULL,'Long Island, KS',22228,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52796,NULL,'Long Island, KS 67647',22228,222,NULL,20,30275,0);
INSERT INTO "django_geo_db_location" VALUES(52797,NULL,'Lucas, KS',22229,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52798,NULL,'Lucas, KS 67648',22229,222,NULL,20,30276,0);
INSERT INTO "django_geo_db_location" VALUES(52799,NULL,'Luray, KS',22230,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52800,NULL,'Luray, KS 67649',22230,222,NULL,20,30277,0);
INSERT INTO "django_geo_db_location" VALUES(52801,NULL,'Morland, KS',22231,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52802,NULL,'Morland, KS 67650',22231,222,NULL,20,30278,0);
INSERT INTO "django_geo_db_location" VALUES(52803,NULL,'Natoma, KS',22232,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52804,NULL,'Natoma, KS 67651',22232,222,NULL,20,30279,0);
INSERT INTO "django_geo_db_location" VALUES(52805,NULL,'Norcatur, KS',22233,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52806,NULL,'Norcatur, KS 67653',22233,222,NULL,20,30280,0);
INSERT INTO "django_geo_db_location" VALUES(52807,NULL,'Norton, KS',22234,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52808,NULL,'Norton, KS 67654',22234,222,NULL,20,30281,0);
INSERT INTO "django_geo_db_location" VALUES(52809,NULL,'Ogallah, KS',22235,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52810,NULL,'Ogallah, KS 67656',22235,222,NULL,20,30282,0);
INSERT INTO "django_geo_db_location" VALUES(52811,NULL,'Palco, KS',22236,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52812,NULL,'Palco, KS 67657',22236,222,NULL,20,30283,0);
INSERT INTO "django_geo_db_location" VALUES(52813,NULL,'Paradise, KS',22237,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52814,NULL,'Paradise, KS 67658',22237,222,NULL,20,30284,0);
INSERT INTO "django_geo_db_location" VALUES(52815,NULL,'Penokee, KS',22238,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52816,NULL,'Penokee, KS 67659',22238,222,NULL,20,30285,0);
INSERT INTO "django_geo_db_location" VALUES(52817,NULL,'Pfeifer, KS',22239,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52818,NULL,'Pfeifer, KS 67660',22239,222,NULL,20,30286,0);
INSERT INTO "django_geo_db_location" VALUES(52819,NULL,'Phillipsburg, KS',22240,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52820,NULL,'Phillipsburg, KS 67661',22240,222,NULL,20,30287,0);
INSERT INTO "django_geo_db_location" VALUES(52821,NULL,'Plainville, KS',22241,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52822,NULL,'Plainville, KS 67663',22241,222,NULL,20,30288,0);
INSERT INTO "django_geo_db_location" VALUES(52823,NULL,'Prairie View, KS',22242,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52824,NULL,'Prairie View, KS 67664',22242,222,NULL,20,30289,0);
INSERT INTO "django_geo_db_location" VALUES(52825,NULL,'Russell, KS',22243,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52826,NULL,'Russell, KS 67665',22243,222,NULL,20,30290,0);
INSERT INTO "django_geo_db_location" VALUES(52827,NULL,'Towanda, KS 67666',22055,222,NULL,20,30291,0);
INSERT INTO "django_geo_db_location" VALUES(52828,NULL,'Schoenchen, KS',22244,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52829,NULL,'Schoenchen, KS 67667',22244,222,NULL,20,30292,0);
INSERT INTO "django_geo_db_location" VALUES(52830,NULL,'Stockton, KS',22245,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52831,NULL,'Stockton, KS 67669',22245,222,NULL,20,30293,0);
INSERT INTO "django_geo_db_location" VALUES(52832,NULL,'Stuttgart, KS',22246,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52833,NULL,'Stuttgart, KS 67670',22246,222,NULL,20,30294,0);
INSERT INTO "django_geo_db_location" VALUES(52834,NULL,'Victoria, KS',22247,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52835,NULL,'Victoria, KS 67671',22247,222,NULL,20,30295,0);
INSERT INTO "django_geo_db_location" VALUES(52836,NULL,'Wa Keeney, KS',22248,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52837,NULL,'Wa Keeney, KS 67672',22248,222,NULL,20,30296,0);
INSERT INTO "django_geo_db_location" VALUES(52838,NULL,'Waldo, KS',22249,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52839,NULL,'Waldo, KS 67673',22249,222,NULL,20,30297,0);
INSERT INTO "django_geo_db_location" VALUES(52840,NULL,'Walker, KS',22250,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52841,NULL,'Walker, KS 67674',22250,222,NULL,20,30298,0);
INSERT INTO "django_geo_db_location" VALUES(52842,NULL,'Woodston, KS',22251,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52843,NULL,'Woodston, KS 67675',22251,222,NULL,20,30299,0);
INSERT INTO "django_geo_db_location" VALUES(52844,NULL,'Colby, KS',22252,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52845,NULL,'Colby, KS 67701',22252,222,NULL,20,30300,0);
INSERT INTO "django_geo_db_location" VALUES(52846,NULL,'Atwood, KS',22253,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52847,NULL,'Atwood, KS 67730',22253,222,NULL,20,30301,0);
INSERT INTO "django_geo_db_location" VALUES(52848,NULL,'Bird City, KS',22254,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52849,NULL,'Bird City, KS 67731',22254,222,NULL,20,30302,0);
INSERT INTO "django_geo_db_location" VALUES(52850,NULL,'Brewster, KS',22255,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52851,NULL,'Brewster, KS 67732',22255,222,NULL,20,30303,0);
INSERT INTO "django_geo_db_location" VALUES(52852,NULL,'Edson, KS',22256,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52853,NULL,'Edson, KS 67733',22256,222,NULL,20,30304,0);
INSERT INTO "django_geo_db_location" VALUES(52854,NULL,'Gem, KS',22257,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52855,NULL,'Gem, KS 67734',22257,222,NULL,20,30305,0);
INSERT INTO "django_geo_db_location" VALUES(52856,NULL,'Goodland, KS',22258,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52857,NULL,'Goodland, KS 67735',22258,222,NULL,20,30306,0);
INSERT INTO "django_geo_db_location" VALUES(52858,NULL,'Gove, KS',22259,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52859,NULL,'Gove, KS 67736',22259,222,NULL,20,30307,0);
INSERT INTO "django_geo_db_location" VALUES(52860,NULL,'Grainfield, KS',22260,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52861,NULL,'Grainfield, KS 67737',22260,222,NULL,20,30308,0);
INSERT INTO "django_geo_db_location" VALUES(52862,NULL,'Grinnell, KS',22261,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52863,NULL,'Grinnell, KS 67738',22261,222,NULL,20,30309,0);
INSERT INTO "django_geo_db_location" VALUES(52864,NULL,'Herndon, KS',22262,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52865,NULL,'Herndon, KS 67739',22262,222,NULL,20,30310,0);
INSERT INTO "django_geo_db_location" VALUES(52866,NULL,'Hoxie, KS',22263,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52867,NULL,'Hoxie, KS 67740',22263,222,NULL,20,30311,0);
INSERT INTO "django_geo_db_location" VALUES(52868,NULL,'Kanorado, KS',22264,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52869,NULL,'Kanorado, KS 67741',22264,222,NULL,20,30312,0);
INSERT INTO "django_geo_db_location" VALUES(52870,NULL,'Levant, KS',22265,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52871,NULL,'Levant, KS 67743',22265,222,NULL,20,30313,0);
INSERT INTO "django_geo_db_location" VALUES(52872,NULL,'Ludell, KS',22266,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52873,NULL,'Ludell, KS 67744',22266,222,NULL,20,30314,0);
INSERT INTO "django_geo_db_location" VALUES(52874,NULL,'McDonald, KS',22267,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52875,NULL,'McDonald, KS 67745',22267,222,NULL,20,30315,0);
INSERT INTO "django_geo_db_location" VALUES(52876,NULL,'Monument, KS',22268,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52877,NULL,'Monument, KS 67747',22268,222,NULL,20,30316,0);
INSERT INTO "django_geo_db_location" VALUES(52878,NULL,'Oakley, KS',22269,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52879,NULL,'Oakley, KS 67748',22269,222,NULL,20,30317,0);
INSERT INTO "django_geo_db_location" VALUES(52880,NULL,'Oberlin, KS',22270,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52881,NULL,'Oberlin, KS 67749',22270,222,NULL,20,30318,0);
INSERT INTO "django_geo_db_location" VALUES(52882,NULL,'Park, KS',22271,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52883,NULL,'Park, KS 67751',22271,222,NULL,20,30319,0);
INSERT INTO "django_geo_db_location" VALUES(52884,NULL,'Quinter, KS',22272,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52885,NULL,'Quinter, KS 67752',22272,222,NULL,20,30320,0);
INSERT INTO "django_geo_db_location" VALUES(52886,NULL,'Rexford, KS',22273,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52887,NULL,'Rexford, KS 67753',22273,222,NULL,20,30321,0);
INSERT INTO "django_geo_db_location" VALUES(52888,NULL,'Saint Francis, KS',22274,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52889,NULL,'Saint Francis, KS 67756',22274,222,NULL,20,30322,0);
INSERT INTO "django_geo_db_location" VALUES(52890,NULL,'Selden, KS',22275,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52891,NULL,'Selden, KS 67757',22275,222,NULL,20,30323,0);
INSERT INTO "django_geo_db_location" VALUES(52892,NULL,'Sharon Springs, KS',22276,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52893,NULL,'Sharon Springs, KS 67758',22276,222,NULL,20,30324,0);
INSERT INTO "django_geo_db_location" VALUES(52894,NULL,'Wallace, KS',22277,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52895,NULL,'Wallace, KS 67761',22277,222,NULL,20,30325,0);
INSERT INTO "django_geo_db_location" VALUES(52896,NULL,'Weskan, KS',22278,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52897,NULL,'Weskan, KS 67762',22278,222,NULL,20,30326,0);
INSERT INTO "django_geo_db_location" VALUES(52898,NULL,'Winona, KS',22279,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52899,NULL,'Winona, KS 67764',22279,222,NULL,20,30327,0);
INSERT INTO "django_geo_db_location" VALUES(52900,NULL,'Dodge City, KS',22280,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52901,NULL,'Dodge City, KS 67801',22280,222,NULL,20,30328,0);
INSERT INTO "django_geo_db_location" VALUES(52902,NULL,'Ashland, KS',22281,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52903,NULL,'Ashland, KS 67831',22281,222,NULL,20,30329,0);
INSERT INTO "django_geo_db_location" VALUES(52904,NULL,'Bucklin, KS',22282,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52905,NULL,'Bucklin, KS 67834',22282,222,NULL,20,30330,0);
INSERT INTO "django_geo_db_location" VALUES(52906,NULL,'Cimarron, KS',22283,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52907,NULL,'Cimarron, KS 67835',22283,222,NULL,20,30331,0);
INSERT INTO "django_geo_db_location" VALUES(52908,NULL,'Coolidge, KS',22284,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52909,NULL,'Coolidge, KS 67836',22284,222,NULL,20,30332,0);
INSERT INTO "django_geo_db_location" VALUES(52910,NULL,'Copeland, KS',22285,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52911,NULL,'Copeland, KS 67837',22285,222,NULL,20,30333,0);
INSERT INTO "django_geo_db_location" VALUES(52912,NULL,'Deerfield, KS',22286,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52913,NULL,'Deerfield, KS 67838',22286,222,NULL,20,30334,0);
INSERT INTO "django_geo_db_location" VALUES(52914,NULL,'Dighton, KS',22287,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52915,NULL,'Dighton, KS 67839',22287,222,NULL,20,30335,0);
INSERT INTO "django_geo_db_location" VALUES(52916,NULL,'Englewood, KS',22288,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52917,NULL,'Englewood, KS 67840',22288,222,NULL,20,30336,0);
INSERT INTO "django_geo_db_location" VALUES(52918,NULL,'Ensign, KS',22289,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52919,NULL,'Ensign, KS 67841',22289,222,NULL,20,30337,0);
INSERT INTO "django_geo_db_location" VALUES(52920,NULL,'Ford, KS',22290,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52921,NULL,'Ford, KS 67842',22290,222,NULL,20,30338,0);
INSERT INTO "django_geo_db_location" VALUES(52922,NULL,'Fowler, KS',22291,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52923,NULL,'Fowler, KS 67844',22291,222,NULL,20,30339,0);
INSERT INTO "django_geo_db_location" VALUES(52924,NULL,'Bloom, KS',22292,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52925,NULL,'Bloom, KS 67845',22292,222,NULL,20,30340,0);
INSERT INTO "django_geo_db_location" VALUES(52926,NULL,'Garden City, KS',22293,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52927,NULL,'Garden City, KS 67846',22293,222,NULL,20,30341,0);
INSERT INTO "django_geo_db_location" VALUES(52928,NULL,'Hanston, KS',22294,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52929,NULL,'Hanston, KS 67849',22294,222,NULL,20,30342,0);
INSERT INTO "django_geo_db_location" VALUES(52930,NULL,'Healy, KS',22295,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52931,NULL,'Healy, KS 67850',22295,222,NULL,20,30343,0);
INSERT INTO "django_geo_db_location" VALUES(52932,NULL,'Holcomb, KS',22296,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52933,NULL,'Holcomb, KS 67851',22296,222,NULL,20,30344,0);
INSERT INTO "django_geo_db_location" VALUES(52934,NULL,'Holcomb, KS 67852',22296,222,NULL,20,30345,0);
INSERT INTO "django_geo_db_location" VALUES(52935,NULL,'Ingalls, KS',22297,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52936,NULL,'Ingalls, KS 67853',22297,222,NULL,20,30346,0);
INSERT INTO "django_geo_db_location" VALUES(52937,NULL,'Jetmore, KS',22298,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52938,NULL,'Jetmore, KS 67854',22298,222,NULL,20,30347,0);
INSERT INTO "django_geo_db_location" VALUES(52939,NULL,'Johnson, KS',22299,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52940,NULL,'Johnson, KS 67855',22299,222,NULL,20,30348,0);
INSERT INTO "django_geo_db_location" VALUES(52941,NULL,'Garfield, KS 67856',22171,222,NULL,20,30349,0);
INSERT INTO "django_geo_db_location" VALUES(52942,NULL,'Kendall, KS',22300,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52943,NULL,'Kendall, KS 67857',22300,222,NULL,20,30350,0);
INSERT INTO "django_geo_db_location" VALUES(52944,NULL,'Sodville, KS',22301,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52945,NULL,'Sodville, KS 67858',22301,222,NULL,20,30351,0);
INSERT INTO "django_geo_db_location" VALUES(52946,NULL,'Kismet, KS',22302,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52947,NULL,'Kismet, KS 67859',22302,222,NULL,20,30352,0);
INSERT INTO "django_geo_db_location" VALUES(52948,NULL,'Lakin, KS',22303,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52949,NULL,'Lakin, KS 67860',22303,222,NULL,20,30353,0);
INSERT INTO "django_geo_db_location" VALUES(52950,NULL,'Leoti, KS',22304,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52951,NULL,'Leoti, KS 67861',22304,222,NULL,20,30354,0);
INSERT INTO "django_geo_db_location" VALUES(52952,NULL,'Manter, KS',22305,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52953,NULL,'Manter, KS 67862',22305,222,NULL,20,30355,0);
INSERT INTO "django_geo_db_location" VALUES(52954,NULL,'Marienthal, KS',22306,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52955,NULL,'Marienthal, KS 67863',22306,222,NULL,20,30356,0);
INSERT INTO "django_geo_db_location" VALUES(52956,NULL,'Meade, KS',22307,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52957,NULL,'Meade, KS 67864',22307,222,NULL,20,30357,0);
INSERT INTO "django_geo_db_location" VALUES(52958,NULL,'Minneola, KS',22308,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52959,NULL,'Minneola, KS 67865',22308,222,NULL,20,30358,0);
INSERT INTO "django_geo_db_location" VALUES(52960,NULL,'Montezuma, KS',22309,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52961,NULL,'Montezuma, KS 67867',22309,222,NULL,20,30359,0);
INSERT INTO "django_geo_db_location" VALUES(52962,NULL,'Pierceville, KS',22310,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52963,NULL,'Pierceville, KS 67868',22310,222,NULL,20,30360,0);
INSERT INTO "django_geo_db_location" VALUES(52964,NULL,'Plains, KS',22311,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52965,NULL,'Plains, KS 67869',22311,222,NULL,20,30361,0);
INSERT INTO "django_geo_db_location" VALUES(52966,NULL,'Satanta, KS',22312,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52967,NULL,'Satanta, KS 67870',22312,222,NULL,20,30362,0);
INSERT INTO "django_geo_db_location" VALUES(52968,NULL,'Scott City, KS',22313,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52969,NULL,'Scott City, KS 67871',22313,222,NULL,20,30363,0);
INSERT INTO "django_geo_db_location" VALUES(52970,NULL,'Spearville, KS',22314,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52971,NULL,'Spearville, KS 67876',22314,222,NULL,20,30364,0);
INSERT INTO "django_geo_db_location" VALUES(52972,NULL,'Sublette, KS',22315,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52973,NULL,'Sublette, KS 67877',22315,222,NULL,20,30365,0);
INSERT INTO "django_geo_db_location" VALUES(52974,NULL,'Syracuse, KS',22316,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52975,NULL,'Syracuse, KS 67878',22316,222,NULL,20,30366,0);
INSERT INTO "django_geo_db_location" VALUES(52976,NULL,'Tribune, KS',22317,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52977,NULL,'Tribune, KS 67879',22317,222,NULL,20,30367,0);
INSERT INTO "django_geo_db_location" VALUES(52978,NULL,'Ulysses, KS',22318,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52979,NULL,'Ulysses, KS 67880',22318,222,NULL,20,30368,0);
INSERT INTO "django_geo_db_location" VALUES(52980,NULL,'Wright, KS',22319,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52981,NULL,'Wright, KS 67882',22319,222,NULL,20,30369,0);
INSERT INTO "django_geo_db_location" VALUES(52982,NULL,'Liberal, KS',22320,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52983,NULL,'Liberal, KS 67901',22320,222,NULL,20,30370,0);
INSERT INTO "django_geo_db_location" VALUES(52984,NULL,'Liberal, KS 67905',22320,222,NULL,20,30371,0);
INSERT INTO "django_geo_db_location" VALUES(52985,NULL,'Colfax, KS',22321,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52986,NULL,'Colfax, KS 67938',22321,222,NULL,20,30372,0);
INSERT INTO "django_geo_db_location" VALUES(52987,NULL,'Elkhart, KS',22322,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52988,NULL,'Elkhart, KS 67950',22322,222,NULL,20,30373,0);
INSERT INTO "django_geo_db_location" VALUES(52989,NULL,'Hugoton, KS',22323,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52990,NULL,'Hugoton, KS 67951',22323,222,NULL,20,30374,0);
INSERT INTO "django_geo_db_location" VALUES(52991,NULL,'Moscow, KS',22324,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52992,NULL,'Moscow, KS 67952',22324,222,NULL,20,30375,0);
INSERT INTO "django_geo_db_location" VALUES(52993,NULL,'Richfield, KS',22325,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52994,NULL,'Richfield, KS 67953',22325,222,NULL,20,30376,0);
INSERT INTO "django_geo_db_location" VALUES(52995,NULL,'Rolla, KS',22326,222,NULL,20,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52996,NULL,'Rolla, KS 67954',22326,222,NULL,20,30377,0);
INSERT INTO "django_geo_db_location" VALUES(52997,NULL,'Abie, NE',22327,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(52998,NULL,'Abie, NE 68001',22327,222,NULL,27,30378,0);
INSERT INTO "django_geo_db_location" VALUES(52999,NULL,'Arlington, NE',22328,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53000,NULL,'Arlington, NE 68002',22328,222,NULL,27,30379,0);
INSERT INTO "django_geo_db_location" VALUES(53001,NULL,'Ashland, NE',22329,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53002,NULL,'Ashland, NE 68003',22329,222,NULL,27,30380,0);
INSERT INTO "django_geo_db_location" VALUES(53003,NULL,'Bancroft, NE',22330,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53004,NULL,'Bancroft, NE 68004',22330,222,NULL,27,30381,0);
INSERT INTO "django_geo_db_location" VALUES(53005,NULL,'Bellevue, NE',22331,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53006,NULL,'Bellevue, NE 68005',22331,222,NULL,27,30382,0);
INSERT INTO "django_geo_db_location" VALUES(53007,NULL,'Bennington, NE',22332,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53008,NULL,'Bennington, NE 68007',22332,222,NULL,27,30383,0);
INSERT INTO "django_geo_db_location" VALUES(53009,NULL,'Blair, NE',22333,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53010,NULL,'Blair, NE 68008',22333,222,NULL,27,30384,0);
INSERT INTO "django_geo_db_location" VALUES(53011,NULL,'Blair, NE 68009',22333,222,NULL,27,30385,0);
INSERT INTO "django_geo_db_location" VALUES(53012,NULL,'Boys Town, NE',22334,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53013,NULL,'Boys Town, NE 68010',22334,222,NULL,27,30386,0);
INSERT INTO "django_geo_db_location" VALUES(53014,NULL,'Bruno, NE',22335,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53015,NULL,'Bruno, NE 68014',22335,222,NULL,27,30387,0);
INSERT INTO "django_geo_db_location" VALUES(53016,NULL,'Cedar Bluffs, NE',22336,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53017,NULL,'Cedar Bluffs, NE 68015',22336,222,NULL,27,30388,0);
INSERT INTO "django_geo_db_location" VALUES(53018,NULL,'Cedar Creek, NE',22337,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53019,NULL,'Cedar Creek, NE 68016',22337,222,NULL,27,30389,0);
INSERT INTO "django_geo_db_location" VALUES(53020,NULL,'Ceresco, NE',22338,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53021,NULL,'Ceresco, NE 68017',22338,222,NULL,27,30390,0);
INSERT INTO "django_geo_db_location" VALUES(53022,NULL,'Colon, NE',22339,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53023,NULL,'Colon, NE 68018',22339,222,NULL,27,30391,0);
INSERT INTO "django_geo_db_location" VALUES(53024,NULL,'Craig, NE',22340,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53025,NULL,'Craig, NE 68019',22340,222,NULL,27,30392,0);
INSERT INTO "django_geo_db_location" VALUES(53026,NULL,'Decatur, NE',22341,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53027,NULL,'Decatur, NE 68020',22341,222,NULL,27,30393,0);
INSERT INTO "django_geo_db_location" VALUES(53028,NULL,'Elkhorn, NE',22342,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53029,NULL,'Elkhorn, NE 68022',22342,222,NULL,27,30394,0);
INSERT INTO "django_geo_db_location" VALUES(53030,NULL,'Fort Calhoun, NE',22343,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53031,NULL,'Fort Calhoun, NE 68023',22343,222,NULL,27,30395,0);
INSERT INTO "django_geo_db_location" VALUES(53032,NULL,'Fremont, NE',22344,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53033,NULL,'Fremont, NE 68025',22344,222,NULL,27,30396,0);
INSERT INTO "django_geo_db_location" VALUES(53034,NULL,'Fremont, NE 68026',22344,222,NULL,27,30397,0);
INSERT INTO "django_geo_db_location" VALUES(53035,NULL,'Gretna, NE',22345,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53036,NULL,'Gretna, NE 68028',22345,222,NULL,27,30398,0);
INSERT INTO "django_geo_db_location" VALUES(53037,NULL,'Herman, NE',22346,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53038,NULL,'Herman, NE 68029',22346,222,NULL,27,30399,0);
INSERT INTO "django_geo_db_location" VALUES(53039,NULL,'Homer, NE',22347,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53040,NULL,'Homer, NE 68030',22347,222,NULL,27,30400,0);
INSERT INTO "django_geo_db_location" VALUES(53041,NULL,'Hooper, NE',22348,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53042,NULL,'Hooper, NE 68031',22348,222,NULL,27,30401,0);
INSERT INTO "django_geo_db_location" VALUES(53043,NULL,'Linwood, NE',22349,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53044,NULL,'Linwood, NE 68032',22349,222,NULL,27,30402,0);
INSERT INTO "django_geo_db_location" VALUES(53045,NULL,'Ithaca, NE',22350,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53046,NULL,'Ithaca, NE 68033',22350,222,NULL,27,30403,0);
INSERT INTO "django_geo_db_location" VALUES(53047,NULL,'Kennard, NE',22351,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53048,NULL,'Kennard, NE 68034',22351,222,NULL,27,30404,0);
INSERT INTO "django_geo_db_location" VALUES(53049,NULL,'Leshara, NE',22352,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53050,NULL,'Leshara, NE 68035',22352,222,NULL,27,30405,0);
INSERT INTO "django_geo_db_location" VALUES(53051,NULL,'Linwood, NE 68036',22349,222,NULL,27,30406,0);
INSERT INTO "django_geo_db_location" VALUES(53052,NULL,'Louisville, NE',22353,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53053,NULL,'Louisville, NE 68037',22353,222,NULL,27,30407,0);
INSERT INTO "django_geo_db_location" VALUES(53054,NULL,'Lyons, NE',22354,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53055,NULL,'Lyons, NE 68038',22354,222,NULL,27,30408,0);
INSERT INTO "django_geo_db_location" VALUES(53056,NULL,'Macy, NE',22355,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53057,NULL,'Macy, NE 68039',22355,222,NULL,27,30409,0);
INSERT INTO "django_geo_db_location" VALUES(53058,NULL,'Malmo, NE',22356,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53059,NULL,'Malmo, NE 68040',22356,222,NULL,27,30410,0);
INSERT INTO "django_geo_db_location" VALUES(53060,NULL,'Mead, NE',22357,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53061,NULL,'Mead, NE 68041',22357,222,NULL,27,30411,0);
INSERT INTO "django_geo_db_location" VALUES(53062,NULL,'Memphis, NE',22358,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53063,NULL,'Memphis, NE 68042',22358,222,NULL,27,30412,0);
INSERT INTO "django_geo_db_location" VALUES(53064,NULL,'Nickerson, NE',22359,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53065,NULL,'Nickerson, NE 68044',22359,222,NULL,27,30413,0);
INSERT INTO "django_geo_db_location" VALUES(53066,NULL,'Oakland, NE',22360,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53067,NULL,'Oakland, NE 68045',22360,222,NULL,27,30414,0);
INSERT INTO "django_geo_db_location" VALUES(53068,NULL,'Papillion, NE',22361,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53069,NULL,'Papillion, NE 68046',22361,222,NULL,27,30415,0);
INSERT INTO "django_geo_db_location" VALUES(53070,NULL,'Pender, NE',22362,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53071,NULL,'Pender, NE 68047',22362,222,NULL,27,30416,0);
INSERT INTO "django_geo_db_location" VALUES(53072,NULL,'Plattsmouth, NE',22363,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53073,NULL,'Plattsmouth, NE 68048',22363,222,NULL,27,30417,0);
INSERT INTO "django_geo_db_location" VALUES(53074,NULL,'Prague, NE',22364,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53075,NULL,'Prague, NE 68050',22364,222,NULL,27,30418,0);
INSERT INTO "django_geo_db_location" VALUES(53076,NULL,'Richfield, NE',22365,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53077,NULL,'Richfield, NE 68054',22365,222,NULL,27,30419,0);
INSERT INTO "django_geo_db_location" VALUES(53078,NULL,'Rosalie, NE',22366,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53079,NULL,'Rosalie, NE 68055',22366,222,NULL,27,30420,0);
INSERT INTO "django_geo_db_location" VALUES(53080,NULL,'St Columbans, NE',22367,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53081,NULL,'St Columbans, NE 68056',22367,222,NULL,27,30421,0);
INSERT INTO "django_geo_db_location" VALUES(53082,NULL,'Scribner, NE',22368,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53083,NULL,'Scribner, NE 68057',22368,222,NULL,27,30422,0);
INSERT INTO "django_geo_db_location" VALUES(53084,NULL,'South Bend, NE',22369,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53085,NULL,'South Bend, NE 68058',22369,222,NULL,27,30423,0);
INSERT INTO "django_geo_db_location" VALUES(53086,NULL,'Springfield, NE',22370,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53087,NULL,'Springfield, NE 68059',22370,222,NULL,27,30424,0);
INSERT INTO "django_geo_db_location" VALUES(53088,NULL,'Tekamah, NE',22371,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53089,NULL,'Tekamah, NE 68061',22371,222,NULL,27,30425,0);
INSERT INTO "django_geo_db_location" VALUES(53090,NULL,'Thurston, NE',22372,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53091,NULL,'Thurston, NE 68062',22372,222,NULL,27,30426,0);
INSERT INTO "django_geo_db_location" VALUES(53092,NULL,'Uehling, NE',22373,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53093,NULL,'Uehling, NE 68063',22373,222,NULL,27,30427,0);
INSERT INTO "django_geo_db_location" VALUES(53094,NULL,'Valley, NE',22374,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53095,NULL,'Valley, NE 68064',22374,222,NULL,27,30428,0);
INSERT INTO "django_geo_db_location" VALUES(53096,NULL,'Valparaiso, NE',22375,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53097,NULL,'Valparaiso, NE 68065',22375,222,NULL,27,30429,0);
INSERT INTO "django_geo_db_location" VALUES(53098,NULL,'Wahoo, NE',22376,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53099,NULL,'Wahoo, NE 68066',22376,222,NULL,27,30430,0);
INSERT INTO "django_geo_db_location" VALUES(53100,NULL,'Walthill, NE',22377,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53101,NULL,'Walthill, NE 68067',22377,222,NULL,27,30431,0);
INSERT INTO "django_geo_db_location" VALUES(53102,NULL,'Washington, NE',22378,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53103,NULL,'Washington, NE 68068',22378,222,NULL,27,30432,0);
INSERT INTO "django_geo_db_location" VALUES(53104,NULL,'Waterloo, NE',22379,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53105,NULL,'Waterloo, NE 68069',22379,222,NULL,27,30433,0);
INSERT INTO "django_geo_db_location" VALUES(53106,NULL,'Weston, NE',22380,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53107,NULL,'Weston, NE 68070',22380,222,NULL,27,30434,0);
INSERT INTO "django_geo_db_location" VALUES(53108,NULL,'Winnebago, NE',22381,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53109,NULL,'Winnebago, NE 68071',22381,222,NULL,27,30435,0);
INSERT INTO "django_geo_db_location" VALUES(53110,NULL,'Winslow, NE',22382,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53111,NULL,'Winslow, NE 68072',22382,222,NULL,27,30436,0);
INSERT INTO "django_geo_db_location" VALUES(53112,NULL,'Yutan, NE',22383,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53113,NULL,'Yutan, NE 68073',22383,222,NULL,27,30437,0);
INSERT INTO "django_geo_db_location" VALUES(53114,NULL,'Omaha, NE',22384,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53115,NULL,'Omaha, NE 68101',22384,222,NULL,27,30438,0);
INSERT INTO "django_geo_db_location" VALUES(53116,NULL,'Omaha, NE 68102',22384,222,NULL,27,30439,0);
INSERT INTO "django_geo_db_location" VALUES(53117,NULL,'Omaha, NE 68103',22384,222,NULL,27,30440,0);
INSERT INTO "django_geo_db_location" VALUES(53118,NULL,'Omaha, NE 68104',22384,222,NULL,27,30441,0);
INSERT INTO "django_geo_db_location" VALUES(53119,NULL,'Omaha, NE 68105',22384,222,NULL,27,30442,0);
INSERT INTO "django_geo_db_location" VALUES(53120,NULL,'Omaha, NE 68106',22384,222,NULL,27,30443,0);
INSERT INTO "django_geo_db_location" VALUES(53121,NULL,'Omaha, NE 68107',22384,222,NULL,27,30444,0);
INSERT INTO "django_geo_db_location" VALUES(53122,NULL,'Omaha, NE 68108',22384,222,NULL,27,30445,0);
INSERT INTO "django_geo_db_location" VALUES(53123,NULL,'Omaha, NE 68109',22384,222,NULL,27,30446,0);
INSERT INTO "django_geo_db_location" VALUES(53124,NULL,'Omaha, NE 68110',22384,222,NULL,27,30447,0);
INSERT INTO "django_geo_db_location" VALUES(53125,NULL,'Omaha, NE 68111',22384,222,NULL,27,30448,0);
INSERT INTO "django_geo_db_location" VALUES(53126,NULL,'Omaha, NE 68112',22384,222,NULL,27,30449,0);
INSERT INTO "django_geo_db_location" VALUES(53127,NULL,'Offutt A F B, NE',22385,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53128,NULL,'Offutt A F B, NE 68113',22385,222,NULL,27,30450,0);
INSERT INTO "django_geo_db_location" VALUES(53129,NULL,'Omaha, NE 68114',22384,222,NULL,27,30451,0);
INSERT INTO "django_geo_db_location" VALUES(53130,NULL,'Omaha, NE 68116',22384,222,NULL,27,30452,0);
INSERT INTO "django_geo_db_location" VALUES(53131,NULL,'Omaha, NE 68117',22384,222,NULL,27,30453,0);
INSERT INTO "django_geo_db_location" VALUES(53132,NULL,'Omaha, NE 68118',22384,222,NULL,27,30454,0);
INSERT INTO "django_geo_db_location" VALUES(53133,NULL,'Omaha, NE 68119',22384,222,NULL,27,30455,0);
INSERT INTO "django_geo_db_location" VALUES(53134,NULL,'Omaha, NE 68120',22384,222,NULL,27,30456,0);
INSERT INTO "django_geo_db_location" VALUES(53135,NULL,'Omaha, NE 68122',22384,222,NULL,27,30457,0);
INSERT INTO "django_geo_db_location" VALUES(53136,NULL,'Bellevue, NE 68123',22331,222,NULL,27,30458,0);
INSERT INTO "django_geo_db_location" VALUES(53137,NULL,'Omaha, NE 68124',22384,222,NULL,27,30459,0);
INSERT INTO "django_geo_db_location" VALUES(53138,NULL,'Omaha, NE 68127',22384,222,NULL,27,30460,0);
INSERT INTO "django_geo_db_location" VALUES(53139,NULL,'La Vista, NE',22386,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53140,NULL,'La Vista, NE 68128',22386,222,NULL,27,30461,0);
INSERT INTO "django_geo_db_location" VALUES(53141,NULL,'Omaha, NE 68130',22384,222,NULL,27,30462,0);
INSERT INTO "django_geo_db_location" VALUES(53142,NULL,'Omaha, NE 68131',22384,222,NULL,27,30463,0);
INSERT INTO "django_geo_db_location" VALUES(53143,NULL,'Omaha, NE 68132',22384,222,NULL,27,30464,0);
INSERT INTO "django_geo_db_location" VALUES(53144,NULL,'Papillion, NE 68133',22361,222,NULL,27,30465,0);
INSERT INTO "django_geo_db_location" VALUES(53145,NULL,'Omaha, NE 68134',22384,222,NULL,27,30466,0);
INSERT INTO "django_geo_db_location" VALUES(53146,NULL,'Omaha, NE 68135',22384,222,NULL,27,30467,0);
INSERT INTO "django_geo_db_location" VALUES(53147,NULL,'Omaha, NE 68136',22384,222,NULL,27,30468,0);
INSERT INTO "django_geo_db_location" VALUES(53148,NULL,'Omaha, NE 68137',22384,222,NULL,27,30469,0);
INSERT INTO "django_geo_db_location" VALUES(53149,NULL,'Omaha, NE 68138',22384,222,NULL,27,30470,0);
INSERT INTO "django_geo_db_location" VALUES(53150,NULL,'Omaha, NE 68139',22384,222,NULL,27,30471,0);
INSERT INTO "django_geo_db_location" VALUES(53151,NULL,'Omaha, NE 68142',22384,222,NULL,27,30472,0);
INSERT INTO "django_geo_db_location" VALUES(53152,NULL,'Omaha, NE 68144',22384,222,NULL,27,30473,0);
INSERT INTO "django_geo_db_location" VALUES(53153,NULL,'Omaha, NE 68145',22384,222,NULL,27,30474,0);
INSERT INTO "django_geo_db_location" VALUES(53154,NULL,'Bellevue, NE 68147',22331,222,NULL,27,30475,0);
INSERT INTO "django_geo_db_location" VALUES(53155,NULL,'Omaha, NE 68152',22384,222,NULL,27,30476,0);
INSERT INTO "django_geo_db_location" VALUES(53156,NULL,'Omaha, NE 68154',22384,222,NULL,27,30477,0);
INSERT INTO "django_geo_db_location" VALUES(53157,NULL,'Omaha, NE 68155',22384,222,NULL,27,30478,0);
INSERT INTO "django_geo_db_location" VALUES(53158,NULL,'Omaha, NE 68157',22384,222,NULL,27,30479,0);
INSERT INTO "django_geo_db_location" VALUES(53159,NULL,'Omaha, NE 68164',22384,222,NULL,27,30480,0);
INSERT INTO "django_geo_db_location" VALUES(53160,NULL,'Omaha, NE 68172',22384,222,NULL,27,30481,0);
INSERT INTO "django_geo_db_location" VALUES(53161,NULL,'Omaha, NE 68175',22384,222,NULL,27,30482,0);
INSERT INTO "django_geo_db_location" VALUES(53162,NULL,'Omaha, NE 68176',22384,222,NULL,27,30483,0);
INSERT INTO "django_geo_db_location" VALUES(53163,NULL,'Omaha, NE 68178',22384,222,NULL,27,30484,0);
INSERT INTO "django_geo_db_location" VALUES(53164,NULL,'Omaha, NE 68179',22384,222,NULL,27,30485,0);
INSERT INTO "django_geo_db_location" VALUES(53165,NULL,'Omaha, NE 68180',22384,222,NULL,27,30486,0);
INSERT INTO "django_geo_db_location" VALUES(53166,NULL,'Omaha, NE 68181',22384,222,NULL,27,30487,0);
INSERT INTO "django_geo_db_location" VALUES(53167,NULL,'Omaha, NE 68182',22384,222,NULL,27,30488,0);
INSERT INTO "django_geo_db_location" VALUES(53168,NULL,'Omaha, NE 68183',22384,222,NULL,27,30489,0);
INSERT INTO "django_geo_db_location" VALUES(53169,NULL,'Omaha, NE 68198',22384,222,NULL,27,30490,0);
INSERT INTO "django_geo_db_location" VALUES(53170,NULL,'Central City, NE',22387,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53171,NULL,'Central City, NE 68226',22387,222,NULL,27,30491,0);
INSERT INTO "django_geo_db_location" VALUES(53172,NULL,'Omaha, NE 68278',22384,222,NULL,27,30492,0);
INSERT INTO "django_geo_db_location" VALUES(53173,NULL,'Adams, NE',22388,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53174,NULL,'Adams, NE 68301',22388,222,NULL,27,30493,0);
INSERT INTO "django_geo_db_location" VALUES(53175,NULL,'Alexandria, NE',22389,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53176,NULL,'Alexandria, NE 68303',22389,222,NULL,27,30494,0);
INSERT INTO "django_geo_db_location" VALUES(53177,NULL,'Alvo, NE',22390,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53178,NULL,'Alvo, NE 68304',22390,222,NULL,27,30495,0);
INSERT INTO "django_geo_db_location" VALUES(53179,NULL,'Auburn, NE',22391,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53180,NULL,'Auburn, NE 68305',22391,222,NULL,27,30496,0);
INSERT INTO "django_geo_db_location" VALUES(53181,NULL,'Avoca, NE',22392,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53182,NULL,'Avoca, NE 68307',22392,222,NULL,27,30497,0);
INSERT INTO "django_geo_db_location" VALUES(53183,NULL,'Barneston, NE',22393,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53184,NULL,'Barneston, NE 68309',22393,222,NULL,27,30498,0);
INSERT INTO "django_geo_db_location" VALUES(53185,NULL,'Beatrice, NE',22394,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53186,NULL,'Beatrice, NE 68310',22394,222,NULL,27,30499,0);
INSERT INTO "django_geo_db_location" VALUES(53187,NULL,'Beaver Crossing, NE',22395,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53188,NULL,'Beaver Crossing, NE 68313',22395,222,NULL,27,30500,0);
INSERT INTO "django_geo_db_location" VALUES(53189,NULL,'Bee, NE',22396,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53190,NULL,'Bee, NE 68314',22396,222,NULL,27,30501,0);
INSERT INTO "django_geo_db_location" VALUES(53191,NULL,'Belvidere, NE',22397,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53192,NULL,'Belvidere, NE 68315',22397,222,NULL,27,30502,0);
INSERT INTO "django_geo_db_location" VALUES(53193,NULL,'Benedict, NE',22398,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53194,NULL,'Benedict, NE 68316',22398,222,NULL,27,30503,0);
INSERT INTO "django_geo_db_location" VALUES(53195,NULL,'Bennet, NE',22399,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53196,NULL,'Bennet, NE 68317',22399,222,NULL,27,30504,0);
INSERT INTO "django_geo_db_location" VALUES(53197,NULL,'Blue Springs, NE',22400,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53198,NULL,'Blue Springs, NE 68318',22400,222,NULL,27,30505,0);
INSERT INTO "django_geo_db_location" VALUES(53199,NULL,'Bradshaw, NE',22401,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53200,NULL,'Bradshaw, NE 68319',22401,222,NULL,27,30506,0);
INSERT INTO "django_geo_db_location" VALUES(53201,NULL,'Brock, NE',22402,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53202,NULL,'Brock, NE 68320',22402,222,NULL,27,30507,0);
INSERT INTO "django_geo_db_location" VALUES(53203,NULL,'Brownville, NE',22403,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53204,NULL,'Brownville, NE 68321',22403,222,NULL,27,30508,0);
INSERT INTO "django_geo_db_location" VALUES(53205,NULL,'Bruning, NE',22404,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53206,NULL,'Bruning, NE 68322',22404,222,NULL,27,30509,0);
INSERT INTO "django_geo_db_location" VALUES(53207,NULL,'Burchard, NE',22405,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53208,NULL,'Burchard, NE 68323',22405,222,NULL,27,30510,0);
INSERT INTO "django_geo_db_location" VALUES(53209,NULL,'Burr, NE',22406,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53210,NULL,'Burr, NE 68324',22406,222,NULL,27,30511,0);
INSERT INTO "django_geo_db_location" VALUES(53211,NULL,'Byron, NE',22407,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53212,NULL,'Byron, NE 68325',22407,222,NULL,27,30512,0);
INSERT INTO "django_geo_db_location" VALUES(53213,NULL,'Carleton, NE',22408,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53214,NULL,'Carleton, NE 68326',22408,222,NULL,27,30513,0);
INSERT INTO "django_geo_db_location" VALUES(53215,NULL,'Chester, NE',22409,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53216,NULL,'Chester, NE 68327',22409,222,NULL,27,30514,0);
INSERT INTO "django_geo_db_location" VALUES(53217,NULL,'Clatonia, NE',22410,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53218,NULL,'Clatonia, NE 68328',22410,222,NULL,27,30515,0);
INSERT INTO "django_geo_db_location" VALUES(53219,NULL,'Cook, NE',22411,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53220,NULL,'Cook, NE 68329',22411,222,NULL,27,30516,0);
INSERT INTO "django_geo_db_location" VALUES(53221,NULL,'Cordova, NE',22412,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53222,NULL,'Cordova, NE 68330',22412,222,NULL,27,30517,0);
INSERT INTO "django_geo_db_location" VALUES(53223,NULL,'Cortland, NE',22413,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53224,NULL,'Cortland, NE 68331',22413,222,NULL,27,30518,0);
INSERT INTO "django_geo_db_location" VALUES(53225,NULL,'Crab Orchard, NE',22414,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53226,NULL,'Crab Orchard, NE 68332',22414,222,NULL,27,30519,0);
INSERT INTO "django_geo_db_location" VALUES(53227,NULL,'Crete, NE',22415,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53228,NULL,'Crete, NE 68333',22415,222,NULL,27,30520,0);
INSERT INTO "django_geo_db_location" VALUES(53229,NULL,'Davenport, NE',22416,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53230,NULL,'Davenport, NE 68335',22416,222,NULL,27,30521,0);
INSERT INTO "django_geo_db_location" VALUES(53231,NULL,'Davey, NE',22417,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53232,NULL,'Davey, NE 68336',22417,222,NULL,27,30522,0);
INSERT INTO "django_geo_db_location" VALUES(53233,NULL,'Dawson, NE',22418,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53234,NULL,'Dawson, NE 68337',22418,222,NULL,27,30523,0);
INSERT INTO "django_geo_db_location" VALUES(53235,NULL,'Daykin, NE',22419,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53236,NULL,'Daykin, NE 68338',22419,222,NULL,27,30524,0);
INSERT INTO "django_geo_db_location" VALUES(53237,NULL,'Denton, NE',22420,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53238,NULL,'Denton, NE 68339',22420,222,NULL,27,30525,0);
INSERT INTO "django_geo_db_location" VALUES(53239,NULL,'Deshler, NE',22421,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53240,NULL,'Deshler, NE 68340',22421,222,NULL,27,30526,0);
INSERT INTO "django_geo_db_location" VALUES(53241,NULL,'De Witt, NE',22422,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53242,NULL,'De Witt, NE 68341',22422,222,NULL,27,30527,0);
INSERT INTO "django_geo_db_location" VALUES(53243,NULL,'Diller, NE',22423,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53244,NULL,'Diller, NE 68342',22423,222,NULL,27,30528,0);
INSERT INTO "django_geo_db_location" VALUES(53245,NULL,'Dorchester, NE',22424,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53246,NULL,'Dorchester, NE 68343',22424,222,NULL,27,30529,0);
INSERT INTO "django_geo_db_location" VALUES(53247,NULL,'Douglas, NE',22425,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53248,NULL,'Douglas, NE 68344',22425,222,NULL,27,30530,0);
INSERT INTO "django_geo_db_location" VALUES(53249,NULL,'Du Bois, NE',22426,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53250,NULL,'Du Bois, NE 68345',22426,222,NULL,27,30531,0);
INSERT INTO "django_geo_db_location" VALUES(53251,NULL,'Dunbar, NE',22427,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53252,NULL,'Dunbar, NE 68346',22427,222,NULL,27,30532,0);
INSERT INTO "django_geo_db_location" VALUES(53253,NULL,'Eagle, NE',22428,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53254,NULL,'Eagle, NE 68347',22428,222,NULL,27,30533,0);
INSERT INTO "django_geo_db_location" VALUES(53255,NULL,'Elk Creek, NE',22429,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53256,NULL,'Elk Creek, NE 68348',22429,222,NULL,27,30534,0);
INSERT INTO "django_geo_db_location" VALUES(53257,NULL,'Elmwood, NE',22430,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53258,NULL,'Elmwood, NE 68349',22430,222,NULL,27,30535,0);
INSERT INTO "django_geo_db_location" VALUES(53259,NULL,'Endicott, NE',22431,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53260,NULL,'Endicott, NE 68350',22431,222,NULL,27,30536,0);
INSERT INTO "django_geo_db_location" VALUES(53261,NULL,'Exeter, NE',22432,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53262,NULL,'Exeter, NE 68351',22432,222,NULL,27,30537,0);
INSERT INTO "django_geo_db_location" VALUES(53263,NULL,'Fairbury, NE',22433,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53264,NULL,'Fairbury, NE 68352',22433,222,NULL,27,30538,0);
INSERT INTO "django_geo_db_location" VALUES(53265,NULL,'Fairmont, NE',22434,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53266,NULL,'Fairmont, NE 68354',22434,222,NULL,27,30539,0);
INSERT INTO "django_geo_db_location" VALUES(53267,NULL,'Falls City, NE',22435,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53268,NULL,'Falls City, NE 68355',22435,222,NULL,27,30540,0);
INSERT INTO "django_geo_db_location" VALUES(53269,NULL,'Filley, NE',22436,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53270,NULL,'Filley, NE 68357',22436,222,NULL,27,30541,0);
INSERT INTO "django_geo_db_location" VALUES(53271,NULL,'Firth, NE',22437,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53272,NULL,'Firth, NE 68358',22437,222,NULL,27,30542,0);
INSERT INTO "django_geo_db_location" VALUES(53273,NULL,'Friend, NE',22438,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53274,NULL,'Friend, NE 68359',22438,222,NULL,27,30543,0);
INSERT INTO "django_geo_db_location" VALUES(53275,NULL,'Garland, NE',22439,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53276,NULL,'Garland, NE 68360',22439,222,NULL,27,30544,0);
INSERT INTO "django_geo_db_location" VALUES(53277,NULL,'Geneva, NE',22440,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53278,NULL,'Geneva, NE 68361',22440,222,NULL,27,30545,0);
INSERT INTO "django_geo_db_location" VALUES(53279,NULL,'Gilead, NE',22441,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53280,NULL,'Gilead, NE 68362',22441,222,NULL,27,30546,0);
INSERT INTO "django_geo_db_location" VALUES(53281,NULL,'Goehner, NE',22442,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53282,NULL,'Goehner, NE 68364',22442,222,NULL,27,30547,0);
INSERT INTO "django_geo_db_location" VALUES(53283,NULL,'Grafton, NE',22443,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53284,NULL,'Grafton, NE 68365',22443,222,NULL,27,30548,0);
INSERT INTO "django_geo_db_location" VALUES(53285,NULL,'Greenwood, NE',22444,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53286,NULL,'Greenwood, NE 68366',22444,222,NULL,27,30549,0);
INSERT INTO "django_geo_db_location" VALUES(53287,NULL,'Gresham, NE',22445,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53288,NULL,'Gresham, NE 68367',22445,222,NULL,27,30550,0);
INSERT INTO "django_geo_db_location" VALUES(53289,NULL,'Hallam, NE',22446,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53290,NULL,'Hallam, NE 68368',22446,222,NULL,27,30551,0);
INSERT INTO "django_geo_db_location" VALUES(53291,NULL,'Hebron, NE',22447,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53292,NULL,'Hebron, NE 68370',22447,222,NULL,27,30552,0);
INSERT INTO "django_geo_db_location" VALUES(53293,NULL,'Henderson, NE',22448,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53294,NULL,'Henderson, NE 68371',22448,222,NULL,27,30553,0);
INSERT INTO "django_geo_db_location" VALUES(53295,NULL,'Hickman, NE',22449,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53296,NULL,'Hickman, NE 68372',22449,222,NULL,27,30554,0);
INSERT INTO "django_geo_db_location" VALUES(53297,NULL,'Holmesville, NE',22450,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53298,NULL,'Holmesville, NE 68374',22450,222,NULL,27,30555,0);
INSERT INTO "django_geo_db_location" VALUES(53299,NULL,'Hubbell, NE',22451,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53300,NULL,'Hubbell, NE 68375',22451,222,NULL,27,30556,0);
INSERT INTO "django_geo_db_location" VALUES(53301,NULL,'Humboldt, NE',22452,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53302,NULL,'Humboldt, NE 68376',22452,222,NULL,27,30557,0);
INSERT INTO "django_geo_db_location" VALUES(53303,NULL,'Jansen, NE',22453,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53304,NULL,'Jansen, NE 68377',22453,222,NULL,27,30558,0);
INSERT INTO "django_geo_db_location" VALUES(53305,NULL,'Johnson, NE',22454,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53306,NULL,'Johnson, NE 68378',22454,222,NULL,27,30559,0);
INSERT INTO "django_geo_db_location" VALUES(53307,NULL,'Lewiston, NE',22455,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53308,NULL,'Lewiston, NE 68380',22455,222,NULL,27,30560,0);
INSERT INTO "django_geo_db_location" VALUES(53309,NULL,'Liberty, NE',22456,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53310,NULL,'Liberty, NE 68381',22456,222,NULL,27,30561,0);
INSERT INTO "django_geo_db_location" VALUES(53311,NULL,'Lorton, NE',22457,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53312,NULL,'Lorton, NE 68382',22457,222,NULL,27,30562,0);
INSERT INTO "django_geo_db_location" VALUES(53313,NULL,'McCool Junction, NE',22458,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53314,NULL,'McCool Junction, NE 68401',22458,222,NULL,27,30563,0);
INSERT INTO "django_geo_db_location" VALUES(53315,NULL,'Malcolm, NE',22459,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53316,NULL,'Malcolm, NE 68402',22459,222,NULL,27,30564,0);
INSERT INTO "django_geo_db_location" VALUES(53317,NULL,'Manley, NE',22460,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53318,NULL,'Manley, NE 68403',22460,222,NULL,27,30565,0);
INSERT INTO "django_geo_db_location" VALUES(53319,NULL,'Martell, NE',22461,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53320,NULL,'Martell, NE 68404',22461,222,NULL,27,30566,0);
INSERT INTO "django_geo_db_location" VALUES(53321,NULL,'Milford, NE',22462,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53322,NULL,'Milford, NE 68405',22462,222,NULL,27,30567,0);
INSERT INTO "django_geo_db_location" VALUES(53323,NULL,'Milligan, NE',22463,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53324,NULL,'Milligan, NE 68406',22463,222,NULL,27,30568,0);
INSERT INTO "django_geo_db_location" VALUES(53325,NULL,'Murdock, NE',22464,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53326,NULL,'Murdock, NE 68407',22464,222,NULL,27,30569,0);
INSERT INTO "django_geo_db_location" VALUES(53327,NULL,'Murray, NE',22465,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53328,NULL,'Murray, NE 68409',22465,222,NULL,27,30570,0);
INSERT INTO "django_geo_db_location" VALUES(53329,NULL,'Nebraska City, NE',22466,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53330,NULL,'Nebraska City, NE 68410',22466,222,NULL,27,30571,0);
INSERT INTO "django_geo_db_location" VALUES(53331,NULL,'Nehawka, NE',22467,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53332,NULL,'Nehawka, NE 68413',22467,222,NULL,27,30572,0);
INSERT INTO "django_geo_db_location" VALUES(53333,NULL,'Nemaha, NE',22468,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53334,NULL,'Nemaha, NE 68414',22468,222,NULL,27,30573,0);
INSERT INTO "django_geo_db_location" VALUES(53335,NULL,'Odell, NE',22469,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53336,NULL,'Odell, NE 68415',22469,222,NULL,27,30574,0);
INSERT INTO "django_geo_db_location" VALUES(53337,NULL,'Ohiowa, NE',22470,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53338,NULL,'Ohiowa, NE 68416',22470,222,NULL,27,30575,0);
INSERT INTO "django_geo_db_location" VALUES(53339,NULL,'Otoe, NE',22471,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53340,NULL,'Otoe, NE 68417',22471,222,NULL,27,30576,0);
INSERT INTO "django_geo_db_location" VALUES(53341,NULL,'Palmyra, NE',22472,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53342,NULL,'Palmyra, NE 68418',22472,222,NULL,27,30577,0);
INSERT INTO "django_geo_db_location" VALUES(53343,NULL,'Panama, NE',22473,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53344,NULL,'Panama, NE 68419',22473,222,NULL,27,30578,0);
INSERT INTO "django_geo_db_location" VALUES(53345,NULL,'Pawnee City, NE',22474,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53346,NULL,'Pawnee City, NE 68420',22474,222,NULL,27,30579,0);
INSERT INTO "django_geo_db_location" VALUES(53347,NULL,'Peru, NE',22475,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53348,NULL,'Peru, NE 68421',22475,222,NULL,27,30580,0);
INSERT INTO "django_geo_db_location" VALUES(53349,NULL,'Pickrell, NE',22476,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53350,NULL,'Pickrell, NE 68422',22476,222,NULL,27,30581,0);
INSERT INTO "django_geo_db_location" VALUES(53351,NULL,'Pleasant Dale, NE',22477,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53352,NULL,'Pleasant Dale, NE 68423',22477,222,NULL,27,30582,0);
INSERT INTO "django_geo_db_location" VALUES(53353,NULL,'Plymouth, NE',22478,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53354,NULL,'Plymouth, NE 68424',22478,222,NULL,27,30583,0);
INSERT INTO "django_geo_db_location" VALUES(53355,NULL,'Raymond, NE',22479,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53356,NULL,'Raymond, NE 68428',22479,222,NULL,27,30584,0);
INSERT INTO "django_geo_db_location" VALUES(53357,NULL,'Reynolds, NE',22480,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53358,NULL,'Reynolds, NE 68429',22480,222,NULL,27,30585,0);
INSERT INTO "django_geo_db_location" VALUES(53359,NULL,'Roca, NE',22481,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53360,NULL,'Roca, NE 68430',22481,222,NULL,27,30586,0);
INSERT INTO "django_geo_db_location" VALUES(53361,NULL,'Rulo, NE',22482,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53362,NULL,'Rulo, NE 68431',22482,222,NULL,27,30587,0);
INSERT INTO "django_geo_db_location" VALUES(53363,NULL,'Salem, NE',22483,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53364,NULL,'Salem, NE 68433',22483,222,NULL,27,30588,0);
INSERT INTO "django_geo_db_location" VALUES(53365,NULL,'Seward, NE',22484,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53366,NULL,'Seward, NE 68434',22484,222,NULL,27,30589,0);
INSERT INTO "django_geo_db_location" VALUES(53367,NULL,'Shickley, NE',22485,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53368,NULL,'Shickley, NE 68436',22485,222,NULL,27,30590,0);
INSERT INTO "django_geo_db_location" VALUES(53369,NULL,'Shubert, NE',22486,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53370,NULL,'Shubert, NE 68437',22486,222,NULL,27,30591,0);
INSERT INTO "django_geo_db_location" VALUES(53371,NULL,'Sprague, NE',22487,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53372,NULL,'Sprague, NE 68438',22487,222,NULL,27,30592,0);
INSERT INTO "django_geo_db_location" VALUES(53373,NULL,'Staplehurst, NE',22488,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53374,NULL,'Staplehurst, NE 68439',22488,222,NULL,27,30593,0);
INSERT INTO "django_geo_db_location" VALUES(53375,NULL,'Steele City, NE',22489,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53376,NULL,'Steele City, NE 68440',22489,222,NULL,27,30594,0);
INSERT INTO "django_geo_db_location" VALUES(53377,NULL,'Steinauer, NE',22490,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53378,NULL,'Steinauer, NE 68441',22490,222,NULL,27,30595,0);
INSERT INTO "django_geo_db_location" VALUES(53379,NULL,'Stella, NE',22491,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53380,NULL,'Stella, NE 68442',22491,222,NULL,27,30596,0);
INSERT INTO "django_geo_db_location" VALUES(53381,NULL,'Sterling, NE',22492,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53382,NULL,'Sterling, NE 68443',22492,222,NULL,27,30597,0);
INSERT INTO "django_geo_db_location" VALUES(53383,NULL,'Strang, NE',22493,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53384,NULL,'Strang, NE 68444',22493,222,NULL,27,30598,0);
INSERT INTO "django_geo_db_location" VALUES(53385,NULL,'Swanton, NE',22494,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53386,NULL,'Swanton, NE 68445',22494,222,NULL,27,30599,0);
INSERT INTO "django_geo_db_location" VALUES(53387,NULL,'Syracuse, NE',22495,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53388,NULL,'Syracuse, NE 68446',22495,222,NULL,27,30600,0);
INSERT INTO "django_geo_db_location" VALUES(53389,NULL,'Table Rock, NE',22496,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53390,NULL,'Table Rock, NE 68447',22496,222,NULL,27,30601,0);
INSERT INTO "django_geo_db_location" VALUES(53391,NULL,'Talmage, NE',22497,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53392,NULL,'Talmage, NE 68448',22497,222,NULL,27,30602,0);
INSERT INTO "django_geo_db_location" VALUES(53393,NULL,'Tecumseh, NE',22498,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53394,NULL,'Tecumseh, NE 68450',22498,222,NULL,27,30603,0);
INSERT INTO "django_geo_db_location" VALUES(53395,NULL,'Ong, NE',22499,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53396,NULL,'Ong, NE 68452',22499,222,NULL,27,30604,0);
INSERT INTO "django_geo_db_location" VALUES(53397,NULL,'Tobias, NE',22500,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53398,NULL,'Tobias, NE 68453',22500,222,NULL,27,30605,0);
INSERT INTO "django_geo_db_location" VALUES(53399,NULL,'Unadilla, NE',22501,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53400,NULL,'Unadilla, NE 68454',22501,222,NULL,27,30606,0);
INSERT INTO "django_geo_db_location" VALUES(53401,NULL,'Union, NE',22502,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53402,NULL,'Union, NE 68455',22502,222,NULL,27,30607,0);
INSERT INTO "django_geo_db_location" VALUES(53403,NULL,'Utica, NE',22503,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53404,NULL,'Utica, NE 68456',22503,222,NULL,27,30608,0);
INSERT INTO "django_geo_db_location" VALUES(53405,NULL,'Verdon, NE',22504,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53406,NULL,'Verdon, NE 68457',22504,222,NULL,27,30609,0);
INSERT INTO "django_geo_db_location" VALUES(53407,NULL,'Virginia, NE',22505,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53408,NULL,'Virginia, NE 68458',22505,222,NULL,27,30610,0);
INSERT INTO "django_geo_db_location" VALUES(53409,NULL,'Waco, NE',22506,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53410,NULL,'Waco, NE 68460',22506,222,NULL,27,30611,0);
INSERT INTO "django_geo_db_location" VALUES(53411,NULL,'Walton, NE',22507,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53412,NULL,'Walton, NE 68461',22507,222,NULL,27,30612,0);
INSERT INTO "django_geo_db_location" VALUES(53413,NULL,'Waverly, NE',22508,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53414,NULL,'Waverly, NE 68462',22508,222,NULL,27,30613,0);
INSERT INTO "django_geo_db_location" VALUES(53415,NULL,'Weeping Water, NE',22509,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53416,NULL,'Weeping Water, NE 68463',22509,222,NULL,27,30614,0);
INSERT INTO "django_geo_db_location" VALUES(53417,NULL,'Western, NE',22510,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53418,NULL,'Western, NE 68464',22510,222,NULL,27,30615,0);
INSERT INTO "django_geo_db_location" VALUES(53419,NULL,'Wilber, NE',22511,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53420,NULL,'Wilber, NE 68465',22511,222,NULL,27,30616,0);
INSERT INTO "django_geo_db_location" VALUES(53421,NULL,'Wymore, NE',22512,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53422,NULL,'Wymore, NE 68466',22512,222,NULL,27,30617,0);
INSERT INTO "django_geo_db_location" VALUES(53423,NULL,'York, NE',22513,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53424,NULL,'York, NE 68467',22513,222,NULL,27,30618,0);
INSERT INTO "django_geo_db_location" VALUES(53425,NULL,'Lincoln, NE',22514,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53426,NULL,'Lincoln, NE 68501',22514,222,NULL,27,30619,0);
INSERT INTO "django_geo_db_location" VALUES(53427,NULL,'Lincoln, NE 68502',22514,222,NULL,27,30620,0);
INSERT INTO "django_geo_db_location" VALUES(53428,NULL,'Lincoln, NE 68503',22514,222,NULL,27,30621,0);
INSERT INTO "django_geo_db_location" VALUES(53429,NULL,'Lincoln, NE 68504',22514,222,NULL,27,30622,0);
INSERT INTO "django_geo_db_location" VALUES(53430,NULL,'Lincoln, NE 68505',22514,222,NULL,27,30623,0);
INSERT INTO "django_geo_db_location" VALUES(53431,NULL,'Lincoln, NE 68506',22514,222,NULL,27,30624,0);
INSERT INTO "django_geo_db_location" VALUES(53432,NULL,'Lincoln, NE 68507',22514,222,NULL,27,30625,0);
INSERT INTO "django_geo_db_location" VALUES(53433,NULL,'Lincoln, NE 68508',22514,222,NULL,27,30626,0);
INSERT INTO "django_geo_db_location" VALUES(53434,NULL,'Lincoln, NE 68509',22514,222,NULL,27,30627,0);
INSERT INTO "django_geo_db_location" VALUES(53435,NULL,'Lincoln, NE 68510',22514,222,NULL,27,30628,0);
INSERT INTO "django_geo_db_location" VALUES(53436,NULL,'Lincoln, NE 68512',22514,222,NULL,27,30629,0);
INSERT INTO "django_geo_db_location" VALUES(53437,NULL,'Lincoln, NE 68514',22514,222,NULL,27,30630,0);
INSERT INTO "django_geo_db_location" VALUES(53438,NULL,'Lincoln, NE 68516',22514,222,NULL,27,30631,0);
INSERT INTO "django_geo_db_location" VALUES(53439,NULL,'Lincoln, NE 68517',22514,222,NULL,27,30632,0);
INSERT INTO "django_geo_db_location" VALUES(53440,NULL,'Lincoln, NE 68520',22514,222,NULL,27,30633,0);
INSERT INTO "django_geo_db_location" VALUES(53441,NULL,'Lincoln, NE 68521',22514,222,NULL,27,30634,0);
INSERT INTO "django_geo_db_location" VALUES(53442,NULL,'Lincoln, NE 68522',22514,222,NULL,27,30635,0);
INSERT INTO "django_geo_db_location" VALUES(53443,NULL,'Lincoln, NE 68523',22514,222,NULL,27,30636,0);
INSERT INTO "django_geo_db_location" VALUES(53444,NULL,'Lincoln, NE 68524',22514,222,NULL,27,30637,0);
INSERT INTO "django_geo_db_location" VALUES(53445,NULL,'Lincoln, NE 68526',22514,222,NULL,27,30638,0);
INSERT INTO "django_geo_db_location" VALUES(53446,NULL,'Lincoln, NE 68527',22514,222,NULL,27,30639,0);
INSERT INTO "django_geo_db_location" VALUES(53447,NULL,'Lincoln, NE 68528',22514,222,NULL,27,30640,0);
INSERT INTO "django_geo_db_location" VALUES(53448,NULL,'Lincoln, NE 68529',22514,222,NULL,27,30641,0);
INSERT INTO "django_geo_db_location" VALUES(53449,NULL,'Lincoln, NE 68531',22514,222,NULL,27,30642,0);
INSERT INTO "django_geo_db_location" VALUES(53450,NULL,'Lincoln, NE 68532',22514,222,NULL,27,30643,0);
INSERT INTO "django_geo_db_location" VALUES(53451,NULL,'Lincoln, NE 68542',22514,222,NULL,27,30644,0);
INSERT INTO "django_geo_db_location" VALUES(53452,NULL,'Lincoln, NE 68544',22514,222,NULL,27,30645,0);
INSERT INTO "django_geo_db_location" VALUES(53453,NULL,'Lincoln, NE 68572',22514,222,NULL,27,30646,0);
INSERT INTO "django_geo_db_location" VALUES(53454,NULL,'Lincoln, NE 68583',22514,222,NULL,27,30647,0);
INSERT INTO "django_geo_db_location" VALUES(53455,NULL,'Lincoln, NE 68588',22514,222,NULL,27,30648,0);
INSERT INTO "django_geo_db_location" VALUES(53456,NULL,'Columbus, NE',22515,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53457,NULL,'Columbus, NE 68601',22515,222,NULL,27,30649,0);
INSERT INTO "django_geo_db_location" VALUES(53458,NULL,'Columbus, NE 68602',22515,222,NULL,27,30650,0);
INSERT INTO "django_geo_db_location" VALUES(53459,NULL,'Albion, NE',22516,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53460,NULL,'Albion, NE 68620',22516,222,NULL,27,30651,0);
INSERT INTO "django_geo_db_location" VALUES(53461,NULL,'Ames, NE',22517,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53462,NULL,'Ames, NE 68621',22517,222,NULL,27,30652,0);
INSERT INTO "django_geo_db_location" VALUES(53463,NULL,'Bartlett, NE',22518,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53464,NULL,'Bartlett, NE 68622',22518,222,NULL,27,30653,0);
INSERT INTO "django_geo_db_location" VALUES(53465,NULL,'Belgrade, NE',22519,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53466,NULL,'Belgrade, NE 68623',22519,222,NULL,27,30654,0);
INSERT INTO "django_geo_db_location" VALUES(53467,NULL,'Bellwood, NE',22520,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53468,NULL,'Bellwood, NE 68624',22520,222,NULL,27,30655,0);
INSERT INTO "django_geo_db_location" VALUES(53469,NULL,'Brainard, NE',22521,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53470,NULL,'Brainard, NE 68626',22521,222,NULL,27,30656,0);
INSERT INTO "django_geo_db_location" VALUES(53471,NULL,'Cedar Rapids, NE',22522,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53472,NULL,'Cedar Rapids, NE 68627',22522,222,NULL,27,30657,0);
INSERT INTO "django_geo_db_location" VALUES(53473,NULL,'Clarks, NE',22523,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53474,NULL,'Clarks, NE 68628',22523,222,NULL,27,30658,0);
INSERT INTO "django_geo_db_location" VALUES(53475,NULL,'Clarkson, NE',22524,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53476,NULL,'Clarkson, NE 68629',22524,222,NULL,27,30659,0);
INSERT INTO "django_geo_db_location" VALUES(53477,NULL,'Creston, NE',22525,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53478,NULL,'Creston, NE 68631',22525,222,NULL,27,30660,0);
INSERT INTO "django_geo_db_location" VALUES(53479,NULL,'David City, NE',22526,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53480,NULL,'David City, NE 68632',22526,222,NULL,27,30661,0);
INSERT INTO "django_geo_db_location" VALUES(53481,NULL,'Dodge, NE',22527,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53482,NULL,'Dodge, NE 68633',22527,222,NULL,27,30662,0);
INSERT INTO "django_geo_db_location" VALUES(53483,NULL,'Duncan, NE',22528,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53484,NULL,'Duncan, NE 68634',22528,222,NULL,27,30663,0);
INSERT INTO "django_geo_db_location" VALUES(53485,NULL,'Dwight, NE',22529,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53486,NULL,'Dwight, NE 68635',22529,222,NULL,27,30664,0);
INSERT INTO "django_geo_db_location" VALUES(53487,NULL,'Elgin, NE',22530,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53488,NULL,'Elgin, NE 68636',22530,222,NULL,27,30665,0);
INSERT INTO "django_geo_db_location" VALUES(53489,NULL,'Ericson, NE',22531,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53490,NULL,'Ericson, NE 68637',22531,222,NULL,27,30666,0);
INSERT INTO "django_geo_db_location" VALUES(53491,NULL,'Fullerton, NE',22532,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53492,NULL,'Fullerton, NE 68638',22532,222,NULL,27,30667,0);
INSERT INTO "django_geo_db_location" VALUES(53493,NULL,'Genoa, NE',22533,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53494,NULL,'Genoa, NE 68640',22533,222,NULL,27,30668,0);
INSERT INTO "django_geo_db_location" VALUES(53495,NULL,'Howells, NE',22534,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53496,NULL,'Howells, NE 68641',22534,222,NULL,27,30669,0);
INSERT INTO "django_geo_db_location" VALUES(53497,NULL,'Humphrey, NE',22535,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53498,NULL,'Humphrey, NE 68642',22535,222,NULL,27,30670,0);
INSERT INTO "django_geo_db_location" VALUES(53499,NULL,'Leigh, NE',22536,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53500,NULL,'Leigh, NE 68643',22536,222,NULL,27,30671,0);
INSERT INTO "django_geo_db_location" VALUES(53501,NULL,'Lindsay, NE',22537,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53502,NULL,'Lindsay, NE 68644',22537,222,NULL,27,30672,0);
INSERT INTO "django_geo_db_location" VALUES(53503,NULL,'Monroe, NE',22538,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53504,NULL,'Monroe, NE 68647',22538,222,NULL,27,30673,0);
INSERT INTO "django_geo_db_location" VALUES(53505,NULL,'Morse Bluff, NE',22539,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53506,NULL,'Morse Bluff, NE 68648',22539,222,NULL,27,30674,0);
INSERT INTO "django_geo_db_location" VALUES(53507,NULL,'North Bend, NE',22540,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53508,NULL,'North Bend, NE 68649',22540,222,NULL,27,30675,0);
INSERT INTO "django_geo_db_location" VALUES(53509,NULL,'Osceola, NE',22541,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53510,NULL,'Osceola, NE 68651',22541,222,NULL,27,30676,0);
INSERT INTO "django_geo_db_location" VALUES(53511,NULL,'Petersburg, NE',22542,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53512,NULL,'Petersburg, NE 68652',22542,222,NULL,27,30677,0);
INSERT INTO "django_geo_db_location" VALUES(53513,NULL,'Platte Center, NE',22543,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53514,NULL,'Platte Center, NE 68653',22543,222,NULL,27,30678,0);
INSERT INTO "django_geo_db_location" VALUES(53515,NULL,'Polk, NE',22544,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53516,NULL,'Polk, NE 68654',22544,222,NULL,27,30679,0);
INSERT INTO "django_geo_db_location" VALUES(53517,NULL,'Primrose, NE',22545,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53518,NULL,'Primrose, NE 68655',22545,222,NULL,27,30680,0);
INSERT INTO "django_geo_db_location" VALUES(53519,NULL,'Rising City, NE',22546,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53520,NULL,'Rising City, NE 68658',22546,222,NULL,27,30681,0);
INSERT INTO "django_geo_db_location" VALUES(53521,NULL,'Rogers, NE',22547,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53522,NULL,'Rogers, NE 68659',22547,222,NULL,27,30682,0);
INSERT INTO "django_geo_db_location" VALUES(53523,NULL,'Saint Edward, NE',22548,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53524,NULL,'Saint Edward, NE 68660',22548,222,NULL,27,30683,0);
INSERT INTO "django_geo_db_location" VALUES(53525,NULL,'Schuyler, NE',22549,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53526,NULL,'Schuyler, NE 68661',22549,222,NULL,27,30684,0);
INSERT INTO "django_geo_db_location" VALUES(53527,NULL,'Shelby, NE',22550,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53528,NULL,'Shelby, NE 68662',22550,222,NULL,27,30685,0);
INSERT INTO "django_geo_db_location" VALUES(53529,NULL,'Silver Creek, NE',22551,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53530,NULL,'Silver Creek, NE 68663',22551,222,NULL,27,30686,0);
INSERT INTO "django_geo_db_location" VALUES(53531,NULL,'Snyder, NE',22552,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53532,NULL,'Snyder, NE 68664',22552,222,NULL,27,30687,0);
INSERT INTO "django_geo_db_location" VALUES(53533,NULL,'Spalding, NE',22553,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53534,NULL,'Spalding, NE 68665',22553,222,NULL,27,30688,0);
INSERT INTO "django_geo_db_location" VALUES(53535,NULL,'Stromsburg, NE',22554,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53536,NULL,'Stromsburg, NE 68666',22554,222,NULL,27,30689,0);
INSERT INTO "django_geo_db_location" VALUES(53537,NULL,'Surprise, NE',22555,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53538,NULL,'Surprise, NE 68667',22555,222,NULL,27,30690,0);
INSERT INTO "django_geo_db_location" VALUES(53539,NULL,'Ulysses, NE',22556,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53540,NULL,'Ulysses, NE 68669',22556,222,NULL,27,30691,0);
INSERT INTO "django_geo_db_location" VALUES(53541,NULL,'Norfolk, NE',22557,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53542,NULL,'Norfolk, NE 68701',22557,222,NULL,27,30692,0);
INSERT INTO "django_geo_db_location" VALUES(53543,NULL,'Norfolk, NE 68702',22557,222,NULL,27,30693,0);
INSERT INTO "django_geo_db_location" VALUES(53544,NULL,'Allen, NE',22558,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53545,NULL,'Allen, NE 68710',22558,222,NULL,27,30694,0);
INSERT INTO "django_geo_db_location" VALUES(53546,NULL,'Amelia, NE',22559,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53547,NULL,'Amelia, NE 68711',22559,222,NULL,27,30695,0);
INSERT INTO "django_geo_db_location" VALUES(53548,NULL,'Atkinson, NE',22560,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53549,NULL,'Atkinson, NE 68713',22560,222,NULL,27,30696,0);
INSERT INTO "django_geo_db_location" VALUES(53550,NULL,'Bassett, NE',22561,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53551,NULL,'Bassett, NE 68714',22561,222,NULL,27,30697,0);
INSERT INTO "django_geo_db_location" VALUES(53552,NULL,'Battle Creek, NE',22562,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53553,NULL,'Battle Creek, NE 68715',22562,222,NULL,27,30698,0);
INSERT INTO "django_geo_db_location" VALUES(53554,NULL,'Beemer, NE',22563,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53555,NULL,'Beemer, NE 68716',22563,222,NULL,27,30699,0);
INSERT INTO "django_geo_db_location" VALUES(53556,NULL,'Belden, NE',22564,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53557,NULL,'Belden, NE 68717',22564,222,NULL,27,30700,0);
INSERT INTO "django_geo_db_location" VALUES(53558,NULL,'Bloomfield, NE',22565,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53559,NULL,'Bloomfield, NE 68718',22565,222,NULL,27,30701,0);
INSERT INTO "django_geo_db_location" VALUES(53560,NULL,'Bristow, NE',22566,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53561,NULL,'Bristow, NE 68719',22566,222,NULL,27,30702,0);
INSERT INTO "django_geo_db_location" VALUES(53562,NULL,'Brunswick, NE',22567,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53563,NULL,'Brunswick, NE 68720',22567,222,NULL,27,30703,0);
INSERT INTO "django_geo_db_location" VALUES(53564,NULL,'Butte, NE',22568,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53565,NULL,'Butte, NE 68722',22568,222,NULL,27,30704,0);
INSERT INTO "django_geo_db_location" VALUES(53566,NULL,'Carroll, NE',22569,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53567,NULL,'Carroll, NE 68723',22569,222,NULL,27,30705,0);
INSERT INTO "django_geo_db_location" VALUES(53568,NULL,'Center, NE',22570,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53569,NULL,'Center, NE 68724',22570,222,NULL,27,30706,0);
INSERT INTO "django_geo_db_location" VALUES(53570,NULL,'Chambers, NE',22571,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53571,NULL,'Chambers, NE 68725',22571,222,NULL,27,30707,0);
INSERT INTO "django_geo_db_location" VALUES(53572,NULL,'Clearwater, NE',22572,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53573,NULL,'Clearwater, NE 68726',22572,222,NULL,27,30708,0);
INSERT INTO "django_geo_db_location" VALUES(53574,NULL,'Coleridge, NE',22573,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53575,NULL,'Coleridge, NE 68727',22573,222,NULL,27,30709,0);
INSERT INTO "django_geo_db_location" VALUES(53576,NULL,'Concord, NE',22574,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53577,NULL,'Concord, NE 68728',22574,222,NULL,27,30710,0);
INSERT INTO "django_geo_db_location" VALUES(53578,NULL,'Creighton, NE',22575,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53579,NULL,'Creighton, NE 68729',22575,222,NULL,27,30711,0);
INSERT INTO "django_geo_db_location" VALUES(53580,NULL,'Crofton, NE',22576,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53581,NULL,'Crofton, NE 68730',22576,222,NULL,27,30712,0);
INSERT INTO "django_geo_db_location" VALUES(53582,NULL,'Dakota City, NE',22577,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53583,NULL,'Dakota City, NE 68731',22577,222,NULL,27,30713,0);
INSERT INTO "django_geo_db_location" VALUES(53584,NULL,'Dixon, NE',22578,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53585,NULL,'Dixon, NE 68732',22578,222,NULL,27,30714,0);
INSERT INTO "django_geo_db_location" VALUES(53586,NULL,'Emerson, NE',22579,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53587,NULL,'Emerson, NE 68733',22579,222,NULL,27,30715,0);
INSERT INTO "django_geo_db_location" VALUES(53588,NULL,'Emmet, NE',22580,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53589,NULL,'Emmet, NE 68734',22580,222,NULL,27,30716,0);
INSERT INTO "django_geo_db_location" VALUES(53590,NULL,'Ewing, NE',22581,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53591,NULL,'Ewing, NE 68735',22581,222,NULL,27,30717,0);
INSERT INTO "django_geo_db_location" VALUES(53592,NULL,'Fordyce, NE',22582,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53593,NULL,'Fordyce, NE 68736',22582,222,NULL,27,30718,0);
INSERT INTO "django_geo_db_location" VALUES(53594,NULL,'Foster, NE',22583,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53595,NULL,'Foster, NE 68737',22583,222,NULL,27,30719,0);
INSERT INTO "django_geo_db_location" VALUES(53596,NULL,'Hadar, NE',22584,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53597,NULL,'Hadar, NE 68738',22584,222,NULL,27,30720,0);
INSERT INTO "django_geo_db_location" VALUES(53598,NULL,'Hartington, NE',22585,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53599,NULL,'Hartington, NE 68739',22585,222,NULL,27,30721,0);
INSERT INTO "django_geo_db_location" VALUES(53600,NULL,'Hoskins, NE',22586,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53601,NULL,'Hoskins, NE 68740',22586,222,NULL,27,30722,0);
INSERT INTO "django_geo_db_location" VALUES(53602,NULL,'Hubbard, NE',22587,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53603,NULL,'Hubbard, NE 68741',22587,222,NULL,27,30723,0);
INSERT INTO "django_geo_db_location" VALUES(53604,NULL,'Inman, NE',22588,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53605,NULL,'Inman, NE 68742',22588,222,NULL,27,30724,0);
INSERT INTO "django_geo_db_location" VALUES(53606,NULL,'Jackson, NE',22589,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53607,NULL,'Jackson, NE 68743',22589,222,NULL,27,30725,0);
INSERT INTO "django_geo_db_location" VALUES(53608,NULL,'Laurel, NE',22590,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53609,NULL,'Laurel, NE 68745',22590,222,NULL,27,30726,0);
INSERT INTO "django_geo_db_location" VALUES(53610,NULL,'Lynch, NE',22591,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53611,NULL,'Lynch, NE 68746',22591,222,NULL,27,30727,0);
INSERT INTO "django_geo_db_location" VALUES(53612,NULL,'Mclean, NE',22592,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53613,NULL,'Mclean, NE 68747',22592,222,NULL,27,30728,0);
INSERT INTO "django_geo_db_location" VALUES(53614,NULL,'Madison, NE',22593,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53615,NULL,'Madison, NE 68748',22593,222,NULL,27,30729,0);
INSERT INTO "django_geo_db_location" VALUES(53616,NULL,'Magnet, NE',22594,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53617,NULL,'Magnet, NE 68749',22594,222,NULL,27,30730,0);
INSERT INTO "django_geo_db_location" VALUES(53618,NULL,'Maskell, NE',22595,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53619,NULL,'Maskell, NE 68751',22595,222,NULL,27,30731,0);
INSERT INTO "django_geo_db_location" VALUES(53620,NULL,'Meadow Grove, NE',22596,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53621,NULL,'Meadow Grove, NE 68752',22596,222,NULL,27,30732,0);
INSERT INTO "django_geo_db_location" VALUES(53622,NULL,'Mills, NE',22597,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53623,NULL,'Mills, NE 68753',22597,222,NULL,27,30733,0);
INSERT INTO "django_geo_db_location" VALUES(53624,NULL,'Naper, NE',22598,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53625,NULL,'Naper, NE 68755',22598,222,NULL,27,30734,0);
INSERT INTO "django_geo_db_location" VALUES(53626,NULL,'Neligh, NE',22599,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53627,NULL,'Neligh, NE 68756',22599,222,NULL,27,30735,0);
INSERT INTO "django_geo_db_location" VALUES(53628,NULL,'Newcastle, NE',22600,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53629,NULL,'Newcastle, NE 68757',22600,222,NULL,27,30736,0);
INSERT INTO "django_geo_db_location" VALUES(53630,NULL,'Newman Grove, NE',22601,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53631,NULL,'Newman Grove, NE 68758',22601,222,NULL,27,30737,0);
INSERT INTO "django_geo_db_location" VALUES(53632,NULL,'Newport, NE',22602,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53633,NULL,'Newport, NE 68759',22602,222,NULL,27,30738,0);
INSERT INTO "django_geo_db_location" VALUES(53634,NULL,'Niobrara, NE',22603,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53635,NULL,'Niobrara, NE 68760',22603,222,NULL,27,30739,0);
INSERT INTO "django_geo_db_location" VALUES(53636,NULL,'Oakdale, NE',22604,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53637,NULL,'Oakdale, NE 68761',22604,222,NULL,27,30740,0);
INSERT INTO "django_geo_db_location" VALUES(53638,NULL,'Oneill, NE',22605,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53639,NULL,'Oneill, NE 68763',22605,222,NULL,27,30741,0);
INSERT INTO "django_geo_db_location" VALUES(53640,NULL,'Orchard, NE',22606,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53641,NULL,'Orchard, NE 68764',22606,222,NULL,27,30742,0);
INSERT INTO "django_geo_db_location" VALUES(53642,NULL,'Osmond, NE',22607,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53643,NULL,'Osmond, NE 68765',22607,222,NULL,27,30743,0);
INSERT INTO "django_geo_db_location" VALUES(53644,NULL,'Page, NE',22608,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53645,NULL,'Page, NE 68766',22608,222,NULL,27,30744,0);
INSERT INTO "django_geo_db_location" VALUES(53646,NULL,'Pierce, NE',22609,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53647,NULL,'Pierce, NE 68767',22609,222,NULL,27,30745,0);
INSERT INTO "django_geo_db_location" VALUES(53648,NULL,'Pilger, NE',22610,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53649,NULL,'Pilger, NE 68768',22610,222,NULL,27,30746,0);
INSERT INTO "django_geo_db_location" VALUES(53650,NULL,'Plainview, NE',22611,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53651,NULL,'Plainview, NE 68769',22611,222,NULL,27,30747,0);
INSERT INTO "django_geo_db_location" VALUES(53652,NULL,'Ponca, NE',22612,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53653,NULL,'Ponca, NE 68770',22612,222,NULL,27,30748,0);
INSERT INTO "django_geo_db_location" VALUES(53654,NULL,'Randolph, NE',22613,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53655,NULL,'Randolph, NE 68771',22613,222,NULL,27,30749,0);
INSERT INTO "django_geo_db_location" VALUES(53656,NULL,'Rose, NE',22614,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53657,NULL,'Rose, NE 68772',22614,222,NULL,27,30750,0);
INSERT INTO "django_geo_db_location" VALUES(53658,NULL,'Royal, NE',22615,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53659,NULL,'Royal, NE 68773',22615,222,NULL,27,30751,0);
INSERT INTO "django_geo_db_location" VALUES(53660,NULL,'Saint Helena, NE',22616,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53661,NULL,'Saint Helena, NE 68774',22616,222,NULL,27,30752,0);
INSERT INTO "django_geo_db_location" VALUES(53662,NULL,'South Sioux City, NE',22617,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53663,NULL,'South Sioux City, NE 68776',22617,222,NULL,27,30753,0);
INSERT INTO "django_geo_db_location" VALUES(53664,NULL,'Spencer, NE',22618,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53665,NULL,'Spencer, NE 68777',22618,222,NULL,27,30754,0);
INSERT INTO "django_geo_db_location" VALUES(53666,NULL,'Springview, NE',22619,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53667,NULL,'Springview, NE 68778',22619,222,NULL,27,30755,0);
INSERT INTO "django_geo_db_location" VALUES(53668,NULL,'Stanton, NE',22620,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53669,NULL,'Stanton, NE 68779',22620,222,NULL,27,30756,0);
INSERT INTO "django_geo_db_location" VALUES(53670,NULL,'Stuart, NE',22621,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53671,NULL,'Stuart, NE 68780',22621,222,NULL,27,30757,0);
INSERT INTO "django_geo_db_location" VALUES(53672,NULL,'Tilden, NE',22622,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53673,NULL,'Tilden, NE 68781',22622,222,NULL,27,30758,0);
INSERT INTO "django_geo_db_location" VALUES(53674,NULL,'Verdel, NE',22623,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53675,NULL,'Verdel, NE 68782',22623,222,NULL,27,30759,0);
INSERT INTO "django_geo_db_location" VALUES(53676,NULL,'Verdigre, NE',22624,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53677,NULL,'Verdigre, NE 68783',22624,222,NULL,27,30760,0);
INSERT INTO "django_geo_db_location" VALUES(53678,NULL,'Wakefield, NE',22625,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53679,NULL,'Wakefield, NE 68784',22625,222,NULL,27,30761,0);
INSERT INTO "django_geo_db_location" VALUES(53680,NULL,'Waterbury, NE',22626,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53681,NULL,'Waterbury, NE 68785',22626,222,NULL,27,30762,0);
INSERT INTO "django_geo_db_location" VALUES(53682,NULL,'Wausa, NE',22627,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53683,NULL,'Wausa, NE 68786',22627,222,NULL,27,30763,0);
INSERT INTO "django_geo_db_location" VALUES(53684,NULL,'Wayne, NE',22628,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53685,NULL,'Wayne, NE 68787',22628,222,NULL,27,30764,0);
INSERT INTO "django_geo_db_location" VALUES(53686,NULL,'West Point, NE',22629,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53687,NULL,'West Point, NE 68788',22629,222,NULL,27,30765,0);
INSERT INTO "django_geo_db_location" VALUES(53688,NULL,'Winnetoon, NE',22630,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53689,NULL,'Winnetoon, NE 68789',22630,222,NULL,27,30766,0);
INSERT INTO "django_geo_db_location" VALUES(53690,NULL,'Winside, NE',22631,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53691,NULL,'Winside, NE 68790',22631,222,NULL,27,30767,0);
INSERT INTO "django_geo_db_location" VALUES(53692,NULL,'Wisner, NE',22632,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53693,NULL,'Wisner, NE 68791',22632,222,NULL,27,30768,0);
INSERT INTO "django_geo_db_location" VALUES(53694,NULL,'Wynot, NE',22633,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53695,NULL,'Wynot, NE 68792',22633,222,NULL,27,30769,0);
INSERT INTO "django_geo_db_location" VALUES(53696,NULL,'Sutton, NE',22634,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53697,NULL,'Sutton, NE 68797',22634,222,NULL,27,30770,0);
INSERT INTO "django_geo_db_location" VALUES(53698,NULL,'Grand Island, NE',22635,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53699,NULL,'Grand Island, NE 68801',22635,222,NULL,27,30771,0);
INSERT INTO "django_geo_db_location" VALUES(53700,NULL,'Grand Island, NE 68802',22635,222,NULL,27,30772,0);
INSERT INTO "django_geo_db_location" VALUES(53701,NULL,'Grand Island, NE 68803',22635,222,NULL,27,30773,0);
INSERT INTO "django_geo_db_location" VALUES(53702,NULL,'Alda, NE',22636,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53703,NULL,'Alda, NE 68810',22636,222,NULL,27,30774,0);
INSERT INTO "django_geo_db_location" VALUES(53704,NULL,'Amherst, NE',22637,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53705,NULL,'Amherst, NE 68812',22637,222,NULL,27,30775,0);
INSERT INTO "django_geo_db_location" VALUES(53706,NULL,'Anselmo, NE',22638,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53707,NULL,'Anselmo, NE 68813',22638,222,NULL,27,30776,0);
INSERT INTO "django_geo_db_location" VALUES(53708,NULL,'Ansley, NE',22639,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53709,NULL,'Ansley, NE 68814',22639,222,NULL,27,30777,0);
INSERT INTO "django_geo_db_location" VALUES(53710,NULL,'Arcadia, NE',22640,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53711,NULL,'Arcadia, NE 68815',22640,222,NULL,27,30778,0);
INSERT INTO "django_geo_db_location" VALUES(53712,NULL,'Archer, NE',22641,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53713,NULL,'Archer, NE 68816',22641,222,NULL,27,30779,0);
INSERT INTO "django_geo_db_location" VALUES(53714,NULL,'Ashton, NE',22642,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53715,NULL,'Ashton, NE 68817',22642,222,NULL,27,30780,0);
INSERT INTO "django_geo_db_location" VALUES(53716,NULL,'Aurora, NE',22643,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53717,NULL,'Aurora, NE 68818',22643,222,NULL,27,30781,0);
INSERT INTO "django_geo_db_location" VALUES(53718,NULL,'Berwyn, NE',22644,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53719,NULL,'Berwyn, NE 68819',22644,222,NULL,27,30782,0);
INSERT INTO "django_geo_db_location" VALUES(53720,NULL,'Boelus, NE',22645,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53721,NULL,'Boelus, NE 68820',22645,222,NULL,27,30783,0);
INSERT INTO "django_geo_db_location" VALUES(53722,NULL,'Brewster, NE',22646,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53723,NULL,'Brewster, NE 68821',22646,222,NULL,27,30784,0);
INSERT INTO "django_geo_db_location" VALUES(53724,NULL,'Broken Bow, NE',22647,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53725,NULL,'Broken Bow, NE 68822',22647,222,NULL,27,30785,0);
INSERT INTO "django_geo_db_location" VALUES(53726,NULL,'Burwell, NE',22648,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53727,NULL,'Burwell, NE 68823',22648,222,NULL,27,30786,0);
INSERT INTO "django_geo_db_location" VALUES(53728,NULL,'Cairo, NE',22649,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53729,NULL,'Cairo, NE 68824',22649,222,NULL,27,30787,0);
INSERT INTO "django_geo_db_location" VALUES(53730,NULL,'Callaway, NE',22650,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53731,NULL,'Callaway, NE 68825',22650,222,NULL,27,30788,0);
INSERT INTO "django_geo_db_location" VALUES(53732,NULL,'Central City, NE 68826',22387,222,NULL,27,30789,0);
INSERT INTO "django_geo_db_location" VALUES(53733,NULL,'Chapman, NE',22651,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53734,NULL,'Chapman, NE 68827',22651,222,NULL,27,30790,0);
INSERT INTO "django_geo_db_location" VALUES(53735,NULL,'Comstock, NE',22652,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53736,NULL,'Comstock, NE 68828',22652,222,NULL,27,30791,0);
INSERT INTO "django_geo_db_location" VALUES(53737,NULL,'Dannebrog, NE',22653,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53738,NULL,'Dannebrog, NE 68831',22653,222,NULL,27,30792,0);
INSERT INTO "django_geo_db_location" VALUES(53739,NULL,'Doniphan, NE',22654,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53740,NULL,'Doniphan, NE 68832',22654,222,NULL,27,30793,0);
INSERT INTO "django_geo_db_location" VALUES(53741,NULL,'Dunning, NE',22655,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53742,NULL,'Dunning, NE 68833',22655,222,NULL,27,30794,0);
INSERT INTO "django_geo_db_location" VALUES(53743,NULL,'Eddyville, NE',22656,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53744,NULL,'Eddyville, NE 68834',22656,222,NULL,27,30795,0);
INSERT INTO "django_geo_db_location" VALUES(53745,NULL,'Elba, NE',22657,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53746,NULL,'Elba, NE 68835',22657,222,NULL,27,30796,0);
INSERT INTO "django_geo_db_location" VALUES(53747,NULL,'Elm Creek, NE',22658,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53748,NULL,'Elm Creek, NE 68836',22658,222,NULL,27,30797,0);
INSERT INTO "django_geo_db_location" VALUES(53749,NULL,'Elyria, NE',22659,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53750,NULL,'Elyria, NE 68837',22659,222,NULL,27,30798,0);
INSERT INTO "django_geo_db_location" VALUES(53751,NULL,'Farwell, NE',22660,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53752,NULL,'Farwell, NE 68838',22660,222,NULL,27,30799,0);
INSERT INTO "django_geo_db_location" VALUES(53753,NULL,'Gibbon, NE',22661,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53754,NULL,'Gibbon, NE 68840',22661,222,NULL,27,30800,0);
INSERT INTO "django_geo_db_location" VALUES(53755,NULL,'Giltner, NE',22662,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53756,NULL,'Giltner, NE 68841',22662,222,NULL,27,30801,0);
INSERT INTO "django_geo_db_location" VALUES(53757,NULL,'Greeley, NE',22663,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53758,NULL,'Greeley, NE 68842',22663,222,NULL,27,30802,0);
INSERT INTO "django_geo_db_location" VALUES(53759,NULL,'Hampton, NE',22664,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53760,NULL,'Hampton, NE 68843',22664,222,NULL,27,30803,0);
INSERT INTO "django_geo_db_location" VALUES(53761,NULL,'Hazard, NE',22665,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53762,NULL,'Hazard, NE 68844',22665,222,NULL,27,30804,0);
INSERT INTO "django_geo_db_location" VALUES(53763,NULL,'Kearney, NE',22666,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53764,NULL,'Kearney, NE 68845',22666,222,NULL,27,30805,0);
INSERT INTO "django_geo_db_location" VALUES(53765,NULL,'Hordville, NE',22667,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53766,NULL,'Hordville, NE 68846',22667,222,NULL,27,30806,0);
INSERT INTO "django_geo_db_location" VALUES(53767,NULL,'Kearney, NE 68847',22666,222,NULL,27,30807,0);
INSERT INTO "django_geo_db_location" VALUES(53768,NULL,'Kearney, NE 68848',22666,222,NULL,27,30808,0);
INSERT INTO "django_geo_db_location" VALUES(53769,NULL,'Kearney, NE 68849',22666,222,NULL,27,30809,0);
INSERT INTO "django_geo_db_location" VALUES(53770,NULL,'Lexington, NE',22668,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53771,NULL,'Lexington, NE 68850',22668,222,NULL,27,30810,0);
INSERT INTO "django_geo_db_location" VALUES(53772,NULL,'Litchfield, NE',22669,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53773,NULL,'Litchfield, NE 68852',22669,222,NULL,27,30811,0);
INSERT INTO "django_geo_db_location" VALUES(53774,NULL,'Loup City, NE',22670,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53775,NULL,'Loup City, NE 68853',22670,222,NULL,27,30812,0);
INSERT INTO "django_geo_db_location" VALUES(53776,NULL,'Marquette, NE',22671,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53777,NULL,'Marquette, NE 68854',22671,222,NULL,27,30813,0);
INSERT INTO "django_geo_db_location" VALUES(53778,NULL,'Mason City, NE',22672,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53779,NULL,'Mason City, NE 68855',22672,222,NULL,27,30814,0);
INSERT INTO "django_geo_db_location" VALUES(53780,NULL,'Merna, NE',22673,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53781,NULL,'Merna, NE 68856',22673,222,NULL,27,30815,0);
INSERT INTO "django_geo_db_location" VALUES(53782,NULL,'Miller, NE',22674,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53783,NULL,'Miller, NE 68858',22674,222,NULL,27,30816,0);
INSERT INTO "django_geo_db_location" VALUES(53784,NULL,'North Loup, NE',22675,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53785,NULL,'North Loup, NE 68859',22675,222,NULL,27,30817,0);
INSERT INTO "django_geo_db_location" VALUES(53786,NULL,'Oconto, NE',22676,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53787,NULL,'Oconto, NE 68860',22676,222,NULL,27,30818,0);
INSERT INTO "django_geo_db_location" VALUES(53788,NULL,'Odessa, NE',22677,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53789,NULL,'Odessa, NE 68861',22677,222,NULL,27,30819,0);
INSERT INTO "django_geo_db_location" VALUES(53790,NULL,'Ord, NE',22678,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53791,NULL,'Ord, NE 68862',22678,222,NULL,27,30820,0);
INSERT INTO "django_geo_db_location" VALUES(53792,NULL,'Overton, NE',22679,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53793,NULL,'Overton, NE 68863',22679,222,NULL,27,30821,0);
INSERT INTO "django_geo_db_location" VALUES(53794,NULL,'Palmer, NE',22680,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53795,NULL,'Palmer, NE 68864',22680,222,NULL,27,30822,0);
INSERT INTO "django_geo_db_location" VALUES(53796,NULL,'Phillips, NE',22681,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53797,NULL,'Phillips, NE 68865',22681,222,NULL,27,30823,0);
INSERT INTO "django_geo_db_location" VALUES(53798,NULL,'Pleasanton, NE',22682,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53799,NULL,'Pleasanton, NE 68866',22682,222,NULL,27,30824,0);
INSERT INTO "django_geo_db_location" VALUES(53800,NULL,'Martin, NE',22683,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53801,NULL,'Martin, NE 68868',22683,222,NULL,27,30825,0);
INSERT INTO "django_geo_db_location" VALUES(53802,NULL,'Ravenna, NE',22684,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53803,NULL,'Ravenna, NE 68869',22684,222,NULL,27,30826,0);
INSERT INTO "django_geo_db_location" VALUES(53804,NULL,'Riverdale, NE',22685,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53805,NULL,'Riverdale, NE 68870',22685,222,NULL,27,30827,0);
INSERT INTO "django_geo_db_location" VALUES(53806,NULL,'Rockville, NE',22686,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53807,NULL,'Rockville, NE 68871',22686,222,NULL,27,30828,0);
INSERT INTO "django_geo_db_location" VALUES(53808,NULL,'Saint Libory, NE',22687,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53809,NULL,'Saint Libory, NE 68872',22687,222,NULL,27,30829,0);
INSERT INTO "django_geo_db_location" VALUES(53810,NULL,'Saint Paul, NE',22688,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53811,NULL,'Saint Paul, NE 68873',22688,222,NULL,27,30830,0);
INSERT INTO "django_geo_db_location" VALUES(53812,NULL,'Sargent, NE',22689,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53813,NULL,'Sargent, NE 68874',22689,222,NULL,27,30831,0);
INSERT INTO "django_geo_db_location" VALUES(53814,NULL,'Scotia, NE',22690,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53815,NULL,'Scotia, NE 68875',22690,222,NULL,27,30832,0);
INSERT INTO "django_geo_db_location" VALUES(53816,NULL,'Shelton, NE',22691,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53817,NULL,'Shelton, NE 68876',22691,222,NULL,27,30833,0);
INSERT INTO "django_geo_db_location" VALUES(53818,NULL,'Sumner, NE',22692,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53819,NULL,'Sumner, NE 68878',22692,222,NULL,27,30834,0);
INSERT INTO "django_geo_db_location" VALUES(53820,NULL,'Taylor, NE',22693,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53821,NULL,'Taylor, NE 68879',22693,222,NULL,27,30835,0);
INSERT INTO "django_geo_db_location" VALUES(53822,NULL,'Weissert, NE',22694,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53823,NULL,'Weissert, NE 68880',22694,222,NULL,27,30836,0);
INSERT INTO "django_geo_db_location" VALUES(53824,NULL,'Westerville, NE',22695,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53825,NULL,'Westerville, NE 68881',22695,222,NULL,27,30837,0);
INSERT INTO "django_geo_db_location" VALUES(53826,NULL,'Wolbach, NE',22696,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53827,NULL,'Wolbach, NE 68882',22696,222,NULL,27,30838,0);
INSERT INTO "django_geo_db_location" VALUES(53828,NULL,'Wood River, NE',22697,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53829,NULL,'Wood River, NE 68883',22697,222,NULL,27,30839,0);
INSERT INTO "django_geo_db_location" VALUES(53830,NULL,'Hastings, NE',22698,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53831,NULL,'Hastings, NE 68901',22698,222,NULL,27,30840,0);
INSERT INTO "django_geo_db_location" VALUES(53832,NULL,'Hastings, NE 68902',22698,222,NULL,27,30841,0);
INSERT INTO "django_geo_db_location" VALUES(53833,NULL,'Alma, NE',22699,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53834,NULL,'Alma, NE 68920',22699,222,NULL,27,30842,0);
INSERT INTO "django_geo_db_location" VALUES(53835,NULL,'Arapahoe, NE',22700,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53836,NULL,'Arapahoe, NE 68922',22700,222,NULL,27,30843,0);
INSERT INTO "django_geo_db_location" VALUES(53837,NULL,'Atlanta, NE',22701,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53838,NULL,'Atlanta, NE 68923',22701,222,NULL,27,30844,0);
INSERT INTO "django_geo_db_location" VALUES(53839,NULL,'Axtell, NE',22702,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53840,NULL,'Axtell, NE 68924',22702,222,NULL,27,30845,0);
INSERT INTO "django_geo_db_location" VALUES(53841,NULL,'Ayr, NE',22703,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53842,NULL,'Ayr, NE 68925',22703,222,NULL,27,30846,0);
INSERT INTO "django_geo_db_location" VALUES(53843,NULL,'Beaver City, NE',22704,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53844,NULL,'Beaver City, NE 68926',22704,222,NULL,27,30847,0);
INSERT INTO "django_geo_db_location" VALUES(53845,NULL,'Bertrand, NE',22705,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53846,NULL,'Bertrand, NE 68927',22705,222,NULL,27,30848,0);
INSERT INTO "django_geo_db_location" VALUES(53847,NULL,'Bladen, NE',22706,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53848,NULL,'Bladen, NE 68928',22706,222,NULL,27,30849,0);
INSERT INTO "django_geo_db_location" VALUES(53849,NULL,'Bloomington, NE',22707,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53850,NULL,'Bloomington, NE 68929',22707,222,NULL,27,30850,0);
INSERT INTO "django_geo_db_location" VALUES(53851,NULL,'Blue Hill, NE',22708,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53852,NULL,'Blue Hill, NE 68930',22708,222,NULL,27,30851,0);
INSERT INTO "django_geo_db_location" VALUES(53853,NULL,'Campbell, NE',22709,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53854,NULL,'Campbell, NE 68932',22709,222,NULL,27,30852,0);
INSERT INTO "django_geo_db_location" VALUES(53855,NULL,'Clay Center, NE',22710,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53856,NULL,'Clay Center, NE 68933',22710,222,NULL,27,30853,0);
INSERT INTO "django_geo_db_location" VALUES(53857,NULL,'Deweese, NE',22711,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53858,NULL,'Deweese, NE 68934',22711,222,NULL,27,30854,0);
INSERT INTO "django_geo_db_location" VALUES(53859,NULL,'Edgar, NE',22712,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53860,NULL,'Edgar, NE 68935',22712,222,NULL,27,30855,0);
INSERT INTO "django_geo_db_location" VALUES(53861,NULL,'Edison, NE',22713,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53862,NULL,'Edison, NE 68936',22713,222,NULL,27,30856,0);
INSERT INTO "django_geo_db_location" VALUES(53863,NULL,'Elwood, NE',22714,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53864,NULL,'Elwood, NE 68937',22714,222,NULL,27,30857,0);
INSERT INTO "django_geo_db_location" VALUES(53865,NULL,'Fairfield, NE',22715,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53866,NULL,'Fairfield, NE 68938',22715,222,NULL,27,30858,0);
INSERT INTO "django_geo_db_location" VALUES(53867,NULL,'Franklin, NE',22716,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53868,NULL,'Franklin, NE 68939',22716,222,NULL,27,30859,0);
INSERT INTO "django_geo_db_location" VALUES(53869,NULL,'Funk, NE',22717,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53870,NULL,'Funk, NE 68940',22717,222,NULL,27,30860,0);
INSERT INTO "django_geo_db_location" VALUES(53871,NULL,'Glenvil, NE',22718,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53872,NULL,'Glenvil, NE 68941',22718,222,NULL,27,30861,0);
INSERT INTO "django_geo_db_location" VALUES(53873,NULL,'Guide Rock, NE',22719,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53874,NULL,'Guide Rock, NE 68942',22719,222,NULL,27,30862,0);
INSERT INTO "django_geo_db_location" VALUES(53875,NULL,'Hardy, NE',22720,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53876,NULL,'Hardy, NE 68943',22720,222,NULL,27,30863,0);
INSERT INTO "django_geo_db_location" VALUES(53877,NULL,'Harvard, NE',22721,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53878,NULL,'Harvard, NE 68944',22721,222,NULL,27,30864,0);
INSERT INTO "django_geo_db_location" VALUES(53879,NULL,'Heartwell, NE',22722,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53880,NULL,'Heartwell, NE 68945',22722,222,NULL,27,30865,0);
INSERT INTO "django_geo_db_location" VALUES(53881,NULL,'Hendley, NE',22723,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53882,NULL,'Hendley, NE 68946',22723,222,NULL,27,30866,0);
INSERT INTO "django_geo_db_location" VALUES(53883,NULL,'Hildreth, NE',22724,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53884,NULL,'Hildreth, NE 68947',22724,222,NULL,27,30867,0);
INSERT INTO "django_geo_db_location" VALUES(53885,NULL,'Holbrook, NE',22725,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53886,NULL,'Holbrook, NE 68948',22725,222,NULL,27,30868,0);
INSERT INTO "django_geo_db_location" VALUES(53887,NULL,'Holdrege, NE',22726,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53888,NULL,'Holdrege, NE 68949',22726,222,NULL,27,30869,0);
INSERT INTO "django_geo_db_location" VALUES(53889,NULL,'Holstein, NE',22727,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53890,NULL,'Holstein, NE 68950',22727,222,NULL,27,30870,0);
INSERT INTO "django_geo_db_location" VALUES(53891,NULL,'Inavale, NE',22728,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53892,NULL,'Inavale, NE 68952',22728,222,NULL,27,30871,0);
INSERT INTO "django_geo_db_location" VALUES(53893,NULL,'Inland, NE',22729,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53894,NULL,'Inland, NE 68954',22729,222,NULL,27,30872,0);
INSERT INTO "django_geo_db_location" VALUES(53895,NULL,'Juniata, NE',22730,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53896,NULL,'Juniata, NE 68955',22730,222,NULL,27,30873,0);
INSERT INTO "django_geo_db_location" VALUES(53897,NULL,'Kenesaw, NE',22731,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53898,NULL,'Kenesaw, NE 68956',22731,222,NULL,27,30874,0);
INSERT INTO "django_geo_db_location" VALUES(53899,NULL,'Lawrence, NE',22732,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53900,NULL,'Lawrence, NE 68957',22732,222,NULL,27,30875,0);
INSERT INTO "django_geo_db_location" VALUES(53901,NULL,'Loomis, NE',22733,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53902,NULL,'Loomis, NE 68958',22733,222,NULL,27,30876,0);
INSERT INTO "django_geo_db_location" VALUES(53903,NULL,'Minden, NE',22734,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53904,NULL,'Minden, NE 68959',22734,222,NULL,27,30877,0);
INSERT INTO "django_geo_db_location" VALUES(53905,NULL,'Naponee, NE',22735,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53906,NULL,'Naponee, NE 68960',22735,222,NULL,27,30878,0);
INSERT INTO "django_geo_db_location" VALUES(53907,NULL,'Nelson, NE',22736,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53908,NULL,'Nelson, NE 68961',22736,222,NULL,27,30879,0);
INSERT INTO "django_geo_db_location" VALUES(53909,NULL,'Norman, NE',22737,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53910,NULL,'Norman, NE 68963',22737,222,NULL,27,30880,0);
INSERT INTO "django_geo_db_location" VALUES(53911,NULL,'Oak, NE',22738,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53912,NULL,'Oak, NE 68964',22738,222,NULL,27,30881,0);
INSERT INTO "django_geo_db_location" VALUES(53913,NULL,'Orleans, NE',22739,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53914,NULL,'Orleans, NE 68966',22739,222,NULL,27,30882,0);
INSERT INTO "django_geo_db_location" VALUES(53915,NULL,'Oxford, NE',22740,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53916,NULL,'Oxford, NE 68967',22740,222,NULL,27,30883,0);
INSERT INTO "django_geo_db_location" VALUES(53917,NULL,'Ragan, NE',22741,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53918,NULL,'Ragan, NE 68969',22741,222,NULL,27,30884,0);
INSERT INTO "django_geo_db_location" VALUES(53919,NULL,'Red Cloud, NE',22742,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53920,NULL,'Red Cloud, NE 68970',22742,222,NULL,27,30885,0);
INSERT INTO "django_geo_db_location" VALUES(53921,NULL,'Republican City, NE',22743,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53922,NULL,'Republican City, NE 68971',22743,222,NULL,27,30886,0);
INSERT INTO "django_geo_db_location" VALUES(53923,NULL,'Riverton, NE',22744,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53924,NULL,'Riverton, NE 68972',22744,222,NULL,27,30887,0);
INSERT INTO "django_geo_db_location" VALUES(53925,NULL,'Roseland, NE',22745,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53926,NULL,'Roseland, NE 68973',22745,222,NULL,27,30888,0);
INSERT INTO "django_geo_db_location" VALUES(53927,NULL,'Ruskin, NE',22746,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53928,NULL,'Ruskin, NE 68974',22746,222,NULL,27,30889,0);
INSERT INTO "django_geo_db_location" VALUES(53929,NULL,'Saronville, NE',22747,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53930,NULL,'Saronville, NE 68975',22747,222,NULL,27,30890,0);
INSERT INTO "django_geo_db_location" VALUES(53931,NULL,'Smithfield, NE',22748,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53932,NULL,'Smithfield, NE 68976',22748,222,NULL,27,30891,0);
INSERT INTO "django_geo_db_location" VALUES(53933,NULL,'Stamford, NE',22749,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53934,NULL,'Stamford, NE 68977',22749,222,NULL,27,30892,0);
INSERT INTO "django_geo_db_location" VALUES(53935,NULL,'Superior, NE',22750,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53936,NULL,'Superior, NE 68978',22750,222,NULL,27,30893,0);
INSERT INTO "django_geo_db_location" VALUES(53937,NULL,'Sutton, NE 68979',22634,222,NULL,27,30894,0);
INSERT INTO "django_geo_db_location" VALUES(53938,NULL,'Trumbull, NE',22751,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53939,NULL,'Trumbull, NE 68980',22751,222,NULL,27,30895,0);
INSERT INTO "django_geo_db_location" VALUES(53940,NULL,'Upland, NE',22752,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53941,NULL,'Upland, NE 68981',22752,222,NULL,27,30896,0);
INSERT INTO "django_geo_db_location" VALUES(53942,NULL,'Wilcox, NE',22753,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53943,NULL,'Wilcox, NE 68982',22753,222,NULL,27,30897,0);
INSERT INTO "django_geo_db_location" VALUES(53944,NULL,'McCook, NE',22754,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53945,NULL,'McCook, NE 69001',22754,222,NULL,27,30898,0);
INSERT INTO "django_geo_db_location" VALUES(53946,NULL,'Bartley, NE',22755,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53947,NULL,'Bartley, NE 69020',22755,222,NULL,27,30899,0);
INSERT INTO "django_geo_db_location" VALUES(53948,NULL,'Benkelman, NE',22756,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53949,NULL,'Benkelman, NE 69021',22756,222,NULL,27,30900,0);
INSERT INTO "django_geo_db_location" VALUES(53950,NULL,'Cambridge, NE',22757,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53951,NULL,'Cambridge, NE 69022',22757,222,NULL,27,30901,0);
INSERT INTO "django_geo_db_location" VALUES(53952,NULL,'Champion, NE',22758,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53953,NULL,'Champion, NE 69023',22758,222,NULL,27,30902,0);
INSERT INTO "django_geo_db_location" VALUES(53954,NULL,'Culbertson, NE',22759,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53955,NULL,'Culbertson, NE 69024',22759,222,NULL,27,30903,0);
INSERT INTO "django_geo_db_location" VALUES(53956,NULL,'Curtis, NE',22760,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53957,NULL,'Curtis, NE 69025',22760,222,NULL,27,30904,0);
INSERT INTO "django_geo_db_location" VALUES(53958,NULL,'Danbury, NE',22761,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53959,NULL,'Danbury, NE 69026',22761,222,NULL,27,30905,0);
INSERT INTO "django_geo_db_location" VALUES(53960,NULL,'Enders, NE',22762,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53961,NULL,'Enders, NE 69027',22762,222,NULL,27,30906,0);
INSERT INTO "django_geo_db_location" VALUES(53962,NULL,'Eustis, NE',22763,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53963,NULL,'Eustis, NE 69028',22763,222,NULL,27,30907,0);
INSERT INTO "django_geo_db_location" VALUES(53964,NULL,'Farnam, NE',22764,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53965,NULL,'Farnam, NE 69029',22764,222,NULL,27,30908,0);
INSERT INTO "django_geo_db_location" VALUES(53966,NULL,'Haigler, NE',22765,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53967,NULL,'Haigler, NE 69030',22765,222,NULL,27,30909,0);
INSERT INTO "django_geo_db_location" VALUES(53968,NULL,'Hamlet, NE',22766,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53969,NULL,'Hamlet, NE 69031',22766,222,NULL,27,30910,0);
INSERT INTO "django_geo_db_location" VALUES(53970,NULL,'Hayes Center, NE',22767,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53971,NULL,'Hayes Center, NE 69032',22767,222,NULL,27,30911,0);
INSERT INTO "django_geo_db_location" VALUES(53972,NULL,'Imperial, NE',22768,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53973,NULL,'Imperial, NE 69033',22768,222,NULL,27,30912,0);
INSERT INTO "django_geo_db_location" VALUES(53974,NULL,'Indianola, NE',22769,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53975,NULL,'Indianola, NE 69034',22769,222,NULL,27,30913,0);
INSERT INTO "django_geo_db_location" VALUES(53976,NULL,'Lebanon, NE',22770,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53977,NULL,'Lebanon, NE 69036',22770,222,NULL,27,30914,0);
INSERT INTO "django_geo_db_location" VALUES(53978,NULL,'Max, NE',22771,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53979,NULL,'Max, NE 69037',22771,222,NULL,27,30915,0);
INSERT INTO "django_geo_db_location" VALUES(53980,NULL,'Maywood, NE',22772,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53981,NULL,'Maywood, NE 69038',22772,222,NULL,27,30916,0);
INSERT INTO "django_geo_db_location" VALUES(53982,NULL,'Moorefield, NE',22773,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53983,NULL,'Moorefield, NE 69039',22773,222,NULL,27,30917,0);
INSERT INTO "django_geo_db_location" VALUES(53984,NULL,'Palisade, NE',22774,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53985,NULL,'Palisade, NE 69040',22774,222,NULL,27,30918,0);
INSERT INTO "django_geo_db_location" VALUES(53986,NULL,'Parks, NE',22775,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53987,NULL,'Parks, NE 69041',22775,222,NULL,27,30919,0);
INSERT INTO "django_geo_db_location" VALUES(53988,NULL,'Stockville, NE',22776,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53989,NULL,'Stockville, NE 69042',22776,222,NULL,27,30920,0);
INSERT INTO "django_geo_db_location" VALUES(53990,NULL,'Stratton, NE',22777,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53991,NULL,'Stratton, NE 69043',22777,222,NULL,27,30921,0);
INSERT INTO "django_geo_db_location" VALUES(53992,NULL,'Trenton, NE',22778,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53993,NULL,'Trenton, NE 69044',22778,222,NULL,27,30922,0);
INSERT INTO "django_geo_db_location" VALUES(53994,NULL,'Wauneta, NE',22779,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53995,NULL,'Wauneta, NE 69045',22779,222,NULL,27,30923,0);
INSERT INTO "django_geo_db_location" VALUES(53996,NULL,'Wilsonville, NE',22780,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53997,NULL,'Wilsonville, NE 69046',22780,222,NULL,27,30924,0);
INSERT INTO "django_geo_db_location" VALUES(53998,NULL,'North Platte, NE',22781,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(53999,NULL,'North Platte, NE 69101',22781,222,NULL,27,30925,0);
INSERT INTO "django_geo_db_location" VALUES(54000,NULL,'North Platte, NE 69103',22781,222,NULL,27,30926,0);
INSERT INTO "django_geo_db_location" VALUES(54001,NULL,'Arnold, NE',22782,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54002,NULL,'Arnold, NE 69120',22782,222,NULL,27,30927,0);
INSERT INTO "django_geo_db_location" VALUES(54003,NULL,'Arthur, NE',22783,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54004,NULL,'Arthur, NE 69121',22783,222,NULL,27,30928,0);
INSERT INTO "django_geo_db_location" VALUES(54005,NULL,'Big Springs, NE',22784,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54006,NULL,'Big Springs, NE 69122',22784,222,NULL,27,30929,0);
INSERT INTO "django_geo_db_location" VALUES(54007,NULL,'Brady, NE',22785,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54008,NULL,'Brady, NE 69123',22785,222,NULL,27,30930,0);
INSERT INTO "django_geo_db_location" VALUES(54009,NULL,'Broadwater, NE',22786,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54010,NULL,'Broadwater, NE 69125',22786,222,NULL,27,30931,0);
INSERT INTO "django_geo_db_location" VALUES(54011,NULL,'Brule, NE',22787,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54012,NULL,'Brule, NE 69127',22787,222,NULL,27,30932,0);
INSERT INTO "django_geo_db_location" VALUES(54013,NULL,'Bushnell, NE',22788,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54014,NULL,'Bushnell, NE 69128',22788,222,NULL,27,30933,0);
INSERT INTO "django_geo_db_location" VALUES(54015,NULL,'Chappell, NE',22789,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54016,NULL,'Chappell, NE 69129',22789,222,NULL,27,30934,0);
INSERT INTO "django_geo_db_location" VALUES(54017,NULL,'Cozad, NE',22790,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54018,NULL,'Cozad, NE 69130',22790,222,NULL,27,30935,0);
INSERT INTO "django_geo_db_location" VALUES(54019,NULL,'Dalton, NE',22791,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54020,NULL,'Dalton, NE 69131',22791,222,NULL,27,30936,0);
INSERT INTO "django_geo_db_location" VALUES(54021,NULL,'Dickens, NE',22792,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54022,NULL,'Dickens, NE 69132',22792,222,NULL,27,30937,0);
INSERT INTO "django_geo_db_location" VALUES(54023,NULL,'Dix, NE',22793,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54024,NULL,'Dix, NE 69133',22793,222,NULL,27,30938,0);
INSERT INTO "django_geo_db_location" VALUES(54025,NULL,'Elsie, NE',22794,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54026,NULL,'Elsie, NE 69134',22794,222,NULL,27,30939,0);
INSERT INTO "django_geo_db_location" VALUES(54027,NULL,'Elsmere, NE',22795,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54028,NULL,'Elsmere, NE 69135',22795,222,NULL,27,30940,0);
INSERT INTO "django_geo_db_location" VALUES(54029,NULL,'Gothenburg, NE',22796,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54030,NULL,'Gothenburg, NE 69138',22796,222,NULL,27,30941,0);
INSERT INTO "django_geo_db_location" VALUES(54031,NULL,'Grant, NE',22797,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54032,NULL,'Grant, NE 69140',22797,222,NULL,27,30942,0);
INSERT INTO "django_geo_db_location" VALUES(54033,NULL,'Gurley, NE',22798,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54034,NULL,'Gurley, NE 69141',22798,222,NULL,27,30943,0);
INSERT INTO "django_geo_db_location" VALUES(54035,NULL,'Halsey, NE',22799,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54036,NULL,'Halsey, NE 69142',22799,222,NULL,27,30944,0);
INSERT INTO "django_geo_db_location" VALUES(54037,NULL,'Hershey, NE',22800,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54038,NULL,'Hershey, NE 69143',22800,222,NULL,27,30945,0);
INSERT INTO "django_geo_db_location" VALUES(54039,NULL,'Keystone, NE',22801,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54040,NULL,'Keystone, NE 69144',22801,222,NULL,27,30946,0);
INSERT INTO "django_geo_db_location" VALUES(54041,NULL,'Kimball, NE',22802,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54042,NULL,'Kimball, NE 69145',22802,222,NULL,27,30947,0);
INSERT INTO "django_geo_db_location" VALUES(54043,NULL,'Lemoyne, NE',22803,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54044,NULL,'Lemoyne, NE 69146',22803,222,NULL,27,30948,0);
INSERT INTO "django_geo_db_location" VALUES(54045,NULL,'Lewellen, NE',22804,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54046,NULL,'Lewellen, NE 69147',22804,222,NULL,27,30949,0);
INSERT INTO "django_geo_db_location" VALUES(54047,NULL,'Lisco, NE',22805,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54048,NULL,'Lisco, NE 69148',22805,222,NULL,27,30950,0);
INSERT INTO "django_geo_db_location" VALUES(54049,NULL,'Lodgepole, NE',22806,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54050,NULL,'Lodgepole, NE 69149',22806,222,NULL,27,30951,0);
INSERT INTO "django_geo_db_location" VALUES(54051,NULL,'Madrid, NE',22807,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54052,NULL,'Madrid, NE 69150',22807,222,NULL,27,30952,0);
INSERT INTO "django_geo_db_location" VALUES(54053,NULL,'Maxwell, NE',22808,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54054,NULL,'Maxwell, NE 69151',22808,222,NULL,27,30953,0);
INSERT INTO "django_geo_db_location" VALUES(54055,NULL,'Mullen, NE',22809,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54056,NULL,'Mullen, NE 69152',22809,222,NULL,27,30954,0);
INSERT INTO "django_geo_db_location" VALUES(54057,NULL,'Ogallala, NE',22810,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54058,NULL,'Ogallala, NE 69153',22810,222,NULL,27,30955,0);
INSERT INTO "django_geo_db_location" VALUES(54059,NULL,'Oshkosh, NE',22811,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54060,NULL,'Oshkosh, NE 69154',22811,222,NULL,27,30956,0);
INSERT INTO "django_geo_db_location" VALUES(54061,NULL,'Paxton, NE',22812,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54062,NULL,'Paxton, NE 69155',22812,222,NULL,27,30957,0);
INSERT INTO "django_geo_db_location" VALUES(54063,NULL,'Potter, NE',22813,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54064,NULL,'Potter, NE 69156',22813,222,NULL,27,30958,0);
INSERT INTO "django_geo_db_location" VALUES(54065,NULL,'Purdum, NE',22814,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54066,NULL,'Purdum, NE 69157',22814,222,NULL,27,30959,0);
INSERT INTO "django_geo_db_location" VALUES(54067,NULL,'Sidney, NE',22815,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54068,NULL,'Sidney, NE 69160',22815,222,NULL,27,30960,0);
INSERT INTO "django_geo_db_location" VALUES(54069,NULL,'Seneca, NE',22816,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54070,NULL,'Seneca, NE 69161',22816,222,NULL,27,30961,0);
INSERT INTO "django_geo_db_location" VALUES(54071,NULL,'Sidney, NE 69162',22815,222,NULL,27,30962,0);
INSERT INTO "django_geo_db_location" VALUES(54072,NULL,'Stapleton, NE',22817,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54073,NULL,'Stapleton, NE 69163',22817,222,NULL,27,30963,0);
INSERT INTO "django_geo_db_location" VALUES(54074,NULL,'Sutherland, NE',22818,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54075,NULL,'Sutherland, NE 69165',22818,222,NULL,27,30964,0);
INSERT INTO "django_geo_db_location" VALUES(54076,NULL,'Thedford, NE',22819,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54077,NULL,'Thedford, NE 69166',22819,222,NULL,27,30965,0);
INSERT INTO "django_geo_db_location" VALUES(54078,NULL,'Tryon, NE',22820,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54079,NULL,'Tryon, NE 69167',22820,222,NULL,27,30966,0);
INSERT INTO "django_geo_db_location" VALUES(54080,NULL,'Venango, NE',22821,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54081,NULL,'Venango, NE 69168',22821,222,NULL,27,30967,0);
INSERT INTO "django_geo_db_location" VALUES(54082,NULL,'Wallace, NE',22822,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54083,NULL,'Wallace, NE 69169',22822,222,NULL,27,30968,0);
INSERT INTO "django_geo_db_location" VALUES(54084,NULL,'Wellfleet, NE',22823,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54085,NULL,'Wellfleet, NE 69170',22823,222,NULL,27,30969,0);
INSERT INTO "django_geo_db_location" VALUES(54086,NULL,'Willow Island, NE',22824,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54087,NULL,'Willow Island, NE 69171',22824,222,NULL,27,30970,0);
INSERT INTO "django_geo_db_location" VALUES(54088,NULL,'Oshkosh, NE 69190',22811,222,NULL,27,30971,0);
INSERT INTO "django_geo_db_location" VALUES(54089,NULL,'Valentine, NE',22825,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54090,NULL,'Valentine, NE 69201',22825,222,NULL,27,30972,0);
INSERT INTO "django_geo_db_location" VALUES(54091,NULL,'Ainsworth, NE',22826,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54092,NULL,'Ainsworth, NE 69210',22826,222,NULL,27,30973,0);
INSERT INTO "django_geo_db_location" VALUES(54093,NULL,'Cody, NE',22827,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54094,NULL,'Cody, NE 69211',22827,222,NULL,27,30974,0);
INSERT INTO "django_geo_db_location" VALUES(54095,NULL,'Crookston, NE',22828,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54096,NULL,'Crookston, NE 69212',22828,222,NULL,27,30975,0);
INSERT INTO "django_geo_db_location" VALUES(54097,NULL,'Johnstown, NE',22829,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54098,NULL,'Johnstown, NE 69214',22829,222,NULL,27,30976,0);
INSERT INTO "django_geo_db_location" VALUES(54099,NULL,'Kilgore, NE',22830,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54100,NULL,'Kilgore, NE 69216',22830,222,NULL,27,30977,0);
INSERT INTO "django_geo_db_location" VALUES(54101,NULL,'Long Pine, NE',22831,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54102,NULL,'Long Pine, NE 69217',22831,222,NULL,27,30978,0);
INSERT INTO "django_geo_db_location" VALUES(54103,NULL,'Merriman, NE',22832,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54104,NULL,'Merriman, NE 69218',22832,222,NULL,27,30979,0);
INSERT INTO "django_geo_db_location" VALUES(54105,NULL,'Nenzel, NE',22833,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54106,NULL,'Nenzel, NE 69219',22833,222,NULL,27,30980,0);
INSERT INTO "django_geo_db_location" VALUES(54107,NULL,'Sparks, NE',22834,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54108,NULL,'Sparks, NE 69220',22834,222,NULL,27,30981,0);
INSERT INTO "django_geo_db_location" VALUES(54109,NULL,'Wood Lake, NE',22835,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54110,NULL,'Wood Lake, NE 69221',22835,222,NULL,27,30982,0);
INSERT INTO "django_geo_db_location" VALUES(54111,NULL,'Alliance, NE',22836,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54112,NULL,'Alliance, NE 69301',22836,222,NULL,27,30983,0);
INSERT INTO "django_geo_db_location" VALUES(54113,NULL,'Angora, NE',22837,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54114,NULL,'Angora, NE 69331',22837,222,NULL,27,30984,0);
INSERT INTO "django_geo_db_location" VALUES(54115,NULL,'Ashby, NE',22838,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54116,NULL,'Ashby, NE 69333',22838,222,NULL,27,30985,0);
INSERT INTO "django_geo_db_location" VALUES(54117,NULL,'Bayard, NE',22839,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54118,NULL,'Bayard, NE 69334',22839,222,NULL,27,30986,0);
INSERT INTO "django_geo_db_location" VALUES(54119,NULL,'Bingham, NE',22840,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54120,NULL,'Bingham, NE 69335',22840,222,NULL,27,30987,0);
INSERT INTO "django_geo_db_location" VALUES(54121,NULL,'Bridgeport, NE',22841,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54122,NULL,'Bridgeport, NE 69336',22841,222,NULL,27,30988,0);
INSERT INTO "django_geo_db_location" VALUES(54123,NULL,'Chadron, NE',22842,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54124,NULL,'Chadron, NE 69337',22842,222,NULL,27,30989,0);
INSERT INTO "django_geo_db_location" VALUES(54125,NULL,'Crawford, NE',22843,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54126,NULL,'Crawford, NE 69339',22843,222,NULL,27,30990,0);
INSERT INTO "django_geo_db_location" VALUES(54127,NULL,'Ellsworth, NE',22844,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54128,NULL,'Ellsworth, NE 69340',22844,222,NULL,27,30991,0);
INSERT INTO "django_geo_db_location" VALUES(54129,NULL,'Gering, NE',22845,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54130,NULL,'Gering, NE 69341',22845,222,NULL,27,30992,0);
INSERT INTO "django_geo_db_location" VALUES(54131,NULL,'Gordon, NE',22846,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54132,NULL,'Gordon, NE 69343',22846,222,NULL,27,30993,0);
INSERT INTO "django_geo_db_location" VALUES(54133,NULL,'Harrisburg, NE',22847,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54134,NULL,'Harrisburg, NE 69345',22847,222,NULL,27,30994,0);
INSERT INTO "django_geo_db_location" VALUES(54135,NULL,'Harrison, NE',22848,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54136,NULL,'Harrison, NE 69346',22848,222,NULL,27,30995,0);
INSERT INTO "django_geo_db_location" VALUES(54137,NULL,'Hay Springs, NE',22849,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54138,NULL,'Hay Springs, NE 69347',22849,222,NULL,27,30996,0);
INSERT INTO "django_geo_db_location" VALUES(54139,NULL,'Hemingford, NE',22850,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54140,NULL,'Hemingford, NE 69348',22850,222,NULL,27,30997,0);
INSERT INTO "django_geo_db_location" VALUES(54141,NULL,'Henry, NE',22851,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54142,NULL,'Henry, NE 69349',22851,222,NULL,27,30998,0);
INSERT INTO "django_geo_db_location" VALUES(54143,NULL,'Hyannis, NE',22852,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54144,NULL,'Hyannis, NE 69350',22852,222,NULL,27,30999,0);
INSERT INTO "django_geo_db_location" VALUES(54145,NULL,'Lakeside, NE',22853,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54146,NULL,'Lakeside, NE 69351',22853,222,NULL,27,31000,0);
INSERT INTO "django_geo_db_location" VALUES(54147,NULL,'Lyman, NE',22854,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54148,NULL,'Lyman, NE 69352',22854,222,NULL,27,31001,0);
INSERT INTO "django_geo_db_location" VALUES(54149,NULL,'Mcgrew, NE',22855,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54150,NULL,'Mcgrew, NE 69353',22855,222,NULL,27,31002,0);
INSERT INTO "django_geo_db_location" VALUES(54151,NULL,'Marsland, NE',22856,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54152,NULL,'Marsland, NE 69354',22856,222,NULL,27,31003,0);
INSERT INTO "django_geo_db_location" VALUES(54153,NULL,'Melbeta, NE',22857,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54154,NULL,'Melbeta, NE 69355',22857,222,NULL,27,31004,0);
INSERT INTO "django_geo_db_location" VALUES(54155,NULL,'Minatare, NE',22858,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54156,NULL,'Minatare, NE 69356',22858,222,NULL,27,31005,0);
INSERT INTO "django_geo_db_location" VALUES(54157,NULL,'Mitchell, NE',22859,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54158,NULL,'Mitchell, NE 69357',22859,222,NULL,27,31006,0);
INSERT INTO "django_geo_db_location" VALUES(54159,NULL,'Morrill, NE',22860,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54160,NULL,'Morrill, NE 69358',22860,222,NULL,27,31007,0);
INSERT INTO "django_geo_db_location" VALUES(54161,NULL,'Rushville, NE',22861,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54162,NULL,'Rushville, NE 69360',22861,222,NULL,27,31008,0);
INSERT INTO "django_geo_db_location" VALUES(54163,NULL,'Scottsbluff, NE',22862,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54164,NULL,'Scottsbluff, NE 69361',22862,222,NULL,27,31009,0);
INSERT INTO "django_geo_db_location" VALUES(54165,NULL,'Scottsbluff, NE 69363',22862,222,NULL,27,31010,0);
INSERT INTO "django_geo_db_location" VALUES(54166,NULL,'Whiteclay, NE',22863,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54167,NULL,'Whiteclay, NE 69365',22863,222,NULL,27,31011,0);
INSERT INTO "django_geo_db_location" VALUES(54168,NULL,'Whitman, NE',22864,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54169,NULL,'Whitman, NE 69366',22864,222,NULL,27,31012,0);
INSERT INTO "django_geo_db_location" VALUES(54170,NULL,'Whitney, NE',22865,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54171,NULL,'Whitney, NE 69367',22865,222,NULL,27,31013,0);
INSERT INTO "django_geo_db_location" VALUES(54172,NULL,'Laplace, LA',22866,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54173,NULL,'Laplace, LA 70000',22866,222,NULL,22,31014,0);
INSERT INTO "django_geo_db_location" VALUES(54174,NULL,'Metairie, LA',22867,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54175,NULL,'Metairie, LA 70001',22867,222,NULL,22,31015,0);
INSERT INTO "django_geo_db_location" VALUES(54176,NULL,'Metairie, LA 70002',22867,222,NULL,22,31016,0);
INSERT INTO "django_geo_db_location" VALUES(54177,NULL,'Metairie, LA 70003',22867,222,NULL,22,31017,0);
INSERT INTO "django_geo_db_location" VALUES(54178,NULL,'Metairie, LA 70004',22867,222,NULL,22,31018,0);
INSERT INTO "django_geo_db_location" VALUES(54179,NULL,'Metairie, LA 70005',22867,222,NULL,22,31019,0);
INSERT INTO "django_geo_db_location" VALUES(54180,NULL,'Metairie, LA 70006',22867,222,NULL,22,31020,0);
INSERT INTO "django_geo_db_location" VALUES(54181,NULL,'Metairie, LA 70009',22867,222,NULL,22,31021,0);
INSERT INTO "django_geo_db_location" VALUES(54182,NULL,'Metairie, LA 70010',22867,222,NULL,22,31022,0);
INSERT INTO "django_geo_db_location" VALUES(54183,NULL,'Metairie, LA 70011',22867,222,NULL,22,31023,0);
INSERT INTO "django_geo_db_location" VALUES(54184,NULL,'Jefferson, LA',22868,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54185,NULL,'Jefferson, LA 70021',22868,222,NULL,22,31024,0);
INSERT INTO "django_geo_db_location" VALUES(54186,NULL,'Des Allemands, LA',22869,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54187,NULL,'Des Allemands, LA 70030',22869,222,NULL,22,31025,0);
INSERT INTO "django_geo_db_location" VALUES(54188,NULL,'Ama, LA',22870,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54189,NULL,'Ama, LA 70031',22870,222,NULL,22,31026,0);
INSERT INTO "django_geo_db_location" VALUES(54190,NULL,'Arabi, LA',22871,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54191,NULL,'Arabi, LA 70032',22871,222,NULL,22,31027,0);
INSERT INTO "django_geo_db_location" VALUES(54192,NULL,'Metairie, LA 70033',22867,222,NULL,22,31028,0);
INSERT INTO "django_geo_db_location" VALUES(54193,NULL,'Barataria, LA',22872,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54194,NULL,'Barataria, LA 70036',22872,222,NULL,22,31029,0);
INSERT INTO "django_geo_db_location" VALUES(54195,NULL,'Belle Chasse, LA',22873,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54196,NULL,'Belle Chasse, LA 70037',22873,222,NULL,22,31030,0);
INSERT INTO "django_geo_db_location" VALUES(54197,NULL,'Boothville, LA',22874,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54198,NULL,'Boothville, LA 70038',22874,222,NULL,22,31031,0);
INSERT INTO "django_geo_db_location" VALUES(54199,NULL,'Boutte, LA',22875,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54200,NULL,'Boutte, LA 70039',22875,222,NULL,22,31032,0);
INSERT INTO "django_geo_db_location" VALUES(54201,NULL,'Braithwaite, LA',22876,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54202,NULL,'Braithwaite, LA 70040',22876,222,NULL,22,31033,0);
INSERT INTO "django_geo_db_location" VALUES(54203,NULL,'Buras, LA',22877,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54204,NULL,'Buras, LA 70041',22877,222,NULL,22,31034,0);
INSERT INTO "django_geo_db_location" VALUES(54205,NULL,'Carlisle, LA',22878,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54206,NULL,'Carlisle, LA 70042',22878,222,NULL,22,31035,0);
INSERT INTO "django_geo_db_location" VALUES(54207,NULL,'Chalmette, LA',22879,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54208,NULL,'Chalmette, LA 70043',22879,222,NULL,22,31036,0);
INSERT INTO "django_geo_db_location" VALUES(54209,NULL,'Chalmette, LA 70044',22879,222,NULL,22,31037,0);
INSERT INTO "django_geo_db_location" VALUES(54210,NULL,'Davant, LA',22880,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54211,NULL,'Davant, LA 70046',22880,222,NULL,22,31038,0);
INSERT INTO "django_geo_db_location" VALUES(54212,NULL,'Destrehan, LA',22881,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54213,NULL,'Destrehan, LA 70047',22881,222,NULL,22,31039,0);
INSERT INTO "django_geo_db_location" VALUES(54214,NULL,'Reserve, LA',22882,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54215,NULL,'Reserve, LA 70048',22882,222,NULL,22,31040,0);
INSERT INTO "django_geo_db_location" VALUES(54216,NULL,'Edgard, LA',22883,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54217,NULL,'Edgard, LA 70049',22883,222,NULL,22,31041,0);
INSERT INTO "django_geo_db_location" VALUES(54218,NULL,'Empire, LA',22884,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54219,NULL,'Empire, LA 70050',22884,222,NULL,22,31042,0);
INSERT INTO "django_geo_db_location" VALUES(54220,NULL,'Garyville, LA',22885,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54221,NULL,'Garyville, LA 70051',22885,222,NULL,22,31043,0);
INSERT INTO "django_geo_db_location" VALUES(54222,NULL,'Gramercy, LA',22886,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54223,NULL,'Gramercy, LA 70052',22886,222,NULL,22,31044,0);
INSERT INTO "django_geo_db_location" VALUES(54224,NULL,'Gretna, LA',22887,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54225,NULL,'Gretna, LA 70053',22887,222,NULL,22,31045,0);
INSERT INTO "django_geo_db_location" VALUES(54226,NULL,'Gretna, LA 70054',22887,222,NULL,22,31046,0);
INSERT INTO "django_geo_db_location" VALUES(54227,NULL,'Metairie, LA 70055',22867,222,NULL,22,31047,0);
INSERT INTO "django_geo_db_location" VALUES(54228,NULL,'Gretna, LA 70056',22887,222,NULL,22,31048,0);
INSERT INTO "django_geo_db_location" VALUES(54229,NULL,'Hahnville, LA',22888,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54230,NULL,'Hahnville, LA 70057',22888,222,NULL,22,31049,0);
INSERT INTO "django_geo_db_location" VALUES(54231,NULL,'Harvey, LA',22889,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54232,NULL,'Harvey, LA 70058',22889,222,NULL,22,31050,0);
INSERT INTO "django_geo_db_location" VALUES(54233,NULL,'Harvey, LA 70059',22889,222,NULL,22,31051,0);
INSERT INTO "django_geo_db_location" VALUES(54234,NULL,'Metairie, LA 70060',22867,222,NULL,22,31052,0);
INSERT INTO "django_geo_db_location" VALUES(54235,NULL,'Kenner, LA',22890,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54236,NULL,'Kenner, LA 70062',22890,222,NULL,22,31053,0);
INSERT INTO "django_geo_db_location" VALUES(54237,NULL,'Kenner, LA 70063',22890,222,NULL,22,31054,0);
INSERT INTO "django_geo_db_location" VALUES(54238,NULL,'Kenner, LA 70064',22890,222,NULL,22,31055,0);
INSERT INTO "django_geo_db_location" VALUES(54239,NULL,'Kenner, LA 70065',22890,222,NULL,22,31056,0);
INSERT INTO "django_geo_db_location" VALUES(54240,NULL,'Killona, LA',22891,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54241,NULL,'Killona, LA 70066',22891,222,NULL,22,31057,0);
INSERT INTO "django_geo_db_location" VALUES(54242,NULL,'Lafitte, LA',22892,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54243,NULL,'Lafitte, LA 70067',22892,222,NULL,22,31058,0);
INSERT INTO "django_geo_db_location" VALUES(54244,NULL,'La Place, LA',22893,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54245,NULL,'La Place, LA 70068',22893,222,NULL,22,31059,0);
INSERT INTO "django_geo_db_location" VALUES(54246,NULL,'La Place, LA 70069',22893,222,NULL,22,31060,0);
INSERT INTO "django_geo_db_location" VALUES(54247,NULL,'Luling, LA',22894,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54248,NULL,'Luling, LA 70070',22894,222,NULL,22,31061,0);
INSERT INTO "django_geo_db_location" VALUES(54249,NULL,'Lutcher, LA',22895,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54250,NULL,'Lutcher, LA 70071',22895,222,NULL,22,31062,0);
INSERT INTO "django_geo_db_location" VALUES(54251,NULL,'Marrero, LA',22896,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54252,NULL,'Marrero, LA 70072',22896,222,NULL,22,31063,0);
INSERT INTO "django_geo_db_location" VALUES(54253,NULL,'Marrero, LA 70073',22896,222,NULL,22,31064,0);
INSERT INTO "django_geo_db_location" VALUES(54254,NULL,'Meraux, LA',22897,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54255,NULL,'Meraux, LA 70075',22897,222,NULL,22,31065,0);
INSERT INTO "django_geo_db_location" VALUES(54256,NULL,'Mount Airy, LA',22898,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54257,NULL,'Mount Airy, LA 70076',22898,222,NULL,22,31066,0);
INSERT INTO "django_geo_db_location" VALUES(54258,NULL,'New Sarpy, LA',22899,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54259,NULL,'New Sarpy, LA 70078',22899,222,NULL,22,31067,0);
INSERT INTO "django_geo_db_location" VALUES(54260,NULL,'Norco, LA',22900,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54261,NULL,'Norco, LA 70079',22900,222,NULL,22,31068,0);
INSERT INTO "django_geo_db_location" VALUES(54262,NULL,'Paradis, LA',22901,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54263,NULL,'Paradis, LA 70080',22901,222,NULL,22,31069,0);
INSERT INTO "django_geo_db_location" VALUES(54264,NULL,'Pilottown, LA',22902,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54265,NULL,'Pilottown, LA 70081',22902,222,NULL,22,31070,0);
INSERT INTO "django_geo_db_location" VALUES(54266,NULL,'Pointe A La Hache, LA',22903,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54267,NULL,'Pointe A La Hache, LA 70082',22903,222,NULL,22,31071,0);
INSERT INTO "django_geo_db_location" VALUES(54268,NULL,'Port Sulphur, LA',22904,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54269,NULL,'Port Sulphur, LA 70083',22904,222,NULL,22,31072,0);
INSERT INTO "django_geo_db_location" VALUES(54270,NULL,'Reserve, LA 70084',22882,222,NULL,22,31073,0);
INSERT INTO "django_geo_db_location" VALUES(54271,NULL,'Saint Bernard, LA',22905,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54272,NULL,'Saint Bernard, LA 70085',22905,222,NULL,22,31074,0);
INSERT INTO "django_geo_db_location" VALUES(54273,NULL,'Saint James, LA',22906,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54274,NULL,'Saint James, LA 70086',22906,222,NULL,22,31075,0);
INSERT INTO "django_geo_db_location" VALUES(54275,NULL,'Saint Rose, LA',22907,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54276,NULL,'Saint Rose, LA 70087',22907,222,NULL,22,31076,0);
INSERT INTO "django_geo_db_location" VALUES(54277,NULL,'Vacherie, LA',22908,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54278,NULL,'Vacherie, LA 70090',22908,222,NULL,22,31077,0);
INSERT INTO "django_geo_db_location" VALUES(54279,NULL,'Venice, LA',22909,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54280,NULL,'Venice, LA 70091',22909,222,NULL,22,31078,0);
INSERT INTO "django_geo_db_location" VALUES(54281,NULL,'Violet, LA',22910,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54282,NULL,'Violet, LA 70092',22910,222,NULL,22,31079,0);
INSERT INTO "django_geo_db_location" VALUES(54283,NULL,'Violet, LA 70093',22910,222,NULL,22,31080,0);
INSERT INTO "django_geo_db_location" VALUES(54284,NULL,'Westwego, LA',22911,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54285,NULL,'Westwego, LA 70094',22911,222,NULL,22,31081,0);
INSERT INTO "django_geo_db_location" VALUES(54286,NULL,'Westwego, LA 70096',22911,222,NULL,22,31082,0);
INSERT INTO "django_geo_db_location" VALUES(54287,NULL,'New Orleans, LA',22912,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54288,NULL,'New Orleans, LA 70112',22912,222,NULL,22,31083,0);
INSERT INTO "django_geo_db_location" VALUES(54289,NULL,'New Orleans, LA 70113',22912,222,NULL,22,31084,0);
INSERT INTO "django_geo_db_location" VALUES(54290,NULL,'New Orleans, LA 70114',22912,222,NULL,22,31085,0);
INSERT INTO "django_geo_db_location" VALUES(54291,NULL,'New Orleans, LA 70115',22912,222,NULL,22,31086,0);
INSERT INTO "django_geo_db_location" VALUES(54292,NULL,'New Orleans, LA 70116',22912,222,NULL,22,31087,0);
INSERT INTO "django_geo_db_location" VALUES(54293,NULL,'New Orleans, LA 70117',22912,222,NULL,22,31088,0);
INSERT INTO "django_geo_db_location" VALUES(54294,NULL,'New Orleans, LA 70118',22912,222,NULL,22,31089,0);
INSERT INTO "django_geo_db_location" VALUES(54295,NULL,'New Orleans, LA 70119',22912,222,NULL,22,31090,0);
INSERT INTO "django_geo_db_location" VALUES(54296,NULL,'New Orleans, LA 70121',22912,222,NULL,22,31091,0);
INSERT INTO "django_geo_db_location" VALUES(54297,NULL,'New Orleans, LA 70122',22912,222,NULL,22,31092,0);
INSERT INTO "django_geo_db_location" VALUES(54298,NULL,'New Orleans, LA 70123',22912,222,NULL,22,31093,0);
INSERT INTO "django_geo_db_location" VALUES(54299,NULL,'New Orleans, LA 70124',22912,222,NULL,22,31094,0);
INSERT INTO "django_geo_db_location" VALUES(54300,NULL,'New Orleans, LA 70125',22912,222,NULL,22,31095,0);
INSERT INTO "django_geo_db_location" VALUES(54301,NULL,'New Orleans, LA 70126',22912,222,NULL,22,31096,0);
INSERT INTO "django_geo_db_location" VALUES(54302,NULL,'New Orleans, LA 70127',22912,222,NULL,22,31097,0);
INSERT INTO "django_geo_db_location" VALUES(54303,NULL,'New Orleans, LA 70128',22912,222,NULL,22,31098,0);
INSERT INTO "django_geo_db_location" VALUES(54304,NULL,'New Orleans, LA 70129',22912,222,NULL,22,31099,0);
INSERT INTO "django_geo_db_location" VALUES(54305,NULL,'New Orleans, LA 70130',22912,222,NULL,22,31100,0);
INSERT INTO "django_geo_db_location" VALUES(54306,NULL,'New Orleans, LA 70131',22912,222,NULL,22,31101,0);
INSERT INTO "django_geo_db_location" VALUES(54307,NULL,'New Orleans, LA 70139',22912,222,NULL,22,31102,0);
INSERT INTO "django_geo_db_location" VALUES(54308,NULL,'New Orleans, LA 70140',22912,222,NULL,22,31103,0);
INSERT INTO "django_geo_db_location" VALUES(54309,NULL,'New Orleans, LA 70141',22912,222,NULL,22,31104,0);
INSERT INTO "django_geo_db_location" VALUES(54310,NULL,'New Orleans, LA 70142',22912,222,NULL,22,31105,0);
INSERT INTO "django_geo_db_location" VALUES(54311,NULL,'New Orleans, LA 70143',22912,222,NULL,22,31106,0);
INSERT INTO "django_geo_db_location" VALUES(54312,NULL,'New Orleans, LA 70144',22912,222,NULL,22,31107,0);
INSERT INTO "django_geo_db_location" VALUES(54313,NULL,'New Orleans, LA 70145',22912,222,NULL,22,31108,0);
INSERT INTO "django_geo_db_location" VALUES(54314,NULL,'New Orleans, LA 70146',22912,222,NULL,22,31109,0);
INSERT INTO "django_geo_db_location" VALUES(54315,NULL,'New Orleans, LA 70148',22912,222,NULL,22,31110,0);
INSERT INTO "django_geo_db_location" VALUES(54316,NULL,'New Orleans, LA 70149',22912,222,NULL,22,31111,0);
INSERT INTO "django_geo_db_location" VALUES(54317,NULL,'New Orleans, LA 70150',22912,222,NULL,22,31112,0);
INSERT INTO "django_geo_db_location" VALUES(54318,NULL,'New Orleans, LA 70151',22912,222,NULL,22,31113,0);
INSERT INTO "django_geo_db_location" VALUES(54319,NULL,'New Orleans, LA 70152',22912,222,NULL,22,31114,0);
INSERT INTO "django_geo_db_location" VALUES(54320,NULL,'New Orleans, LA 70153',22912,222,NULL,22,31115,0);
INSERT INTO "django_geo_db_location" VALUES(54321,NULL,'New Orleans, LA 70154',22912,222,NULL,22,31116,0);
INSERT INTO "django_geo_db_location" VALUES(54322,NULL,'New Orleans, LA 70155',22912,222,NULL,22,31117,0);
INSERT INTO "django_geo_db_location" VALUES(54323,NULL,'New Orleans, LA 70156',22912,222,NULL,22,31118,0);
INSERT INTO "django_geo_db_location" VALUES(54324,NULL,'New Orleans, LA 70157',22912,222,NULL,22,31119,0);
INSERT INTO "django_geo_db_location" VALUES(54325,NULL,'New Orleans, LA 70158',22912,222,NULL,22,31120,0);
INSERT INTO "django_geo_db_location" VALUES(54326,NULL,'New Orleans, LA 70159',22912,222,NULL,22,31121,0);
INSERT INTO "django_geo_db_location" VALUES(54327,NULL,'New Orleans, LA 70160',22912,222,NULL,22,31122,0);
INSERT INTO "django_geo_db_location" VALUES(54328,NULL,'New Orleans, LA 70161',22912,222,NULL,22,31123,0);
INSERT INTO "django_geo_db_location" VALUES(54329,NULL,'New Orleans, LA 70162',22912,222,NULL,22,31124,0);
INSERT INTO "django_geo_db_location" VALUES(54330,NULL,'New Orleans, LA 70163',22912,222,NULL,22,31125,0);
INSERT INTO "django_geo_db_location" VALUES(54331,NULL,'New Orleans, LA 70164',22912,222,NULL,22,31126,0);
INSERT INTO "django_geo_db_location" VALUES(54332,NULL,'New Orleans, LA 70165',22912,222,NULL,22,31127,0);
INSERT INTO "django_geo_db_location" VALUES(54333,NULL,'New Orleans, LA 70166',22912,222,NULL,22,31128,0);
INSERT INTO "django_geo_db_location" VALUES(54334,NULL,'New Orleans, LA 70167',22912,222,NULL,22,31129,0);
INSERT INTO "django_geo_db_location" VALUES(54335,NULL,'New Orleans, LA 70170',22912,222,NULL,22,31130,0);
INSERT INTO "django_geo_db_location" VALUES(54336,NULL,'New Orleans, LA 70172',22912,222,NULL,22,31131,0);
INSERT INTO "django_geo_db_location" VALUES(54337,NULL,'New Orleans, LA 70174',22912,222,NULL,22,31132,0);
INSERT INTO "django_geo_db_location" VALUES(54338,NULL,'New Orleans, LA 70175',22912,222,NULL,22,31133,0);
INSERT INTO "django_geo_db_location" VALUES(54339,NULL,'New Orleans, LA 70176',22912,222,NULL,22,31134,0);
INSERT INTO "django_geo_db_location" VALUES(54340,NULL,'New Orleans, LA 70177',22912,222,NULL,22,31135,0);
INSERT INTO "django_geo_db_location" VALUES(54341,NULL,'New Orleans, LA 70178',22912,222,NULL,22,31136,0);
INSERT INTO "django_geo_db_location" VALUES(54342,NULL,'New Orleans, LA 70179',22912,222,NULL,22,31137,0);
INSERT INTO "django_geo_db_location" VALUES(54343,NULL,'New Orleans, LA 70181',22912,222,NULL,22,31138,0);
INSERT INTO "django_geo_db_location" VALUES(54344,NULL,'New Orleans, LA 70182',22912,222,NULL,22,31139,0);
INSERT INTO "django_geo_db_location" VALUES(54345,NULL,'New Orleans, LA 70183',22912,222,NULL,22,31140,0);
INSERT INTO "django_geo_db_location" VALUES(54346,NULL,'New Orleans, LA 70184',22912,222,NULL,22,31141,0);
INSERT INTO "django_geo_db_location" VALUES(54347,NULL,'New Orleans, LA 70185',22912,222,NULL,22,31142,0);
INSERT INTO "django_geo_db_location" VALUES(54348,NULL,'New Orleans, LA 70186',22912,222,NULL,22,31143,0);
INSERT INTO "django_geo_db_location" VALUES(54349,NULL,'New Orleans, LA 70187',22912,222,NULL,22,31144,0);
INSERT INTO "django_geo_db_location" VALUES(54350,NULL,'New Orleans, LA 70189',22912,222,NULL,22,31145,0);
INSERT INTO "django_geo_db_location" VALUES(54351,NULL,'New Orleans, LA 70190',22912,222,NULL,22,31146,0);
INSERT INTO "django_geo_db_location" VALUES(54352,NULL,'New Orleans, LA 70195',22912,222,NULL,22,31147,0);
INSERT INTO "django_geo_db_location" VALUES(54353,NULL,'New Orleans, LA 70199',22912,222,NULL,22,31148,0);
INSERT INTO "django_geo_db_location" VALUES(54354,NULL,'Thibodaux, LA',22913,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54355,NULL,'Thibodaux, LA 70301',22913,222,NULL,22,31149,0);
INSERT INTO "django_geo_db_location" VALUES(54356,NULL,'Thibodaux, LA 70302',22913,222,NULL,22,31150,0);
INSERT INTO "django_geo_db_location" VALUES(54357,NULL,'Thibodaux, LA 70310',22913,222,NULL,22,31151,0);
INSERT INTO "django_geo_db_location" VALUES(54358,NULL,'Pierre Part, LA',22914,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54359,NULL,'Pierre Part, LA 70339',22914,222,NULL,22,31152,0);
INSERT INTO "django_geo_db_location" VALUES(54360,NULL,'Amelia, LA',22915,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54361,NULL,'Amelia, LA 70340',22915,222,NULL,22,31153,0);
INSERT INTO "django_geo_db_location" VALUES(54362,NULL,'Belle Rose, LA',22916,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54363,NULL,'Belle Rose, LA 70341',22916,222,NULL,22,31154,0);
INSERT INTO "django_geo_db_location" VALUES(54364,NULL,'Berwick, LA',22917,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54365,NULL,'Berwick, LA 70342',22917,222,NULL,22,31155,0);
INSERT INTO "django_geo_db_location" VALUES(54366,NULL,'Bourg, LA',22918,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54367,NULL,'Bourg, LA 70343',22918,222,NULL,22,31156,0);
INSERT INTO "django_geo_db_location" VALUES(54368,NULL,'Chauvin, LA',22919,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54369,NULL,'Chauvin, LA 70344',22919,222,NULL,22,31157,0);
INSERT INTO "django_geo_db_location" VALUES(54370,NULL,'Cut Off, LA',22920,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54371,NULL,'Cut Off, LA 70345',22920,222,NULL,22,31158,0);
INSERT INTO "django_geo_db_location" VALUES(54372,NULL,'Donaldsonville, LA',22921,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54373,NULL,'Donaldsonville, LA 70346',22921,222,NULL,22,31159,0);
INSERT INTO "django_geo_db_location" VALUES(54374,NULL,'Donner, LA',22922,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54375,NULL,'Donner, LA 70352',22922,222,NULL,22,31160,0);
INSERT INTO "django_geo_db_location" VALUES(54376,NULL,'Dulac, LA',22923,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54377,NULL,'Dulac, LA 70353',22923,222,NULL,22,31161,0);
INSERT INTO "django_geo_db_location" VALUES(54378,NULL,'Galliano, LA',22924,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54379,NULL,'Galliano, LA 70354',22924,222,NULL,22,31162,0);
INSERT INTO "django_geo_db_location" VALUES(54380,NULL,'Gheens, LA',22925,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54381,NULL,'Gheens, LA 70355',22925,222,NULL,22,31163,0);
INSERT INTO "django_geo_db_location" VALUES(54382,NULL,'Gibson, LA',22926,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54383,NULL,'Gibson, LA 70356',22926,222,NULL,22,31164,0);
INSERT INTO "django_geo_db_location" VALUES(54384,NULL,'Golden Meadow, LA',22927,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54385,NULL,'Golden Meadow, LA 70357',22927,222,NULL,22,31165,0);
INSERT INTO "django_geo_db_location" VALUES(54386,NULL,'Grand Isle, LA',22928,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54387,NULL,'Grand Isle, LA 70358',22928,222,NULL,22,31166,0);
INSERT INTO "django_geo_db_location" VALUES(54388,NULL,'Gray, LA',22929,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54389,NULL,'Gray, LA 70359',22929,222,NULL,22,31167,0);
INSERT INTO "django_geo_db_location" VALUES(54390,NULL,'Houma, LA',22930,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54391,NULL,'Houma, LA 70360',22930,222,NULL,22,31168,0);
INSERT INTO "django_geo_db_location" VALUES(54392,NULL,'Houma, LA 70361',22930,222,NULL,22,31169,0);
INSERT INTO "django_geo_db_location" VALUES(54393,NULL,'Houma, LA 70363',22930,222,NULL,22,31170,0);
INSERT INTO "django_geo_db_location" VALUES(54394,NULL,'Houma, LA 70364',22930,222,NULL,22,31171,0);
INSERT INTO "django_geo_db_location" VALUES(54395,NULL,'Houma, LA 70369',22930,222,NULL,22,31172,0);
INSERT INTO "django_geo_db_location" VALUES(54396,NULL,'Kraemer, LA',22931,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54397,NULL,'Kraemer, LA 70371',22931,222,NULL,22,31173,0);
INSERT INTO "django_geo_db_location" VALUES(54398,NULL,'Labadieville, LA',22932,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54399,NULL,'Labadieville, LA 70372',22932,222,NULL,22,31174,0);
INSERT INTO "django_geo_db_location" VALUES(54400,NULL,'Larose, LA',22933,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54401,NULL,'Larose, LA 70373',22933,222,NULL,22,31175,0);
INSERT INTO "django_geo_db_location" VALUES(54402,NULL,'Lockport, LA',22934,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54403,NULL,'Lockport, LA 70374',22934,222,NULL,22,31176,0);
INSERT INTO "django_geo_db_location" VALUES(54404,NULL,'Mathews, LA',22935,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54405,NULL,'Mathews, LA 70375',22935,222,NULL,22,31177,0);
INSERT INTO "django_geo_db_location" VALUES(54406,NULL,'Modeste, LA',22936,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54407,NULL,'Modeste, LA 70376',22936,222,NULL,22,31178,0);
INSERT INTO "django_geo_db_location" VALUES(54408,NULL,'Montegut, LA',22937,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54409,NULL,'Montegut, LA 70377',22937,222,NULL,22,31179,0);
INSERT INTO "django_geo_db_location" VALUES(54410,NULL,'Morgan City, LA',22938,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54411,NULL,'Morgan City, LA 70380',22938,222,NULL,22,31180,0);
INSERT INTO "django_geo_db_location" VALUES(54412,NULL,'Morgan City, LA 70381',22938,222,NULL,22,31181,0);
INSERT INTO "django_geo_db_location" VALUES(54413,NULL,'Cankton, LA',22939,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54414,NULL,'Cankton, LA 70384',22939,222,NULL,22,31182,0);
INSERT INTO "django_geo_db_location" VALUES(54415,NULL,'Napoleonville, LA',22940,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54416,NULL,'Napoleonville, LA 70390',22940,222,NULL,22,31183,0);
INSERT INTO "django_geo_db_location" VALUES(54417,NULL,'Paincourtville, LA',22941,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54418,NULL,'Paincourtville, LA 70391',22941,222,NULL,22,31184,0);
INSERT INTO "django_geo_db_location" VALUES(54419,NULL,'Patterson, LA',22942,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54420,NULL,'Patterson, LA 70392',22942,222,NULL,22,31185,0);
INSERT INTO "django_geo_db_location" VALUES(54421,NULL,'Plattenville, LA',22943,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54422,NULL,'Plattenville, LA 70393',22943,222,NULL,22,31186,0);
INSERT INTO "django_geo_db_location" VALUES(54423,NULL,'Raceland, LA',22944,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54424,NULL,'Raceland, LA 70394',22944,222,NULL,22,31187,0);
INSERT INTO "django_geo_db_location" VALUES(54425,NULL,'Schriever, LA',22945,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54426,NULL,'Schriever, LA 70395',22945,222,NULL,22,31188,0);
INSERT INTO "django_geo_db_location" VALUES(54427,NULL,'Theriot, LA',22946,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54428,NULL,'Theriot, LA 70397',22946,222,NULL,22,31189,0);
INSERT INTO "django_geo_db_location" VALUES(54429,NULL,'Hammond, LA',22947,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54430,NULL,'Hammond, LA 70401',22947,222,NULL,22,31190,0);
INSERT INTO "django_geo_db_location" VALUES(54431,NULL,'Hammond, LA 70402',22947,222,NULL,22,31191,0);
INSERT INTO "django_geo_db_location" VALUES(54432,NULL,'Hammond, LA 70403',22947,222,NULL,22,31192,0);
INSERT INTO "django_geo_db_location" VALUES(54433,NULL,'Hammond, LA 70404',22947,222,NULL,22,31193,0);
INSERT INTO "django_geo_db_location" VALUES(54434,NULL,'Abita Springs, LA',22948,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54435,NULL,'Abita Springs, LA 70420',22948,222,NULL,22,31194,0);
INSERT INTO "django_geo_db_location" VALUES(54436,NULL,'Akers, LA',22949,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54437,NULL,'Akers, LA 70421',22949,222,NULL,22,31195,0);
INSERT INTO "django_geo_db_location" VALUES(54438,NULL,'Amite, LA',22950,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54439,NULL,'Amite, LA 70422',22950,222,NULL,22,31196,0);
INSERT INTO "django_geo_db_location" VALUES(54440,NULL,'Angie, LA',22951,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54441,NULL,'Angie, LA 70426',22951,222,NULL,22,31197,0);
INSERT INTO "django_geo_db_location" VALUES(54442,NULL,'Bogalusa, LA',22952,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54443,NULL,'Bogalusa, LA 70427',22952,222,NULL,22,31198,0);
INSERT INTO "django_geo_db_location" VALUES(54444,NULL,'Sun, LA',22953,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54445,NULL,'Sun, LA 70428',22953,222,NULL,22,31199,0);
INSERT INTO "django_geo_db_location" VALUES(54446,NULL,'Bogalusa, LA 70429',22952,222,NULL,22,31200,0);
INSERT INTO "django_geo_db_location" VALUES(54447,NULL,'Bush, LA',22954,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54448,NULL,'Bush, LA 70431',22954,222,NULL,22,31201,0);
INSERT INTO "django_geo_db_location" VALUES(54449,NULL,'Covington, LA',22955,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54450,NULL,'Covington, LA 70432',22955,222,NULL,22,31202,0);
INSERT INTO "django_geo_db_location" VALUES(54451,NULL,'Covington, LA 70433',22955,222,NULL,22,31203,0);
INSERT INTO "django_geo_db_location" VALUES(54452,NULL,'Covington, LA 70434',22955,222,NULL,22,31204,0);
INSERT INTO "django_geo_db_location" VALUES(54453,NULL,'Covington, LA 70435',22955,222,NULL,22,31205,0);
INSERT INTO "django_geo_db_location" VALUES(54454,NULL,'Fluker, LA',22956,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54455,NULL,'Fluker, LA 70436',22956,222,NULL,22,31206,0);
INSERT INTO "django_geo_db_location" VALUES(54456,NULL,'Folsom, LA',22957,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54457,NULL,'Folsom, LA 70437',22957,222,NULL,22,31207,0);
INSERT INTO "django_geo_db_location" VALUES(54458,NULL,'Franklinton, LA',22958,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54459,NULL,'Franklinton, LA 70438',22958,222,NULL,22,31208,0);
INSERT INTO "django_geo_db_location" VALUES(54460,NULL,'Mandeville, LA',22959,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54461,NULL,'Mandeville, LA 70440',22959,222,NULL,22,31209,0);
INSERT INTO "django_geo_db_location" VALUES(54462,NULL,'Greensburg, LA',22960,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54463,NULL,'Greensburg, LA 70441',22960,222,NULL,22,31210,0);
INSERT INTO "django_geo_db_location" VALUES(54464,NULL,'Husser, LA',22961,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54465,NULL,'Husser, LA 70442',22961,222,NULL,22,31211,0);
INSERT INTO "django_geo_db_location" VALUES(54466,NULL,'Independence, LA',22962,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54467,NULL,'Independence, LA 70443',22962,222,NULL,22,31212,0);
INSERT INTO "django_geo_db_location" VALUES(54468,NULL,'Kentwood, LA',22963,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54469,NULL,'Kentwood, LA 70444',22963,222,NULL,22,31213,0);
INSERT INTO "django_geo_db_location" VALUES(54470,NULL,'Lacombe, LA',22964,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54471,NULL,'Lacombe, LA 70445',22964,222,NULL,22,31214,0);
INSERT INTO "django_geo_db_location" VALUES(54472,NULL,'Loranger, LA',22965,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54473,NULL,'Loranger, LA 70446',22965,222,NULL,22,31215,0);
INSERT INTO "django_geo_db_location" VALUES(54474,NULL,'Madisonville, LA',22966,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54475,NULL,'Madisonville, LA 70447',22966,222,NULL,22,31216,0);
INSERT INTO "django_geo_db_location" VALUES(54476,NULL,'Mandeville, LA 70448',22959,222,NULL,22,31217,0);
INSERT INTO "django_geo_db_location" VALUES(54477,NULL,'Maurepas, LA',22967,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54478,NULL,'Maurepas, LA 70449',22967,222,NULL,22,31218,0);
INSERT INTO "django_geo_db_location" VALUES(54479,NULL,'Mount Hermon, LA',22968,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54480,NULL,'Mount Hermon, LA 70450',22968,222,NULL,22,31219,0);
INSERT INTO "django_geo_db_location" VALUES(54481,NULL,'Natalbany, LA',22969,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54482,NULL,'Natalbany, LA 70451',22969,222,NULL,22,31220,0);
INSERT INTO "django_geo_db_location" VALUES(54483,NULL,'Pearl River, LA',22970,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54484,NULL,'Pearl River, LA 70452',22970,222,NULL,22,31221,0);
INSERT INTO "django_geo_db_location" VALUES(54485,NULL,'Pine Grove, LA',22971,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54486,NULL,'Pine Grove, LA 70453',22971,222,NULL,22,31222,0);
INSERT INTO "django_geo_db_location" VALUES(54487,NULL,'Ponchatoula, LA',22972,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54488,NULL,'Ponchatoula, LA 70454',22972,222,NULL,22,31223,0);
INSERT INTO "django_geo_db_location" VALUES(54489,NULL,'Robert, LA',22973,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54490,NULL,'Robert, LA 70455',22973,222,NULL,22,31224,0);
INSERT INTO "django_geo_db_location" VALUES(54491,NULL,'Roseland, LA',22974,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54492,NULL,'Roseland, LA 70456',22974,222,NULL,22,31225,0);
INSERT INTO "django_geo_db_location" VALUES(54493,NULL,'Saint Benedict, LA',22975,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54494,NULL,'Saint Benedict, LA 70457',22975,222,NULL,22,31226,0);
INSERT INTO "django_geo_db_location" VALUES(54495,NULL,'Slidell, LA',22976,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54496,NULL,'Slidell, LA 70458',22976,222,NULL,22,31227,0);
INSERT INTO "django_geo_db_location" VALUES(54497,NULL,'Slidell, LA 70459',22976,222,NULL,22,31228,0);
INSERT INTO "django_geo_db_location" VALUES(54498,NULL,'Slidell, LA 70460',22976,222,NULL,22,31229,0);
INSERT INTO "django_geo_db_location" VALUES(54499,NULL,'Slidell, LA 70461',22976,222,NULL,22,31230,0);
INSERT INTO "django_geo_db_location" VALUES(54500,NULL,'Springfield, LA',22977,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54501,NULL,'Springfield, LA 70462',22977,222,NULL,22,31231,0);
INSERT INTO "django_geo_db_location" VALUES(54502,NULL,'Sun, LA 70463',22953,222,NULL,22,31232,0);
INSERT INTO "django_geo_db_location" VALUES(54503,NULL,'Talisheek, LA',22978,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54504,NULL,'Talisheek, LA 70464',22978,222,NULL,22,31233,0);
INSERT INTO "django_geo_db_location" VALUES(54505,NULL,'Tangipahoa, LA',22979,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54506,NULL,'Tangipahoa, LA 70465',22979,222,NULL,22,31234,0);
INSERT INTO "django_geo_db_location" VALUES(54507,NULL,'Tickfaw, LA',22980,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54508,NULL,'Tickfaw, LA 70466',22980,222,NULL,22,31235,0);
INSERT INTO "django_geo_db_location" VALUES(54509,NULL,'Angie, LA 70467',22951,222,NULL,22,31236,0);
INSERT INTO "django_geo_db_location" VALUES(54510,NULL,'Slidell, LA 70469',22976,222,NULL,22,31237,0);
INSERT INTO "django_geo_db_location" VALUES(54511,NULL,'Mandeville, LA 70470',22959,222,NULL,22,31238,0);
INSERT INTO "django_geo_db_location" VALUES(54512,NULL,'Mandeville, LA 70471',22959,222,NULL,22,31239,0);
INSERT INTO "django_geo_db_location" VALUES(54513,NULL,'Ponchatoula, LA 70494',22972,222,NULL,22,31240,0);
INSERT INTO "django_geo_db_location" VALUES(54514,NULL,'Franklinton, LA 70499',22958,222,NULL,22,31241,0);
INSERT INTO "django_geo_db_location" VALUES(54515,NULL,'Lafayette, LA',22981,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54516,NULL,'Lafayette, LA 70501',22981,222,NULL,22,31242,0);
INSERT INTO "django_geo_db_location" VALUES(54517,NULL,'Lafayette, LA 70502',22981,222,NULL,22,31243,0);
INSERT INTO "django_geo_db_location" VALUES(54518,NULL,'Lafayette, LA 70503',22981,222,NULL,22,31244,0);
INSERT INTO "django_geo_db_location" VALUES(54519,NULL,'Lafayette, LA 70504',22981,222,NULL,22,31245,0);
INSERT INTO "django_geo_db_location" VALUES(54520,NULL,'Lafayette, LA 70505',22981,222,NULL,22,31246,0);
INSERT INTO "django_geo_db_location" VALUES(54521,NULL,'Lafayette, LA 70506',22981,222,NULL,22,31247,0);
INSERT INTO "django_geo_db_location" VALUES(54522,NULL,'Lafayette, LA 70507',22981,222,NULL,22,31248,0);
INSERT INTO "django_geo_db_location" VALUES(54523,NULL,'Lafayette, LA 70508',22981,222,NULL,22,31249,0);
INSERT INTO "django_geo_db_location" VALUES(54524,NULL,'Lafayette, LA 70509',22981,222,NULL,22,31250,0);
INSERT INTO "django_geo_db_location" VALUES(54525,NULL,'Abbeville, LA',22982,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54526,NULL,'Abbeville, LA 70510',22982,222,NULL,22,31251,0);
INSERT INTO "django_geo_db_location" VALUES(54527,NULL,'Abbeville, LA 70511',22982,222,NULL,22,31252,0);
INSERT INTO "django_geo_db_location" VALUES(54528,NULL,'Arnaudville, LA',22983,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54529,NULL,'Arnaudville, LA 70512',22983,222,NULL,22,31253,0);
INSERT INTO "django_geo_db_location" VALUES(54530,NULL,'Avery Island, LA',22984,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54531,NULL,'Avery Island, LA 70513',22984,222,NULL,22,31254,0);
INSERT INTO "django_geo_db_location" VALUES(54532,NULL,'Baldwin, LA',22985,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54533,NULL,'Baldwin, LA 70514',22985,222,NULL,22,31255,0);
INSERT INTO "django_geo_db_location" VALUES(54534,NULL,'Basile, LA',22986,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54535,NULL,'Basile, LA 70515',22986,222,NULL,22,31256,0);
INSERT INTO "django_geo_db_location" VALUES(54536,NULL,'Branch, LA',22987,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54537,NULL,'Branch, LA 70516',22987,222,NULL,22,31257,0);
INSERT INTO "django_geo_db_location" VALUES(54538,NULL,'Breaux Bridge, LA',22988,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54539,NULL,'Breaux Bridge, LA 70517',22988,222,NULL,22,31258,0);
INSERT INTO "django_geo_db_location" VALUES(54540,NULL,'Broussard, LA',22989,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54541,NULL,'Broussard, LA 70518',22989,222,NULL,22,31259,0);
INSERT INTO "django_geo_db_location" VALUES(54542,NULL,'Cade, LA',22990,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54543,NULL,'Cade, LA 70519',22990,222,NULL,22,31260,0);
INSERT INTO "django_geo_db_location" VALUES(54544,NULL,'Carencro, LA',22991,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54545,NULL,'Carencro, LA 70520',22991,222,NULL,22,31261,0);
INSERT INTO "django_geo_db_location" VALUES(54546,NULL,'Cecilia, LA',22992,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54547,NULL,'Cecilia, LA 70521',22992,222,NULL,22,31262,0);
INSERT INTO "django_geo_db_location" VALUES(54548,NULL,'Centerville, LA',22993,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54549,NULL,'Centerville, LA 70522',22993,222,NULL,22,31263,0);
INSERT INTO "django_geo_db_location" VALUES(54550,NULL,'Charenton, LA',22994,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54551,NULL,'Charenton, LA 70523',22994,222,NULL,22,31264,0);
INSERT INTO "django_geo_db_location" VALUES(54552,NULL,'Chataignier, LA',22995,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54553,NULL,'Chataignier, LA 70524',22995,222,NULL,22,31265,0);
INSERT INTO "django_geo_db_location" VALUES(54554,NULL,'Church Point, LA',22996,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54555,NULL,'Church Point, LA 70525',22996,222,NULL,22,31266,0);
INSERT INTO "django_geo_db_location" VALUES(54556,NULL,'Crowley, LA',22997,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54557,NULL,'Crowley, LA 70526',22997,222,NULL,22,31267,0);
INSERT INTO "django_geo_db_location" VALUES(54558,NULL,'Crowley, LA 70527',22997,222,NULL,22,31268,0);
INSERT INTO "django_geo_db_location" VALUES(54559,NULL,'Delcambre, LA',22998,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54560,NULL,'Delcambre, LA 70528',22998,222,NULL,22,31269,0);
INSERT INTO "django_geo_db_location" VALUES(54561,NULL,'Duson, LA',22999,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54562,NULL,'Duson, LA 70529',22999,222,NULL,22,31270,0);
INSERT INTO "django_geo_db_location" VALUES(54563,NULL,'Egan, LA',23000,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54564,NULL,'Egan, LA 70531',23000,222,NULL,22,31271,0);
INSERT INTO "django_geo_db_location" VALUES(54565,NULL,'Elton, LA',23001,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54566,NULL,'Elton, LA 70532',23001,222,NULL,22,31272,0);
INSERT INTO "django_geo_db_location" VALUES(54567,NULL,'Erath, LA',23002,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54568,NULL,'Erath, LA 70533',23002,222,NULL,22,31273,0);
INSERT INTO "django_geo_db_location" VALUES(54569,NULL,'Estherwood, LA',23003,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54570,NULL,'Estherwood, LA 70534',23003,222,NULL,22,31274,0);
INSERT INTO "django_geo_db_location" VALUES(54571,NULL,'Eunice, LA',23004,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54572,NULL,'Eunice, LA 70535',23004,222,NULL,22,31275,0);
INSERT INTO "django_geo_db_location" VALUES(54573,NULL,'Evangeline, LA',23005,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54574,NULL,'Evangeline, LA 70537',23005,222,NULL,22,31276,0);
INSERT INTO "django_geo_db_location" VALUES(54575,NULL,'Franklin, LA',23006,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54576,NULL,'Franklin, LA 70538',23006,222,NULL,22,31277,0);
INSERT INTO "django_geo_db_location" VALUES(54577,NULL,'Garden City, LA',23007,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54578,NULL,'Garden City, LA 70540',23007,222,NULL,22,31278,0);
INSERT INTO "django_geo_db_location" VALUES(54579,NULL,'Grand Coteau, LA',23008,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54580,NULL,'Grand Coteau, LA 70541',23008,222,NULL,22,31279,0);
INSERT INTO "django_geo_db_location" VALUES(54581,NULL,'Gueydan, LA',23009,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54582,NULL,'Gueydan, LA 70542',23009,222,NULL,22,31280,0);
INSERT INTO "django_geo_db_location" VALUES(54583,NULL,'Iota, LA',23010,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54584,NULL,'Iota, LA 70543',23010,222,NULL,22,31281,0);
INSERT INTO "django_geo_db_location" VALUES(54585,NULL,'Jeanerette, LA',23011,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54586,NULL,'Jeanerette, LA 70544',23011,222,NULL,22,31282,0);
INSERT INTO "django_geo_db_location" VALUES(54587,NULL,'Jennings, LA',23012,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54588,NULL,'Jennings, LA 70546',23012,222,NULL,22,31283,0);
INSERT INTO "django_geo_db_location" VALUES(54589,NULL,'Kaplan, LA',23013,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54590,NULL,'Kaplan, LA 70548',23013,222,NULL,22,31284,0);
INSERT INTO "django_geo_db_location" VALUES(54591,NULL,'Lake Arthur, LA',23014,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54592,NULL,'Lake Arthur, LA 70549',23014,222,NULL,22,31285,0);
INSERT INTO "django_geo_db_location" VALUES(54593,NULL,'Lawtell, LA',23015,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54594,NULL,'Lawtell, LA 70550',23015,222,NULL,22,31286,0);
INSERT INTO "django_geo_db_location" VALUES(54595,NULL,'Leonville, LA',23016,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54596,NULL,'Leonville, LA 70551',23016,222,NULL,22,31287,0);
INSERT INTO "django_geo_db_location" VALUES(54597,NULL,'Loreauville, LA',23017,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54598,NULL,'Loreauville, LA 70552',23017,222,NULL,22,31288,0);
INSERT INTO "django_geo_db_location" VALUES(54599,NULL,'Mamou, LA',23018,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54600,NULL,'Mamou, LA 70554',23018,222,NULL,22,31289,0);
INSERT INTO "django_geo_db_location" VALUES(54601,NULL,'Maurice, LA',23019,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54602,NULL,'Maurice, LA 70555',23019,222,NULL,22,31290,0);
INSERT INTO "django_geo_db_location" VALUES(54603,NULL,'Mermentau, LA',23020,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54604,NULL,'Mermentau, LA 70556',23020,222,NULL,22,31291,0);
INSERT INTO "django_geo_db_location" VALUES(54605,NULL,'Milton, LA',23021,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54606,NULL,'Milton, LA 70558',23021,222,NULL,22,31292,0);
INSERT INTO "django_geo_db_location" VALUES(54607,NULL,'Morse, LA',23022,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54608,NULL,'Morse, LA 70559',23022,222,NULL,22,31293,0);
INSERT INTO "django_geo_db_location" VALUES(54609,NULL,'New Iberia, LA',23023,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54610,NULL,'New Iberia, LA 70560',23023,222,NULL,22,31294,0);
INSERT INTO "django_geo_db_location" VALUES(54611,NULL,'New Iberia, LA 70562',23023,222,NULL,22,31295,0);
INSERT INTO "django_geo_db_location" VALUES(54612,NULL,'New Iberia, LA 70563',23023,222,NULL,22,31296,0);
INSERT INTO "django_geo_db_location" VALUES(54613,NULL,'Lydia, LA',23024,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54614,NULL,'Lydia, LA 70569',23024,222,NULL,22,31297,0);
INSERT INTO "django_geo_db_location" VALUES(54615,NULL,'Opelousas, LA',23025,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54616,NULL,'Opelousas, LA 70570',23025,222,NULL,22,31298,0);
INSERT INTO "django_geo_db_location" VALUES(54617,NULL,'Opelousas, LA 70571',23025,222,NULL,22,31299,0);
INSERT INTO "django_geo_db_location" VALUES(54618,NULL,'Perry, LA',23026,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54619,NULL,'Perry, LA 70575',23026,222,NULL,22,31300,0);
INSERT INTO "django_geo_db_location" VALUES(54620,NULL,'Pine Prairie, LA',23027,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54621,NULL,'Pine Prairie, LA 70576',23027,222,NULL,22,31301,0);
INSERT INTO "django_geo_db_location" VALUES(54622,NULL,'Port Barre, LA',23028,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54623,NULL,'Port Barre, LA 70577',23028,222,NULL,22,31302,0);
INSERT INTO "django_geo_db_location" VALUES(54624,NULL,'Rayne, LA',23029,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54625,NULL,'Rayne, LA 70578',23029,222,NULL,22,31303,0);
INSERT INTO "django_geo_db_location" VALUES(54626,NULL,'Reddell, LA',23030,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54627,NULL,'Reddell, LA 70580',23030,222,NULL,22,31304,0);
INSERT INTO "django_geo_db_location" VALUES(54628,NULL,'Roanoke, LA',23031,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54629,NULL,'Roanoke, LA 70581',23031,222,NULL,22,31305,0);
INSERT INTO "django_geo_db_location" VALUES(54630,NULL,'Saint Martinville, LA',23032,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54631,NULL,'Saint Martinville, LA 70582',23032,222,NULL,22,31306,0);
INSERT INTO "django_geo_db_location" VALUES(54632,NULL,'Scott, LA',23033,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54633,NULL,'Scott, LA 70583',23033,222,NULL,22,31307,0);
INSERT INTO "django_geo_db_location" VALUES(54634,NULL,'Sunset, LA',23034,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54635,NULL,'Sunset, LA 70584',23034,222,NULL,22,31308,0);
INSERT INTO "django_geo_db_location" VALUES(54636,NULL,'Turkey Creek, LA',23035,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54637,NULL,'Turkey Creek, LA 70585',23035,222,NULL,22,31309,0);
INSERT INTO "django_geo_db_location" VALUES(54638,NULL,'Ville Platte, LA',23036,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54639,NULL,'Ville Platte, LA 70586',23036,222,NULL,22,31310,0);
INSERT INTO "django_geo_db_location" VALUES(54640,NULL,'Washington, LA',23037,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54641,NULL,'Washington, LA 70589',23037,222,NULL,22,31311,0);
INSERT INTO "django_geo_db_location" VALUES(54642,NULL,'Welsh, LA',23038,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54643,NULL,'Welsh, LA 70591',23038,222,NULL,22,31312,0);
INSERT INTO "django_geo_db_location" VALUES(54644,NULL,'Youngsville, LA',23039,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54645,NULL,'Youngsville, LA 70592',23039,222,NULL,22,31313,0);
INSERT INTO "django_geo_db_location" VALUES(54646,NULL,'Lafayette, LA 70593',22981,222,NULL,22,31314,0);
INSERT INTO "django_geo_db_location" VALUES(54647,NULL,'Raceland, LA 70594',22944,222,NULL,22,31315,0);
INSERT INTO "django_geo_db_location" VALUES(54648,NULL,'Lafayette, LA 70596',22981,222,NULL,22,31316,0);
INSERT INTO "django_geo_db_location" VALUES(54649,NULL,'Lafayette, LA 70598',22981,222,NULL,22,31317,0);
INSERT INTO "django_geo_db_location" VALUES(54650,NULL,'Lake Charles, LA',23040,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54651,NULL,'Lake Charles, LA 70601',23040,222,NULL,22,31318,0);
INSERT INTO "django_geo_db_location" VALUES(54652,NULL,'Lake Charles, LA 70602',23040,222,NULL,22,31319,0);
INSERT INTO "django_geo_db_location" VALUES(54653,NULL,'Lake Charles, LA 70605',23040,222,NULL,22,31320,0);
INSERT INTO "django_geo_db_location" VALUES(54654,NULL,'Lake Charles, LA 70606',23040,222,NULL,22,31321,0);
INSERT INTO "django_geo_db_location" VALUES(54655,NULL,'Lake Charles, LA 70607',23040,222,NULL,22,31322,0);
INSERT INTO "django_geo_db_location" VALUES(54656,NULL,'Lake Charles, LA 70609',23040,222,NULL,22,31323,0);
INSERT INTO "django_geo_db_location" VALUES(54657,NULL,'Lake Charles, LA 70611',23040,222,NULL,22,31324,0);
INSERT INTO "django_geo_db_location" VALUES(54658,NULL,'Lake Charles, LA 70612',23040,222,NULL,22,31325,0);
INSERT INTO "django_geo_db_location" VALUES(54659,NULL,'Lake Charles, LA 70615',23040,222,NULL,22,31326,0);
INSERT INTO "django_geo_db_location" VALUES(54660,NULL,'Lake Charles, LA 70616',23040,222,NULL,22,31327,0);
INSERT INTO "django_geo_db_location" VALUES(54661,NULL,'Lake Charles, LA 70629',23040,222,NULL,22,31328,0);
INSERT INTO "django_geo_db_location" VALUES(54662,NULL,'Bell City, LA',23041,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54663,NULL,'Bell City, LA 70630',23041,222,NULL,22,31329,0);
INSERT INTO "django_geo_db_location" VALUES(54664,NULL,'Cameron, LA',23042,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54665,NULL,'Cameron, LA 70631',23042,222,NULL,22,31330,0);
INSERT INTO "django_geo_db_location" VALUES(54666,NULL,'Creole, LA',23043,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54667,NULL,'Creole, LA 70632',23043,222,NULL,22,31331,0);
INSERT INTO "django_geo_db_location" VALUES(54668,NULL,'Dequincy, LA',23044,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54669,NULL,'Dequincy, LA 70633',23044,222,NULL,22,31332,0);
INSERT INTO "django_geo_db_location" VALUES(54670,NULL,'Deridder, LA',23045,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54671,NULL,'Deridder, LA 70634',23045,222,NULL,22,31333,0);
INSERT INTO "django_geo_db_location" VALUES(54672,NULL,'Dry Creek, LA',23046,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54673,NULL,'Dry Creek, LA 70637',23046,222,NULL,22,31334,0);
INSERT INTO "django_geo_db_location" VALUES(54674,NULL,'Elizabeth, LA',23047,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54675,NULL,'Elizabeth, LA 70638',23047,222,NULL,22,31335,0);
INSERT INTO "django_geo_db_location" VALUES(54676,NULL,'Evans, LA',23048,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54677,NULL,'Evans, LA 70639',23048,222,NULL,22,31336,0);
INSERT INTO "django_geo_db_location" VALUES(54678,NULL,'Fenton, LA',23049,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54679,NULL,'Fenton, LA 70640',23049,222,NULL,22,31337,0);
INSERT INTO "django_geo_db_location" VALUES(54680,NULL,'Fullerton, LA',23050,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54681,NULL,'Fullerton, LA 70642',23050,222,NULL,22,31338,0);
INSERT INTO "django_geo_db_location" VALUES(54682,NULL,'Grand Chenier, LA',23051,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54683,NULL,'Grand Chenier, LA 70643',23051,222,NULL,22,31339,0);
INSERT INTO "django_geo_db_location" VALUES(54684,NULL,'Grant, LA',23052,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54685,NULL,'Grant, LA 70644',23052,222,NULL,22,31340,0);
INSERT INTO "django_geo_db_location" VALUES(54686,NULL,'Hackberry, LA',23053,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54687,NULL,'Hackberry, LA 70645',23053,222,NULL,22,31341,0);
INSERT INTO "django_geo_db_location" VALUES(54688,NULL,'Hayes, LA',23054,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54689,NULL,'Hayes, LA 70646',23054,222,NULL,22,31342,0);
INSERT INTO "django_geo_db_location" VALUES(54690,NULL,'Iowa, LA',23055,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54691,NULL,'Iowa, LA 70647',23055,222,NULL,22,31343,0);
INSERT INTO "django_geo_db_location" VALUES(54692,NULL,'Kinder, LA',23056,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54693,NULL,'Kinder, LA 70648',23056,222,NULL,22,31344,0);
INSERT INTO "django_geo_db_location" VALUES(54694,NULL,'Lacassine, LA',23057,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54695,NULL,'Lacassine, LA 70650',23057,222,NULL,22,31345,0);
INSERT INTO "django_geo_db_location" VALUES(54696,NULL,'Leblanc, LA',23058,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54697,NULL,'Leblanc, LA 70651',23058,222,NULL,22,31346,0);
INSERT INTO "django_geo_db_location" VALUES(54698,NULL,'Longville, LA',23059,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54699,NULL,'Longville, LA 70652',23059,222,NULL,22,31347,0);
INSERT INTO "django_geo_db_location" VALUES(54700,NULL,'Merryville, LA',23060,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54701,NULL,'Merryville, LA 70653',23060,222,NULL,22,31348,0);
INSERT INTO "django_geo_db_location" VALUES(54702,NULL,'Mittie, LA',23061,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54703,NULL,'Mittie, LA 70654',23061,222,NULL,22,31349,0);
INSERT INTO "django_geo_db_location" VALUES(54704,NULL,'Oberlin, LA',23062,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54705,NULL,'Oberlin, LA 70655',23062,222,NULL,22,31350,0);
INSERT INTO "django_geo_db_location" VALUES(54706,NULL,'Pitkin, LA',23063,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54707,NULL,'Pitkin, LA 70656',23063,222,NULL,22,31351,0);
INSERT INTO "django_geo_db_location" VALUES(54708,NULL,'Ragley, LA',23064,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54709,NULL,'Ragley, LA 70657',23064,222,NULL,22,31352,0);
INSERT INTO "django_geo_db_location" VALUES(54710,NULL,'Reeves, LA',23065,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54711,NULL,'Reeves, LA 70658',23065,222,NULL,22,31353,0);
INSERT INTO "django_geo_db_location" VALUES(54712,NULL,'Rosepine, LA',23066,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54713,NULL,'Rosepine, LA 70659',23066,222,NULL,22,31354,0);
INSERT INTO "django_geo_db_location" VALUES(54714,NULL,'Singer, LA',23067,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54715,NULL,'Singer, LA 70660',23067,222,NULL,22,31355,0);
INSERT INTO "django_geo_db_location" VALUES(54716,NULL,'Starks, LA',23068,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54717,NULL,'Starks, LA 70661',23068,222,NULL,22,31356,0);
INSERT INTO "django_geo_db_location" VALUES(54718,NULL,'Sugartown, LA',23069,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54719,NULL,'Sugartown, LA 70662',23069,222,NULL,22,31357,0);
INSERT INTO "django_geo_db_location" VALUES(54720,NULL,'Sulphur, LA',23070,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54721,NULL,'Sulphur, LA 70663',23070,222,NULL,22,31358,0);
INSERT INTO "django_geo_db_location" VALUES(54722,NULL,'Sulphur, LA 70664',23070,222,NULL,22,31359,0);
INSERT INTO "django_geo_db_location" VALUES(54723,NULL,'Sulphur, LA 70665',23070,222,NULL,22,31360,0);
INSERT INTO "django_geo_db_location" VALUES(54724,NULL,'Vinton, LA',23071,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54725,NULL,'Vinton, LA 70668',23071,222,NULL,22,31361,0);
INSERT INTO "django_geo_db_location" VALUES(54726,NULL,'Westlake, LA',23072,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54727,NULL,'Westlake, LA 70669',23072,222,NULL,22,31362,0);
INSERT INTO "django_geo_db_location" VALUES(54728,NULL,'Baker, LA',23073,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54729,NULL,'Baker, LA 70704',23073,222,NULL,22,31363,0);
INSERT INTO "django_geo_db_location" VALUES(54730,NULL,'Denham Springs, LA',23074,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54731,NULL,'Denham Springs, LA 70706',23074,222,NULL,22,31364,0);
INSERT INTO "django_geo_db_location" VALUES(54732,NULL,'Gonzales, LA',23075,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54733,NULL,'Gonzales, LA 70707',23075,222,NULL,22,31365,0);
INSERT INTO "django_geo_db_location" VALUES(54734,NULL,'Addis, LA',23076,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54735,NULL,'Addis, LA 70710',23076,222,NULL,22,31366,0);
INSERT INTO "django_geo_db_location" VALUES(54736,NULL,'Albany, LA',23077,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54737,NULL,'Albany, LA 70711',23077,222,NULL,22,31367,0);
INSERT INTO "django_geo_db_location" VALUES(54738,NULL,'Angola, LA',23078,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54739,NULL,'Angola, LA 70712',23078,222,NULL,22,31368,0);
INSERT INTO "django_geo_db_location" VALUES(54740,NULL,'Baker, LA 70714',23073,222,NULL,22,31369,0);
INSERT INTO "django_geo_db_location" VALUES(54741,NULL,'Batchelor, LA',23079,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54742,NULL,'Batchelor, LA 70715',23079,222,NULL,22,31370,0);
INSERT INTO "django_geo_db_location" VALUES(54743,NULL,'Bayou Goula, LA',23080,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54744,NULL,'Bayou Goula, LA 70716',23080,222,NULL,22,31371,0);
INSERT INTO "django_geo_db_location" VALUES(54745,NULL,'Blanks, LA',23081,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54746,NULL,'Blanks, LA 70717',23081,222,NULL,22,31372,0);
INSERT INTO "django_geo_db_location" VALUES(54747,NULL,'Brittany, LA',23082,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54748,NULL,'Brittany, LA 70718',23082,222,NULL,22,31373,0);
INSERT INTO "django_geo_db_location" VALUES(54749,NULL,'Brusly, LA',23083,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54750,NULL,'Brusly, LA 70719',23083,222,NULL,22,31374,0);
INSERT INTO "django_geo_db_location" VALUES(54751,NULL,'Bueche, LA',23084,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54752,NULL,'Bueche, LA 70720',23084,222,NULL,22,31375,0);
INSERT INTO "django_geo_db_location" VALUES(54753,NULL,'Carville, LA',23085,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54754,NULL,'Carville, LA 70721',23085,222,NULL,22,31376,0);
INSERT INTO "django_geo_db_location" VALUES(54755,NULL,'Clinton, LA',23086,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54756,NULL,'Clinton, LA 70722',23086,222,NULL,22,31377,0);
INSERT INTO "django_geo_db_location" VALUES(54757,NULL,'Convent, LA',23087,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54758,NULL,'Convent, LA 70723',23087,222,NULL,22,31378,0);
INSERT INTO "django_geo_db_location" VALUES(54759,NULL,'Darrow, LA',23088,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54760,NULL,'Darrow, LA 70725',23088,222,NULL,22,31379,0);
INSERT INTO "django_geo_db_location" VALUES(54761,NULL,'Denham Springs, LA 70726',23074,222,NULL,22,31380,0);
INSERT INTO "django_geo_db_location" VALUES(54762,NULL,'Denham Springs, LA 70727',23074,222,NULL,22,31381,0);
INSERT INTO "django_geo_db_location" VALUES(54763,NULL,'Duplessis, LA',23089,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54764,NULL,'Duplessis, LA 70728',23089,222,NULL,22,31382,0);
INSERT INTO "django_geo_db_location" VALUES(54765,NULL,'Erwinville, LA',23090,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54766,NULL,'Erwinville, LA 70729',23090,222,NULL,22,31383,0);
INSERT INTO "django_geo_db_location" VALUES(54767,NULL,'Ethel, LA',23091,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54768,NULL,'Ethel, LA 70730',23091,222,NULL,22,31384,0);
INSERT INTO "django_geo_db_location" VALUES(54769,NULL,'Fordoche, LA',23092,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54770,NULL,'Fordoche, LA 70732',23092,222,NULL,22,31385,0);
INSERT INTO "django_geo_db_location" VALUES(54771,NULL,'French Settlement, LA',23093,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54772,NULL,'French Settlement, LA 70733',23093,222,NULL,22,31386,0);
INSERT INTO "django_geo_db_location" VALUES(54773,NULL,'Geismar, LA',23094,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54774,NULL,'Geismar, LA 70734',23094,222,NULL,22,31387,0);
INSERT INTO "django_geo_db_location" VALUES(54775,NULL,'Glynn, LA',23095,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54776,NULL,'Glynn, LA 70736',23095,222,NULL,22,31388,0);
INSERT INTO "django_geo_db_location" VALUES(54777,NULL,'Gonzales, LA 70737',23075,222,NULL,22,31389,0);
INSERT INTO "django_geo_db_location" VALUES(54778,NULL,'Burnside, LA',23096,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54779,NULL,'Burnside, LA 70738',23096,222,NULL,22,31390,0);
INSERT INTO "django_geo_db_location" VALUES(54780,NULL,'Greenwell Springs, LA',23097,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54781,NULL,'Greenwell Springs, LA 70739',23097,222,NULL,22,31391,0);
INSERT INTO "django_geo_db_location" VALUES(54782,NULL,'Grosse Tete, LA',23098,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54783,NULL,'Grosse Tete, LA 70740',23098,222,NULL,22,31392,0);
INSERT INTO "django_geo_db_location" VALUES(54784,NULL,'Hester, LA',23099,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54785,NULL,'Hester, LA 70743',23099,222,NULL,22,31393,0);
INSERT INTO "django_geo_db_location" VALUES(54786,NULL,'Holden, LA',23100,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54787,NULL,'Holden, LA 70744',23100,222,NULL,22,31394,0);
INSERT INTO "django_geo_db_location" VALUES(54788,NULL,'Innis, LA',23101,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54789,NULL,'Innis, LA 70747',23101,222,NULL,22,31395,0);
INSERT INTO "django_geo_db_location" VALUES(54790,NULL,'Jackson, LA',23102,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54791,NULL,'Jackson, LA 70748',23102,222,NULL,22,31396,0);
INSERT INTO "django_geo_db_location" VALUES(54792,NULL,'Jarreau, LA',23103,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54793,NULL,'Jarreau, LA 70749',23103,222,NULL,22,31397,0);
INSERT INTO "django_geo_db_location" VALUES(54794,NULL,'Krotz Springs, LA',23104,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54795,NULL,'Krotz Springs, LA 70750',23104,222,NULL,22,31398,0);
INSERT INTO "django_geo_db_location" VALUES(54796,NULL,'Labarre, LA',23105,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54797,NULL,'Labarre, LA 70751',23105,222,NULL,22,31399,0);
INSERT INTO "django_geo_db_location" VALUES(54798,NULL,'Lakeland, LA',23106,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54799,NULL,'Lakeland, LA 70752',23106,222,NULL,22,31400,0);
INSERT INTO "django_geo_db_location" VALUES(54800,NULL,'Lettsworth, LA',23107,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54801,NULL,'Lettsworth, LA 70753',23107,222,NULL,22,31401,0);
INSERT INTO "django_geo_db_location" VALUES(54802,NULL,'Livingston, LA',23108,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54803,NULL,'Livingston, LA 70754',23108,222,NULL,22,31402,0);
INSERT INTO "django_geo_db_location" VALUES(54804,NULL,'Livonia, LA',23109,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54805,NULL,'Livonia, LA 70755',23109,222,NULL,22,31403,0);
INSERT INTO "django_geo_db_location" VALUES(54806,NULL,'Lottie, LA',23110,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54807,NULL,'Lottie, LA 70756',23110,222,NULL,22,31404,0);
INSERT INTO "django_geo_db_location" VALUES(54808,NULL,'Maringouin, LA',23111,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54809,NULL,'Maringouin, LA 70757',23111,222,NULL,22,31405,0);
INSERT INTO "django_geo_db_location" VALUES(54810,NULL,'Morganza, LA',23112,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54811,NULL,'Morganza, LA 70759',23112,222,NULL,22,31406,0);
INSERT INTO "django_geo_db_location" VALUES(54812,NULL,'New Roads, LA',23113,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54813,NULL,'New Roads, LA 70760',23113,222,NULL,22,31407,0);
INSERT INTO "django_geo_db_location" VALUES(54814,NULL,'Norwood, LA',23114,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54815,NULL,'Norwood, LA 70761',23114,222,NULL,22,31408,0);
INSERT INTO "django_geo_db_location" VALUES(54816,NULL,'Oscar, LA',23115,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54817,NULL,'Oscar, LA 70762',23115,222,NULL,22,31409,0);
INSERT INTO "django_geo_db_location" VALUES(54818,NULL,'Paulina, LA',23116,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54819,NULL,'Paulina, LA 70763',23116,222,NULL,22,31410,0);
INSERT INTO "django_geo_db_location" VALUES(54820,NULL,'Plaquemine, LA',23117,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54821,NULL,'Plaquemine, LA 70764',23117,222,NULL,22,31411,0);
INSERT INTO "django_geo_db_location" VALUES(54822,NULL,'Plaquemine, LA 70765',23117,222,NULL,22,31412,0);
INSERT INTO "django_geo_db_location" VALUES(54823,NULL,'Port Allen, LA',23118,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54824,NULL,'Port Allen, LA 70767',23118,222,NULL,22,31413,0);
INSERT INTO "django_geo_db_location" VALUES(54825,NULL,'Prairieville, LA',23119,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54826,NULL,'Prairieville, LA 70769',23119,222,NULL,22,31414,0);
INSERT INTO "django_geo_db_location" VALUES(54827,NULL,'Pride, LA',23120,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54828,NULL,'Pride, LA 70770',23120,222,NULL,22,31415,0);
INSERT INTO "django_geo_db_location" VALUES(54829,NULL,'Rosedale, LA',23121,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54830,NULL,'Rosedale, LA 70772',23121,222,NULL,22,31416,0);
INSERT INTO "django_geo_db_location" VALUES(54831,NULL,'Rougon, LA',23122,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54832,NULL,'Rougon, LA 70773',23122,222,NULL,22,31417,0);
INSERT INTO "django_geo_db_location" VALUES(54833,NULL,'Saint Amant, LA',23123,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54834,NULL,'Saint Amant, LA 70774',23123,222,NULL,22,31418,0);
INSERT INTO "django_geo_db_location" VALUES(54835,NULL,'Saint Francisville, LA',23124,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54836,NULL,'Saint Francisville, LA 70775',23124,222,NULL,22,31419,0);
INSERT INTO "django_geo_db_location" VALUES(54837,NULL,'Saint Gabriel, LA',23125,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54838,NULL,'Saint Gabriel, LA 70776',23125,222,NULL,22,31420,0);
INSERT INTO "django_geo_db_location" VALUES(54839,NULL,'Slaughter, LA',23126,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54840,NULL,'Slaughter, LA 70777',23126,222,NULL,22,31421,0);
INSERT INTO "django_geo_db_location" VALUES(54841,NULL,'Sorrento, LA',23127,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54842,NULL,'Sorrento, LA 70778',23127,222,NULL,22,31422,0);
INSERT INTO "django_geo_db_location" VALUES(54843,NULL,'Sunshine, LA',23128,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54844,NULL,'Sunshine, LA 70780',23128,222,NULL,22,31423,0);
INSERT INTO "django_geo_db_location" VALUES(54845,NULL,'Torbert, LA',23129,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54846,NULL,'Torbert, LA 70781',23129,222,NULL,22,31424,0);
INSERT INTO "django_geo_db_location" VALUES(54847,NULL,'Tunica, LA',23130,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54848,NULL,'Tunica, LA 70782',23130,222,NULL,22,31425,0);
INSERT INTO "django_geo_db_location" VALUES(54849,NULL,'Ventress, LA',23131,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54850,NULL,'Ventress, LA 70783',23131,222,NULL,22,31426,0);
INSERT INTO "django_geo_db_location" VALUES(54851,NULL,'Wakefield, LA',23132,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54852,NULL,'Wakefield, LA 70784',23132,222,NULL,22,31427,0);
INSERT INTO "django_geo_db_location" VALUES(54853,NULL,'Walker, LA',23133,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54854,NULL,'Walker, LA 70785',23133,222,NULL,22,31428,0);
INSERT INTO "django_geo_db_location" VALUES(54855,NULL,'Watson, LA',23134,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54856,NULL,'Watson, LA 70786',23134,222,NULL,22,31429,0);
INSERT INTO "django_geo_db_location" VALUES(54857,NULL,'Weyanoke, LA',23135,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54858,NULL,'Weyanoke, LA 70787',23135,222,NULL,22,31430,0);
INSERT INTO "django_geo_db_location" VALUES(54859,NULL,'White Castle, LA',23136,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54860,NULL,'White Castle, LA 70788',23136,222,NULL,22,31431,0);
INSERT INTO "django_geo_db_location" VALUES(54861,NULL,'Wilson, LA',23137,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54862,NULL,'Wilson, LA 70789',23137,222,NULL,22,31432,0);
INSERT INTO "django_geo_db_location" VALUES(54863,NULL,'Zachary, LA',23138,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54864,NULL,'Zachary, LA 70791',23138,222,NULL,22,31433,0);
INSERT INTO "django_geo_db_location" VALUES(54865,NULL,'Uncle Sam, LA',23139,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54866,NULL,'Uncle Sam, LA 70792',23139,222,NULL,22,31434,0);
INSERT INTO "django_geo_db_location" VALUES(54867,NULL,'Baton Rouge, LA',23140,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54868,NULL,'Baton Rouge, LA 70801',23140,222,NULL,22,31435,0);
INSERT INTO "django_geo_db_location" VALUES(54869,NULL,'Baton Rouge, LA 70802',23140,222,NULL,22,31436,0);
INSERT INTO "django_geo_db_location" VALUES(54870,NULL,'Baton Rouge, LA 70803',23140,222,NULL,22,31437,0);
INSERT INTO "django_geo_db_location" VALUES(54871,NULL,'Baton Rouge, LA 70804',23140,222,NULL,22,31438,0);
INSERT INTO "django_geo_db_location" VALUES(54872,NULL,'Baton Rouge, LA 70805',23140,222,NULL,22,31439,0);
INSERT INTO "django_geo_db_location" VALUES(54873,NULL,'Baton Rouge, LA 70806',23140,222,NULL,22,31440,0);
INSERT INTO "django_geo_db_location" VALUES(54874,NULL,'Baton Rouge, LA 70807',23140,222,NULL,22,31441,0);
INSERT INTO "django_geo_db_location" VALUES(54875,NULL,'Baton Rouge, LA 70808',23140,222,NULL,22,31442,0);
INSERT INTO "django_geo_db_location" VALUES(54876,NULL,'Baton Rouge, LA 70809',23140,222,NULL,22,31443,0);
INSERT INTO "django_geo_db_location" VALUES(54877,NULL,'Baton Rouge, LA 70810',23140,222,NULL,22,31444,0);
INSERT INTO "django_geo_db_location" VALUES(54878,NULL,'Baton Rouge, LA 70811',23140,222,NULL,22,31445,0);
INSERT INTO "django_geo_db_location" VALUES(54879,NULL,'Baton Rouge, LA 70812',23140,222,NULL,22,31446,0);
INSERT INTO "django_geo_db_location" VALUES(54880,NULL,'Baton Rouge, LA 70813',23140,222,NULL,22,31447,0);
INSERT INTO "django_geo_db_location" VALUES(54881,NULL,'Baton Rouge, LA 70814',23140,222,NULL,22,31448,0);
INSERT INTO "django_geo_db_location" VALUES(54882,NULL,'Baton Rouge, LA 70815',23140,222,NULL,22,31449,0);
INSERT INTO "django_geo_db_location" VALUES(54883,NULL,'Baton Rouge, LA 70816',23140,222,NULL,22,31450,0);
INSERT INTO "django_geo_db_location" VALUES(54884,NULL,'Baton Rouge, LA 70817',23140,222,NULL,22,31451,0);
INSERT INTO "django_geo_db_location" VALUES(54885,NULL,'Baton Rouge, LA 70818',23140,222,NULL,22,31452,0);
INSERT INTO "django_geo_db_location" VALUES(54886,NULL,'Baton Rouge, LA 70819',23140,222,NULL,22,31453,0);
INSERT INTO "django_geo_db_location" VALUES(54887,NULL,'Baton Rouge, LA 70820',23140,222,NULL,22,31454,0);
INSERT INTO "django_geo_db_location" VALUES(54888,NULL,'Baton Rouge, LA 70821',23140,222,NULL,22,31455,0);
INSERT INTO "django_geo_db_location" VALUES(54889,NULL,'Baton Rouge, LA 70822',23140,222,NULL,22,31456,0);
INSERT INTO "django_geo_db_location" VALUES(54890,NULL,'Baton Rouge, LA 70823',23140,222,NULL,22,31457,0);
INSERT INTO "django_geo_db_location" VALUES(54891,NULL,'Baton Rouge, LA 70825',23140,222,NULL,22,31458,0);
INSERT INTO "django_geo_db_location" VALUES(54892,NULL,'Baton Rouge, LA 70826',23140,222,NULL,22,31459,0);
INSERT INTO "django_geo_db_location" VALUES(54893,NULL,'Baton Rouge, LA 70827',23140,222,NULL,22,31460,0);
INSERT INTO "django_geo_db_location" VALUES(54894,NULL,'Baton Rouge, LA 70831',23140,222,NULL,22,31461,0);
INSERT INTO "django_geo_db_location" VALUES(54895,NULL,'Elton, LA 70832',23001,222,NULL,22,31462,0);
INSERT INTO "django_geo_db_location" VALUES(54896,NULL,'Baton Rouge, LA 70833',23140,222,NULL,22,31463,0);
INSERT INTO "django_geo_db_location" VALUES(54897,NULL,'Baton Rouge, LA 70835',23140,222,NULL,22,31464,0);
INSERT INTO "django_geo_db_location" VALUES(54898,NULL,'Baton Rouge, LA 70836',23140,222,NULL,22,31465,0);
INSERT INTO "django_geo_db_location" VALUES(54899,NULL,'Baton Rouge, LA 70837',23140,222,NULL,22,31466,0);
INSERT INTO "django_geo_db_location" VALUES(54900,NULL,'Baton Rouge, LA 70848',23140,222,NULL,22,31467,0);
INSERT INTO "django_geo_db_location" VALUES(54901,NULL,'Baton Rouge, LA 70874',23140,222,NULL,22,31468,0);
INSERT INTO "django_geo_db_location" VALUES(54902,NULL,'Baton Rouge, LA 70879',23140,222,NULL,22,31469,0);
INSERT INTO "django_geo_db_location" VALUES(54903,NULL,'Baton Rouge, LA 70883',23140,222,NULL,22,31470,0);
INSERT INTO "django_geo_db_location" VALUES(54904,NULL,'Baton Rouge, LA 70884',23140,222,NULL,22,31471,0);
INSERT INTO "django_geo_db_location" VALUES(54905,NULL,'Baton Rouge, LA 70892',23140,222,NULL,22,31472,0);
INSERT INTO "django_geo_db_location" VALUES(54906,NULL,'Baton Rouge, LA 70893',23140,222,NULL,22,31473,0);
INSERT INTO "django_geo_db_location" VALUES(54907,NULL,'Baton Rouge, LA 70894',23140,222,NULL,22,31474,0);
INSERT INTO "django_geo_db_location" VALUES(54908,NULL,'Baton Rouge, LA 70895',23140,222,NULL,22,31475,0);
INSERT INTO "django_geo_db_location" VALUES(54909,NULL,'Baton Rouge, LA 70896',23140,222,NULL,22,31476,0);
INSERT INTO "django_geo_db_location" VALUES(54910,NULL,'Baton Rouge, LA 70898',23140,222,NULL,22,31477,0);
INSERT INTO "django_geo_db_location" VALUES(54911,NULL,'Youngsville, LA 70952',23039,222,NULL,22,31478,0);
INSERT INTO "django_geo_db_location" VALUES(54912,NULL,'Arcadia, LA',23141,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54913,NULL,'Arcadia, LA 71001',23141,222,NULL,22,31479,0);
INSERT INTO "django_geo_db_location" VALUES(54914,NULL,'Ashland, LA',23142,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54915,NULL,'Ashland, LA 71002',23142,222,NULL,22,31480,0);
INSERT INTO "django_geo_db_location" VALUES(54916,NULL,'Athens, LA',23143,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54917,NULL,'Athens, LA 71003',23143,222,NULL,22,31481,0);
INSERT INTO "django_geo_db_location" VALUES(54918,NULL,'Belcher, LA',23144,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54919,NULL,'Belcher, LA 71004',23144,222,NULL,22,31482,0);
INSERT INTO "django_geo_db_location" VALUES(54920,NULL,'Benton, LA',23145,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54921,NULL,'Benton, LA 71006',23145,222,NULL,22,31483,0);
INSERT INTO "django_geo_db_location" VALUES(54922,NULL,'Bethany, LA',23146,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54923,NULL,'Bethany, LA 71007',23146,222,NULL,22,31484,0);
INSERT INTO "django_geo_db_location" VALUES(54924,NULL,'Bienville, LA',23147,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54925,NULL,'Bienville, LA 71008',23147,222,NULL,22,31485,0);
INSERT INTO "django_geo_db_location" VALUES(54926,NULL,'Blanchard, LA',23148,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54927,NULL,'Blanchard, LA 71009',23148,222,NULL,22,31486,0);
INSERT INTO "django_geo_db_location" VALUES(54928,NULL,'Castor, LA',23149,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54929,NULL,'Castor, LA 71016',23149,222,NULL,22,31487,0);
INSERT INTO "django_geo_db_location" VALUES(54930,NULL,'Cotton Valley, LA',23150,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54931,NULL,'Cotton Valley, LA 71018',23150,222,NULL,22,31488,0);
INSERT INTO "django_geo_db_location" VALUES(54932,NULL,'Coushatta, LA',23151,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54933,NULL,'Coushatta, LA 71019',23151,222,NULL,22,31489,0);
INSERT INTO "django_geo_db_location" VALUES(54934,NULL,'Cullen, LA',23152,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54935,NULL,'Cullen, LA 71021',23152,222,NULL,22,31490,0);
INSERT INTO "django_geo_db_location" VALUES(54936,NULL,'Doyline, LA',23153,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54937,NULL,'Doyline, LA 71023',23153,222,NULL,22,31491,0);
INSERT INTO "django_geo_db_location" VALUES(54938,NULL,'Dubberly, LA',23154,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54939,NULL,'Dubberly, LA 71024',23154,222,NULL,22,31492,0);
INSERT INTO "django_geo_db_location" VALUES(54940,NULL,'East Point, LA',23155,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54941,NULL,'East Point, LA 71025',23155,222,NULL,22,31493,0);
INSERT INTO "django_geo_db_location" VALUES(54942,NULL,'Frierson, LA',23156,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54943,NULL,'Frierson, LA 71027',23156,222,NULL,22,31494,0);
INSERT INTO "django_geo_db_location" VALUES(54944,NULL,'Gibsland, LA',23157,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54945,NULL,'Gibsland, LA 71028',23157,222,NULL,22,31495,0);
INSERT INTO "django_geo_db_location" VALUES(54946,NULL,'Gilliam, LA',23158,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54947,NULL,'Gilliam, LA 71029',23158,222,NULL,22,31496,0);
INSERT INTO "django_geo_db_location" VALUES(54948,NULL,'Gloster, LA',23159,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54949,NULL,'Gloster, LA 71030',23159,222,NULL,22,31497,0);
INSERT INTO "django_geo_db_location" VALUES(54950,NULL,'Goldonna, LA',23160,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54951,NULL,'Goldonna, LA 71031',23160,222,NULL,22,31498,0);
INSERT INTO "django_geo_db_location" VALUES(54952,NULL,'Grand Cane, LA',23161,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54953,NULL,'Grand Cane, LA 71032',23161,222,NULL,22,31499,0);
INSERT INTO "django_geo_db_location" VALUES(54954,NULL,'Greenwood, LA',23162,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54955,NULL,'Greenwood, LA 71033',23162,222,NULL,22,31500,0);
INSERT INTO "django_geo_db_location" VALUES(54956,NULL,'Hall Summit, LA',23163,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54957,NULL,'Hall Summit, LA 71034',23163,222,NULL,22,31501,0);
INSERT INTO "django_geo_db_location" VALUES(54958,NULL,'Harmon, LA',23164,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54959,NULL,'Harmon, LA 71036',23164,222,NULL,22,31502,0);
INSERT INTO "django_geo_db_location" VALUES(54960,NULL,'Haughton, LA',23165,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54961,NULL,'Haughton, LA 71037',23165,222,NULL,22,31503,0);
INSERT INTO "django_geo_db_location" VALUES(54962,NULL,'Haynesville, LA',23166,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54963,NULL,'Haynesville, LA 71038',23166,222,NULL,22,31504,0);
INSERT INTO "django_geo_db_location" VALUES(54964,NULL,'Heflin, LA',23167,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54965,NULL,'Heflin, LA 71039',23167,222,NULL,22,31505,0);
INSERT INTO "django_geo_db_location" VALUES(54966,NULL,'Homer, LA',23168,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54967,NULL,'Homer, LA 71040',23168,222,NULL,22,31506,0);
INSERT INTO "django_geo_db_location" VALUES(54968,NULL,'Hosston, LA',23169,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54969,NULL,'Hosston, LA 71043',23169,222,NULL,22,31507,0);
INSERT INTO "django_geo_db_location" VALUES(54970,NULL,'Ida, LA',23170,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54971,NULL,'Ida, LA 71044',23170,222,NULL,22,31508,0);
INSERT INTO "django_geo_db_location" VALUES(54972,NULL,'Jamestown, LA',23171,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54973,NULL,'Jamestown, LA 71045',23171,222,NULL,22,31509,0);
INSERT INTO "django_geo_db_location" VALUES(54974,NULL,'Keatchie, LA',23172,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54975,NULL,'Keatchie, LA 71046',23172,222,NULL,22,31510,0);
INSERT INTO "django_geo_db_location" VALUES(54976,NULL,'Keithville, LA',23173,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54977,NULL,'Keithville, LA 71047',23173,222,NULL,22,31511,0);
INSERT INTO "django_geo_db_location" VALUES(54978,NULL,'Lisbon, LA',23174,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54979,NULL,'Lisbon, LA 71048',23174,222,NULL,22,31512,0);
INSERT INTO "django_geo_db_location" VALUES(54980,NULL,'Logansport, LA',23175,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54981,NULL,'Logansport, LA 71049',23175,222,NULL,22,31513,0);
INSERT INTO "django_geo_db_location" VALUES(54982,NULL,'Longstreet, LA',23176,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54983,NULL,'Longstreet, LA 71050',23176,222,NULL,22,31514,0);
INSERT INTO "django_geo_db_location" VALUES(54984,NULL,'Elm Grove, LA',23177,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54985,NULL,'Elm Grove, LA 71051',23177,222,NULL,22,31515,0);
INSERT INTO "django_geo_db_location" VALUES(54986,NULL,'Mansfield, LA',23178,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54987,NULL,'Mansfield, LA 71052',23178,222,NULL,22,31516,0);
INSERT INTO "django_geo_db_location" VALUES(54988,NULL,'South Mansfield, LA',23179,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54989,NULL,'South Mansfield, LA 71053',23179,222,NULL,22,31517,0);
INSERT INTO "django_geo_db_location" VALUES(54990,NULL,'Minden, LA',23180,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54991,NULL,'Minden, LA 71055',23180,222,NULL,22,31518,0);
INSERT INTO "django_geo_db_location" VALUES(54992,NULL,'Minden, LA 71058',23180,222,NULL,22,31519,0);
INSERT INTO "django_geo_db_location" VALUES(54993,NULL,'Mansfield, LA 71059',23178,222,NULL,22,31520,0);
INSERT INTO "django_geo_db_location" VALUES(54994,NULL,'Mooringsport, LA',23181,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54995,NULL,'Mooringsport, LA 71060',23181,222,NULL,22,31521,0);
INSERT INTO "django_geo_db_location" VALUES(54996,NULL,'Oil City, LA',23182,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54997,NULL,'Oil City, LA 71061',23182,222,NULL,22,31522,0);
INSERT INTO "django_geo_db_location" VALUES(54998,NULL,'Pelican, LA',23183,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(54999,NULL,'Pelican, LA 71063',23183,222,NULL,22,31523,0);
INSERT INTO "django_geo_db_location" VALUES(55000,NULL,'Plain Dealing, LA',23184,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55001,NULL,'Plain Dealing, LA 71064',23184,222,NULL,22,31524,0);
INSERT INTO "django_geo_db_location" VALUES(55002,NULL,'Pleasant Hill, LA',23185,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55003,NULL,'Pleasant Hill, LA 71065',23185,222,NULL,22,31525,0);
INSERT INTO "django_geo_db_location" VALUES(55004,NULL,'Powhatan, LA',23186,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55005,NULL,'Powhatan, LA 71066',23186,222,NULL,22,31526,0);
INSERT INTO "django_geo_db_location" VALUES(55006,NULL,'Princeton, LA',23187,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55007,NULL,'Princeton, LA 71067',23187,222,NULL,22,31527,0);
INSERT INTO "django_geo_db_location" VALUES(55008,NULL,'Ringgold, LA',23188,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55009,NULL,'Ringgold, LA 71068',23188,222,NULL,22,31528,0);
INSERT INTO "django_geo_db_location" VALUES(55010,NULL,'Rodessa, LA',23189,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55011,NULL,'Rodessa, LA 71069',23189,222,NULL,22,31529,0);
INSERT INTO "django_geo_db_location" VALUES(55012,NULL,'Saline, LA',23190,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55013,NULL,'Saline, LA 71070',23190,222,NULL,22,31530,0);
INSERT INTO "django_geo_db_location" VALUES(55014,NULL,'Sarepta, LA',23191,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55015,NULL,'Sarepta, LA 71071',23191,222,NULL,22,31531,0);
INSERT INTO "django_geo_db_location" VALUES(55016,NULL,'Shongaloo, LA',23192,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55017,NULL,'Shongaloo, LA 71072',23192,222,NULL,22,31532,0);
INSERT INTO "django_geo_db_location" VALUES(55018,NULL,'Sibley, LA',23193,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55019,NULL,'Sibley, LA 71073',23193,222,NULL,22,31533,0);
INSERT INTO "django_geo_db_location" VALUES(55020,NULL,'Springhill, LA',23194,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55021,NULL,'Springhill, LA 71075',23194,222,NULL,22,31534,0);
INSERT INTO "django_geo_db_location" VALUES(55022,NULL,'Castor, LA 71076',23149,222,NULL,22,31535,0);
INSERT INTO "django_geo_db_location" VALUES(55023,NULL,'Stonewall, LA',23195,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55024,NULL,'Stonewall, LA 71078',23195,222,NULL,22,31536,0);
INSERT INTO "django_geo_db_location" VALUES(55025,NULL,'Summerfield, LA',23196,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55026,NULL,'Summerfield, LA 71079',23196,222,NULL,22,31537,0);
INSERT INTO "django_geo_db_location" VALUES(55027,NULL,'Taylor, LA',23197,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55028,NULL,'Taylor, LA 71080',23197,222,NULL,22,31538,0);
INSERT INTO "django_geo_db_location" VALUES(55029,NULL,'Vivian, LA',23198,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55030,NULL,'Vivian, LA 71082',23198,222,NULL,22,31539,0);
INSERT INTO "django_geo_db_location" VALUES(55031,NULL,'Jamestown, LA 71095',23171,222,NULL,22,31540,0);
INSERT INTO "django_geo_db_location" VALUES(55032,NULL,'Shreveport, LA',23199,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55033,NULL,'Shreveport, LA 71101',23199,222,NULL,22,31541,0);
INSERT INTO "django_geo_db_location" VALUES(55034,NULL,'Shreveport, LA 71102',23199,222,NULL,22,31542,0);
INSERT INTO "django_geo_db_location" VALUES(55035,NULL,'Shreveport, LA 71103',23199,222,NULL,22,31543,0);
INSERT INTO "django_geo_db_location" VALUES(55036,NULL,'Shreveport, LA 71104',23199,222,NULL,22,31544,0);
INSERT INTO "django_geo_db_location" VALUES(55037,NULL,'Shreveport, LA 71105',23199,222,NULL,22,31545,0);
INSERT INTO "django_geo_db_location" VALUES(55038,NULL,'Shreveport, LA 71106',23199,222,NULL,22,31546,0);
INSERT INTO "django_geo_db_location" VALUES(55039,NULL,'Shreveport, LA 71107',23199,222,NULL,22,31547,0);
INSERT INTO "django_geo_db_location" VALUES(55040,NULL,'Shreveport, LA 71108',23199,222,NULL,22,31548,0);
INSERT INTO "django_geo_db_location" VALUES(55041,NULL,'Shreveport, LA 71109',23199,222,NULL,22,31549,0);
INSERT INTO "django_geo_db_location" VALUES(55042,NULL,'Barksdale AFB, LA',23200,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55043,NULL,'Barksdale AFB, LA 71110',23200,222,NULL,22,31550,0);
INSERT INTO "django_geo_db_location" VALUES(55044,NULL,'Bossier City, LA',23201,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55045,NULL,'Bossier City, LA 71111',23201,222,NULL,22,31551,0);
INSERT INTO "django_geo_db_location" VALUES(55046,NULL,'Bossier City, LA 71112',23201,222,NULL,22,31552,0);
INSERT INTO "django_geo_db_location" VALUES(55047,NULL,'Bossier City, LA 71113',23201,222,NULL,22,31553,0);
INSERT INTO "django_geo_db_location" VALUES(55048,NULL,'Shreveport, LA 71115',23199,222,NULL,22,31554,0);
INSERT INTO "django_geo_db_location" VALUES(55049,NULL,'Shreveport, LA 71118',23199,222,NULL,22,31555,0);
INSERT INTO "django_geo_db_location" VALUES(55050,NULL,'Shreveport, LA 71119',23199,222,NULL,22,31556,0);
INSERT INTO "django_geo_db_location" VALUES(55051,NULL,'Shreveport, LA 71120',23199,222,NULL,22,31557,0);
INSERT INTO "django_geo_db_location" VALUES(55052,NULL,'Shreveport, LA 71129',23199,222,NULL,22,31558,0);
INSERT INTO "django_geo_db_location" VALUES(55053,NULL,'Shreveport, LA 71130',23199,222,NULL,22,31559,0);
INSERT INTO "django_geo_db_location" VALUES(55054,NULL,'Shreveport, LA 71133',23199,222,NULL,22,31560,0);
INSERT INTO "django_geo_db_location" VALUES(55055,NULL,'Shreveport, LA 71134',23199,222,NULL,22,31561,0);
INSERT INTO "django_geo_db_location" VALUES(55056,NULL,'Shreveport, LA 71135',23199,222,NULL,22,31562,0);
INSERT INTO "django_geo_db_location" VALUES(55057,NULL,'Shreveport, LA 71136',23199,222,NULL,22,31563,0);
INSERT INTO "django_geo_db_location" VALUES(55058,NULL,'Shreveport, LA 71137',23199,222,NULL,22,31564,0);
INSERT INTO "django_geo_db_location" VALUES(55059,NULL,'Shreveport, LA 71138',23199,222,NULL,22,31565,0);
INSERT INTO "django_geo_db_location" VALUES(55060,NULL,'Shreveport, LA 71148',23199,222,NULL,22,31566,0);
INSERT INTO "django_geo_db_location" VALUES(55061,NULL,'Shreveport, LA 71149',23199,222,NULL,22,31567,0);
INSERT INTO "django_geo_db_location" VALUES(55062,NULL,'Shreveport, LA 71151',23199,222,NULL,22,31568,0);
INSERT INTO "django_geo_db_location" VALUES(55063,NULL,'Shreveport, LA 71152',23199,222,NULL,22,31569,0);
INSERT INTO "django_geo_db_location" VALUES(55064,NULL,'Shreveport, LA 71153',23199,222,NULL,22,31570,0);
INSERT INTO "django_geo_db_location" VALUES(55065,NULL,'Shreveport, LA 71154',23199,222,NULL,22,31571,0);
INSERT INTO "django_geo_db_location" VALUES(55066,NULL,'Shreveport, LA 71156',23199,222,NULL,22,31572,0);
INSERT INTO "django_geo_db_location" VALUES(55067,NULL,'Shreveport, LA 71161',23199,222,NULL,22,31573,0);
INSERT INTO "django_geo_db_location" VALUES(55068,NULL,'Shreveport, LA 71162',23199,222,NULL,22,31574,0);
INSERT INTO "django_geo_db_location" VALUES(55069,NULL,'Shreveport, LA 71163',23199,222,NULL,22,31575,0);
INSERT INTO "django_geo_db_location" VALUES(55070,NULL,'Shreveport, LA 71164',23199,222,NULL,22,31576,0);
INSERT INTO "django_geo_db_location" VALUES(55071,NULL,'Shreveport, LA 71165',23199,222,NULL,22,31577,0);
INSERT INTO "django_geo_db_location" VALUES(55072,NULL,'Shreveport, LA 71166',23199,222,NULL,22,31578,0);
INSERT INTO "django_geo_db_location" VALUES(55073,NULL,'Bossier City, LA 71171',23201,222,NULL,22,31579,0);
INSERT INTO "django_geo_db_location" VALUES(55074,NULL,'Bossier City, LA 71172',23201,222,NULL,22,31580,0);
INSERT INTO "django_geo_db_location" VALUES(55075,NULL,'Monroe, LA',23202,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55076,NULL,'Monroe, LA 71201',23202,222,NULL,22,31581,0);
INSERT INTO "django_geo_db_location" VALUES(55077,NULL,'Monroe, LA 71202',23202,222,NULL,22,31582,0);
INSERT INTO "django_geo_db_location" VALUES(55078,NULL,'Monroe, LA 71203',23202,222,NULL,22,31583,0);
INSERT INTO "django_geo_db_location" VALUES(55079,NULL,'Monroe, LA 71207',23202,222,NULL,22,31584,0);
INSERT INTO "django_geo_db_location" VALUES(55080,NULL,'Monroe, LA 71208',23202,222,NULL,22,31585,0);
INSERT INTO "django_geo_db_location" VALUES(55081,NULL,'Monroe, LA 71209',23202,222,NULL,22,31586,0);
INSERT INTO "django_geo_db_location" VALUES(55082,NULL,'Monroe, LA 71210',23202,222,NULL,22,31587,0);
INSERT INTO "django_geo_db_location" VALUES(55083,NULL,'Monroe, LA 71211',23202,222,NULL,22,31588,0);
INSERT INTO "django_geo_db_location" VALUES(55084,NULL,'Monroe, LA 71212',23202,222,NULL,22,31589,0);
INSERT INTO "django_geo_db_location" VALUES(55085,NULL,'Monroe, LA 71213',23202,222,NULL,22,31590,0);
INSERT INTO "django_geo_db_location" VALUES(55086,NULL,'Archibald, LA',23203,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55087,NULL,'Archibald, LA 71218',23203,222,NULL,22,31591,0);
INSERT INTO "django_geo_db_location" VALUES(55088,NULL,'Baskin, LA',23204,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55089,NULL,'Baskin, LA 71219',23204,222,NULL,22,31592,0);
INSERT INTO "django_geo_db_location" VALUES(55090,NULL,'Bastrop, LA',23205,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55091,NULL,'Bastrop, LA 71220',23205,222,NULL,22,31593,0);
INSERT INTO "django_geo_db_location" VALUES(55092,NULL,'Bastrop, LA 71221',23205,222,NULL,22,31594,0);
INSERT INTO "django_geo_db_location" VALUES(55093,NULL,'Bernice, LA',23206,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55094,NULL,'Bernice, LA 71222',23206,222,NULL,22,31595,0);
INSERT INTO "django_geo_db_location" VALUES(55095,NULL,'Bonita, LA',23207,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55096,NULL,'Bonita, LA 71223',23207,222,NULL,22,31596,0);
INSERT INTO "django_geo_db_location" VALUES(55097,NULL,'Calhoun, LA',23208,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55098,NULL,'Calhoun, LA 71225',23208,222,NULL,22,31597,0);
INSERT INTO "django_geo_db_location" VALUES(55099,NULL,'Chatham, LA',23209,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55100,NULL,'Chatham, LA 71226',23209,222,NULL,22,31598,0);
INSERT INTO "django_geo_db_location" VALUES(55101,NULL,'Choudrant, LA',23210,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55102,NULL,'Choudrant, LA 71227',23210,222,NULL,22,31599,0);
INSERT INTO "django_geo_db_location" VALUES(55103,NULL,'Collinston, LA',23211,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55104,NULL,'Collinston, LA 71229',23211,222,NULL,22,31600,0);
INSERT INTO "django_geo_db_location" VALUES(55105,NULL,'Crowville, LA',23212,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55106,NULL,'Crowville, LA 71230',23212,222,NULL,22,31601,0);
INSERT INTO "django_geo_db_location" VALUES(55107,NULL,'Delhi, LA',23213,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55108,NULL,'Delhi, LA 71232',23213,222,NULL,22,31602,0);
INSERT INTO "django_geo_db_location" VALUES(55109,NULL,'Delta, LA',23214,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55110,NULL,'Delta, LA 71233',23214,222,NULL,22,31603,0);
INSERT INTO "django_geo_db_location" VALUES(55111,NULL,'Downsville, LA',23215,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55112,NULL,'Downsville, LA 71234',23215,222,NULL,22,31604,0);
INSERT INTO "django_geo_db_location" VALUES(55113,NULL,'Dubach, LA',23216,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55114,NULL,'Dubach, LA 71235',23216,222,NULL,22,31605,0);
INSERT INTO "django_geo_db_location" VALUES(55115,NULL,'Epps, LA',23217,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55116,NULL,'Epps, LA 71237',23217,222,NULL,22,31606,0);
INSERT INTO "django_geo_db_location" VALUES(55117,NULL,'Eros, LA',23218,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55118,NULL,'Eros, LA 71238',23218,222,NULL,22,31607,0);
INSERT INTO "django_geo_db_location" VALUES(55119,NULL,'Fairbanks, LA',23219,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55120,NULL,'Fairbanks, LA 71240',23219,222,NULL,22,31608,0);
INSERT INTO "django_geo_db_location" VALUES(55121,NULL,'Farmerville, LA',23220,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55122,NULL,'Farmerville, LA 71241',23220,222,NULL,22,31609,0);
INSERT INTO "django_geo_db_location" VALUES(55123,NULL,'Forest, LA',23221,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55124,NULL,'Forest, LA 71242',23221,222,NULL,22,31610,0);
INSERT INTO "django_geo_db_location" VALUES(55125,NULL,'Fort Necessity, LA',23222,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55126,NULL,'Fort Necessity, LA 71243',23222,222,NULL,22,31611,0);
INSERT INTO "django_geo_db_location" VALUES(55127,NULL,'Grambling, LA',23223,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55128,NULL,'Grambling, LA 71245',23223,222,NULL,22,31612,0);
INSERT INTO "django_geo_db_location" VALUES(55129,NULL,'Hodge, LA',23224,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55130,NULL,'Hodge, LA 71247',23224,222,NULL,22,31613,0);
INSERT INTO "django_geo_db_location" VALUES(55131,NULL,'Jigger, LA',23225,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55132,NULL,'Jigger, LA 71249',23225,222,NULL,22,31614,0);
INSERT INTO "django_geo_db_location" VALUES(55133,NULL,'Jones, LA',23226,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55134,NULL,'Jones, LA 71250',23226,222,NULL,22,31615,0);
INSERT INTO "django_geo_db_location" VALUES(55135,NULL,'Jonesboro, LA',23227,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55136,NULL,'Jonesboro, LA 71251',23227,222,NULL,22,31616,0);
INSERT INTO "django_geo_db_location" VALUES(55137,NULL,'Kilbourne, LA',23228,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55138,NULL,'Kilbourne, LA 71253',23228,222,NULL,22,31617,0);
INSERT INTO "django_geo_db_location" VALUES(55139,NULL,'Lake Providence, LA',23229,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55140,NULL,'Lake Providence, LA 71254',23229,222,NULL,22,31618,0);
INSERT INTO "django_geo_db_location" VALUES(55141,NULL,'Lillie, LA',23230,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55142,NULL,'Lillie, LA 71256',23230,222,NULL,22,31619,0);
INSERT INTO "django_geo_db_location" VALUES(55143,NULL,'Mangham, LA',23231,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55144,NULL,'Mangham, LA 71259',23231,222,NULL,22,31620,0);
INSERT INTO "django_geo_db_location" VALUES(55145,NULL,'Marion, LA',23232,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55146,NULL,'Marion, LA 71260',23232,222,NULL,22,31621,0);
INSERT INTO "django_geo_db_location" VALUES(55147,NULL,'Mer Rouge, LA',23233,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55148,NULL,'Mer Rouge, LA 71261',23233,222,NULL,22,31622,0);
INSERT INTO "django_geo_db_location" VALUES(55149,NULL,'Oak Grove, LA',23234,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55150,NULL,'Oak Grove, LA 71263',23234,222,NULL,22,31623,0);
INSERT INTO "django_geo_db_location" VALUES(55151,NULL,'Oak Ridge, LA',23235,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55152,NULL,'Oak Ridge, LA 71264',23235,222,NULL,22,31624,0);
INSERT INTO "django_geo_db_location" VALUES(55153,NULL,'Pioneer, LA',23236,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55154,NULL,'Pioneer, LA 71266',23236,222,NULL,22,31625,0);
INSERT INTO "django_geo_db_location" VALUES(55155,NULL,'Quitman, LA',23237,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55156,NULL,'Quitman, LA 71268',23237,222,NULL,22,31626,0);
INSERT INTO "django_geo_db_location" VALUES(55157,NULL,'Rayville, LA',23238,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55158,NULL,'Rayville, LA 71269',23238,222,NULL,22,31627,0);
INSERT INTO "django_geo_db_location" VALUES(55159,NULL,'Ruston, LA',23239,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55160,NULL,'Ruston, LA 71270',23239,222,NULL,22,31628,0);
INSERT INTO "django_geo_db_location" VALUES(55161,NULL,'Ruston, LA 71272',23239,222,NULL,22,31629,0);
INSERT INTO "django_geo_db_location" VALUES(55162,NULL,'Ruston, LA 71273',23239,222,NULL,22,31630,0);
INSERT INTO "django_geo_db_location" VALUES(55163,NULL,'Simsboro, LA',23240,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55164,NULL,'Simsboro, LA 71275',23240,222,NULL,22,31631,0);
INSERT INTO "django_geo_db_location" VALUES(55165,NULL,'Sondheimer, LA',23241,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55166,NULL,'Sondheimer, LA 71276',23241,222,NULL,22,31632,0);
INSERT INTO "django_geo_db_location" VALUES(55167,NULL,'Spearsville, LA',23242,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55168,NULL,'Spearsville, LA 71277',23242,222,NULL,22,31633,0);
INSERT INTO "django_geo_db_location" VALUES(55169,NULL,'Start, LA',23243,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55170,NULL,'Start, LA 71279',23243,222,NULL,22,31634,0);
INSERT INTO "django_geo_db_location" VALUES(55171,NULL,'Sterlington, LA',23244,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55172,NULL,'Sterlington, LA 71280',23244,222,NULL,22,31635,0);
INSERT INTO "django_geo_db_location" VALUES(55173,NULL,'Swartz, LA',23245,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55174,NULL,'Swartz, LA 71281',23245,222,NULL,22,31636,0);
INSERT INTO "django_geo_db_location" VALUES(55175,NULL,'Tallulah, LA',23246,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55176,NULL,'Tallulah, LA 71282',23246,222,NULL,22,31637,0);
INSERT INTO "django_geo_db_location" VALUES(55177,NULL,'Tallulah, LA 71284',23246,222,NULL,22,31638,0);
INSERT INTO "django_geo_db_location" VALUES(55178,NULL,'Transylvania, LA',23247,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55179,NULL,'Transylvania, LA 71286',23247,222,NULL,22,31639,0);
INSERT INTO "django_geo_db_location" VALUES(55180,NULL,'West Monroe, LA',23248,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55181,NULL,'West Monroe, LA 71291',23248,222,NULL,22,31640,0);
INSERT INTO "django_geo_db_location" VALUES(55182,NULL,'West Monroe, LA 71292',23248,222,NULL,22,31641,0);
INSERT INTO "django_geo_db_location" VALUES(55183,NULL,'West Monroe, LA 71294',23248,222,NULL,22,31642,0);
INSERT INTO "django_geo_db_location" VALUES(55184,NULL,'Winnsboro, LA',23249,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55185,NULL,'Winnsboro, LA 71295',23249,222,NULL,22,31643,0);
INSERT INTO "django_geo_db_location" VALUES(55186,NULL,'Alexandria, LA',23250,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55187,NULL,'Alexandria, LA 71301',23250,222,NULL,22,31644,0);
INSERT INTO "django_geo_db_location" VALUES(55188,NULL,'Alexandria, LA 71302',23250,222,NULL,22,31645,0);
INSERT INTO "django_geo_db_location" VALUES(55189,NULL,'Alexandria, LA 71303',23250,222,NULL,22,31646,0);
INSERT INTO "django_geo_db_location" VALUES(55190,NULL,'Alexandria, LA 71306',23250,222,NULL,22,31647,0);
INSERT INTO "django_geo_db_location" VALUES(55191,NULL,'Alexandria, LA 71307',23250,222,NULL,22,31648,0);
INSERT INTO "django_geo_db_location" VALUES(55192,NULL,'Alexandria, LA 71309',23250,222,NULL,22,31649,0);
INSERT INTO "django_geo_db_location" VALUES(55193,NULL,'Alexandria, LA 71315',23250,222,NULL,22,31650,0);
INSERT INTO "django_geo_db_location" VALUES(55194,NULL,'Acme, LA',23251,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55195,NULL,'Acme, LA 71316',23251,222,NULL,22,31651,0);
INSERT INTO "django_geo_db_location" VALUES(55196,NULL,'Bordelonville, LA',23252,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55197,NULL,'Bordelonville, LA 71320',23252,222,NULL,22,31652,0);
INSERT INTO "django_geo_db_location" VALUES(55198,NULL,'Bunkie, LA',23253,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55199,NULL,'Bunkie, LA 71322',23253,222,NULL,22,31653,0);
INSERT INTO "django_geo_db_location" VALUES(55200,NULL,'Center Point, LA',23254,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55201,NULL,'Center Point, LA 71323',23254,222,NULL,22,31654,0);
INSERT INTO "django_geo_db_location" VALUES(55202,NULL,'Chase, LA',23255,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55203,NULL,'Chase, LA 71324',23255,222,NULL,22,31655,0);
INSERT INTO "django_geo_db_location" VALUES(55204,NULL,'Cheneyville, LA',23256,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55205,NULL,'Cheneyville, LA 71325',23256,222,NULL,22,31656,0);
INSERT INTO "django_geo_db_location" VALUES(55206,NULL,'Clayton, LA',23257,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55207,NULL,'Clayton, LA 71326',23257,222,NULL,22,31657,0);
INSERT INTO "django_geo_db_location" VALUES(55208,NULL,'Cottonport, LA',23258,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55209,NULL,'Cottonport, LA 71327',23258,222,NULL,22,31658,0);
INSERT INTO "django_geo_db_location" VALUES(55210,NULL,'Deville, LA',23259,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55211,NULL,'Deville, LA 71328',23259,222,NULL,22,31659,0);
INSERT INTO "django_geo_db_location" VALUES(55212,NULL,'Dupont, LA',23260,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55213,NULL,'Dupont, LA 71329',23260,222,NULL,22,31660,0);
INSERT INTO "django_geo_db_location" VALUES(55214,NULL,'Echo, LA',23261,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55215,NULL,'Echo, LA 71330',23261,222,NULL,22,31661,0);
INSERT INTO "django_geo_db_location" VALUES(55216,NULL,'Effie, LA',23262,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55217,NULL,'Effie, LA 71331',23262,222,NULL,22,31662,0);
INSERT INTO "django_geo_db_location" VALUES(55218,NULL,'Evergreen, LA',23263,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55219,NULL,'Evergreen, LA 71333',23263,222,NULL,22,31663,0);
INSERT INTO "django_geo_db_location" VALUES(55220,NULL,'Ferriday, LA',23264,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55221,NULL,'Ferriday, LA 71334',23264,222,NULL,22,31664,0);
INSERT INTO "django_geo_db_location" VALUES(55222,NULL,'Gilbert, LA',23265,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55223,NULL,'Gilbert, LA 71336',23265,222,NULL,22,31665,0);
INSERT INTO "django_geo_db_location" VALUES(55224,NULL,'Hamburg, LA',23266,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55225,NULL,'Hamburg, LA 71339',23266,222,NULL,22,31666,0);
INSERT INTO "django_geo_db_location" VALUES(55226,NULL,'Harrisonburg, LA',23267,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55227,NULL,'Harrisonburg, LA 71340',23267,222,NULL,22,31667,0);
INSERT INTO "django_geo_db_location" VALUES(55228,NULL,'Hessmer, LA',23268,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55229,NULL,'Hessmer, LA 71341',23268,222,NULL,22,31668,0);
INSERT INTO "django_geo_db_location" VALUES(55230,NULL,'Jena, LA',23269,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55231,NULL,'Jena, LA 71342',23269,222,NULL,22,31669,0);
INSERT INTO "django_geo_db_location" VALUES(55232,NULL,'Jonesville, LA',23270,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55233,NULL,'Jonesville, LA 71343',23270,222,NULL,22,31670,0);
INSERT INTO "django_geo_db_location" VALUES(55234,NULL,'Lebeau, LA',23271,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55235,NULL,'Lebeau, LA 71345',23271,222,NULL,22,31671,0);
INSERT INTO "django_geo_db_location" VALUES(55236,NULL,'Lecompte, LA',23272,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55237,NULL,'Lecompte, LA 71346',23272,222,NULL,22,31672,0);
INSERT INTO "django_geo_db_location" VALUES(55238,NULL,'Libuse, LA',23273,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55239,NULL,'Libuse, LA 71348',23273,222,NULL,22,31673,0);
INSERT INTO "django_geo_db_location" VALUES(55240,NULL,'Mansura, LA',23274,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55241,NULL,'Mansura, LA 71350',23274,222,NULL,22,31674,0);
INSERT INTO "django_geo_db_location" VALUES(55242,NULL,'Marksville, LA',23275,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55243,NULL,'Marksville, LA 71351',23275,222,NULL,22,31675,0);
INSERT INTO "django_geo_db_location" VALUES(55244,NULL,'Melville, LA',23276,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55245,NULL,'Melville, LA 71353',23276,222,NULL,22,31676,0);
INSERT INTO "django_geo_db_location" VALUES(55246,NULL,'Monterey, LA',23277,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55247,NULL,'Monterey, LA 71354',23277,222,NULL,22,31677,0);
INSERT INTO "django_geo_db_location" VALUES(55248,NULL,'Moreauville, LA',23278,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55249,NULL,'Moreauville, LA 71355',23278,222,NULL,22,31678,0);
INSERT INTO "django_geo_db_location" VALUES(55250,NULL,'Morrow, LA',23279,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55251,NULL,'Morrow, LA 71356',23279,222,NULL,22,31679,0);
INSERT INTO "django_geo_db_location" VALUES(55252,NULL,'Newellton, LA',23280,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55253,NULL,'Newellton, LA 71357',23280,222,NULL,22,31680,0);
INSERT INTO "django_geo_db_location" VALUES(55254,NULL,'Palmetto, LA',23281,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55255,NULL,'Palmetto, LA 71358',23281,222,NULL,22,31681,0);
INSERT INTO "django_geo_db_location" VALUES(55256,NULL,'Pineville, LA',23282,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55257,NULL,'Pineville, LA 71359',23282,222,NULL,22,31682,0);
INSERT INTO "django_geo_db_location" VALUES(55258,NULL,'Pineville, LA 71360',23282,222,NULL,22,31683,0);
INSERT INTO "django_geo_db_location" VALUES(55259,NULL,'Pineville, LA 71361',23282,222,NULL,22,31684,0);
INSERT INTO "django_geo_db_location" VALUES(55260,NULL,'Plaucheville, LA',23283,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55261,NULL,'Plaucheville, LA 71362',23283,222,NULL,22,31685,0);
INSERT INTO "django_geo_db_location" VALUES(55262,NULL,'Rhinehart, LA',23284,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55263,NULL,'Rhinehart, LA 71363',23284,222,NULL,22,31686,0);
INSERT INTO "django_geo_db_location" VALUES(55264,NULL,'Ruby, LA',23285,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55265,NULL,'Ruby, LA 71365',23285,222,NULL,22,31687,0);
INSERT INTO "django_geo_db_location" VALUES(55266,NULL,'Saint Joseph, LA',23286,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55267,NULL,'Saint Joseph, LA 71366',23286,222,NULL,22,31688,0);
INSERT INTO "django_geo_db_location" VALUES(55268,NULL,'Saint Landry, LA',23287,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55269,NULL,'Saint Landry, LA 71367',23287,222,NULL,22,31689,0);
INSERT INTO "django_geo_db_location" VALUES(55270,NULL,'Sicily Island, LA',23288,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55271,NULL,'Sicily Island, LA 71368',23288,222,NULL,22,31690,0);
INSERT INTO "django_geo_db_location" VALUES(55272,NULL,'Simmesport, LA',23289,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55273,NULL,'Simmesport, LA 71369',23289,222,NULL,22,31691,0);
INSERT INTO "django_geo_db_location" VALUES(55274,NULL,'Trout, LA',23290,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55275,NULL,'Trout, LA 71371',23290,222,NULL,22,31692,0);
INSERT INTO "django_geo_db_location" VALUES(55276,NULL,'Vidalia, LA',23291,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55277,NULL,'Vidalia, LA 71373',23291,222,NULL,22,31693,0);
INSERT INTO "django_geo_db_location" VALUES(55278,NULL,'Waterproof, LA',23292,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55279,NULL,'Waterproof, LA 71375',23292,222,NULL,22,31694,0);
INSERT INTO "django_geo_db_location" VALUES(55280,NULL,'Wildsville, LA',23293,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55281,NULL,'Wildsville, LA 71377',23293,222,NULL,22,31695,0);
INSERT INTO "django_geo_db_location" VALUES(55282,NULL,'Wisner, LA',23294,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55283,NULL,'Wisner, LA 71378',23294,222,NULL,22,31696,0);
INSERT INTO "django_geo_db_location" VALUES(55284,NULL,'Aimwell, LA',23295,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55285,NULL,'Aimwell, LA 71401',23295,222,NULL,22,31697,0);
INSERT INTO "django_geo_db_location" VALUES(55286,NULL,'Anacoco, LA',23296,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55287,NULL,'Anacoco, LA 71403',23296,222,NULL,22,31698,0);
INSERT INTO "django_geo_db_location" VALUES(55288,NULL,'Atlanta, LA',23297,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55289,NULL,'Atlanta, LA 71404',23297,222,NULL,22,31699,0);
INSERT INTO "django_geo_db_location" VALUES(55290,NULL,'Ball, LA',23298,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55291,NULL,'Ball, LA 71405',23298,222,NULL,22,31700,0);
INSERT INTO "django_geo_db_location" VALUES(55292,NULL,'Belmont, LA',23299,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55293,NULL,'Belmont, LA 71406',23299,222,NULL,22,31701,0);
INSERT INTO "django_geo_db_location" VALUES(55294,NULL,'Bentley, LA',23300,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55295,NULL,'Bentley, LA 71407',23300,222,NULL,22,31702,0);
INSERT INTO "django_geo_db_location" VALUES(55296,NULL,'Boyce, LA',23301,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55297,NULL,'Boyce, LA 71409',23301,222,NULL,22,31703,0);
INSERT INTO "django_geo_db_location" VALUES(55298,NULL,'Calvin, LA',23302,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55299,NULL,'Calvin, LA 71410',23302,222,NULL,22,31704,0);
INSERT INTO "django_geo_db_location" VALUES(55300,NULL,'Campti, LA',23303,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55301,NULL,'Campti, LA 71411',23303,222,NULL,22,31705,0);
INSERT INTO "django_geo_db_location" VALUES(55302,NULL,'Clarence, LA',23304,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55303,NULL,'Clarence, LA 71414',23304,222,NULL,22,31706,0);
INSERT INTO "django_geo_db_location" VALUES(55304,NULL,'Clarks, LA',23305,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55305,NULL,'Clarks, LA 71415',23305,222,NULL,22,31707,0);
INSERT INTO "django_geo_db_location" VALUES(55306,NULL,'Cloutierville, LA',23306,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55307,NULL,'Cloutierville, LA 71416',23306,222,NULL,22,31708,0);
INSERT INTO "django_geo_db_location" VALUES(55308,NULL,'Colfax, LA',23307,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55309,NULL,'Colfax, LA 71417',23307,222,NULL,22,31709,0);
INSERT INTO "django_geo_db_location" VALUES(55310,NULL,'Columbia, LA',23308,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55311,NULL,'Columbia, LA 71418',23308,222,NULL,22,31710,0);
INSERT INTO "django_geo_db_location" VALUES(55312,NULL,'Converse, LA',23309,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55313,NULL,'Converse, LA 71419',23309,222,NULL,22,31711,0);
INSERT INTO "django_geo_db_location" VALUES(55314,NULL,'Dodson, LA',23310,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55315,NULL,'Dodson, LA 71422',23310,222,NULL,22,31712,0);
INSERT INTO "django_geo_db_location" VALUES(55316,NULL,'Dry Prong, LA',23311,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55317,NULL,'Dry Prong, LA 71423',23311,222,NULL,22,31713,0);
INSERT INTO "django_geo_db_location" VALUES(55318,NULL,'Elmer, LA',23312,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55319,NULL,'Elmer, LA 71424',23312,222,NULL,22,31714,0);
INSERT INTO "django_geo_db_location" VALUES(55320,NULL,'Enterprise, LA',23313,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55321,NULL,'Enterprise, LA 71425',23313,222,NULL,22,31715,0);
INSERT INTO "django_geo_db_location" VALUES(55322,NULL,'Fisher, LA',23314,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55323,NULL,'Fisher, LA 71426',23314,222,NULL,22,31716,0);
INSERT INTO "django_geo_db_location" VALUES(55324,NULL,'Flatwoods, LA',23315,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55325,NULL,'Flatwoods, LA 71427',23315,222,NULL,22,31717,0);
INSERT INTO "django_geo_db_location" VALUES(55326,NULL,'Flora, LA',23316,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55327,NULL,'Flora, LA 71428',23316,222,NULL,22,31718,0);
INSERT INTO "django_geo_db_location" VALUES(55328,NULL,'Florien, LA',23317,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55329,NULL,'Florien, LA 71429',23317,222,NULL,22,31719,0);
INSERT INTO "django_geo_db_location" VALUES(55330,NULL,'Forest Hill, LA',23318,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55331,NULL,'Forest Hill, LA 71430',23318,222,NULL,22,31720,0);
INSERT INTO "django_geo_db_location" VALUES(55332,NULL,'Gardner, LA',23319,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55333,NULL,'Gardner, LA 71431',23319,222,NULL,22,31721,0);
INSERT INTO "django_geo_db_location" VALUES(55334,NULL,'Georgetown, LA',23320,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55335,NULL,'Georgetown, LA 71432',23320,222,NULL,22,31722,0);
INSERT INTO "django_geo_db_location" VALUES(55336,NULL,'Glenmora, LA',23321,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55337,NULL,'Glenmora, LA 71433',23321,222,NULL,22,31723,0);
INSERT INTO "django_geo_db_location" VALUES(55338,NULL,'Gorum, LA',23322,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55339,NULL,'Gorum, LA 71434',23322,222,NULL,22,31724,0);
INSERT INTO "django_geo_db_location" VALUES(55340,NULL,'Grayson, LA',23323,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55341,NULL,'Grayson, LA 71435',23323,222,NULL,22,31725,0);
INSERT INTO "django_geo_db_location" VALUES(55342,NULL,'McNary, LA',23324,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55343,NULL,'McNary, LA 71436',23324,222,NULL,22,31726,0);
INSERT INTO "django_geo_db_location" VALUES(55344,NULL,'Hineston, LA',23325,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55345,NULL,'Hineston, LA 71438',23325,222,NULL,22,31727,0);
INSERT INTO "django_geo_db_location" VALUES(55346,NULL,'Hornbeck, LA',23326,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55347,NULL,'Hornbeck, LA 71439',23326,222,NULL,22,31728,0);
INSERT INTO "django_geo_db_location" VALUES(55348,NULL,'Joyce, LA',23327,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55349,NULL,'Joyce, LA 71440',23327,222,NULL,22,31729,0);
INSERT INTO "django_geo_db_location" VALUES(55350,NULL,'Kelly, LA',23328,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55351,NULL,'Kelly, LA 71441',23328,222,NULL,22,31730,0);
INSERT INTO "django_geo_db_location" VALUES(55352,NULL,'Kurthwood, LA',23329,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55353,NULL,'Kurthwood, LA 71443',23329,222,NULL,22,31731,0);
INSERT INTO "django_geo_db_location" VALUES(55354,NULL,'Lacamp, LA',23330,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55355,NULL,'Lacamp, LA 71444',23330,222,NULL,22,31732,0);
INSERT INTO "django_geo_db_location" VALUES(55356,NULL,'Leesville, LA',23331,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55357,NULL,'Leesville, LA 71446',23331,222,NULL,22,31733,0);
INSERT INTO "django_geo_db_location" VALUES(55358,NULL,'Lena, LA',23332,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55359,NULL,'Lena, LA 71447',23332,222,NULL,22,31734,0);
INSERT INTO "django_geo_db_location" VALUES(55360,NULL,'Longleaf, LA',23333,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55361,NULL,'Longleaf, LA 71448',23333,222,NULL,22,31735,0);
INSERT INTO "django_geo_db_location" VALUES(55362,NULL,'Many, LA',23334,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55363,NULL,'Many, LA 71449',23334,222,NULL,22,31736,0);
INSERT INTO "django_geo_db_location" VALUES(55364,NULL,'Marthaville, LA',23335,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55365,NULL,'Marthaville, LA 71450',23335,222,NULL,22,31737,0);
INSERT INTO "django_geo_db_location" VALUES(55366,NULL,'Melrose, LA',23336,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55367,NULL,'Melrose, LA 71452',23336,222,NULL,22,31738,0);
INSERT INTO "django_geo_db_location" VALUES(55368,NULL,'Montgomery, LA',23337,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55369,NULL,'Montgomery, LA 71454',23337,222,NULL,22,31739,0);
INSERT INTO "django_geo_db_location" VALUES(55370,NULL,'Mora, LA',23338,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55371,NULL,'Mora, LA 71455',23338,222,NULL,22,31740,0);
INSERT INTO "django_geo_db_location" VALUES(55372,NULL,'Natchez, LA',23339,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55373,NULL,'Natchez, LA 71456',23339,222,NULL,22,31741,0);
INSERT INTO "django_geo_db_location" VALUES(55374,NULL,'Natchitoches, LA',23340,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55375,NULL,'Natchitoches, LA 71457',23340,222,NULL,22,31742,0);
INSERT INTO "django_geo_db_location" VALUES(55376,NULL,'Natchitoches, LA 71458',23340,222,NULL,22,31743,0);
INSERT INTO "django_geo_db_location" VALUES(55377,NULL,'Leesville, LA 71459',23331,222,NULL,22,31744,0);
INSERT INTO "django_geo_db_location" VALUES(55378,NULL,'Negreet, LA',23341,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55379,NULL,'Negreet, LA 71460',23341,222,NULL,22,31745,0);
INSERT INTO "django_geo_db_location" VALUES(55380,NULL,'Newllano, LA',23342,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55381,NULL,'Newllano, LA 71461',23342,222,NULL,22,31746,0);
INSERT INTO "django_geo_db_location" VALUES(55382,NULL,'Noble, LA',23343,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55383,NULL,'Noble, LA 71462',23343,222,NULL,22,31747,0);
INSERT INTO "django_geo_db_location" VALUES(55384,NULL,'Oakdale, LA',23344,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55385,NULL,'Oakdale, LA 71463',23344,222,NULL,22,31748,0);
INSERT INTO "django_geo_db_location" VALUES(55386,NULL,'Olla, LA',23345,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55387,NULL,'Olla, LA 71465',23345,222,NULL,22,31749,0);
INSERT INTO "django_geo_db_location" VALUES(55388,NULL,'Otis, LA',23346,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55389,NULL,'Otis, LA 71466',23346,222,NULL,22,31750,0);
INSERT INTO "django_geo_db_location" VALUES(55390,NULL,'Pollock, LA',23347,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55391,NULL,'Pollock, LA 71467',23347,222,NULL,22,31751,0);
INSERT INTO "django_geo_db_location" VALUES(55392,NULL,'Provencal, LA',23348,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55393,NULL,'Provencal, LA 71468',23348,222,NULL,22,31752,0);
INSERT INTO "django_geo_db_location" VALUES(55394,NULL,'Robeline, LA',23349,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55395,NULL,'Robeline, LA 71469',23349,222,NULL,22,31753,0);
INSERT INTO "django_geo_db_location" VALUES(55396,NULL,'Saint Maurice, LA',23350,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55397,NULL,'Saint Maurice, LA 71471',23350,222,NULL,22,31754,0);
INSERT INTO "django_geo_db_location" VALUES(55398,NULL,'Sieper, LA',23351,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55399,NULL,'Sieper, LA 71472',23351,222,NULL,22,31755,0);
INSERT INTO "django_geo_db_location" VALUES(55400,NULL,'Sikes, LA',23352,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55401,NULL,'Sikes, LA 71473',23352,222,NULL,22,31756,0);
INSERT INTO "django_geo_db_location" VALUES(55402,NULL,'Simpson, LA',23353,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55403,NULL,'Simpson, LA 71474',23353,222,NULL,22,31757,0);
INSERT INTO "django_geo_db_location" VALUES(55404,NULL,'Slagle, LA',23354,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55405,NULL,'Slagle, LA 71475',23354,222,NULL,22,31758,0);
INSERT INTO "django_geo_db_location" VALUES(55406,NULL,'Tioga, LA',23355,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55407,NULL,'Tioga, LA 71477',23355,222,NULL,22,31759,0);
INSERT INTO "django_geo_db_location" VALUES(55408,NULL,'Tullos, LA',23356,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55409,NULL,'Tullos, LA 71479',23356,222,NULL,22,31760,0);
INSERT INTO "django_geo_db_location" VALUES(55410,NULL,'Urania, LA',23357,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55411,NULL,'Urania, LA 71480',23357,222,NULL,22,31761,0);
INSERT INTO "django_geo_db_location" VALUES(55412,NULL,'Verda, LA',23358,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55413,NULL,'Verda, LA 71481',23358,222,NULL,22,31762,0);
INSERT INTO "django_geo_db_location" VALUES(55414,NULL,'Winnfield, LA',23359,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55415,NULL,'Winnfield, LA 71483',23359,222,NULL,22,31763,0);
INSERT INTO "django_geo_db_location" VALUES(55416,NULL,'Woodworth, LA',23360,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55417,NULL,'Woodworth, LA 71485',23360,222,NULL,22,31764,0);
INSERT INTO "django_geo_db_location" VALUES(55418,NULL,'Zwolle, LA',23361,222,NULL,22,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55419,NULL,'Zwolle, LA 71486',23361,222,NULL,22,31765,0);
INSERT INTO "django_geo_db_location" VALUES(55420,NULL,'Leesville, LA 71496',23331,222,NULL,22,31766,0);
INSERT INTO "django_geo_db_location" VALUES(55421,NULL,'Natchitoches, LA 71497',23340,222,NULL,22,31767,0);
INSERT INTO "django_geo_db_location" VALUES(55422,NULL,'Montgomery, LA 71545',23337,222,NULL,22,31768,0);
INSERT INTO "django_geo_db_location" VALUES(55423,NULL,'Pine Bluff, AR',23362,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55424,NULL,'Pine Bluff, AR 71601',23362,222,NULL,4,31769,0);
INSERT INTO "django_geo_db_location" VALUES(55425,NULL,'White Hall, AR',23363,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55426,NULL,'White Hall, AR 71602',23363,222,NULL,4,31770,0);
INSERT INTO "django_geo_db_location" VALUES(55427,NULL,'Pine Bluff, AR 71603',23362,222,NULL,4,31771,0);
INSERT INTO "django_geo_db_location" VALUES(55428,NULL,'Pine Bluff, AR 71611',23362,222,NULL,4,31772,0);
INSERT INTO "django_geo_db_location" VALUES(55429,NULL,'White Hall, AR 71612',23363,222,NULL,4,31773,0);
INSERT INTO "django_geo_db_location" VALUES(55430,NULL,'Pine Bluff, AR 71613',23362,222,NULL,4,31774,0);
INSERT INTO "django_geo_db_location" VALUES(55431,NULL,'Arkansas City, AR',23364,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55432,NULL,'Arkansas City, AR 71630',23364,222,NULL,4,31775,0);
INSERT INTO "django_geo_db_location" VALUES(55433,NULL,'Banks, AR',23365,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55434,NULL,'Banks, AR 71631',23365,222,NULL,4,31776,0);
INSERT INTO "django_geo_db_location" VALUES(55435,NULL,'Crossett, AR',23366,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55436,NULL,'Crossett, AR 71635',23366,222,NULL,4,31777,0);
INSERT INTO "django_geo_db_location" VALUES(55437,NULL,'Dermott, AR',23367,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55438,NULL,'Dermott, AR 71638',23367,222,NULL,4,31778,0);
INSERT INTO "django_geo_db_location" VALUES(55439,NULL,'Dumas, AR',23368,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55440,NULL,'Dumas, AR 71639',23368,222,NULL,4,31779,0);
INSERT INTO "django_geo_db_location" VALUES(55441,NULL,'Eudora, AR',23369,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55442,NULL,'Eudora, AR 71640',23369,222,NULL,4,31780,0);
INSERT INTO "django_geo_db_location" VALUES(55443,NULL,'Fountain Hill, AR',23370,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55444,NULL,'Fountain Hill, AR 71642',23370,222,NULL,4,31781,0);
INSERT INTO "django_geo_db_location" VALUES(55445,NULL,'Gould, AR',23371,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55446,NULL,'Gould, AR 71643',23371,222,NULL,4,31782,0);
INSERT INTO "django_geo_db_location" VALUES(55447,NULL,'Grady, AR',23372,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55448,NULL,'Grady, AR 71644',23372,222,NULL,4,31783,0);
INSERT INTO "django_geo_db_location" VALUES(55449,NULL,'Hamburg, AR',23373,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55450,NULL,'Hamburg, AR 71646',23373,222,NULL,4,31784,0);
INSERT INTO "django_geo_db_location" VALUES(55451,NULL,'Hermitage, AR',23374,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55452,NULL,'Hermitage, AR 71647',23374,222,NULL,4,31785,0);
INSERT INTO "django_geo_db_location" VALUES(55453,NULL,'Jennie, AR',23375,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55454,NULL,'Jennie, AR 71649',23375,222,NULL,4,31786,0);
INSERT INTO "django_geo_db_location" VALUES(55455,NULL,'Jerome, AR',23376,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55456,NULL,'Jerome, AR 71650',23376,222,NULL,4,31787,0);
INSERT INTO "django_geo_db_location" VALUES(55457,NULL,'Jersey, AR',23377,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55458,NULL,'Jersey, AR 71651',23377,222,NULL,4,31788,0);
INSERT INTO "django_geo_db_location" VALUES(55459,NULL,'Kingsland, AR',23378,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55460,NULL,'Kingsland, AR 71652',23378,222,NULL,4,31789,0);
INSERT INTO "django_geo_db_location" VALUES(55461,NULL,'Lake Village, AR',23379,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55462,NULL,'Lake Village, AR 71653',23379,222,NULL,4,31790,0);
INSERT INTO "django_geo_db_location" VALUES(55463,NULL,'McGehee, AR',23380,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55464,NULL,'McGehee, AR 71654',23380,222,NULL,4,31791,0);
INSERT INTO "django_geo_db_location" VALUES(55465,NULL,'Monticello, AR',23381,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55466,NULL,'Monticello, AR 71655',23381,222,NULL,4,31792,0);
INSERT INTO "django_geo_db_location" VALUES(55467,NULL,'Monticello, AR 71656',23381,222,NULL,4,31793,0);
INSERT INTO "django_geo_db_location" VALUES(55468,NULL,'Monticello, AR 71657',23381,222,NULL,4,31794,0);
INSERT INTO "django_geo_db_location" VALUES(55469,NULL,'Montrose, AR',23382,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55470,NULL,'Montrose, AR 71658',23382,222,NULL,4,31795,0);
INSERT INTO "django_geo_db_location" VALUES(55471,NULL,'Moscow, AR',23383,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55472,NULL,'Moscow, AR 71659',23383,222,NULL,4,31796,0);
INSERT INTO "django_geo_db_location" VALUES(55473,NULL,'New Edinburg, AR',23384,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55474,NULL,'New Edinburg, AR 71660',23384,222,NULL,4,31797,0);
INSERT INTO "django_geo_db_location" VALUES(55475,NULL,'Parkdale, AR',23385,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55476,NULL,'Parkdale, AR 71661',23385,222,NULL,4,31798,0);
INSERT INTO "django_geo_db_location" VALUES(55477,NULL,'Pickens, AR',23386,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55478,NULL,'Pickens, AR 71662',23386,222,NULL,4,31799,0);
INSERT INTO "django_geo_db_location" VALUES(55479,NULL,'Portland, AR',23387,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55480,NULL,'Portland, AR 71663',23387,222,NULL,4,31800,0);
INSERT INTO "django_geo_db_location" VALUES(55481,NULL,'Rison, AR',23388,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55482,NULL,'Rison, AR 71665',23388,222,NULL,4,31801,0);
INSERT INTO "django_geo_db_location" VALUES(55483,NULL,'McGehee, AR 71666',23380,222,NULL,4,31802,0);
INSERT INTO "django_geo_db_location" VALUES(55484,NULL,'Star City, AR',23389,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55485,NULL,'Star City, AR 71667',23389,222,NULL,4,31803,0);
INSERT INTO "django_geo_db_location" VALUES(55486,NULL,'Tillar, AR',23390,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55487,NULL,'Tillar, AR 71670',23390,222,NULL,4,31804,0);
INSERT INTO "django_geo_db_location" VALUES(55488,NULL,'Warren, AR',23391,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55489,NULL,'Warren, AR 71671',23391,222,NULL,4,31805,0);
INSERT INTO "django_geo_db_location" VALUES(55490,NULL,'Watson, AR',23392,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55491,NULL,'Watson, AR 71674',23392,222,NULL,4,31806,0);
INSERT INTO "django_geo_db_location" VALUES(55492,NULL,'Wilmar, AR',23393,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55493,NULL,'Wilmar, AR 71675',23393,222,NULL,4,31807,0);
INSERT INTO "django_geo_db_location" VALUES(55494,NULL,'Wilmot, AR',23394,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55495,NULL,'Wilmot, AR 71676',23394,222,NULL,4,31808,0);
INSERT INTO "django_geo_db_location" VALUES(55496,NULL,'Winchester, AR',23395,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55497,NULL,'Winchester, AR 71677',23395,222,NULL,4,31809,0);
INSERT INTO "django_geo_db_location" VALUES(55498,NULL,'Yorktown, AR',23396,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55499,NULL,'Yorktown, AR 71678',23396,222,NULL,4,31810,0);
INSERT INTO "django_geo_db_location" VALUES(55500,NULL,'Warren, AR 71691',23391,222,NULL,4,31811,0);
INSERT INTO "django_geo_db_location" VALUES(55501,NULL,'Camden, AR',23397,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55502,NULL,'Camden, AR 71701',23397,222,NULL,4,31812,0);
INSERT INTO "django_geo_db_location" VALUES(55503,NULL,'Camden, AR 71711',23397,222,NULL,4,31813,0);
INSERT INTO "django_geo_db_location" VALUES(55504,NULL,'Bearden, AR',23398,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55505,NULL,'Bearden, AR 71720',23398,222,NULL,4,31814,0);
INSERT INTO "django_geo_db_location" VALUES(55506,NULL,'Beirne, AR',23399,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55507,NULL,'Beirne, AR 71721',23399,222,NULL,4,31815,0);
INSERT INTO "django_geo_db_location" VALUES(55508,NULL,'Bluff City, AR',23400,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55509,NULL,'Bluff City, AR 71722',23400,222,NULL,4,31816,0);
INSERT INTO "django_geo_db_location" VALUES(55510,NULL,'Calion, AR',23401,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55511,NULL,'Calion, AR 71724',23401,222,NULL,4,31817,0);
INSERT INTO "django_geo_db_location" VALUES(55512,NULL,'Carthage, AR',23402,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55513,NULL,'Carthage, AR 71725',23402,222,NULL,4,31818,0);
INSERT INTO "django_geo_db_location" VALUES(55514,NULL,'Chidester, AR',23403,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55515,NULL,'Chidester, AR 71726',23403,222,NULL,4,31819,0);
INSERT INTO "django_geo_db_location" VALUES(55516,NULL,'Curtis, AR',23404,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55517,NULL,'Curtis, AR 71728',23404,222,NULL,4,31820,0);
INSERT INTO "django_geo_db_location" VALUES(55518,NULL,'El Dorado, AR',23405,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55519,NULL,'El Dorado, AR 71730',23405,222,NULL,4,31821,0);
INSERT INTO "django_geo_db_location" VALUES(55520,NULL,'El Dorado, AR 71731',23405,222,NULL,4,31822,0);
INSERT INTO "django_geo_db_location" VALUES(55521,NULL,'Emerson, AR',23406,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55522,NULL,'Emerson, AR 71740',23406,222,NULL,4,31823,0);
INSERT INTO "django_geo_db_location" VALUES(55523,NULL,'Fordyce, AR',23407,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55524,NULL,'Fordyce, AR 71742',23407,222,NULL,4,31824,0);
INSERT INTO "django_geo_db_location" VALUES(55525,NULL,'Gurdon, AR',23408,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55526,NULL,'Gurdon, AR 71743',23408,222,NULL,4,31825,0);
INSERT INTO "django_geo_db_location" VALUES(55527,NULL,'Hampton, AR',23409,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55528,NULL,'Hampton, AR 71744',23409,222,NULL,4,31826,0);
INSERT INTO "django_geo_db_location" VALUES(55529,NULL,'Harrell, AR',23410,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55530,NULL,'Harrell, AR 71745',23410,222,NULL,4,31827,0);
INSERT INTO "django_geo_db_location" VALUES(55531,NULL,'Huttig, AR',23411,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55532,NULL,'Huttig, AR 71747',23411,222,NULL,4,31828,0);
INSERT INTO "django_geo_db_location" VALUES(55533,NULL,'Ivan, AR',23412,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55534,NULL,'Ivan, AR 71748',23412,222,NULL,4,31829,0);
INSERT INTO "django_geo_db_location" VALUES(55535,NULL,'Junction City, AR',23413,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55536,NULL,'Junction City, AR 71749',23413,222,NULL,4,31830,0);
INSERT INTO "django_geo_db_location" VALUES(55537,NULL,'Lawson, AR',23414,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55538,NULL,'Lawson, AR 71750',23414,222,NULL,4,31831,0);
INSERT INTO "django_geo_db_location" VALUES(55539,NULL,'Louann, AR',23415,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55540,NULL,'Louann, AR 71751',23415,222,NULL,4,31832,0);
INSERT INTO "django_geo_db_location" VALUES(55541,NULL,'McNeil, AR',23416,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55542,NULL,'McNeil, AR 71752',23416,222,NULL,4,31833,0);
INSERT INTO "django_geo_db_location" VALUES(55543,NULL,'Magnolia, AR',23417,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55544,NULL,'Magnolia, AR 71753',23417,222,NULL,4,31834,0);
INSERT INTO "django_geo_db_location" VALUES(55545,NULL,'Magnolia, AR 71754',23417,222,NULL,4,31835,0);
INSERT INTO "django_geo_db_location" VALUES(55546,NULL,'Mount Holly, AR',23418,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55547,NULL,'Mount Holly, AR 71758',23418,222,NULL,4,31836,0);
INSERT INTO "django_geo_db_location" VALUES(55548,NULL,'Norphlet, AR',23419,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55549,NULL,'Norphlet, AR 71759',23419,222,NULL,4,31837,0);
INSERT INTO "django_geo_db_location" VALUES(55550,NULL,'Smackover, AR',23420,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55551,NULL,'Smackover, AR 71762',23420,222,NULL,4,31838,0);
INSERT INTO "django_geo_db_location" VALUES(55552,NULL,'Sparkman, AR',23421,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55553,NULL,'Sparkman, AR 71763',23421,222,NULL,4,31839,0);
INSERT INTO "django_geo_db_location" VALUES(55554,NULL,'Stephens, AR',23422,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55555,NULL,'Stephens, AR 71764',23422,222,NULL,4,31840,0);
INSERT INTO "django_geo_db_location" VALUES(55556,NULL,'Strong, AR',23423,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55557,NULL,'Strong, AR 71765',23423,222,NULL,4,31841,0);
INSERT INTO "django_geo_db_location" VALUES(55558,NULL,'Thornton, AR',23424,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55559,NULL,'Thornton, AR 71766',23424,222,NULL,4,31842,0);
INSERT INTO "django_geo_db_location" VALUES(55560,NULL,'Hampton, AR 71767',23409,222,NULL,4,31843,0);
INSERT INTO "django_geo_db_location" VALUES(55561,NULL,'Urbana, AR',23425,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55562,NULL,'Urbana, AR 71768',23425,222,NULL,4,31844,0);
INSERT INTO "django_geo_db_location" VALUES(55563,NULL,'Village, AR',23426,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55564,NULL,'Village, AR 71769',23426,222,NULL,4,31845,0);
INSERT INTO "django_geo_db_location" VALUES(55565,NULL,'Waldo, AR',23427,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55566,NULL,'Waldo, AR 71770',23427,222,NULL,4,31846,0);
INSERT INTO "django_geo_db_location" VALUES(55567,NULL,'Whelen Springs, AR',23428,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55568,NULL,'Whelen Springs, AR 71772',23428,222,NULL,4,31847,0);
INSERT INTO "django_geo_db_location" VALUES(55569,NULL,'Hope, AR',23429,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55570,NULL,'Hope, AR 71801',23429,222,NULL,4,31848,0);
INSERT INTO "django_geo_db_location" VALUES(55571,NULL,'Hope, AR 71802',23429,222,NULL,4,31849,0);
INSERT INTO "django_geo_db_location" VALUES(55572,NULL,'Alleene, AR',23430,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55573,NULL,'Alleene, AR 71820',23430,222,NULL,4,31850,0);
INSERT INTO "django_geo_db_location" VALUES(55574,NULL,'Ashdown, AR',23431,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55575,NULL,'Ashdown, AR 71822',23431,222,NULL,4,31851,0);
INSERT INTO "django_geo_db_location" VALUES(55576,NULL,'Ben Lomond, AR',23432,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55577,NULL,'Ben Lomond, AR 71823',23432,222,NULL,4,31852,0);
INSERT INTO "django_geo_db_location" VALUES(55578,NULL,'Blevins, AR',23433,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55579,NULL,'Blevins, AR 71825',23433,222,NULL,4,31853,0);
INSERT INTO "django_geo_db_location" VALUES(55580,NULL,'Bradley, AR',23434,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55581,NULL,'Bradley, AR 71826',23434,222,NULL,4,31854,0);
INSERT INTO "django_geo_db_location" VALUES(55582,NULL,'Buckner, AR',23435,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55583,NULL,'Buckner, AR 71827',23435,222,NULL,4,31855,0);
INSERT INTO "django_geo_db_location" VALUES(55584,NULL,'Cale, AR',23436,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55585,NULL,'Cale, AR 71828',23436,222,NULL,4,31856,0);
INSERT INTO "django_geo_db_location" VALUES(55586,NULL,'Columbus, AR',23437,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55587,NULL,'Columbus, AR 71831',23437,222,NULL,4,31857,0);
INSERT INTO "django_geo_db_location" VALUES(55588,NULL,'De Queen, AR',23438,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55589,NULL,'De Queen, AR 71832',23438,222,NULL,4,31858,0);
INSERT INTO "django_geo_db_location" VALUES(55590,NULL,'Dierks, AR',23439,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55591,NULL,'Dierks, AR 71833',23439,222,NULL,4,31859,0);
INSERT INTO "django_geo_db_location" VALUES(55592,NULL,'Doddridge, AR',23440,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55593,NULL,'Doddridge, AR 71834',23440,222,NULL,4,31860,0);
INSERT INTO "django_geo_db_location" VALUES(55594,NULL,'Emmet, AR',23441,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55595,NULL,'Emmet, AR 71835',23441,222,NULL,4,31861,0);
INSERT INTO "django_geo_db_location" VALUES(55596,NULL,'Foreman, AR',23442,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55597,NULL,'Foreman, AR 71836',23442,222,NULL,4,31862,0);
INSERT INTO "django_geo_db_location" VALUES(55598,NULL,'Fouke, AR',23443,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55599,NULL,'Fouke, AR 71837',23443,222,NULL,4,31863,0);
INSERT INTO "django_geo_db_location" VALUES(55600,NULL,'Fulton, AR',23444,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55601,NULL,'Fulton, AR 71838',23444,222,NULL,4,31864,0);
INSERT INTO "django_geo_db_location" VALUES(55602,NULL,'Garland City, AR',23445,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55603,NULL,'Garland City, AR 71839',23445,222,NULL,4,31865,0);
INSERT INTO "django_geo_db_location" VALUES(55604,NULL,'Genoa, AR',23446,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55605,NULL,'Genoa, AR 71840',23446,222,NULL,4,31866,0);
INSERT INTO "django_geo_db_location" VALUES(55606,NULL,'Gillham, AR',23447,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55607,NULL,'Gillham, AR 71841',23447,222,NULL,4,31867,0);
INSERT INTO "django_geo_db_location" VALUES(55608,NULL,'Horatio, AR',23448,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55609,NULL,'Horatio, AR 71842',23448,222,NULL,4,31868,0);
INSERT INTO "django_geo_db_location" VALUES(55610,NULL,'Laneburg, AR',23449,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55611,NULL,'Laneburg, AR 71844',23449,222,NULL,4,31869,0);
INSERT INTO "django_geo_db_location" VALUES(55612,NULL,'Lewisville, AR',23450,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55613,NULL,'Lewisville, AR 71845',23450,222,NULL,4,31870,0);
INSERT INTO "django_geo_db_location" VALUES(55614,NULL,'Lockesburg, AR',23451,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55615,NULL,'Lockesburg, AR 71846',23451,222,NULL,4,31871,0);
INSERT INTO "django_geo_db_location" VALUES(55616,NULL,'McCaskill, AR',23452,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55617,NULL,'McCaskill, AR 71847',23452,222,NULL,4,31872,0);
INSERT INTO "django_geo_db_location" VALUES(55618,NULL,'Mineral Springs, AR',23453,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55619,NULL,'Mineral Springs, AR 71851',23453,222,NULL,4,31873,0);
INSERT INTO "django_geo_db_location" VALUES(55620,NULL,'Nashville, AR',23454,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55621,NULL,'Nashville, AR 71852',23454,222,NULL,4,31874,0);
INSERT INTO "django_geo_db_location" VALUES(55622,NULL,'Ogden, AR',23455,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55623,NULL,'Ogden, AR 71853',23455,222,NULL,4,31875,0);
INSERT INTO "django_geo_db_location" VALUES(55624,NULL,'Texarkana, AR',23456,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55625,NULL,'Texarkana, AR 71854',23456,222,NULL,4,31876,0);
INSERT INTO "django_geo_db_location" VALUES(55626,NULL,'Ozan, AR',23457,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55627,NULL,'Ozan, AR 71855',23457,222,NULL,4,31877,0);
INSERT INTO "django_geo_db_location" VALUES(55628,NULL,'Prescott, AR',23458,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55629,NULL,'Prescott, AR 71857',23458,222,NULL,4,31878,0);
INSERT INTO "django_geo_db_location" VALUES(55630,NULL,'Rosston, AR',23459,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55631,NULL,'Rosston, AR 71858',23459,222,NULL,4,31879,0);
INSERT INTO "django_geo_db_location" VALUES(55632,NULL,'Saratoga, AR',23460,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55633,NULL,'Saratoga, AR 71859',23460,222,NULL,4,31880,0);
INSERT INTO "django_geo_db_location" VALUES(55634,NULL,'Stamps, AR',23461,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55635,NULL,'Stamps, AR 71860',23461,222,NULL,4,31881,0);
INSERT INTO "django_geo_db_location" VALUES(55636,NULL,'Taylor, AR',23462,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55637,NULL,'Taylor, AR 71861',23462,222,NULL,4,31882,0);
INSERT INTO "django_geo_db_location" VALUES(55638,NULL,'Washington, AR',23463,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55639,NULL,'Washington, AR 71862',23463,222,NULL,4,31883,0);
INSERT INTO "django_geo_db_location" VALUES(55640,NULL,'Willisville, AR',23464,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55641,NULL,'Willisville, AR 71864',23464,222,NULL,4,31884,0);
INSERT INTO "django_geo_db_location" VALUES(55642,NULL,'Wilton, AR',23465,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55643,NULL,'Wilton, AR 71865',23465,222,NULL,4,31885,0);
INSERT INTO "django_geo_db_location" VALUES(55644,NULL,'Winthrop, AR',23466,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55645,NULL,'Winthrop, AR 71866',23466,222,NULL,4,31886,0);
INSERT INTO "django_geo_db_location" VALUES(55646,NULL,'Hot Springs National Park, AR',23467,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55647,NULL,'Hot Springs National Park, AR 71901',23467,222,NULL,4,31887,0);
INSERT INTO "django_geo_db_location" VALUES(55648,NULL,'Hot Springs National Park, AR 71902',23467,222,NULL,4,31888,0);
INSERT INTO "django_geo_db_location" VALUES(55649,NULL,'Hot Springs National Park, AR 71903',23467,222,NULL,4,31889,0);
INSERT INTO "django_geo_db_location" VALUES(55650,NULL,'Hot Springs, AR',23468,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55651,NULL,'Hot Springs, AR 71907',23468,222,NULL,4,31890,0);
INSERT INTO "django_geo_db_location" VALUES(55652,NULL,'Hot Springs Village, AR',23469,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55653,NULL,'Hot Springs Village, AR 71909',23469,222,NULL,4,31891,0);
INSERT INTO "django_geo_db_location" VALUES(55654,NULL,'Hot Springs Village, AR 71910',23469,222,NULL,4,31892,0);
INSERT INTO "django_geo_db_location" VALUES(55655,NULL,'Hot Springs National Park, AR 71913',23467,222,NULL,4,31893,0);
INSERT INTO "django_geo_db_location" VALUES(55656,NULL,'Hot Springs National Park, AR 71914',23467,222,NULL,4,31894,0);
INSERT INTO "django_geo_db_location" VALUES(55657,NULL,'Alpine, AR',23470,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55658,NULL,'Alpine, AR 71920',23470,222,NULL,4,31895,0);
INSERT INTO "django_geo_db_location" VALUES(55659,NULL,'Amity, AR',23471,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55660,NULL,'Amity, AR 71921',23471,222,NULL,4,31896,0);
INSERT INTO "django_geo_db_location" VALUES(55661,NULL,'Antoine, AR',23472,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55662,NULL,'Antoine, AR 71922',23472,222,NULL,4,31897,0);
INSERT INTO "django_geo_db_location" VALUES(55663,NULL,'Arkadelphia, AR',23473,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55664,NULL,'Arkadelphia, AR 71923',23473,222,NULL,4,31898,0);
INSERT INTO "django_geo_db_location" VALUES(55665,NULL,'Bismarck, AR',23474,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55666,NULL,'Bismarck, AR 71929',23474,222,NULL,4,31899,0);
INSERT INTO "django_geo_db_location" VALUES(55667,NULL,'Board Camp, AR',23475,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55668,NULL,'Board Camp, AR 71932',23475,222,NULL,4,31900,0);
INSERT INTO "django_geo_db_location" VALUES(55669,NULL,'Bonnerdale, AR',23476,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55670,NULL,'Bonnerdale, AR 71933',23476,222,NULL,4,31901,0);
INSERT INTO "django_geo_db_location" VALUES(55671,NULL,'Caddo Gap, AR',23477,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55672,NULL,'Caddo Gap, AR 71935',23477,222,NULL,4,31902,0);
INSERT INTO "django_geo_db_location" VALUES(55673,NULL,'Cove, AR',23478,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55674,NULL,'Cove, AR 71937',23478,222,NULL,4,31903,0);
INSERT INTO "django_geo_db_location" VALUES(55675,NULL,'Delight, AR',23479,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55676,NULL,'Delight, AR 71940',23479,222,NULL,4,31904,0);
INSERT INTO "django_geo_db_location" VALUES(55677,NULL,'Donaldson, AR',23480,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55678,NULL,'Donaldson, AR 71941',23480,222,NULL,4,31905,0);
INSERT INTO "django_geo_db_location" VALUES(55679,NULL,'Friendship, AR',23481,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55680,NULL,'Friendship, AR 71942',23481,222,NULL,4,31906,0);
INSERT INTO "django_geo_db_location" VALUES(55681,NULL,'Glenwood, AR',23482,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55682,NULL,'Glenwood, AR 71943',23482,222,NULL,4,31907,0);
INSERT INTO "django_geo_db_location" VALUES(55683,NULL,'Grannis, AR',23483,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55684,NULL,'Grannis, AR 71944',23483,222,NULL,4,31908,0);
INSERT INTO "django_geo_db_location" VALUES(55685,NULL,'Hatfield, AR',23484,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55686,NULL,'Hatfield, AR 71945',23484,222,NULL,4,31909,0);
INSERT INTO "django_geo_db_location" VALUES(55687,NULL,'Hatton, AR',23485,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55688,NULL,'Hatton, AR 71946',23485,222,NULL,4,31910,0);
INSERT INTO "django_geo_db_location" VALUES(55689,NULL,'Jessieville, AR',23486,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55690,NULL,'Jessieville, AR 71949',23486,222,NULL,4,31911,0);
INSERT INTO "django_geo_db_location" VALUES(55691,NULL,'Kirby, AR',23487,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55692,NULL,'Kirby, AR 71950',23487,222,NULL,4,31912,0);
INSERT INTO "django_geo_db_location" VALUES(55693,NULL,'Hot Springs National Park, AR 71951',23467,222,NULL,4,31913,0);
INSERT INTO "django_geo_db_location" VALUES(55694,NULL,'Langley, AR',23488,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55695,NULL,'Langley, AR 71952',23488,222,NULL,4,31914,0);
INSERT INTO "django_geo_db_location" VALUES(55696,NULL,'Mena, AR',23489,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55697,NULL,'Mena, AR 71953',23489,222,NULL,4,31915,0);
INSERT INTO "django_geo_db_location" VALUES(55698,NULL,'Mountain Pine, AR',23490,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55699,NULL,'Mountain Pine, AR 71956',23490,222,NULL,4,31916,0);
INSERT INTO "django_geo_db_location" VALUES(55700,NULL,'Mount Ida, AR',23491,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55701,NULL,'Mount Ida, AR 71957',23491,222,NULL,4,31917,0);
INSERT INTO "django_geo_db_location" VALUES(55702,NULL,'Murfreesboro, AR',23492,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55703,NULL,'Murfreesboro, AR 71958',23492,222,NULL,4,31918,0);
INSERT INTO "django_geo_db_location" VALUES(55704,NULL,'Newhope, AR',23493,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55705,NULL,'Newhope, AR 71959',23493,222,NULL,4,31919,0);
INSERT INTO "django_geo_db_location" VALUES(55706,NULL,'Norman, AR',23494,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55707,NULL,'Norman, AR 71960',23494,222,NULL,4,31920,0);
INSERT INTO "django_geo_db_location" VALUES(55708,NULL,'Oden, AR',23495,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55709,NULL,'Oden, AR 71961',23495,222,NULL,4,31921,0);
INSERT INTO "django_geo_db_location" VALUES(55710,NULL,'Okolona, AR',23496,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55711,NULL,'Okolona, AR 71962',23496,222,NULL,4,31922,0);
INSERT INTO "django_geo_db_location" VALUES(55712,NULL,'Pearcy, AR',23497,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55713,NULL,'Pearcy, AR 71964',23497,222,NULL,4,31923,0);
INSERT INTO "django_geo_db_location" VALUES(55714,NULL,'Pencil Bluff, AR',23498,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55715,NULL,'Pencil Bluff, AR 71965',23498,222,NULL,4,31924,0);
INSERT INTO "django_geo_db_location" VALUES(55716,NULL,'Oden, AR 71966',23495,222,NULL,4,31925,0);
INSERT INTO "django_geo_db_location" VALUES(55717,NULL,'Royal, AR',23499,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55718,NULL,'Royal, AR 71968',23499,222,NULL,4,31926,0);
INSERT INTO "django_geo_db_location" VALUES(55719,NULL,'Sims, AR',23500,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55720,NULL,'Sims, AR 71969',23500,222,NULL,4,31927,0);
INSERT INTO "django_geo_db_location" VALUES(55721,NULL,'Story, AR',23501,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55722,NULL,'Story, AR 71970',23501,222,NULL,4,31928,0);
INSERT INTO "django_geo_db_location" VALUES(55723,NULL,'Umpire, AR',23502,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55724,NULL,'Umpire, AR 71971',23502,222,NULL,4,31929,0);
INSERT INTO "django_geo_db_location" VALUES(55725,NULL,'Vandervoort, AR',23503,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55726,NULL,'Vandervoort, AR 71972',23503,222,NULL,4,31930,0);
INSERT INTO "django_geo_db_location" VALUES(55727,NULL,'Wickes, AR',23504,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55728,NULL,'Wickes, AR 71973',23504,222,NULL,4,31931,0);
INSERT INTO "django_geo_db_location" VALUES(55729,NULL,'Arkadelphia, AR 71998',23473,222,NULL,4,31932,0);
INSERT INTO "django_geo_db_location" VALUES(55730,NULL,'Arkadelphia, AR 71999',23473,222,NULL,4,31933,0);
INSERT INTO "django_geo_db_location" VALUES(55731,NULL,'Adona, AR',23505,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55732,NULL,'Adona, AR 72001',23505,222,NULL,4,31934,0);
INSERT INTO "django_geo_db_location" VALUES(55733,NULL,'Alexander, AR',23506,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55734,NULL,'Alexander, AR 72002',23506,222,NULL,4,31935,0);
INSERT INTO "django_geo_db_location" VALUES(55735,NULL,'Almyra, AR',23507,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55736,NULL,'Almyra, AR 72003',23507,222,NULL,4,31936,0);
INSERT INTO "django_geo_db_location" VALUES(55737,NULL,'Altheimer, AR',23508,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55738,NULL,'Altheimer, AR 72004',23508,222,NULL,4,31937,0);
INSERT INTO "django_geo_db_location" VALUES(55739,NULL,'Amagon, AR',23509,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55740,NULL,'Amagon, AR 72005',23509,222,NULL,4,31938,0);
INSERT INTO "django_geo_db_location" VALUES(55741,NULL,'Augusta, AR',23510,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55742,NULL,'Augusta, AR 72006',23510,222,NULL,4,31939,0);
INSERT INTO "django_geo_db_location" VALUES(55743,NULL,'Austin, AR',23511,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55744,NULL,'Austin, AR 72007',23511,222,NULL,4,31940,0);
INSERT INTO "django_geo_db_location" VALUES(55745,NULL,'Bald Knob, AR',23512,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55746,NULL,'Bald Knob, AR 72010',23512,222,NULL,4,31941,0);
INSERT INTO "django_geo_db_location" VALUES(55747,NULL,'Bauxite, AR',23513,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55748,NULL,'Bauxite, AR 72011',23513,222,NULL,4,31942,0);
INSERT INTO "django_geo_db_location" VALUES(55749,NULL,'Beebe, AR',23514,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55750,NULL,'Beebe, AR 72012',23514,222,NULL,4,31943,0);
INSERT INTO "django_geo_db_location" VALUES(55751,NULL,'Bee Branch, AR',23515,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55752,NULL,'Bee Branch, AR 72013',23515,222,NULL,4,31944,0);
INSERT INTO "django_geo_db_location" VALUES(55753,NULL,'Beedeville, AR',23516,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55754,NULL,'Beedeville, AR 72014',23516,222,NULL,4,31945,0);
INSERT INTO "django_geo_db_location" VALUES(55755,NULL,'Benton, AR',23517,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55756,NULL,'Benton, AR 72015',23517,222,NULL,4,31946,0);
INSERT INTO "django_geo_db_location" VALUES(55757,NULL,'Bigelow, AR',23518,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55758,NULL,'Bigelow, AR 72016',23518,222,NULL,4,31947,0);
INSERT INTO "django_geo_db_location" VALUES(55759,NULL,'Biscoe, AR',23519,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55760,NULL,'Biscoe, AR 72017',23519,222,NULL,4,31948,0);
INSERT INTO "django_geo_db_location" VALUES(55761,NULL,'Benton, AR 72018',23517,222,NULL,4,31949,0);
INSERT INTO "django_geo_db_location" VALUES(55762,NULL,'North Little Rock, AR',23520,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55763,NULL,'North Little Rock, AR 72019',23520,222,NULL,4,31950,0);
INSERT INTO "django_geo_db_location" VALUES(55764,NULL,'Bradford, AR',23521,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55765,NULL,'Bradford, AR 72020',23521,222,NULL,4,31951,0);
INSERT INTO "django_geo_db_location" VALUES(55766,NULL,'Brinkley, AR',23522,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55767,NULL,'Brinkley, AR 72021',23522,222,NULL,4,31952,0);
INSERT INTO "django_geo_db_location" VALUES(55768,NULL,'Bryant, AR',23523,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55769,NULL,'Bryant, AR 72022',23523,222,NULL,4,31953,0);
INSERT INTO "django_geo_db_location" VALUES(55770,NULL,'Cabot, AR',23524,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55771,NULL,'Cabot, AR 72023',23524,222,NULL,4,31954,0);
INSERT INTO "django_geo_db_location" VALUES(55772,NULL,'Carlisle, AR',23525,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55773,NULL,'Carlisle, AR 72024',23525,222,NULL,4,31955,0);
INSERT INTO "django_geo_db_location" VALUES(55774,NULL,'Casa, AR',23526,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55775,NULL,'Casa, AR 72025',23526,222,NULL,4,31956,0);
INSERT INTO "django_geo_db_location" VALUES(55776,NULL,'Casscoe, AR',23527,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55777,NULL,'Casscoe, AR 72026',23527,222,NULL,4,31957,0);
INSERT INTO "django_geo_db_location" VALUES(55778,NULL,'Center Ridge, AR',23528,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55779,NULL,'Center Ridge, AR 72027',23528,222,NULL,4,31958,0);
INSERT INTO "django_geo_db_location" VALUES(55780,NULL,'Choctaw, AR',23529,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55781,NULL,'Choctaw, AR 72028',23529,222,NULL,4,31959,0);
INSERT INTO "django_geo_db_location" VALUES(55782,NULL,'Clarendon, AR',23530,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55783,NULL,'Clarendon, AR 72029',23530,222,NULL,4,31960,0);
INSERT INTO "django_geo_db_location" VALUES(55784,NULL,'Cleveland, AR',23531,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55785,NULL,'Cleveland, AR 72030',23531,222,NULL,4,31961,0);
INSERT INTO "django_geo_db_location" VALUES(55786,NULL,'Clinton, AR',23532,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55787,NULL,'Clinton, AR 72031',23532,222,NULL,4,31962,0);
INSERT INTO "django_geo_db_location" VALUES(55788,NULL,'Conway, AR',23533,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55789,NULL,'Conway, AR 72032',23533,222,NULL,4,31963,0);
INSERT INTO "django_geo_db_location" VALUES(55790,NULL,'Conway, AR 72033',23533,222,NULL,4,31964,0);
INSERT INTO "django_geo_db_location" VALUES(55791,NULL,'Conway, AR 72034',23533,222,NULL,4,31965,0);
INSERT INTO "django_geo_db_location" VALUES(55792,NULL,'Conway, AR 72035',23533,222,NULL,4,31966,0);
INSERT INTO "django_geo_db_location" VALUES(55793,NULL,'Cotton Plant, AR',23534,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55794,NULL,'Cotton Plant, AR 72036',23534,222,NULL,4,31967,0);
INSERT INTO "django_geo_db_location" VALUES(55795,NULL,'Coy, AR',23535,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55796,NULL,'Coy, AR 72037',23535,222,NULL,4,31968,0);
INSERT INTO "django_geo_db_location" VALUES(55797,NULL,'Crocketts Bluff, AR',23536,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55798,NULL,'Crocketts Bluff, AR 72038',23536,222,NULL,4,31969,0);
INSERT INTO "django_geo_db_location" VALUES(55799,NULL,'Damascus, AR',23537,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55800,NULL,'Damascus, AR 72039',23537,222,NULL,4,31970,0);
INSERT INTO "django_geo_db_location" VALUES(55801,NULL,'Des Arc, AR',23538,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55802,NULL,'Des Arc, AR 72040',23538,222,NULL,4,31971,0);
INSERT INTO "django_geo_db_location" VALUES(55803,NULL,'De Valls Bluff, AR',23539,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55804,NULL,'De Valls Bluff, AR 72041',23539,222,NULL,4,31972,0);
INSERT INTO "django_geo_db_location" VALUES(55805,NULL,'De Witt, AR',23540,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55806,NULL,'De Witt, AR 72042',23540,222,NULL,4,31973,0);
INSERT INTO "django_geo_db_location" VALUES(55807,NULL,'Diaz, AR',23541,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55808,NULL,'Diaz, AR 72043',23541,222,NULL,4,31974,0);
INSERT INTO "django_geo_db_location" VALUES(55809,NULL,'Edgemont, AR',23542,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55810,NULL,'Edgemont, AR 72044',23542,222,NULL,4,31975,0);
INSERT INTO "django_geo_db_location" VALUES(55811,NULL,'El Paso, AR',23543,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55812,NULL,'El Paso, AR 72045',23543,222,NULL,4,31976,0);
INSERT INTO "django_geo_db_location" VALUES(55813,NULL,'England, AR',23544,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55814,NULL,'England, AR 72046',23544,222,NULL,4,31977,0);
INSERT INTO "django_geo_db_location" VALUES(55815,NULL,'Enola, AR',23545,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55816,NULL,'Enola, AR 72047',23545,222,NULL,4,31978,0);
INSERT INTO "django_geo_db_location" VALUES(55817,NULL,'Ethel, AR',23546,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55818,NULL,'Ethel, AR 72048',23546,222,NULL,4,31979,0);
INSERT INTO "django_geo_db_location" VALUES(55819,NULL,'Fox, AR',23547,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55820,NULL,'Fox, AR 72051',23547,222,NULL,4,31980,0);
INSERT INTO "django_geo_db_location" VALUES(55821,NULL,'Garner, AR',23548,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55822,NULL,'Garner, AR 72052',23548,222,NULL,4,31981,0);
INSERT INTO "django_geo_db_location" VALUES(55823,NULL,'College Station, AR',23549,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55824,NULL,'College Station, AR 72053',23549,222,NULL,4,31982,0);
INSERT INTO "django_geo_db_location" VALUES(55825,NULL,'Gillett, AR',23550,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55826,NULL,'Gillett, AR 72055',23550,222,NULL,4,31983,0);
INSERT INTO "django_geo_db_location" VALUES(55827,NULL,'Grapevine, AR',23551,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55828,NULL,'Grapevine, AR 72057',23551,222,NULL,4,31984,0);
INSERT INTO "django_geo_db_location" VALUES(55829,NULL,'Greenbrier, AR',23552,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55830,NULL,'Greenbrier, AR 72058',23552,222,NULL,4,31985,0);
INSERT INTO "django_geo_db_location" VALUES(55831,NULL,'Gregory, AR',23553,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55832,NULL,'Gregory, AR 72059',23553,222,NULL,4,31986,0);
INSERT INTO "django_geo_db_location" VALUES(55833,NULL,'Griffithville, AR',23554,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55834,NULL,'Griffithville, AR 72060',23554,222,NULL,4,31987,0);
INSERT INTO "django_geo_db_location" VALUES(55835,NULL,'Guy, AR',23555,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55836,NULL,'Guy, AR 72061',23555,222,NULL,4,31988,0);
INSERT INTO "django_geo_db_location" VALUES(55837,NULL,'Hattieville, AR',23556,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55838,NULL,'Hattieville, AR 72063',23556,222,NULL,4,31989,0);
INSERT INTO "django_geo_db_location" VALUES(55839,NULL,'Hazen, AR',23557,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55840,NULL,'Hazen, AR 72064',23557,222,NULL,4,31990,0);
INSERT INTO "django_geo_db_location" VALUES(55841,NULL,'Hensley, AR',23558,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55842,NULL,'Hensley, AR 72065',23558,222,NULL,4,31991,0);
INSERT INTO "django_geo_db_location" VALUES(55843,NULL,'Hickory Plains, AR',23559,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55844,NULL,'Hickory Plains, AR 72066',23559,222,NULL,4,31992,0);
INSERT INTO "django_geo_db_location" VALUES(55845,NULL,'Higden, AR',23560,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55846,NULL,'Higden, AR 72067',23560,222,NULL,4,31993,0);
INSERT INTO "django_geo_db_location" VALUES(55847,NULL,'Higginson, AR',23561,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55848,NULL,'Higginson, AR 72068',23561,222,NULL,4,31994,0);
INSERT INTO "django_geo_db_location" VALUES(55849,NULL,'Holly Grove, AR',23562,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55850,NULL,'Holly Grove, AR 72069',23562,222,NULL,4,31995,0);
INSERT INTO "django_geo_db_location" VALUES(55851,NULL,'Houston, AR',23563,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55852,NULL,'Houston, AR 72070',23563,222,NULL,4,31996,0);
INSERT INTO "django_geo_db_location" VALUES(55853,NULL,'Howell, AR',23564,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55854,NULL,'Howell, AR 72071',23564,222,NULL,4,31997,0);
INSERT INTO "django_geo_db_location" VALUES(55855,NULL,'Humnoke, AR',23565,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55856,NULL,'Humnoke, AR 72072',23565,222,NULL,4,31998,0);
INSERT INTO "django_geo_db_location" VALUES(55857,NULL,'Humphrey, AR',23566,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55858,NULL,'Humphrey, AR 72073',23566,222,NULL,4,31999,0);
INSERT INTO "django_geo_db_location" VALUES(55859,NULL,'Hunter, AR',23567,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55860,NULL,'Hunter, AR 72074',23567,222,NULL,4,32000,0);
INSERT INTO "django_geo_db_location" VALUES(55861,NULL,'Jacksonport, AR',23568,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55862,NULL,'Jacksonport, AR 72075',23568,222,NULL,4,32001,0);
INSERT INTO "django_geo_db_location" VALUES(55863,NULL,'Jacksonville, AR',23569,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55864,NULL,'Jacksonville, AR 72076',23569,222,NULL,4,32002,0);
INSERT INTO "django_geo_db_location" VALUES(55865,NULL,'Jacksonville, AR 72078',23569,222,NULL,4,32003,0);
INSERT INTO "django_geo_db_location" VALUES(55866,NULL,'Jefferson, AR',23570,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55867,NULL,'Jefferson, AR 72079',23570,222,NULL,4,32004,0);
INSERT INTO "django_geo_db_location" VALUES(55868,NULL,'Jerusalem, AR',23571,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55869,NULL,'Jerusalem, AR 72080',23571,222,NULL,4,32005,0);
INSERT INTO "django_geo_db_location" VALUES(55870,NULL,'Judsonia, AR',23572,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55871,NULL,'Judsonia, AR 72081',23572,222,NULL,4,32006,0);
INSERT INTO "django_geo_db_location" VALUES(55872,NULL,'Kensett, AR',23573,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55873,NULL,'Kensett, AR 72082',23573,222,NULL,4,32007,0);
INSERT INTO "django_geo_db_location" VALUES(55874,NULL,'Keo, AR',23574,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55875,NULL,'Keo, AR 72083',23574,222,NULL,4,32008,0);
INSERT INTO "django_geo_db_location" VALUES(55876,NULL,'Leola, AR',23575,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55877,NULL,'Leola, AR 72084',23575,222,NULL,4,32009,0);
INSERT INTO "django_geo_db_location" VALUES(55878,NULL,'Letona, AR',23576,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55879,NULL,'Letona, AR 72085',23576,222,NULL,4,32010,0);
INSERT INTO "django_geo_db_location" VALUES(55880,NULL,'Lonoke, AR',23577,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55881,NULL,'Lonoke, AR 72086',23577,222,NULL,4,32011,0);
INSERT INTO "django_geo_db_location" VALUES(55882,NULL,'Lonsdale, AR',23578,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55883,NULL,'Lonsdale, AR 72087',23578,222,NULL,4,32012,0);
INSERT INTO "django_geo_db_location" VALUES(55884,NULL,'Fairfield Bay, AR',23579,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55885,NULL,'Fairfield Bay, AR 72088',23579,222,NULL,4,32013,0);
INSERT INTO "django_geo_db_location" VALUES(55886,NULL,'Bryant, AR 72089',23523,222,NULL,4,32014,0);
INSERT INTO "django_geo_db_location" VALUES(55887,NULL,'Jacksonville, AR 72098',23569,222,NULL,4,32015,0);
INSERT INTO "django_geo_db_location" VALUES(55888,NULL,'Little Rock Air Force Base, AR',23580,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55889,NULL,'Little Rock Air Force Base, AR 72099',23580,222,NULL,4,32016,0);
INSERT INTO "django_geo_db_location" VALUES(55890,NULL,'McCrory, AR',23581,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55891,NULL,'McCrory, AR 72101',23581,222,NULL,4,32017,0);
INSERT INTO "django_geo_db_location" VALUES(55892,NULL,'McRae, AR',23582,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55893,NULL,'McRae, AR 72102',23582,222,NULL,4,32018,0);
INSERT INTO "django_geo_db_location" VALUES(55894,NULL,'Mabelvale, AR',23583,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55895,NULL,'Mabelvale, AR 72103',23583,222,NULL,4,32019,0);
INSERT INTO "django_geo_db_location" VALUES(55896,NULL,'Malvern, AR',23584,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55897,NULL,'Malvern, AR 72104',23584,222,NULL,4,32020,0);
INSERT INTO "django_geo_db_location" VALUES(55898,NULL,'Jones Mill, AR',23585,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55899,NULL,'Jones Mill, AR 72105',23585,222,NULL,4,32021,0);
INSERT INTO "django_geo_db_location" VALUES(55900,NULL,'Mayflower, AR',23586,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55901,NULL,'Mayflower, AR 72106',23586,222,NULL,4,32022,0);
INSERT INTO "django_geo_db_location" VALUES(55902,NULL,'Menifee, AR',23587,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55903,NULL,'Menifee, AR 72107',23587,222,NULL,4,32023,0);
INSERT INTO "django_geo_db_location" VALUES(55904,NULL,'Monroe, AR',23588,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55905,NULL,'Monroe, AR 72108',23588,222,NULL,4,32024,0);
INSERT INTO "django_geo_db_location" VALUES(55906,NULL,'Morrilton, AR',23589,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55907,NULL,'Morrilton, AR 72110',23589,222,NULL,4,32025,0);
INSERT INTO "django_geo_db_location" VALUES(55908,NULL,'Mount Vernon, AR',23590,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55909,NULL,'Mount Vernon, AR 72111',23590,222,NULL,4,32026,0);
INSERT INTO "django_geo_db_location" VALUES(55910,NULL,'Newport, AR',23591,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55911,NULL,'Newport, AR 72112',23591,222,NULL,4,32027,0);
INSERT INTO "django_geo_db_location" VALUES(55912,NULL,'Maumelle, AR',23592,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55913,NULL,'Maumelle, AR 72113',23592,222,NULL,4,32028,0);
INSERT INTO "django_geo_db_location" VALUES(55914,NULL,'North Little Rock, AR 72114',23520,222,NULL,4,32029,0);
INSERT INTO "django_geo_db_location" VALUES(55915,NULL,'North Little Rock, AR 72115',23520,222,NULL,4,32030,0);
INSERT INTO "django_geo_db_location" VALUES(55916,NULL,'North Little Rock, AR 72116',23520,222,NULL,4,32031,0);
INSERT INTO "django_geo_db_location" VALUES(55917,NULL,'North Little Rock, AR 72117',23520,222,NULL,4,32032,0);
INSERT INTO "django_geo_db_location" VALUES(55918,NULL,'North Little Rock, AR 72118',23520,222,NULL,4,32033,0);
INSERT INTO "django_geo_db_location" VALUES(55919,NULL,'North Little Rock, AR 72119',23520,222,NULL,4,32034,0);
INSERT INTO "django_geo_db_location" VALUES(55920,NULL,'Sherwood, AR',23593,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55921,NULL,'Sherwood, AR 72120',23593,222,NULL,4,32035,0);
INSERT INTO "django_geo_db_location" VALUES(55922,NULL,'Pangburn, AR',23594,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55923,NULL,'Pangburn, AR 72121',23594,222,NULL,4,32036,0);
INSERT INTO "django_geo_db_location" VALUES(55924,NULL,'Paron, AR',23595,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55925,NULL,'Paron, AR 72122',23595,222,NULL,4,32037,0);
INSERT INTO "django_geo_db_location" VALUES(55926,NULL,'Patterson, AR',23596,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55927,NULL,'Patterson, AR 72123',23596,222,NULL,4,32038,0);
INSERT INTO "django_geo_db_location" VALUES(55928,NULL,'North Little Rock, AR 72124',23520,222,NULL,4,32039,0);
INSERT INTO "django_geo_db_location" VALUES(55929,NULL,'Perry, AR',23597,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55930,NULL,'Perry, AR 72125',23597,222,NULL,4,32040,0);
INSERT INTO "django_geo_db_location" VALUES(55931,NULL,'Perryville, AR',23598,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55932,NULL,'Perryville, AR 72126',23598,222,NULL,4,32041,0);
INSERT INTO "django_geo_db_location" VALUES(55933,NULL,'Plumerville, AR',23599,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55934,NULL,'Plumerville, AR 72127',23599,222,NULL,4,32042,0);
INSERT INTO "django_geo_db_location" VALUES(55935,NULL,'Poyen, AR',23600,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55936,NULL,'Poyen, AR 72128',23600,222,NULL,4,32043,0);
INSERT INTO "django_geo_db_location" VALUES(55937,NULL,'Prattsville, AR',23601,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55938,NULL,'Prattsville, AR 72129',23601,222,NULL,4,32044,0);
INSERT INTO "django_geo_db_location" VALUES(55939,NULL,'Prim, AR',23602,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55940,NULL,'Prim, AR 72130',23602,222,NULL,4,32045,0);
INSERT INTO "django_geo_db_location" VALUES(55941,NULL,'Quitman, AR',23603,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55942,NULL,'Quitman, AR 72131',23603,222,NULL,4,32046,0);
INSERT INTO "django_geo_db_location" VALUES(55943,NULL,'Redfield, AR',23604,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55944,NULL,'Redfield, AR 72132',23604,222,NULL,4,32047,0);
INSERT INTO "django_geo_db_location" VALUES(55945,NULL,'Reydell, AR',23605,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55946,NULL,'Reydell, AR 72133',23605,222,NULL,4,32048,0);
INSERT INTO "django_geo_db_location" VALUES(55947,NULL,'Roe, AR',23606,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55948,NULL,'Roe, AR 72134',23606,222,NULL,4,32049,0);
INSERT INTO "django_geo_db_location" VALUES(55949,NULL,'Roland, AR',23607,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55950,NULL,'Roland, AR 72135',23607,222,NULL,4,32050,0);
INSERT INTO "django_geo_db_location" VALUES(55951,NULL,'Romance, AR',23608,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55952,NULL,'Romance, AR 72136',23608,222,NULL,4,32051,0);
INSERT INTO "django_geo_db_location" VALUES(55953,NULL,'Rose Bud, AR',23609,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55954,NULL,'Rose Bud, AR 72137',23609,222,NULL,4,32052,0);
INSERT INTO "django_geo_db_location" VALUES(55955,NULL,'Russell, AR',23610,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55956,NULL,'Russell, AR 72139',23610,222,NULL,4,32053,0);
INSERT INTO "django_geo_db_location" VALUES(55957,NULL,'Saint Charles, AR',23611,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55958,NULL,'Saint Charles, AR 72140',23611,222,NULL,4,32054,0);
INSERT INTO "django_geo_db_location" VALUES(55959,NULL,'Scotland, AR',23612,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55960,NULL,'Scotland, AR 72141',23612,222,NULL,4,32055,0);
INSERT INTO "django_geo_db_location" VALUES(55961,NULL,'Scott, AR',23613,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55962,NULL,'Scott, AR 72142',23613,222,NULL,4,32056,0);
INSERT INTO "django_geo_db_location" VALUES(55963,NULL,'Searcy, AR',23614,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55964,NULL,'Searcy, AR 72143',23614,222,NULL,4,32057,0);
INSERT INTO "django_geo_db_location" VALUES(55965,NULL,'Searcy, AR 72145',23614,222,NULL,4,32058,0);
INSERT INTO "django_geo_db_location" VALUES(55966,NULL,'Searcy, AR 72149',23614,222,NULL,4,32059,0);
INSERT INTO "django_geo_db_location" VALUES(55967,NULL,'Sheridan, AR',23615,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55968,NULL,'Sheridan, AR 72150',23615,222,NULL,4,32060,0);
INSERT INTO "django_geo_db_location" VALUES(55969,NULL,'Sherrill, AR',23616,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55970,NULL,'Sherrill, AR 72152',23616,222,NULL,4,32061,0);
INSERT INTO "django_geo_db_location" VALUES(55971,NULL,'Shirley, AR',23617,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55972,NULL,'Shirley, AR 72153',23617,222,NULL,4,32062,0);
INSERT INTO "django_geo_db_location" VALUES(55973,NULL,'Solgohachia, AR',23618,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55974,NULL,'Solgohachia, AR 72156',23618,222,NULL,4,32063,0);
INSERT INTO "django_geo_db_location" VALUES(55975,NULL,'Springfield, AR',23619,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55976,NULL,'Springfield, AR 72157',23619,222,NULL,4,32064,0);
INSERT INTO "django_geo_db_location" VALUES(55977,NULL,'Benton, AR 72158',23517,222,NULL,4,32065,0);
INSERT INTO "django_geo_db_location" VALUES(55978,NULL,'Stuttgart, AR',23620,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55979,NULL,'Stuttgart, AR 72160',23620,222,NULL,4,32066,0);
INSERT INTO "django_geo_db_location" VALUES(55980,NULL,'Sweet Home, AR',23621,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55981,NULL,'Sweet Home, AR 72164',23621,222,NULL,4,32067,0);
INSERT INTO "django_geo_db_location" VALUES(55982,NULL,'Thida, AR',23622,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55983,NULL,'Thida, AR 72165',23622,222,NULL,4,32068,0);
INSERT INTO "django_geo_db_location" VALUES(55984,NULL,'Tichnor, AR',23623,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55985,NULL,'Tichnor, AR 72166',23623,222,NULL,4,32069,0);
INSERT INTO "django_geo_db_location" VALUES(55986,NULL,'Traskwood, AR',23624,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55987,NULL,'Traskwood, AR 72167',23624,222,NULL,4,32070,0);
INSERT INTO "django_geo_db_location" VALUES(55988,NULL,'Tucker, AR',23625,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55989,NULL,'Tucker, AR 72168',23625,222,NULL,4,32071,0);
INSERT INTO "django_geo_db_location" VALUES(55990,NULL,'Tupelo, AR',23626,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55991,NULL,'Tupelo, AR 72169',23626,222,NULL,4,32072,0);
INSERT INTO "django_geo_db_location" VALUES(55992,NULL,'Ulm, AR',23627,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55993,NULL,'Ulm, AR 72170',23627,222,NULL,4,32073,0);
INSERT INTO "django_geo_db_location" VALUES(55994,NULL,'Vilonia, AR',23628,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55995,NULL,'Vilonia, AR 72173',23628,222,NULL,4,32074,0);
INSERT INTO "django_geo_db_location" VALUES(55996,NULL,'Wabbaseka, AR',23629,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55997,NULL,'Wabbaseka, AR 72175',23629,222,NULL,4,32075,0);
INSERT INTO "django_geo_db_location" VALUES(55998,NULL,'Ward, AR',23630,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(55999,NULL,'Ward, AR 72176',23630,222,NULL,4,32076,0);
INSERT INTO "django_geo_db_location" VALUES(56000,NULL,'West Point, AR',23631,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56001,NULL,'West Point, AR 72178',23631,222,NULL,4,32077,0);
INSERT INTO "django_geo_db_location" VALUES(56002,NULL,'Wilburn, AR',23632,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56003,NULL,'Wilburn, AR 72179',23632,222,NULL,4,32078,0);
INSERT INTO "django_geo_db_location" VALUES(56004,NULL,'Woodson, AR',23633,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56005,NULL,'Woodson, AR 72180',23633,222,NULL,4,32079,0);
INSERT INTO "django_geo_db_location" VALUES(56006,NULL,'Wooster, AR',23634,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56007,NULL,'Wooster, AR 72181',23634,222,NULL,4,32080,0);
INSERT INTO "django_geo_db_location" VALUES(56008,NULL,'Wright, AR',23635,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56009,NULL,'Wright, AR 72182',23635,222,NULL,4,32081,0);
INSERT INTO "django_geo_db_location" VALUES(56010,NULL,'Wrightsville, AR',23636,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56011,NULL,'Wrightsville, AR 72183',23636,222,NULL,4,32082,0);
INSERT INTO "django_geo_db_location" VALUES(56012,NULL,'McCrory, AR 72189',23581,222,NULL,4,32083,0);
INSERT INTO "django_geo_db_location" VALUES(56013,NULL,'North Little Rock, AR 72190',23520,222,NULL,4,32084,0);
INSERT INTO "django_geo_db_location" VALUES(56014,NULL,'North Little Rock, AR 72199',23520,222,NULL,4,32085,0);
INSERT INTO "django_geo_db_location" VALUES(56015,NULL,'Little Rock, AR',23637,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56016,NULL,'Little Rock, AR 72201',23637,222,NULL,4,32086,0);
INSERT INTO "django_geo_db_location" VALUES(56017,NULL,'Little Rock, AR 72202',23637,222,NULL,4,32087,0);
INSERT INTO "django_geo_db_location" VALUES(56018,NULL,'Little Rock, AR 72203',23637,222,NULL,4,32088,0);
INSERT INTO "django_geo_db_location" VALUES(56019,NULL,'Little Rock, AR 72204',23637,222,NULL,4,32089,0);
INSERT INTO "django_geo_db_location" VALUES(56020,NULL,'Little Rock, AR 72205',23637,222,NULL,4,32090,0);
INSERT INTO "django_geo_db_location" VALUES(56021,NULL,'Little Rock, AR 72206',23637,222,NULL,4,32091,0);
INSERT INTO "django_geo_db_location" VALUES(56022,NULL,'Little Rock, AR 72207',23637,222,NULL,4,32092,0);
INSERT INTO "django_geo_db_location" VALUES(56023,NULL,'Little Rock, AR 72209',23637,222,NULL,4,32093,0);
INSERT INTO "django_geo_db_location" VALUES(56024,NULL,'Little Rock, AR 72210',23637,222,NULL,4,32094,0);
INSERT INTO "django_geo_db_location" VALUES(56025,NULL,'Little Rock, AR 72211',23637,222,NULL,4,32095,0);
INSERT INTO "django_geo_db_location" VALUES(56026,NULL,'Little Rock, AR 72212',23637,222,NULL,4,32096,0);
INSERT INTO "django_geo_db_location" VALUES(56027,NULL,'Little Rock, AR 72214',23637,222,NULL,4,32097,0);
INSERT INTO "django_geo_db_location" VALUES(56028,NULL,'Little Rock, AR 72215',23637,222,NULL,4,32098,0);
INSERT INTO "django_geo_db_location" VALUES(56029,NULL,'Little Rock, AR 72216',23637,222,NULL,4,32099,0);
INSERT INTO "django_geo_db_location" VALUES(56030,NULL,'Little Rock, AR 72217',23637,222,NULL,4,32100,0);
INSERT INTO "django_geo_db_location" VALUES(56031,NULL,'Little Rock, AR 72219',23637,222,NULL,4,32101,0);
INSERT INTO "django_geo_db_location" VALUES(56032,NULL,'Little Rock, AR 72221',23637,222,NULL,4,32102,0);
INSERT INTO "django_geo_db_location" VALUES(56033,NULL,'Little Rock, AR 72222',23637,222,NULL,4,32103,0);
INSERT INTO "django_geo_db_location" VALUES(56034,NULL,'Little Rock, AR 72223',23637,222,NULL,4,32104,0);
INSERT INTO "django_geo_db_location" VALUES(56035,NULL,'Little Rock, AR 72225',23637,222,NULL,4,32105,0);
INSERT INTO "django_geo_db_location" VALUES(56036,NULL,'Little Rock, AR 72227',23637,222,NULL,4,32106,0);
INSERT INTO "django_geo_db_location" VALUES(56037,NULL,'Little Rock, AR 72231',23637,222,NULL,4,32107,0);
INSERT INTO "django_geo_db_location" VALUES(56038,NULL,'Little Rock, AR 72259',23637,222,NULL,4,32108,0);
INSERT INTO "django_geo_db_location" VALUES(56039,NULL,'Little Rock, AR 72295',23637,222,NULL,4,32109,0);
INSERT INTO "django_geo_db_location" VALUES(56040,NULL,'West Memphis, AR',23638,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56041,NULL,'West Memphis, AR 72301',23638,222,NULL,4,32110,0);
INSERT INTO "django_geo_db_location" VALUES(56042,NULL,'West Memphis, AR 72303',23638,222,NULL,4,32111,0);
INSERT INTO "django_geo_db_location" VALUES(56043,NULL,'Armorel, AR',23639,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56044,NULL,'Armorel, AR 72310',23639,222,NULL,4,32112,0);
INSERT INTO "django_geo_db_location" VALUES(56045,NULL,'Aubrey, AR',23640,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56046,NULL,'Aubrey, AR 72311',23640,222,NULL,4,32113,0);
INSERT INTO "django_geo_db_location" VALUES(56047,NULL,'Barton, AR',23641,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56048,NULL,'Barton, AR 72312',23641,222,NULL,4,32114,0);
INSERT INTO "django_geo_db_location" VALUES(56049,NULL,'Bassett, AR',23642,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56050,NULL,'Bassett, AR 72313',23642,222,NULL,4,32115,0);
INSERT INTO "django_geo_db_location" VALUES(56051,NULL,'Birdeye, AR',23643,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56052,NULL,'Birdeye, AR 72314',23643,222,NULL,4,32116,0);
INSERT INTO "django_geo_db_location" VALUES(56053,NULL,'Blytheville, AR',23644,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56054,NULL,'Blytheville, AR 72315',23644,222,NULL,4,32117,0);
INSERT INTO "django_geo_db_location" VALUES(56055,NULL,'Blytheville, AR 72316',23644,222,NULL,4,32118,0);
INSERT INTO "django_geo_db_location" VALUES(56056,NULL,'Gosnell, AR',23645,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56057,NULL,'Gosnell, AR 72319',23645,222,NULL,4,32119,0);
INSERT INTO "django_geo_db_location" VALUES(56058,NULL,'Brickeys, AR',23646,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56059,NULL,'Brickeys, AR 72320',23646,222,NULL,4,32120,0);
INSERT INTO "django_geo_db_location" VALUES(56060,NULL,'Burdette, AR',23647,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56061,NULL,'Burdette, AR 72321',23647,222,NULL,4,32121,0);
INSERT INTO "django_geo_db_location" VALUES(56062,NULL,'Caldwell, AR',23648,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56063,NULL,'Caldwell, AR 72322',23648,222,NULL,4,32122,0);
INSERT INTO "django_geo_db_location" VALUES(56064,NULL,'Cherry Valley, AR',23649,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56065,NULL,'Cherry Valley, AR 72324',23649,222,NULL,4,32123,0);
INSERT INTO "django_geo_db_location" VALUES(56066,NULL,'Clarkedale, AR',23650,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56067,NULL,'Clarkedale, AR 72325',23650,222,NULL,4,32124,0);
INSERT INTO "django_geo_db_location" VALUES(56068,NULL,'Colt, AR',23651,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56069,NULL,'Colt, AR 72326',23651,222,NULL,4,32125,0);
INSERT INTO "django_geo_db_location" VALUES(56070,NULL,'Crawfordsville, AR',23652,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56071,NULL,'Crawfordsville, AR 72327',23652,222,NULL,4,32126,0);
INSERT INTO "django_geo_db_location" VALUES(56072,NULL,'Crumrod, AR',23653,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56073,NULL,'Crumrod, AR 72328',23653,222,NULL,4,32127,0);
INSERT INTO "django_geo_db_location" VALUES(56074,NULL,'Driver, AR',23654,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56075,NULL,'Driver, AR 72329',23654,222,NULL,4,32128,0);
INSERT INTO "django_geo_db_location" VALUES(56076,NULL,'Dyess, AR',23655,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56077,NULL,'Dyess, AR 72330',23655,222,NULL,4,32129,0);
INSERT INTO "django_geo_db_location" VALUES(56078,NULL,'Earle, AR',23656,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56079,NULL,'Earle, AR 72331',23656,222,NULL,4,32130,0);
INSERT INTO "django_geo_db_location" VALUES(56080,NULL,'Edmondson, AR',23657,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56081,NULL,'Edmondson, AR 72332',23657,222,NULL,4,32131,0);
INSERT INTO "django_geo_db_location" VALUES(56082,NULL,'Elaine, AR',23658,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56083,NULL,'Elaine, AR 72333',23658,222,NULL,4,32132,0);
INSERT INTO "django_geo_db_location" VALUES(56084,NULL,'Forrest City, AR',23659,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56085,NULL,'Forrest City, AR 72335',23659,222,NULL,4,32133,0);
INSERT INTO "django_geo_db_location" VALUES(56086,NULL,'Forrest City, AR 72336',23659,222,NULL,4,32134,0);
INSERT INTO "django_geo_db_location" VALUES(56087,NULL,'Frenchmans Bayou, AR',23660,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56088,NULL,'Frenchmans Bayou, AR 72338',23660,222,NULL,4,32135,0);
INSERT INTO "django_geo_db_location" VALUES(56089,NULL,'Gilmore, AR',23661,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56090,NULL,'Gilmore, AR 72339',23661,222,NULL,4,32136,0);
INSERT INTO "django_geo_db_location" VALUES(56091,NULL,'Goodwin, AR',23662,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56092,NULL,'Goodwin, AR 72340',23662,222,NULL,4,32137,0);
INSERT INTO "django_geo_db_location" VALUES(56093,NULL,'Haynes, AR',23663,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56094,NULL,'Haynes, AR 72341',23663,222,NULL,4,32138,0);
INSERT INTO "django_geo_db_location" VALUES(56095,NULL,'Helena, AR',23664,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56096,NULL,'Helena, AR 72342',23664,222,NULL,4,32139,0);
INSERT INTO "django_geo_db_location" VALUES(56097,NULL,'Marked Tree, AR',23665,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56098,NULL,'Marked Tree, AR 72345',23665,222,NULL,4,32140,0);
INSERT INTO "django_geo_db_location" VALUES(56099,NULL,'Heth, AR',23666,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56100,NULL,'Heth, AR 72346',23666,222,NULL,4,32141,0);
INSERT INTO "django_geo_db_location" VALUES(56101,NULL,'Hickory Ridge, AR',23667,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56102,NULL,'Hickory Ridge, AR 72347',23667,222,NULL,4,32142,0);
INSERT INTO "django_geo_db_location" VALUES(56103,NULL,'Hughes, AR',23668,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56104,NULL,'Hughes, AR 72348',23668,222,NULL,4,32143,0);
INSERT INTO "django_geo_db_location" VALUES(56105,NULL,'Joiner, AR',23669,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56106,NULL,'Joiner, AR 72350',23669,222,NULL,4,32144,0);
INSERT INTO "django_geo_db_location" VALUES(56107,NULL,'Keiser, AR',23670,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56108,NULL,'Keiser, AR 72351',23670,222,NULL,4,32145,0);
INSERT INTO "django_geo_db_location" VALUES(56109,NULL,'La Grange, AR',23671,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56110,NULL,'La Grange, AR 72352',23671,222,NULL,4,32146,0);
INSERT INTO "django_geo_db_location" VALUES(56111,NULL,'Lambrook, AR',23672,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56112,NULL,'Lambrook, AR 72353',23672,222,NULL,4,32147,0);
INSERT INTO "django_geo_db_location" VALUES(56113,NULL,'Lepanto, AR',23673,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56114,NULL,'Lepanto, AR 72354',23673,222,NULL,4,32148,0);
INSERT INTO "django_geo_db_location" VALUES(56115,NULL,'Lexa, AR',23674,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56116,NULL,'Lexa, AR 72355',23674,222,NULL,4,32149,0);
INSERT INTO "django_geo_db_location" VALUES(56117,NULL,'Luxora, AR',23675,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56118,NULL,'Luxora, AR 72358',23675,222,NULL,4,32150,0);
INSERT INTO "django_geo_db_location" VALUES(56119,NULL,'Madison, AR',23676,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56120,NULL,'Madison, AR 72359',23676,222,NULL,4,32151,0);
INSERT INTO "django_geo_db_location" VALUES(56121,NULL,'Marianna, AR',23677,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56122,NULL,'Marianna, AR 72360',23677,222,NULL,4,32152,0);
INSERT INTO "django_geo_db_location" VALUES(56123,NULL,'Marion, AR',23678,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56124,NULL,'Marion, AR 72364',23678,222,NULL,4,32153,0);
INSERT INTO "django_geo_db_location" VALUES(56125,NULL,'Marked Tree, AR 72365',23665,222,NULL,4,32154,0);
INSERT INTO "django_geo_db_location" VALUES(56126,NULL,'Marvell, AR',23679,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56127,NULL,'Marvell, AR 72366',23679,222,NULL,4,32155,0);
INSERT INTO "django_geo_db_location" VALUES(56128,NULL,'Mellwood, AR',23680,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56129,NULL,'Mellwood, AR 72367',23680,222,NULL,4,32156,0);
INSERT INTO "django_geo_db_location" VALUES(56130,NULL,'Moro, AR',23681,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56131,NULL,'Moro, AR 72368',23681,222,NULL,4,32157,0);
INSERT INTO "django_geo_db_location" VALUES(56132,NULL,'Oneida, AR',23682,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56133,NULL,'Oneida, AR 72369',23682,222,NULL,4,32158,0);
INSERT INTO "django_geo_db_location" VALUES(56134,NULL,'Osceola, AR',23683,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56135,NULL,'Osceola, AR 72370',23683,222,NULL,4,32159,0);
INSERT INTO "django_geo_db_location" VALUES(56136,NULL,'Palestine, AR',23684,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56137,NULL,'Palestine, AR 72372',23684,222,NULL,4,32160,0);
INSERT INTO "django_geo_db_location" VALUES(56138,NULL,'Parkin, AR',23685,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56139,NULL,'Parkin, AR 72373',23685,222,NULL,4,32161,0);
INSERT INTO "django_geo_db_location" VALUES(56140,NULL,'Poplar Grove, AR',23686,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56141,NULL,'Poplar Grove, AR 72374',23686,222,NULL,4,32162,0);
INSERT INTO "django_geo_db_location" VALUES(56142,NULL,'Proctor, AR',23687,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56143,NULL,'Proctor, AR 72376',23687,222,NULL,4,32163,0);
INSERT INTO "django_geo_db_location" VALUES(56144,NULL,'Rivervale, AR',23688,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56145,NULL,'Rivervale, AR 72377',23688,222,NULL,4,32164,0);
INSERT INTO "django_geo_db_location" VALUES(56146,NULL,'Snow Lake, AR',23689,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56147,NULL,'Snow Lake, AR 72379',23689,222,NULL,4,32165,0);
INSERT INTO "django_geo_db_location" VALUES(56148,NULL,'Tomato, AR',23690,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56149,NULL,'Tomato, AR 72381',23690,222,NULL,4,32166,0);
INSERT INTO "django_geo_db_location" VALUES(56150,NULL,'Turner, AR',23691,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56151,NULL,'Turner, AR 72383',23691,222,NULL,4,32167,0);
INSERT INTO "django_geo_db_location" VALUES(56152,NULL,'Turrell, AR',23692,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56153,NULL,'Turrell, AR 72384',23692,222,NULL,4,32168,0);
INSERT INTO "django_geo_db_location" VALUES(56154,NULL,'Twist, AR',23693,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56155,NULL,'Twist, AR 72385',23693,222,NULL,4,32169,0);
INSERT INTO "django_geo_db_location" VALUES(56156,NULL,'Tyronza, AR',23694,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56157,NULL,'Tyronza, AR 72386',23694,222,NULL,4,32170,0);
INSERT INTO "django_geo_db_location" VALUES(56158,NULL,'Vanndale, AR',23695,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56159,NULL,'Vanndale, AR 72387',23695,222,NULL,4,32171,0);
INSERT INTO "django_geo_db_location" VALUES(56160,NULL,'Wabash, AR',23696,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56161,NULL,'Wabash, AR 72389',23696,222,NULL,4,32172,0);
INSERT INTO "django_geo_db_location" VALUES(56162,NULL,'West Helena, AR',23697,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56163,NULL,'West Helena, AR 72390',23697,222,NULL,4,32173,0);
INSERT INTO "django_geo_db_location" VALUES(56164,NULL,'West Ridge, AR',23698,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56165,NULL,'West Ridge, AR 72391',23698,222,NULL,4,32174,0);
INSERT INTO "django_geo_db_location" VALUES(56166,NULL,'Wheatley, AR',23699,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56167,NULL,'Wheatley, AR 72392',23699,222,NULL,4,32175,0);
INSERT INTO "django_geo_db_location" VALUES(56168,NULL,'Widener, AR',23700,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56169,NULL,'Widener, AR 72394',23700,222,NULL,4,32176,0);
INSERT INTO "django_geo_db_location" VALUES(56170,NULL,'Wilson, AR',23701,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56171,NULL,'Wilson, AR 72395',23701,222,NULL,4,32177,0);
INSERT INTO "django_geo_db_location" VALUES(56172,NULL,'Wynne, AR',23702,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56173,NULL,'Wynne, AR 72396',23702,222,NULL,4,32178,0);
INSERT INTO "django_geo_db_location" VALUES(56174,NULL,'McCrory, AR 72397',23581,222,NULL,4,32179,0);
INSERT INTO "django_geo_db_location" VALUES(56175,NULL,'Jonesboro, AR',23703,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56176,NULL,'Jonesboro, AR 72401',23703,222,NULL,4,32180,0);
INSERT INTO "django_geo_db_location" VALUES(56177,NULL,'Jonesboro, AR 72402',23703,222,NULL,4,32181,0);
INSERT INTO "django_geo_db_location" VALUES(56178,NULL,'Jonesboro, AR 72403',23703,222,NULL,4,32182,0);
INSERT INTO "django_geo_db_location" VALUES(56179,NULL,'Jonesboro, AR 72404',23703,222,NULL,4,32183,0);
INSERT INTO "django_geo_db_location" VALUES(56180,NULL,'Alicia, AR',23704,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56181,NULL,'Alicia, AR 72410',23704,222,NULL,4,32184,0);
INSERT INTO "django_geo_db_location" VALUES(56182,NULL,'Bay, AR',23705,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56183,NULL,'Bay, AR 72411',23705,222,NULL,4,32185,0);
INSERT INTO "django_geo_db_location" VALUES(56184,NULL,'Beech Grove, AR',23706,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56185,NULL,'Beech Grove, AR 72412',23706,222,NULL,4,32186,0);
INSERT INTO "django_geo_db_location" VALUES(56186,NULL,'Biggers, AR',23707,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56187,NULL,'Biggers, AR 72413',23707,222,NULL,4,32187,0);
INSERT INTO "django_geo_db_location" VALUES(56188,NULL,'Black Oak, AR',23708,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56189,NULL,'Black Oak, AR 72414',23708,222,NULL,4,32188,0);
INSERT INTO "django_geo_db_location" VALUES(56190,NULL,'Black Rock, AR',23709,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56191,NULL,'Black Rock, AR 72415',23709,222,NULL,4,32189,0);
INSERT INTO "django_geo_db_location" VALUES(56192,NULL,'Bono, AR',23710,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56193,NULL,'Bono, AR 72416',23710,222,NULL,4,32190,0);
INSERT INTO "django_geo_db_location" VALUES(56194,NULL,'Brookland, AR',23711,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56195,NULL,'Brookland, AR 72417',23711,222,NULL,4,32191,0);
INSERT INTO "django_geo_db_location" VALUES(56196,NULL,'Caraway, AR',23712,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56197,NULL,'Caraway, AR 72419',23712,222,NULL,4,32192,0);
INSERT INTO "django_geo_db_location" VALUES(56198,NULL,'Cash, AR',23713,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56199,NULL,'Cash, AR 72421',23713,222,NULL,4,32193,0);
INSERT INTO "django_geo_db_location" VALUES(56200,NULL,'Corning, AR',23714,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56201,NULL,'Corning, AR 72422',23714,222,NULL,4,32194,0);
INSERT INTO "django_geo_db_location" VALUES(56202,NULL,'Tuckerman, AR',23715,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56203,NULL,'Tuckerman, AR 72423',23715,222,NULL,4,32195,0);
INSERT INTO "django_geo_db_location" VALUES(56204,NULL,'Datto, AR',23716,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56205,NULL,'Datto, AR 72424',23716,222,NULL,4,32196,0);
INSERT INTO "django_geo_db_location" VALUES(56206,NULL,'Delaplaine, AR',23717,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56207,NULL,'Delaplaine, AR 72425',23717,222,NULL,4,32197,0);
INSERT INTO "django_geo_db_location" VALUES(56208,NULL,'Dell, AR',23718,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56209,NULL,'Dell, AR 72426',23718,222,NULL,4,32198,0);
INSERT INTO "django_geo_db_location" VALUES(56210,NULL,'Egypt, AR',23719,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56211,NULL,'Egypt, AR 72427',23719,222,NULL,4,32199,0);
INSERT INTO "django_geo_db_location" VALUES(56212,NULL,'Etowah, AR',23720,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56213,NULL,'Etowah, AR 72428',23720,222,NULL,4,32200,0);
INSERT INTO "django_geo_db_location" VALUES(56214,NULL,'Fisher, AR',23721,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56215,NULL,'Fisher, AR 72429',23721,222,NULL,4,32201,0);
INSERT INTO "django_geo_db_location" VALUES(56216,NULL,'Greenway, AR',23722,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56217,NULL,'Greenway, AR 72430',23722,222,NULL,4,32202,0);
INSERT INTO "django_geo_db_location" VALUES(56218,NULL,'Grubbs, AR',23723,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56219,NULL,'Grubbs, AR 72431',23723,222,NULL,4,32203,0);
INSERT INTO "django_geo_db_location" VALUES(56220,NULL,'Harrisburg, AR',23724,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56221,NULL,'Harrisburg, AR 72432',23724,222,NULL,4,32204,0);
INSERT INTO "django_geo_db_location" VALUES(56222,NULL,'Hoxie, AR',23725,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56223,NULL,'Hoxie, AR 72433',23725,222,NULL,4,32205,0);
INSERT INTO "django_geo_db_location" VALUES(56224,NULL,'Imboden, AR',23726,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56225,NULL,'Imboden, AR 72434',23726,222,NULL,4,32206,0);
INSERT INTO "django_geo_db_location" VALUES(56226,NULL,'Knobel, AR',23727,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56227,NULL,'Knobel, AR 72435',23727,222,NULL,4,32207,0);
INSERT INTO "django_geo_db_location" VALUES(56228,NULL,'Lafe, AR',23728,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56229,NULL,'Lafe, AR 72436',23728,222,NULL,4,32208,0);
INSERT INTO "django_geo_db_location" VALUES(56230,NULL,'Lake City, AR',23729,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56231,NULL,'Lake City, AR 72437',23729,222,NULL,4,32209,0);
INSERT INTO "django_geo_db_location" VALUES(56232,NULL,'Leachville, AR',23730,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56233,NULL,'Leachville, AR 72438',23730,222,NULL,4,32210,0);
INSERT INTO "django_geo_db_location" VALUES(56234,NULL,'Light, AR',23731,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56235,NULL,'Light, AR 72439',23731,222,NULL,4,32211,0);
INSERT INTO "django_geo_db_location" VALUES(56236,NULL,'Lynn, AR',23732,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56237,NULL,'Lynn, AR 72440',23732,222,NULL,4,32212,0);
INSERT INTO "django_geo_db_location" VALUES(56238,NULL,'McDougal, AR',23733,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56239,NULL,'McDougal, AR 72441',23733,222,NULL,4,32213,0);
INSERT INTO "django_geo_db_location" VALUES(56240,NULL,'Manila, AR',23734,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56241,NULL,'Manila, AR 72442',23734,222,NULL,4,32214,0);
INSERT INTO "django_geo_db_location" VALUES(56242,NULL,'Marmaduke, AR',23735,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56243,NULL,'Marmaduke, AR 72443',23735,222,NULL,4,32215,0);
INSERT INTO "django_geo_db_location" VALUES(56244,NULL,'Maynard, AR',23736,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56245,NULL,'Maynard, AR 72444',23736,222,NULL,4,32216,0);
INSERT INTO "django_geo_db_location" VALUES(56246,NULL,'Minturn, AR',23737,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56247,NULL,'Minturn, AR 72445',23737,222,NULL,4,32217,0);
INSERT INTO "django_geo_db_location" VALUES(56248,NULL,'Monette, AR',23738,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56249,NULL,'Monette, AR 72447',23738,222,NULL,4,32218,0);
INSERT INTO "django_geo_db_location" VALUES(56250,NULL,'Marmaduke, AR 72448',23735,222,NULL,4,32219,0);
INSERT INTO "django_geo_db_location" VALUES(56251,NULL,'O Kean, AR',23739,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56252,NULL,'O Kean, AR 72449',23739,222,NULL,4,32220,0);
INSERT INTO "django_geo_db_location" VALUES(56253,NULL,'Paragould, AR',23740,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56254,NULL,'Paragould, AR 72450',23740,222,NULL,4,32221,0);
INSERT INTO "django_geo_db_location" VALUES(56255,NULL,'Paragould, AR 72451',23740,222,NULL,4,32222,0);
INSERT INTO "django_geo_db_location" VALUES(56256,NULL,'Paragould, AR 72452',23740,222,NULL,4,32223,0);
INSERT INTO "django_geo_db_location" VALUES(56257,NULL,'Peach Orchard, AR',23741,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56258,NULL,'Peach Orchard, AR 72453',23741,222,NULL,4,32224,0);
INSERT INTO "django_geo_db_location" VALUES(56259,NULL,'Piggott, AR',23742,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56260,NULL,'Piggott, AR 72454',23742,222,NULL,4,32225,0);
INSERT INTO "django_geo_db_location" VALUES(56261,NULL,'Pocahontas, AR',23743,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56262,NULL,'Pocahontas, AR 72455',23743,222,NULL,4,32226,0);
INSERT INTO "django_geo_db_location" VALUES(56263,NULL,'Pollard, AR',23744,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56264,NULL,'Pollard, AR 72456',23744,222,NULL,4,32227,0);
INSERT INTO "django_geo_db_location" VALUES(56265,NULL,'Portia, AR',23745,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56266,NULL,'Portia, AR 72457',23745,222,NULL,4,32228,0);
INSERT INTO "django_geo_db_location" VALUES(56267,NULL,'Powhatan, AR',23746,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56268,NULL,'Powhatan, AR 72458',23746,222,NULL,4,32229,0);
INSERT INTO "django_geo_db_location" VALUES(56269,NULL,'Ravenden, AR',23747,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56270,NULL,'Ravenden, AR 72459',23747,222,NULL,4,32230,0);
INSERT INTO "django_geo_db_location" VALUES(56271,NULL,'Ravenden Springs, AR',23748,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56272,NULL,'Ravenden Springs, AR 72460',23748,222,NULL,4,32231,0);
INSERT INTO "django_geo_db_location" VALUES(56273,NULL,'Rector, AR',23749,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56274,NULL,'Rector, AR 72461',23749,222,NULL,4,32232,0);
INSERT INTO "django_geo_db_location" VALUES(56275,NULL,'Reyno, AR',23750,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56276,NULL,'Reyno, AR 72462',23750,222,NULL,4,32233,0);
INSERT INTO "django_geo_db_location" VALUES(56277,NULL,'Saint Francis, AR',23751,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56278,NULL,'Saint Francis, AR 72464',23751,222,NULL,4,32234,0);
INSERT INTO "django_geo_db_location" VALUES(56279,NULL,'Sedgwick, AR',23752,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56280,NULL,'Sedgwick, AR 72465',23752,222,NULL,4,32235,0);
INSERT INTO "django_geo_db_location" VALUES(56281,NULL,'Smithville, AR',23753,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56282,NULL,'Smithville, AR 72466',23753,222,NULL,4,32236,0);
INSERT INTO "django_geo_db_location" VALUES(56283,NULL,'State University, AR',23754,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56284,NULL,'State University, AR 72467',23754,222,NULL,4,32237,0);
INSERT INTO "django_geo_db_location" VALUES(56285,NULL,'Strawberry, AR',23755,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56286,NULL,'Strawberry, AR 72469',23755,222,NULL,4,32238,0);
INSERT INTO "django_geo_db_location" VALUES(56287,NULL,'Success, AR',23756,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56288,NULL,'Success, AR 72470',23756,222,NULL,4,32239,0);
INSERT INTO "django_geo_db_location" VALUES(56289,NULL,'Swifton, AR',23757,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56290,NULL,'Swifton, AR 72471',23757,222,NULL,4,32240,0);
INSERT INTO "django_geo_db_location" VALUES(56291,NULL,'Trumann, AR',23758,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56292,NULL,'Trumann, AR 72472',23758,222,NULL,4,32241,0);
INSERT INTO "django_geo_db_location" VALUES(56293,NULL,'Tuckerman, AR 72473',23715,222,NULL,4,32242,0);
INSERT INTO "django_geo_db_location" VALUES(56294,NULL,'Walcott, AR',23759,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56295,NULL,'Walcott, AR 72474',23759,222,NULL,4,32243,0);
INSERT INTO "django_geo_db_location" VALUES(56296,NULL,'Waldenburg, AR',23760,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56297,NULL,'Waldenburg, AR 72475',23760,222,NULL,4,32244,0);
INSERT INTO "django_geo_db_location" VALUES(56298,NULL,'Walnut Ridge, AR',23761,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56299,NULL,'Walnut Ridge, AR 72476',23761,222,NULL,4,32245,0);
INSERT INTO "django_geo_db_location" VALUES(56300,NULL,'Maynard, AR 72477',23736,222,NULL,4,32246,0);
INSERT INTO "django_geo_db_location" VALUES(56301,NULL,'Warm Springs, AR',23762,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56302,NULL,'Warm Springs, AR 72478',23762,222,NULL,4,32247,0);
INSERT INTO "django_geo_db_location" VALUES(56303,NULL,'Weiner, AR',23763,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56304,NULL,'Weiner, AR 72479',23763,222,NULL,4,32248,0);
INSERT INTO "django_geo_db_location" VALUES(56305,NULL,'Williford, AR',23764,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56306,NULL,'Williford, AR 72482',23764,222,NULL,4,32249,0);
INSERT INTO "django_geo_db_location" VALUES(56307,NULL,'Batesville, AR',23765,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56308,NULL,'Batesville, AR 72501',23765,222,NULL,4,32250,0);
INSERT INTO "django_geo_db_location" VALUES(56309,NULL,'Batesville, AR 72503',23765,222,NULL,4,32251,0);
INSERT INTO "django_geo_db_location" VALUES(56310,NULL,'Horseshoe Bend, AR',23766,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56311,NULL,'Horseshoe Bend, AR 72512',23766,222,NULL,4,32252,0);
INSERT INTO "django_geo_db_location" VALUES(56312,NULL,'Ash Flat, AR',23767,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56313,NULL,'Ash Flat, AR 72513',23767,222,NULL,4,32253,0);
INSERT INTO "django_geo_db_location" VALUES(56314,NULL,'Bexar, AR',23768,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56315,NULL,'Bexar, AR 72515',23768,222,NULL,4,32254,0);
INSERT INTO "django_geo_db_location" VALUES(56316,NULL,'Boswell, AR',23769,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56317,NULL,'Boswell, AR 72516',23769,222,NULL,4,32255,0);
INSERT INTO "django_geo_db_location" VALUES(56318,NULL,'Brockwell, AR',23770,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56319,NULL,'Brockwell, AR 72517',23770,222,NULL,4,32256,0);
INSERT INTO "django_geo_db_location" VALUES(56320,NULL,'Calico Rock, AR',23771,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56321,NULL,'Calico Rock, AR 72519',23771,222,NULL,4,32257,0);
INSERT INTO "django_geo_db_location" VALUES(56322,NULL,'Camp, AR',23772,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56323,NULL,'Camp, AR 72520',23772,222,NULL,4,32258,0);
INSERT INTO "django_geo_db_location" VALUES(56324,NULL,'Cave City, AR',23773,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56325,NULL,'Cave City, AR 72521',23773,222,NULL,4,32259,0);
INSERT INTO "django_geo_db_location" VALUES(56326,NULL,'Charlotte, AR',23774,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56327,NULL,'Charlotte, AR 72522',23774,222,NULL,4,32260,0);
INSERT INTO "django_geo_db_location" VALUES(56328,NULL,'Concord, AR',23775,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56329,NULL,'Concord, AR 72523',23775,222,NULL,4,32261,0);
INSERT INTO "django_geo_db_location" VALUES(56330,NULL,'Cord, AR',23776,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56331,NULL,'Cord, AR 72524',23776,222,NULL,4,32262,0);
INSERT INTO "django_geo_db_location" VALUES(56332,NULL,'Cherokee Village, AR',23777,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56333,NULL,'Cherokee Village, AR 72525',23777,222,NULL,4,32263,0);
INSERT INTO "django_geo_db_location" VALUES(56334,NULL,'Cushman, AR',23778,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56335,NULL,'Cushman, AR 72526',23778,222,NULL,4,32264,0);
INSERT INTO "django_geo_db_location" VALUES(56336,NULL,'Desha, AR',23779,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56337,NULL,'Desha, AR 72527',23779,222,NULL,4,32265,0);
INSERT INTO "django_geo_db_location" VALUES(56338,NULL,'Dolph, AR',23780,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56339,NULL,'Dolph, AR 72528',23780,222,NULL,4,32266,0);
INSERT INTO "django_geo_db_location" VALUES(56340,NULL,'Cherokee Village, AR 72529',23777,222,NULL,4,32267,0);
INSERT INTO "django_geo_db_location" VALUES(56341,NULL,'Drasco, AR',23781,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56342,NULL,'Drasco, AR 72530',23781,222,NULL,4,32268,0);
INSERT INTO "django_geo_db_location" VALUES(56343,NULL,'Elizabeth, AR',23782,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56344,NULL,'Elizabeth, AR 72531',23782,222,NULL,4,32269,0);
INSERT INTO "django_geo_db_location" VALUES(56345,NULL,'Evening Shade, AR',23783,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56346,NULL,'Evening Shade, AR 72532',23783,222,NULL,4,32270,0);
INSERT INTO "django_geo_db_location" VALUES(56347,NULL,'Fifty Six, AR',23784,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56348,NULL,'Fifty Six, AR 72533',23784,222,NULL,4,32271,0);
INSERT INTO "django_geo_db_location" VALUES(56349,NULL,'Floral, AR',23785,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56350,NULL,'Floral, AR 72534',23785,222,NULL,4,32272,0);
INSERT INTO "django_geo_db_location" VALUES(56351,NULL,'Franklin, AR',23786,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56352,NULL,'Franklin, AR 72536',23786,222,NULL,4,32273,0);
INSERT INTO "django_geo_db_location" VALUES(56353,NULL,'Gamaliel, AR',23787,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56354,NULL,'Gamaliel, AR 72537',23787,222,NULL,4,32274,0);
INSERT INTO "django_geo_db_location" VALUES(56355,NULL,'Gepp, AR',23788,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56356,NULL,'Gepp, AR 72538',23788,222,NULL,4,32275,0);
INSERT INTO "django_geo_db_location" VALUES(56357,NULL,'Glencoe, AR',23789,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56358,NULL,'Glencoe, AR 72539',23789,222,NULL,4,32276,0);
INSERT INTO "django_geo_db_location" VALUES(56359,NULL,'Guion, AR',23790,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56360,NULL,'Guion, AR 72540',23790,222,NULL,4,32277,0);
INSERT INTO "django_geo_db_location" VALUES(56361,NULL,'Hardy, AR',23791,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56362,NULL,'Hardy, AR 72542',23791,222,NULL,4,32278,0);
INSERT INTO "django_geo_db_location" VALUES(56363,NULL,'Heber Springs, AR',23792,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56364,NULL,'Heber Springs, AR 72543',23792,222,NULL,4,32279,0);
INSERT INTO "django_geo_db_location" VALUES(56365,NULL,'Henderson, AR',23793,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56366,NULL,'Henderson, AR 72544',23793,222,NULL,4,32280,0);
INSERT INTO "django_geo_db_location" VALUES(56367,NULL,'Heber Springs, AR 72545',23792,222,NULL,4,32281,0);
INSERT INTO "django_geo_db_location" VALUES(56368,NULL,'Ida, AR',23794,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56369,NULL,'Ida, AR 72546',23794,222,NULL,4,32282,0);
INSERT INTO "django_geo_db_location" VALUES(56370,NULL,'Locust Grove, AR',23795,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56371,NULL,'Locust Grove, AR 72550',23795,222,NULL,4,32283,0);
INSERT INTO "django_geo_db_location" VALUES(56372,NULL,'Magness, AR',23796,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56373,NULL,'Magness, AR 72553',23796,222,NULL,4,32284,0);
INSERT INTO "django_geo_db_location" VALUES(56374,NULL,'Mammoth Spring, AR',23797,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56375,NULL,'Mammoth Spring, AR 72554',23797,222,NULL,4,32285,0);
INSERT INTO "django_geo_db_location" VALUES(56376,NULL,'Marcella, AR',23798,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56377,NULL,'Marcella, AR 72555',23798,222,NULL,4,32286,0);
INSERT INTO "django_geo_db_location" VALUES(56378,NULL,'Melbourne, AR',23799,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56379,NULL,'Melbourne, AR 72556',23799,222,NULL,4,32287,0);
INSERT INTO "django_geo_db_location" VALUES(56380,NULL,'Moko, AR',23800,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56381,NULL,'Moko, AR 72557',23800,222,NULL,4,32288,0);
INSERT INTO "django_geo_db_location" VALUES(56382,NULL,'Salem, AR',23801,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56383,NULL,'Salem, AR 72559',23801,222,NULL,4,32289,0);
INSERT INTO "django_geo_db_location" VALUES(56384,NULL,'Mountain View, AR',23802,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56385,NULL,'Mountain View, AR 72560',23802,222,NULL,4,32290,0);
INSERT INTO "django_geo_db_location" VALUES(56386,NULL,'Mount Pleasant, AR',23803,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56387,NULL,'Mount Pleasant, AR 72561',23803,222,NULL,4,32291,0);
INSERT INTO "django_geo_db_location" VALUES(56388,NULL,'Newark, AR',23804,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56389,NULL,'Newark, AR 72562',23804,222,NULL,4,32292,0);
INSERT INTO "django_geo_db_location" VALUES(56390,NULL,'Oil Trough, AR',23805,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56391,NULL,'Oil Trough, AR 72564',23805,222,NULL,4,32293,0);
INSERT INTO "django_geo_db_location" VALUES(56392,NULL,'Oxford, AR',23806,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56393,NULL,'Oxford, AR 72565',23806,222,NULL,4,32294,0);
INSERT INTO "django_geo_db_location" VALUES(56394,NULL,'Pineville, AR',23807,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56395,NULL,'Pineville, AR 72566',23807,222,NULL,4,32295,0);
INSERT INTO "django_geo_db_location" VALUES(56396,NULL,'Pleasant Grove, AR',23808,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56397,NULL,'Pleasant Grove, AR 72567',23808,222,NULL,4,32296,0);
INSERT INTO "django_geo_db_location" VALUES(56398,NULL,'Pleasant Plains, AR',23809,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56399,NULL,'Pleasant Plains, AR 72568',23809,222,NULL,4,32297,0);
INSERT INTO "django_geo_db_location" VALUES(56400,NULL,'Poughkeepsie, AR',23810,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56401,NULL,'Poughkeepsie, AR 72569',23810,222,NULL,4,32298,0);
INSERT INTO "django_geo_db_location" VALUES(56402,NULL,'Rosie, AR',23811,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56403,NULL,'Rosie, AR 72571',23811,222,NULL,4,32299,0);
INSERT INTO "django_geo_db_location" VALUES(56404,NULL,'Saffell, AR',23812,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56405,NULL,'Saffell, AR 72572',23812,222,NULL,4,32300,0);
INSERT INTO "django_geo_db_location" VALUES(56406,NULL,'Sage, AR',23813,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56407,NULL,'Sage, AR 72573',23813,222,NULL,4,32301,0);
INSERT INTO "django_geo_db_location" VALUES(56408,NULL,'Salado, AR',23814,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56409,NULL,'Salado, AR 72575',23814,222,NULL,4,32302,0);
INSERT INTO "django_geo_db_location" VALUES(56410,NULL,'Salem, AR 72576',23801,222,NULL,4,32303,0);
INSERT INTO "django_geo_db_location" VALUES(56411,NULL,'Sidney, AR',23815,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56412,NULL,'Sidney, AR 72577',23815,222,NULL,4,32304,0);
INSERT INTO "django_geo_db_location" VALUES(56413,NULL,'Sturkie, AR',23816,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56414,NULL,'Sturkie, AR 72578',23816,222,NULL,4,32305,0);
INSERT INTO "django_geo_db_location" VALUES(56415,NULL,'Sulphur Rock, AR',23817,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56416,NULL,'Sulphur Rock, AR 72579',23817,222,NULL,4,32306,0);
INSERT INTO "django_geo_db_location" VALUES(56417,NULL,'Tumbling Shoals, AR',23818,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56418,NULL,'Tumbling Shoals, AR 72581',23818,222,NULL,4,32307,0);
INSERT INTO "django_geo_db_location" VALUES(56419,NULL,'Viola, AR',23819,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56420,NULL,'Viola, AR 72583',23819,222,NULL,4,32308,0);
INSERT INTO "django_geo_db_location" VALUES(56421,NULL,'Violet Hill, AR',23820,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56422,NULL,'Violet Hill, AR 72584',23820,222,NULL,4,32309,0);
INSERT INTO "django_geo_db_location" VALUES(56423,NULL,'Wideman, AR',23821,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56424,NULL,'Wideman, AR 72585',23821,222,NULL,4,32310,0);
INSERT INTO "django_geo_db_location" VALUES(56425,NULL,'Wiseman, AR',23822,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56426,NULL,'Wiseman, AR 72587',23822,222,NULL,4,32311,0);
INSERT INTO "django_geo_db_location" VALUES(56427,NULL,'Harrison, AR',23823,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56428,NULL,'Harrison, AR 72601',23823,222,NULL,4,32312,0);
INSERT INTO "django_geo_db_location" VALUES(56429,NULL,'Harrison, AR 72602',23823,222,NULL,4,32313,0);
INSERT INTO "django_geo_db_location" VALUES(56430,NULL,'Alco, AR',23824,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56431,NULL,'Alco, AR 72610',23824,222,NULL,4,32314,0);
INSERT INTO "django_geo_db_location" VALUES(56432,NULL,'Alpena, AR',23825,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56433,NULL,'Alpena, AR 72611',23825,222,NULL,4,32315,0);
INSERT INTO "django_geo_db_location" VALUES(56434,NULL,'Beaver, AR',23826,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56435,NULL,'Beaver, AR 72613',23826,222,NULL,4,32316,0);
INSERT INTO "django_geo_db_location" VALUES(56436,NULL,'Bergman, AR',23827,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56437,NULL,'Bergman, AR 72615',23827,222,NULL,4,32317,0);
INSERT INTO "django_geo_db_location" VALUES(56438,NULL,'Berryville, AR',23828,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56439,NULL,'Berryville, AR 72616',23828,222,NULL,4,32318,0);
INSERT INTO "django_geo_db_location" VALUES(56440,NULL,'Big Flat, AR',23829,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56441,NULL,'Big Flat, AR 72617',23829,222,NULL,4,32319,0);
INSERT INTO "django_geo_db_location" VALUES(56442,NULL,'Bull Shoals, AR',23830,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56443,NULL,'Bull Shoals, AR 72619',23830,222,NULL,4,32320,0);
INSERT INTO "django_geo_db_location" VALUES(56444,NULL,'Clarkridge, AR',23831,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56445,NULL,'Clarkridge, AR 72623',23831,222,NULL,4,32321,0);
INSERT INTO "django_geo_db_location" VALUES(56446,NULL,'Compton, AR',23832,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56447,NULL,'Compton, AR 72624',23832,222,NULL,4,32322,0);
INSERT INTO "django_geo_db_location" VALUES(56448,NULL,'Cotter, AR',23833,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56449,NULL,'Cotter, AR 72626',23833,222,NULL,4,32323,0);
INSERT INTO "django_geo_db_location" VALUES(56450,NULL,'Deer, AR',23834,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56451,NULL,'Deer, AR 72628',23834,222,NULL,4,32324,0);
INSERT INTO "django_geo_db_location" VALUES(56452,NULL,'Dennard, AR',23835,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56453,NULL,'Dennard, AR 72629',23835,222,NULL,4,32325,0);
INSERT INTO "django_geo_db_location" VALUES(56454,NULL,'Diamond City, AR',23836,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56455,NULL,'Diamond City, AR 72630',23836,222,NULL,4,32326,0);
INSERT INTO "django_geo_db_location" VALUES(56456,NULL,'Eureka Springs, AR',23837,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56457,NULL,'Eureka Springs, AR 72631',23837,222,NULL,4,32327,0);
INSERT INTO "django_geo_db_location" VALUES(56458,NULL,'Eureka Springs, AR 72632',23837,222,NULL,4,32328,0);
INSERT INTO "django_geo_db_location" VALUES(56459,NULL,'Everton, AR',23838,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56460,NULL,'Everton, AR 72633',23838,222,NULL,4,32329,0);
INSERT INTO "django_geo_db_location" VALUES(56461,NULL,'Flippin, AR',23839,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56462,NULL,'Flippin, AR 72634',23839,222,NULL,4,32330,0);
INSERT INTO "django_geo_db_location" VALUES(56463,NULL,'Gassville, AR',23840,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56464,NULL,'Gassville, AR 72635',23840,222,NULL,4,32331,0);
INSERT INTO "django_geo_db_location" VALUES(56465,NULL,'Gilbert, AR',23841,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56466,NULL,'Gilbert, AR 72636',23841,222,NULL,4,32332,0);
INSERT INTO "django_geo_db_location" VALUES(56467,NULL,'Green Forest, AR',23842,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56468,NULL,'Green Forest, AR 72638',23842,222,NULL,4,32333,0);
INSERT INTO "django_geo_db_location" VALUES(56469,NULL,'Harriet, AR',23843,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56470,NULL,'Harriet, AR 72639',23843,222,NULL,4,32334,0);
INSERT INTO "django_geo_db_location" VALUES(56471,NULL,'Hasty, AR',23844,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56472,NULL,'Hasty, AR 72640',23844,222,NULL,4,32335,0);
INSERT INTO "django_geo_db_location" VALUES(56473,NULL,'Jasper, AR',23845,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56474,NULL,'Jasper, AR 72641',23845,222,NULL,4,32336,0);
INSERT INTO "django_geo_db_location" VALUES(56475,NULL,'Lakeview, AR',23846,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56476,NULL,'Lakeview, AR 72642',23846,222,NULL,4,32337,0);
INSERT INTO "django_geo_db_location" VALUES(56477,NULL,'Lead Hill, AR',23847,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56478,NULL,'Lead Hill, AR 72644',23847,222,NULL,4,32338,0);
INSERT INTO "django_geo_db_location" VALUES(56479,NULL,'Leslie, AR',23848,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56480,NULL,'Leslie, AR 72645',23848,222,NULL,4,32339,0);
INSERT INTO "django_geo_db_location" VALUES(56481,NULL,'Marble Falls, AR',23849,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56482,NULL,'Marble Falls, AR 72648',23849,222,NULL,4,32340,0);
INSERT INTO "django_geo_db_location" VALUES(56483,NULL,'Marshall, AR',23850,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56484,NULL,'Marshall, AR 72650',23850,222,NULL,4,32341,0);
INSERT INTO "django_geo_db_location" VALUES(56485,NULL,'Midway, AR',23851,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56486,NULL,'Midway, AR 72651',23851,222,NULL,4,32342,0);
INSERT INTO "django_geo_db_location" VALUES(56487,NULL,'Mountain Home, AR',23852,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56488,NULL,'Mountain Home, AR 72653',23852,222,NULL,4,32343,0);
INSERT INTO "django_geo_db_location" VALUES(56489,NULL,'Mountain Home, AR 72654',23852,222,NULL,4,32344,0);
INSERT INTO "django_geo_db_location" VALUES(56490,NULL,'Mount Judea, AR',23853,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56491,NULL,'Mount Judea, AR 72655',23853,222,NULL,4,32345,0);
INSERT INTO "django_geo_db_location" VALUES(56492,NULL,'Timbo, AR',23854,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56493,NULL,'Timbo, AR 72657',23854,222,NULL,4,32346,0);
INSERT INTO "django_geo_db_location" VALUES(56494,NULL,'Norfork, AR',23855,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56495,NULL,'Norfork, AR 72658',23855,222,NULL,4,32347,0);
INSERT INTO "django_geo_db_location" VALUES(56496,NULL,'Norfork, AR 72659',23855,222,NULL,4,32348,0);
INSERT INTO "django_geo_db_location" VALUES(56497,NULL,'Oak Grove, AR',23856,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56498,NULL,'Oak Grove, AR 72660',23856,222,NULL,4,32349,0);
INSERT INTO "django_geo_db_location" VALUES(56499,NULL,'Oakland, AR',23857,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56500,NULL,'Oakland, AR 72661',23857,222,NULL,4,32350,0);
INSERT INTO "django_geo_db_location" VALUES(56501,NULL,'Omaha, AR',23858,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56502,NULL,'Omaha, AR 72662',23858,222,NULL,4,32351,0);
INSERT INTO "django_geo_db_location" VALUES(56503,NULL,'Onia, AR',23859,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56504,NULL,'Onia, AR 72663',23859,222,NULL,4,32352,0);
INSERT INTO "django_geo_db_location" VALUES(56505,NULL,'Parthenon, AR',23860,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56506,NULL,'Parthenon, AR 72666',23860,222,NULL,4,32353,0);
INSERT INTO "django_geo_db_location" VALUES(56507,NULL,'Peel, AR',23861,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56508,NULL,'Peel, AR 72668',23861,222,NULL,4,32354,0);
INSERT INTO "django_geo_db_location" VALUES(56509,NULL,'Pindall, AR',23862,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56510,NULL,'Pindall, AR 72669',23862,222,NULL,4,32355,0);
INSERT INTO "django_geo_db_location" VALUES(56511,NULL,'Ponca, AR',23863,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56512,NULL,'Ponca, AR 72670',23863,222,NULL,4,32356,0);
INSERT INTO "django_geo_db_location" VALUES(56513,NULL,'Pyatt, AR',23864,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56514,NULL,'Pyatt, AR 72672',23864,222,NULL,4,32357,0);
INSERT INTO "django_geo_db_location" VALUES(56515,NULL,'Saint Joe, AR',23865,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56516,NULL,'Saint Joe, AR 72675',23865,222,NULL,4,32358,0);
INSERT INTO "django_geo_db_location" VALUES(56517,NULL,'Summit, AR',23866,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56518,NULL,'Summit, AR 72677',23866,222,NULL,4,32359,0);
INSERT INTO "django_geo_db_location" VALUES(56519,NULL,'Tilly, AR',23867,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56520,NULL,'Tilly, AR 72679',23867,222,NULL,4,32360,0);
INSERT INTO "django_geo_db_location" VALUES(56521,NULL,'Timbo, AR 72680',23854,222,NULL,4,32361,0);
INSERT INTO "django_geo_db_location" VALUES(56522,NULL,'Valley Springs, AR',23868,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56523,NULL,'Valley Springs, AR 72682',23868,222,NULL,4,32362,0);
INSERT INTO "django_geo_db_location" VALUES(56524,NULL,'Vendor, AR',23869,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56525,NULL,'Vendor, AR 72683',23869,222,NULL,4,32363,0);
INSERT INTO "django_geo_db_location" VALUES(56526,NULL,'Western Grove, AR',23870,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56527,NULL,'Western Grove, AR 72685',23870,222,NULL,4,32364,0);
INSERT INTO "django_geo_db_location" VALUES(56528,NULL,'Witts Springs, AR',23871,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56529,NULL,'Witts Springs, AR 72686',23871,222,NULL,4,32365,0);
INSERT INTO "django_geo_db_location" VALUES(56530,NULL,'Yellville, AR',23872,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56531,NULL,'Yellville, AR 72687',23872,222,NULL,4,32366,0);
INSERT INTO "django_geo_db_location" VALUES(56532,NULL,'Fayetteville, AR',23873,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56533,NULL,'Fayetteville, AR 72701',23873,222,NULL,4,32367,0);
INSERT INTO "django_geo_db_location" VALUES(56534,NULL,'Fayetteville, AR 72702',23873,222,NULL,4,32368,0);
INSERT INTO "django_geo_db_location" VALUES(56535,NULL,'Fayetteville, AR 72703',23873,222,NULL,4,32369,0);
INSERT INTO "django_geo_db_location" VALUES(56536,NULL,'Fayetteville, AR 72704',23873,222,NULL,4,32370,0);
INSERT INTO "django_geo_db_location" VALUES(56537,NULL,'Avoca, AR',23874,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56538,NULL,'Avoca, AR 72711',23874,222,NULL,4,32371,0);
INSERT INTO "django_geo_db_location" VALUES(56539,NULL,'Bentonville, AR',23875,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56540,NULL,'Bentonville, AR 72712',23875,222,NULL,4,32372,0);
INSERT INTO "django_geo_db_location" VALUES(56541,NULL,'Bella Vista, AR',23876,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56542,NULL,'Bella Vista, AR 72714',23876,222,NULL,4,32373,0);
INSERT INTO "django_geo_db_location" VALUES(56543,NULL,'Bella Vista, AR 72715',23876,222,NULL,4,32374,0);
INSERT INTO "django_geo_db_location" VALUES(56544,NULL,'Bentonville, AR 72716',23875,222,NULL,4,32375,0);
INSERT INTO "django_geo_db_location" VALUES(56545,NULL,'Canehill, AR',23877,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56546,NULL,'Canehill, AR 72717',23877,222,NULL,4,32376,0);
INSERT INTO "django_geo_db_location" VALUES(56547,NULL,'Cave Springs, AR',23878,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56548,NULL,'Cave Springs, AR 72718',23878,222,NULL,4,32377,0);
INSERT INTO "django_geo_db_location" VALUES(56549,NULL,'Centerton, AR',23879,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56550,NULL,'Centerton, AR 72719',23879,222,NULL,4,32378,0);
INSERT INTO "django_geo_db_location" VALUES(56551,NULL,'Combs, AR',23880,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56552,NULL,'Combs, AR 72721',23880,222,NULL,4,32379,0);
INSERT INTO "django_geo_db_location" VALUES(56553,NULL,'Decatur, AR',23881,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56554,NULL,'Decatur, AR 72722',23881,222,NULL,4,32380,0);
INSERT INTO "django_geo_db_location" VALUES(56555,NULL,'Elkins, AR',23882,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56556,NULL,'Elkins, AR 72727',23882,222,NULL,4,32381,0);
INSERT INTO "django_geo_db_location" VALUES(56557,NULL,'Elm Springs, AR',23883,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56558,NULL,'Elm Springs, AR 72728',23883,222,NULL,4,32382,0);
INSERT INTO "django_geo_db_location" VALUES(56559,NULL,'Evansville, AR',23884,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56560,NULL,'Evansville, AR 72729',23884,222,NULL,4,32383,0);
INSERT INTO "django_geo_db_location" VALUES(56561,NULL,'Farmington, AR',23885,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56562,NULL,'Farmington, AR 72730',23885,222,NULL,4,32384,0);
INSERT INTO "django_geo_db_location" VALUES(56563,NULL,'Garfield, AR',23886,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56564,NULL,'Garfield, AR 72732',23886,222,NULL,4,32385,0);
INSERT INTO "django_geo_db_location" VALUES(56565,NULL,'Gateway, AR',23887,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56566,NULL,'Gateway, AR 72733',23887,222,NULL,4,32386,0);
INSERT INTO "django_geo_db_location" VALUES(56567,NULL,'Gentry, AR',23888,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56568,NULL,'Gentry, AR 72734',23888,222,NULL,4,32387,0);
INSERT INTO "django_geo_db_location" VALUES(56569,NULL,'Goshen, AR',23889,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56570,NULL,'Goshen, AR 72735',23889,222,NULL,4,32388,0);
INSERT INTO "django_geo_db_location" VALUES(56571,NULL,'Gravette, AR',23890,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56572,NULL,'Gravette, AR 72736',23890,222,NULL,4,32389,0);
INSERT INTO "django_geo_db_location" VALUES(56573,NULL,'Greenland, AR',23891,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56574,NULL,'Greenland, AR 72737',23891,222,NULL,4,32390,0);
INSERT INTO "django_geo_db_location" VALUES(56575,NULL,'Hindsville, AR',23892,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56576,NULL,'Hindsville, AR 72738',23892,222,NULL,4,32391,0);
INSERT INTO "django_geo_db_location" VALUES(56577,NULL,'Hiwasse, AR',23893,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56578,NULL,'Hiwasse, AR 72739',23893,222,NULL,4,32392,0);
INSERT INTO "django_geo_db_location" VALUES(56579,NULL,'Huntsville, AR',23894,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56580,NULL,'Huntsville, AR 72740',23894,222,NULL,4,32393,0);
INSERT INTO "django_geo_db_location" VALUES(56581,NULL,'Johnson, AR',23895,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56582,NULL,'Johnson, AR 72741',23895,222,NULL,4,32394,0);
INSERT INTO "django_geo_db_location" VALUES(56583,NULL,'Kingston, AR',23896,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56584,NULL,'Kingston, AR 72742',23896,222,NULL,4,32395,0);
INSERT INTO "django_geo_db_location" VALUES(56585,NULL,'Lincoln, AR',23897,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56586,NULL,'Lincoln, AR 72744',23897,222,NULL,4,32396,0);
INSERT INTO "django_geo_db_location" VALUES(56587,NULL,'Lowell, AR',23898,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56588,NULL,'Lowell, AR 72745',23898,222,NULL,4,32397,0);
INSERT INTO "django_geo_db_location" VALUES(56589,NULL,'Maysville, AR',23899,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56590,NULL,'Maysville, AR 72747',23899,222,NULL,4,32398,0);
INSERT INTO "django_geo_db_location" VALUES(56591,NULL,'Morrow, AR',23900,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56592,NULL,'Morrow, AR 72749',23900,222,NULL,4,32399,0);
INSERT INTO "django_geo_db_location" VALUES(56593,NULL,'Pea Ridge, AR',23901,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56594,NULL,'Pea Ridge, AR 72751',23901,222,NULL,4,32400,0);
INSERT INTO "django_geo_db_location" VALUES(56595,NULL,'Pettigrew, AR',23902,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56596,NULL,'Pettigrew, AR 72752',23902,222,NULL,4,32401,0);
INSERT INTO "django_geo_db_location" VALUES(56597,NULL,'Prairie Grove, AR',23903,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56598,NULL,'Prairie Grove, AR 72753',23903,222,NULL,4,32402,0);
INSERT INTO "django_geo_db_location" VALUES(56599,NULL,'Rogers, AR',23904,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56600,NULL,'Rogers, AR 72756',23904,222,NULL,4,32403,0);
INSERT INTO "django_geo_db_location" VALUES(56601,NULL,'Rogers, AR 72757',23904,222,NULL,4,32404,0);
INSERT INTO "django_geo_db_location" VALUES(56602,NULL,'Rogers, AR 72758',23904,222,NULL,4,32405,0);
INSERT INTO "django_geo_db_location" VALUES(56603,NULL,'Saint Paul, AR',23905,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56604,NULL,'Saint Paul, AR 72760',23905,222,NULL,4,32406,0);
INSERT INTO "django_geo_db_location" VALUES(56605,NULL,'Siloam Springs, AR',23906,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56606,NULL,'Siloam Springs, AR 72761',23906,222,NULL,4,32407,0);
INSERT INTO "django_geo_db_location" VALUES(56607,NULL,'Springdale, AR',23907,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56608,NULL,'Springdale, AR 72762',23907,222,NULL,4,32408,0);
INSERT INTO "django_geo_db_location" VALUES(56609,NULL,'Springdale, AR 72764',23907,222,NULL,4,32409,0);
INSERT INTO "django_geo_db_location" VALUES(56610,NULL,'Springdale, AR 72765',23907,222,NULL,4,32410,0);
INSERT INTO "django_geo_db_location" VALUES(56611,NULL,'Springdale, AR 72766',23907,222,NULL,4,32411,0);
INSERT INTO "django_geo_db_location" VALUES(56612,NULL,'Sulphur Springs, AR',23908,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56613,NULL,'Sulphur Springs, AR 72768',23908,222,NULL,4,32412,0);
INSERT INTO "django_geo_db_location" VALUES(56614,NULL,'Summers, AR',23909,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56615,NULL,'Summers, AR 72769',23909,222,NULL,4,32413,0);
INSERT INTO "django_geo_db_location" VALUES(56616,NULL,'Tontitown, AR',23910,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56617,NULL,'Tontitown, AR 72770',23910,222,NULL,4,32414,0);
INSERT INTO "django_geo_db_location" VALUES(56618,NULL,'Wesley, AR',23911,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56619,NULL,'Wesley, AR 72773',23911,222,NULL,4,32415,0);
INSERT INTO "django_geo_db_location" VALUES(56620,NULL,'West Fork, AR',23912,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56621,NULL,'West Fork, AR 72774',23912,222,NULL,4,32416,0);
INSERT INTO "django_geo_db_location" VALUES(56622,NULL,'Witter, AR',23913,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56623,NULL,'Witter, AR 72776',23913,222,NULL,4,32417,0);
INSERT INTO "django_geo_db_location" VALUES(56624,NULL,'Russellville, AR',23914,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56625,NULL,'Russellville, AR 72801',23914,222,NULL,4,32418,0);
INSERT INTO "django_geo_db_location" VALUES(56626,NULL,'Russellville, AR 72802',23914,222,NULL,4,32419,0);
INSERT INTO "django_geo_db_location" VALUES(56627,NULL,'Russellville, AR 72811',23914,222,NULL,4,32420,0);
INSERT INTO "django_geo_db_location" VALUES(56628,NULL,'Russellville, AR 72812',23914,222,NULL,4,32421,0);
INSERT INTO "django_geo_db_location" VALUES(56629,NULL,'Alix, AR',23915,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56630,NULL,'Alix, AR 72820',23915,222,NULL,4,32422,0);
INSERT INTO "django_geo_db_location" VALUES(56631,NULL,'Altus, AR',23916,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56632,NULL,'Altus, AR 72821',23916,222,NULL,4,32423,0);
INSERT INTO "django_geo_db_location" VALUES(56633,NULL,'Russellville, AR 72822',23914,222,NULL,4,32424,0);
INSERT INTO "django_geo_db_location" VALUES(56634,NULL,'Atkins, AR',23917,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56635,NULL,'Atkins, AR 72823',23917,222,NULL,4,32425,0);
INSERT INTO "django_geo_db_location" VALUES(56636,NULL,'Belleville, AR',23918,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56637,NULL,'Belleville, AR 72824',23918,222,NULL,4,32426,0);
INSERT INTO "django_geo_db_location" VALUES(56638,NULL,'Blue Mountain, AR',23919,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56639,NULL,'Blue Mountain, AR 72826',23919,222,NULL,4,32427,0);
INSERT INTO "django_geo_db_location" VALUES(56640,NULL,'Bluffton, AR',23920,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56641,NULL,'Bluffton, AR 72827',23920,222,NULL,4,32428,0);
INSERT INTO "django_geo_db_location" VALUES(56642,NULL,'Briggsville, AR',23921,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56643,NULL,'Briggsville, AR 72828',23921,222,NULL,4,32429,0);
INSERT INTO "django_geo_db_location" VALUES(56644,NULL,'Centerville, AR',23922,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56645,NULL,'Centerville, AR 72829',23922,222,NULL,4,32430,0);
INSERT INTO "django_geo_db_location" VALUES(56646,NULL,'Clarksville, AR',23923,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56647,NULL,'Clarksville, AR 72830',23923,222,NULL,4,32431,0);
INSERT INTO "django_geo_db_location" VALUES(56648,NULL,'Coal Hill, AR',23924,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56649,NULL,'Coal Hill, AR 72832',23924,222,NULL,4,32432,0);
INSERT INTO "django_geo_db_location" VALUES(56650,NULL,'Danville, AR',23925,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56651,NULL,'Danville, AR 72833',23925,222,NULL,4,32433,0);
INSERT INTO "django_geo_db_location" VALUES(56652,NULL,'Dardanelle, AR',23926,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56653,NULL,'Dardanelle, AR 72834',23926,222,NULL,4,32434,0);
INSERT INTO "django_geo_db_location" VALUES(56654,NULL,'Delaware, AR',23927,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56655,NULL,'Delaware, AR 72835',23927,222,NULL,4,32435,0);
INSERT INTO "django_geo_db_location" VALUES(56656,NULL,'Dover, AR',23928,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56657,NULL,'Dover, AR 72837',23928,222,NULL,4,32436,0);
INSERT INTO "django_geo_db_location" VALUES(56658,NULL,'Gravelly, AR',23929,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56659,NULL,'Gravelly, AR 72838',23929,222,NULL,4,32437,0);
INSERT INTO "django_geo_db_location" VALUES(56660,NULL,'Hagarville, AR',23930,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56661,NULL,'Hagarville, AR 72839',23930,222,NULL,4,32438,0);
INSERT INTO "django_geo_db_location" VALUES(56662,NULL,'Hartman, AR',23931,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56663,NULL,'Hartman, AR 72840',23931,222,NULL,4,32439,0);
INSERT INTO "django_geo_db_location" VALUES(56664,NULL,'Harvey, AR',23932,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56665,NULL,'Harvey, AR 72841',23932,222,NULL,4,32440,0);
INSERT INTO "django_geo_db_location" VALUES(56666,NULL,'Havana, AR',23933,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56667,NULL,'Havana, AR 72842',23933,222,NULL,4,32441,0);
INSERT INTO "django_geo_db_location" VALUES(56668,NULL,'Hector, AR',23934,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56669,NULL,'Hector, AR 72843',23934,222,NULL,4,32442,0);
INSERT INTO "django_geo_db_location" VALUES(56670,NULL,'Knoxville, AR',23935,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56671,NULL,'Knoxville, AR 72845',23935,222,NULL,4,32443,0);
INSERT INTO "django_geo_db_location" VALUES(56672,NULL,'Lamar, AR',23936,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56673,NULL,'Lamar, AR 72846',23936,222,NULL,4,32444,0);
INSERT INTO "django_geo_db_location" VALUES(56674,NULL,'London, AR',23937,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56675,NULL,'London, AR 72847',23937,222,NULL,4,32445,0);
INSERT INTO "django_geo_db_location" VALUES(56676,NULL,'New Blaine, AR',23938,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56677,NULL,'New Blaine, AR 72851',23938,222,NULL,4,32446,0);
INSERT INTO "django_geo_db_location" VALUES(56678,NULL,'Oark, AR',23939,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56679,NULL,'Oark, AR 72852',23939,222,NULL,4,32447,0);
INSERT INTO "django_geo_db_location" VALUES(56680,NULL,'Ola, AR',23940,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56681,NULL,'Ola, AR 72853',23940,222,NULL,4,32448,0);
INSERT INTO "django_geo_db_location" VALUES(56682,NULL,'Ozone, AR',23941,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56683,NULL,'Ozone, AR 72854',23941,222,NULL,4,32449,0);
INSERT INTO "django_geo_db_location" VALUES(56684,NULL,'Paris, AR',23942,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56685,NULL,'Paris, AR 72855',23942,222,NULL,4,32450,0);
INSERT INTO "django_geo_db_location" VALUES(56686,NULL,'Pelsor, AR',23943,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56687,NULL,'Pelsor, AR 72856',23943,222,NULL,4,32451,0);
INSERT INTO "django_geo_db_location" VALUES(56688,NULL,'Plainview, AR',23944,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56689,NULL,'Plainview, AR 72857',23944,222,NULL,4,32452,0);
INSERT INTO "django_geo_db_location" VALUES(56690,NULL,'Pottsville, AR',23945,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56691,NULL,'Pottsville, AR 72858',23945,222,NULL,4,32453,0);
INSERT INTO "django_geo_db_location" VALUES(56692,NULL,'Rover, AR',23946,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56693,NULL,'Rover, AR 72860',23946,222,NULL,4,32454,0);
INSERT INTO "django_geo_db_location" VALUES(56694,NULL,'Scranton, AR',23947,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56695,NULL,'Scranton, AR 72863',23947,222,NULL,4,32455,0);
INSERT INTO "django_geo_db_location" VALUES(56696,NULL,'Subiaco, AR',23948,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56697,NULL,'Subiaco, AR 72865',23948,222,NULL,4,32456,0);
INSERT INTO "django_geo_db_location" VALUES(56698,NULL,'Fort Smith, AR',23949,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56699,NULL,'Fort Smith, AR 72901',23949,222,NULL,4,32457,0);
INSERT INTO "django_geo_db_location" VALUES(56700,NULL,'Fort Smith, AR 72902',23949,222,NULL,4,32458,0);
INSERT INTO "django_geo_db_location" VALUES(56701,NULL,'Fort Smith, AR 72903',23949,222,NULL,4,32459,0);
INSERT INTO "django_geo_db_location" VALUES(56702,NULL,'Fort Smith, AR 72904',23949,222,NULL,4,32460,0);
INSERT INTO "django_geo_db_location" VALUES(56703,NULL,'Fort Smith, AR 72905',23949,222,NULL,4,32461,0);
INSERT INTO "django_geo_db_location" VALUES(56704,NULL,'Fort Smith, AR 72906',23949,222,NULL,4,32462,0);
INSERT INTO "django_geo_db_location" VALUES(56705,NULL,'Fort Smith, AR 72908',23949,222,NULL,4,32463,0);
INSERT INTO "django_geo_db_location" VALUES(56706,NULL,'Fort Smith, AR 72913',23949,222,NULL,4,32464,0);
INSERT INTO "django_geo_db_location" VALUES(56707,NULL,'Fort Smith, AR 72914',23949,222,NULL,4,32465,0);
INSERT INTO "django_geo_db_location" VALUES(56708,NULL,'Fort Smith, AR 72916',23949,222,NULL,4,32466,0);
INSERT INTO "django_geo_db_location" VALUES(56709,NULL,'Fort Smith, AR 72917',23949,222,NULL,4,32467,0);
INSERT INTO "django_geo_db_location" VALUES(56710,NULL,'Fort Smith, AR 72918',23949,222,NULL,4,32468,0);
INSERT INTO "django_geo_db_location" VALUES(56711,NULL,'Fort Smith, AR 72919',23949,222,NULL,4,32469,0);
INSERT INTO "django_geo_db_location" VALUES(56712,NULL,'Alma, AR',23950,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56713,NULL,'Alma, AR 72921',23950,222,NULL,4,32470,0);
INSERT INTO "django_geo_db_location" VALUES(56714,NULL,'Barling, AR',23951,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56715,NULL,'Barling, AR 72923',23951,222,NULL,4,32471,0);
INSERT INTO "django_geo_db_location" VALUES(56716,NULL,'Bates, AR',23952,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56717,NULL,'Bates, AR 72924',23952,222,NULL,4,32472,0);
INSERT INTO "django_geo_db_location" VALUES(56718,NULL,'Boles, AR',23953,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56719,NULL,'Boles, AR 72926',23953,222,NULL,4,32473,0);
INSERT INTO "django_geo_db_location" VALUES(56720,NULL,'Booneville, AR',23954,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56721,NULL,'Booneville, AR 72927',23954,222,NULL,4,32474,0);
INSERT INTO "django_geo_db_location" VALUES(56722,NULL,'Branch, AR',23955,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56723,NULL,'Branch, AR 72928',23955,222,NULL,4,32475,0);
INSERT INTO "django_geo_db_location" VALUES(56724,NULL,'Cecil, AR',23956,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56725,NULL,'Cecil, AR 72930',23956,222,NULL,4,32476,0);
INSERT INTO "django_geo_db_location" VALUES(56726,NULL,'Cedarville, AR',23957,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56727,NULL,'Cedarville, AR 72932',23957,222,NULL,4,32477,0);
INSERT INTO "django_geo_db_location" VALUES(56728,NULL,'Charleston, AR',23958,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56729,NULL,'Charleston, AR 72933',23958,222,NULL,4,32478,0);
INSERT INTO "django_geo_db_location" VALUES(56730,NULL,'Chester, AR',23959,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56731,NULL,'Chester, AR 72934',23959,222,NULL,4,32479,0);
INSERT INTO "django_geo_db_location" VALUES(56732,NULL,'Dyer, AR',23960,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56733,NULL,'Dyer, AR 72935',23960,222,NULL,4,32480,0);
INSERT INTO "django_geo_db_location" VALUES(56734,NULL,'Greenwood, AR',23961,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56735,NULL,'Greenwood, AR 72936',23961,222,NULL,4,32481,0);
INSERT INTO "django_geo_db_location" VALUES(56736,NULL,'Hackett, AR',23962,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56737,NULL,'Hackett, AR 72937',23962,222,NULL,4,32482,0);
INSERT INTO "django_geo_db_location" VALUES(56738,NULL,'Hartford, AR',23963,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56739,NULL,'Hartford, AR 72938',23963,222,NULL,4,32483,0);
INSERT INTO "django_geo_db_location" VALUES(56740,NULL,'Huntington, AR',23964,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56741,NULL,'Huntington, AR 72940',23964,222,NULL,4,32484,0);
INSERT INTO "django_geo_db_location" VALUES(56742,NULL,'Lavaca, AR',23965,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56743,NULL,'Lavaca, AR 72941',23965,222,NULL,4,32485,0);
INSERT INTO "django_geo_db_location" VALUES(56744,NULL,'Magazine, AR',23966,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56745,NULL,'Magazine, AR 72943',23966,222,NULL,4,32486,0);
INSERT INTO "django_geo_db_location" VALUES(56746,NULL,'Mansfield, AR',23967,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56747,NULL,'Mansfield, AR 72944',23967,222,NULL,4,32487,0);
INSERT INTO "django_geo_db_location" VALUES(56748,NULL,'Midland, AR',23968,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56749,NULL,'Midland, AR 72945',23968,222,NULL,4,32488,0);
INSERT INTO "django_geo_db_location" VALUES(56750,NULL,'Mountainburg, AR',23969,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56751,NULL,'Mountainburg, AR 72946',23969,222,NULL,4,32489,0);
INSERT INTO "django_geo_db_location" VALUES(56752,NULL,'Mulberry, AR',23970,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56753,NULL,'Mulberry, AR 72947',23970,222,NULL,4,32490,0);
INSERT INTO "django_geo_db_location" VALUES(56754,NULL,'Natural Dam, AR',23971,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56755,NULL,'Natural Dam, AR 72948',23971,222,NULL,4,32491,0);
INSERT INTO "django_geo_db_location" VALUES(56756,NULL,'Ozark, AR',23972,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56757,NULL,'Ozark, AR 72949',23972,222,NULL,4,32492,0);
INSERT INTO "django_geo_db_location" VALUES(56758,NULL,'Parks, AR',23973,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56759,NULL,'Parks, AR 72950',23973,222,NULL,4,32493,0);
INSERT INTO "django_geo_db_location" VALUES(56760,NULL,'Ratcliff, AR',23974,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56761,NULL,'Ratcliff, AR 72951',23974,222,NULL,4,32494,0);
INSERT INTO "django_geo_db_location" VALUES(56762,NULL,'Rudy, AR',23975,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56763,NULL,'Rudy, AR 72952',23975,222,NULL,4,32495,0);
INSERT INTO "django_geo_db_location" VALUES(56764,NULL,'Uniontown, AR',23976,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56765,NULL,'Uniontown, AR 72955',23976,222,NULL,4,32496,0);
INSERT INTO "django_geo_db_location" VALUES(56766,NULL,'Van Buren, AR',23977,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56767,NULL,'Van Buren, AR 72956',23977,222,NULL,4,32497,0);
INSERT INTO "django_geo_db_location" VALUES(56768,NULL,'Van Buren, AR 72957',23977,222,NULL,4,32498,0);
INSERT INTO "django_geo_db_location" VALUES(56769,NULL,'Waldron, AR',23978,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56770,NULL,'Waldron, AR 72958',23978,222,NULL,4,32499,0);
INSERT INTO "django_geo_db_location" VALUES(56771,NULL,'Winslow, AR',23979,222,NULL,4,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56772,NULL,'Winslow, AR 72959',23979,222,NULL,4,32500,0);
INSERT INTO "django_geo_db_location" VALUES(56773,NULL,'Albert, OK',23980,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56774,NULL,'Albert, OK 73001',23980,222,NULL,36,32501,0);
INSERT INTO "django_geo_db_location" VALUES(56775,NULL,'Alex, OK',23981,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56776,NULL,'Alex, OK 73002',23981,222,NULL,36,32502,0);
INSERT INTO "django_geo_db_location" VALUES(56777,NULL,'Edmond, OK',23982,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56778,NULL,'Edmond, OK 73003',23982,222,NULL,36,32503,0);
INSERT INTO "django_geo_db_location" VALUES(56779,NULL,'Amber, OK',23983,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56780,NULL,'Amber, OK 73004',23983,222,NULL,36,32504,0);
INSERT INTO "django_geo_db_location" VALUES(56781,NULL,'Anadarko, OK',23984,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56782,NULL,'Anadarko, OK 73005',23984,222,NULL,36,32505,0);
INSERT INTO "django_geo_db_location" VALUES(56783,NULL,'Apache, OK',23985,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56784,NULL,'Apache, OK 73006',23985,222,NULL,36,32506,0);
INSERT INTO "django_geo_db_location" VALUES(56785,NULL,'Arcadia, OK',23986,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56786,NULL,'Arcadia, OK 73007',23986,222,NULL,36,32507,0);
INSERT INTO "django_geo_db_location" VALUES(56787,NULL,'Bethany, OK',23987,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56788,NULL,'Bethany, OK 73008',23987,222,NULL,36,32508,0);
INSERT INTO "django_geo_db_location" VALUES(56789,NULL,'Binger, OK',23988,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56790,NULL,'Binger, OK 73009',23988,222,NULL,36,32509,0);
INSERT INTO "django_geo_db_location" VALUES(56791,NULL,'Blanchard, OK',23989,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56792,NULL,'Blanchard, OK 73010',23989,222,NULL,36,32510,0);
INSERT INTO "django_geo_db_location" VALUES(56793,NULL,'Bradley, OK',23990,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56794,NULL,'Bradley, OK 73011',23990,222,NULL,36,32511,0);
INSERT INTO "django_geo_db_location" VALUES(56795,NULL,'Bray, OK',23991,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56796,NULL,'Bray, OK 73012',23991,222,NULL,36,32512,0);
INSERT INTO "django_geo_db_location" VALUES(56797,NULL,'Edmond, OK 73013',23982,222,NULL,36,32513,0);
INSERT INTO "django_geo_db_location" VALUES(56798,NULL,'Calumet, OK',23992,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56799,NULL,'Calumet, OK 73014',23992,222,NULL,36,32514,0);
INSERT INTO "django_geo_db_location" VALUES(56800,NULL,'Carnegie, OK',23993,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56801,NULL,'Carnegie, OK 73015',23993,222,NULL,36,32515,0);
INSERT INTO "django_geo_db_location" VALUES(56802,NULL,'Cashion, OK',23994,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56803,NULL,'Cashion, OK 73016',23994,222,NULL,36,32516,0);
INSERT INTO "django_geo_db_location" VALUES(56804,NULL,'Cement, OK',23995,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56805,NULL,'Cement, OK 73017',23995,222,NULL,36,32517,0);
INSERT INTO "django_geo_db_location" VALUES(56806,NULL,'Chickasha, OK',23996,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56807,NULL,'Chickasha, OK 73018',23996,222,NULL,36,32518,0);
INSERT INTO "django_geo_db_location" VALUES(56808,NULL,'Norman, OK',23997,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56809,NULL,'Norman, OK 73019',23997,222,NULL,36,32519,0);
INSERT INTO "django_geo_db_location" VALUES(56810,NULL,'Choctaw, OK',23998,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56811,NULL,'Choctaw, OK 73020',23998,222,NULL,36,32520,0);
INSERT INTO "django_geo_db_location" VALUES(56812,NULL,'Colony, OK',23999,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56813,NULL,'Colony, OK 73021',23999,222,NULL,36,32521,0);
INSERT INTO "django_geo_db_location" VALUES(56814,NULL,'Concho, OK',24000,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56815,NULL,'Concho, OK 73022',24000,222,NULL,36,32522,0);
INSERT INTO "django_geo_db_location" VALUES(56816,NULL,'Chickasha, OK 73023',23996,222,NULL,36,32523,0);
INSERT INTO "django_geo_db_location" VALUES(56817,NULL,'Corn, OK',24001,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56818,NULL,'Corn, OK 73024',24001,222,NULL,36,32524,0);
INSERT INTO "django_geo_db_location" VALUES(56819,NULL,'Norman, OK 73026',23997,222,NULL,36,32525,0);
INSERT INTO "django_geo_db_location" VALUES(56820,NULL,'Coyle, OK',24002,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56821,NULL,'Coyle, OK 73027',24002,222,NULL,36,32526,0);
INSERT INTO "django_geo_db_location" VALUES(56822,NULL,'Crescent, OK',24003,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56823,NULL,'Crescent, OK 73028',24003,222,NULL,36,32527,0);
INSERT INTO "django_geo_db_location" VALUES(56824,NULL,'Cyril, OK',24004,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56825,NULL,'Cyril, OK 73029',24004,222,NULL,36,32528,0);
INSERT INTO "django_geo_db_location" VALUES(56826,NULL,'Davis, OK',24005,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56827,NULL,'Davis, OK 73030',24005,222,NULL,36,32529,0);
INSERT INTO "django_geo_db_location" VALUES(56828,NULL,'Dibble, OK',24006,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56829,NULL,'Dibble, OK 73031',24006,222,NULL,36,32530,0);
INSERT INTO "django_geo_db_location" VALUES(56830,NULL,'Dougherty, OK',24007,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56831,NULL,'Dougherty, OK 73032',24007,222,NULL,36,32531,0);
INSERT INTO "django_geo_db_location" VALUES(56832,NULL,'Eakly, OK',24008,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56833,NULL,'Eakly, OK 73033',24008,222,NULL,36,32532,0);
INSERT INTO "django_geo_db_location" VALUES(56834,NULL,'Edmond, OK 73034',23982,222,NULL,36,32533,0);
INSERT INTO "django_geo_db_location" VALUES(56835,NULL,'El Reno, OK',24009,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56836,NULL,'El Reno, OK 73036',24009,222,NULL,36,32534,0);
INSERT INTO "django_geo_db_location" VALUES(56837,NULL,'Fort Cobb, OK',24010,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56838,NULL,'Fort Cobb, OK 73038',24010,222,NULL,36,32535,0);
INSERT INTO "django_geo_db_location" VALUES(56839,NULL,'Geary, OK',24011,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56840,NULL,'Geary, OK 73040',24011,222,NULL,36,32536,0);
INSERT INTO "django_geo_db_location" VALUES(56841,NULL,'Gotebo, OK',24012,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56842,NULL,'Gotebo, OK 73041',24012,222,NULL,36,32537,0);
INSERT INTO "django_geo_db_location" VALUES(56843,NULL,'Gracemont, OK',24013,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56844,NULL,'Gracemont, OK 73042',24013,222,NULL,36,32538,0);
INSERT INTO "django_geo_db_location" VALUES(56845,NULL,'Greenfield, OK',24014,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56846,NULL,'Greenfield, OK 73043',24014,222,NULL,36,32539,0);
INSERT INTO "django_geo_db_location" VALUES(56847,NULL,'Guthrie, OK',24015,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56848,NULL,'Guthrie, OK 73044',24015,222,NULL,36,32540,0);
INSERT INTO "django_geo_db_location" VALUES(56849,NULL,'Harrah, OK',24016,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56850,NULL,'Harrah, OK 73045',24016,222,NULL,36,32541,0);
INSERT INTO "django_geo_db_location" VALUES(56851,NULL,'Hinton, OK',24017,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56852,NULL,'Hinton, OK 73047',24017,222,NULL,36,32542,0);
INSERT INTO "django_geo_db_location" VALUES(56853,NULL,'Hydro, OK',24018,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56854,NULL,'Hydro, OK 73048',24018,222,NULL,36,32543,0);
INSERT INTO "django_geo_db_location" VALUES(56855,NULL,'Jones, OK',24019,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56856,NULL,'Jones, OK 73049',24019,222,NULL,36,32544,0);
INSERT INTO "django_geo_db_location" VALUES(56857,NULL,'Langston, OK',24020,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56858,NULL,'Langston, OK 73050',24020,222,NULL,36,32545,0);
INSERT INTO "django_geo_db_location" VALUES(56859,NULL,'Lexington, OK',24021,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56860,NULL,'Lexington, OK 73051',24021,222,NULL,36,32546,0);
INSERT INTO "django_geo_db_location" VALUES(56861,NULL,'Lindsay, OK',24022,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56862,NULL,'Lindsay, OK 73052',24022,222,NULL,36,32547,0);
INSERT INTO "django_geo_db_location" VALUES(56863,NULL,'Lookeba, OK',24023,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56864,NULL,'Lookeba, OK 73053',24023,222,NULL,36,32548,0);
INSERT INTO "django_geo_db_location" VALUES(56865,NULL,'Luther, OK',24024,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56866,NULL,'Luther, OK 73054',24024,222,NULL,36,32549,0);
INSERT INTO "django_geo_db_location" VALUES(56867,NULL,'Marlow, OK',24025,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56868,NULL,'Marlow, OK 73055',24025,222,NULL,36,32550,0);
INSERT INTO "django_geo_db_location" VALUES(56869,NULL,'Marshall, OK',24026,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56870,NULL,'Marshall, OK 73056',24026,222,NULL,36,32551,0);
INSERT INTO "django_geo_db_location" VALUES(56871,NULL,'Maysville, OK',24027,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56872,NULL,'Maysville, OK 73057',24027,222,NULL,36,32552,0);
INSERT INTO "django_geo_db_location" VALUES(56873,NULL,'Meridian, OK',24028,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56874,NULL,'Meridian, OK 73058',24028,222,NULL,36,32553,0);
INSERT INTO "django_geo_db_location" VALUES(56875,NULL,'Minco, OK',24029,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56876,NULL,'Minco, OK 73059',24029,222,NULL,36,32554,0);
INSERT INTO "django_geo_db_location" VALUES(56877,NULL,'Morrison, OK',24030,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56878,NULL,'Morrison, OK 73061',24030,222,NULL,36,32555,0);
INSERT INTO "django_geo_db_location" VALUES(56879,NULL,'Mountain View, OK',24031,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56880,NULL,'Mountain View, OK 73062',24031,222,NULL,36,32556,0);
INSERT INTO "django_geo_db_location" VALUES(56881,NULL,'Mulhall, OK',24032,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56882,NULL,'Mulhall, OK 73063',24032,222,NULL,36,32557,0);
INSERT INTO "django_geo_db_location" VALUES(56883,NULL,'Mustang, OK',24033,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56884,NULL,'Mustang, OK 73064',24033,222,NULL,36,32558,0);
INSERT INTO "django_geo_db_location" VALUES(56885,NULL,'Newcastle, OK',24034,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56886,NULL,'Newcastle, OK 73065',24034,222,NULL,36,32559,0);
INSERT INTO "django_geo_db_location" VALUES(56887,NULL,'Nicoma Park, OK',24035,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56888,NULL,'Nicoma Park, OK 73066',24035,222,NULL,36,32560,0);
INSERT INTO "django_geo_db_location" VALUES(56889,NULL,'Ninnekah, OK',24036,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56890,NULL,'Ninnekah, OK 73067',24036,222,NULL,36,32561,0);
INSERT INTO "django_geo_db_location" VALUES(56891,NULL,'Noble, OK',24037,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56892,NULL,'Noble, OK 73068',24037,222,NULL,36,32562,0);
INSERT INTO "django_geo_db_location" VALUES(56893,NULL,'Norman, OK 73069',23997,222,NULL,36,32563,0);
INSERT INTO "django_geo_db_location" VALUES(56894,NULL,'Norman, OK 73070',23997,222,NULL,36,32564,0);
INSERT INTO "django_geo_db_location" VALUES(56895,NULL,'Norman, OK 73071',23997,222,NULL,36,32565,0);
INSERT INTO "django_geo_db_location" VALUES(56896,NULL,'Norman, OK 73072',23997,222,NULL,36,32566,0);
INSERT INTO "django_geo_db_location" VALUES(56897,NULL,'Orlando, OK',24038,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56898,NULL,'Orlando, OK 73073',24038,222,NULL,36,32567,0);
INSERT INTO "django_geo_db_location" VALUES(56899,NULL,'Paoli, OK',24039,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56900,NULL,'Paoli, OK 73074',24039,222,NULL,36,32568,0);
INSERT INTO "django_geo_db_location" VALUES(56901,NULL,'Pauls Valley, OK',24040,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56902,NULL,'Pauls Valley, OK 73075',24040,222,NULL,36,32569,0);
INSERT INTO "django_geo_db_location" VALUES(56903,NULL,'Perry, OK',24041,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56904,NULL,'Perry, OK 73077',24041,222,NULL,36,32570,0);
INSERT INTO "django_geo_db_location" VALUES(56905,NULL,'Piedmont, OK',24042,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56906,NULL,'Piedmont, OK 73078',24042,222,NULL,36,32571,0);
INSERT INTO "django_geo_db_location" VALUES(56907,NULL,'Pocasset, OK',24043,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56908,NULL,'Pocasset, OK 73079',24043,222,NULL,36,32572,0);
INSERT INTO "django_geo_db_location" VALUES(56909,NULL,'Purcell, OK',24044,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56910,NULL,'Purcell, OK 73080',24044,222,NULL,36,32573,0);
INSERT INTO "django_geo_db_location" VALUES(56911,NULL,'Rush Springs, OK',24045,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56912,NULL,'Rush Springs, OK 73082',24045,222,NULL,36,32574,0);
INSERT INTO "django_geo_db_location" VALUES(56913,NULL,'Edmond, OK 73083',23982,222,NULL,36,32575,0);
INSERT INTO "django_geo_db_location" VALUES(56914,NULL,'Spencer, OK',24046,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56915,NULL,'Spencer, OK 73084',24046,222,NULL,36,32576,0);
INSERT INTO "django_geo_db_location" VALUES(56916,NULL,'Yukon, OK',24047,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56917,NULL,'Yukon, OK 73085',24047,222,NULL,36,32577,0);
INSERT INTO "django_geo_db_location" VALUES(56918,NULL,'Sulphur, OK',24048,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56919,NULL,'Sulphur, OK 73086',24048,222,NULL,36,32578,0);
INSERT INTO "django_geo_db_location" VALUES(56920,NULL,'Tuttle, OK',24049,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56921,NULL,'Tuttle, OK 73089',24049,222,NULL,36,32579,0);
INSERT INTO "django_geo_db_location" VALUES(56922,NULL,'Union City, OK',24050,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56923,NULL,'Union City, OK 73090',24050,222,NULL,36,32580,0);
INSERT INTO "django_geo_db_location" VALUES(56924,NULL,'Verden, OK',24051,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56925,NULL,'Verden, OK 73092',24051,222,NULL,36,32581,0);
INSERT INTO "django_geo_db_location" VALUES(56926,NULL,'Washington, OK',24052,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56927,NULL,'Washington, OK 73093',24052,222,NULL,36,32582,0);
INSERT INTO "django_geo_db_location" VALUES(56928,NULL,'Washita, OK',24053,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56929,NULL,'Washita, OK 73094',24053,222,NULL,36,32583,0);
INSERT INTO "django_geo_db_location" VALUES(56930,NULL,'Wayne, OK',24054,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56931,NULL,'Wayne, OK 73095',24054,222,NULL,36,32584,0);
INSERT INTO "django_geo_db_location" VALUES(56932,NULL,'Weatherford, OK',24055,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56933,NULL,'Weatherford, OK 73096',24055,222,NULL,36,32585,0);
INSERT INTO "django_geo_db_location" VALUES(56934,NULL,'Wheatland, OK',24056,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56935,NULL,'Wheatland, OK 73097',24056,222,NULL,36,32586,0);
INSERT INTO "django_geo_db_location" VALUES(56936,NULL,'Wynnewood, OK',24057,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56937,NULL,'Wynnewood, OK 73098',24057,222,NULL,36,32587,0);
INSERT INTO "django_geo_db_location" VALUES(56938,NULL,'Yukon, OK 73099',24047,222,NULL,36,32588,0);
INSERT INTO "django_geo_db_location" VALUES(56939,NULL,'Oklahoma City, OK',24058,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(56940,NULL,'Oklahoma City, OK 73101',24058,222,NULL,36,32589,0);
INSERT INTO "django_geo_db_location" VALUES(56941,NULL,'Oklahoma City, OK 73102',24058,222,NULL,36,32590,0);
INSERT INTO "django_geo_db_location" VALUES(56942,NULL,'Oklahoma City, OK 73103',24058,222,NULL,36,32591,0);
INSERT INTO "django_geo_db_location" VALUES(56943,NULL,'Oklahoma City, OK 73104',24058,222,NULL,36,32592,0);
INSERT INTO "django_geo_db_location" VALUES(56944,NULL,'Oklahoma City, OK 73105',24058,222,NULL,36,32593,0);
INSERT INTO "django_geo_db_location" VALUES(56945,NULL,'Oklahoma City, OK 73106',24058,222,NULL,36,32594,0);
INSERT INTO "django_geo_db_location" VALUES(56946,NULL,'Oklahoma City, OK 73107',24058,222,NULL,36,32595,0);
INSERT INTO "django_geo_db_location" VALUES(56947,NULL,'Oklahoma City, OK 73108',24058,222,NULL,36,32596,0);
INSERT INTO "django_geo_db_location" VALUES(56948,NULL,'Oklahoma City, OK 73109',24058,222,NULL,36,32597,0);
INSERT INTO "django_geo_db_location" VALUES(56949,NULL,'Oklahoma City, OK 73110',24058,222,NULL,36,32598,0);
INSERT INTO "django_geo_db_location" VALUES(56950,NULL,'Oklahoma City, OK 73111',24058,222,NULL,36,32599,0);
INSERT INTO "django_geo_db_location" VALUES(56951,NULL,'Oklahoma City, OK 73112',24058,222,NULL,36,32600,0);
INSERT INTO "django_geo_db_location" VALUES(56952,NULL,'Oklahoma City, OK 73113',24058,222,NULL,36,32601,0);
INSERT INTO "django_geo_db_location" VALUES(56953,NULL,'Oklahoma City, OK 73114',24058,222,NULL,36,32602,0);
INSERT INTO "django_geo_db_location" VALUES(56954,NULL,'Oklahoma City, OK 73115',24058,222,NULL,36,32603,0);
INSERT INTO "django_geo_db_location" VALUES(56955,NULL,'Oklahoma City, OK 73116',24058,222,NULL,36,32604,0);
INSERT INTO "django_geo_db_location" VALUES(56956,NULL,'Oklahoma City, OK 73117',24058,222,NULL,36,32605,0);
INSERT INTO "django_geo_db_location" VALUES(56957,NULL,'Oklahoma City, OK 73118',24058,222,NULL,36,32606,0);
INSERT INTO "django_geo_db_location" VALUES(56958,NULL,'Oklahoma City, OK 73119',24058,222,NULL,36,32607,0);
INSERT INTO "django_geo_db_location" VALUES(56959,NULL,'Oklahoma City, OK 73120',24058,222,NULL,36,32608,0);
INSERT INTO "django_geo_db_location" VALUES(56960,NULL,'Oklahoma City, OK 73121',24058,222,NULL,36,32609,0);
INSERT INTO "django_geo_db_location" VALUES(56961,NULL,'Oklahoma City, OK 73122',24058,222,NULL,36,32610,0);
INSERT INTO "django_geo_db_location" VALUES(56962,NULL,'Oklahoma City, OK 73123',24058,222,NULL,36,32611,0);
INSERT INTO "django_geo_db_location" VALUES(56963,NULL,'Oklahoma City, OK 73124',24058,222,NULL,36,32612,0);
INSERT INTO "django_geo_db_location" VALUES(56964,NULL,'Oklahoma City, OK 73125',24058,222,NULL,36,32613,0);
INSERT INTO "django_geo_db_location" VALUES(56965,NULL,'Oklahoma City, OK 73126',24058,222,NULL,36,32614,0);
INSERT INTO "django_geo_db_location" VALUES(56966,NULL,'Oklahoma City, OK 73127',24058,222,NULL,36,32615,0);
INSERT INTO "django_geo_db_location" VALUES(56967,NULL,'Oklahoma City, OK 73128',24058,222,NULL,36,32616,0);
INSERT INTO "django_geo_db_location" VALUES(56968,NULL,'Oklahoma City, OK 73129',24058,222,NULL,36,32617,0);
INSERT INTO "django_geo_db_location" VALUES(56969,NULL,'Oklahoma City, OK 73130',24058,222,NULL,36,32618,0);
INSERT INTO "django_geo_db_location" VALUES(56970,NULL,'Oklahoma City, OK 73131',24058,222,NULL,36,32619,0);
INSERT INTO "django_geo_db_location" VALUES(56971,NULL,'Oklahoma City, OK 73132',24058,222,NULL,36,32620,0);
INSERT INTO "django_geo_db_location" VALUES(56972,NULL,'Oklahoma City, OK 73134',24058,222,NULL,36,32621,0);
INSERT INTO "django_geo_db_location" VALUES(56973,NULL,'Oklahoma City, OK 73135',24058,222,NULL,36,32622,0);
INSERT INTO "django_geo_db_location" VALUES(56974,NULL,'Oklahoma City, OK 73136',24058,222,NULL,36,32623,0);
INSERT INTO "django_geo_db_location" VALUES(56975,NULL,'Oklahoma City, OK 73137',24058,222,NULL,36,32624,0);
INSERT INTO "django_geo_db_location" VALUES(56976,NULL,'Oklahoma City, OK 73139',24058,222,NULL,36,32625,0);
INSERT INTO "django_geo_db_location" VALUES(56977,NULL,'Oklahoma City, OK 73140',24058,222,NULL,36,32626,0);
INSERT INTO "django_geo_db_location" VALUES(56978,NULL,'Oklahoma City, OK 73141',24058,222,NULL,36,32627,0);
INSERT INTO "django_geo_db_location" VALUES(56979,NULL,'Oklahoma City, OK 73142',24058,222,NULL,36,32628,0);
INSERT INTO "django_geo_db_location" VALUES(56980,NULL,'Oklahoma City, OK 73143',24058,222,NULL,36,32629,0);
INSERT INTO "django_geo_db_location" VALUES(56981,NULL,'Oklahoma City, OK 73144',24058,222,NULL,36,32630,0);
INSERT INTO "django_geo_db_location" VALUES(56982,NULL,'Oklahoma City, OK 73145',24058,222,NULL,36,32631,0);
INSERT INTO "django_geo_db_location" VALUES(56983,NULL,'Oklahoma City, OK 73146',24058,222,NULL,36,32632,0);
INSERT INTO "django_geo_db_location" VALUES(56984,NULL,'Oklahoma City, OK 73147',24058,222,NULL,36,32633,0);
INSERT INTO "django_geo_db_location" VALUES(56985,NULL,'Oklahoma City, OK 73148',24058,222,NULL,36,32634,0);
INSERT INTO "django_geo_db_location" VALUES(56986,NULL,'Oklahoma City, OK 73149',24058,222,NULL,36,32635,0);
INSERT INTO "django_geo_db_location" VALUES(56987,NULL,'Oklahoma City, OK 73150',24058,222,NULL,36,32636,0);
INSERT INTO "django_geo_db_location" VALUES(56988,NULL,'Oklahoma City, OK 73151',24058,222,NULL,36,32637,0);
INSERT INTO "django_geo_db_location" VALUES(56989,NULL,'Oklahoma City, OK 73152',24058,222,NULL,36,32638,0);
INSERT INTO "django_geo_db_location" VALUES(56990,NULL,'Oklahoma City, OK 73153',24058,222,NULL,36,32639,0);
INSERT INTO "django_geo_db_location" VALUES(56991,NULL,'Oklahoma City, OK 73154',24058,222,NULL,36,32640,0);
INSERT INTO "django_geo_db_location" VALUES(56992,NULL,'Oklahoma City, OK 73155',24058,222,NULL,36,32641,0);
INSERT INTO "django_geo_db_location" VALUES(56993,NULL,'Oklahoma City, OK 73156',24058,222,NULL,36,32642,0);
INSERT INTO "django_geo_db_location" VALUES(56994,NULL,'Oklahoma City, OK 73157',24058,222,NULL,36,32643,0);
INSERT INTO "django_geo_db_location" VALUES(56995,NULL,'Oklahoma City, OK 73159',24058,222,NULL,36,32644,0);
INSERT INTO "django_geo_db_location" VALUES(56996,NULL,'Oklahoma City, OK 73160',24058,222,NULL,36,32645,0);
INSERT INTO "django_geo_db_location" VALUES(56997,NULL,'Oklahoma City, OK 73162',24058,222,NULL,36,32646,0);
INSERT INTO "django_geo_db_location" VALUES(56998,NULL,'Oklahoma City, OK 73163',24058,222,NULL,36,32647,0);
INSERT INTO "django_geo_db_location" VALUES(56999,NULL,'Oklahoma City, OK 73164',24058,222,NULL,36,32648,0);
INSERT INTO "django_geo_db_location" VALUES(57000,NULL,'Oklahoma City, OK 73165',24058,222,NULL,36,32649,0);
INSERT INTO "django_geo_db_location" VALUES(57001,NULL,'Oklahoma City, OK 73167',24058,222,NULL,36,32650,0);
INSERT INTO "django_geo_db_location" VALUES(57002,NULL,'Oklahoma City, OK 73169',24058,222,NULL,36,32651,0);
INSERT INTO "django_geo_db_location" VALUES(57003,NULL,'Oklahoma City, OK 73170',24058,222,NULL,36,32652,0);
INSERT INTO "django_geo_db_location" VALUES(57004,NULL,'Oklahoma City, OK 73172',24058,222,NULL,36,32653,0);
INSERT INTO "django_geo_db_location" VALUES(57005,NULL,'Oklahoma City, OK 73173',24058,222,NULL,36,32654,0);
INSERT INTO "django_geo_db_location" VALUES(57006,NULL,'Oklahoma City, OK 73177',24058,222,NULL,36,32655,0);
INSERT INTO "django_geo_db_location" VALUES(57007,NULL,'Oklahoma City, OK 73178',24058,222,NULL,36,32656,0);
INSERT INTO "django_geo_db_location" VALUES(57008,NULL,'Oklahoma City, OK 73179',24058,222,NULL,36,32657,0);
INSERT INTO "django_geo_db_location" VALUES(57009,NULL,'Oklahoma City, OK 73180',24058,222,NULL,36,32658,0);
INSERT INTO "django_geo_db_location" VALUES(57010,NULL,'Oklahoma City, OK 73184',24058,222,NULL,36,32659,0);
INSERT INTO "django_geo_db_location" VALUES(57011,NULL,'Oklahoma City, OK 73185',24058,222,NULL,36,32660,0);
INSERT INTO "django_geo_db_location" VALUES(57012,NULL,'Oklahoma City, OK 73189',24058,222,NULL,36,32661,0);
INSERT INTO "django_geo_db_location" VALUES(57013,NULL,'Oklahoma City, OK 73190',24058,222,NULL,36,32662,0);
INSERT INTO "django_geo_db_location" VALUES(57014,NULL,'Oklahoma City, OK 73193',24058,222,NULL,36,32663,0);
INSERT INTO "django_geo_db_location" VALUES(57015,NULL,'Oklahoma City, OK 73194',24058,222,NULL,36,32664,0);
INSERT INTO "django_geo_db_location" VALUES(57016,NULL,'Oklahoma City, OK 73196',24058,222,NULL,36,32665,0);
INSERT INTO "django_geo_db_location" VALUES(57017,NULL,'Oklahoma City, OK 73197',24058,222,NULL,36,32666,0);
INSERT INTO "django_geo_db_location" VALUES(57018,NULL,'Oklahoma City, OK 73198',24058,222,NULL,36,32667,0);
INSERT INTO "django_geo_db_location" VALUES(57019,NULL,'Oklahoma City, OK 73199',24058,222,NULL,36,32668,0);
INSERT INTO "django_geo_db_location" VALUES(57020,NULL,'Austin, TX',24059,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57021,NULL,'Austin, TX 73301',24059,222,NULL,51,32669,0);
INSERT INTO "django_geo_db_location" VALUES(57022,NULL,'Austin, TX 73344',24059,222,NULL,51,32670,0);
INSERT INTO "django_geo_db_location" VALUES(57023,NULL,'Sterling, OK',24060,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57024,NULL,'Sterling, OK 73367',24060,222,NULL,36,32671,0);
INSERT INTO "django_geo_db_location" VALUES(57025,NULL,'Ames, OK',24061,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57026,NULL,'Ames, OK 73371',24061,222,NULL,36,32672,0);
INSERT INTO "django_geo_db_location" VALUES(57027,NULL,'Ardmore, OK',24062,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57028,NULL,'Ardmore, OK 73401',24062,222,NULL,36,32673,0);
INSERT INTO "django_geo_db_location" VALUES(57029,NULL,'Ardmore, OK 73402',24062,222,NULL,36,32674,0);
INSERT INTO "django_geo_db_location" VALUES(57030,NULL,'Ardmore, OK 73403',24062,222,NULL,36,32675,0);
INSERT INTO "django_geo_db_location" VALUES(57031,NULL,'Countyline, OK',24063,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57032,NULL,'Countyline, OK 73425',24063,222,NULL,36,32676,0);
INSERT INTO "django_geo_db_location" VALUES(57033,NULL,'Burneyville, OK',24064,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57034,NULL,'Burneyville, OK 73430',24064,222,NULL,36,32677,0);
INSERT INTO "django_geo_db_location" VALUES(57035,NULL,'Coleman, OK',24065,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57036,NULL,'Coleman, OK 73432',24065,222,NULL,36,32678,0);
INSERT INTO "django_geo_db_location" VALUES(57037,NULL,'Elmore City, OK',24066,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57038,NULL,'Elmore City, OK 73433',24066,222,NULL,36,32679,0);
INSERT INTO "django_geo_db_location" VALUES(57039,NULL,'Foster, OK',24067,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57040,NULL,'Foster, OK 73434',24067,222,NULL,36,32680,0);
INSERT INTO "django_geo_db_location" VALUES(57041,NULL,'Fox, OK',24068,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57042,NULL,'Fox, OK 73435',24068,222,NULL,36,32681,0);
INSERT INTO "django_geo_db_location" VALUES(57043,NULL,'Gene Autry, OK',24069,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57044,NULL,'Gene Autry, OK 73436',24069,222,NULL,36,32682,0);
INSERT INTO "django_geo_db_location" VALUES(57045,NULL,'Graham, OK',24070,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57046,NULL,'Graham, OK 73437',24070,222,NULL,36,32683,0);
INSERT INTO "django_geo_db_location" VALUES(57047,NULL,'Healdton, OK',24071,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57048,NULL,'Healdton, OK 73438',24071,222,NULL,36,32684,0);
INSERT INTO "django_geo_db_location" VALUES(57049,NULL,'Kingston, OK',24072,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57050,NULL,'Kingston, OK 73439',24072,222,NULL,36,32685,0);
INSERT INTO "django_geo_db_location" VALUES(57051,NULL,'Lebanon, OK',24073,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57052,NULL,'Lebanon, OK 73440',24073,222,NULL,36,32686,0);
INSERT INTO "django_geo_db_location" VALUES(57053,NULL,'Leon, OK',24074,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57054,NULL,'Leon, OK 73441',24074,222,NULL,36,32687,0);
INSERT INTO "django_geo_db_location" VALUES(57055,NULL,'Loco, OK',24075,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57056,NULL,'Loco, OK 73442',24075,222,NULL,36,32688,0);
INSERT INTO "django_geo_db_location" VALUES(57057,NULL,'Lone Grove, OK',24076,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57058,NULL,'Lone Grove, OK 73443',24076,222,NULL,36,32689,0);
INSERT INTO "django_geo_db_location" VALUES(57059,NULL,'Hennepin, OK',24077,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57060,NULL,'Hennepin, OK 73444',24077,222,NULL,36,32690,0);
INSERT INTO "django_geo_db_location" VALUES(57061,NULL,'Ravia, OK',24078,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57062,NULL,'Ravia, OK 73445',24078,222,NULL,36,32691,0);
INSERT INTO "django_geo_db_location" VALUES(57063,NULL,'Madill, OK',24079,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57064,NULL,'Madill, OK 73446',24079,222,NULL,36,32692,0);
INSERT INTO "django_geo_db_location" VALUES(57065,NULL,'Mannsville, OK',24080,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57066,NULL,'Mannsville, OK 73447',24080,222,NULL,36,32693,0);
INSERT INTO "django_geo_db_location" VALUES(57067,NULL,'Marietta, OK',24081,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57068,NULL,'Marietta, OK 73448',24081,222,NULL,36,32694,0);
INSERT INTO "django_geo_db_location" VALUES(57069,NULL,'Mead, OK',24082,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57070,NULL,'Mead, OK 73449',24082,222,NULL,36,32695,0);
INSERT INTO "django_geo_db_location" VALUES(57071,NULL,'Milburn, OK',24083,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57072,NULL,'Milburn, OK 73450',24083,222,NULL,36,32696,0);
INSERT INTO "django_geo_db_location" VALUES(57073,NULL,'Overbrook, OK',24084,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57074,NULL,'Overbrook, OK 73453',24084,222,NULL,36,32697,0);
INSERT INTO "django_geo_db_location" VALUES(57075,NULL,'Ravia, OK 73455',24078,222,NULL,36,32698,0);
INSERT INTO "django_geo_db_location" VALUES(57076,NULL,'Ringling, OK',24085,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57077,NULL,'Ringling, OK 73456',24085,222,NULL,36,32699,0);
INSERT INTO "django_geo_db_location" VALUES(57078,NULL,'Springer, OK',24086,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57079,NULL,'Springer, OK 73458',24086,222,NULL,36,32700,0);
INSERT INTO "django_geo_db_location" VALUES(57080,NULL,'Thackerville, OK',24087,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57081,NULL,'Thackerville, OK 73459',24087,222,NULL,36,32701,0);
INSERT INTO "django_geo_db_location" VALUES(57082,NULL,'Tishomingo, OK',24088,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57083,NULL,'Tishomingo, OK 73460',24088,222,NULL,36,32702,0);
INSERT INTO "django_geo_db_location" VALUES(57084,NULL,'Wapanucka, OK',24089,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57085,NULL,'Wapanucka, OK 73461',24089,222,NULL,36,32703,0);
INSERT INTO "django_geo_db_location" VALUES(57086,NULL,'Wilson, OK',24090,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57087,NULL,'Wilson, OK 73463',24090,222,NULL,36,32704,0);
INSERT INTO "django_geo_db_location" VALUES(57088,NULL,'Pernell, OK',24091,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57089,NULL,'Pernell, OK 73476',24091,222,NULL,36,32705,0);
INSERT INTO "django_geo_db_location" VALUES(57090,NULL,'Ratliff City, OK',24092,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57091,NULL,'Ratliff City, OK 73481',24092,222,NULL,36,32706,0);
INSERT INTO "django_geo_db_location" VALUES(57092,NULL,'Tatums, OK',24093,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57093,NULL,'Tatums, OK 73487',24093,222,NULL,36,32707,0);
INSERT INTO "django_geo_db_location" VALUES(57094,NULL,'Tussy, OK',24094,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57095,NULL,'Tussy, OK 73488',24094,222,NULL,36,32708,0);
INSERT INTO "django_geo_db_location" VALUES(57096,NULL,'Velma, OK',24095,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57097,NULL,'Velma, OK 73491',24095,222,NULL,36,32709,0);
INSERT INTO "django_geo_db_location" VALUES(57098,NULL,'Lawton, OK',24096,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57099,NULL,'Lawton, OK 73501',24096,222,NULL,36,32710,0);
INSERT INTO "django_geo_db_location" VALUES(57100,NULL,'Lawton, OK 73502',24096,222,NULL,36,32711,0);
INSERT INTO "django_geo_db_location" VALUES(57101,NULL,'Fort Sill, OK',24097,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57102,NULL,'Fort Sill, OK 73503',24097,222,NULL,36,32712,0);
INSERT INTO "django_geo_db_location" VALUES(57103,NULL,'Lawton, OK 73505',24096,222,NULL,36,32713,0);
INSERT INTO "django_geo_db_location" VALUES(57104,NULL,'Lawton, OK 73506',24096,222,NULL,36,32714,0);
INSERT INTO "django_geo_db_location" VALUES(57105,NULL,'Lawton, OK 73507',24096,222,NULL,36,32715,0);
INSERT INTO "django_geo_db_location" VALUES(57106,NULL,'Addington, OK',24098,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57107,NULL,'Addington, OK 73520',24098,222,NULL,36,32716,0);
INSERT INTO "django_geo_db_location" VALUES(57108,NULL,'Altus, OK',24099,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57109,NULL,'Altus, OK 73521',24099,222,NULL,36,32717,0);
INSERT INTO "django_geo_db_location" VALUES(57110,NULL,'Altus, OK 73522',24099,222,NULL,36,32718,0);
INSERT INTO "django_geo_db_location" VALUES(57111,NULL,'Altus AFB, OK',24100,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57112,NULL,'Altus AFB, OK 73523',24100,222,NULL,36,32719,0);
INSERT INTO "django_geo_db_location" VALUES(57113,NULL,'Blair, OK',24101,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57114,NULL,'Blair, OK 73526',24101,222,NULL,36,32720,0);
INSERT INTO "django_geo_db_location" VALUES(57115,NULL,'Cache, OK',24102,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57116,NULL,'Cache, OK 73527',24102,222,NULL,36,32721,0);
INSERT INTO "django_geo_db_location" VALUES(57117,NULL,'Chattanooga, OK',24103,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57118,NULL,'Chattanooga, OK 73528',24103,222,NULL,36,32722,0);
INSERT INTO "django_geo_db_location" VALUES(57119,NULL,'Comanche, OK',24104,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57120,NULL,'Comanche, OK 73529',24104,222,NULL,36,32723,0);
INSERT INTO "django_geo_db_location" VALUES(57121,NULL,'Davidson, OK',24105,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57122,NULL,'Davidson, OK 73530',24105,222,NULL,36,32724,0);
INSERT INTO "django_geo_db_location" VALUES(57123,NULL,'Devol, OK',24106,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57124,NULL,'Devol, OK 73531',24106,222,NULL,36,32725,0);
INSERT INTO "django_geo_db_location" VALUES(57125,NULL,'Duke, OK',24107,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57126,NULL,'Duke, OK 73532',24107,222,NULL,36,32726,0);
INSERT INTO "django_geo_db_location" VALUES(57127,NULL,'Duncan, OK',24108,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57128,NULL,'Duncan, OK 73533',24108,222,NULL,36,32727,0);
INSERT INTO "django_geo_db_location" VALUES(57129,NULL,'Duncan, OK 73534',24108,222,NULL,36,32728,0);
INSERT INTO "django_geo_db_location" VALUES(57130,NULL,'Duncan, OK 73536',24108,222,NULL,36,32729,0);
INSERT INTO "django_geo_db_location" VALUES(57131,NULL,'Eldorado, OK',24109,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57132,NULL,'Eldorado, OK 73537',24109,222,NULL,36,32730,0);
INSERT INTO "django_geo_db_location" VALUES(57133,NULL,'Elgin, OK',24110,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57134,NULL,'Elgin, OK 73538',24110,222,NULL,36,32731,0);
INSERT INTO "django_geo_db_location" VALUES(57135,NULL,'Elmer, OK',24111,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57136,NULL,'Elmer, OK 73539',24111,222,NULL,36,32732,0);
INSERT INTO "django_geo_db_location" VALUES(57137,NULL,'Faxon, OK',24112,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57138,NULL,'Faxon, OK 73540',24112,222,NULL,36,32733,0);
INSERT INTO "django_geo_db_location" VALUES(57139,NULL,'Fletcher, OK',24113,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57140,NULL,'Fletcher, OK 73541',24113,222,NULL,36,32734,0);
INSERT INTO "django_geo_db_location" VALUES(57141,NULL,'Frederick, OK',24114,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57142,NULL,'Frederick, OK 73542',24114,222,NULL,36,32735,0);
INSERT INTO "django_geo_db_location" VALUES(57143,NULL,'Geronimo, OK',24115,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57144,NULL,'Geronimo, OK 73543',24115,222,NULL,36,32736,0);
INSERT INTO "django_geo_db_location" VALUES(57145,NULL,'Gould, OK',24116,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57146,NULL,'Gould, OK 73544',24116,222,NULL,36,32737,0);
INSERT INTO "django_geo_db_location" VALUES(57147,NULL,'Grandfield, OK',24117,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57148,NULL,'Grandfield, OK 73546',24117,222,NULL,36,32738,0);
INSERT INTO "django_geo_db_location" VALUES(57149,NULL,'Granite, OK',24118,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57150,NULL,'Granite, OK 73547',24118,222,NULL,36,32739,0);
INSERT INTO "django_geo_db_location" VALUES(57151,NULL,'Hastings, OK',24119,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57152,NULL,'Hastings, OK 73548',24119,222,NULL,36,32740,0);
INSERT INTO "django_geo_db_location" VALUES(57153,NULL,'Headrick, OK',24120,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57154,NULL,'Headrick, OK 73549',24120,222,NULL,36,32741,0);
INSERT INTO "django_geo_db_location" VALUES(57155,NULL,'Hollis, OK',24121,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57156,NULL,'Hollis, OK 73550',24121,222,NULL,36,32742,0);
INSERT INTO "django_geo_db_location" VALUES(57157,NULL,'Hollister, OK',24122,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57158,NULL,'Hollister, OK 73551',24122,222,NULL,36,32743,0);
INSERT INTO "django_geo_db_location" VALUES(57159,NULL,'Indiahoma, OK',24123,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57160,NULL,'Indiahoma, OK 73552',24123,222,NULL,36,32744,0);
INSERT INTO "django_geo_db_location" VALUES(57161,NULL,'Loveland, OK',24124,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57162,NULL,'Loveland, OK 73553',24124,222,NULL,36,32745,0);
INSERT INTO "django_geo_db_location" VALUES(57163,NULL,'Mangum, OK',24125,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57164,NULL,'Mangum, OK 73554',24125,222,NULL,36,32746,0);
INSERT INTO "django_geo_db_location" VALUES(57165,NULL,'Manitou, OK',24126,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57166,NULL,'Manitou, OK 73555',24126,222,NULL,36,32747,0);
INSERT INTO "django_geo_db_location" VALUES(57167,NULL,'Martha, OK',24127,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57168,NULL,'Martha, OK 73556',24127,222,NULL,36,32748,0);
INSERT INTO "django_geo_db_location" VALUES(57169,NULL,'Medicine Park, OK',24128,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57170,NULL,'Medicine Park, OK 73557',24128,222,NULL,36,32749,0);
INSERT INTO "django_geo_db_location" VALUES(57171,NULL,'Meers, OK',24129,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57172,NULL,'Meers, OK 73558',24129,222,NULL,36,32750,0);
INSERT INTO "django_geo_db_location" VALUES(57173,NULL,'Mountain Park, OK',24130,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57174,NULL,'Mountain Park, OK 73559',24130,222,NULL,36,32751,0);
INSERT INTO "django_geo_db_location" VALUES(57175,NULL,'Olustee, OK',24131,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57176,NULL,'Olustee, OK 73560',24131,222,NULL,36,32752,0);
INSERT INTO "django_geo_db_location" VALUES(57177,NULL,'Oscar, OK',24132,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57178,NULL,'Oscar, OK 73561',24132,222,NULL,36,32753,0);
INSERT INTO "django_geo_db_location" VALUES(57179,NULL,'Randlett, OK',24133,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57180,NULL,'Randlett, OK 73562',24133,222,NULL,36,32754,0);
INSERT INTO "django_geo_db_location" VALUES(57181,NULL,'Roosevelt, OK',24134,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57182,NULL,'Roosevelt, OK 73564',24134,222,NULL,36,32755,0);
INSERT INTO "django_geo_db_location" VALUES(57183,NULL,'Ryan, OK',24135,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57184,NULL,'Ryan, OK 73565',24135,222,NULL,36,32756,0);
INSERT INTO "django_geo_db_location" VALUES(57185,NULL,'Snyder, OK',24136,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57186,NULL,'Snyder, OK 73566',24136,222,NULL,36,32757,0);
INSERT INTO "django_geo_db_location" VALUES(57187,NULL,'Sterling, OK 73567',24060,222,NULL,36,32758,0);
INSERT INTO "django_geo_db_location" VALUES(57188,NULL,'Temple, OK',24137,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57189,NULL,'Temple, OK 73568',24137,222,NULL,36,32759,0);
INSERT INTO "django_geo_db_location" VALUES(57190,NULL,'Terral, OK',24138,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57191,NULL,'Terral, OK 73569',24138,222,NULL,36,32760,0);
INSERT INTO "django_geo_db_location" VALUES(57192,NULL,'Tipton, OK',24139,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57193,NULL,'Tipton, OK 73570',24139,222,NULL,36,32761,0);
INSERT INTO "django_geo_db_location" VALUES(57194,NULL,'Vinson, OK',24140,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57195,NULL,'Vinson, OK 73571',24140,222,NULL,36,32762,0);
INSERT INTO "django_geo_db_location" VALUES(57196,NULL,'Walters, OK',24141,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57197,NULL,'Walters, OK 73572',24141,222,NULL,36,32763,0);
INSERT INTO "django_geo_db_location" VALUES(57198,NULL,'Waurika, OK',24142,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57199,NULL,'Waurika, OK 73573',24142,222,NULL,36,32764,0);
INSERT INTO "django_geo_db_location" VALUES(57200,NULL,'Duncan, OK 73575',24108,222,NULL,36,32765,0);
INSERT INTO "django_geo_db_location" VALUES(57201,NULL,'Clinton, OK',24143,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57202,NULL,'Clinton, OK 73601',24143,222,NULL,36,32766,0);
INSERT INTO "django_geo_db_location" VALUES(57203,NULL,'Arapaho, OK',24144,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57204,NULL,'Arapaho, OK 73620',24144,222,NULL,36,32767,0);
INSERT INTO "django_geo_db_location" VALUES(57205,NULL,'Bessie, OK',24145,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57206,NULL,'Bessie, OK 73622',24145,222,NULL,36,32768,0);
INSERT INTO "django_geo_db_location" VALUES(57207,NULL,'Burns Flat, OK',24146,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57208,NULL,'Burns Flat, OK 73624',24146,222,NULL,36,32769,0);
INSERT INTO "django_geo_db_location" VALUES(57209,NULL,'Butler, OK',24147,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57210,NULL,'Butler, OK 73625',24147,222,NULL,36,32770,0);
INSERT INTO "django_geo_db_location" VALUES(57211,NULL,'Canute, OK',24148,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57212,NULL,'Canute, OK 73626',24148,222,NULL,36,32771,0);
INSERT INTO "django_geo_db_location" VALUES(57213,NULL,'Carter, OK',24149,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57214,NULL,'Carter, OK 73627',24149,222,NULL,36,32772,0);
INSERT INTO "django_geo_db_location" VALUES(57215,NULL,'Cheyenne, OK',24150,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57216,NULL,'Cheyenne, OK 73628',24150,222,NULL,36,32773,0);
INSERT INTO "django_geo_db_location" VALUES(57217,NULL,'Cordell, OK',24151,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57218,NULL,'Cordell, OK 73632',24151,222,NULL,36,32774,0);
INSERT INTO "django_geo_db_location" VALUES(57219,NULL,'Crawford, OK',24152,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57220,NULL,'Crawford, OK 73638',24152,222,NULL,36,32775,0);
INSERT INTO "django_geo_db_location" VALUES(57221,NULL,'Custer City, OK',24153,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57222,NULL,'Custer City, OK 73639',24153,222,NULL,36,32776,0);
INSERT INTO "django_geo_db_location" VALUES(57223,NULL,'Dill City, OK',24154,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57224,NULL,'Dill City, OK 73641',24154,222,NULL,36,32777,0);
INSERT INTO "django_geo_db_location" VALUES(57225,NULL,'Durham, OK',24155,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57226,NULL,'Durham, OK 73642',24155,222,NULL,36,32778,0);
INSERT INTO "django_geo_db_location" VALUES(57227,NULL,'Elk City, OK',24156,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57228,NULL,'Elk City, OK 73644',24156,222,NULL,36,32779,0);
INSERT INTO "django_geo_db_location" VALUES(57229,NULL,'Erick, OK',24157,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57230,NULL,'Erick, OK 73645',24157,222,NULL,36,32780,0);
INSERT INTO "django_geo_db_location" VALUES(57231,NULL,'Fay, OK',24158,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57232,NULL,'Fay, OK 73646',24158,222,NULL,36,32781,0);
INSERT INTO "django_geo_db_location" VALUES(57233,NULL,'Foss, OK',24159,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57234,NULL,'Foss, OK 73647',24159,222,NULL,36,32782,0);
INSERT INTO "django_geo_db_location" VALUES(57235,NULL,'Elk City, OK 73648',24156,222,NULL,36,32783,0);
INSERT INTO "django_geo_db_location" VALUES(57236,NULL,'Hammon, OK',24160,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57237,NULL,'Hammon, OK 73650',24160,222,NULL,36,32784,0);
INSERT INTO "django_geo_db_location" VALUES(57238,NULL,'Hobart, OK',24161,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57239,NULL,'Hobart, OK 73651',24161,222,NULL,36,32785,0);
INSERT INTO "django_geo_db_location" VALUES(57240,NULL,'Leedey, OK',24162,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57241,NULL,'Leedey, OK 73654',24162,222,NULL,36,32786,0);
INSERT INTO "django_geo_db_location" VALUES(57242,NULL,'Lone Wolf, OK',24163,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57243,NULL,'Lone Wolf, OK 73655',24163,222,NULL,36,32787,0);
INSERT INTO "django_geo_db_location" VALUES(57244,NULL,'Mayfield, OK',24164,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57245,NULL,'Mayfield, OK 73656',24164,222,NULL,36,32788,0);
INSERT INTO "django_geo_db_location" VALUES(57246,NULL,'Oakwood, OK',24165,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57247,NULL,'Oakwood, OK 73658',24165,222,NULL,36,32789,0);
INSERT INTO "django_geo_db_location" VALUES(57248,NULL,'Putnam, OK',24166,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57249,NULL,'Putnam, OK 73659',24166,222,NULL,36,32790,0);
INSERT INTO "django_geo_db_location" VALUES(57250,NULL,'Reydon, OK',24167,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57251,NULL,'Reydon, OK 73660',24167,222,NULL,36,32791,0);
INSERT INTO "django_geo_db_location" VALUES(57252,NULL,'Rocky, OK',24168,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57253,NULL,'Rocky, OK 73661',24168,222,NULL,36,32792,0);
INSERT INTO "django_geo_db_location" VALUES(57254,NULL,'Sayre, OK',24169,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57255,NULL,'Sayre, OK 73662',24169,222,NULL,36,32793,0);
INSERT INTO "django_geo_db_location" VALUES(57256,NULL,'Seiling, OK',24170,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57257,NULL,'Seiling, OK 73663',24170,222,NULL,36,32794,0);
INSERT INTO "django_geo_db_location" VALUES(57258,NULL,'Sentinel, OK',24171,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57259,NULL,'Sentinel, OK 73664',24171,222,NULL,36,32795,0);
INSERT INTO "django_geo_db_location" VALUES(57260,NULL,'Sweetwater, OK',24172,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57261,NULL,'Sweetwater, OK 73666',24172,222,NULL,36,32796,0);
INSERT INTO "django_geo_db_location" VALUES(57262,NULL,'Taloga, OK',24173,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57263,NULL,'Taloga, OK 73667',24173,222,NULL,36,32797,0);
INSERT INTO "django_geo_db_location" VALUES(57264,NULL,'Texola, OK',24174,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57265,NULL,'Texola, OK 73668',24174,222,NULL,36,32798,0);
INSERT INTO "django_geo_db_location" VALUES(57266,NULL,'Thomas, OK',24175,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57267,NULL,'Thomas, OK 73669',24175,222,NULL,36,32799,0);
INSERT INTO "django_geo_db_location" VALUES(57268,NULL,'Willow, OK',24176,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57269,NULL,'Willow, OK 73673',24176,222,NULL,36,32800,0);
INSERT INTO "django_geo_db_location" VALUES(57270,NULL,'Enid, OK',24177,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57271,NULL,'Enid, OK 73701',24177,222,NULL,36,32801,0);
INSERT INTO "django_geo_db_location" VALUES(57272,NULL,'Enid, OK 73702',24177,222,NULL,36,32802,0);
INSERT INTO "django_geo_db_location" VALUES(57273,NULL,'Enid, OK 73703',24177,222,NULL,36,32803,0);
INSERT INTO "django_geo_db_location" VALUES(57274,NULL,'Enid, OK 73705',24177,222,NULL,36,32804,0);
INSERT INTO "django_geo_db_location" VALUES(57275,NULL,'Enid, OK 73706',24177,222,NULL,36,32805,0);
INSERT INTO "django_geo_db_location" VALUES(57276,NULL,'Aline, OK',24178,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57277,NULL,'Aline, OK 73716',24178,222,NULL,36,32806,0);
INSERT INTO "django_geo_db_location" VALUES(57278,NULL,'Alva, OK',24179,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57279,NULL,'Alva, OK 73717',24179,222,NULL,36,32807,0);
INSERT INTO "django_geo_db_location" VALUES(57280,NULL,'Ames, OK 73718',24061,222,NULL,36,32808,0);
INSERT INTO "django_geo_db_location" VALUES(57281,NULL,'Amorita, OK',24180,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57282,NULL,'Amorita, OK 73719',24180,222,NULL,36,32809,0);
INSERT INTO "django_geo_db_location" VALUES(57283,NULL,'Bison, OK',24181,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57284,NULL,'Bison, OK 73720',24181,222,NULL,36,32810,0);
INSERT INTO "django_geo_db_location" VALUES(57285,NULL,'Burlington, OK',24182,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57286,NULL,'Burlington, OK 73722',24182,222,NULL,36,32811,0);
INSERT INTO "django_geo_db_location" VALUES(57287,NULL,'Canton, OK',24183,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57288,NULL,'Canton, OK 73724',24183,222,NULL,36,32812,0);
INSERT INTO "django_geo_db_location" VALUES(57289,NULL,'Carmen, OK',24184,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57290,NULL,'Carmen, OK 73726',24184,222,NULL,36,32813,0);
INSERT INTO "django_geo_db_location" VALUES(57291,NULL,'Carrier, OK',24185,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57292,NULL,'Carrier, OK 73727',24185,222,NULL,36,32814,0);
INSERT INTO "django_geo_db_location" VALUES(57293,NULL,'Cherokee, OK',24186,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57294,NULL,'Cherokee, OK 73728',24186,222,NULL,36,32815,0);
INSERT INTO "django_geo_db_location" VALUES(57295,NULL,'Cleo Springs, OK',24187,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57296,NULL,'Cleo Springs, OK 73729',24187,222,NULL,36,32816,0);
INSERT INTO "django_geo_db_location" VALUES(57297,NULL,'Covington, OK',24188,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57298,NULL,'Covington, OK 73730',24188,222,NULL,36,32817,0);
INSERT INTO "django_geo_db_location" VALUES(57299,NULL,'Dacoma, OK',24189,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57300,NULL,'Dacoma, OK 73731',24189,222,NULL,36,32818,0);
INSERT INTO "django_geo_db_location" VALUES(57301,NULL,'Douglas, OK',24190,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57302,NULL,'Douglas, OK 73733',24190,222,NULL,36,32819,0);
INSERT INTO "django_geo_db_location" VALUES(57303,NULL,'Dover, OK',24191,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57304,NULL,'Dover, OK 73734',24191,222,NULL,36,32820,0);
INSERT INTO "django_geo_db_location" VALUES(57305,NULL,'Drummond, OK',24192,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57306,NULL,'Drummond, OK 73735',24192,222,NULL,36,32821,0);
INSERT INTO "django_geo_db_location" VALUES(57307,NULL,'Fairmont, OK',24193,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57308,NULL,'Fairmont, OK 73736',24193,222,NULL,36,32822,0);
INSERT INTO "django_geo_db_location" VALUES(57309,NULL,'Fairview, OK',24194,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57310,NULL,'Fairview, OK 73737',24194,222,NULL,36,32823,0);
INSERT INTO "django_geo_db_location" VALUES(57311,NULL,'Garber, OK',24195,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57312,NULL,'Garber, OK 73738',24195,222,NULL,36,32824,0);
INSERT INTO "django_geo_db_location" VALUES(57313,NULL,'Goltry, OK',24196,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57314,NULL,'Goltry, OK 73739',24196,222,NULL,36,32825,0);
INSERT INTO "django_geo_db_location" VALUES(57315,NULL,'Helena, OK',24197,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57316,NULL,'Helena, OK 73741',24197,222,NULL,36,32826,0);
INSERT INTO "django_geo_db_location" VALUES(57317,NULL,'Hennessey, OK',24198,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57318,NULL,'Hennessey, OK 73742',24198,222,NULL,36,32827,0);
INSERT INTO "django_geo_db_location" VALUES(57319,NULL,'Hillsdale, OK',24199,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57320,NULL,'Hillsdale, OK 73743',24199,222,NULL,36,32828,0);
INSERT INTO "django_geo_db_location" VALUES(57321,NULL,'Hitchcock, OK',24200,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57322,NULL,'Hitchcock, OK 73744',24200,222,NULL,36,32829,0);
INSERT INTO "django_geo_db_location" VALUES(57323,NULL,'Hopeton, OK',24201,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57324,NULL,'Hopeton, OK 73746',24201,222,NULL,36,32830,0);
INSERT INTO "django_geo_db_location" VALUES(57325,NULL,'Isabella, OK',24202,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57326,NULL,'Isabella, OK 73747',24202,222,NULL,36,32831,0);
INSERT INTO "django_geo_db_location" VALUES(57327,NULL,'Jet, OK',24203,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57328,NULL,'Jet, OK 73749',24203,222,NULL,36,32832,0);
INSERT INTO "django_geo_db_location" VALUES(57329,NULL,'Kingfisher, OK',24204,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57330,NULL,'Kingfisher, OK 73750',24204,222,NULL,36,32833,0);
INSERT INTO "django_geo_db_location" VALUES(57331,NULL,'Kremlin, OK',24205,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57332,NULL,'Kremlin, OK 73753',24205,222,NULL,36,32834,0);
INSERT INTO "django_geo_db_location" VALUES(57333,NULL,'Lahoma, OK',24206,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57334,NULL,'Lahoma, OK 73754',24206,222,NULL,36,32835,0);
INSERT INTO "django_geo_db_location" VALUES(57335,NULL,'Longdale, OK',24207,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57336,NULL,'Longdale, OK 73755',24207,222,NULL,36,32836,0);
INSERT INTO "django_geo_db_location" VALUES(57337,NULL,'Loyal, OK',24208,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57338,NULL,'Loyal, OK 73756',24208,222,NULL,36,32837,0);
INSERT INTO "django_geo_db_location" VALUES(57339,NULL,'Lucien, OK',24209,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57340,NULL,'Lucien, OK 73757',24209,222,NULL,36,32838,0);
INSERT INTO "django_geo_db_location" VALUES(57341,NULL,'Manchester, OK',24210,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57342,NULL,'Manchester, OK 73758',24210,222,NULL,36,32839,0);
INSERT INTO "django_geo_db_location" VALUES(57343,NULL,'Medford, OK',24211,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57344,NULL,'Medford, OK 73759',24211,222,NULL,36,32840,0);
INSERT INTO "django_geo_db_location" VALUES(57345,NULL,'Meno, OK',24212,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57346,NULL,'Meno, OK 73760',24212,222,NULL,36,32841,0);
INSERT INTO "django_geo_db_location" VALUES(57347,NULL,'Nash, OK',24213,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57348,NULL,'Nash, OK 73761',24213,222,NULL,36,32842,0);
INSERT INTO "django_geo_db_location" VALUES(57349,NULL,'Okarche, OK',24214,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57350,NULL,'Okarche, OK 73762',24214,222,NULL,36,32843,0);
INSERT INTO "django_geo_db_location" VALUES(57351,NULL,'Okeene, OK',24215,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57352,NULL,'Okeene, OK 73763',24215,222,NULL,36,32844,0);
INSERT INTO "django_geo_db_location" VALUES(57353,NULL,'Omega, OK',24216,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57354,NULL,'Omega, OK 73764',24216,222,NULL,36,32845,0);
INSERT INTO "django_geo_db_location" VALUES(57355,NULL,'Pond Creek, OK',24217,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57356,NULL,'Pond Creek, OK 73766',24217,222,NULL,36,32846,0);
INSERT INTO "django_geo_db_location" VALUES(57357,NULL,'Ringwood, OK',24218,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57358,NULL,'Ringwood, OK 73768',24218,222,NULL,36,32847,0);
INSERT INTO "django_geo_db_location" VALUES(57359,NULL,'Southard, OK',24219,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57360,NULL,'Southard, OK 73770',24219,222,NULL,36,32848,0);
INSERT INTO "django_geo_db_location" VALUES(57361,NULL,'Wakita, OK',24220,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57362,NULL,'Wakita, OK 73771',24220,222,NULL,36,32849,0);
INSERT INTO "django_geo_db_location" VALUES(57363,NULL,'Watonga, OK',24221,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57364,NULL,'Watonga, OK 73772',24221,222,NULL,36,32850,0);
INSERT INTO "django_geo_db_location" VALUES(57365,NULL,'Waukomis, OK',24222,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57366,NULL,'Waukomis, OK 73773',24222,222,NULL,36,32851,0);
INSERT INTO "django_geo_db_location" VALUES(57367,NULL,'Woodward, OK',24223,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57368,NULL,'Woodward, OK 73801',24223,222,NULL,36,32852,0);
INSERT INTO "django_geo_db_location" VALUES(57369,NULL,'Woodward, OK 73802',24223,222,NULL,36,32853,0);
INSERT INTO "django_geo_db_location" VALUES(57370,NULL,'Arnett, OK',24224,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57371,NULL,'Arnett, OK 73832',24224,222,NULL,36,32854,0);
INSERT INTO "django_geo_db_location" VALUES(57372,NULL,'Buffalo, OK',24225,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57373,NULL,'Buffalo, OK 73834',24225,222,NULL,36,32855,0);
INSERT INTO "django_geo_db_location" VALUES(57374,NULL,'Camargo, OK',24226,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57375,NULL,'Camargo, OK 73835',24226,222,NULL,36,32856,0);
INSERT INTO "django_geo_db_location" VALUES(57376,NULL,'Chester, OK',24227,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57377,NULL,'Chester, OK 73838',24227,222,NULL,36,32857,0);
INSERT INTO "django_geo_db_location" VALUES(57378,NULL,'Fargo, OK',24228,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57379,NULL,'Fargo, OK 73840',24228,222,NULL,36,32858,0);
INSERT INTO "django_geo_db_location" VALUES(57380,NULL,'Fort Supply, OK',24229,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57381,NULL,'Fort Supply, OK 73841',24229,222,NULL,36,32859,0);
INSERT INTO "django_geo_db_location" VALUES(57382,NULL,'Freedom, OK',24230,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57383,NULL,'Freedom, OK 73842',24230,222,NULL,36,32860,0);
INSERT INTO "django_geo_db_location" VALUES(57384,NULL,'Gage, OK',24231,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57385,NULL,'Gage, OK 73843',24231,222,NULL,36,32861,0);
INSERT INTO "django_geo_db_location" VALUES(57386,NULL,'Gate, OK',24232,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57387,NULL,'Gate, OK 73844',24232,222,NULL,36,32862,0);
INSERT INTO "django_geo_db_location" VALUES(57388,NULL,'Knowles, OK',24233,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57389,NULL,'Knowles, OK 73847',24233,222,NULL,36,32863,0);
INSERT INTO "django_geo_db_location" VALUES(57390,NULL,'Laverne, OK',24234,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57391,NULL,'Laverne, OK 73848',24234,222,NULL,36,32864,0);
INSERT INTO "django_geo_db_location" VALUES(57392,NULL,'May, OK',24235,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57393,NULL,'May, OK 73851',24235,222,NULL,36,32865,0);
INSERT INTO "django_geo_db_location" VALUES(57394,NULL,'Mooreland, OK',24236,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57395,NULL,'Mooreland, OK 73852',24236,222,NULL,36,32866,0);
INSERT INTO "django_geo_db_location" VALUES(57396,NULL,'Mutual, OK',24237,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57397,NULL,'Mutual, OK 73853',24237,222,NULL,36,32867,0);
INSERT INTO "django_geo_db_location" VALUES(57398,NULL,'Rosston, OK',24238,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57399,NULL,'Rosston, OK 73855',24238,222,NULL,36,32868,0);
INSERT INTO "django_geo_db_location" VALUES(57400,NULL,'Sharon, OK',24239,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57401,NULL,'Sharon, OK 73857',24239,222,NULL,36,32869,0);
INSERT INTO "django_geo_db_location" VALUES(57402,NULL,'Shattuck, OK',24240,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57403,NULL,'Shattuck, OK 73858',24240,222,NULL,36,32870,0);
INSERT INTO "django_geo_db_location" VALUES(57404,NULL,'Vici, OK',24241,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57405,NULL,'Vici, OK 73859',24241,222,NULL,36,32871,0);
INSERT INTO "django_geo_db_location" VALUES(57406,NULL,'Waynoka, OK',24242,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57407,NULL,'Waynoka, OK 73860',24242,222,NULL,36,32872,0);
INSERT INTO "django_geo_db_location" VALUES(57408,NULL,'Adams, OK',24243,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57409,NULL,'Adams, OK 73901',24243,222,NULL,36,32873,0);
INSERT INTO "django_geo_db_location" VALUES(57410,NULL,'Balko, OK',24244,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57411,NULL,'Balko, OK 73931',24244,222,NULL,36,32874,0);
INSERT INTO "django_geo_db_location" VALUES(57412,NULL,'Beaver, OK',24245,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57413,NULL,'Beaver, OK 73932',24245,222,NULL,36,32875,0);
INSERT INTO "django_geo_db_location" VALUES(57414,NULL,'Boise City, OK',24246,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57415,NULL,'Boise City, OK 73933',24246,222,NULL,36,32876,0);
INSERT INTO "django_geo_db_location" VALUES(57416,NULL,'Felt, OK',24247,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57417,NULL,'Felt, OK 73937',24247,222,NULL,36,32877,0);
INSERT INTO "django_geo_db_location" VALUES(57418,NULL,'Forgan, OK',24248,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57419,NULL,'Forgan, OK 73938',24248,222,NULL,36,32878,0);
INSERT INTO "django_geo_db_location" VALUES(57420,NULL,'Goodwell, OK',24249,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57421,NULL,'Goodwell, OK 73939',24249,222,NULL,36,32879,0);
INSERT INTO "django_geo_db_location" VALUES(57422,NULL,'Guymon, OK',24250,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57423,NULL,'Guymon, OK 73942',24250,222,NULL,36,32880,0);
INSERT INTO "django_geo_db_location" VALUES(57424,NULL,'Hardesty, OK',24251,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57425,NULL,'Hardesty, OK 73944',24251,222,NULL,36,32881,0);
INSERT INTO "django_geo_db_location" VALUES(57426,NULL,'Hooker, OK',24252,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57427,NULL,'Hooker, OK 73945',24252,222,NULL,36,32882,0);
INSERT INTO "django_geo_db_location" VALUES(57428,NULL,'Kenton, OK',24253,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57429,NULL,'Kenton, OK 73946',24253,222,NULL,36,32883,0);
INSERT INTO "django_geo_db_location" VALUES(57430,NULL,'Keyes, OK',24254,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57431,NULL,'Keyes, OK 73947',24254,222,NULL,36,32884,0);
INSERT INTO "django_geo_db_location" VALUES(57432,NULL,'Texhoma, OK',24255,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57433,NULL,'Texhoma, OK 73949',24255,222,NULL,36,32885,0);
INSERT INTO "django_geo_db_location" VALUES(57434,NULL,'Turpin, OK',24256,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57435,NULL,'Turpin, OK 73950',24256,222,NULL,36,32886,0);
INSERT INTO "django_geo_db_location" VALUES(57436,NULL,'Tyrone, OK',24257,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57437,NULL,'Tyrone, OK 73951',24257,222,NULL,36,32887,0);
INSERT INTO "django_geo_db_location" VALUES(57438,NULL,'Avant, OK',24258,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57439,NULL,'Avant, OK 74001',24258,222,NULL,36,32888,0);
INSERT INTO "django_geo_db_location" VALUES(57440,NULL,'Barnsdall, OK',24259,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57441,NULL,'Barnsdall, OK 74002',24259,222,NULL,36,32889,0);
INSERT INTO "django_geo_db_location" VALUES(57442,NULL,'Bartlesville, OK',24260,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57443,NULL,'Bartlesville, OK 74003',24260,222,NULL,36,32890,0);
INSERT INTO "django_geo_db_location" VALUES(57444,NULL,'Bartlesville, OK 74004',24260,222,NULL,36,32891,0);
INSERT INTO "django_geo_db_location" VALUES(57445,NULL,'Bartlesville, OK 74005',24260,222,NULL,36,32892,0);
INSERT INTO "django_geo_db_location" VALUES(57446,NULL,'Bartlesville, OK 74006',24260,222,NULL,36,32893,0);
INSERT INTO "django_geo_db_location" VALUES(57447,NULL,'Bixby, OK',24261,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57448,NULL,'Bixby, OK 74008',24261,222,NULL,36,32894,0);
INSERT INTO "django_geo_db_location" VALUES(57449,NULL,'Bowring, OK',24262,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57450,NULL,'Bowring, OK 74009',24262,222,NULL,36,32895,0);
INSERT INTO "django_geo_db_location" VALUES(57451,NULL,'Bristow, OK',24263,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57452,NULL,'Bristow, OK 74010',24263,222,NULL,36,32896,0);
INSERT INTO "django_geo_db_location" VALUES(57453,NULL,'Broken Arrow, OK',24264,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57454,NULL,'Broken Arrow, OK 74011',24264,222,NULL,36,32897,0);
INSERT INTO "django_geo_db_location" VALUES(57455,NULL,'Broken Arrow, OK 74012',24264,222,NULL,36,32898,0);
INSERT INTO "django_geo_db_location" VALUES(57456,NULL,'Broken Arrow, OK 74013',24264,222,NULL,36,32899,0);
INSERT INTO "django_geo_db_location" VALUES(57457,NULL,'Broken Arrow, OK 74014',24264,222,NULL,36,32900,0);
INSERT INTO "django_geo_db_location" VALUES(57458,NULL,'Catoosa, OK',24265,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57459,NULL,'Catoosa, OK 74015',24265,222,NULL,36,32901,0);
INSERT INTO "django_geo_db_location" VALUES(57460,NULL,'Chelsea, OK',24266,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57461,NULL,'Chelsea, OK 74016',24266,222,NULL,36,32902,0);
INSERT INTO "django_geo_db_location" VALUES(57462,NULL,'Claremore, OK',24267,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57463,NULL,'Claremore, OK 74017',24267,222,NULL,36,32903,0);
INSERT INTO "django_geo_db_location" VALUES(57464,NULL,'Claremore, OK 74018',24267,222,NULL,36,32904,0);
INSERT INTO "django_geo_db_location" VALUES(57465,NULL,'Cleveland, OK',24268,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57466,NULL,'Cleveland, OK 74020',24268,222,NULL,36,32905,0);
INSERT INTO "django_geo_db_location" VALUES(57467,NULL,'Collinsville, OK',24269,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57468,NULL,'Collinsville, OK 74021',24269,222,NULL,36,32906,0);
INSERT INTO "django_geo_db_location" VALUES(57469,NULL,'Copan, OK',24270,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57470,NULL,'Copan, OK 74022',24270,222,NULL,36,32907,0);
INSERT INTO "django_geo_db_location" VALUES(57471,NULL,'Cushing, OK',24271,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57472,NULL,'Cushing, OK 74023',24271,222,NULL,36,32908,0);
INSERT INTO "django_geo_db_location" VALUES(57473,NULL,'Davenport, OK',24272,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57474,NULL,'Davenport, OK 74026',24272,222,NULL,36,32909,0);
INSERT INTO "django_geo_db_location" VALUES(57475,NULL,'Delaware, OK',24273,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57476,NULL,'Delaware, OK 74027',24273,222,NULL,36,32910,0);
INSERT INTO "django_geo_db_location" VALUES(57477,NULL,'Depew, OK',24274,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57478,NULL,'Depew, OK 74028',24274,222,NULL,36,32911,0);
INSERT INTO "django_geo_db_location" VALUES(57479,NULL,'Dewey, OK',24275,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57480,NULL,'Dewey, OK 74029',24275,222,NULL,36,32912,0);
INSERT INTO "django_geo_db_location" VALUES(57481,NULL,'Drumright, OK',24276,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57482,NULL,'Drumright, OK 74030',24276,222,NULL,36,32913,0);
INSERT INTO "django_geo_db_location" VALUES(57483,NULL,'Foyil, OK',24277,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57484,NULL,'Foyil, OK 74031',24277,222,NULL,36,32914,0);
INSERT INTO "django_geo_db_location" VALUES(57485,NULL,'Glencoe, OK',24278,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57486,NULL,'Glencoe, OK 74032',24278,222,NULL,36,32915,0);
INSERT INTO "django_geo_db_location" VALUES(57487,NULL,'Glenpool, OK',24279,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57488,NULL,'Glenpool, OK 74033',24279,222,NULL,36,32916,0);
INSERT INTO "django_geo_db_location" VALUES(57489,NULL,'Hallett, OK',24280,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57490,NULL,'Hallett, OK 74034',24280,222,NULL,36,32917,0);
INSERT INTO "django_geo_db_location" VALUES(57491,NULL,'Hominy, OK',24281,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57492,NULL,'Hominy, OK 74035',24281,222,NULL,36,32918,0);
INSERT INTO "django_geo_db_location" VALUES(57493,NULL,'Inola, OK',24282,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57494,NULL,'Inola, OK 74036',24282,222,NULL,36,32919,0);
INSERT INTO "django_geo_db_location" VALUES(57495,NULL,'Jenks, OK',24283,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57496,NULL,'Jenks, OK 74037',24283,222,NULL,36,32920,0);
INSERT INTO "django_geo_db_location" VALUES(57497,NULL,'Jennings, OK',24284,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57498,NULL,'Jennings, OK 74038',24284,222,NULL,36,32921,0);
INSERT INTO "django_geo_db_location" VALUES(57499,NULL,'Kellyville, OK',24285,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57500,NULL,'Kellyville, OK 74039',24285,222,NULL,36,32922,0);
INSERT INTO "django_geo_db_location" VALUES(57501,NULL,'Kiefer, OK',24286,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57502,NULL,'Kiefer, OK 74041',24286,222,NULL,36,32923,0);
INSERT INTO "django_geo_db_location" VALUES(57503,NULL,'Lenapah, OK',24287,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57504,NULL,'Lenapah, OK 74042',24287,222,NULL,36,32924,0);
INSERT INTO "django_geo_db_location" VALUES(57505,NULL,'Leonard, OK',24288,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57506,NULL,'Leonard, OK 74043',24288,222,NULL,36,32925,0);
INSERT INTO "django_geo_db_location" VALUES(57507,NULL,'Mannford, OK',24289,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57508,NULL,'Mannford, OK 74044',24289,222,NULL,36,32926,0);
INSERT INTO "django_geo_db_location" VALUES(57509,NULL,'Maramec, OK',24290,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57510,NULL,'Maramec, OK 74045',24290,222,NULL,36,32927,0);
INSERT INTO "django_geo_db_location" VALUES(57511,NULL,'Milfay, OK',24291,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57512,NULL,'Milfay, OK 74046',24291,222,NULL,36,32928,0);
INSERT INTO "django_geo_db_location" VALUES(57513,NULL,'Mounds, OK',24292,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57514,NULL,'Mounds, OK 74047',24292,222,NULL,36,32929,0);
INSERT INTO "django_geo_db_location" VALUES(57515,NULL,'Nowata, OK',24293,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57516,NULL,'Nowata, OK 74048',24293,222,NULL,36,32930,0);
INSERT INTO "django_geo_db_location" VALUES(57517,NULL,'Oakhurst, OK',24294,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57518,NULL,'Oakhurst, OK 74050',24294,222,NULL,36,32931,0);
INSERT INTO "django_geo_db_location" VALUES(57519,NULL,'Ochelata, OK',24295,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57520,NULL,'Ochelata, OK 74051',24295,222,NULL,36,32932,0);
INSERT INTO "django_geo_db_location" VALUES(57521,NULL,'Oilton, OK',24296,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57522,NULL,'Oilton, OK 74052',24296,222,NULL,36,32933,0);
INSERT INTO "django_geo_db_location" VALUES(57523,NULL,'Oologah, OK',24297,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57524,NULL,'Oologah, OK 74053',24297,222,NULL,36,32934,0);
INSERT INTO "django_geo_db_location" VALUES(57525,NULL,'Osage, OK',24298,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57526,NULL,'Osage, OK 74054',24298,222,NULL,36,32935,0);
INSERT INTO "django_geo_db_location" VALUES(57527,NULL,'Owasso, OK',24299,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57528,NULL,'Owasso, OK 74055',24299,222,NULL,36,32936,0);
INSERT INTO "django_geo_db_location" VALUES(57529,NULL,'Pawhuska, OK',24300,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57530,NULL,'Pawhuska, OK 74056',24300,222,NULL,36,32937,0);
INSERT INTO "django_geo_db_location" VALUES(57531,NULL,'Pawnee, OK',24301,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57532,NULL,'Pawnee, OK 74058',24301,222,NULL,36,32938,0);
INSERT INTO "django_geo_db_location" VALUES(57533,NULL,'Perkins, OK',24302,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57534,NULL,'Perkins, OK 74059',24302,222,NULL,36,32939,0);
INSERT INTO "django_geo_db_location" VALUES(57535,NULL,'Prue, OK',24303,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57536,NULL,'Prue, OK 74060',24303,222,NULL,36,32940,0);
INSERT INTO "django_geo_db_location" VALUES(57537,NULL,'Ramona, OK',24304,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57538,NULL,'Ramona, OK 74061',24304,222,NULL,36,32941,0);
INSERT INTO "django_geo_db_location" VALUES(57539,NULL,'Ripley, OK',24305,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57540,NULL,'Ripley, OK 74062',24305,222,NULL,36,32942,0);
INSERT INTO "django_geo_db_location" VALUES(57541,NULL,'Sand Springs, OK',24306,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57542,NULL,'Sand Springs, OK 74063',24306,222,NULL,36,32943,0);
INSERT INTO "django_geo_db_location" VALUES(57543,NULL,'McCord, OK',24307,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57544,NULL,'McCord, OK 74064',24307,222,NULL,36,32944,0);
INSERT INTO "django_geo_db_location" VALUES(57545,NULL,'Sapulpa, OK',24308,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57546,NULL,'Sapulpa, OK 74066',24308,222,NULL,36,32945,0);
INSERT INTO "django_geo_db_location" VALUES(57547,NULL,'Sapulpa, OK 74067',24308,222,NULL,36,32946,0);
INSERT INTO "django_geo_db_location" VALUES(57548,NULL,'Shamrock, OK',24309,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57549,NULL,'Shamrock, OK 74068',24309,222,NULL,36,32947,0);
INSERT INTO "django_geo_db_location" VALUES(57550,NULL,'Skiatook, OK',24310,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57551,NULL,'Skiatook, OK 74070',24310,222,NULL,36,32948,0);
INSERT INTO "django_geo_db_location" VALUES(57552,NULL,'Slick, OK',24311,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57553,NULL,'Slick, OK 74071',24311,222,NULL,36,32949,0);
INSERT INTO "django_geo_db_location" VALUES(57554,NULL,'S Coffeyville, OK',24312,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57555,NULL,'S Coffeyville, OK 74072',24312,222,NULL,36,32950,0);
INSERT INTO "django_geo_db_location" VALUES(57556,NULL,'Sperry, OK',24313,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57557,NULL,'Sperry, OK 74073',24313,222,NULL,36,32951,0);
INSERT INTO "django_geo_db_location" VALUES(57558,NULL,'Stillwater, OK',24314,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57559,NULL,'Stillwater, OK 74074',24314,222,NULL,36,32952,0);
INSERT INTO "django_geo_db_location" VALUES(57560,NULL,'Stillwater, OK 74075',24314,222,NULL,36,32953,0);
INSERT INTO "django_geo_db_location" VALUES(57561,NULL,'Stillwater, OK 74076',24314,222,NULL,36,32954,0);
INSERT INTO "django_geo_db_location" VALUES(57562,NULL,'Stillwater, OK 74077',24314,222,NULL,36,32955,0);
INSERT INTO "django_geo_db_location" VALUES(57563,NULL,'Stillwater, OK 74078',24314,222,NULL,36,32956,0);
INSERT INTO "django_geo_db_location" VALUES(57564,NULL,'Stroud, OK',24315,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57565,NULL,'Stroud, OK 74079',24315,222,NULL,36,32957,0);
INSERT INTO "django_geo_db_location" VALUES(57566,NULL,'Talala, OK',24316,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57567,NULL,'Talala, OK 74080',24316,222,NULL,36,32958,0);
INSERT INTO "django_geo_db_location" VALUES(57568,NULL,'Terlton, OK',24317,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57569,NULL,'Terlton, OK 74081',24317,222,NULL,36,32959,0);
INSERT INTO "django_geo_db_location" VALUES(57570,NULL,'Vera, OK',24318,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57571,NULL,'Vera, OK 74082',24318,222,NULL,36,32960,0);
INSERT INTO "django_geo_db_location" VALUES(57572,NULL,'Wann, OK',24319,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57573,NULL,'Wann, OK 74083',24319,222,NULL,36,32961,0);
INSERT INTO "django_geo_db_location" VALUES(57574,NULL,'Wynona, OK',24320,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57575,NULL,'Wynona, OK 74084',24320,222,NULL,36,32962,0);
INSERT INTO "django_geo_db_location" VALUES(57576,NULL,'Yale, OK',24321,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57577,NULL,'Yale, OK 74085',24321,222,NULL,36,32963,0);
INSERT INTO "django_geo_db_location" VALUES(57578,NULL,'Tulsa, OK',24322,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57579,NULL,'Tulsa, OK 74101',24322,222,NULL,36,32964,0);
INSERT INTO "django_geo_db_location" VALUES(57580,NULL,'Tulsa, OK 74102',24322,222,NULL,36,32965,0);
INSERT INTO "django_geo_db_location" VALUES(57581,NULL,'Tulsa, OK 74103',24322,222,NULL,36,32966,0);
INSERT INTO "django_geo_db_location" VALUES(57582,NULL,'Tulsa, OK 74104',24322,222,NULL,36,32967,0);
INSERT INTO "django_geo_db_location" VALUES(57583,NULL,'Tulsa, OK 74105',24322,222,NULL,36,32968,0);
INSERT INTO "django_geo_db_location" VALUES(57584,NULL,'Tulsa, OK 74106',24322,222,NULL,36,32969,0);
INSERT INTO "django_geo_db_location" VALUES(57585,NULL,'Tulsa, OK 74107',24322,222,NULL,36,32970,0);
INSERT INTO "django_geo_db_location" VALUES(57586,NULL,'Tulsa, OK 74108',24322,222,NULL,36,32971,0);
INSERT INTO "django_geo_db_location" VALUES(57587,NULL,'Tulsa, OK 74110',24322,222,NULL,36,32972,0);
INSERT INTO "django_geo_db_location" VALUES(57588,NULL,'Tulsa, OK 74112',24322,222,NULL,36,32973,0);
INSERT INTO "django_geo_db_location" VALUES(57589,NULL,'Tulsa, OK 74114',24322,222,NULL,36,32974,0);
INSERT INTO "django_geo_db_location" VALUES(57590,NULL,'Tulsa, OK 74115',24322,222,NULL,36,32975,0);
INSERT INTO "django_geo_db_location" VALUES(57591,NULL,'Tulsa, OK 74116',24322,222,NULL,36,32976,0);
INSERT INTO "django_geo_db_location" VALUES(57592,NULL,'Tulsa, OK 74117',24322,222,NULL,36,32977,0);
INSERT INTO "django_geo_db_location" VALUES(57593,NULL,'Tulsa, OK 74119',24322,222,NULL,36,32978,0);
INSERT INTO "django_geo_db_location" VALUES(57594,NULL,'Tulsa, OK 74120',24322,222,NULL,36,32979,0);
INSERT INTO "django_geo_db_location" VALUES(57595,NULL,'Tulsa, OK 74121',24322,222,NULL,36,32980,0);
INSERT INTO "django_geo_db_location" VALUES(57596,NULL,'Tulsa, OK 74126',24322,222,NULL,36,32981,0);
INSERT INTO "django_geo_db_location" VALUES(57597,NULL,'Tulsa, OK 74127',24322,222,NULL,36,32982,0);
INSERT INTO "django_geo_db_location" VALUES(57598,NULL,'Tulsa, OK 74128',24322,222,NULL,36,32983,0);
INSERT INTO "django_geo_db_location" VALUES(57599,NULL,'Tulsa, OK 74129',24322,222,NULL,36,32984,0);
INSERT INTO "django_geo_db_location" VALUES(57600,NULL,'Tulsa, OK 74130',24322,222,NULL,36,32985,0);
INSERT INTO "django_geo_db_location" VALUES(57601,NULL,'Tulsa, OK 74131',24322,222,NULL,36,32986,0);
INSERT INTO "django_geo_db_location" VALUES(57602,NULL,'Tulsa, OK 74132',24322,222,NULL,36,32987,0);
INSERT INTO "django_geo_db_location" VALUES(57603,NULL,'Tulsa, OK 74133',24322,222,NULL,36,32988,0);
INSERT INTO "django_geo_db_location" VALUES(57604,NULL,'Tulsa, OK 74134',24322,222,NULL,36,32989,0);
INSERT INTO "django_geo_db_location" VALUES(57605,NULL,'Tulsa, OK 74135',24322,222,NULL,36,32990,0);
INSERT INTO "django_geo_db_location" VALUES(57606,NULL,'Tulsa, OK 74136',24322,222,NULL,36,32991,0);
INSERT INTO "django_geo_db_location" VALUES(57607,NULL,'Tulsa, OK 74137',24322,222,NULL,36,32992,0);
INSERT INTO "django_geo_db_location" VALUES(57608,NULL,'Tulsa, OK 74141',24322,222,NULL,36,32993,0);
INSERT INTO "django_geo_db_location" VALUES(57609,NULL,'Tulsa, OK 74145',24322,222,NULL,36,32994,0);
INSERT INTO "django_geo_db_location" VALUES(57610,NULL,'Tulsa, OK 74146',24322,222,NULL,36,32995,0);
INSERT INTO "django_geo_db_location" VALUES(57611,NULL,'Tulsa, OK 74147',24322,222,NULL,36,32996,0);
INSERT INTO "django_geo_db_location" VALUES(57612,NULL,'Tulsa, OK 74148',24322,222,NULL,36,32997,0);
INSERT INTO "django_geo_db_location" VALUES(57613,NULL,'Tulsa, OK 74149',24322,222,NULL,36,32998,0);
INSERT INTO "django_geo_db_location" VALUES(57614,NULL,'Tulsa, OK 74150',24322,222,NULL,36,32999,0);
INSERT INTO "django_geo_db_location" VALUES(57615,NULL,'Tulsa, OK 74152',24322,222,NULL,36,33000,0);
INSERT INTO "django_geo_db_location" VALUES(57616,NULL,'Tulsa, OK 74153',24322,222,NULL,36,33001,0);
INSERT INTO "django_geo_db_location" VALUES(57617,NULL,'Tulsa, OK 74155',24322,222,NULL,36,33002,0);
INSERT INTO "django_geo_db_location" VALUES(57618,NULL,'Tulsa, OK 74156',24322,222,NULL,36,33003,0);
INSERT INTO "django_geo_db_location" VALUES(57619,NULL,'Tulsa, OK 74157',24322,222,NULL,36,33004,0);
INSERT INTO "django_geo_db_location" VALUES(57620,NULL,'Tulsa, OK 74158',24322,222,NULL,36,33005,0);
INSERT INTO "django_geo_db_location" VALUES(57621,NULL,'Tulsa, OK 74159',24322,222,NULL,36,33006,0);
INSERT INTO "django_geo_db_location" VALUES(57622,NULL,'Tulsa, OK 74169',24322,222,NULL,36,33007,0);
INSERT INTO "django_geo_db_location" VALUES(57623,NULL,'Tulsa, OK 74170',24322,222,NULL,36,33008,0);
INSERT INTO "django_geo_db_location" VALUES(57624,NULL,'Tulsa, OK 74171',24322,222,NULL,36,33009,0);
INSERT INTO "django_geo_db_location" VALUES(57625,NULL,'Tulsa, OK 74172',24322,222,NULL,36,33010,0);
INSERT INTO "django_geo_db_location" VALUES(57626,NULL,'Tulsa, OK 74177',24322,222,NULL,36,33011,0);
INSERT INTO "django_geo_db_location" VALUES(57627,NULL,'Tulsa, OK 74182',24322,222,NULL,36,33012,0);
INSERT INTO "django_geo_db_location" VALUES(57628,NULL,'Tulsa, OK 74183',24322,222,NULL,36,33013,0);
INSERT INTO "django_geo_db_location" VALUES(57629,NULL,'Tulsa, OK 74184',24322,222,NULL,36,33014,0);
INSERT INTO "django_geo_db_location" VALUES(57630,NULL,'Tulsa, OK 74186',24322,222,NULL,36,33015,0);
INSERT INTO "django_geo_db_location" VALUES(57631,NULL,'Tulsa, OK 74187',24322,222,NULL,36,33016,0);
INSERT INTO "django_geo_db_location" VALUES(57632,NULL,'Tulsa, OK 74189',24322,222,NULL,36,33017,0);
INSERT INTO "django_geo_db_location" VALUES(57633,NULL,'Tulsa, OK 74192',24322,222,NULL,36,33018,0);
INSERT INTO "django_geo_db_location" VALUES(57634,NULL,'Tulsa, OK 74193',24322,222,NULL,36,33019,0);
INSERT INTO "django_geo_db_location" VALUES(57635,NULL,'Tulsa, OK 74194',24322,222,NULL,36,33020,0);
INSERT INTO "django_geo_db_location" VALUES(57636,NULL,'Vinita, OK',24323,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57637,NULL,'Vinita, OK 74301',24323,222,NULL,36,33021,0);
INSERT INTO "django_geo_db_location" VALUES(57638,NULL,'Colcord, OK',24324,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57639,NULL,'Colcord, OK 74328',24324,222,NULL,36,33022,0);
INSERT INTO "django_geo_db_location" VALUES(57640,NULL,'Adair, OK',24325,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57641,NULL,'Adair, OK 74330',24325,222,NULL,36,33023,0);
INSERT INTO "django_geo_db_location" VALUES(57642,NULL,'Afton, OK',24326,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57643,NULL,'Afton, OK 74331',24326,222,NULL,36,33024,0);
INSERT INTO "django_geo_db_location" VALUES(57644,NULL,'Big Cabin, OK',24327,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57645,NULL,'Big Cabin, OK 74332',24327,222,NULL,36,33025,0);
INSERT INTO "django_geo_db_location" VALUES(57646,NULL,'Bluejacket, OK',24328,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57647,NULL,'Bluejacket, OK 74333',24328,222,NULL,36,33026,0);
INSERT INTO "django_geo_db_location" VALUES(57648,NULL,'Dodge, OK',24329,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57649,NULL,'Dodge, OK 74334',24329,222,NULL,36,33027,0);
INSERT INTO "django_geo_db_location" VALUES(57650,NULL,'Cardin, OK',24330,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57651,NULL,'Cardin, OK 74335',24330,222,NULL,36,33028,0);
INSERT INTO "django_geo_db_location" VALUES(57652,NULL,'Jay, OK',24331,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57653,NULL,'Jay, OK 74336',24331,222,NULL,36,33029,0);
INSERT INTO "django_geo_db_location" VALUES(57654,NULL,'Chouteau, OK',24332,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57655,NULL,'Chouteau, OK 74337',24332,222,NULL,36,33030,0);
INSERT INTO "django_geo_db_location" VALUES(57656,NULL,'Colcord, OK 74338',24324,222,NULL,36,33031,0);
INSERT INTO "django_geo_db_location" VALUES(57657,NULL,'Commerce, OK',24333,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57658,NULL,'Commerce, OK 74339',24333,222,NULL,36,33032,0);
INSERT INTO "django_geo_db_location" VALUES(57659,NULL,'Disney, OK',24334,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57660,NULL,'Disney, OK 74340',24334,222,NULL,36,33033,0);
INSERT INTO "django_geo_db_location" VALUES(57661,NULL,'Eucha, OK',24335,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57662,NULL,'Eucha, OK 74342',24335,222,NULL,36,33034,0);
INSERT INTO "django_geo_db_location" VALUES(57663,NULL,'Fairland, OK',24336,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57664,NULL,'Fairland, OK 74343',24336,222,NULL,36,33035,0);
INSERT INTO "django_geo_db_location" VALUES(57665,NULL,'Grove, OK',24337,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57666,NULL,'Grove, OK 74344',24337,222,NULL,36,33036,0);
INSERT INTO "django_geo_db_location" VALUES(57667,NULL,'Grove, OK 74345',24337,222,NULL,36,33037,0);
INSERT INTO "django_geo_db_location" VALUES(57668,NULL,'Jay, OK 74346',24331,222,NULL,36,33038,0);
INSERT INTO "django_geo_db_location" VALUES(57669,NULL,'Kansas, OK',24338,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57670,NULL,'Kansas, OK 74347',24338,222,NULL,36,33039,0);
INSERT INTO "django_geo_db_location" VALUES(57671,NULL,'Ketchum, OK',24339,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57672,NULL,'Ketchum, OK 74349',24339,222,NULL,36,33040,0);
INSERT INTO "django_geo_db_location" VALUES(57673,NULL,'Langley, OK',24340,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57674,NULL,'Langley, OK 74350',24340,222,NULL,36,33041,0);
INSERT INTO "django_geo_db_location" VALUES(57675,NULL,'Locust Grove, OK',24341,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57676,NULL,'Locust Grove, OK 74352',24341,222,NULL,36,33042,0);
INSERT INTO "django_geo_db_location" VALUES(57677,NULL,'Mazie, OK',24342,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57678,NULL,'Mazie, OK 74353',24342,222,NULL,36,33043,0);
INSERT INTO "django_geo_db_location" VALUES(57679,NULL,'Miami, OK',24343,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57680,NULL,'Miami, OK 74354',24343,222,NULL,36,33044,0);
INSERT INTO "django_geo_db_location" VALUES(57681,NULL,'Miami, OK 74355',24343,222,NULL,36,33045,0);
INSERT INTO "django_geo_db_location" VALUES(57682,NULL,'North Miami, OK',24344,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57683,NULL,'North Miami, OK 74358',24344,222,NULL,36,33046,0);
INSERT INTO "django_geo_db_location" VALUES(57684,NULL,'Oaks, OK',24345,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57685,NULL,'Oaks, OK 74359',24345,222,NULL,36,33047,0);
INSERT INTO "django_geo_db_location" VALUES(57686,NULL,'Picher, OK',24346,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57687,NULL,'Picher, OK 74360',24346,222,NULL,36,33048,0);
INSERT INTO "django_geo_db_location" VALUES(57688,NULL,'Pryor, OK',24347,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57689,NULL,'Pryor, OK 74361',24347,222,NULL,36,33049,0);
INSERT INTO "django_geo_db_location" VALUES(57690,NULL,'Pryor, OK 74362',24347,222,NULL,36,33050,0);
INSERT INTO "django_geo_db_location" VALUES(57691,NULL,'Quapaw, OK',24348,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57692,NULL,'Quapaw, OK 74363',24348,222,NULL,36,33051,0);
INSERT INTO "django_geo_db_location" VALUES(57693,NULL,'Rose, OK',24349,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57694,NULL,'Rose, OK 74364',24349,222,NULL,36,33052,0);
INSERT INTO "django_geo_db_location" VALUES(57695,NULL,'Salina, OK',24350,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57696,NULL,'Salina, OK 74365',24350,222,NULL,36,33053,0);
INSERT INTO "django_geo_db_location" VALUES(57697,NULL,'Spavinaw, OK',24351,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57698,NULL,'Spavinaw, OK 74366',24351,222,NULL,36,33054,0);
INSERT INTO "django_geo_db_location" VALUES(57699,NULL,'Strang, OK',24352,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57700,NULL,'Strang, OK 74367',24352,222,NULL,36,33055,0);
INSERT INTO "django_geo_db_location" VALUES(57701,NULL,'Twin Oaks, OK',24353,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57702,NULL,'Twin Oaks, OK 74368',24353,222,NULL,36,33056,0);
INSERT INTO "django_geo_db_location" VALUES(57703,NULL,'Welch, OK',24354,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57704,NULL,'Welch, OK 74369',24354,222,NULL,36,33057,0);
INSERT INTO "django_geo_db_location" VALUES(57705,NULL,'Wyandotte, OK',24355,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57706,NULL,'Wyandotte, OK 74370',24355,222,NULL,36,33058,0);
INSERT INTO "django_geo_db_location" VALUES(57707,NULL,'Commerce, OK 74399',24333,222,NULL,36,33059,0);
INSERT INTO "django_geo_db_location" VALUES(57708,NULL,'Muskogee, OK',24356,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57709,NULL,'Muskogee, OK 74401',24356,222,NULL,36,33060,0);
INSERT INTO "django_geo_db_location" VALUES(57710,NULL,'Muskogee, OK 74402',24356,222,NULL,36,33061,0);
INSERT INTO "django_geo_db_location" VALUES(57711,NULL,'Muskogee, OK 74403',24356,222,NULL,36,33062,0);
INSERT INTO "django_geo_db_location" VALUES(57712,NULL,'Beggs, OK',24357,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57713,NULL,'Beggs, OK 74421',24357,222,NULL,36,33063,0);
INSERT INTO "django_geo_db_location" VALUES(57714,NULL,'Boynton, OK',24358,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57715,NULL,'Boynton, OK 74422',24358,222,NULL,36,33064,0);
INSERT INTO "django_geo_db_location" VALUES(57716,NULL,'Braggs, OK',24359,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57717,NULL,'Braggs, OK 74423',24359,222,NULL,36,33065,0);
INSERT INTO "django_geo_db_location" VALUES(57718,NULL,'Canadian, OK',24360,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57719,NULL,'Canadian, OK 74425',24360,222,NULL,36,33066,0);
INSERT INTO "django_geo_db_location" VALUES(57720,NULL,'Checotah, OK',24361,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57721,NULL,'Checotah, OK 74426',24361,222,NULL,36,33067,0);
INSERT INTO "django_geo_db_location" VALUES(57722,NULL,'Cookson, OK',24362,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57723,NULL,'Cookson, OK 74427',24362,222,NULL,36,33068,0);
INSERT INTO "django_geo_db_location" VALUES(57724,NULL,'Council Hill, OK',24363,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57725,NULL,'Council Hill, OK 74428',24363,222,NULL,36,33069,0);
INSERT INTO "django_geo_db_location" VALUES(57726,NULL,'Coweta, OK',24364,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57727,NULL,'Coweta, OK 74429',24364,222,NULL,36,33070,0);
INSERT INTO "django_geo_db_location" VALUES(57728,NULL,'Crowder, OK',24365,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57729,NULL,'Crowder, OK 74430',24365,222,NULL,36,33071,0);
INSERT INTO "django_geo_db_location" VALUES(57730,NULL,'Dewar, OK',24366,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57731,NULL,'Dewar, OK 74431',24366,222,NULL,36,33072,0);
INSERT INTO "django_geo_db_location" VALUES(57732,NULL,'Eufaula, OK',24367,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57733,NULL,'Eufaula, OK 74432',24367,222,NULL,36,33073,0);
INSERT INTO "django_geo_db_location" VALUES(57734,NULL,'Fort Gibson, OK',24368,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57735,NULL,'Fort Gibson, OK 74434',24368,222,NULL,36,33074,0);
INSERT INTO "django_geo_db_location" VALUES(57736,NULL,'Gore, OK',24369,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57737,NULL,'Gore, OK 74435',24369,222,NULL,36,33075,0);
INSERT INTO "django_geo_db_location" VALUES(57738,NULL,'Haskell, OK',24370,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57739,NULL,'Haskell, OK 74436',24370,222,NULL,36,33076,0);
INSERT INTO "django_geo_db_location" VALUES(57740,NULL,'Henryetta, OK',24371,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57741,NULL,'Henryetta, OK 74437',24371,222,NULL,36,33077,0);
INSERT INTO "django_geo_db_location" VALUES(57742,NULL,'Hitchita, OK',24372,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57743,NULL,'Hitchita, OK 74438',24372,222,NULL,36,33078,0);
INSERT INTO "django_geo_db_location" VALUES(57744,NULL,'Hoyt, OK',24373,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57745,NULL,'Hoyt, OK 74440',24373,222,NULL,36,33079,0);
INSERT INTO "django_geo_db_location" VALUES(57746,NULL,'Hulbert, OK',24374,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57747,NULL,'Hulbert, OK 74441',24374,222,NULL,36,33080,0);
INSERT INTO "django_geo_db_location" VALUES(57748,NULL,'Indianola, OK',24375,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57749,NULL,'Indianola, OK 74442',24375,222,NULL,36,33081,0);
INSERT INTO "django_geo_db_location" VALUES(57750,NULL,'Moodys, OK',24376,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57751,NULL,'Moodys, OK 74444',24376,222,NULL,36,33082,0);
INSERT INTO "django_geo_db_location" VALUES(57752,NULL,'Morris, OK',24377,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57753,NULL,'Morris, OK 74445',24377,222,NULL,36,33083,0);
INSERT INTO "django_geo_db_location" VALUES(57754,NULL,'Okay, OK',24378,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57755,NULL,'Okay, OK 74446',24378,222,NULL,36,33084,0);
INSERT INTO "django_geo_db_location" VALUES(57756,NULL,'Okmulgee, OK',24379,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57757,NULL,'Okmulgee, OK 74447',24379,222,NULL,36,33085,0);
INSERT INTO "django_geo_db_location" VALUES(57758,NULL,'Oktaha, OK',24380,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57759,NULL,'Oktaha, OK 74450',24380,222,NULL,36,33086,0);
INSERT INTO "django_geo_db_location" VALUES(57760,NULL,'Park Hill, OK',24381,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57761,NULL,'Park Hill, OK 74451',24381,222,NULL,36,33087,0);
INSERT INTO "django_geo_db_location" VALUES(57762,NULL,'Peggs, OK',24382,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57763,NULL,'Peggs, OK 74452',24382,222,NULL,36,33088,0);
INSERT INTO "django_geo_db_location" VALUES(57764,NULL,'Porter, OK',24383,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57765,NULL,'Porter, OK 74454',24383,222,NULL,36,33089,0);
INSERT INTO "django_geo_db_location" VALUES(57766,NULL,'Porum, OK',24384,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57767,NULL,'Porum, OK 74455',24384,222,NULL,36,33090,0);
INSERT INTO "django_geo_db_location" VALUES(57768,NULL,'Preston, OK',24385,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57769,NULL,'Preston, OK 74456',24385,222,NULL,36,33091,0);
INSERT INTO "django_geo_db_location" VALUES(57770,NULL,'Proctor, OK',24386,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57771,NULL,'Proctor, OK 74457',24386,222,NULL,36,33092,0);
INSERT INTO "django_geo_db_location" VALUES(57772,NULL,'Redbird, OK',24387,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57773,NULL,'Redbird, OK 74458',24387,222,NULL,36,33093,0);
INSERT INTO "django_geo_db_location" VALUES(57774,NULL,'Rentiesville, OK',24388,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57775,NULL,'Rentiesville, OK 74459',24388,222,NULL,36,33094,0);
INSERT INTO "django_geo_db_location" VALUES(57776,NULL,'Schulter, OK',24389,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57777,NULL,'Schulter, OK 74460',24389,222,NULL,36,33095,0);
INSERT INTO "django_geo_db_location" VALUES(57778,NULL,'Stidham, OK',24390,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57779,NULL,'Stidham, OK 74461',24390,222,NULL,36,33096,0);
INSERT INTO "django_geo_db_location" VALUES(57780,NULL,'Stigler, OK',24391,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57781,NULL,'Stigler, OK 74462',24391,222,NULL,36,33097,0);
INSERT INTO "django_geo_db_location" VALUES(57782,NULL,'Taft, OK',24392,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57783,NULL,'Taft, OK 74463',24392,222,NULL,36,33098,0);
INSERT INTO "django_geo_db_location" VALUES(57784,NULL,'Tahlequah, OK',24393,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57785,NULL,'Tahlequah, OK 74464',24393,222,NULL,36,33099,0);
INSERT INTO "django_geo_db_location" VALUES(57786,NULL,'Tahlequah, OK 74465',24393,222,NULL,36,33100,0);
INSERT INTO "django_geo_db_location" VALUES(57787,NULL,'Tullahassee, OK',24394,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57788,NULL,'Tullahassee, OK 74466',24394,222,NULL,36,33101,0);
INSERT INTO "django_geo_db_location" VALUES(57789,NULL,'Wagoner, OK',24395,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57790,NULL,'Wagoner, OK 74467',24395,222,NULL,36,33102,0);
INSERT INTO "django_geo_db_location" VALUES(57791,NULL,'Wainwright, OK',24396,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57792,NULL,'Wainwright, OK 74468',24396,222,NULL,36,33103,0);
INSERT INTO "django_geo_db_location" VALUES(57793,NULL,'Warner, OK',24397,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57794,NULL,'Warner, OK 74469',24397,222,NULL,36,33104,0);
INSERT INTO "django_geo_db_location" VALUES(57795,NULL,'Webbers Falls, OK',24398,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57796,NULL,'Webbers Falls, OK 74470',24398,222,NULL,36,33105,0);
INSERT INTO "django_geo_db_location" VALUES(57797,NULL,'Welling, OK',24399,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57798,NULL,'Welling, OK 74471',24399,222,NULL,36,33106,0);
INSERT INTO "django_geo_db_location" VALUES(57799,NULL,'Whitefield, OK',24400,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57800,NULL,'Whitefield, OK 74472',24400,222,NULL,36,33107,0);
INSERT INTO "django_geo_db_location" VALUES(57801,NULL,'Wagoner, OK 74477',24395,222,NULL,36,33108,0);
INSERT INTO "django_geo_db_location" VALUES(57802,NULL,'Mcalester, OK',24401,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57803,NULL,'Mcalester, OK 74501',24401,222,NULL,36,33109,0);
INSERT INTO "django_geo_db_location" VALUES(57804,NULL,'Mcalester, OK 74502',24401,222,NULL,36,33110,0);
INSERT INTO "django_geo_db_location" VALUES(57805,NULL,'Ada, OK',24402,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57806,NULL,'Ada, OK 74520',24402,222,NULL,36,33111,0);
INSERT INTO "django_geo_db_location" VALUES(57807,NULL,'Albion, OK',24403,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57808,NULL,'Albion, OK 74521',24403,222,NULL,36,33112,0);
INSERT INTO "django_geo_db_location" VALUES(57809,NULL,'Alderson, OK',24404,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57810,NULL,'Alderson, OK 74522',24404,222,NULL,36,33113,0);
INSERT INTO "django_geo_db_location" VALUES(57811,NULL,'Antlers, OK',24405,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57812,NULL,'Antlers, OK 74523',24405,222,NULL,36,33114,0);
INSERT INTO "django_geo_db_location" VALUES(57813,NULL,'Atoka, OK',24406,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57814,NULL,'Atoka, OK 74525',24406,222,NULL,36,33115,0);
INSERT INTO "django_geo_db_location" VALUES(57815,NULL,'Blanco, OK',24407,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57816,NULL,'Blanco, OK 74528',24407,222,NULL,36,33116,0);
INSERT INTO "django_geo_db_location" VALUES(57817,NULL,'Blocker, OK',24408,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57818,NULL,'Blocker, OK 74529',24408,222,NULL,36,33117,0);
INSERT INTO "django_geo_db_location" VALUES(57819,NULL,'Bromide, OK',24409,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57820,NULL,'Bromide, OK 74530',24409,222,NULL,36,33118,0);
INSERT INTO "django_geo_db_location" VALUES(57821,NULL,'Calvin, OK',24410,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57822,NULL,'Calvin, OK 74531',24410,222,NULL,36,33119,0);
INSERT INTO "django_geo_db_location" VALUES(57823,NULL,'Caney, OK',24411,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57824,NULL,'Caney, OK 74533',24411,222,NULL,36,33120,0);
INSERT INTO "django_geo_db_location" VALUES(57825,NULL,'Centrahoma, OK',24412,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57826,NULL,'Centrahoma, OK 74534',24412,222,NULL,36,33121,0);
INSERT INTO "django_geo_db_location" VALUES(57827,NULL,'Clarita, OK',24413,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57828,NULL,'Clarita, OK 74535',24413,222,NULL,36,33122,0);
INSERT INTO "django_geo_db_location" VALUES(57829,NULL,'Clayton, OK',24414,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57830,NULL,'Clayton, OK 74536',24414,222,NULL,36,33123,0);
INSERT INTO "django_geo_db_location" VALUES(57831,NULL,'Coalgate, OK',24415,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57832,NULL,'Coalgate, OK 74538',24415,222,NULL,36,33124,0);
INSERT INTO "django_geo_db_location" VALUES(57833,NULL,'Daisy, OK',24416,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57834,NULL,'Daisy, OK 74540',24416,222,NULL,36,33125,0);
INSERT INTO "django_geo_db_location" VALUES(57835,NULL,'Atoka, OK 74542',24406,222,NULL,36,33126,0);
INSERT INTO "django_geo_db_location" VALUES(57836,NULL,'Finley, OK',24417,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57837,NULL,'Finley, OK 74543',24417,222,NULL,36,33127,0);
INSERT INTO "django_geo_db_location" VALUES(57838,NULL,'Gowen, OK',24418,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57839,NULL,'Gowen, OK 74545',24418,222,NULL,36,33128,0);
INSERT INTO "django_geo_db_location" VALUES(57840,NULL,'Haileyville, OK',24419,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57841,NULL,'Haileyville, OK 74546',24419,222,NULL,36,33129,0);
INSERT INTO "django_geo_db_location" VALUES(57842,NULL,'Hartshorne, OK',24420,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57843,NULL,'Hartshorne, OK 74547',24420,222,NULL,36,33130,0);
INSERT INTO "django_geo_db_location" VALUES(57844,NULL,'Honobia, OK',24421,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57845,NULL,'Honobia, OK 74549',24421,222,NULL,36,33131,0);
INSERT INTO "django_geo_db_location" VALUES(57846,NULL,'Kinta, OK',24422,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57847,NULL,'Kinta, OK 74552',24422,222,NULL,36,33132,0);
INSERT INTO "django_geo_db_location" VALUES(57848,NULL,'Kiowa, OK',24423,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57849,NULL,'Kiowa, OK 74553',24423,222,NULL,36,33133,0);
INSERT INTO "django_geo_db_location" VALUES(57850,NULL,'Krebs, OK',24424,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57851,NULL,'Krebs, OK 74554',24424,222,NULL,36,33134,0);
INSERT INTO "django_geo_db_location" VALUES(57852,NULL,'Lane, OK',24425,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57853,NULL,'Lane, OK 74555',24425,222,NULL,36,33135,0);
INSERT INTO "django_geo_db_location" VALUES(57854,NULL,'Lehigh, OK',24426,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57855,NULL,'Lehigh, OK 74556',24426,222,NULL,36,33136,0);
INSERT INTO "django_geo_db_location" VALUES(57856,NULL,'Moyers, OK',24427,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57857,NULL,'Moyers, OK 74557',24427,222,NULL,36,33137,0);
INSERT INTO "django_geo_db_location" VALUES(57858,NULL,'Nashoba, OK',24428,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57859,NULL,'Nashoba, OK 74558',24428,222,NULL,36,33138,0);
INSERT INTO "django_geo_db_location" VALUES(57860,NULL,'Panola, OK',24429,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57861,NULL,'Panola, OK 74559',24429,222,NULL,36,33139,0);
INSERT INTO "django_geo_db_location" VALUES(57862,NULL,'Pittsburg, OK',24430,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57863,NULL,'Pittsburg, OK 74560',24430,222,NULL,36,33140,0);
INSERT INTO "django_geo_db_location" VALUES(57864,NULL,'Quinton, OK',24431,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57865,NULL,'Quinton, OK 74561',24431,222,NULL,36,33141,0);
INSERT INTO "django_geo_db_location" VALUES(57866,NULL,'Rattan, OK',24432,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57867,NULL,'Rattan, OK 74562',24432,222,NULL,36,33142,0);
INSERT INTO "django_geo_db_location" VALUES(57868,NULL,'Red Oak, OK',24433,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57869,NULL,'Red Oak, OK 74563',24433,222,NULL,36,33143,0);
INSERT INTO "django_geo_db_location" VALUES(57870,NULL,'Savanna, OK',24434,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57871,NULL,'Savanna, OK 74565',24434,222,NULL,36,33144,0);
INSERT INTO "django_geo_db_location" VALUES(57872,NULL,'Snow, OK',24435,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57873,NULL,'Snow, OK 74567',24435,222,NULL,36,33145,0);
INSERT INTO "django_geo_db_location" VALUES(57874,NULL,'Stringtown, OK',24436,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57875,NULL,'Stringtown, OK 74569',24436,222,NULL,36,33146,0);
INSERT INTO "django_geo_db_location" VALUES(57876,NULL,'Stuart, OK',24437,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57877,NULL,'Stuart, OK 74570',24437,222,NULL,36,33147,0);
INSERT INTO "django_geo_db_location" VALUES(57878,NULL,'Talihina, OK',24438,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57879,NULL,'Talihina, OK 74571',24438,222,NULL,36,33148,0);
INSERT INTO "django_geo_db_location" VALUES(57880,NULL,'Tupelo, OK',24439,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57881,NULL,'Tupelo, OK 74572',24439,222,NULL,36,33149,0);
INSERT INTO "django_geo_db_location" VALUES(57882,NULL,'Tuskahoma, OK',24440,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57883,NULL,'Tuskahoma, OK 74574',24440,222,NULL,36,33150,0);
INSERT INTO "django_geo_db_location" VALUES(57884,NULL,'Wardville, OK',24441,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57885,NULL,'Wardville, OK 74576',24441,222,NULL,36,33151,0);
INSERT INTO "django_geo_db_location" VALUES(57886,NULL,'Whitesboro, OK',24442,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57887,NULL,'Whitesboro, OK 74577',24442,222,NULL,36,33152,0);
INSERT INTO "django_geo_db_location" VALUES(57888,NULL,'Wilburton, OK',24443,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57889,NULL,'Wilburton, OK 74578',24443,222,NULL,36,33153,0);
INSERT INTO "django_geo_db_location" VALUES(57890,NULL,'Ponca City, OK',24444,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57891,NULL,'Ponca City, OK 74601',24444,222,NULL,36,33154,0);
INSERT INTO "django_geo_db_location" VALUES(57892,NULL,'Ponca City, OK 74602',24444,222,NULL,36,33155,0);
INSERT INTO "django_geo_db_location" VALUES(57893,NULL,'Ponca City, OK 74603',24444,222,NULL,36,33156,0);
INSERT INTO "django_geo_db_location" VALUES(57894,NULL,'Ponca City, OK 74604',24444,222,NULL,36,33157,0);
INSERT INTO "django_geo_db_location" VALUES(57895,NULL,'Billings, OK',24445,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57896,NULL,'Billings, OK 74630',24445,222,NULL,36,33158,0);
INSERT INTO "django_geo_db_location" VALUES(57897,NULL,'Blackwell, OK',24446,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57898,NULL,'Blackwell, OK 74631',24446,222,NULL,36,33159,0);
INSERT INTO "django_geo_db_location" VALUES(57899,NULL,'Braman, OK',24447,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57900,NULL,'Braman, OK 74632',24447,222,NULL,36,33160,0);
INSERT INTO "django_geo_db_location" VALUES(57901,NULL,'Burbank, OK',24448,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57902,NULL,'Burbank, OK 74633',24448,222,NULL,36,33161,0);
INSERT INTO "django_geo_db_location" VALUES(57903,NULL,'Deer Creek, OK',24449,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57904,NULL,'Deer Creek, OK 74636',24449,222,NULL,36,33162,0);
INSERT INTO "django_geo_db_location" VALUES(57905,NULL,'Fairfax, OK',24450,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57906,NULL,'Fairfax, OK 74637',24450,222,NULL,36,33163,0);
INSERT INTO "django_geo_db_location" VALUES(57907,NULL,'Hunter, OK',24451,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57908,NULL,'Hunter, OK 74640',24451,222,NULL,36,33164,0);
INSERT INTO "django_geo_db_location" VALUES(57909,NULL,'Kaw City, OK',24452,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57910,NULL,'Kaw City, OK 74641',24452,222,NULL,36,33165,0);
INSERT INTO "django_geo_db_location" VALUES(57911,NULL,'Lamont, OK',24453,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57912,NULL,'Lamont, OK 74643',24453,222,NULL,36,33166,0);
INSERT INTO "django_geo_db_location" VALUES(57913,NULL,'Marland, OK',24454,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57914,NULL,'Marland, OK 74644',24454,222,NULL,36,33167,0);
INSERT INTO "django_geo_db_location" VALUES(57915,NULL,'Nardin, OK',24455,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57916,NULL,'Nardin, OK 74646',24455,222,NULL,36,33168,0);
INSERT INTO "django_geo_db_location" VALUES(57917,NULL,'Newkirk, OK',24456,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57918,NULL,'Newkirk, OK 74647',24456,222,NULL,36,33169,0);
INSERT INTO "django_geo_db_location" VALUES(57919,NULL,'Ralston, OK',24457,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57920,NULL,'Ralston, OK 74650',24457,222,NULL,36,33170,0);
INSERT INTO "django_geo_db_location" VALUES(57921,NULL,'Red Rock, OK',24458,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57922,NULL,'Red Rock, OK 74651',24458,222,NULL,36,33171,0);
INSERT INTO "django_geo_db_location" VALUES(57923,NULL,'Shidler, OK',24459,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57924,NULL,'Shidler, OK 74652',24459,222,NULL,36,33172,0);
INSERT INTO "django_geo_db_location" VALUES(57925,NULL,'Tonkawa, OK',24460,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57926,NULL,'Tonkawa, OK 74653',24460,222,NULL,36,33173,0);
INSERT INTO "django_geo_db_location" VALUES(57927,NULL,'Durant, OK',24461,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57928,NULL,'Durant, OK 74701',24461,222,NULL,36,33174,0);
INSERT INTO "django_geo_db_location" VALUES(57929,NULL,'Durant, OK 74702',24461,222,NULL,36,33175,0);
INSERT INTO "django_geo_db_location" VALUES(57930,NULL,'Achille, OK',24462,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57931,NULL,'Achille, OK 74720',24462,222,NULL,36,33176,0);
INSERT INTO "django_geo_db_location" VALUES(57932,NULL,'Albany, OK',24463,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57933,NULL,'Albany, OK 74721',24463,222,NULL,36,33177,0);
INSERT INTO "django_geo_db_location" VALUES(57934,NULL,'Battiest, OK',24464,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57935,NULL,'Battiest, OK 74722',24464,222,NULL,36,33178,0);
INSERT INTO "django_geo_db_location" VALUES(57936,NULL,'Bennington, OK',24465,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57937,NULL,'Bennington, OK 74723',24465,222,NULL,36,33179,0);
INSERT INTO "django_geo_db_location" VALUES(57938,NULL,'Bethel, OK',24466,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57939,NULL,'Bethel, OK 74724',24466,222,NULL,36,33180,0);
INSERT INTO "django_geo_db_location" VALUES(57940,NULL,'Bokchito, OK',24467,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57941,NULL,'Bokchito, OK 74726',24467,222,NULL,36,33181,0);
INSERT INTO "django_geo_db_location" VALUES(57942,NULL,'Boswell, OK',24468,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57943,NULL,'Boswell, OK 74727',24468,222,NULL,36,33182,0);
INSERT INTO "django_geo_db_location" VALUES(57944,NULL,'Broken Bow, OK',24469,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57945,NULL,'Broken Bow, OK 74728',24469,222,NULL,36,33183,0);
INSERT INTO "django_geo_db_location" VALUES(57946,NULL,'Caddo, OK',24470,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57947,NULL,'Caddo, OK 74729',24470,222,NULL,36,33184,0);
INSERT INTO "django_geo_db_location" VALUES(57948,NULL,'Calera, OK',24471,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57949,NULL,'Calera, OK 74730',24471,222,NULL,36,33185,0);
INSERT INTO "django_geo_db_location" VALUES(57950,NULL,'Cartwright, OK',24472,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57951,NULL,'Cartwright, OK 74731',24472,222,NULL,36,33186,0);
INSERT INTO "django_geo_db_location" VALUES(57952,NULL,'Colbert, OK',24473,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57953,NULL,'Colbert, OK 74733',24473,222,NULL,36,33187,0);
INSERT INTO "django_geo_db_location" VALUES(57954,NULL,'Eagletown, OK',24474,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57955,NULL,'Eagletown, OK 74734',24474,222,NULL,36,33188,0);
INSERT INTO "django_geo_db_location" VALUES(57956,NULL,'Fort Towson, OK',24475,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57957,NULL,'Fort Towson, OK 74735',24475,222,NULL,36,33189,0);
INSERT INTO "django_geo_db_location" VALUES(57958,NULL,'Garvin, OK',24476,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57959,NULL,'Garvin, OK 74736',24476,222,NULL,36,33190,0);
INSERT INTO "django_geo_db_location" VALUES(57960,NULL,'Golden, OK',24477,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57961,NULL,'Golden, OK 74737',24477,222,NULL,36,33191,0);
INSERT INTO "django_geo_db_location" VALUES(57962,NULL,'Grant, OK',24478,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57963,NULL,'Grant, OK 74738',24478,222,NULL,36,33192,0);
INSERT INTO "django_geo_db_location" VALUES(57964,NULL,'Haworth, OK',24479,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57965,NULL,'Haworth, OK 74740',24479,222,NULL,36,33193,0);
INSERT INTO "django_geo_db_location" VALUES(57966,NULL,'Hendrix, OK',24480,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57967,NULL,'Hendrix, OK 74741',24480,222,NULL,36,33194,0);
INSERT INTO "django_geo_db_location" VALUES(57968,NULL,'Hugo, OK',24481,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57969,NULL,'Hugo, OK 74743',24481,222,NULL,36,33195,0);
INSERT INTO "django_geo_db_location" VALUES(57970,NULL,'Idabel, OK',24482,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57971,NULL,'Idabel, OK 74745',24482,222,NULL,36,33196,0);
INSERT INTO "django_geo_db_location" VALUES(57972,NULL,'Kemp, OK',24483,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57973,NULL,'Kemp, OK 74747',24483,222,NULL,36,33197,0);
INSERT INTO "django_geo_db_location" VALUES(57974,NULL,'Kenefic, OK',24484,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57975,NULL,'Kenefic, OK 74748',24484,222,NULL,36,33198,0);
INSERT INTO "django_geo_db_location" VALUES(57976,NULL,'Millerton, OK',24485,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57977,NULL,'Millerton, OK 74750',24485,222,NULL,36,33199,0);
INSERT INTO "django_geo_db_location" VALUES(57978,NULL,'Pickens, OK',24486,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57979,NULL,'Pickens, OK 74752',24486,222,NULL,36,33200,0);
INSERT INTO "django_geo_db_location" VALUES(57980,NULL,'Platter, OK',24487,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57981,NULL,'Platter, OK 74753',24487,222,NULL,36,33201,0);
INSERT INTO "django_geo_db_location" VALUES(57982,NULL,'Ringold, OK',24488,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57983,NULL,'Ringold, OK 74754',24488,222,NULL,36,33202,0);
INSERT INTO "django_geo_db_location" VALUES(57984,NULL,'Rufe, OK',24489,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57985,NULL,'Rufe, OK 74755',24489,222,NULL,36,33203,0);
INSERT INTO "django_geo_db_location" VALUES(57986,NULL,'Sawyer, OK',24490,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57987,NULL,'Sawyer, OK 74756',24490,222,NULL,36,33204,0);
INSERT INTO "django_geo_db_location" VALUES(57988,NULL,'Soper, OK',24491,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57989,NULL,'Soper, OK 74759',24491,222,NULL,36,33205,0);
INSERT INTO "django_geo_db_location" VALUES(57990,NULL,'Spencerville, OK',24492,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57991,NULL,'Spencerville, OK 74760',24492,222,NULL,36,33206,0);
INSERT INTO "django_geo_db_location" VALUES(57992,NULL,'Swink, OK',24493,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57993,NULL,'Swink, OK 74761',24493,222,NULL,36,33207,0);
INSERT INTO "django_geo_db_location" VALUES(57994,NULL,'Valliant, OK',24494,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57995,NULL,'Valliant, OK 74764',24494,222,NULL,36,33208,0);
INSERT INTO "django_geo_db_location" VALUES(57996,NULL,'Wright City, OK',24495,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57997,NULL,'Wright City, OK 74766',24495,222,NULL,36,33209,0);
INSERT INTO "django_geo_db_location" VALUES(57998,NULL,'Shawnee, OK',24496,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(57999,NULL,'Shawnee, OK 74801',24496,222,NULL,36,33210,0);
INSERT INTO "django_geo_db_location" VALUES(58000,NULL,'Shawnee, OK 74802',24496,222,NULL,36,33211,0);
INSERT INTO "django_geo_db_location" VALUES(58001,NULL,'Shawnee, OK 74804',24496,222,NULL,36,33212,0);
INSERT INTO "django_geo_db_location" VALUES(58002,NULL,'Shawnee, OK 74807',24496,222,NULL,36,33213,0);
INSERT INTO "django_geo_db_location" VALUES(58003,NULL,'Seminole, OK',24497,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58004,NULL,'Seminole, OK 74818',24497,222,NULL,36,33214,0);
INSERT INTO "django_geo_db_location" VALUES(58005,NULL,'Ada, OK 74820',24402,222,NULL,36,33215,0);
INSERT INTO "django_geo_db_location" VALUES(58006,NULL,'Ada, OK 74821',24402,222,NULL,36,33216,0);
INSERT INTO "django_geo_db_location" VALUES(58007,NULL,'Agra, OK',24498,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58008,NULL,'Agra, OK 74824',24498,222,NULL,36,33217,0);
INSERT INTO "django_geo_db_location" VALUES(58009,NULL,'Allen, OK',24499,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58010,NULL,'Allen, OK 74825',24499,222,NULL,36,33218,0);
INSERT INTO "django_geo_db_location" VALUES(58011,NULL,'Asher, OK',24500,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58012,NULL,'Asher, OK 74826',24500,222,NULL,36,33219,0);
INSERT INTO "django_geo_db_location" VALUES(58013,NULL,'Atwood, OK',24501,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58014,NULL,'Atwood, OK 74827',24501,222,NULL,36,33220,0);
INSERT INTO "django_geo_db_location" VALUES(58015,NULL,'Boley, OK',24502,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58016,NULL,'Boley, OK 74829',24502,222,NULL,36,33221,0);
INSERT INTO "django_geo_db_location" VALUES(58017,NULL,'Bowlegs, OK',24503,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58018,NULL,'Bowlegs, OK 74830',24503,222,NULL,36,33222,0);
INSERT INTO "django_geo_db_location" VALUES(58019,NULL,'Byars, OK',24504,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58020,NULL,'Byars, OK 74831',24504,222,NULL,36,33223,0);
INSERT INTO "django_geo_db_location" VALUES(58021,NULL,'Carney, OK',24505,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58022,NULL,'Carney, OK 74832',24505,222,NULL,36,33224,0);
INSERT INTO "django_geo_db_location" VALUES(58023,NULL,'Castle, OK',24506,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58024,NULL,'Castle, OK 74833',24506,222,NULL,36,33225,0);
INSERT INTO "django_geo_db_location" VALUES(58025,NULL,'Chandler, OK',24507,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58026,NULL,'Chandler, OK 74834',24507,222,NULL,36,33226,0);
INSERT INTO "django_geo_db_location" VALUES(58027,NULL,'Connerville, OK',24508,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58028,NULL,'Connerville, OK 74836',24508,222,NULL,36,33227,0);
INSERT INTO "django_geo_db_location" VALUES(58029,NULL,'Cromwell, OK',24509,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58030,NULL,'Cromwell, OK 74837',24509,222,NULL,36,33228,0);
INSERT INTO "django_geo_db_location" VALUES(58031,NULL,'Dustin, OK',24510,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58032,NULL,'Dustin, OK 74839',24510,222,NULL,36,33229,0);
INSERT INTO "django_geo_db_location" VALUES(58033,NULL,'Earlsboro, OK',24511,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58034,NULL,'Earlsboro, OK 74840',24511,222,NULL,36,33230,0);
INSERT INTO "django_geo_db_location" VALUES(58035,NULL,'Fittstown, OK',24512,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58036,NULL,'Fittstown, OK 74842',24512,222,NULL,36,33231,0);
INSERT INTO "django_geo_db_location" VALUES(58037,NULL,'Fitzhugh, OK',24513,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58038,NULL,'Fitzhugh, OK 74843',24513,222,NULL,36,33232,0);
INSERT INTO "django_geo_db_location" VALUES(58039,NULL,'Francis, OK',24514,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58040,NULL,'Francis, OK 74844',24514,222,NULL,36,33233,0);
INSERT INTO "django_geo_db_location" VALUES(58041,NULL,'Hanna, OK',24515,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58042,NULL,'Hanna, OK 74845',24515,222,NULL,36,33234,0);
INSERT INTO "django_geo_db_location" VALUES(58043,NULL,'Holdenville, OK',24516,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58044,NULL,'Holdenville, OK 74848',24516,222,NULL,36,33235,0);
INSERT INTO "django_geo_db_location" VALUES(58045,NULL,'Konawa, OK',24517,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58046,NULL,'Konawa, OK 74849',24517,222,NULL,36,33236,0);
INSERT INTO "django_geo_db_location" VALUES(58047,NULL,'Lamar, OK',24518,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58048,NULL,'Lamar, OK 74850',24518,222,NULL,36,33237,0);
INSERT INTO "django_geo_db_location" VALUES(58049,NULL,'Mcloud, OK',24519,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58050,NULL,'Mcloud, OK 74851',24519,222,NULL,36,33238,0);
INSERT INTO "django_geo_db_location" VALUES(58051,NULL,'Macomb, OK',24520,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58052,NULL,'Macomb, OK 74852',24520,222,NULL,36,33239,0);
INSERT INTO "django_geo_db_location" VALUES(58053,NULL,'Wetumka, OK',24521,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58054,NULL,'Wetumka, OK 74853',24521,222,NULL,36,33240,0);
INSERT INTO "django_geo_db_location" VALUES(58055,NULL,'Maud, OK',24522,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58056,NULL,'Maud, OK 74854',24522,222,NULL,36,33241,0);
INSERT INTO "django_geo_db_location" VALUES(58057,NULL,'Meeker, OK',24523,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58058,NULL,'Meeker, OK 74855',24523,222,NULL,36,33242,0);
INSERT INTO "django_geo_db_location" VALUES(58059,NULL,'Mill Creek, OK',24524,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58060,NULL,'Mill Creek, OK 74856',24524,222,NULL,36,33243,0);
INSERT INTO "django_geo_db_location" VALUES(58061,NULL,'Newalla, OK',24525,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58062,NULL,'Newalla, OK 74857',24525,222,NULL,36,33244,0);
INSERT INTO "django_geo_db_location" VALUES(58063,NULL,'Okemah, OK',24526,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58064,NULL,'Okemah, OK 74859',24526,222,NULL,36,33245,0);
INSERT INTO "django_geo_db_location" VALUES(58065,NULL,'Paden, OK',24527,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58066,NULL,'Paden, OK 74860',24527,222,NULL,36,33246,0);
INSERT INTO "django_geo_db_location" VALUES(58067,NULL,'Prague, OK',24528,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58068,NULL,'Prague, OK 74864',24528,222,NULL,36,33247,0);
INSERT INTO "django_geo_db_location" VALUES(58069,NULL,'Roff, OK',24529,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58070,NULL,'Roff, OK 74865',24529,222,NULL,36,33248,0);
INSERT INTO "django_geo_db_location" VALUES(58071,NULL,'Saint Louis, OK',24530,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58072,NULL,'Saint Louis, OK 74866',24530,222,NULL,36,33249,0);
INSERT INTO "django_geo_db_location" VALUES(58073,NULL,'Sasakwa, OK',24531,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58074,NULL,'Sasakwa, OK 74867',24531,222,NULL,36,33250,0);
INSERT INTO "django_geo_db_location" VALUES(58075,NULL,'Seminole, OK 74868',24497,222,NULL,36,33251,0);
INSERT INTO "django_geo_db_location" VALUES(58076,NULL,'Sparks, OK',24532,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58077,NULL,'Sparks, OK 74869',24532,222,NULL,36,33252,0);
INSERT INTO "django_geo_db_location" VALUES(58078,NULL,'Stonewall, OK',24533,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58079,NULL,'Stonewall, OK 74871',24533,222,NULL,36,33253,0);
INSERT INTO "django_geo_db_location" VALUES(58080,NULL,'Stratford, OK',24534,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58081,NULL,'Stratford, OK 74872',24534,222,NULL,36,33254,0);
INSERT INTO "django_geo_db_location" VALUES(58082,NULL,'Tecumseh, OK',24535,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58083,NULL,'Tecumseh, OK 74873',24535,222,NULL,36,33255,0);
INSERT INTO "django_geo_db_location" VALUES(58084,NULL,'Tryon, OK',24536,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58085,NULL,'Tryon, OK 74875',24536,222,NULL,36,33256,0);
INSERT INTO "django_geo_db_location" VALUES(58086,NULL,'Wanette, OK',24537,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58087,NULL,'Wanette, OK 74878',24537,222,NULL,36,33257,0);
INSERT INTO "django_geo_db_location" VALUES(58088,NULL,'Weleetka, OK',24538,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58089,NULL,'Weleetka, OK 74880',24538,222,NULL,36,33258,0);
INSERT INTO "django_geo_db_location" VALUES(58090,NULL,'Wellston, OK',24539,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58091,NULL,'Wellston, OK 74881',24539,222,NULL,36,33259,0);
INSERT INTO "django_geo_db_location" VALUES(58092,NULL,'Wetumka, OK 74883',24521,222,NULL,36,33260,0);
INSERT INTO "django_geo_db_location" VALUES(58093,NULL,'Wewoka, OK',24540,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58094,NULL,'Wewoka, OK 74884',24540,222,NULL,36,33261,0);
INSERT INTO "django_geo_db_location" VALUES(58095,NULL,'Konawa, OK 74894',24517,222,NULL,36,33262,0);
INSERT INTO "django_geo_db_location" VALUES(58096,NULL,'Arkoma, OK',24541,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58097,NULL,'Arkoma, OK 74901',24541,222,NULL,36,33263,0);
INSERT INTO "django_geo_db_location" VALUES(58098,NULL,'Pocola, OK',24542,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58099,NULL,'Pocola, OK 74902',24542,222,NULL,36,33264,0);
INSERT INTO "django_geo_db_location" VALUES(58100,NULL,'Bokoshe, OK',24543,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58101,NULL,'Bokoshe, OK 74930',24543,222,NULL,36,33265,0);
INSERT INTO "django_geo_db_location" VALUES(58102,NULL,'Bunch, OK',24544,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58103,NULL,'Bunch, OK 74931',24544,222,NULL,36,33266,0);
INSERT INTO "django_geo_db_location" VALUES(58104,NULL,'Cameron, OK',24545,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58105,NULL,'Cameron, OK 74932',24545,222,NULL,36,33267,0);
INSERT INTO "django_geo_db_location" VALUES(58106,NULL,'Fanshawe, OK',24546,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58107,NULL,'Fanshawe, OK 74935',24546,222,NULL,36,33268,0);
INSERT INTO "django_geo_db_location" VALUES(58108,NULL,'Gans, OK',24547,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58109,NULL,'Gans, OK 74936',24547,222,NULL,36,33269,0);
INSERT INTO "django_geo_db_location" VALUES(58110,NULL,'Heavener, OK',24548,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58111,NULL,'Heavener, OK 74937',24548,222,NULL,36,33270,0);
INSERT INTO "django_geo_db_location" VALUES(58112,NULL,'Hodgen, OK',24549,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58113,NULL,'Hodgen, OK 74939',24549,222,NULL,36,33271,0);
INSERT INTO "django_geo_db_location" VALUES(58114,NULL,'Howe, OK',24550,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58115,NULL,'Howe, OK 74940',24550,222,NULL,36,33272,0);
INSERT INTO "django_geo_db_location" VALUES(58116,NULL,'Keota, OK',24551,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58117,NULL,'Keota, OK 74941',24551,222,NULL,36,33273,0);
INSERT INTO "django_geo_db_location" VALUES(58118,NULL,'Leflore, OK',24552,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58119,NULL,'Leflore, OK 74942',24552,222,NULL,36,33274,0);
INSERT INTO "django_geo_db_location" VALUES(58120,NULL,'Lequire, OK',24553,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58121,NULL,'Lequire, OK 74943',24553,222,NULL,36,33275,0);
INSERT INTO "django_geo_db_location" VALUES(58122,NULL,'Mccurtain, OK',24554,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58123,NULL,'Mccurtain, OK 74944',24554,222,NULL,36,33276,0);
INSERT INTO "django_geo_db_location" VALUES(58124,NULL,'Marble City, OK',24555,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58125,NULL,'Marble City, OK 74945',24555,222,NULL,36,33277,0);
INSERT INTO "django_geo_db_location" VALUES(58126,NULL,'Moffett, OK',24556,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58127,NULL,'Moffett, OK 74946',24556,222,NULL,36,33278,0);
INSERT INTO "django_geo_db_location" VALUES(58128,NULL,'Monroe, OK',24557,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58129,NULL,'Monroe, OK 74947',24557,222,NULL,36,33279,0);
INSERT INTO "django_geo_db_location" VALUES(58130,NULL,'Muldrow, OK',24558,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58131,NULL,'Muldrow, OK 74948',24558,222,NULL,36,33280,0);
INSERT INTO "django_geo_db_location" VALUES(58132,NULL,'Muse, OK',24559,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58133,NULL,'Muse, OK 74949',24559,222,NULL,36,33281,0);
INSERT INTO "django_geo_db_location" VALUES(58134,NULL,'Panama, OK',24560,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58135,NULL,'Panama, OK 74951',24560,222,NULL,36,33282,0);
INSERT INTO "django_geo_db_location" VALUES(58136,NULL,'Poteau, OK',24561,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58137,NULL,'Poteau, OK 74953',24561,222,NULL,36,33283,0);
INSERT INTO "django_geo_db_location" VALUES(58138,NULL,'Roland, OK',24562,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58139,NULL,'Roland, OK 74954',24562,222,NULL,36,33284,0);
INSERT INTO "django_geo_db_location" VALUES(58140,NULL,'Sallisaw, OK',24563,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58141,NULL,'Sallisaw, OK 74955',24563,222,NULL,36,33285,0);
INSERT INTO "django_geo_db_location" VALUES(58142,NULL,'Shady Point, OK',24564,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58143,NULL,'Shady Point, OK 74956',24564,222,NULL,36,33286,0);
INSERT INTO "django_geo_db_location" VALUES(58144,NULL,'Smithville, OK',24565,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58145,NULL,'Smithville, OK 74957',24565,222,NULL,36,33287,0);
INSERT INTO "django_geo_db_location" VALUES(58146,NULL,'Spiro, OK',24566,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58147,NULL,'Spiro, OK 74959',24566,222,NULL,36,33288,0);
INSERT INTO "django_geo_db_location" VALUES(58148,NULL,'Stilwell, OK',24567,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58149,NULL,'Stilwell, OK 74960',24567,222,NULL,36,33289,0);
INSERT INTO "django_geo_db_location" VALUES(58150,NULL,'Vian, OK',24568,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58151,NULL,'Vian, OK 74962',24568,222,NULL,36,33290,0);
INSERT INTO "django_geo_db_location" VALUES(58152,NULL,'Watson, OK',24569,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58153,NULL,'Watson, OK 74963',24569,222,NULL,36,33291,0);
INSERT INTO "django_geo_db_location" VALUES(58154,NULL,'Watts, OK',24570,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58155,NULL,'Watts, OK 74964',24570,222,NULL,36,33292,0);
INSERT INTO "django_geo_db_location" VALUES(58156,NULL,'Westville, OK',24571,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58157,NULL,'Westville, OK 74965',24571,222,NULL,36,33293,0);
INSERT INTO "django_geo_db_location" VALUES(58158,NULL,'Wister, OK',24572,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58159,NULL,'Wister, OK 74966',24572,222,NULL,36,33294,0);
INSERT INTO "django_geo_db_location" VALUES(58160,NULL,'Muldrow, OK 74968',24558,222,NULL,36,33295,0);
INSERT INTO "django_geo_db_location" VALUES(58161,NULL,'Addison, TX',24573,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58162,NULL,'Addison, TX 75001',24573,222,NULL,51,33296,0);
INSERT INTO "django_geo_db_location" VALUES(58163,NULL,'Allen, TX',24574,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58164,NULL,'Allen, TX 75002',24574,222,NULL,51,33297,0);
INSERT INTO "django_geo_db_location" VALUES(58165,NULL,'Carrollton, TX',24575,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58166,NULL,'Carrollton, TX 75006',24575,222,NULL,51,33298,0);
INSERT INTO "django_geo_db_location" VALUES(58167,NULL,'Carrollton, TX 75007',24575,222,NULL,51,33299,0);
INSERT INTO "django_geo_db_location" VALUES(58168,NULL,'Carrollton, TX 75008',24575,222,NULL,51,33300,0);
INSERT INTO "django_geo_db_location" VALUES(58169,NULL,'Celina, TX',24576,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58170,NULL,'Celina, TX 75009',24576,222,NULL,51,33301,0);
INSERT INTO "django_geo_db_location" VALUES(58171,NULL,'Carrollton, TX 75010',24575,222,NULL,51,33302,0);
INSERT INTO "django_geo_db_location" VALUES(58172,NULL,'Carrollton, TX 75011',24575,222,NULL,51,33303,0);
INSERT INTO "django_geo_db_location" VALUES(58173,NULL,'Allen, TX 75013',24574,222,NULL,51,33304,0);
INSERT INTO "django_geo_db_location" VALUES(58174,NULL,'Irving, TX',24577,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58175,NULL,'Irving, TX 75014',24577,222,NULL,51,33305,0);
INSERT INTO "django_geo_db_location" VALUES(58176,NULL,'Irving, TX 75015',24577,222,NULL,51,33306,0);
INSERT INTO "django_geo_db_location" VALUES(58177,NULL,'Irving, TX 75016',24577,222,NULL,51,33307,0);
INSERT INTO "django_geo_db_location" VALUES(58178,NULL,'Irving, TX 75017',24577,222,NULL,51,33308,0);
INSERT INTO "django_geo_db_location" VALUES(58179,NULL,'Coppell, TX',24578,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58180,NULL,'Coppell, TX 75019',24578,222,NULL,51,33309,0);
INSERT INTO "django_geo_db_location" VALUES(58181,NULL,'Denison, TX',24579,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58182,NULL,'Denison, TX 75020',24579,222,NULL,51,33310,0);
INSERT INTO "django_geo_db_location" VALUES(58183,NULL,'Denison, TX 75021',24579,222,NULL,51,33311,0);
INSERT INTO "django_geo_db_location" VALUES(58184,NULL,'Flower Mound, TX',24580,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58185,NULL,'Flower Mound, TX 75022',24580,222,NULL,51,33312,0);
INSERT INTO "django_geo_db_location" VALUES(58186,NULL,'Plano, TX',24581,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58187,NULL,'Plano, TX 75023',24581,222,NULL,51,33313,0);
INSERT INTO "django_geo_db_location" VALUES(58188,NULL,'Plano, TX 75024',24581,222,NULL,51,33314,0);
INSERT INTO "django_geo_db_location" VALUES(58189,NULL,'Plano, TX 75025',24581,222,NULL,51,33315,0);
INSERT INTO "django_geo_db_location" VALUES(58190,NULL,'Plano, TX 75026',24581,222,NULL,51,33316,0);
INSERT INTO "django_geo_db_location" VALUES(58191,NULL,'Flower Mound, TX 75027',24580,222,NULL,51,33317,0);
INSERT INTO "django_geo_db_location" VALUES(58192,NULL,'Flower Mound, TX 75028',24580,222,NULL,51,33318,0);
INSERT INTO "django_geo_db_location" VALUES(58193,NULL,'Lewisville, TX',24582,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58194,NULL,'Lewisville, TX 75029',24582,222,NULL,51,33319,0);
INSERT INTO "django_geo_db_location" VALUES(58195,NULL,'Rowlett, TX',24583,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58196,NULL,'Rowlett, TX 75030',24583,222,NULL,51,33320,0);
INSERT INTO "django_geo_db_location" VALUES(58197,NULL,'Rockwall, TX',24584,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58198,NULL,'Rockwall, TX 75032',24584,222,NULL,51,33321,0);
INSERT INTO "django_geo_db_location" VALUES(58199,NULL,'Frisco, TX',24585,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58200,NULL,'Frisco, TX 75034',24585,222,NULL,51,33322,0);
INSERT INTO "django_geo_db_location" VALUES(58201,NULL,'Frisco, TX 75035',24585,222,NULL,51,33323,0);
INSERT INTO "django_geo_db_location" VALUES(58202,NULL,'Irving, TX 75037',24577,222,NULL,51,33324,0);
INSERT INTO "django_geo_db_location" VALUES(58203,NULL,'Irving, TX 75038',24577,222,NULL,51,33325,0);
INSERT INTO "django_geo_db_location" VALUES(58204,NULL,'Irving, TX 75039',24577,222,NULL,51,33326,0);
INSERT INTO "django_geo_db_location" VALUES(58205,NULL,'Garland, TX',24586,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58206,NULL,'Garland, TX 75040',24586,222,NULL,51,33327,0);
INSERT INTO "django_geo_db_location" VALUES(58207,NULL,'Garland, TX 75041',24586,222,NULL,51,33328,0);
INSERT INTO "django_geo_db_location" VALUES(58208,NULL,'Garland, TX 75042',24586,222,NULL,51,33329,0);
INSERT INTO "django_geo_db_location" VALUES(58209,NULL,'Garland, TX 75043',24586,222,NULL,51,33330,0);
INSERT INTO "django_geo_db_location" VALUES(58210,NULL,'Garland, TX 75044',24586,222,NULL,51,33331,0);
INSERT INTO "django_geo_db_location" VALUES(58211,NULL,'Garland, TX 75045',24586,222,NULL,51,33332,0);
INSERT INTO "django_geo_db_location" VALUES(58212,NULL,'Garland, TX 75046',24586,222,NULL,51,33333,0);
INSERT INTO "django_geo_db_location" VALUES(58213,NULL,'Garland, TX 75047',24586,222,NULL,51,33334,0);
INSERT INTO "django_geo_db_location" VALUES(58214,NULL,'Garland, TX 75048',24586,222,NULL,51,33335,0);
INSERT INTO "django_geo_db_location" VALUES(58215,NULL,'Garland, TX 75049',24586,222,NULL,51,33336,0);
INSERT INTO "django_geo_db_location" VALUES(58216,NULL,'Grand Prairie, TX',24587,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58217,NULL,'Grand Prairie, TX 75050',24587,222,NULL,51,33337,0);
INSERT INTO "django_geo_db_location" VALUES(58218,NULL,'Grand Prairie, TX 75051',24587,222,NULL,51,33338,0);
INSERT INTO "django_geo_db_location" VALUES(58219,NULL,'Grand Prairie, TX 75052',24587,222,NULL,51,33339,0);
INSERT INTO "django_geo_db_location" VALUES(58220,NULL,'Grand Prairie, TX 75053',24587,222,NULL,51,33340,0);
INSERT INTO "django_geo_db_location" VALUES(58221,NULL,'Grand Prairie, TX 75054',24587,222,NULL,51,33341,0);
INSERT INTO "django_geo_db_location" VALUES(58222,NULL,'The Colony, TX',24588,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58223,NULL,'The Colony, TX 75056',24588,222,NULL,51,33342,0);
INSERT INTO "django_geo_db_location" VALUES(58224,NULL,'Lewisville, TX 75057',24582,222,NULL,51,33343,0);
INSERT INTO "django_geo_db_location" VALUES(58225,NULL,'Gunter, TX',24589,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58226,NULL,'Gunter, TX 75058',24589,222,NULL,51,33344,0);
INSERT INTO "django_geo_db_location" VALUES(58227,NULL,'Irving, TX 75059',24577,222,NULL,51,33345,0);
INSERT INTO "django_geo_db_location" VALUES(58228,NULL,'Irving, TX 75060',24577,222,NULL,51,33346,0);
INSERT INTO "django_geo_db_location" VALUES(58229,NULL,'Irving, TX 75061',24577,222,NULL,51,33347,0);
INSERT INTO "django_geo_db_location" VALUES(58230,NULL,'Irving, TX 75062',24577,222,NULL,51,33348,0);
INSERT INTO "django_geo_db_location" VALUES(58231,NULL,'Irving, TX 75063',24577,222,NULL,51,33349,0);
INSERT INTO "django_geo_db_location" VALUES(58232,NULL,'Lake Dallas, TX',24590,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58233,NULL,'Lake Dallas, TX 75065',24590,222,NULL,51,33350,0);
INSERT INTO "django_geo_db_location" VALUES(58234,NULL,'Carrollton, TX 75066',24575,222,NULL,51,33351,0);
INSERT INTO "django_geo_db_location" VALUES(58235,NULL,'Lewisville, TX 75067',24582,222,NULL,51,33352,0);
INSERT INTO "django_geo_db_location" VALUES(58236,NULL,'Little Elm, TX',24591,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58237,NULL,'Little Elm, TX 75068',24591,222,NULL,51,33353,0);
INSERT INTO "django_geo_db_location" VALUES(58238,NULL,'McKinney, TX',24592,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58239,NULL,'McKinney, TX 75069',24592,222,NULL,51,33354,0);
INSERT INTO "django_geo_db_location" VALUES(58240,NULL,'McKinney, TX 75070',24592,222,NULL,51,33355,0);
INSERT INTO "django_geo_db_location" VALUES(58241,NULL,'Frisco, TX 75071',24585,222,NULL,51,33356,0);
INSERT INTO "django_geo_db_location" VALUES(58242,NULL,'Plano, TX 75074',24581,222,NULL,51,33357,0);
INSERT INTO "django_geo_db_location" VALUES(58243,NULL,'Plano, TX 75075',24581,222,NULL,51,33358,0);
INSERT INTO "django_geo_db_location" VALUES(58244,NULL,'Pottsboro, TX',24593,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58245,NULL,'Pottsboro, TX 75076',24593,222,NULL,51,33359,0);
INSERT INTO "django_geo_db_location" VALUES(58246,NULL,'Lewisville, TX 75077',24582,222,NULL,51,33360,0);
INSERT INTO "django_geo_db_location" VALUES(58247,NULL,'Prosper, TX',24594,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58248,NULL,'Prosper, TX 75078',24594,222,NULL,51,33361,0);
INSERT INTO "django_geo_db_location" VALUES(58249,NULL,'Richardson, TX',24595,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58250,NULL,'Richardson, TX 75080',24595,222,NULL,51,33362,0);
INSERT INTO "django_geo_db_location" VALUES(58251,NULL,'Richardson, TX 75081',24595,222,NULL,51,33363,0);
INSERT INTO "django_geo_db_location" VALUES(58252,NULL,'Richardson, TX 75082',24595,222,NULL,51,33364,0);
INSERT INTO "django_geo_db_location" VALUES(58253,NULL,'Richardson, TX 75083',24595,222,NULL,51,33365,0);
INSERT INTO "django_geo_db_location" VALUES(58254,NULL,'Richardson, TX 75085',24595,222,NULL,51,33366,0);
INSERT INTO "django_geo_db_location" VALUES(58255,NULL,'Plano, TX 75086',24581,222,NULL,51,33367,0);
INSERT INTO "django_geo_db_location" VALUES(58256,NULL,'Rockwall, TX 75087',24584,222,NULL,51,33368,0);
INSERT INTO "django_geo_db_location" VALUES(58257,NULL,'Rowlett, TX 75088',24583,222,NULL,51,33369,0);
INSERT INTO "django_geo_db_location" VALUES(58258,NULL,'Rowlett, TX 75089',24583,222,NULL,51,33370,0);
INSERT INTO "django_geo_db_location" VALUES(58259,NULL,'Sherman, TX',24596,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58260,NULL,'Sherman, TX 75090',24596,222,NULL,51,33371,0);
INSERT INTO "django_geo_db_location" VALUES(58261,NULL,'Sherman, TX 75091',24596,222,NULL,51,33372,0);
INSERT INTO "django_geo_db_location" VALUES(58262,NULL,'Sherman, TX 75092',24596,222,NULL,51,33373,0);
INSERT INTO "django_geo_db_location" VALUES(58263,NULL,'Plano, TX 75093',24581,222,NULL,51,33374,0);
INSERT INTO "django_geo_db_location" VALUES(58264,NULL,'Plano, TX 75094',24581,222,NULL,51,33375,0);
INSERT INTO "django_geo_db_location" VALUES(58265,NULL,'Weston, TX',24597,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58266,NULL,'Weston, TX 75097',24597,222,NULL,51,33376,0);
INSERT INTO "django_geo_db_location" VALUES(58267,NULL,'Wylie, TX',24598,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58268,NULL,'Wylie, TX 75098',24598,222,NULL,51,33377,0);
INSERT INTO "django_geo_db_location" VALUES(58269,NULL,'Coppell, TX 75099',24578,222,NULL,51,33378,0);
INSERT INTO "django_geo_db_location" VALUES(58270,NULL,'Bardwell, TX',24599,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58271,NULL,'Bardwell, TX 75101',24599,222,NULL,51,33379,0);
INSERT INTO "django_geo_db_location" VALUES(58272,NULL,'Barry, TX',24600,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58273,NULL,'Barry, TX 75102',24600,222,NULL,51,33380,0);
INSERT INTO "django_geo_db_location" VALUES(58274,NULL,'Canton, TX',24601,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58275,NULL,'Canton, TX 75103',24601,222,NULL,51,33381,0);
INSERT INTO "django_geo_db_location" VALUES(58276,NULL,'Cedar Hill, TX',24602,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58277,NULL,'Cedar Hill, TX 75104',24602,222,NULL,51,33382,0);
INSERT INTO "django_geo_db_location" VALUES(58278,NULL,'Chatfield, TX',24603,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58279,NULL,'Chatfield, TX 75105',24603,222,NULL,51,33383,0);
INSERT INTO "django_geo_db_location" VALUES(58280,NULL,'Cedar Hill, TX 75106',24602,222,NULL,51,33384,0);
INSERT INTO "django_geo_db_location" VALUES(58281,NULL,'Angus, TX',24604,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58282,NULL,'Angus, TX 75109',24604,222,NULL,51,33385,0);
INSERT INTO "django_geo_db_location" VALUES(58283,NULL,'Corsicana, TX',24605,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58284,NULL,'Corsicana, TX 75110',24605,222,NULL,51,33386,0);
INSERT INTO "django_geo_db_location" VALUES(58285,NULL,'Crandall, TX',24606,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58286,NULL,'Crandall, TX 75114',24606,222,NULL,51,33387,0);
INSERT INTO "django_geo_db_location" VALUES(58287,NULL,'Desoto, TX',24607,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58288,NULL,'Desoto, TX 75115',24607,222,NULL,51,33388,0);
INSERT INTO "django_geo_db_location" VALUES(58289,NULL,'Duncanville, TX',24608,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58290,NULL,'Duncanville, TX 75116',24608,222,NULL,51,33389,0);
INSERT INTO "django_geo_db_location" VALUES(58291,NULL,'Edgewood, TX',24609,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58292,NULL,'Edgewood, TX 75117',24609,222,NULL,51,33390,0);
INSERT INTO "django_geo_db_location" VALUES(58293,NULL,'Elmo, TX',24610,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58294,NULL,'Elmo, TX 75118',24610,222,NULL,51,33391,0);
INSERT INTO "django_geo_db_location" VALUES(58295,NULL,'Ennis, TX',24611,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58296,NULL,'Ennis, TX 75119',24611,222,NULL,51,33392,0);
INSERT INTO "django_geo_db_location" VALUES(58297,NULL,'Ennis, TX 75120',24611,222,NULL,51,33393,0);
INSERT INTO "django_geo_db_location" VALUES(58298,NULL,'Copeville, TX',24612,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58299,NULL,'Copeville, TX 75121',24612,222,NULL,51,33394,0);
INSERT INTO "django_geo_db_location" VALUES(58300,NULL,'Desoto, TX 75123',24607,222,NULL,51,33395,0);
INSERT INTO "django_geo_db_location" VALUES(58301,NULL,'Eustace, TX',24613,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58302,NULL,'Eustace, TX 75124',24613,222,NULL,51,33396,0);
INSERT INTO "django_geo_db_location" VALUES(58303,NULL,'Ferris, TX',24614,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58304,NULL,'Ferris, TX 75125',24614,222,NULL,51,33397,0);
INSERT INTO "django_geo_db_location" VALUES(58305,NULL,'Forney, TX',24615,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58306,NULL,'Forney, TX 75126',24615,222,NULL,51,33398,0);
INSERT INTO "django_geo_db_location" VALUES(58307,NULL,'Fruitvale, TX',24616,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58308,NULL,'Fruitvale, TX 75127',24616,222,NULL,51,33399,0);
INSERT INTO "django_geo_db_location" VALUES(58309,NULL,'Fate, TX',24617,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58310,NULL,'Fate, TX 75132',24617,222,NULL,51,33400,0);
INSERT INTO "django_geo_db_location" VALUES(58311,NULL,'Lancaster, TX',24618,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58312,NULL,'Lancaster, TX 75134',24618,222,NULL,51,33401,0);
INSERT INTO "django_geo_db_location" VALUES(58313,NULL,'Caddo Mills, TX',24619,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58314,NULL,'Caddo Mills, TX 75135',24619,222,NULL,51,33402,0);
INSERT INTO "django_geo_db_location" VALUES(58315,NULL,'Duncanville, TX 75137',24608,222,NULL,51,33403,0);
INSERT INTO "django_geo_db_location" VALUES(58316,NULL,'Duncanville, TX 75138',24608,222,NULL,51,33404,0);
INSERT INTO "django_geo_db_location" VALUES(58317,NULL,'Grand Saline, TX',24620,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58318,NULL,'Grand Saline, TX 75140',24620,222,NULL,51,33405,0);
INSERT INTO "django_geo_db_location" VALUES(58319,NULL,'Hutchins, TX',24621,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58320,NULL,'Hutchins, TX 75141',24621,222,NULL,51,33406,0);
INSERT INTO "django_geo_db_location" VALUES(58321,NULL,'Kaufman, TX',24622,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58322,NULL,'Kaufman, TX 75142',24622,222,NULL,51,33407,0);
INSERT INTO "django_geo_db_location" VALUES(58323,NULL,'Kemp, TX',24623,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58324,NULL,'Kemp, TX 75143',24623,222,NULL,51,33408,0);
INSERT INTO "django_geo_db_location" VALUES(58325,NULL,'Kerens, TX',24624,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58326,NULL,'Kerens, TX 75144',24624,222,NULL,51,33409,0);
INSERT INTO "django_geo_db_location" VALUES(58327,NULL,'Lancaster, TX 75146',24618,222,NULL,51,33410,0);
INSERT INTO "django_geo_db_location" VALUES(58328,NULL,'Mabank, TX',24625,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58329,NULL,'Mabank, TX 75147',24625,222,NULL,51,33411,0);
INSERT INTO "django_geo_db_location" VALUES(58330,NULL,'Malakoff, TX',24626,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58331,NULL,'Malakoff, TX 75148',24626,222,NULL,51,33412,0);
INSERT INTO "django_geo_db_location" VALUES(58332,NULL,'Mesquite, TX',24627,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58333,NULL,'Mesquite, TX 75149',24627,222,NULL,51,33413,0);
INSERT INTO "django_geo_db_location" VALUES(58334,NULL,'Mesquite, TX 75150',24627,222,NULL,51,33414,0);
INSERT INTO "django_geo_db_location" VALUES(58335,NULL,'Corsicana, TX 75151',24605,222,NULL,51,33415,0);
INSERT INTO "django_geo_db_location" VALUES(58336,NULL,'Palmer, TX',24628,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58337,NULL,'Palmer, TX 75152',24628,222,NULL,51,33416,0);
INSERT INTO "django_geo_db_location" VALUES(58338,NULL,'Powell, TX',24629,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58339,NULL,'Powell, TX 75153',24629,222,NULL,51,33417,0);
INSERT INTO "django_geo_db_location" VALUES(58340,NULL,'Red Oak, TX',24630,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58341,NULL,'Red Oak, TX 75154',24630,222,NULL,51,33418,0);
INSERT INTO "django_geo_db_location" VALUES(58342,NULL,'Rice, TX',24631,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58343,NULL,'Rice, TX 75155',24631,222,NULL,51,33419,0);
INSERT INTO "django_geo_db_location" VALUES(58344,NULL,'Gun Barrel City, TX',24632,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58345,NULL,'Gun Barrel City, TX 75156',24632,222,NULL,51,33420,0);
INSERT INTO "django_geo_db_location" VALUES(58346,NULL,'Rosser, TX',24633,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58347,NULL,'Rosser, TX 75157',24633,222,NULL,51,33421,0);
INSERT INTO "django_geo_db_location" VALUES(58348,NULL,'Scurry, TX',24634,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58349,NULL,'Scurry, TX 75158',24634,222,NULL,51,33422,0);
INSERT INTO "django_geo_db_location" VALUES(58350,NULL,'Seagoville, TX',24635,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58351,NULL,'Seagoville, TX 75159',24635,222,NULL,51,33423,0);
INSERT INTO "django_geo_db_location" VALUES(58352,NULL,'Terrell, TX',24636,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58353,NULL,'Terrell, TX 75160',24636,222,NULL,51,33424,0);
INSERT INTO "django_geo_db_location" VALUES(58354,NULL,'Terrell, TX 75161',24636,222,NULL,51,33425,0);
INSERT INTO "django_geo_db_location" VALUES(58355,NULL,'Trinidad, TX',24637,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58356,NULL,'Trinidad, TX 75163',24637,222,NULL,51,33426,0);
INSERT INTO "django_geo_db_location" VALUES(58357,NULL,'Josephine, TX',24638,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58358,NULL,'Josephine, TX 75164',24638,222,NULL,51,33427,0);
INSERT INTO "django_geo_db_location" VALUES(58359,NULL,'Waxahachie, TX',24639,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58360,NULL,'Waxahachie, TX 75165',24639,222,NULL,51,33428,0);
INSERT INTO "django_geo_db_location" VALUES(58361,NULL,'Lavon, TX',24640,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58362,NULL,'Lavon, TX 75166',24640,222,NULL,51,33429,0);
INSERT INTO "django_geo_db_location" VALUES(58363,NULL,'Waxahachie, TX 75167',24639,222,NULL,51,33430,0);
INSERT INTO "django_geo_db_location" VALUES(58364,NULL,'Waxahachie, TX 75168',24639,222,NULL,51,33431,0);
INSERT INTO "django_geo_db_location" VALUES(58365,NULL,'Wills Point, TX',24641,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58366,NULL,'Wills Point, TX 75169',24641,222,NULL,51,33432,0);
INSERT INTO "django_geo_db_location" VALUES(58367,NULL,'Wilmer, TX',24642,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58368,NULL,'Wilmer, TX 75172',24642,222,NULL,51,33433,0);
INSERT INTO "django_geo_db_location" VALUES(58369,NULL,'Nevada, TX',24643,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58370,NULL,'Nevada, TX 75173',24643,222,NULL,51,33434,0);
INSERT INTO "django_geo_db_location" VALUES(58371,NULL,'Mesquite, TX 75180',24627,222,NULL,51,33435,0);
INSERT INTO "django_geo_db_location" VALUES(58372,NULL,'Mesquite, TX 75181',24627,222,NULL,51,33436,0);
INSERT INTO "django_geo_db_location" VALUES(58373,NULL,'Sunnyvale, TX',24644,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58374,NULL,'Sunnyvale, TX 75182',24644,222,NULL,51,33437,0);
INSERT INTO "django_geo_db_location" VALUES(58375,NULL,'Mesquite, TX 75185',24627,222,NULL,51,33438,0);
INSERT INTO "django_geo_db_location" VALUES(58376,NULL,'Mesquite, TX 75187',24627,222,NULL,51,33439,0);
INSERT INTO "django_geo_db_location" VALUES(58377,NULL,'Royse City, TX',24645,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58378,NULL,'Royse City, TX 75189',24645,222,NULL,51,33440,0);
INSERT INTO "django_geo_db_location" VALUES(58379,NULL,'Dallas, TX',24646,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58380,NULL,'Dallas, TX 75201',24646,222,NULL,51,33441,0);
INSERT INTO "django_geo_db_location" VALUES(58381,NULL,'Dallas, TX 75202',24646,222,NULL,51,33442,0);
INSERT INTO "django_geo_db_location" VALUES(58382,NULL,'Dallas, TX 75203',24646,222,NULL,51,33443,0);
INSERT INTO "django_geo_db_location" VALUES(58383,NULL,'Dallas, TX 75204',24646,222,NULL,51,33444,0);
INSERT INTO "django_geo_db_location" VALUES(58384,NULL,'Dallas, TX 75205',24646,222,NULL,51,33445,0);
INSERT INTO "django_geo_db_location" VALUES(58385,NULL,'Dallas, TX 75206',24646,222,NULL,51,33446,0);
INSERT INTO "django_geo_db_location" VALUES(58386,NULL,'Dallas, TX 75207',24646,222,NULL,51,33447,0);
INSERT INTO "django_geo_db_location" VALUES(58387,NULL,'Dallas, TX 75208',24646,222,NULL,51,33448,0);
INSERT INTO "django_geo_db_location" VALUES(58388,NULL,'Dallas, TX 75209',24646,222,NULL,51,33449,0);
INSERT INTO "django_geo_db_location" VALUES(58389,NULL,'Dallas, TX 75210',24646,222,NULL,51,33450,0);
INSERT INTO "django_geo_db_location" VALUES(58390,NULL,'Dallas, TX 75211',24646,222,NULL,51,33451,0);
INSERT INTO "django_geo_db_location" VALUES(58391,NULL,'Dallas, TX 75212',24646,222,NULL,51,33452,0);
INSERT INTO "django_geo_db_location" VALUES(58392,NULL,'Dallas, TX 75214',24646,222,NULL,51,33453,0);
INSERT INTO "django_geo_db_location" VALUES(58393,NULL,'Dallas, TX 75215',24646,222,NULL,51,33454,0);
INSERT INTO "django_geo_db_location" VALUES(58394,NULL,'Dallas, TX 75216',24646,222,NULL,51,33455,0);
INSERT INTO "django_geo_db_location" VALUES(58395,NULL,'Dallas, TX 75217',24646,222,NULL,51,33456,0);
INSERT INTO "django_geo_db_location" VALUES(58396,NULL,'Dallas, TX 75218',24646,222,NULL,51,33457,0);
INSERT INTO "django_geo_db_location" VALUES(58397,NULL,'Dallas, TX 75219',24646,222,NULL,51,33458,0);
INSERT INTO "django_geo_db_location" VALUES(58398,NULL,'Dallas, TX 75220',24646,222,NULL,51,33459,0);
INSERT INTO "django_geo_db_location" VALUES(58399,NULL,'Dallas, TX 75221',24646,222,NULL,51,33460,0);
INSERT INTO "django_geo_db_location" VALUES(58400,NULL,'Dallas, TX 75222',24646,222,NULL,51,33461,0);
INSERT INTO "django_geo_db_location" VALUES(58401,NULL,'Dallas, TX 75223',24646,222,NULL,51,33462,0);
INSERT INTO "django_geo_db_location" VALUES(58402,NULL,'Dallas, TX 75224',24646,222,NULL,51,33463,0);
INSERT INTO "django_geo_db_location" VALUES(58403,NULL,'Dallas, TX 75225',24646,222,NULL,51,33464,0);
INSERT INTO "django_geo_db_location" VALUES(58404,NULL,'Dallas, TX 75226',24646,222,NULL,51,33465,0);
INSERT INTO "django_geo_db_location" VALUES(58405,NULL,'Dallas, TX 75227',24646,222,NULL,51,33466,0);
INSERT INTO "django_geo_db_location" VALUES(58406,NULL,'Dallas, TX 75228',24646,222,NULL,51,33467,0);
INSERT INTO "django_geo_db_location" VALUES(58407,NULL,'Dallas, TX 75229',24646,222,NULL,51,33468,0);
INSERT INTO "django_geo_db_location" VALUES(58408,NULL,'Dallas, TX 75230',24646,222,NULL,51,33469,0);
INSERT INTO "django_geo_db_location" VALUES(58409,NULL,'Dallas, TX 75231',24646,222,NULL,51,33470,0);
INSERT INTO "django_geo_db_location" VALUES(58410,NULL,'Dallas, TX 75232',24646,222,NULL,51,33471,0);
INSERT INTO "django_geo_db_location" VALUES(58411,NULL,'Dallas, TX 75233',24646,222,NULL,51,33472,0);
INSERT INTO "django_geo_db_location" VALUES(58412,NULL,'Dallas, TX 75234',24646,222,NULL,51,33473,0);
INSERT INTO "django_geo_db_location" VALUES(58413,NULL,'Dallas, TX 75235',24646,222,NULL,51,33474,0);
INSERT INTO "django_geo_db_location" VALUES(58414,NULL,'Dallas, TX 75236',24646,222,NULL,51,33475,0);
INSERT INTO "django_geo_db_location" VALUES(58415,NULL,'Dallas, TX 75237',24646,222,NULL,51,33476,0);
INSERT INTO "django_geo_db_location" VALUES(58416,NULL,'Dallas, TX 75238',24646,222,NULL,51,33477,0);
INSERT INTO "django_geo_db_location" VALUES(58417,NULL,'Dallas, TX 75239',24646,222,NULL,51,33478,0);
INSERT INTO "django_geo_db_location" VALUES(58418,NULL,'Dallas, TX 75240',24646,222,NULL,51,33479,0);
INSERT INTO "django_geo_db_location" VALUES(58419,NULL,'Dallas, TX 75241',24646,222,NULL,51,33480,0);
INSERT INTO "django_geo_db_location" VALUES(58420,NULL,'Dallas, TX 75242',24646,222,NULL,51,33481,0);
INSERT INTO "django_geo_db_location" VALUES(58421,NULL,'Dallas, TX 75243',24646,222,NULL,51,33482,0);
INSERT INTO "django_geo_db_location" VALUES(58422,NULL,'Dallas, TX 75244',24646,222,NULL,51,33483,0);
INSERT INTO "django_geo_db_location" VALUES(58423,NULL,'Dallas, TX 75245',24646,222,NULL,51,33484,0);
INSERT INTO "django_geo_db_location" VALUES(58424,NULL,'Dallas, TX 75246',24646,222,NULL,51,33485,0);
INSERT INTO "django_geo_db_location" VALUES(58425,NULL,'Dallas, TX 75247',24646,222,NULL,51,33486,0);
INSERT INTO "django_geo_db_location" VALUES(58426,NULL,'Dallas, TX 75248',24646,222,NULL,51,33487,0);
INSERT INTO "django_geo_db_location" VALUES(58427,NULL,'Dallas, TX 75249',24646,222,NULL,51,33488,0);
INSERT INTO "django_geo_db_location" VALUES(58428,NULL,'Dallas, TX 75250',24646,222,NULL,51,33489,0);
INSERT INTO "django_geo_db_location" VALUES(58429,NULL,'Dallas, TX 75251',24646,222,NULL,51,33490,0);
INSERT INTO "django_geo_db_location" VALUES(58430,NULL,'Dallas, TX 75252',24646,222,NULL,51,33491,0);
INSERT INTO "django_geo_db_location" VALUES(58431,NULL,'Dallas, TX 75253',24646,222,NULL,51,33492,0);
INSERT INTO "django_geo_db_location" VALUES(58432,NULL,'Dallas, TX 75254',24646,222,NULL,51,33493,0);
INSERT INTO "django_geo_db_location" VALUES(58433,NULL,'Dallas, TX 75255',24646,222,NULL,51,33494,0);
INSERT INTO "django_geo_db_location" VALUES(58434,NULL,'Dallas, TX 75258',24646,222,NULL,51,33495,0);
INSERT INTO "django_geo_db_location" VALUES(58435,NULL,'Dallas, TX 75260',24646,222,NULL,51,33496,0);
INSERT INTO "django_geo_db_location" VALUES(58436,NULL,'Dallas, TX 75261',24646,222,NULL,51,33497,0);
INSERT INTO "django_geo_db_location" VALUES(58437,NULL,'Dallas, TX 75262',24646,222,NULL,51,33498,0);
INSERT INTO "django_geo_db_location" VALUES(58438,NULL,'Dallas, TX 75263',24646,222,NULL,51,33499,0);
INSERT INTO "django_geo_db_location" VALUES(58439,NULL,'Dallas, TX 75264',24646,222,NULL,51,33500,0);
INSERT INTO "django_geo_db_location" VALUES(58440,NULL,'Dallas, TX 75265',24646,222,NULL,51,33501,0);
INSERT INTO "django_geo_db_location" VALUES(58441,NULL,'Dallas, TX 75266',24646,222,NULL,51,33502,0);
INSERT INTO "django_geo_db_location" VALUES(58442,NULL,'Dallas, TX 75267',24646,222,NULL,51,33503,0);
INSERT INTO "django_geo_db_location" VALUES(58443,NULL,'Dallas, TX 75270',24646,222,NULL,51,33504,0);
INSERT INTO "django_geo_db_location" VALUES(58444,NULL,'Dallas, TX 75275',24646,222,NULL,51,33505,0);
INSERT INTO "django_geo_db_location" VALUES(58445,NULL,'Dallas, TX 75277',24646,222,NULL,51,33506,0);
INSERT INTO "django_geo_db_location" VALUES(58446,NULL,'Dallas, TX 75283',24646,222,NULL,51,33507,0);
INSERT INTO "django_geo_db_location" VALUES(58447,NULL,'Dallas, TX 75284',24646,222,NULL,51,33508,0);
INSERT INTO "django_geo_db_location" VALUES(58448,NULL,'Dallas, TX 75285',24646,222,NULL,51,33509,0);
INSERT INTO "django_geo_db_location" VALUES(58449,NULL,'Dallas, TX 75286',24646,222,NULL,51,33510,0);
INSERT INTO "django_geo_db_location" VALUES(58450,NULL,'Dallas, TX 75287',24646,222,NULL,51,33511,0);
INSERT INTO "django_geo_db_location" VALUES(58451,NULL,'Dallas, TX 75294',24646,222,NULL,51,33512,0);
INSERT INTO "django_geo_db_location" VALUES(58452,NULL,'Dallas, TX 75295',24646,222,NULL,51,33513,0);
INSERT INTO "django_geo_db_location" VALUES(58453,NULL,'Dallas, TX 75301',24646,222,NULL,51,33514,0);
INSERT INTO "django_geo_db_location" VALUES(58454,NULL,'Dallas, TX 75303',24646,222,NULL,51,33515,0);
INSERT INTO "django_geo_db_location" VALUES(58455,NULL,'Dallas, TX 75310',24646,222,NULL,51,33516,0);
INSERT INTO "django_geo_db_location" VALUES(58456,NULL,'Dallas, TX 75312',24646,222,NULL,51,33517,0);
INSERT INTO "django_geo_db_location" VALUES(58457,NULL,'Dallas, TX 75313',24646,222,NULL,51,33518,0);
INSERT INTO "django_geo_db_location" VALUES(58458,NULL,'Dallas, TX 75315',24646,222,NULL,51,33519,0);
INSERT INTO "django_geo_db_location" VALUES(58459,NULL,'Dallas, TX 75320',24646,222,NULL,51,33520,0);
INSERT INTO "django_geo_db_location" VALUES(58460,NULL,'Dallas, TX 75323',24646,222,NULL,51,33521,0);
INSERT INTO "django_geo_db_location" VALUES(58461,NULL,'Dallas, TX 75326',24646,222,NULL,51,33522,0);
INSERT INTO "django_geo_db_location" VALUES(58462,NULL,'Dallas, TX 75336',24646,222,NULL,51,33523,0);
INSERT INTO "django_geo_db_location" VALUES(58463,NULL,'Dallas, TX 75339',24646,222,NULL,51,33524,0);
INSERT INTO "django_geo_db_location" VALUES(58464,NULL,'Dallas, TX 75342',24646,222,NULL,51,33525,0);
INSERT INTO "django_geo_db_location" VALUES(58465,NULL,'Dallas, TX 75346',24646,222,NULL,51,33526,0);
INSERT INTO "django_geo_db_location" VALUES(58466,NULL,'Dallas, TX 75350',24646,222,NULL,51,33527,0);
INSERT INTO "django_geo_db_location" VALUES(58467,NULL,'Dallas, TX 75353',24646,222,NULL,51,33528,0);
INSERT INTO "django_geo_db_location" VALUES(58468,NULL,'Dallas, TX 75354',24646,222,NULL,51,33529,0);
INSERT INTO "django_geo_db_location" VALUES(58469,NULL,'Dallas, TX 75355',24646,222,NULL,51,33530,0);
INSERT INTO "django_geo_db_location" VALUES(58470,NULL,'Dallas, TX 75356',24646,222,NULL,51,33531,0);
INSERT INTO "django_geo_db_location" VALUES(58471,NULL,'Dallas, TX 75357',24646,222,NULL,51,33532,0);
INSERT INTO "django_geo_db_location" VALUES(58472,NULL,'Dallas, TX 75359',24646,222,NULL,51,33533,0);
INSERT INTO "django_geo_db_location" VALUES(58473,NULL,'Dallas, TX 75360',24646,222,NULL,51,33534,0);
INSERT INTO "django_geo_db_location" VALUES(58474,NULL,'Dallas, TX 75363',24646,222,NULL,51,33535,0);
INSERT INTO "django_geo_db_location" VALUES(58475,NULL,'Dallas, TX 75364',24646,222,NULL,51,33536,0);
INSERT INTO "django_geo_db_location" VALUES(58476,NULL,'Dallas, TX 75367',24646,222,NULL,51,33537,0);
INSERT INTO "django_geo_db_location" VALUES(58477,NULL,'Dallas, TX 75368',24646,222,NULL,51,33538,0);
INSERT INTO "django_geo_db_location" VALUES(58478,NULL,'Dallas, TX 75370',24646,222,NULL,51,33539,0);
INSERT INTO "django_geo_db_location" VALUES(58479,NULL,'Dallas, TX 75371',24646,222,NULL,51,33540,0);
INSERT INTO "django_geo_db_location" VALUES(58480,NULL,'Dallas, TX 75372',24646,222,NULL,51,33541,0);
INSERT INTO "django_geo_db_location" VALUES(58481,NULL,'Dallas, TX 75373',24646,222,NULL,51,33542,0);
INSERT INTO "django_geo_db_location" VALUES(58482,NULL,'Dallas, TX 75374',24646,222,NULL,51,33543,0);
INSERT INTO "django_geo_db_location" VALUES(58483,NULL,'Dallas, TX 75376',24646,222,NULL,51,33544,0);
INSERT INTO "django_geo_db_location" VALUES(58484,NULL,'Dallas, TX 75378',24646,222,NULL,51,33545,0);
INSERT INTO "django_geo_db_location" VALUES(58485,NULL,'Dallas, TX 75379',24646,222,NULL,51,33546,0);
INSERT INTO "django_geo_db_location" VALUES(58486,NULL,'Dallas, TX 75380',24646,222,NULL,51,33547,0);
INSERT INTO "django_geo_db_location" VALUES(58487,NULL,'Dallas, TX 75381',24646,222,NULL,51,33548,0);
INSERT INTO "django_geo_db_location" VALUES(58488,NULL,'Dallas, TX 75382',24646,222,NULL,51,33549,0);
INSERT INTO "django_geo_db_location" VALUES(58489,NULL,'Dallas, TX 75386',24646,222,NULL,51,33550,0);
INSERT INTO "django_geo_db_location" VALUES(58490,NULL,'Dallas, TX 75387',24646,222,NULL,51,33551,0);
INSERT INTO "django_geo_db_location" VALUES(58491,NULL,'Dallas, TX 75388',24646,222,NULL,51,33552,0);
INSERT INTO "django_geo_db_location" VALUES(58492,NULL,'Dallas, TX 75389',24646,222,NULL,51,33553,0);
INSERT INTO "django_geo_db_location" VALUES(58493,NULL,'Dallas, TX 75390',24646,222,NULL,51,33554,0);
INSERT INTO "django_geo_db_location" VALUES(58494,NULL,'Dallas, TX 75391',24646,222,NULL,51,33555,0);
INSERT INTO "django_geo_db_location" VALUES(58495,NULL,'Dallas, TX 75392',24646,222,NULL,51,33556,0);
INSERT INTO "django_geo_db_location" VALUES(58496,NULL,'Dallas, TX 75393',24646,222,NULL,51,33557,0);
INSERT INTO "django_geo_db_location" VALUES(58497,NULL,'Dallas, TX 75394',24646,222,NULL,51,33558,0);
INSERT INTO "django_geo_db_location" VALUES(58498,NULL,'Dallas, TX 75395',24646,222,NULL,51,33559,0);
INSERT INTO "django_geo_db_location" VALUES(58499,NULL,'Dallas, TX 75396',24646,222,NULL,51,33560,0);
INSERT INTO "django_geo_db_location" VALUES(58500,NULL,'Dallas, TX 75397',24646,222,NULL,51,33561,0);
INSERT INTO "django_geo_db_location" VALUES(58501,NULL,'Dallas, TX 75398',24646,222,NULL,51,33562,0);
INSERT INTO "django_geo_db_location" VALUES(58502,NULL,'Greenville, TX',24647,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58503,NULL,'Greenville, TX 75401',24647,222,NULL,51,33563,0);
INSERT INTO "django_geo_db_location" VALUES(58504,NULL,'Greenville, TX 75402',24647,222,NULL,51,33564,0);
INSERT INTO "django_geo_db_location" VALUES(58505,NULL,'Greenville, TX 75403',24647,222,NULL,51,33565,0);
INSERT INTO "django_geo_db_location" VALUES(58506,NULL,'Greenville, TX 75404',24647,222,NULL,51,33566,0);
INSERT INTO "django_geo_db_location" VALUES(58507,NULL,'Princeton, TX',24648,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58508,NULL,'Princeton, TX 75407',24648,222,NULL,51,33567,0);
INSERT INTO "django_geo_db_location" VALUES(58509,NULL,'Anna, TX',24649,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58510,NULL,'Anna, TX 75408',24649,222,NULL,51,33568,0);
INSERT INTO "django_geo_db_location" VALUES(58511,NULL,'Anna, TX 75409',24649,222,NULL,51,33569,0);
INSERT INTO "django_geo_db_location" VALUES(58512,NULL,'Alba, TX',24650,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58513,NULL,'Alba, TX 75410',24650,222,NULL,51,33570,0);
INSERT INTO "django_geo_db_location" VALUES(58514,NULL,'Arthur City, TX',24651,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58515,NULL,'Arthur City, TX 75411',24651,222,NULL,51,33571,0);
INSERT INTO "django_geo_db_location" VALUES(58516,NULL,'Bagwell, TX',24652,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58517,NULL,'Bagwell, TX 75412',24652,222,NULL,51,33572,0);
INSERT INTO "django_geo_db_location" VALUES(58518,NULL,'Bailey, TX',24653,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58519,NULL,'Bailey, TX 75413',24653,222,NULL,51,33573,0);
INSERT INTO "django_geo_db_location" VALUES(58520,NULL,'Bells, TX',24654,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58521,NULL,'Bells, TX 75414',24654,222,NULL,51,33574,0);
INSERT INTO "django_geo_db_location" VALUES(58522,NULL,'Ben Franklin, TX',24655,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58523,NULL,'Ben Franklin, TX 75415',24655,222,NULL,51,33575,0);
INSERT INTO "django_geo_db_location" VALUES(58524,NULL,'Blossom, TX',24656,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58525,NULL,'Blossom, TX 75416',24656,222,NULL,51,33576,0);
INSERT INTO "django_geo_db_location" VALUES(58526,NULL,'Bogata, TX',24657,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58527,NULL,'Bogata, TX 75417',24657,222,NULL,51,33577,0);
INSERT INTO "django_geo_db_location" VALUES(58528,NULL,'Bonham, TX',24658,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58529,NULL,'Bonham, TX 75418',24658,222,NULL,51,33578,0);
INSERT INTO "django_geo_db_location" VALUES(58530,NULL,'Brashear, TX',24659,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58531,NULL,'Brashear, TX 75420',24659,222,NULL,51,33579,0);
INSERT INTO "django_geo_db_location" VALUES(58532,NULL,'Brookston, TX',24660,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58533,NULL,'Brookston, TX 75421',24660,222,NULL,51,33580,0);
INSERT INTO "django_geo_db_location" VALUES(58534,NULL,'Campbell, TX',24661,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58535,NULL,'Campbell, TX 75422',24661,222,NULL,51,33581,0);
INSERT INTO "django_geo_db_location" VALUES(58536,NULL,'Celeste, TX',24662,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58537,NULL,'Celeste, TX 75423',24662,222,NULL,51,33582,0);
INSERT INTO "django_geo_db_location" VALUES(58538,NULL,'Blue Ridge, TX',24663,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58539,NULL,'Blue Ridge, TX 75424',24663,222,NULL,51,33583,0);
INSERT INTO "django_geo_db_location" VALUES(58540,NULL,'Chicota, TX',24664,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58541,NULL,'Chicota, TX 75425',24664,222,NULL,51,33584,0);
INSERT INTO "django_geo_db_location" VALUES(58542,NULL,'Clarksville, TX',24665,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58543,NULL,'Clarksville, TX 75426',24665,222,NULL,51,33585,0);
INSERT INTO "django_geo_db_location" VALUES(58544,NULL,'Commerce, TX',24666,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58545,NULL,'Commerce, TX 75428',24666,222,NULL,51,33586,0);
INSERT INTO "django_geo_db_location" VALUES(58546,NULL,'Commerce, TX 75429',24666,222,NULL,51,33587,0);
INSERT INTO "django_geo_db_location" VALUES(58547,NULL,'Como, TX',24667,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58548,NULL,'Como, TX 75431',24667,222,NULL,51,33588,0);
INSERT INTO "django_geo_db_location" VALUES(58549,NULL,'Cooper, TX',24668,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58550,NULL,'Cooper, TX 75432',24668,222,NULL,51,33589,0);
INSERT INTO "django_geo_db_location" VALUES(58551,NULL,'Cumby, TX',24669,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58552,NULL,'Cumby, TX 75433',24669,222,NULL,51,33590,0);
INSERT INTO "django_geo_db_location" VALUES(58553,NULL,'Cunningham, TX',24670,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58554,NULL,'Cunningham, TX 75434',24670,222,NULL,51,33591,0);
INSERT INTO "django_geo_db_location" VALUES(58555,NULL,'Deport, TX',24671,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58556,NULL,'Deport, TX 75435',24671,222,NULL,51,33592,0);
INSERT INTO "django_geo_db_location" VALUES(58557,NULL,'Detroit, TX',24672,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58558,NULL,'Detroit, TX 75436',24672,222,NULL,51,33593,0);
INSERT INTO "django_geo_db_location" VALUES(58559,NULL,'Dike, TX',24673,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58560,NULL,'Dike, TX 75437',24673,222,NULL,51,33594,0);
INSERT INTO "django_geo_db_location" VALUES(58561,NULL,'Dodd City, TX',24674,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58562,NULL,'Dodd City, TX 75438',24674,222,NULL,51,33595,0);
INSERT INTO "django_geo_db_location" VALUES(58563,NULL,'Ector, TX',24675,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58564,NULL,'Ector, TX 75439',24675,222,NULL,51,33596,0);
INSERT INTO "django_geo_db_location" VALUES(58565,NULL,'Emory, TX',24676,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58566,NULL,'Emory, TX 75440',24676,222,NULL,51,33597,0);
INSERT INTO "django_geo_db_location" VALUES(58567,NULL,'Enloe, TX',24677,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58568,NULL,'Enloe, TX 75441',24677,222,NULL,51,33598,0);
INSERT INTO "django_geo_db_location" VALUES(58569,NULL,'Farmersville, TX',24678,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58570,NULL,'Farmersville, TX 75442',24678,222,NULL,51,33599,0);
INSERT INTO "django_geo_db_location" VALUES(58571,NULL,'Gober, TX',24679,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58572,NULL,'Gober, TX 75443',24679,222,NULL,51,33600,0);
INSERT INTO "django_geo_db_location" VALUES(58573,NULL,'Golden, TX',24680,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58574,NULL,'Golden, TX 75444',24680,222,NULL,51,33601,0);
INSERT INTO "django_geo_db_location" VALUES(58575,NULL,'Honey Grove, TX',24681,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58576,NULL,'Honey Grove, TX 75446',24681,222,NULL,51,33602,0);
INSERT INTO "django_geo_db_location" VALUES(58577,NULL,'Ivanhoe, TX',24682,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58578,NULL,'Ivanhoe, TX 75447',24682,222,NULL,51,33603,0);
INSERT INTO "django_geo_db_location" VALUES(58579,NULL,'Klondike, TX',24683,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58580,NULL,'Klondike, TX 75448',24683,222,NULL,51,33604,0);
INSERT INTO "django_geo_db_location" VALUES(58581,NULL,'Ladonia, TX',24684,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58582,NULL,'Ladonia, TX 75449',24684,222,NULL,51,33605,0);
INSERT INTO "django_geo_db_location" VALUES(58583,NULL,'Lake Creek, TX',24685,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58584,NULL,'Lake Creek, TX 75450',24685,222,NULL,51,33606,0);
INSERT INTO "django_geo_db_location" VALUES(58585,NULL,'Leesburg, TX',24686,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58586,NULL,'Leesburg, TX 75451',24686,222,NULL,51,33607,0);
INSERT INTO "django_geo_db_location" VALUES(58587,NULL,'Leonard, TX',24687,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58588,NULL,'Leonard, TX 75452',24687,222,NULL,51,33608,0);
INSERT INTO "django_geo_db_location" VALUES(58589,NULL,'Lone Oak, TX',24688,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58590,NULL,'Lone Oak, TX 75453',24688,222,NULL,51,33609,0);
INSERT INTO "django_geo_db_location" VALUES(58591,NULL,'Melissa, TX',24689,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58592,NULL,'Melissa, TX 75454',24689,222,NULL,51,33610,0);
INSERT INTO "django_geo_db_location" VALUES(58593,NULL,'Mount Pleasant, TX',24690,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58594,NULL,'Mount Pleasant, TX 75455',24690,222,NULL,51,33611,0);
INSERT INTO "django_geo_db_location" VALUES(58595,NULL,'Mount Pleasant, TX 75456',24690,222,NULL,51,33612,0);
INSERT INTO "django_geo_db_location" VALUES(58596,NULL,'Mount Vernon, TX',24691,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58597,NULL,'Mount Vernon, TX 75457',24691,222,NULL,51,33613,0);
INSERT INTO "django_geo_db_location" VALUES(58598,NULL,'Merit, TX',24692,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58599,NULL,'Merit, TX 75458',24692,222,NULL,51,33614,0);
INSERT INTO "django_geo_db_location" VALUES(58600,NULL,'Howe, TX',24693,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58601,NULL,'Howe, TX 75459',24693,222,NULL,51,33615,0);
INSERT INTO "django_geo_db_location" VALUES(58602,NULL,'Paris, TX',24694,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58603,NULL,'Paris, TX 75460',24694,222,NULL,51,33616,0);
INSERT INTO "django_geo_db_location" VALUES(58604,NULL,'Paris, TX 75461',24694,222,NULL,51,33617,0);
INSERT INTO "django_geo_db_location" VALUES(58605,NULL,'Paris, TX 75462',24694,222,NULL,51,33618,0);
INSERT INTO "django_geo_db_location" VALUES(58606,NULL,'Pattonville, TX',24695,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58607,NULL,'Pattonville, TX 75468',24695,222,NULL,51,33619,0);
INSERT INTO "django_geo_db_location" VALUES(58608,NULL,'Pecan Gap, TX',24696,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58609,NULL,'Pecan Gap, TX 75469',24696,222,NULL,51,33620,0);
INSERT INTO "django_geo_db_location" VALUES(58610,NULL,'Petty, TX',24697,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58611,NULL,'Petty, TX 75470',24697,222,NULL,51,33621,0);
INSERT INTO "django_geo_db_location" VALUES(58612,NULL,'Pickton, TX',24698,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58613,NULL,'Pickton, TX 75471',24698,222,NULL,51,33622,0);
INSERT INTO "django_geo_db_location" VALUES(58614,NULL,'Point, TX',24699,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58615,NULL,'Point, TX 75472',24699,222,NULL,51,33623,0);
INSERT INTO "django_geo_db_location" VALUES(58616,NULL,'Powderly, TX',24700,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58617,NULL,'Powderly, TX 75473',24700,222,NULL,51,33624,0);
INSERT INTO "django_geo_db_location" VALUES(58618,NULL,'Quinlan, TX',24701,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58619,NULL,'Quinlan, TX 75474',24701,222,NULL,51,33625,0);
INSERT INTO "django_geo_db_location" VALUES(58620,NULL,'Randolph, TX',24702,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58621,NULL,'Randolph, TX 75475',24702,222,NULL,51,33626,0);
INSERT INTO "django_geo_db_location" VALUES(58622,NULL,'Ravenna, TX',24703,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58623,NULL,'Ravenna, TX 75476',24703,222,NULL,51,33627,0);
INSERT INTO "django_geo_db_location" VALUES(58624,NULL,'Roxton, TX',24704,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58625,NULL,'Roxton, TX 75477',24704,222,NULL,51,33628,0);
INSERT INTO "django_geo_db_location" VALUES(58626,NULL,'Saltillo, TX',24705,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58627,NULL,'Saltillo, TX 75478',24705,222,NULL,51,33629,0);
INSERT INTO "django_geo_db_location" VALUES(58628,NULL,'Savoy, TX',24706,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58629,NULL,'Savoy, TX 75479',24706,222,NULL,51,33630,0);
INSERT INTO "django_geo_db_location" VALUES(58630,NULL,'Scroggins, TX',24707,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58631,NULL,'Scroggins, TX 75480',24707,222,NULL,51,33631,0);
INSERT INTO "django_geo_db_location" VALUES(58632,NULL,'Sulphur Bluff, TX',24708,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58633,NULL,'Sulphur Bluff, TX 75481',24708,222,NULL,51,33632,0);
INSERT INTO "django_geo_db_location" VALUES(58634,NULL,'Sulphur Springs, TX',24709,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58635,NULL,'Sulphur Springs, TX 75482',24709,222,NULL,51,33633,0);
INSERT INTO "django_geo_db_location" VALUES(58636,NULL,'Sulphur Springs, TX 75483',24709,222,NULL,51,33634,0);
INSERT INTO "django_geo_db_location" VALUES(58637,NULL,'Westminster, TX',24710,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58638,NULL,'Westminster, TX 75485',24710,222,NULL,51,33635,0);
INSERT INTO "django_geo_db_location" VALUES(58639,NULL,'Sumner, TX',24711,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58640,NULL,'Sumner, TX 75486',24711,222,NULL,51,33636,0);
INSERT INTO "django_geo_db_location" VALUES(58641,NULL,'Talco, TX',24712,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58642,NULL,'Talco, TX 75487',24712,222,NULL,51,33637,0);
INSERT INTO "django_geo_db_location" VALUES(58643,NULL,'Telephone, TX',24713,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58644,NULL,'Telephone, TX 75488',24713,222,NULL,51,33638,0);
INSERT INTO "django_geo_db_location" VALUES(58645,NULL,'Tom Bean, TX',24714,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58646,NULL,'Tom Bean, TX 75489',24714,222,NULL,51,33639,0);
INSERT INTO "django_geo_db_location" VALUES(58647,NULL,'Trenton, TX',24715,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58648,NULL,'Trenton, TX 75490',24715,222,NULL,51,33640,0);
INSERT INTO "django_geo_db_location" VALUES(58649,NULL,'Whitewright, TX',24716,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58650,NULL,'Whitewright, TX 75491',24716,222,NULL,51,33641,0);
INSERT INTO "django_geo_db_location" VALUES(58651,NULL,'Windom, TX',24717,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58652,NULL,'Windom, TX 75492',24717,222,NULL,51,33642,0);
INSERT INTO "django_geo_db_location" VALUES(58653,NULL,'Winfield, TX',24718,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58654,NULL,'Winfield, TX 75493',24718,222,NULL,51,33643,0);
INSERT INTO "django_geo_db_location" VALUES(58655,NULL,'Winnsboro, TX',24719,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58656,NULL,'Winnsboro, TX 75494',24719,222,NULL,51,33644,0);
INSERT INTO "django_geo_db_location" VALUES(58657,NULL,'Van Alstyne, TX',24720,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58658,NULL,'Van Alstyne, TX 75495',24720,222,NULL,51,33645,0);
INSERT INTO "django_geo_db_location" VALUES(58659,NULL,'Wolfe City, TX',24721,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58660,NULL,'Wolfe City, TX 75496',24721,222,NULL,51,33646,0);
INSERT INTO "django_geo_db_location" VALUES(58661,NULL,'Yantis, TX',24722,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58662,NULL,'Yantis, TX 75497',24722,222,NULL,51,33647,0);
INSERT INTO "django_geo_db_location" VALUES(58663,NULL,'Savoy, TX 75499',24706,222,NULL,51,33648,0);
INSERT INTO "django_geo_db_location" VALUES(58664,NULL,'Texarkana, TX',24723,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58665,NULL,'Texarkana, TX 75501',24723,222,NULL,51,33649,0);
INSERT INTO "django_geo_db_location" VALUES(58666,NULL,'Texarkana, TX 75502',24723,222,NULL,51,33650,0);
INSERT INTO "django_geo_db_location" VALUES(58667,NULL,'Texarkana, TX 75503',24723,222,NULL,51,33651,0);
INSERT INTO "django_geo_db_location" VALUES(58668,NULL,'Texarkana, TX 75504',24723,222,NULL,51,33652,0);
INSERT INTO "django_geo_db_location" VALUES(58669,NULL,'Texarkana, TX 75505',24723,222,NULL,51,33653,0);
INSERT INTO "django_geo_db_location" VALUES(58670,NULL,'Texarkana, TX 75507',24723,222,NULL,51,33654,0);
INSERT INTO "django_geo_db_location" VALUES(58671,NULL,'Annona, TX',24724,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58672,NULL,'Annona, TX 75550',24724,222,NULL,51,33655,0);
INSERT INTO "django_geo_db_location" VALUES(58673,NULL,'Atlanta, TX',24725,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58674,NULL,'Atlanta, TX 75551',24725,222,NULL,51,33656,0);
INSERT INTO "django_geo_db_location" VALUES(58675,NULL,'Avery, TX',24726,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58676,NULL,'Avery, TX 75554',24726,222,NULL,51,33657,0);
INSERT INTO "django_geo_db_location" VALUES(58677,NULL,'Bivins, TX',24727,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58678,NULL,'Bivins, TX 75555',24727,222,NULL,51,33658,0);
INSERT INTO "django_geo_db_location" VALUES(58679,NULL,'Bloomburg, TX',24728,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58680,NULL,'Bloomburg, TX 75556',24728,222,NULL,51,33659,0);
INSERT INTO "django_geo_db_location" VALUES(58681,NULL,'Cookville, TX',24729,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58682,NULL,'Cookville, TX 75558',24729,222,NULL,51,33660,0);
INSERT INTO "django_geo_db_location" VALUES(58683,NULL,'De Kalb, TX',24730,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58684,NULL,'De Kalb, TX 75559',24730,222,NULL,51,33661,0);
INSERT INTO "django_geo_db_location" VALUES(58685,NULL,'Douglassville, TX',24731,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58686,NULL,'Douglassville, TX 75560',24731,222,NULL,51,33662,0);
INSERT INTO "django_geo_db_location" VALUES(58687,NULL,'Hooks, TX',24732,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58688,NULL,'Hooks, TX 75561',24732,222,NULL,51,33663,0);
INSERT INTO "django_geo_db_location" VALUES(58689,NULL,'Kildare, TX',24733,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58690,NULL,'Kildare, TX 75562',24733,222,NULL,51,33664,0);
INSERT INTO "django_geo_db_location" VALUES(58691,NULL,'Linden, TX',24734,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58692,NULL,'Linden, TX 75563',24734,222,NULL,51,33665,0);
INSERT INTO "django_geo_db_location" VALUES(58693,NULL,'Lodi, TX',24735,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58694,NULL,'Lodi, TX 75564',24735,222,NULL,51,33666,0);
INSERT INTO "django_geo_db_location" VALUES(58695,NULL,'McLeod, TX',24736,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58696,NULL,'McLeod, TX 75565',24736,222,NULL,51,33667,0);
INSERT INTO "django_geo_db_location" VALUES(58697,NULL,'Marietta, TX',24737,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58698,NULL,'Marietta, TX 75566',24737,222,NULL,51,33668,0);
INSERT INTO "django_geo_db_location" VALUES(58699,NULL,'Maud, TX',24738,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58700,NULL,'Maud, TX 75567',24738,222,NULL,51,33669,0);
INSERT INTO "django_geo_db_location" VALUES(58701,NULL,'Naples, TX',24739,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58702,NULL,'Naples, TX 75568',24739,222,NULL,51,33670,0);
INSERT INTO "django_geo_db_location" VALUES(58703,NULL,'Nash, TX',24740,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58704,NULL,'Nash, TX 75569',24740,222,NULL,51,33671,0);
INSERT INTO "django_geo_db_location" VALUES(58705,NULL,'New Boston, TX',24741,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58706,NULL,'New Boston, TX 75570',24741,222,NULL,51,33672,0);
INSERT INTO "django_geo_db_location" VALUES(58707,NULL,'Omaha, TX',24742,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58708,NULL,'Omaha, TX 75571',24742,222,NULL,51,33673,0);
INSERT INTO "django_geo_db_location" VALUES(58709,NULL,'Queen City, TX',24743,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58710,NULL,'Queen City, TX 75572',24743,222,NULL,51,33674,0);
INSERT INTO "django_geo_db_location" VALUES(58711,NULL,'Redwater, TX',24744,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58712,NULL,'Redwater, TX 75573',24744,222,NULL,51,33675,0);
INSERT INTO "django_geo_db_location" VALUES(58713,NULL,'Simms, TX',24745,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58714,NULL,'Simms, TX 75574',24745,222,NULL,51,33676,0);
INSERT INTO "django_geo_db_location" VALUES(58715,NULL,'Texarkana, TX 75599',24723,222,NULL,51,33677,0);
INSERT INTO "django_geo_db_location" VALUES(58716,NULL,'Longview, TX',24746,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58717,NULL,'Longview, TX 75601',24746,222,NULL,51,33678,0);
INSERT INTO "django_geo_db_location" VALUES(58718,NULL,'Longview, TX 75602',24746,222,NULL,51,33679,0);
INSERT INTO "django_geo_db_location" VALUES(58719,NULL,'Longview, TX 75603',24746,222,NULL,51,33680,0);
INSERT INTO "django_geo_db_location" VALUES(58720,NULL,'Longview, TX 75604',24746,222,NULL,51,33681,0);
INSERT INTO "django_geo_db_location" VALUES(58721,NULL,'Longview, TX 75605',24746,222,NULL,51,33682,0);
INSERT INTO "django_geo_db_location" VALUES(58722,NULL,'Longview, TX 75606',24746,222,NULL,51,33683,0);
INSERT INTO "django_geo_db_location" VALUES(58723,NULL,'Longview, TX 75607',24746,222,NULL,51,33684,0);
INSERT INTO "django_geo_db_location" VALUES(58724,NULL,'Longview, TX 75608',24746,222,NULL,51,33685,0);
INSERT INTO "django_geo_db_location" VALUES(58725,NULL,'Longview, TX 75615',24746,222,NULL,51,33686,0);
INSERT INTO "django_geo_db_location" VALUES(58726,NULL,'Avinger, TX',24747,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58727,NULL,'Avinger, TX 75630',24747,222,NULL,51,33687,0);
INSERT INTO "django_geo_db_location" VALUES(58728,NULL,'Beckville, TX',24748,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58729,NULL,'Beckville, TX 75631',24748,222,NULL,51,33688,0);
INSERT INTO "django_geo_db_location" VALUES(58730,NULL,'Carthage, TX',24749,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58731,NULL,'Carthage, TX 75633',24749,222,NULL,51,33689,0);
INSERT INTO "django_geo_db_location" VALUES(58732,NULL,'Cason, TX',24750,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58733,NULL,'Cason, TX 75636',24750,222,NULL,51,33690,0);
INSERT INTO "django_geo_db_location" VALUES(58734,NULL,'Clayton, TX',24751,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58735,NULL,'Clayton, TX 75637',24751,222,NULL,51,33691,0);
INSERT INTO "django_geo_db_location" VALUES(58736,NULL,'Daingerfield, TX',24752,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58737,NULL,'Daingerfield, TX 75638',24752,222,NULL,51,33692,0);
INSERT INTO "django_geo_db_location" VALUES(58738,NULL,'De Berry, TX',24753,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58739,NULL,'De Berry, TX 75639',24753,222,NULL,51,33693,0);
INSERT INTO "django_geo_db_location" VALUES(58740,NULL,'Diana, TX',24754,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58741,NULL,'Diana, TX 75640',24754,222,NULL,51,33694,0);
INSERT INTO "django_geo_db_location" VALUES(58742,NULL,'Easton, TX',24755,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58743,NULL,'Easton, TX 75641',24755,222,NULL,51,33695,0);
INSERT INTO "django_geo_db_location" VALUES(58744,NULL,'Elysian Fields, TX',24756,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58745,NULL,'Elysian Fields, TX 75642',24756,222,NULL,51,33696,0);
INSERT INTO "django_geo_db_location" VALUES(58746,NULL,'Gary, TX',24757,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58747,NULL,'Gary, TX 75643',24757,222,NULL,51,33697,0);
INSERT INTO "django_geo_db_location" VALUES(58748,NULL,'Gilmer, TX',24758,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58749,NULL,'Gilmer, TX 75644',24758,222,NULL,51,33698,0);
INSERT INTO "django_geo_db_location" VALUES(58750,NULL,'Gilmer, TX 75645',24758,222,NULL,51,33699,0);
INSERT INTO "django_geo_db_location" VALUES(58751,NULL,'Gladewater, TX',24759,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58752,NULL,'Gladewater, TX 75647',24759,222,NULL,51,33700,0);
INSERT INTO "django_geo_db_location" VALUES(58753,NULL,'Hallsville, TX',24760,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58754,NULL,'Hallsville, TX 75650',24760,222,NULL,51,33701,0);
INSERT INTO "django_geo_db_location" VALUES(58755,NULL,'Harleton, TX',24761,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58756,NULL,'Harleton, TX 75651',24761,222,NULL,51,33702,0);
INSERT INTO "django_geo_db_location" VALUES(58757,NULL,'Henderson, TX',24762,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58758,NULL,'Henderson, TX 75652',24762,222,NULL,51,33703,0);
INSERT INTO "django_geo_db_location" VALUES(58759,NULL,'Henderson, TX 75653',24762,222,NULL,51,33704,0);
INSERT INTO "django_geo_db_location" VALUES(58760,NULL,'Henderson, TX 75654',24762,222,NULL,51,33705,0);
INSERT INTO "django_geo_db_location" VALUES(58761,NULL,'Hughes Springs, TX',24763,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58762,NULL,'Hughes Springs, TX 75656',24763,222,NULL,51,33706,0);
INSERT INTO "django_geo_db_location" VALUES(58763,NULL,'Jefferson, TX',24764,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58764,NULL,'Jefferson, TX 75657',24764,222,NULL,51,33707,0);
INSERT INTO "django_geo_db_location" VALUES(58765,NULL,'Joinerville, TX',24765,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58766,NULL,'Joinerville, TX 75658',24765,222,NULL,51,33708,0);
INSERT INTO "django_geo_db_location" VALUES(58767,NULL,'Jonesville, TX',24766,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58768,NULL,'Jonesville, TX 75659',24766,222,NULL,51,33709,0);
INSERT INTO "django_geo_db_location" VALUES(58769,NULL,'Judson, TX',24767,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58770,NULL,'Judson, TX 75660',24767,222,NULL,51,33710,0);
INSERT INTO "django_geo_db_location" VALUES(58771,NULL,'Karnack, TX',24768,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58772,NULL,'Karnack, TX 75661',24768,222,NULL,51,33711,0);
INSERT INTO "django_geo_db_location" VALUES(58773,NULL,'Kilgore, TX',24769,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58774,NULL,'Kilgore, TX 75662',24769,222,NULL,51,33712,0);
INSERT INTO "django_geo_db_location" VALUES(58775,NULL,'Kilgore, TX 75663',24769,222,NULL,51,33713,0);
INSERT INTO "django_geo_db_location" VALUES(58776,NULL,'Laird Hill, TX',24770,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58777,NULL,'Laird Hill, TX 75666',24770,222,NULL,51,33714,0);
INSERT INTO "django_geo_db_location" VALUES(58778,NULL,'Laneville, TX',24771,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58779,NULL,'Laneville, TX 75667',24771,222,NULL,51,33715,0);
INSERT INTO "django_geo_db_location" VALUES(58780,NULL,'Lone Star, TX',24772,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58781,NULL,'Lone Star, TX 75668',24772,222,NULL,51,33716,0);
INSERT INTO "django_geo_db_location" VALUES(58782,NULL,'Long Branch, TX',24773,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58783,NULL,'Long Branch, TX 75669',24773,222,NULL,51,33717,0);
INSERT INTO "django_geo_db_location" VALUES(58784,NULL,'Marshall, TX',24774,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58785,NULL,'Marshall, TX 75670',24774,222,NULL,51,33718,0);
INSERT INTO "django_geo_db_location" VALUES(58786,NULL,'Marshall, TX 75671',24774,222,NULL,51,33719,0);
INSERT INTO "django_geo_db_location" VALUES(58787,NULL,'Marshall, TX 75672',24774,222,NULL,51,33720,0);
INSERT INTO "django_geo_db_location" VALUES(58788,NULL,'Minden, TX',24775,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58789,NULL,'Minden, TX 75680',24775,222,NULL,51,33721,0);
INSERT INTO "django_geo_db_location" VALUES(58790,NULL,'Mount Enterprise, TX',24776,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58791,NULL,'Mount Enterprise, TX 75681',24776,222,NULL,51,33722,0);
INSERT INTO "django_geo_db_location" VALUES(58792,NULL,'New London, TX',24777,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58793,NULL,'New London, TX 75682',24777,222,NULL,51,33723,0);
INSERT INTO "django_geo_db_location" VALUES(58794,NULL,'Ore City, TX',24778,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58795,NULL,'Ore City, TX 75683',24778,222,NULL,51,33724,0);
INSERT INTO "django_geo_db_location" VALUES(58796,NULL,'Overton, TX',24779,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58797,NULL,'Overton, TX 75684',24779,222,NULL,51,33725,0);
INSERT INTO "django_geo_db_location" VALUES(58798,NULL,'Panola, TX',24780,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58799,NULL,'Panola, TX 75685',24780,222,NULL,51,33726,0);
INSERT INTO "django_geo_db_location" VALUES(58800,NULL,'Pittsburg, TX',24781,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58801,NULL,'Pittsburg, TX 75686',24781,222,NULL,51,33727,0);
INSERT INTO "django_geo_db_location" VALUES(58802,NULL,'Price, TX',24782,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58803,NULL,'Price, TX 75687',24782,222,NULL,51,33728,0);
INSERT INTO "django_geo_db_location" VALUES(58804,NULL,'Scottsville, TX',24783,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58805,NULL,'Scottsville, TX 75688',24783,222,NULL,51,33729,0);
INSERT INTO "django_geo_db_location" VALUES(58806,NULL,'Selman City, TX',24784,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58807,NULL,'Selman City, TX 75689',24784,222,NULL,51,33730,0);
INSERT INTO "django_geo_db_location" VALUES(58808,NULL,'Tatum, TX',24785,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58809,NULL,'Tatum, TX 75691',24785,222,NULL,51,33731,0);
INSERT INTO "django_geo_db_location" VALUES(58810,NULL,'Waskom, TX',24786,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58811,NULL,'Waskom, TX 75692',24786,222,NULL,51,33732,0);
INSERT INTO "django_geo_db_location" VALUES(58812,NULL,'White Oak, TX',24787,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58813,NULL,'White Oak, TX 75693',24787,222,NULL,51,33733,0);
INSERT INTO "django_geo_db_location" VALUES(58814,NULL,'Woodlawn, TX',24788,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58815,NULL,'Woodlawn, TX 75694',24788,222,NULL,51,33734,0);
INSERT INTO "django_geo_db_location" VALUES(58816,NULL,'Tyler, TX',24789,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58817,NULL,'Tyler, TX 75701',24789,222,NULL,51,33735,0);
INSERT INTO "django_geo_db_location" VALUES(58818,NULL,'Tyler, TX 75702',24789,222,NULL,51,33736,0);
INSERT INTO "django_geo_db_location" VALUES(58819,NULL,'Tyler, TX 75703',24789,222,NULL,51,33737,0);
INSERT INTO "django_geo_db_location" VALUES(58820,NULL,'Tyler, TX 75704',24789,222,NULL,51,33738,0);
INSERT INTO "django_geo_db_location" VALUES(58821,NULL,'Tyler, TX 75705',24789,222,NULL,51,33739,0);
INSERT INTO "django_geo_db_location" VALUES(58822,NULL,'Tyler, TX 75706',24789,222,NULL,51,33740,0);
INSERT INTO "django_geo_db_location" VALUES(58823,NULL,'Tyler, TX 75707',24789,222,NULL,51,33741,0);
INSERT INTO "django_geo_db_location" VALUES(58824,NULL,'Tyler, TX 75708',24789,222,NULL,51,33742,0);
INSERT INTO "django_geo_db_location" VALUES(58825,NULL,'Tyler, TX 75709',24789,222,NULL,51,33743,0);
INSERT INTO "django_geo_db_location" VALUES(58826,NULL,'Tyler, TX 75710',24789,222,NULL,51,33744,0);
INSERT INTO "django_geo_db_location" VALUES(58827,NULL,'Tyler, TX 75711',24789,222,NULL,51,33745,0);
INSERT INTO "django_geo_db_location" VALUES(58828,NULL,'Tyler, TX 75712',24789,222,NULL,51,33746,0);
INSERT INTO "django_geo_db_location" VALUES(58829,NULL,'Tyler, TX 75713',24789,222,NULL,51,33747,0);
INSERT INTO "django_geo_db_location" VALUES(58830,NULL,'Arp, TX',24790,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58831,NULL,'Arp, TX 75750',24790,222,NULL,51,33748,0);
INSERT INTO "django_geo_db_location" VALUES(58832,NULL,'Athens, TX',24791,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58833,NULL,'Athens, TX 75751',24791,222,NULL,51,33749,0);
INSERT INTO "django_geo_db_location" VALUES(58834,NULL,'Winona, TX',24792,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58835,NULL,'Winona, TX 75752',24792,222,NULL,51,33750,0);
INSERT INTO "django_geo_db_location" VALUES(58836,NULL,'Ben Wheeler, TX',24793,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58837,NULL,'Ben Wheeler, TX 75754',24793,222,NULL,51,33751,0);
INSERT INTO "django_geo_db_location" VALUES(58838,NULL,'Big Sandy, TX',24794,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58839,NULL,'Big Sandy, TX 75755',24794,222,NULL,51,33752,0);
INSERT INTO "django_geo_db_location" VALUES(58840,NULL,'Brownsboro, TX',24795,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58841,NULL,'Brownsboro, TX 75756',24795,222,NULL,51,33753,0);
INSERT INTO "django_geo_db_location" VALUES(58842,NULL,'Bullard, TX',24796,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58843,NULL,'Bullard, TX 75757',24796,222,NULL,51,33754,0);
INSERT INTO "django_geo_db_location" VALUES(58844,NULL,'Chandler, TX',24797,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58845,NULL,'Chandler, TX 75758',24797,222,NULL,51,33755,0);
INSERT INTO "django_geo_db_location" VALUES(58846,NULL,'Cuney, TX',24798,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58847,NULL,'Cuney, TX 75759',24798,222,NULL,51,33756,0);
INSERT INTO "django_geo_db_location" VALUES(58848,NULL,'Cushing, TX',24799,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58849,NULL,'Cushing, TX 75760',24799,222,NULL,51,33757,0);
INSERT INTO "django_geo_db_location" VALUES(58850,NULL,'Flint, TX',24800,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58851,NULL,'Flint, TX 75762',24800,222,NULL,51,33758,0);
INSERT INTO "django_geo_db_location" VALUES(58852,NULL,'Frankston, TX',24801,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58853,NULL,'Frankston, TX 75763',24801,222,NULL,51,33759,0);
INSERT INTO "django_geo_db_location" VALUES(58854,NULL,'Gallatin, TX',24802,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58855,NULL,'Gallatin, TX 75764',24802,222,NULL,51,33760,0);
INSERT INTO "django_geo_db_location" VALUES(58856,NULL,'Hawkins, TX',24803,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58857,NULL,'Hawkins, TX 75765',24803,222,NULL,51,33761,0);
INSERT INTO "django_geo_db_location" VALUES(58858,NULL,'Jacksonville, TX',24804,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58859,NULL,'Jacksonville, TX 75766',24804,222,NULL,51,33762,0);
INSERT INTO "django_geo_db_location" VALUES(58860,NULL,'Larue, TX',24805,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58861,NULL,'Larue, TX 75770',24805,222,NULL,51,33763,0);
INSERT INTO "django_geo_db_location" VALUES(58862,NULL,'Lindale, TX',24806,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58863,NULL,'Lindale, TX 75771',24806,222,NULL,51,33764,0);
INSERT INTO "django_geo_db_location" VALUES(58864,NULL,'Maydelle, TX',24807,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58865,NULL,'Maydelle, TX 75772',24807,222,NULL,51,33765,0);
INSERT INTO "django_geo_db_location" VALUES(58866,NULL,'Mineola, TX',24808,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58867,NULL,'Mineola, TX 75773',24808,222,NULL,51,33766,0);
INSERT INTO "django_geo_db_location" VALUES(58868,NULL,'Murchison, TX',24809,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58869,NULL,'Murchison, TX 75778',24809,222,NULL,51,33767,0);
INSERT INTO "django_geo_db_location" VALUES(58870,NULL,'Neches, TX',24810,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58871,NULL,'Neches, TX 75779',24810,222,NULL,51,33768,0);
INSERT INTO "django_geo_db_location" VALUES(58872,NULL,'New Summerfield, TX',24811,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58873,NULL,'New Summerfield, TX 75780',24811,222,NULL,51,33769,0);
INSERT INTO "django_geo_db_location" VALUES(58874,NULL,'Poynor, TX',24812,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58875,NULL,'Poynor, TX 75782',24812,222,NULL,51,33770,0);
INSERT INTO "django_geo_db_location" VALUES(58876,NULL,'Quitman, TX',24813,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58877,NULL,'Quitman, TX 75783',24813,222,NULL,51,33771,0);
INSERT INTO "django_geo_db_location" VALUES(58878,NULL,'Reklaw, TX',24814,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58879,NULL,'Reklaw, TX 75784',24814,222,NULL,51,33772,0);
INSERT INTO "django_geo_db_location" VALUES(58880,NULL,'Rusk, TX',24815,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58881,NULL,'Rusk, TX 75785',24815,222,NULL,51,33773,0);
INSERT INTO "django_geo_db_location" VALUES(58882,NULL,'Sacul, TX',24816,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58883,NULL,'Sacul, TX 75788',24816,222,NULL,51,33774,0);
INSERT INTO "django_geo_db_location" VALUES(58884,NULL,'Troup, TX',24817,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58885,NULL,'Troup, TX 75789',24817,222,NULL,51,33775,0);
INSERT INTO "django_geo_db_location" VALUES(58886,NULL,'Van, TX',24818,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58887,NULL,'Van, TX 75790',24818,222,NULL,51,33776,0);
INSERT INTO "django_geo_db_location" VALUES(58888,NULL,'Whitehouse, TX',24819,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58889,NULL,'Whitehouse, TX 75791',24819,222,NULL,51,33777,0);
INSERT INTO "django_geo_db_location" VALUES(58890,NULL,'Winona, TX 75792',24792,222,NULL,51,33778,0);
INSERT INTO "django_geo_db_location" VALUES(58891,NULL,'Tyler, TX 75798',24789,222,NULL,51,33779,0);
INSERT INTO "django_geo_db_location" VALUES(58892,NULL,'Tyler, TX 75799',24789,222,NULL,51,33780,0);
INSERT INTO "django_geo_db_location" VALUES(58893,NULL,'Palestine, TX',24820,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58894,NULL,'Palestine, TX 75801',24820,222,NULL,51,33781,0);
INSERT INTO "django_geo_db_location" VALUES(58895,NULL,'Palestine, TX 75802',24820,222,NULL,51,33782,0);
INSERT INTO "django_geo_db_location" VALUES(58896,NULL,'Palestine, TX 75803',24820,222,NULL,51,33783,0);
INSERT INTO "django_geo_db_location" VALUES(58897,NULL,'Little Elm, TX 75806',24591,222,NULL,51,33784,0);
INSERT INTO "django_geo_db_location" VALUES(58898,NULL,'Alto, TX',24821,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58899,NULL,'Alto, TX 75825',24821,222,NULL,51,33785,0);
INSERT INTO "django_geo_db_location" VALUES(58900,NULL,'Buffalo, TX',24822,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58901,NULL,'Buffalo, TX 75831',24822,222,NULL,51,33786,0);
INSERT INTO "django_geo_db_location" VALUES(58902,NULL,'Cayuga, TX',24823,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58903,NULL,'Cayuga, TX 75832',24823,222,NULL,51,33787,0);
INSERT INTO "django_geo_db_location" VALUES(58904,NULL,'Centerville, TX',24824,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58905,NULL,'Centerville, TX 75833',24824,222,NULL,51,33788,0);
INSERT INTO "django_geo_db_location" VALUES(58906,NULL,'Centralia, TX',24825,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58907,NULL,'Centralia, TX 75834',24825,222,NULL,51,33789,0);
INSERT INTO "django_geo_db_location" VALUES(58908,NULL,'Crockett, TX',24826,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58909,NULL,'Crockett, TX 75835',24826,222,NULL,51,33790,0);
INSERT INTO "django_geo_db_location" VALUES(58910,NULL,'Donie, TX',24827,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58911,NULL,'Donie, TX 75838',24827,222,NULL,51,33791,0);
INSERT INTO "django_geo_db_location" VALUES(58912,NULL,'Elkhart, TX',24828,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58913,NULL,'Elkhart, TX 75839',24828,222,NULL,51,33792,0);
INSERT INTO "django_geo_db_location" VALUES(58914,NULL,'Fairfield, TX',24829,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58915,NULL,'Fairfield, TX 75840',24829,222,NULL,51,33793,0);
INSERT INTO "django_geo_db_location" VALUES(58916,NULL,'Grapeland, TX',24830,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58917,NULL,'Grapeland, TX 75844',24830,222,NULL,51,33794,0);
INSERT INTO "django_geo_db_location" VALUES(58918,NULL,'Groveton, TX',24831,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58919,NULL,'Groveton, TX 75845',24831,222,NULL,51,33795,0);
INSERT INTO "django_geo_db_location" VALUES(58920,NULL,'Jewett, TX',24832,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58921,NULL,'Jewett, TX 75846',24832,222,NULL,51,33796,0);
INSERT INTO "django_geo_db_location" VALUES(58922,NULL,'Kennard, TX',24833,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58923,NULL,'Kennard, TX 75847',24833,222,NULL,51,33797,0);
INSERT INTO "django_geo_db_location" VALUES(58924,NULL,'Kirvin, TX',24834,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58925,NULL,'Kirvin, TX 75848',24834,222,NULL,51,33798,0);
INSERT INTO "django_geo_db_location" VALUES(58926,NULL,'Latexo, TX',24835,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58927,NULL,'Latexo, TX 75849',24835,222,NULL,51,33799,0);
INSERT INTO "django_geo_db_location" VALUES(58928,NULL,'Leona, TX',24836,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58929,NULL,'Leona, TX 75850',24836,222,NULL,51,33800,0);
INSERT INTO "django_geo_db_location" VALUES(58930,NULL,'Lovelady, TX',24837,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58931,NULL,'Lovelady, TX 75851',24837,222,NULL,51,33801,0);
INSERT INTO "django_geo_db_location" VALUES(58932,NULL,'Midway, TX',24838,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58933,NULL,'Midway, TX 75852',24838,222,NULL,51,33802,0);
INSERT INTO "django_geo_db_location" VALUES(58934,NULL,'Montalba, TX',24839,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58935,NULL,'Montalba, TX 75853',24839,222,NULL,51,33803,0);
INSERT INTO "django_geo_db_location" VALUES(58936,NULL,'Oakwood, TX',24840,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58937,NULL,'Oakwood, TX 75855',24840,222,NULL,51,33804,0);
INSERT INTO "django_geo_db_location" VALUES(58938,NULL,'Pennington, TX',24841,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58939,NULL,'Pennington, TX 75856',24841,222,NULL,51,33805,0);
INSERT INTO "django_geo_db_location" VALUES(58940,NULL,'Ratcliff, TX',24842,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58941,NULL,'Ratcliff, TX 75858',24842,222,NULL,51,33806,0);
INSERT INTO "django_geo_db_location" VALUES(58942,NULL,'Streetman, TX',24843,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58943,NULL,'Streetman, TX 75859',24843,222,NULL,51,33807,0);
INSERT INTO "django_geo_db_location" VALUES(58944,NULL,'Teague, TX',24844,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58945,NULL,'Teague, TX 75860',24844,222,NULL,51,33808,0);
INSERT INTO "django_geo_db_location" VALUES(58946,NULL,'Tennessee Colony, TX',24845,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58947,NULL,'Tennessee Colony, TX 75861',24845,222,NULL,51,33809,0);
INSERT INTO "django_geo_db_location" VALUES(58948,NULL,'Trinity, TX',24846,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58949,NULL,'Trinity, TX 75862',24846,222,NULL,51,33810,0);
INSERT INTO "django_geo_db_location" VALUES(58950,NULL,'Woodlake, TX',24847,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58951,NULL,'Woodlake, TX 75865',24847,222,NULL,51,33811,0);
INSERT INTO "django_geo_db_location" VALUES(58952,NULL,'Rusk, TX 75875',24815,222,NULL,51,33812,0);
INSERT INTO "django_geo_db_location" VALUES(58953,NULL,'Tennessee Colony, TX 75880',24845,222,NULL,51,33813,0);
INSERT INTO "django_geo_db_location" VALUES(58954,NULL,'Palestine, TX 75882',24820,222,NULL,51,33814,0);
INSERT INTO "django_geo_db_location" VALUES(58955,NULL,'Tennessee Colony, TX 75884',24845,222,NULL,51,33815,0);
INSERT INTO "django_geo_db_location" VALUES(58956,NULL,'Tennessee Colony, TX 75886',24845,222,NULL,51,33816,0);
INSERT INTO "django_geo_db_location" VALUES(58957,NULL,'Lufkin, TX',24848,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58958,NULL,'Lufkin, TX 75901',24848,222,NULL,51,33817,0);
INSERT INTO "django_geo_db_location" VALUES(58959,NULL,'Lufkin, TX 75902',24848,222,NULL,51,33818,0);
INSERT INTO "django_geo_db_location" VALUES(58960,NULL,'Lufkin, TX 75903',24848,222,NULL,51,33819,0);
INSERT INTO "django_geo_db_location" VALUES(58961,NULL,'Lufkin, TX 75904',24848,222,NULL,51,33820,0);
INSERT INTO "django_geo_db_location" VALUES(58962,NULL,'Lufkin, TX 75915',24848,222,NULL,51,33821,0);
INSERT INTO "django_geo_db_location" VALUES(58963,NULL,'Alto, TX 75925',24821,222,NULL,51,33822,0);
INSERT INTO "django_geo_db_location" VALUES(58964,NULL,'Apple Springs, TX',24849,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58965,NULL,'Apple Springs, TX 75926',24849,222,NULL,51,33823,0);
INSERT INTO "django_geo_db_location" VALUES(58966,NULL,'Bon Wier, TX',24850,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58967,NULL,'Bon Wier, TX 75928',24850,222,NULL,51,33824,0);
INSERT INTO "django_geo_db_location" VALUES(58968,NULL,'Broaddus, TX',24851,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58969,NULL,'Broaddus, TX 75929',24851,222,NULL,51,33825,0);
INSERT INTO "django_geo_db_location" VALUES(58970,NULL,'Bronson, TX',24852,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58971,NULL,'Bronson, TX 75930',24852,222,NULL,51,33826,0);
INSERT INTO "django_geo_db_location" VALUES(58972,NULL,'Brookeland, TX',24853,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58973,NULL,'Brookeland, TX 75931',24853,222,NULL,51,33827,0);
INSERT INTO "django_geo_db_location" VALUES(58974,NULL,'Burkeville, TX',24854,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58975,NULL,'Burkeville, TX 75932',24854,222,NULL,51,33828,0);
INSERT INTO "django_geo_db_location" VALUES(58976,NULL,'Call, TX',24855,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58977,NULL,'Call, TX 75933',24855,222,NULL,51,33829,0);
INSERT INTO "django_geo_db_location" VALUES(58978,NULL,'Camden, TX',24856,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58979,NULL,'Camden, TX 75934',24856,222,NULL,51,33830,0);
INSERT INTO "django_geo_db_location" VALUES(58980,NULL,'Center, TX',24857,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58981,NULL,'Center, TX 75935',24857,222,NULL,51,33831,0);
INSERT INTO "django_geo_db_location" VALUES(58982,NULL,'Chester, TX',24858,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58983,NULL,'Chester, TX 75936',24858,222,NULL,51,33832,0);
INSERT INTO "django_geo_db_location" VALUES(58984,NULL,'Chireno, TX',24859,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58985,NULL,'Chireno, TX 75937',24859,222,NULL,51,33833,0);
INSERT INTO "django_geo_db_location" VALUES(58986,NULL,'Colmesneil, TX',24860,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58987,NULL,'Colmesneil, TX 75938',24860,222,NULL,51,33834,0);
INSERT INTO "django_geo_db_location" VALUES(58988,NULL,'Corrigan, TX',24861,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58989,NULL,'Corrigan, TX 75939',24861,222,NULL,51,33835,0);
INSERT INTO "django_geo_db_location" VALUES(58990,NULL,'Diboll, TX',24862,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58991,NULL,'Diboll, TX 75941',24862,222,NULL,51,33836,0);
INSERT INTO "django_geo_db_location" VALUES(58992,NULL,'Doucette, TX',24863,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58993,NULL,'Doucette, TX 75942',24863,222,NULL,51,33837,0);
INSERT INTO "django_geo_db_location" VALUES(58994,NULL,'Douglass, TX',24864,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58995,NULL,'Douglass, TX 75943',24864,222,NULL,51,33838,0);
INSERT INTO "django_geo_db_location" VALUES(58996,NULL,'Etoile, TX',24865,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58997,NULL,'Etoile, TX 75944',24865,222,NULL,51,33839,0);
INSERT INTO "django_geo_db_location" VALUES(58998,NULL,'Garrison, TX',24866,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(58999,NULL,'Garrison, TX 75946',24866,222,NULL,51,33840,0);
INSERT INTO "django_geo_db_location" VALUES(59000,NULL,'Geneva, TX',24867,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59001,NULL,'Geneva, TX 75947',24867,222,NULL,51,33841,0);
INSERT INTO "django_geo_db_location" VALUES(59002,NULL,'Hemphill, TX',24868,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59003,NULL,'Hemphill, TX 75948',24868,222,NULL,51,33842,0);
INSERT INTO "django_geo_db_location" VALUES(59004,NULL,'Huntington, TX',24869,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59005,NULL,'Huntington, TX 75949',24869,222,NULL,51,33843,0);
INSERT INTO "django_geo_db_location" VALUES(59006,NULL,'Jasper, TX',24870,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59007,NULL,'Jasper, TX 75951',24870,222,NULL,51,33844,0);
INSERT INTO "django_geo_db_location" VALUES(59008,NULL,'Joaquin, TX',24871,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59009,NULL,'Joaquin, TX 75954',24871,222,NULL,51,33845,0);
INSERT INTO "django_geo_db_location" VALUES(59010,NULL,'Kirbyville, TX',24872,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59011,NULL,'Kirbyville, TX 75956',24872,222,NULL,51,33846,0);
INSERT INTO "django_geo_db_location" VALUES(59012,NULL,'Timpson, TX',24873,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59013,NULL,'Timpson, TX 75957',24873,222,NULL,51,33847,0);
INSERT INTO "django_geo_db_location" VALUES(59014,NULL,'Martinsville, TX',24874,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59015,NULL,'Martinsville, TX 75958',24874,222,NULL,51,33848,0);
INSERT INTO "django_geo_db_location" VALUES(59016,NULL,'Milam, TX',24875,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59017,NULL,'Milam, TX 75959',24875,222,NULL,51,33849,0);
INSERT INTO "django_geo_db_location" VALUES(59018,NULL,'Moscow, TX',24876,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59019,NULL,'Moscow, TX 75960',24876,222,NULL,51,33850,0);
INSERT INTO "django_geo_db_location" VALUES(59020,NULL,'Nacogdoches, TX',24877,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59021,NULL,'Nacogdoches, TX 75961',24877,222,NULL,51,33851,0);
INSERT INTO "django_geo_db_location" VALUES(59022,NULL,'Nacogdoches, TX 75962',24877,222,NULL,51,33852,0);
INSERT INTO "django_geo_db_location" VALUES(59023,NULL,'Nacogdoches, TX 75963',24877,222,NULL,51,33853,0);
INSERT INTO "django_geo_db_location" VALUES(59024,NULL,'Nacogdoches, TX 75964',24877,222,NULL,51,33854,0);
INSERT INTO "django_geo_db_location" VALUES(59025,NULL,'Nacogdoches, TX 75965',24877,222,NULL,51,33855,0);
INSERT INTO "django_geo_db_location" VALUES(59026,NULL,'Newton, TX',24878,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59027,NULL,'Newton, TX 75966',24878,222,NULL,51,33856,0);
INSERT INTO "django_geo_db_location" VALUES(59028,NULL,'Pineland, TX',24879,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59029,NULL,'Pineland, TX 75968',24879,222,NULL,51,33857,0);
INSERT INTO "django_geo_db_location" VALUES(59030,NULL,'Pollok, TX',24880,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59031,NULL,'Pollok, TX 75969',24880,222,NULL,51,33858,0);
INSERT INTO "django_geo_db_location" VALUES(59032,NULL,'San Augustine, TX',24881,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59033,NULL,'San Augustine, TX 75972',24881,222,NULL,51,33859,0);
INSERT INTO "django_geo_db_location" VALUES(59034,NULL,'Shelbyville, TX',24882,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59035,NULL,'Shelbyville, TX 75973',24882,222,NULL,51,33860,0);
INSERT INTO "django_geo_db_location" VALUES(59036,NULL,'Tenaha, TX',24883,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59037,NULL,'Tenaha, TX 75974',24883,222,NULL,51,33861,0);
INSERT INTO "django_geo_db_location" VALUES(59038,NULL,'Timpson, TX 75975',24873,222,NULL,51,33862,0);
INSERT INTO "django_geo_db_location" VALUES(59039,NULL,'Wells, TX',24884,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59040,NULL,'Wells, TX 75976',24884,222,NULL,51,33863,0);
INSERT INTO "django_geo_db_location" VALUES(59041,NULL,'Wiergate, TX',24885,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59042,NULL,'Wiergate, TX 75977',24885,222,NULL,51,33864,0);
INSERT INTO "django_geo_db_location" VALUES(59043,NULL,'Woden, TX',24886,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59044,NULL,'Woden, TX 75978',24886,222,NULL,51,33865,0);
INSERT INTO "django_geo_db_location" VALUES(59045,NULL,'Woodville, TX',24887,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59046,NULL,'Woodville, TX 75979',24887,222,NULL,51,33866,0);
INSERT INTO "django_geo_db_location" VALUES(59047,NULL,'Zavalla, TX',24888,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59048,NULL,'Zavalla, TX 75980',24888,222,NULL,51,33867,0);
INSERT INTO "django_geo_db_location" VALUES(59049,NULL,'Woodville, TX 75990',24887,222,NULL,51,33868,0);
INSERT INTO "django_geo_db_location" VALUES(59050,NULL,'Arlington, TX',24889,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59051,NULL,'Arlington, TX 76001',24889,222,NULL,51,33869,0);
INSERT INTO "django_geo_db_location" VALUES(59052,NULL,'Arlington, TX 76002',24889,222,NULL,51,33870,0);
INSERT INTO "django_geo_db_location" VALUES(59053,NULL,'Arlington, TX 76003',24889,222,NULL,51,33871,0);
INSERT INTO "django_geo_db_location" VALUES(59054,NULL,'Arlington, TX 76004',24889,222,NULL,51,33872,0);
INSERT INTO "django_geo_db_location" VALUES(59055,NULL,'Arlington, TX 76005',24889,222,NULL,51,33873,0);
INSERT INTO "django_geo_db_location" VALUES(59056,NULL,'Arlington, TX 76006',24889,222,NULL,51,33874,0);
INSERT INTO "django_geo_db_location" VALUES(59057,NULL,'Arlington, TX 76007',24889,222,NULL,51,33875,0);
INSERT INTO "django_geo_db_location" VALUES(59058,NULL,'Aledo, TX',24890,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59059,NULL,'Aledo, TX 76008',24890,222,NULL,51,33876,0);
INSERT INTO "django_geo_db_location" VALUES(59060,NULL,'Alvarado, TX',24891,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59061,NULL,'Alvarado, TX 76009',24891,222,NULL,51,33877,0);
INSERT INTO "django_geo_db_location" VALUES(59062,NULL,'Arlington, TX 76010',24889,222,NULL,51,33878,0);
INSERT INTO "django_geo_db_location" VALUES(59063,NULL,'Arlington, TX 76011',24889,222,NULL,51,33879,0);
INSERT INTO "django_geo_db_location" VALUES(59064,NULL,'Arlington, TX 76012',24889,222,NULL,51,33880,0);
INSERT INTO "django_geo_db_location" VALUES(59065,NULL,'Arlington, TX 76013',24889,222,NULL,51,33881,0);
INSERT INTO "django_geo_db_location" VALUES(59066,NULL,'Arlington, TX 76014',24889,222,NULL,51,33882,0);
INSERT INTO "django_geo_db_location" VALUES(59067,NULL,'Arlington, TX 76015',24889,222,NULL,51,33883,0);
INSERT INTO "django_geo_db_location" VALUES(59068,NULL,'Arlington, TX 76016',24889,222,NULL,51,33884,0);
INSERT INTO "django_geo_db_location" VALUES(59069,NULL,'Arlington, TX 76017',24889,222,NULL,51,33885,0);
INSERT INTO "django_geo_db_location" VALUES(59070,NULL,'Arlington, TX 76018',24889,222,NULL,51,33886,0);
INSERT INTO "django_geo_db_location" VALUES(59071,NULL,'Arlington, TX 76019',24889,222,NULL,51,33887,0);
INSERT INTO "django_geo_db_location" VALUES(59072,NULL,'Azle, TX',24892,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59073,NULL,'Azle, TX 76020',24892,222,NULL,51,33888,0);
INSERT INTO "django_geo_db_location" VALUES(59074,NULL,'Bedford, TX',24893,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59075,NULL,'Bedford, TX 76021',24893,222,NULL,51,33889,0);
INSERT INTO "django_geo_db_location" VALUES(59076,NULL,'Bedford, TX 76022',24893,222,NULL,51,33890,0);
INSERT INTO "django_geo_db_location" VALUES(59077,NULL,'Boyd, TX',24894,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59078,NULL,'Boyd, TX 76023',24894,222,NULL,51,33891,0);
INSERT INTO "django_geo_db_location" VALUES(59079,NULL,'Plano, TX 76025',24581,222,NULL,51,33892,0);
INSERT INTO "django_geo_db_location" VALUES(59080,NULL,'Burleson, TX',24895,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59081,NULL,'Burleson, TX 76028',24895,222,NULL,51,33893,0);
INSERT INTO "django_geo_db_location" VALUES(59082,NULL,'Cleburne, TX',24896,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59083,NULL,'Cleburne, TX 76031',24896,222,NULL,51,33894,0);
INSERT INTO "django_geo_db_location" VALUES(59084,NULL,'Cleburne, TX 76033',24896,222,NULL,51,33895,0);
INSERT INTO "django_geo_db_location" VALUES(59085,NULL,'Colleyville, TX',24897,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59086,NULL,'Colleyville, TX 76034',24897,222,NULL,51,33896,0);
INSERT INTO "django_geo_db_location" VALUES(59087,NULL,'Cresson, TX',24898,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59088,NULL,'Cresson, TX 76035',24898,222,NULL,51,33897,0);
INSERT INTO "django_geo_db_location" VALUES(59089,NULL,'Crowley, TX',24899,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59090,NULL,'Crowley, TX 76036',24899,222,NULL,51,33898,0);
INSERT INTO "django_geo_db_location" VALUES(59091,NULL,'Euless, TX',24900,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59092,NULL,'Euless, TX 76039',24900,222,NULL,51,33899,0);
INSERT INTO "django_geo_db_location" VALUES(59093,NULL,'Euless, TX 76040',24900,222,NULL,51,33900,0);
INSERT INTO "django_geo_db_location" VALUES(59094,NULL,'Forreston, TX',24901,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59095,NULL,'Forreston, TX 76041',24901,222,NULL,51,33901,0);
INSERT INTO "django_geo_db_location" VALUES(59096,NULL,'Glen Rose, TX',24902,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59097,NULL,'Glen Rose, TX 76043',24902,222,NULL,51,33902,0);
INSERT INTO "django_geo_db_location" VALUES(59098,NULL,'Godley, TX',24903,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59099,NULL,'Godley, TX 76044',24903,222,NULL,51,33903,0);
INSERT INTO "django_geo_db_location" VALUES(59100,NULL,'Granbury, TX',24904,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59101,NULL,'Granbury, TX 76048',24904,222,NULL,51,33904,0);
INSERT INTO "django_geo_db_location" VALUES(59102,NULL,'Granbury, TX 76049',24904,222,NULL,51,33905,0);
INSERT INTO "django_geo_db_location" VALUES(59103,NULL,'Grandview, TX',24905,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59104,NULL,'Grandview, TX 76050',24905,222,NULL,51,33906,0);
INSERT INTO "django_geo_db_location" VALUES(59105,NULL,'Grapevine, TX',24906,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59106,NULL,'Grapevine, TX 76051',24906,222,NULL,51,33907,0);
INSERT INTO "django_geo_db_location" VALUES(59107,NULL,'Haslet, TX',24907,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59108,NULL,'Haslet, TX 76052',24907,222,NULL,51,33908,0);
INSERT INTO "django_geo_db_location" VALUES(59109,NULL,'Hurst, TX',24908,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59110,NULL,'Hurst, TX 76053',24908,222,NULL,51,33909,0);
INSERT INTO "django_geo_db_location" VALUES(59111,NULL,'Hurst, TX 76054',24908,222,NULL,51,33910,0);
INSERT INTO "django_geo_db_location" VALUES(59112,NULL,'Itasca, TX',24909,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59113,NULL,'Itasca, TX 76055',24909,222,NULL,51,33911,0);
INSERT INTO "django_geo_db_location" VALUES(59114,NULL,'Joshua, TX',24910,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59115,NULL,'Joshua, TX 76058',24910,222,NULL,51,33912,0);
INSERT INTO "django_geo_db_location" VALUES(59116,NULL,'Keene, TX',24911,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59117,NULL,'Keene, TX 76059',24911,222,NULL,51,33913,0);
INSERT INTO "django_geo_db_location" VALUES(59118,NULL,'Kennedale, TX',24912,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59119,NULL,'Kennedale, TX 76060',24912,222,NULL,51,33914,0);
INSERT INTO "django_geo_db_location" VALUES(59120,NULL,'Lillian, TX',24913,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59121,NULL,'Lillian, TX 76061',24913,222,NULL,51,33915,0);
INSERT INTO "django_geo_db_location" VALUES(59122,NULL,'Mansfield, TX',24914,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59123,NULL,'Mansfield, TX 76063',24914,222,NULL,51,33916,0);
INSERT INTO "django_geo_db_location" VALUES(59124,NULL,'Maypearl, TX',24915,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59125,NULL,'Maypearl, TX 76064',24915,222,NULL,51,33917,0);
INSERT INTO "django_geo_db_location" VALUES(59126,NULL,'Midlothian, TX',24916,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59127,NULL,'Midlothian, TX 76065',24916,222,NULL,51,33918,0);
INSERT INTO "django_geo_db_location" VALUES(59128,NULL,'Millsap, TX',24917,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59129,NULL,'Millsap, TX 76066',24917,222,NULL,51,33919,0);
INSERT INTO "django_geo_db_location" VALUES(59130,NULL,'Mineral Wells, TX',24918,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59131,NULL,'Mineral Wells, TX 76067',24918,222,NULL,51,33920,0);
INSERT INTO "django_geo_db_location" VALUES(59132,NULL,'Mineral Wells, TX 76068',24918,222,NULL,51,33921,0);
INSERT INTO "django_geo_db_location" VALUES(59133,NULL,'Nemo, TX',24919,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59134,NULL,'Nemo, TX 76070',24919,222,NULL,51,33922,0);
INSERT INTO "django_geo_db_location" VALUES(59135,NULL,'Newark, TX',24920,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59136,NULL,'Newark, TX 76071',24920,222,NULL,51,33923,0);
INSERT INTO "django_geo_db_location" VALUES(59137,NULL,'Paradise, TX',24921,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59138,NULL,'Paradise, TX 76073',24921,222,NULL,51,33924,0);
INSERT INTO "django_geo_db_location" VALUES(59139,NULL,'Rainbow, TX',24922,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59140,NULL,'Rainbow, TX 76077',24922,222,NULL,51,33925,0);
INSERT INTO "django_geo_db_location" VALUES(59141,NULL,'Rhome, TX',24923,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59142,NULL,'Rhome, TX 76078',24923,222,NULL,51,33926,0);
INSERT INTO "django_geo_db_location" VALUES(59143,NULL,'Springtown, TX',24924,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59144,NULL,'Springtown, TX 76082',24924,222,NULL,51,33927,0);
INSERT INTO "django_geo_db_location" VALUES(59145,NULL,'Venus, TX',24925,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59146,NULL,'Venus, TX 76084',24925,222,NULL,51,33928,0);
INSERT INTO "django_geo_db_location" VALUES(59147,NULL,'Weatherford, TX',24926,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59148,NULL,'Weatherford, TX 76085',24926,222,NULL,51,33929,0);
INSERT INTO "django_geo_db_location" VALUES(59149,NULL,'Weatherford, TX 76086',24926,222,NULL,51,33930,0);
INSERT INTO "django_geo_db_location" VALUES(59150,NULL,'Weatherford, TX 76087',24926,222,NULL,51,33931,0);
INSERT INTO "django_geo_db_location" VALUES(59151,NULL,'Weatherford, TX 76088',24926,222,NULL,51,33932,0);
INSERT INTO "django_geo_db_location" VALUES(59152,NULL,'Southlake, TX',24927,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59153,NULL,'Southlake, TX 76092',24927,222,NULL,51,33933,0);
INSERT INTO "django_geo_db_location" VALUES(59154,NULL,'Rio Vista, TX',24928,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59155,NULL,'Rio Vista, TX 76093',24928,222,NULL,51,33934,0);
INSERT INTO "django_geo_db_location" VALUES(59156,NULL,'Arlington, TX 76094',24889,222,NULL,51,33935,0);
INSERT INTO "django_geo_db_location" VALUES(59157,NULL,'Bedford, TX 76095',24893,222,NULL,51,33936,0);
INSERT INTO "django_geo_db_location" VALUES(59158,NULL,'Arlington, TX 76096',24889,222,NULL,51,33937,0);
INSERT INTO "django_geo_db_location" VALUES(59159,NULL,'Burleson, TX 76097',24895,222,NULL,51,33938,0);
INSERT INTO "django_geo_db_location" VALUES(59160,NULL,'Azle, TX 76098',24892,222,NULL,51,33939,0);
INSERT INTO "django_geo_db_location" VALUES(59161,NULL,'Grapevine, TX 76099',24906,222,NULL,51,33940,0);
INSERT INTO "django_geo_db_location" VALUES(59162,NULL,'Fort Worth, TX',24929,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59163,NULL,'Fort Worth, TX 76101',24929,222,NULL,51,33941,0);
INSERT INTO "django_geo_db_location" VALUES(59164,NULL,'Fort Worth, TX 76102',24929,222,NULL,51,33942,0);
INSERT INTO "django_geo_db_location" VALUES(59165,NULL,'Fort Worth, TX 76103',24929,222,NULL,51,33943,0);
INSERT INTO "django_geo_db_location" VALUES(59166,NULL,'Fort Worth, TX 76104',24929,222,NULL,51,33944,0);
INSERT INTO "django_geo_db_location" VALUES(59167,NULL,'Fort Worth, TX 76105',24929,222,NULL,51,33945,0);
INSERT INTO "django_geo_db_location" VALUES(59168,NULL,'Fort Worth, TX 76106',24929,222,NULL,51,33946,0);
INSERT INTO "django_geo_db_location" VALUES(59169,NULL,'Fort Worth, TX 76107',24929,222,NULL,51,33947,0);
INSERT INTO "django_geo_db_location" VALUES(59170,NULL,'Fort Worth, TX 76108',24929,222,NULL,51,33948,0);
INSERT INTO "django_geo_db_location" VALUES(59171,NULL,'Fort Worth, TX 76109',24929,222,NULL,51,33949,0);
INSERT INTO "django_geo_db_location" VALUES(59172,NULL,'Fort Worth, TX 76110',24929,222,NULL,51,33950,0);
INSERT INTO "django_geo_db_location" VALUES(59173,NULL,'Fort Worth, TX 76111',24929,222,NULL,51,33951,0);
INSERT INTO "django_geo_db_location" VALUES(59174,NULL,'Fort Worth, TX 76112',24929,222,NULL,51,33952,0);
INSERT INTO "django_geo_db_location" VALUES(59175,NULL,'Fort Worth, TX 76113',24929,222,NULL,51,33953,0);
INSERT INTO "django_geo_db_location" VALUES(59176,NULL,'Fort Worth, TX 76114',24929,222,NULL,51,33954,0);
INSERT INTO "django_geo_db_location" VALUES(59177,NULL,'Fort Worth, TX 76115',24929,222,NULL,51,33955,0);
INSERT INTO "django_geo_db_location" VALUES(59178,NULL,'Fort Worth, TX 76116',24929,222,NULL,51,33956,0);
INSERT INTO "django_geo_db_location" VALUES(59179,NULL,'Haltom City, TX',24930,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59180,NULL,'Haltom City, TX 76117',24930,222,NULL,51,33957,0);
INSERT INTO "django_geo_db_location" VALUES(59181,NULL,'Fort Worth, TX 76118',24929,222,NULL,51,33958,0);
INSERT INTO "django_geo_db_location" VALUES(59182,NULL,'Fort Worth, TX 76119',24929,222,NULL,51,33959,0);
INSERT INTO "django_geo_db_location" VALUES(59183,NULL,'Fort Worth, TX 76120',24929,222,NULL,51,33960,0);
INSERT INTO "django_geo_db_location" VALUES(59184,NULL,'Fort Worth, TX 76121',24929,222,NULL,51,33961,0);
INSERT INTO "django_geo_db_location" VALUES(59185,NULL,'Fort Worth, TX 76122',24929,222,NULL,51,33962,0);
INSERT INTO "django_geo_db_location" VALUES(59186,NULL,'Fort Worth, TX 76123',24929,222,NULL,51,33963,0);
INSERT INTO "django_geo_db_location" VALUES(59187,NULL,'Fort Worth, TX 76124',24929,222,NULL,51,33964,0);
INSERT INTO "django_geo_db_location" VALUES(59188,NULL,'Fort Worth, TX 76126',24929,222,NULL,51,33965,0);
INSERT INTO "django_geo_db_location" VALUES(59189,NULL,'Naval Air Station/ Jrb, TX',24931,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59190,NULL,'Naval Air Station/ Jrb, TX 76127',24931,222,NULL,51,33966,0);
INSERT INTO "django_geo_db_location" VALUES(59191,NULL,'Fort Worth, TX 76129',24929,222,NULL,51,33967,0);
INSERT INTO "django_geo_db_location" VALUES(59192,NULL,'Fort Worth, TX 76130',24929,222,NULL,51,33968,0);
INSERT INTO "django_geo_db_location" VALUES(59193,NULL,'Fort Worth, TX 76131',24929,222,NULL,51,33969,0);
INSERT INTO "django_geo_db_location" VALUES(59194,NULL,'Fort Worth, TX 76132',24929,222,NULL,51,33970,0);
INSERT INTO "django_geo_db_location" VALUES(59195,NULL,'Fort Worth, TX 76133',24929,222,NULL,51,33971,0);
INSERT INTO "django_geo_db_location" VALUES(59196,NULL,'Fort Worth, TX 76134',24929,222,NULL,51,33972,0);
INSERT INTO "django_geo_db_location" VALUES(59197,NULL,'Fort Worth, TX 76135',24929,222,NULL,51,33973,0);
INSERT INTO "django_geo_db_location" VALUES(59198,NULL,'Fort Worth, TX 76136',24929,222,NULL,51,33974,0);
INSERT INTO "django_geo_db_location" VALUES(59199,NULL,'Fort Worth, TX 76137',24929,222,NULL,51,33975,0);
INSERT INTO "django_geo_db_location" VALUES(59200,NULL,'Fort Worth, TX 76140',24929,222,NULL,51,33976,0);
INSERT INTO "django_geo_db_location" VALUES(59201,NULL,'Fort Worth, TX 76147',24929,222,NULL,51,33977,0);
INSERT INTO "django_geo_db_location" VALUES(59202,NULL,'Fort Worth, TX 76148',24929,222,NULL,51,33978,0);
INSERT INTO "django_geo_db_location" VALUES(59203,NULL,'Fort Worth, TX 76150',24929,222,NULL,51,33979,0);
INSERT INTO "django_geo_db_location" VALUES(59204,NULL,'Fort Worth, TX 76153',24929,222,NULL,51,33980,0);
INSERT INTO "django_geo_db_location" VALUES(59205,NULL,'Fort Worth, TX 76155',24929,222,NULL,51,33981,0);
INSERT INTO "django_geo_db_location" VALUES(59206,NULL,'Fort Worth, TX 76161',24929,222,NULL,51,33982,0);
INSERT INTO "django_geo_db_location" VALUES(59207,NULL,'Fort Worth, TX 76162',24929,222,NULL,51,33983,0);
INSERT INTO "django_geo_db_location" VALUES(59208,NULL,'Fort Worth, TX 76163',24929,222,NULL,51,33984,0);
INSERT INTO "django_geo_db_location" VALUES(59209,NULL,'Fort Worth, TX 76164',24929,222,NULL,51,33985,0);
INSERT INTO "django_geo_db_location" VALUES(59210,NULL,'Fort Worth, TX 76177',24929,222,NULL,51,33986,0);
INSERT INTO "django_geo_db_location" VALUES(59211,NULL,'Fort Worth, TX 76178',24929,222,NULL,51,33987,0);
INSERT INTO "django_geo_db_location" VALUES(59212,NULL,'Fort Worth, TX 76179',24929,222,NULL,51,33988,0);
INSERT INTO "django_geo_db_location" VALUES(59213,NULL,'North Richland Hills, TX',24932,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59214,NULL,'North Richland Hills, TX 76180',24932,222,NULL,51,33989,0);
INSERT INTO "django_geo_db_location" VALUES(59215,NULL,'Fort Worth, TX 76181',24929,222,NULL,51,33990,0);
INSERT INTO "django_geo_db_location" VALUES(59216,NULL,'North Richland Hills, TX 76182',24932,222,NULL,51,33991,0);
INSERT INTO "django_geo_db_location" VALUES(59217,NULL,'Fort Worth, TX 76185',24929,222,NULL,51,33992,0);
INSERT INTO "django_geo_db_location" VALUES(59218,NULL,'Fort Worth, TX 76191',24929,222,NULL,51,33993,0);
INSERT INTO "django_geo_db_location" VALUES(59219,NULL,'Fort Worth, TX 76192',24929,222,NULL,51,33994,0);
INSERT INTO "django_geo_db_location" VALUES(59220,NULL,'Fort Worth, TX 76193',24929,222,NULL,51,33995,0);
INSERT INTO "django_geo_db_location" VALUES(59221,NULL,'Fort Worth, TX 76195',24929,222,NULL,51,33996,0);
INSERT INTO "django_geo_db_location" VALUES(59222,NULL,'Fort Worth, TX 76196',24929,222,NULL,51,33997,0);
INSERT INTO "django_geo_db_location" VALUES(59223,NULL,'Fort Worth, TX 76197',24929,222,NULL,51,33998,0);
INSERT INTO "django_geo_db_location" VALUES(59224,NULL,'Fort Worth, TX 76198',24929,222,NULL,51,33999,0);
INSERT INTO "django_geo_db_location" VALUES(59225,NULL,'Fort Worth, TX 76199',24929,222,NULL,51,34000,0);
INSERT INTO "django_geo_db_location" VALUES(59226,NULL,'Denton, TX',24933,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59227,NULL,'Denton, TX 76201',24933,222,NULL,51,34001,0);
INSERT INTO "django_geo_db_location" VALUES(59228,NULL,'Denton, TX 76202',24933,222,NULL,51,34002,0);
INSERT INTO "django_geo_db_location" VALUES(59229,NULL,'Denton, TX 76203',24933,222,NULL,51,34003,0);
INSERT INTO "django_geo_db_location" VALUES(59230,NULL,'Denton, TX 76204',24933,222,NULL,51,34004,0);
INSERT INTO "django_geo_db_location" VALUES(59231,NULL,'Denton, TX 76205',24933,222,NULL,51,34005,0);
INSERT INTO "django_geo_db_location" VALUES(59232,NULL,'Denton, TX 76206',24933,222,NULL,51,34006,0);
INSERT INTO "django_geo_db_location" VALUES(59233,NULL,'Denton, TX 76207',24933,222,NULL,51,34007,0);
INSERT INTO "django_geo_db_location" VALUES(59234,NULL,'Denton, TX 76208',24933,222,NULL,51,34008,0);
INSERT INTO "django_geo_db_location" VALUES(59235,NULL,'Denton, TX 76209',24933,222,NULL,51,34009,0);
INSERT INTO "django_geo_db_location" VALUES(59236,NULL,'Corinth, TX',24934,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59237,NULL,'Corinth, TX 76210',24934,222,NULL,51,34010,0);
INSERT INTO "django_geo_db_location" VALUES(59238,NULL,'Alvord, TX',24935,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59239,NULL,'Alvord, TX 76225',24935,222,NULL,51,34011,0);
INSERT INTO "django_geo_db_location" VALUES(59240,NULL,'Argyle, TX',24936,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59241,NULL,'Argyle, TX 76226',24936,222,NULL,51,34012,0);
INSERT INTO "django_geo_db_location" VALUES(59242,NULL,'Aubrey, TX',24937,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59243,NULL,'Aubrey, TX 76227',24937,222,NULL,51,34013,0);
INSERT INTO "django_geo_db_location" VALUES(59244,NULL,'Bellevue, TX',24938,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59245,NULL,'Bellevue, TX 76228',24938,222,NULL,51,34014,0);
INSERT INTO "django_geo_db_location" VALUES(59246,NULL,'Bowie, TX',24939,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59247,NULL,'Bowie, TX 76230',24939,222,NULL,51,34015,0);
INSERT INTO "django_geo_db_location" VALUES(59248,NULL,'Collinsville, TX',24940,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59249,NULL,'Collinsville, TX 76233',24940,222,NULL,51,34016,0);
INSERT INTO "django_geo_db_location" VALUES(59250,NULL,'Decatur, TX',24941,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59251,NULL,'Decatur, TX 76234',24941,222,NULL,51,34017,0);
INSERT INTO "django_geo_db_location" VALUES(59252,NULL,'Era, TX',24942,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59253,NULL,'Era, TX 76238',24942,222,NULL,51,34018,0);
INSERT INTO "django_geo_db_location" VALUES(59254,NULL,'Forestburg, TX',24943,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59255,NULL,'Forestburg, TX 76239',24943,222,NULL,51,34019,0);
INSERT INTO "django_geo_db_location" VALUES(59256,NULL,'Gainesville, TX',24944,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59257,NULL,'Gainesville, TX 76240',24944,222,NULL,51,34020,0);
INSERT INTO "django_geo_db_location" VALUES(59258,NULL,'Gainesville, TX 76241',24944,222,NULL,51,34021,0);
INSERT INTO "django_geo_db_location" VALUES(59259,NULL,'Keller, TX',24945,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59260,NULL,'Keller, TX 76244',24945,222,NULL,51,34022,0);
INSERT INTO "django_geo_db_location" VALUES(59261,NULL,'Gordonville, TX',24946,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59262,NULL,'Gordonville, TX 76245',24946,222,NULL,51,34023,0);
INSERT INTO "django_geo_db_location" VALUES(59263,NULL,'Greenwood, TX',24947,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59264,NULL,'Greenwood, TX 76246',24947,222,NULL,51,34024,0);
INSERT INTO "django_geo_db_location" VALUES(59265,NULL,'Justin, TX',24948,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59266,NULL,'Justin, TX 76247',24948,222,NULL,51,34025,0);
INSERT INTO "django_geo_db_location" VALUES(59267,NULL,'Keller, TX 76248',24945,222,NULL,51,34026,0);
INSERT INTO "django_geo_db_location" VALUES(59268,NULL,'Krum, TX',24949,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59269,NULL,'Krum, TX 76249',24949,222,NULL,51,34027,0);
INSERT INTO "django_geo_db_location" VALUES(59270,NULL,'Lindsay, TX',24950,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59271,NULL,'Lindsay, TX 76250',24950,222,NULL,51,34028,0);
INSERT INTO "django_geo_db_location" VALUES(59272,NULL,'Montague, TX',24951,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59273,NULL,'Montague, TX 76251',24951,222,NULL,51,34029,0);
INSERT INTO "django_geo_db_location" VALUES(59274,NULL,'Muenster, TX',24952,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59275,NULL,'Muenster, TX 76252',24952,222,NULL,51,34030,0);
INSERT INTO "django_geo_db_location" VALUES(59276,NULL,'Myra, TX',24953,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59277,NULL,'Myra, TX 76253',24953,222,NULL,51,34031,0);
INSERT INTO "django_geo_db_location" VALUES(59278,NULL,'Nocona, TX',24954,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59279,NULL,'Nocona, TX 76255',24954,222,NULL,51,34032,0);
INSERT INTO "django_geo_db_location" VALUES(59280,NULL,'Pilot Point, TX',24955,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59281,NULL,'Pilot Point, TX 76258',24955,222,NULL,51,34033,0);
INSERT INTO "django_geo_db_location" VALUES(59282,NULL,'Ponder, TX',24956,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59283,NULL,'Ponder, TX 76259',24956,222,NULL,51,34034,0);
INSERT INTO "django_geo_db_location" VALUES(59284,NULL,'Ringgold, TX',24957,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59285,NULL,'Ringgold, TX 76261',24957,222,NULL,51,34035,0);
INSERT INTO "django_geo_db_location" VALUES(59286,NULL,'Roanoke, TX',24958,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59287,NULL,'Roanoke, TX 76262',24958,222,NULL,51,34036,0);
INSERT INTO "django_geo_db_location" VALUES(59288,NULL,'Rosston, TX',24959,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59289,NULL,'Rosston, TX 76263',24959,222,NULL,51,34037,0);
INSERT INTO "django_geo_db_location" VALUES(59290,NULL,'Sadler, TX',24960,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59291,NULL,'Sadler, TX 76264',24960,222,NULL,51,34038,0);
INSERT INTO "django_geo_db_location" VALUES(59292,NULL,'Saint Jo, TX',24961,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59293,NULL,'Saint Jo, TX 76265',24961,222,NULL,51,34039,0);
INSERT INTO "django_geo_db_location" VALUES(59294,NULL,'Sanger, TX',24962,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59295,NULL,'Sanger, TX 76266',24962,222,NULL,51,34040,0);
INSERT INTO "django_geo_db_location" VALUES(59296,NULL,'Slidell, TX',24963,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59297,NULL,'Slidell, TX 76267',24963,222,NULL,51,34041,0);
INSERT INTO "django_geo_db_location" VALUES(59298,NULL,'Southmayd, TX',24964,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59299,NULL,'Southmayd, TX 76268',24964,222,NULL,51,34042,0);
INSERT INTO "django_geo_db_location" VALUES(59300,NULL,'Sunset, TX',24965,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59301,NULL,'Sunset, TX 76270',24965,222,NULL,51,34043,0);
INSERT INTO "django_geo_db_location" VALUES(59302,NULL,'Tioga, TX',24966,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59303,NULL,'Tioga, TX 76271',24966,222,NULL,51,34044,0);
INSERT INTO "django_geo_db_location" VALUES(59304,NULL,'Valley View, TX',24967,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59305,NULL,'Valley View, TX 76272',24967,222,NULL,51,34045,0);
INSERT INTO "django_geo_db_location" VALUES(59306,NULL,'Whitesboro, TX',24968,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59307,NULL,'Whitesboro, TX 76273',24968,222,NULL,51,34046,0);
INSERT INTO "django_geo_db_location" VALUES(59308,NULL,'Roanoke, TX 76299',24958,222,NULL,51,34047,0);
INSERT INTO "django_geo_db_location" VALUES(59309,NULL,'Wichita Falls, TX',24969,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59310,NULL,'Wichita Falls, TX 76301',24969,222,NULL,51,34048,0);
INSERT INTO "django_geo_db_location" VALUES(59311,NULL,'Wichita Falls, TX 76302',24969,222,NULL,51,34049,0);
INSERT INTO "django_geo_db_location" VALUES(59312,NULL,'Wichita Falls, TX 76303',24969,222,NULL,51,34050,0);
INSERT INTO "django_geo_db_location" VALUES(59313,NULL,'Wichita Falls, TX 76304',24969,222,NULL,51,34051,0);
INSERT INTO "django_geo_db_location" VALUES(59314,NULL,'Wichita Falls, TX 76305',24969,222,NULL,51,34052,0);
INSERT INTO "django_geo_db_location" VALUES(59315,NULL,'Wichita Falls, TX 76306',24969,222,NULL,51,34053,0);
INSERT INTO "django_geo_db_location" VALUES(59316,NULL,'Wichita Falls, TX 76307',24969,222,NULL,51,34054,0);
INSERT INTO "django_geo_db_location" VALUES(59317,NULL,'Wichita Falls, TX 76308',24969,222,NULL,51,34055,0);
INSERT INTO "django_geo_db_location" VALUES(59318,NULL,'Wichita Falls, TX 76309',24969,222,NULL,51,34056,0);
INSERT INTO "django_geo_db_location" VALUES(59319,NULL,'Wichita Falls, TX 76310',24969,222,NULL,51,34057,0);
INSERT INTO "django_geo_db_location" VALUES(59320,NULL,'Sheppard AFB, TX',24970,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59321,NULL,'Sheppard AFB, TX 76311',24970,222,NULL,51,34058,0);
INSERT INTO "django_geo_db_location" VALUES(59322,NULL,'Fort Worth, TX 76345',24929,222,NULL,51,34059,0);
INSERT INTO "django_geo_db_location" VALUES(59323,NULL,'Archer City, TX',24971,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59324,NULL,'Archer City, TX 76351',24971,222,NULL,51,34060,0);
INSERT INTO "django_geo_db_location" VALUES(59325,NULL,'Bluegrove, TX',24972,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59326,NULL,'Bluegrove, TX 76352',24972,222,NULL,51,34061,0);
INSERT INTO "django_geo_db_location" VALUES(59327,NULL,'Burkburnett, TX',24973,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59328,NULL,'Burkburnett, TX 76354',24973,222,NULL,51,34062,0);
INSERT INTO "django_geo_db_location" VALUES(59329,NULL,'Terral, OK 76356',24138,222,NULL,36,34063,0);
INSERT INTO "django_geo_db_location" VALUES(59330,NULL,'Byers, TX',24974,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59331,NULL,'Byers, TX 76357',24974,222,NULL,51,34064,0);
INSERT INTO "django_geo_db_location" VALUES(59332,NULL,'Electra, TX',24975,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59333,NULL,'Electra, TX 76360',24975,222,NULL,51,34065,0);
INSERT INTO "django_geo_db_location" VALUES(59334,NULL,'Goree, TX',24976,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59335,NULL,'Goree, TX 76363',24976,222,NULL,51,34066,0);
INSERT INTO "django_geo_db_location" VALUES(59336,NULL,'Harrold, TX',24977,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59337,NULL,'Harrold, TX 76364',24977,222,NULL,51,34067,0);
INSERT INTO "django_geo_db_location" VALUES(59338,NULL,'Henrietta, TX',24978,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59339,NULL,'Henrietta, TX 76365',24978,222,NULL,51,34068,0);
INSERT INTO "django_geo_db_location" VALUES(59340,NULL,'Holliday, TX',24979,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59341,NULL,'Holliday, TX 76366',24979,222,NULL,51,34069,0);
INSERT INTO "django_geo_db_location" VALUES(59342,NULL,'Iowa Park, TX',24980,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59343,NULL,'Iowa Park, TX 76367',24980,222,NULL,51,34070,0);
INSERT INTO "django_geo_db_location" VALUES(59344,NULL,'Kamay, TX',24981,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59345,NULL,'Kamay, TX 76369',24981,222,NULL,51,34071,0);
INSERT INTO "django_geo_db_location" VALUES(59346,NULL,'Megargel, TX',24982,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59347,NULL,'Megargel, TX 76370',24982,222,NULL,51,34072,0);
INSERT INTO "django_geo_db_location" VALUES(59348,NULL,'Munday, TX',24983,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59349,NULL,'Munday, TX 76371',24983,222,NULL,51,34073,0);
INSERT INTO "django_geo_db_location" VALUES(59350,NULL,'Newcastle, TX',24984,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59351,NULL,'Newcastle, TX 76372',24984,222,NULL,51,34074,0);
INSERT INTO "django_geo_db_location" VALUES(59352,NULL,'Oklaunion, TX',24985,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59353,NULL,'Oklaunion, TX 76373',24985,222,NULL,51,34075,0);
INSERT INTO "django_geo_db_location" VALUES(59354,NULL,'Olney, TX',24986,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59355,NULL,'Olney, TX 76374',24986,222,NULL,51,34076,0);
INSERT INTO "django_geo_db_location" VALUES(59356,NULL,'Petrolia, TX',24987,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59357,NULL,'Petrolia, TX 76377',24987,222,NULL,51,34077,0);
INSERT INTO "django_geo_db_location" VALUES(59358,NULL,'Scotland, TX',24988,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59359,NULL,'Scotland, TX 76379',24988,222,NULL,51,34078,0);
INSERT INTO "django_geo_db_location" VALUES(59360,NULL,'Seymour, TX',24989,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59361,NULL,'Seymour, TX 76380',24989,222,NULL,51,34079,0);
INSERT INTO "django_geo_db_location" VALUES(59362,NULL,'Vernon, TX',24990,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59363,NULL,'Vernon, TX 76384',24990,222,NULL,51,34080,0);
INSERT INTO "django_geo_db_location" VALUES(59364,NULL,'Vernon, TX 76385',24990,222,NULL,51,34081,0);
INSERT INTO "django_geo_db_location" VALUES(59365,NULL,'Weinert, TX',24991,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59366,NULL,'Weinert, TX 76388',24991,222,NULL,51,34082,0);
INSERT INTO "django_geo_db_location" VALUES(59367,NULL,'Windthorst, TX',24992,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59368,NULL,'Windthorst, TX 76389',24992,222,NULL,51,34083,0);
INSERT INTO "django_geo_db_location" VALUES(59369,NULL,'Stephenville, TX',24993,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59370,NULL,'Stephenville, TX 76401',24993,222,NULL,51,34084,0);
INSERT INTO "django_geo_db_location" VALUES(59371,NULL,'Stephenville, TX 76402',24993,222,NULL,51,34085,0);
INSERT INTO "django_geo_db_location" VALUES(59372,NULL,'Albany, TX',24994,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59373,NULL,'Albany, TX 76420',24994,222,NULL,51,34086,0);
INSERT INTO "django_geo_db_location" VALUES(59374,NULL,'Breckenridge, TX',24995,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59375,NULL,'Breckenridge, TX 76424',24995,222,NULL,51,34087,0);
INSERT INTO "django_geo_db_location" VALUES(59376,NULL,'Bridgeport, TX',24996,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59377,NULL,'Bridgeport, TX 76426',24996,222,NULL,51,34088,0);
INSERT INTO "django_geo_db_location" VALUES(59378,NULL,'Bryson, TX',24997,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59379,NULL,'Bryson, TX 76427',24997,222,NULL,51,34089,0);
INSERT INTO "django_geo_db_location" VALUES(59380,NULL,'Caddo, TX',24998,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59381,NULL,'Caddo, TX 76429',24998,222,NULL,51,34090,0);
INSERT INTO "django_geo_db_location" VALUES(59382,NULL,'Albany, TX 76430',24994,222,NULL,51,34091,0);
INSERT INTO "django_geo_db_location" VALUES(59383,NULL,'Chico, TX',24999,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59384,NULL,'Chico, TX 76431',24999,222,NULL,51,34092,0);
INSERT INTO "django_geo_db_location" VALUES(59385,NULL,'Blanket, TX',25000,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59386,NULL,'Blanket, TX 76432',25000,222,NULL,51,34093,0);
INSERT INTO "django_geo_db_location" VALUES(59387,NULL,'Bluff Dale, TX',25001,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59388,NULL,'Bluff Dale, TX 76433',25001,222,NULL,51,34094,0);
INSERT INTO "django_geo_db_location" VALUES(59389,NULL,'Carbon, TX',25002,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59390,NULL,'Carbon, TX 76435',25002,222,NULL,51,34095,0);
INSERT INTO "django_geo_db_location" VALUES(59391,NULL,'Carlton, TX',25003,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59392,NULL,'Carlton, TX 76436',25003,222,NULL,51,34096,0);
INSERT INTO "django_geo_db_location" VALUES(59393,NULL,'Cisco, TX',25004,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59394,NULL,'Cisco, TX 76437',25004,222,NULL,51,34097,0);
INSERT INTO "django_geo_db_location" VALUES(59395,NULL,'Dennis, TX',25005,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59396,NULL,'Dennis, TX 76439',25005,222,NULL,51,34098,0);
INSERT INTO "django_geo_db_location" VALUES(59397,NULL,'Comanche, TX',25006,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59398,NULL,'Comanche, TX 76442',25006,222,NULL,51,34099,0);
INSERT INTO "django_geo_db_location" VALUES(59399,NULL,'Cross Plains, TX',25007,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59400,NULL,'Cross Plains, TX 76443',25007,222,NULL,51,34100,0);
INSERT INTO "django_geo_db_location" VALUES(59401,NULL,'De Leon, TX',25008,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59402,NULL,'De Leon, TX 76444',25008,222,NULL,51,34101,0);
INSERT INTO "django_geo_db_location" VALUES(59403,NULL,'Desdemona, TX',25009,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59404,NULL,'Desdemona, TX 76445',25009,222,NULL,51,34102,0);
INSERT INTO "django_geo_db_location" VALUES(59405,NULL,'Dublin, TX',25010,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59406,NULL,'Dublin, TX 76446',25010,222,NULL,51,34103,0);
INSERT INTO "django_geo_db_location" VALUES(59407,NULL,'Eastland, TX',25011,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59408,NULL,'Eastland, TX 76448',25011,222,NULL,51,34104,0);
INSERT INTO "django_geo_db_location" VALUES(59409,NULL,'Graford, TX',25012,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59410,NULL,'Graford, TX 76449',25012,222,NULL,51,34105,0);
INSERT INTO "django_geo_db_location" VALUES(59411,NULL,'Graham, TX',25013,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59412,NULL,'Graham, TX 76450',25013,222,NULL,51,34106,0);
INSERT INTO "django_geo_db_location" VALUES(59413,NULL,'Energy, TX',25014,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59414,NULL,'Energy, TX 76452',25014,222,NULL,51,34107,0);
INSERT INTO "django_geo_db_location" VALUES(59415,NULL,'Gordon, TX',25015,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59416,NULL,'Gordon, TX 76453',25015,222,NULL,51,34108,0);
INSERT INTO "django_geo_db_location" VALUES(59417,NULL,'Gorman, TX',25016,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59418,NULL,'Gorman, TX 76454',25016,222,NULL,51,34109,0);
INSERT INTO "django_geo_db_location" VALUES(59419,NULL,'Gustine, TX',25017,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59420,NULL,'Gustine, TX 76455',25017,222,NULL,51,34110,0);
INSERT INTO "django_geo_db_location" VALUES(59421,NULL,'Hico, TX',25018,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59422,NULL,'Hico, TX 76457',25018,222,NULL,51,34111,0);
INSERT INTO "django_geo_db_location" VALUES(59423,NULL,'Jacksboro, TX',25019,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59424,NULL,'Jacksboro, TX 76458',25019,222,NULL,51,34112,0);
INSERT INTO "django_geo_db_location" VALUES(59425,NULL,'Jermyn, TX',25020,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59426,NULL,'Jermyn, TX 76459',25020,222,NULL,51,34113,0);
INSERT INTO "django_geo_db_location" VALUES(59427,NULL,'Loving, TX',25021,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59428,NULL,'Loving, TX 76460',25021,222,NULL,51,34114,0);
INSERT INTO "django_geo_db_location" VALUES(59429,NULL,'Lingleville, TX',25022,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59430,NULL,'Lingleville, TX 76461',25022,222,NULL,51,34115,0);
INSERT INTO "django_geo_db_location" VALUES(59431,NULL,'Lipan, TX',25023,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59432,NULL,'Lipan, TX 76462',25023,222,NULL,51,34116,0);
INSERT INTO "django_geo_db_location" VALUES(59433,NULL,'Mingus, TX',25024,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59434,NULL,'Mingus, TX 76463',25024,222,NULL,51,34117,0);
INSERT INTO "django_geo_db_location" VALUES(59435,NULL,'Moran, TX',25025,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59436,NULL,'Moran, TX 76464',25025,222,NULL,51,34118,0);
INSERT INTO "django_geo_db_location" VALUES(59437,NULL,'Morgan Mill, TX',25026,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59438,NULL,'Morgan Mill, TX 76465',25026,222,NULL,51,34119,0);
INSERT INTO "django_geo_db_location" VALUES(59439,NULL,'Olden, TX',25027,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59440,NULL,'Olden, TX 76466',25027,222,NULL,51,34120,0);
INSERT INTO "django_geo_db_location" VALUES(59441,NULL,'Paluxy, TX',25028,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59442,NULL,'Paluxy, TX 76467',25028,222,NULL,51,34121,0);
INSERT INTO "django_geo_db_location" VALUES(59443,NULL,'Proctor, TX',25029,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59444,NULL,'Proctor, TX 76468',25029,222,NULL,51,34122,0);
INSERT INTO "django_geo_db_location" VALUES(59445,NULL,'Putnam, TX',25030,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59446,NULL,'Putnam, TX 76469',25030,222,NULL,51,34123,0);
INSERT INTO "django_geo_db_location" VALUES(59447,NULL,'Ranger, TX',25031,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59448,NULL,'Ranger, TX 76470',25031,222,NULL,51,34124,0);
INSERT INTO "django_geo_db_location" VALUES(59449,NULL,'Rising Star, TX',25032,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59450,NULL,'Rising Star, TX 76471',25032,222,NULL,51,34125,0);
INSERT INTO "django_geo_db_location" VALUES(59451,NULL,'Santo, TX',25033,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59452,NULL,'Santo, TX 76472',25033,222,NULL,51,34126,0);
INSERT INTO "django_geo_db_location" VALUES(59453,NULL,'Sidney, TX',25034,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59454,NULL,'Sidney, TX 76474',25034,222,NULL,51,34127,0);
INSERT INTO "django_geo_db_location" VALUES(59455,NULL,'Strawn, TX',25035,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59456,NULL,'Strawn, TX 76475',25035,222,NULL,51,34128,0);
INSERT INTO "django_geo_db_location" VALUES(59457,NULL,'Tolar, TX',25036,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59458,NULL,'Tolar, TX 76476',25036,222,NULL,51,34129,0);
INSERT INTO "django_geo_db_location" VALUES(59459,NULL,'South Bend, TX',25037,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59460,NULL,'South Bend, TX 76481',25037,222,NULL,51,34130,0);
INSERT INTO "django_geo_db_location" VALUES(59461,NULL,'Throckmorton, TX',25038,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59462,NULL,'Throckmorton, TX 76483',25038,222,NULL,51,34131,0);
INSERT INTO "django_geo_db_location" VALUES(59463,NULL,'Palo Pinto, TX',25039,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59464,NULL,'Palo Pinto, TX 76484',25039,222,NULL,51,34132,0);
INSERT INTO "django_geo_db_location" VALUES(59465,NULL,'Peaster, TX',25040,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59466,NULL,'Peaster, TX 76485',25040,222,NULL,51,34133,0);
INSERT INTO "django_geo_db_location" VALUES(59467,NULL,'Perrin, TX',25041,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59468,NULL,'Perrin, TX 76486',25041,222,NULL,51,34134,0);
INSERT INTO "django_geo_db_location" VALUES(59469,NULL,'Poolville, TX',25042,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59470,NULL,'Poolville, TX 76487',25042,222,NULL,51,34135,0);
INSERT INTO "django_geo_db_location" VALUES(59471,NULL,'Whitt, TX',25043,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59472,NULL,'Whitt, TX 76490',25043,222,NULL,51,34136,0);
INSERT INTO "django_geo_db_location" VALUES(59473,NULL,'Woodson, TX',25044,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59474,NULL,'Woodson, TX 76491',25044,222,NULL,51,34137,0);
INSERT INTO "django_geo_db_location" VALUES(59475,NULL,'Temple, TX',25045,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59476,NULL,'Temple, TX 76501',25045,222,NULL,51,34138,0);
INSERT INTO "django_geo_db_location" VALUES(59477,NULL,'Temple, TX 76502',25045,222,NULL,51,34139,0);
INSERT INTO "django_geo_db_location" VALUES(59478,NULL,'Temple, TX 76503',25045,222,NULL,51,34140,0);
INSERT INTO "django_geo_db_location" VALUES(59479,NULL,'Temple, TX 76504',25045,222,NULL,51,34141,0);
INSERT INTO "django_geo_db_location" VALUES(59480,NULL,'Temple, TX 76505',25045,222,NULL,51,34142,0);
INSERT INTO "django_geo_db_location" VALUES(59481,NULL,'Temple, TX 76508',25045,222,NULL,51,34143,0);
INSERT INTO "django_geo_db_location" VALUES(59482,NULL,'Bartlett, TX',25046,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59483,NULL,'Bartlett, TX 76511',25046,222,NULL,51,34144,0);
INSERT INTO "django_geo_db_location" VALUES(59484,NULL,'Belton, TX',25047,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59485,NULL,'Belton, TX 76513',25047,222,NULL,51,34145,0);
INSERT INTO "django_geo_db_location" VALUES(59486,NULL,'Buckholts, TX',25048,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59487,NULL,'Buckholts, TX 76518',25048,222,NULL,51,34146,0);
INSERT INTO "django_geo_db_location" VALUES(59488,NULL,'Burlington, TX',25049,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59489,NULL,'Burlington, TX 76519',25049,222,NULL,51,34147,0);
INSERT INTO "django_geo_db_location" VALUES(59490,NULL,'Cameron, TX',25050,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59491,NULL,'Cameron, TX 76520',25050,222,NULL,51,34148,0);
INSERT INTO "django_geo_db_location" VALUES(59492,NULL,'Copperas Cove, TX',25051,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59493,NULL,'Copperas Cove, TX 76522',25051,222,NULL,51,34149,0);
INSERT INTO "django_geo_db_location" VALUES(59494,NULL,'Davilla, TX',25052,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59495,NULL,'Davilla, TX 76523',25052,222,NULL,51,34150,0);
INSERT INTO "django_geo_db_location" VALUES(59496,NULL,'Eddy, TX',25053,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59497,NULL,'Eddy, TX 76524',25053,222,NULL,51,34151,0);
INSERT INTO "django_geo_db_location" VALUES(59498,NULL,'Evant, TX',25054,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59499,NULL,'Evant, TX 76525',25054,222,NULL,51,34152,0);
INSERT INTO "django_geo_db_location" VALUES(59500,NULL,'Flat, TX',25055,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59501,NULL,'Flat, TX 76526',25055,222,NULL,51,34153,0);
INSERT INTO "django_geo_db_location" VALUES(59502,NULL,'Florence, TX',25056,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59503,NULL,'Florence, TX 76527',25056,222,NULL,51,34154,0);
INSERT INTO "django_geo_db_location" VALUES(59504,NULL,'Gatesville, TX',25057,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59505,NULL,'Gatesville, TX 76528',25057,222,NULL,51,34155,0);
INSERT INTO "django_geo_db_location" VALUES(59506,NULL,'Granger, TX',25058,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59507,NULL,'Granger, TX 76530',25058,222,NULL,51,34156,0);
INSERT INTO "django_geo_db_location" VALUES(59508,NULL,'Hamilton, TX',25059,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59509,NULL,'Hamilton, TX 76531',25059,222,NULL,51,34157,0);
INSERT INTO "django_geo_db_location" VALUES(59510,NULL,'Heidenheimer, TX',25060,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59511,NULL,'Heidenheimer, TX 76533',25060,222,NULL,51,34158,0);
INSERT INTO "django_geo_db_location" VALUES(59512,NULL,'Holland, TX',25061,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59513,NULL,'Holland, TX 76534',25061,222,NULL,51,34159,0);
INSERT INTO "django_geo_db_location" VALUES(59514,NULL,'Jarrell, TX',25062,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59515,NULL,'Jarrell, TX 76537',25062,222,NULL,51,34160,0);
INSERT INTO "django_geo_db_location" VALUES(59516,NULL,'Jonesboro, TX',25063,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59517,NULL,'Jonesboro, TX 76538',25063,222,NULL,51,34161,0);
INSERT INTO "django_geo_db_location" VALUES(59518,NULL,'Kempner, TX',25064,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59519,NULL,'Kempner, TX 76539',25064,222,NULL,51,34162,0);
INSERT INTO "django_geo_db_location" VALUES(59520,NULL,'Killeen, TX',25065,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59521,NULL,'Killeen, TX 76540',25065,222,NULL,51,34163,0);
INSERT INTO "django_geo_db_location" VALUES(59522,NULL,'Killeen, TX 76541',25065,222,NULL,51,34164,0);
INSERT INTO "django_geo_db_location" VALUES(59523,NULL,'Killeen, TX 76542',25065,222,NULL,51,34165,0);
INSERT INTO "django_geo_db_location" VALUES(59524,NULL,'Killeen, TX 76543',25065,222,NULL,51,34166,0);
INSERT INTO "django_geo_db_location" VALUES(59525,NULL,'Killeen, TX 76544',25065,222,NULL,51,34167,0);
INSERT INTO "django_geo_db_location" VALUES(59526,NULL,'Killeen, TX 76545',25065,222,NULL,51,34168,0);
INSERT INTO "django_geo_db_location" VALUES(59527,NULL,'Killeen, TX 76546',25065,222,NULL,51,34169,0);
INSERT INTO "django_geo_db_location" VALUES(59528,NULL,'Killeen, TX 76547',25065,222,NULL,51,34170,0);
INSERT INTO "django_geo_db_location" VALUES(59529,NULL,'Harker Heights, TX',25066,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59530,NULL,'Harker Heights, TX 76548',25066,222,NULL,51,34171,0);
INSERT INTO "django_geo_db_location" VALUES(59531,NULL,'Killeen, TX 76549',25065,222,NULL,51,34172,0);
INSERT INTO "django_geo_db_location" VALUES(59532,NULL,'Lampasas, TX',25067,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59533,NULL,'Lampasas, TX 76550',25067,222,NULL,51,34173,0);
INSERT INTO "django_geo_db_location" VALUES(59534,NULL,'Leon Junction, TX',25068,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59535,NULL,'Leon Junction, TX 76552',25068,222,NULL,51,34174,0);
INSERT INTO "django_geo_db_location" VALUES(59536,NULL,'Little River, TX',25069,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59537,NULL,'Little River, TX 76554',25069,222,NULL,51,34175,0);
INSERT INTO "django_geo_db_location" VALUES(59538,NULL,'Maysfield, TX',25070,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59539,NULL,'Maysfield, TX 76555',25070,222,NULL,51,34176,0);
INSERT INTO "django_geo_db_location" VALUES(59540,NULL,'Milano, TX',25071,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59541,NULL,'Milano, TX 76556',25071,222,NULL,51,34177,0);
INSERT INTO "django_geo_db_location" VALUES(59542,NULL,'Moody, TX',25072,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59543,NULL,'Moody, TX 76557',25072,222,NULL,51,34178,0);
INSERT INTO "django_geo_db_location" VALUES(59544,NULL,'Mound, TX',25073,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59545,NULL,'Mound, TX 76558',25073,222,NULL,51,34179,0);
INSERT INTO "django_geo_db_location" VALUES(59546,NULL,'Nolanville, TX',25074,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59547,NULL,'Nolanville, TX 76559',25074,222,NULL,51,34180,0);
INSERT INTO "django_geo_db_location" VALUES(59548,NULL,'Oglesby, TX',25075,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59549,NULL,'Oglesby, TX 76561',25075,222,NULL,51,34181,0);
INSERT INTO "django_geo_db_location" VALUES(59550,NULL,'Pendleton, TX',25076,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59551,NULL,'Pendleton, TX 76564',25076,222,NULL,51,34182,0);
INSERT INTO "django_geo_db_location" VALUES(59552,NULL,'Pottsville, TX',25077,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59553,NULL,'Pottsville, TX 76565',25077,222,NULL,51,34183,0);
INSERT INTO "django_geo_db_location" VALUES(59554,NULL,'Purmela, TX',25078,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59555,NULL,'Purmela, TX 76566',25078,222,NULL,51,34184,0);
INSERT INTO "django_geo_db_location" VALUES(59556,NULL,'Rockdale, TX',25079,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59557,NULL,'Rockdale, TX 76567',25079,222,NULL,51,34185,0);
INSERT INTO "django_geo_db_location" VALUES(59558,NULL,'Rogers, TX',25080,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59559,NULL,'Rogers, TX 76569',25080,222,NULL,51,34186,0);
INSERT INTO "django_geo_db_location" VALUES(59560,NULL,'Rosebud, TX',25081,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59561,NULL,'Rosebud, TX 76570',25081,222,NULL,51,34187,0);
INSERT INTO "django_geo_db_location" VALUES(59562,NULL,'Salado, TX',25082,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59563,NULL,'Salado, TX 76571',25082,222,NULL,51,34188,0);
INSERT INTO "django_geo_db_location" VALUES(59564,NULL,'Schwertner, TX',25083,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59565,NULL,'Schwertner, TX 76573',25083,222,NULL,51,34189,0);
INSERT INTO "django_geo_db_location" VALUES(59566,NULL,'Taylor, TX',25084,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59567,NULL,'Taylor, TX 76574',25084,222,NULL,51,34190,0);
INSERT INTO "django_geo_db_location" VALUES(59568,NULL,'Salado, TX 76576',25082,222,NULL,51,34191,0);
INSERT INTO "django_geo_db_location" VALUES(59569,NULL,'Thorndale, TX',25085,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59570,NULL,'Thorndale, TX 76577',25085,222,NULL,51,34192,0);
INSERT INTO "django_geo_db_location" VALUES(59571,NULL,'Thrall, TX',25086,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59572,NULL,'Thrall, TX 76578',25086,222,NULL,51,34193,0);
INSERT INTO "django_geo_db_location" VALUES(59573,NULL,'Troy, TX',25087,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59574,NULL,'Troy, TX 76579',25087,222,NULL,51,34194,0);
INSERT INTO "django_geo_db_location" VALUES(59575,NULL,'Gatesville, TX 76596',25057,222,NULL,51,34195,0);
INSERT INTO "django_geo_db_location" VALUES(59576,NULL,'Gatesville, TX 76597',25057,222,NULL,51,34196,0);
INSERT INTO "django_geo_db_location" VALUES(59577,NULL,'Gatesville, TX 76598',25057,222,NULL,51,34197,0);
INSERT INTO "django_geo_db_location" VALUES(59578,NULL,'Gatesville, TX 76599',25057,222,NULL,51,34198,0);
INSERT INTO "django_geo_db_location" VALUES(59579,NULL,'Milford, TX',25088,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59580,NULL,'Milford, TX 76607',25088,222,NULL,51,34199,0);
INSERT INTO "django_geo_db_location" VALUES(59581,NULL,'Richland, TX',25089,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59582,NULL,'Richland, TX 76618',25089,222,NULL,51,34200,0);
INSERT INTO "django_geo_db_location" VALUES(59583,NULL,'Abbott, TX',25090,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59584,NULL,'Abbott, TX 76621',25090,222,NULL,51,34201,0);
INSERT INTO "django_geo_db_location" VALUES(59585,NULL,'Aquilla, TX',25091,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59586,NULL,'Aquilla, TX 76622',25091,222,NULL,51,34202,0);
INSERT INTO "django_geo_db_location" VALUES(59587,NULL,'Avalon, TX',25092,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59588,NULL,'Avalon, TX 76623',25092,222,NULL,51,34203,0);
INSERT INTO "django_geo_db_location" VALUES(59589,NULL,'Axtell, TX',25093,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59590,NULL,'Axtell, TX 76624',25093,222,NULL,51,34204,0);
INSERT INTO "django_geo_db_location" VALUES(59591,NULL,'Blooming Grove, TX',25094,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59592,NULL,'Blooming Grove, TX 76626',25094,222,NULL,51,34205,0);
INSERT INTO "django_geo_db_location" VALUES(59593,NULL,'Blum, TX',25095,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59594,NULL,'Blum, TX 76627',25095,222,NULL,51,34206,0);
INSERT INTO "django_geo_db_location" VALUES(59595,NULL,'Brandon, TX',25096,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59596,NULL,'Brandon, TX 76628',25096,222,NULL,51,34207,0);
INSERT INTO "django_geo_db_location" VALUES(59597,NULL,'Bremond, TX',25097,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59598,NULL,'Bremond, TX 76629',25097,222,NULL,51,34208,0);
INSERT INTO "django_geo_db_location" VALUES(59599,NULL,'Bruceville, TX',25098,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59600,NULL,'Bruceville, TX 76630',25098,222,NULL,51,34209,0);
INSERT INTO "django_geo_db_location" VALUES(59601,NULL,'Bynum, TX',25099,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59602,NULL,'Bynum, TX 76631',25099,222,NULL,51,34210,0);
INSERT INTO "django_geo_db_location" VALUES(59603,NULL,'Chilton, TX',25100,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59604,NULL,'Chilton, TX 76632',25100,222,NULL,51,34211,0);
INSERT INTO "django_geo_db_location" VALUES(59605,NULL,'China Spring, TX',25101,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59606,NULL,'China Spring, TX 76633',25101,222,NULL,51,34212,0);
INSERT INTO "django_geo_db_location" VALUES(59607,NULL,'Clifton, TX',25102,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59608,NULL,'Clifton, TX 76634',25102,222,NULL,51,34213,0);
INSERT INTO "django_geo_db_location" VALUES(59609,NULL,'Coolidge, TX',25103,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59610,NULL,'Coolidge, TX 76635',25103,222,NULL,51,34214,0);
INSERT INTO "django_geo_db_location" VALUES(59611,NULL,'Covington, TX',25104,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59612,NULL,'Covington, TX 76636',25104,222,NULL,51,34215,0);
INSERT INTO "django_geo_db_location" VALUES(59613,NULL,'Cranfills Gap, TX',25105,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59614,NULL,'Cranfills Gap, TX 76637',25105,222,NULL,51,34216,0);
INSERT INTO "django_geo_db_location" VALUES(59615,NULL,'Crawford, TX',25106,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59616,NULL,'Crawford, TX 76638',25106,222,NULL,51,34217,0);
INSERT INTO "django_geo_db_location" VALUES(59617,NULL,'Dawson, TX',25107,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59618,NULL,'Dawson, TX 76639',25107,222,NULL,51,34218,0);
INSERT INTO "django_geo_db_location" VALUES(59619,NULL,'Elm Mott, TX',25108,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59620,NULL,'Elm Mott, TX 76640',25108,222,NULL,51,34219,0);
INSERT INTO "django_geo_db_location" VALUES(59621,NULL,'Frost, TX',25109,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59622,NULL,'Frost, TX 76641',25109,222,NULL,51,34220,0);
INSERT INTO "django_geo_db_location" VALUES(59623,NULL,'Groesbeck, TX',25110,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59624,NULL,'Groesbeck, TX 76642',25110,222,NULL,51,34221,0);
INSERT INTO "django_geo_db_location" VALUES(59625,NULL,'Hewitt, TX',25111,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59626,NULL,'Hewitt, TX 76643',25111,222,NULL,51,34222,0);
INSERT INTO "django_geo_db_location" VALUES(59627,NULL,'Laguna Park, TX',25112,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59628,NULL,'Laguna Park, TX 76644',25112,222,NULL,51,34223,0);
INSERT INTO "django_geo_db_location" VALUES(59629,NULL,'Hillsboro, TX',25113,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59630,NULL,'Hillsboro, TX 76645',25113,222,NULL,51,34224,0);
INSERT INTO "django_geo_db_location" VALUES(59631,NULL,'Hubbard, TX',25114,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59632,NULL,'Hubbard, TX 76648',25114,222,NULL,51,34225,0);
INSERT INTO "django_geo_db_location" VALUES(59633,NULL,'Iredell, TX',25115,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59634,NULL,'Iredell, TX 76649',25115,222,NULL,51,34226,0);
INSERT INTO "django_geo_db_location" VALUES(59635,NULL,'Irene, TX',25116,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59636,NULL,'Irene, TX 76650',25116,222,NULL,51,34227,0);
INSERT INTO "django_geo_db_location" VALUES(59637,NULL,'Italy, TX',25117,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59638,NULL,'Italy, TX 76651',25117,222,NULL,51,34228,0);
INSERT INTO "django_geo_db_location" VALUES(59639,NULL,'Kopperl, TX',25118,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59640,NULL,'Kopperl, TX 76652',25118,222,NULL,51,34229,0);
INSERT INTO "django_geo_db_location" VALUES(59641,NULL,'Kosse, TX',25119,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59642,NULL,'Kosse, TX 76653',25119,222,NULL,51,34230,0);
INSERT INTO "django_geo_db_location" VALUES(59643,NULL,'Leroy, TX',25120,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59644,NULL,'Leroy, TX 76654',25120,222,NULL,51,34231,0);
INSERT INTO "django_geo_db_location" VALUES(59645,NULL,'Lorena, TX',25121,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59646,NULL,'Lorena, TX 76655',25121,222,NULL,51,34232,0);
INSERT INTO "django_geo_db_location" VALUES(59647,NULL,'Lott, TX',25122,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59648,NULL,'Lott, TX 76656',25122,222,NULL,51,34233,0);
INSERT INTO "django_geo_db_location" VALUES(59649,NULL,'McGregor, TX',25123,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59650,NULL,'McGregor, TX 76657',25123,222,NULL,51,34234,0);
INSERT INTO "django_geo_db_location" VALUES(59651,NULL,'Malone, TX',25124,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59652,NULL,'Malone, TX 76660',25124,222,NULL,51,34235,0);
INSERT INTO "django_geo_db_location" VALUES(59653,NULL,'Marlin, TX',25125,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59654,NULL,'Marlin, TX 76661',25125,222,NULL,51,34236,0);
INSERT INTO "django_geo_db_location" VALUES(59655,NULL,'Mart, TX',25126,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59656,NULL,'Mart, TX 76664',25126,222,NULL,51,34237,0);
INSERT INTO "django_geo_db_location" VALUES(59657,NULL,'Meridian, TX',25127,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59658,NULL,'Meridian, TX 76665',25127,222,NULL,51,34238,0);
INSERT INTO "django_geo_db_location" VALUES(59659,NULL,'Mertens, TX',25128,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59660,NULL,'Mertens, TX 76666',25128,222,NULL,51,34239,0);
INSERT INTO "django_geo_db_location" VALUES(59661,NULL,'Mexia, TX',25129,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59662,NULL,'Mexia, TX 76667',25129,222,NULL,51,34240,0);
INSERT INTO "django_geo_db_location" VALUES(59663,NULL,'Milford, TX 76670',25088,222,NULL,51,34241,0);
INSERT INTO "django_geo_db_location" VALUES(59664,NULL,'Morgan, TX',25130,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59665,NULL,'Morgan, TX 76671',25130,222,NULL,51,34242,0);
INSERT INTO "django_geo_db_location" VALUES(59666,NULL,'Mount Calm, TX',25131,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59667,NULL,'Mount Calm, TX 76673',25131,222,NULL,51,34243,0);
INSERT INTO "django_geo_db_location" VALUES(59668,NULL,'Otto, TX',25132,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59669,NULL,'Otto, TX 76675',25132,222,NULL,51,34244,0);
INSERT INTO "django_geo_db_location" VALUES(59670,NULL,'Penelope, TX',25133,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59671,NULL,'Penelope, TX 76676',25133,222,NULL,51,34245,0);
INSERT INTO "django_geo_db_location" VALUES(59672,NULL,'Perry, TX',25134,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59673,NULL,'Perry, TX 76677',25134,222,NULL,51,34246,0);
INSERT INTO "django_geo_db_location" VALUES(59674,NULL,'Prairie Hill, TX',25135,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59675,NULL,'Prairie Hill, TX 76678',25135,222,NULL,51,34247,0);
INSERT INTO "django_geo_db_location" VALUES(59676,NULL,'Purdon, TX',25136,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59677,NULL,'Purdon, TX 76679',25136,222,NULL,51,34248,0);
INSERT INTO "django_geo_db_location" VALUES(59678,NULL,'Reagan, TX',25137,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59679,NULL,'Reagan, TX 76680',25137,222,NULL,51,34249,0);
INSERT INTO "django_geo_db_location" VALUES(59680,NULL,'Richland, TX 76681',25089,222,NULL,51,34250,0);
INSERT INTO "django_geo_db_location" VALUES(59681,NULL,'Riesel, TX',25138,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59682,NULL,'Riesel, TX 76682',25138,222,NULL,51,34251,0);
INSERT INTO "django_geo_db_location" VALUES(59683,NULL,'Riesel, TX 76683',25138,222,NULL,51,34252,0);
INSERT INTO "django_geo_db_location" VALUES(59684,NULL,'Ross, TX',25139,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59685,NULL,'Ross, TX 76684',25139,222,NULL,51,34253,0);
INSERT INTO "django_geo_db_location" VALUES(59686,NULL,'Satin, TX',25140,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59687,NULL,'Satin, TX 76685',25140,222,NULL,51,34254,0);
INSERT INTO "django_geo_db_location" VALUES(59688,NULL,'Tehuacana, TX',25141,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59689,NULL,'Tehuacana, TX 76686',25141,222,NULL,51,34255,0);
INSERT INTO "django_geo_db_location" VALUES(59690,NULL,'Thornton, TX',25142,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59691,NULL,'Thornton, TX 76687',25142,222,NULL,51,34256,0);
INSERT INTO "django_geo_db_location" VALUES(59692,NULL,'Valley Mills, TX',25143,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59693,NULL,'Valley Mills, TX 76689',25143,222,NULL,51,34257,0);
INSERT INTO "django_geo_db_location" VALUES(59694,NULL,'Walnut Springs, TX',25144,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59695,NULL,'Walnut Springs, TX 76690',25144,222,NULL,51,34258,0);
INSERT INTO "django_geo_db_location" VALUES(59696,NULL,'West, TX',25145,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59697,NULL,'West, TX 76691',25145,222,NULL,51,34259,0);
INSERT INTO "django_geo_db_location" VALUES(59698,NULL,'Whitney, TX',25146,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59699,NULL,'Whitney, TX 76692',25146,222,NULL,51,34260,0);
INSERT INTO "django_geo_db_location" VALUES(59700,NULL,'Wortham, TX',25147,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59701,NULL,'Wortham, TX 76693',25147,222,NULL,51,34261,0);
INSERT INTO "django_geo_db_location" VALUES(59702,NULL,'Waco, TX',25148,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59703,NULL,'Waco, TX 76701',25148,222,NULL,51,34262,0);
INSERT INTO "django_geo_db_location" VALUES(59704,NULL,'Waco, TX 76702',25148,222,NULL,51,34263,0);
INSERT INTO "django_geo_db_location" VALUES(59705,NULL,'Waco, TX 76703',25148,222,NULL,51,34264,0);
INSERT INTO "django_geo_db_location" VALUES(59706,NULL,'Waco, TX 76704',25148,222,NULL,51,34265,0);
INSERT INTO "django_geo_db_location" VALUES(59707,NULL,'Waco, TX 76705',25148,222,NULL,51,34266,0);
INSERT INTO "django_geo_db_location" VALUES(59708,NULL,'Waco, TX 76706',25148,222,NULL,51,34267,0);
INSERT INTO "django_geo_db_location" VALUES(59709,NULL,'Waco, TX 76707',25148,222,NULL,51,34268,0);
INSERT INTO "django_geo_db_location" VALUES(59710,NULL,'Waco, TX 76708',25148,222,NULL,51,34269,0);
INSERT INTO "django_geo_db_location" VALUES(59711,NULL,'Waco, TX 76710',25148,222,NULL,51,34270,0);
INSERT INTO "django_geo_db_location" VALUES(59712,NULL,'Waco, TX 76711',25148,222,NULL,51,34271,0);
INSERT INTO "django_geo_db_location" VALUES(59713,NULL,'Woodway, TX',25149,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59714,NULL,'Woodway, TX 76712',25149,222,NULL,51,34272,0);
INSERT INTO "django_geo_db_location" VALUES(59715,NULL,'Waco, TX 76714',25148,222,NULL,51,34273,0);
INSERT INTO "django_geo_db_location" VALUES(59716,NULL,'Waco, TX 76715',25148,222,NULL,51,34274,0);
INSERT INTO "django_geo_db_location" VALUES(59717,NULL,'Waco, TX 76716',25148,222,NULL,51,34275,0);
INSERT INTO "django_geo_db_location" VALUES(59718,NULL,'Waco, TX 76795',25148,222,NULL,51,34276,0);
INSERT INTO "django_geo_db_location" VALUES(59719,NULL,'Waco, TX 76797',25148,222,NULL,51,34277,0);
INSERT INTO "django_geo_db_location" VALUES(59720,NULL,'Waco, TX 76798',25148,222,NULL,51,34278,0);
INSERT INTO "django_geo_db_location" VALUES(59721,NULL,'Waco, TX 76799',25148,222,NULL,51,34279,0);
INSERT INTO "django_geo_db_location" VALUES(59722,NULL,'Brownwood, TX',25150,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59723,NULL,'Brownwood, TX 76801',25150,222,NULL,51,34280,0);
INSERT INTO "django_geo_db_location" VALUES(59724,NULL,'Early, TX',25151,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59725,NULL,'Early, TX 76802',25151,222,NULL,51,34281,0);
INSERT INTO "django_geo_db_location" VALUES(59726,NULL,'Brownwood, TX 76803',25150,222,NULL,51,34282,0);
INSERT INTO "django_geo_db_location" VALUES(59727,NULL,'Brownwood, TX 76804',25150,222,NULL,51,34283,0);
INSERT INTO "django_geo_db_location" VALUES(59728,NULL,'Art, TX',25152,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59729,NULL,'Art, TX 76820',25152,222,NULL,51,34284,0);
INSERT INTO "django_geo_db_location" VALUES(59730,NULL,'Ballinger, TX',25153,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59731,NULL,'Ballinger, TX 76821',25153,222,NULL,51,34285,0);
INSERT INTO "django_geo_db_location" VALUES(59732,NULL,'Bangs, TX',25154,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59733,NULL,'Bangs, TX 76823',25154,222,NULL,51,34286,0);
INSERT INTO "django_geo_db_location" VALUES(59734,NULL,'Bend, TX',25155,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59735,NULL,'Bend, TX 76824',25155,222,NULL,51,34287,0);
INSERT INTO "django_geo_db_location" VALUES(59736,NULL,'Brady, TX',25156,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59737,NULL,'Brady, TX 76825',25156,222,NULL,51,34288,0);
INSERT INTO "django_geo_db_location" VALUES(59738,NULL,'Brookesmith, TX',25157,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59739,NULL,'Brookesmith, TX 76827',25157,222,NULL,51,34289,0);
INSERT INTO "django_geo_db_location" VALUES(59740,NULL,'Burkett, TX',25158,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59741,NULL,'Burkett, TX 76828',25158,222,NULL,51,34290,0);
INSERT INTO "django_geo_db_location" VALUES(59742,NULL,'Castell, TX',25159,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59743,NULL,'Castell, TX 76831',25159,222,NULL,51,34291,0);
INSERT INTO "django_geo_db_location" VALUES(59744,NULL,'Cherokee, TX',25160,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59745,NULL,'Cherokee, TX 76832',25160,222,NULL,51,34292,0);
INSERT INTO "django_geo_db_location" VALUES(59746,NULL,'Coleman, TX',25161,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59747,NULL,'Coleman, TX 76834',25161,222,NULL,51,34293,0);
INSERT INTO "django_geo_db_location" VALUES(59748,NULL,'Doole, TX',25162,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59749,NULL,'Doole, TX 76836',25162,222,NULL,51,34294,0);
INSERT INTO "django_geo_db_location" VALUES(59750,NULL,'Eden, TX',25163,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59751,NULL,'Eden, TX 76837',25163,222,NULL,51,34295,0);
INSERT INTO "django_geo_db_location" VALUES(59752,NULL,'Fort McKavett, TX',25164,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59753,NULL,'Fort McKavett, TX 76841',25164,222,NULL,51,34296,0);
INSERT INTO "django_geo_db_location" VALUES(59754,NULL,'Fredonia, TX',25165,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59755,NULL,'Fredonia, TX 76842',25165,222,NULL,51,34297,0);
INSERT INTO "django_geo_db_location" VALUES(59756,NULL,'Goldthwaite, TX',25166,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59757,NULL,'Goldthwaite, TX 76844',25166,222,NULL,51,34298,0);
INSERT INTO "django_geo_db_location" VALUES(59758,NULL,'Gouldbusk, TX',25167,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59759,NULL,'Gouldbusk, TX 76845',25167,222,NULL,51,34299,0);
INSERT INTO "django_geo_db_location" VALUES(59760,NULL,'Hext, TX',25168,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59761,NULL,'Hext, TX 76848',25168,222,NULL,51,34300,0);
INSERT INTO "django_geo_db_location" VALUES(59762,NULL,'Junction, TX',25169,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59763,NULL,'Junction, TX 76849',25169,222,NULL,51,34301,0);
INSERT INTO "django_geo_db_location" VALUES(59764,NULL,'Lohn, TX',25170,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59765,NULL,'Lohn, TX 76852',25170,222,NULL,51,34302,0);
INSERT INTO "django_geo_db_location" VALUES(59766,NULL,'Lometa, TX',25171,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59767,NULL,'Lometa, TX 76853',25171,222,NULL,51,34303,0);
INSERT INTO "django_geo_db_location" VALUES(59768,NULL,'London, TX',25172,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59769,NULL,'London, TX 76854',25172,222,NULL,51,34304,0);
INSERT INTO "django_geo_db_location" VALUES(59770,NULL,'Lowake, TX',25173,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59771,NULL,'Lowake, TX 76855',25173,222,NULL,51,34305,0);
INSERT INTO "django_geo_db_location" VALUES(59772,NULL,'Mason, TX',25174,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59773,NULL,'Mason, TX 76856',25174,222,NULL,51,34306,0);
INSERT INTO "django_geo_db_location" VALUES(59774,NULL,'May, TX',25175,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59775,NULL,'May, TX 76857',25175,222,NULL,51,34307,0);
INSERT INTO "django_geo_db_location" VALUES(59776,NULL,'Melvin, TX',25176,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59777,NULL,'Melvin, TX 76858',25176,222,NULL,51,34308,0);
INSERT INTO "django_geo_db_location" VALUES(59778,NULL,'Menard, TX',25177,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59779,NULL,'Menard, TX 76859',25177,222,NULL,51,34309,0);
INSERT INTO "django_geo_db_location" VALUES(59780,NULL,'Miles, TX',25178,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59781,NULL,'Miles, TX 76861',25178,222,NULL,51,34310,0);
INSERT INTO "django_geo_db_location" VALUES(59782,NULL,'Millersview, TX',25179,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59783,NULL,'Millersview, TX 76862',25179,222,NULL,51,34311,0);
INSERT INTO "django_geo_db_location" VALUES(59784,NULL,'Mullin, TX',25180,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59785,NULL,'Mullin, TX 76864',25180,222,NULL,51,34312,0);
INSERT INTO "django_geo_db_location" VALUES(59786,NULL,'Norton, TX',25181,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59787,NULL,'Norton, TX 76865',25181,222,NULL,51,34313,0);
INSERT INTO "django_geo_db_location" VALUES(59788,NULL,'Paint Rock, TX',25182,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59789,NULL,'Paint Rock, TX 76866',25182,222,NULL,51,34314,0);
INSERT INTO "django_geo_db_location" VALUES(59790,NULL,'Pear Valley, TX',25183,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59791,NULL,'Pear Valley, TX 76867',25183,222,NULL,51,34315,0);
INSERT INTO "django_geo_db_location" VALUES(59792,NULL,'Pontotoc, TX',25184,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59793,NULL,'Pontotoc, TX 76869',25184,222,NULL,51,34316,0);
INSERT INTO "django_geo_db_location" VALUES(59794,NULL,'Priddy, TX',25185,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59795,NULL,'Priddy, TX 76870',25185,222,NULL,51,34317,0);
INSERT INTO "django_geo_db_location" VALUES(59796,NULL,'Richland Springs, TX',25186,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59797,NULL,'Richland Springs, TX 76871',25186,222,NULL,51,34318,0);
INSERT INTO "django_geo_db_location" VALUES(59798,NULL,'Rochelle, TX',25187,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59799,NULL,'Rochelle, TX 76872',25187,222,NULL,51,34319,0);
INSERT INTO "django_geo_db_location" VALUES(59800,NULL,'Rockwood, TX',25188,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59801,NULL,'Rockwood, TX 76873',25188,222,NULL,51,34320,0);
INSERT INTO "django_geo_db_location" VALUES(59802,NULL,'Roosevelt, TX',25189,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59803,NULL,'Roosevelt, TX 76874',25189,222,NULL,51,34321,0);
INSERT INTO "django_geo_db_location" VALUES(59804,NULL,'Rowena, TX',25190,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59805,NULL,'Rowena, TX 76875',25190,222,NULL,51,34322,0);
INSERT INTO "django_geo_db_location" VALUES(59806,NULL,'San Saba, TX',25191,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59807,NULL,'San Saba, TX 76877',25191,222,NULL,51,34323,0);
INSERT INTO "django_geo_db_location" VALUES(59808,NULL,'Santa Anna, TX',25192,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59809,NULL,'Santa Anna, TX 76878',25192,222,NULL,51,34324,0);
INSERT INTO "django_geo_db_location" VALUES(59810,NULL,'Star, TX',25193,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59811,NULL,'Star, TX 76880',25193,222,NULL,51,34325,0);
INSERT INTO "django_geo_db_location" VALUES(59812,NULL,'Talpa, TX',25194,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59813,NULL,'Talpa, TX 76882',25194,222,NULL,51,34326,0);
INSERT INTO "django_geo_db_location" VALUES(59814,NULL,'Telegraph, TX',25195,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59815,NULL,'Telegraph, TX 76883',25195,222,NULL,51,34327,0);
INSERT INTO "django_geo_db_location" VALUES(59816,NULL,'Valera, TX',25196,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59817,NULL,'Valera, TX 76884',25196,222,NULL,51,34328,0);
INSERT INTO "django_geo_db_location" VALUES(59818,NULL,'Valley Spring, TX',25197,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59819,NULL,'Valley Spring, TX 76885',25197,222,NULL,51,34329,0);
INSERT INTO "django_geo_db_location" VALUES(59820,NULL,'Veribest, TX',25198,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59821,NULL,'Veribest, TX 76886',25198,222,NULL,51,34330,0);
INSERT INTO "django_geo_db_location" VALUES(59822,NULL,'Voca, TX',25199,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59823,NULL,'Voca, TX 76887',25199,222,NULL,51,34331,0);
INSERT INTO "django_geo_db_location" VALUES(59824,NULL,'Voss, TX',25200,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59825,NULL,'Voss, TX 76888',25200,222,NULL,51,34332,0);
INSERT INTO "django_geo_db_location" VALUES(59826,NULL,'Zephyr, TX',25201,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59827,NULL,'Zephyr, TX 76890',25201,222,NULL,51,34333,0);
INSERT INTO "django_geo_db_location" VALUES(59828,NULL,'San Angelo, TX',25202,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59829,NULL,'San Angelo, TX 76901',25202,222,NULL,51,34334,0);
INSERT INTO "django_geo_db_location" VALUES(59830,NULL,'San Angelo, TX 76902',25202,222,NULL,51,34335,0);
INSERT INTO "django_geo_db_location" VALUES(59831,NULL,'San Angelo, TX 76903',25202,222,NULL,51,34336,0);
INSERT INTO "django_geo_db_location" VALUES(59832,NULL,'San Angelo, TX 76904',25202,222,NULL,51,34337,0);
INSERT INTO "django_geo_db_location" VALUES(59833,NULL,'San Angelo, TX 76905',25202,222,NULL,51,34338,0);
INSERT INTO "django_geo_db_location" VALUES(59834,NULL,'San Angelo, TX 76906',25202,222,NULL,51,34339,0);
INSERT INTO "django_geo_db_location" VALUES(59835,NULL,'Goodfellow AFB, TX',25203,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59836,NULL,'Goodfellow AFB, TX 76908',25203,222,NULL,51,34340,0);
INSERT INTO "django_geo_db_location" VALUES(59837,NULL,'San Angelo, TX 76909',25202,222,NULL,51,34341,0);
INSERT INTO "django_geo_db_location" VALUES(59838,NULL,'Barnhart, TX',25204,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59839,NULL,'Barnhart, TX 76930',25204,222,NULL,51,34342,0);
INSERT INTO "django_geo_db_location" VALUES(59840,NULL,'Big Lake, TX',25205,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59841,NULL,'Big Lake, TX 76932',25205,222,NULL,51,34343,0);
INSERT INTO "django_geo_db_location" VALUES(59842,NULL,'Bronte, TX',25206,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59843,NULL,'Bronte, TX 76933',25206,222,NULL,51,34344,0);
INSERT INTO "django_geo_db_location" VALUES(59844,NULL,'Carlsbad, TX',25207,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59845,NULL,'Carlsbad, TX 76934',25207,222,NULL,51,34345,0);
INSERT INTO "django_geo_db_location" VALUES(59846,NULL,'Christoval, TX',25208,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59847,NULL,'Christoval, TX 76935',25208,222,NULL,51,34346,0);
INSERT INTO "django_geo_db_location" VALUES(59848,NULL,'Eldorado, TX',25209,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59849,NULL,'Eldorado, TX 76936',25209,222,NULL,51,34347,0);
INSERT INTO "django_geo_db_location" VALUES(59850,NULL,'Eola, TX',25210,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59851,NULL,'Eola, TX 76937',25210,222,NULL,51,34348,0);
INSERT INTO "django_geo_db_location" VALUES(59852,NULL,'Knickerbocker, TX',25211,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59853,NULL,'Knickerbocker, TX 76939',25211,222,NULL,51,34349,0);
INSERT INTO "django_geo_db_location" VALUES(59854,NULL,'Mereta, TX',25212,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59855,NULL,'Mereta, TX 76940',25212,222,NULL,51,34350,0);
INSERT INTO "django_geo_db_location" VALUES(59856,NULL,'Mertzon, TX',25213,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59857,NULL,'Mertzon, TX 76941',25213,222,NULL,51,34351,0);
INSERT INTO "django_geo_db_location" VALUES(59858,NULL,'Ozona, TX',25214,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59859,NULL,'Ozona, TX 76943',25214,222,NULL,51,34352,0);
INSERT INTO "django_geo_db_location" VALUES(59860,NULL,'Robert Lee, TX',25215,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59861,NULL,'Robert Lee, TX 76945',25215,222,NULL,51,34353,0);
INSERT INTO "django_geo_db_location" VALUES(59862,NULL,'Silver, TX',25216,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59863,NULL,'Silver, TX 76949',25216,222,NULL,51,34354,0);
INSERT INTO "django_geo_db_location" VALUES(59864,NULL,'Sonora, TX',25217,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59865,NULL,'Sonora, TX 76950',25217,222,NULL,51,34355,0);
INSERT INTO "django_geo_db_location" VALUES(59866,NULL,'Sterling City, TX',25218,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59867,NULL,'Sterling City, TX 76951',25218,222,NULL,51,34356,0);
INSERT INTO "django_geo_db_location" VALUES(59868,NULL,'Tennyson, TX',25219,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59869,NULL,'Tennyson, TX 76953',25219,222,NULL,51,34357,0);
INSERT INTO "django_geo_db_location" VALUES(59870,NULL,'Vancourt, TX',25220,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59871,NULL,'Vancourt, TX 76955',25220,222,NULL,51,34358,0);
INSERT INTO "django_geo_db_location" VALUES(59872,NULL,'Wall, TX',25221,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59873,NULL,'Wall, TX 76957',25221,222,NULL,51,34359,0);
INSERT INTO "django_geo_db_location" VALUES(59874,NULL,'Water Valley, TX',25222,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59875,NULL,'Water Valley, TX 76958',25222,222,NULL,51,34360,0);
INSERT INTO "django_geo_db_location" VALUES(59876,NULL,'Houston, TX',25223,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(59877,NULL,'Houston, TX 77000',25223,222,NULL,51,34361,0);
INSERT INTO "django_geo_db_location" VALUES(59878,NULL,'Houston, TX 77001',25223,222,NULL,51,34362,0);
INSERT INTO "django_geo_db_location" VALUES(59879,NULL,'Houston, TX 77002',25223,222,NULL,51,34363,0);
INSERT INTO "django_geo_db_location" VALUES(59880,NULL,'Houston, TX 77003',25223,222,NULL,51,34364,0);
INSERT INTO "django_geo_db_location" VALUES(59881,NULL,'Houston, TX 77004',25223,222,NULL,51,34365,0);
INSERT INTO "django_geo_db_location" VALUES(59882,NULL,'Houston, TX 77005',25223,222,NULL,51,34366,0);
INSERT INTO "django_geo_db_location" VALUES(59883,NULL,'Houston, TX 77006',25223,222,NULL,51,34367,0);
INSERT INTO "django_geo_db_location" VALUES(59884,NULL,'Houston, TX 77007',25223,222,NULL,51,34368,0);
INSERT INTO "django_geo_db_location" VALUES(59885,NULL,'Houston, TX 77008',25223,222,NULL,51,34369,0);
INSERT INTO "django_geo_db_location" VALUES(59886,NULL,'Houston, TX 77009',25223,222,NULL,51,34370,0);
INSERT INTO "django_geo_db_location" VALUES(59887,NULL,'Houston, TX 77010',25223,222,NULL,51,34371,0);
INSERT INTO "django_geo_db_location" VALUES(59888,NULL,'Houston, TX 77011',25223,222,NULL,51,34372,0);
INSERT INTO "django_geo_db_location" VALUES(59889,NULL,'Houston, TX 77012',25223,222,NULL,51,34373,0);
INSERT INTO "django_geo_db_location" VALUES(59890,NULL,'Houston, TX 77013',25223,222,NULL,51,34374,0);
INSERT INTO "django_geo_db_location" VALUES(59891,NULL,'Houston, TX 77014',25223,222,NULL,51,34375,0);
INSERT INTO "django_geo_db_location" VALUES(59892,NULL,'Houston, TX 77015',25223,222,NULL,51,34376,0);
INSERT INTO "django_geo_db_location" VALUES(59893,NULL,'Houston, TX 77016',25223,222,NULL,51,34377,0);
INSERT INTO "django_geo_db_location" VALUES(59894,NULL,'Houston, TX 77017',25223,222,NULL,51,34378,0);
INSERT INTO "django_geo_db_location" VALUES(59895,NULL,'Houston, TX 77018',25223,222,NULL,51,34379,0);
INSERT INTO "django_geo_db_location" VALUES(59896,NULL,'Houston, TX 77019',25223,222,NULL,51,34380,0);
INSERT INTO "django_geo_db_location" VALUES(59897,NULL,'Houston, TX 77020',25223,222,NULL,51,34381,0);
INSERT INTO "django_geo_db_location" VALUES(59898,NULL,'Houston, TX 77021',25223,222,NULL,51,34382,0);
INSERT INTO "django_geo_db_location" VALUES(59899,NULL,'Houston, TX 77022',25223,222,NULL,51,34383,0);
INSERT INTO "django_geo_db_location" VALUES(59900,NULL,'Houston, TX 77023',25223,222,NULL,51,34384,0);
INSERT INTO "django_geo_db_location" VALUES(59901,NULL,'Houston, TX 77024',25223,222,NULL,51,34385,0);
INSERT INTO "django_geo_db_location" VALUES(59902,NULL,'Houston, TX 77025',25223,222,NULL,51,34386,0);
INSERT INTO "django_geo_db_location" VALUES(59903,NULL,'Houston, TX 77026',25223,222,NULL,51,34387,0);
INSERT INTO "django_geo_db_location" VALUES(59904,NULL,'Houston, TX 77027',25223,222,NULL,51,34388,0);
INSERT INTO "django_geo_db_location" VALUES(59905,NULL,'Houston, TX 77028',25223,222,NULL,51,34389,0);
INSERT INTO "django_geo_db_location" VALUES(59906,NULL,'Houston, TX 77029',25223,222,NULL,51,34390,0);
INSERT INTO "django_geo_db_location" VALUES(59907,NULL,'Houston, TX 77030',25223,222,NULL,51,34391,0);
INSERT INTO "django_geo_db_location" VALUES(59908,NULL,'Houston, TX 77031',25223,222,NULL,51,34392,0);
INSERT INTO "django_geo_db_location" VALUES(59909,NULL,'Houston, TX 77032',25223,222,NULL,51,34393,0);
INSERT INTO "django_geo_db_location" VALUES(59910,NULL,'Houston, TX 77033',25223,222,NULL,51,34394,0);
INSERT INTO "django_geo_db_location" VALUES(59911,NULL,'Houston, TX 77034',25223,222,NULL,51,34395,0);
INSERT INTO "django_geo_db_location" VALUES(59912,NULL,'Houston, TX 77035',25223,222,NULL,51,34396,0);
INSERT INTO "django_geo_db_location" VALUES(59913,NULL,'Houston, TX 77036',25223,222,NULL,51,34397,0);
INSERT INTO "django_geo_db_location" VALUES(59914,NULL,'Houston, TX 77037',25223,222,NULL,51,34398,0);
INSERT INTO "django_geo_db_location" VALUES(59915,NULL,'Houston, TX 77038',25223,222,NULL,51,34399,0);
INSERT INTO "django_geo_db_location" VALUES(59916,NULL,'Houston, TX 77039',25223,222,NULL,51,34400,0);
INSERT INTO "django_geo_db_location" VALUES(59917,NULL,'Houston, TX 77040',25223,222,NULL,51,34401,0);
INSERT INTO "django_geo_db_location" VALUES(59918,NULL,'Houston, TX 77041',25223,222,NULL,51,34402,0);
INSERT INTO "django_geo_db_location" VALUES(59919,NULL,'Houston, TX 77042',25223,222,NULL,51,34403,0);
INSERT INTO "django_geo_db_location" VALUES(59920,NULL,'Houston, TX 77043',25223,222,NULL,51,34404,0);
INSERT INTO "django_geo_db_location" VALUES(59921,NULL,'Houston, TX 77044',25223,222,NULL,51,34405,0);
INSERT INTO "django_geo_db_location" VALUES(59922,NULL,'Houston, TX 77045',25223,222,NULL,51,34406,0);
INSERT INTO "django_geo_db_location" VALUES(59923,NULL,'Houston, TX 77046',25223,222,NULL,51,34407,0);
INSERT INTO "django_geo_db_location" VALUES(59924,NULL,'Houston, TX 77047',25223,222,NULL,51,34408,0);
INSERT INTO "django_geo_db_location" VALUES(59925,NULL,'Houston, TX 77048',25223,222,NULL,51,34409,0);
INSERT INTO "django_geo_db_location" VALUES(59926,NULL,'Houston, TX 77049',25223,222,NULL,51,34410,0);
INSERT INTO "django_geo_db_location" VALUES(59927,NULL,'Houston, TX 77050',25223,222,NULL,51,34411,0);
INSERT INTO "django_geo_db_location" VALUES(59928,NULL,'Houston, TX 77051',25223,222,NULL,51,34412,0);
INSERT INTO "django_geo_db_location" VALUES(59929,NULL,'Houston, TX 77052',25223,222,NULL,51,34413,0);
INSERT INTO "django_geo_db_location" VALUES(59930,NULL,'Houston, TX 77053',25223,222,NULL,51,34414,0);
INSERT INTO "django_geo_db_location" VALUES(59931,NULL,'Houston, TX 77054',25223,222,NULL,51,34415,0);
INSERT INTO "django_geo_db_location" VALUES(59932,NULL,'Houston, TX 77055',25223,222,NULL,51,34416,0);
INSERT INTO "django_geo_db_location" VALUES(59933,NULL,'Houston, TX 77056',25223,222,NULL,51,34417,0);
INSERT INTO "django_geo_db_location" VALUES(59934,NULL,'Houston, TX 77057',25223,222,NULL,51,34418,0);
INSERT INTO "django_geo_db_location" VALUES(59935,NULL,'Houston, TX 77058',25223,222,NULL,51,34419,0);
INSERT INTO "django_geo_db_location" VALUES(59936,NULL,'Houston, TX 77059',25223,222,NULL,51,34420,0);
INSERT INTO "django_geo_db_location" VALUES(59937,NULL,'Houston, TX 77060',25223,222,NULL,51,34421,0);
INSERT INTO "django_geo_db_location" VALUES(59938,NULL,'Houston, TX 77061',25223,222,NULL,51,34422,0);
INSERT INTO "django_geo_db_location" VALUES(59939,NULL,'Houston, TX 77062',25223,222,NULL,51,34423,0);
INSERT INTO "django_geo_db_location" VALUES(59940,NULL,'Houston, TX 77063',25223,222,NULL,51,34424,0);
INSERT INTO "django_geo_db_location" VALUES(59941,NULL,'Houston, TX 77064',25223,222,NULL,51,34425,0);
INSERT INTO "django_geo_db_location" VALUES(59942,NULL,'Houston, TX 77065',25223,222,NULL,51,34426,0);
INSERT INTO "django_geo_db_location" VALUES(59943,NULL,'Houston, TX 77066',25223,222,NULL,51,34427,0);
INSERT INTO "django_geo_db_location" VALUES(59944,NULL,'Houston, TX 77067',25223,222,NULL,51,34428,0);
INSERT INTO "django_geo_db_location" VALUES(59945,NULL,'Houston, TX 77068',25223,222,NULL,51,34429,0);
INSERT INTO "django_geo_db_location" VALUES(59946,NULL,'Houston, TX 77069',25223,222,NULL,51,34430,0);
INSERT INTO "django_geo_db_location" VALUES(59947,NULL,'Houston, TX 77070',25223,222,NULL,51,34431,0);
INSERT INTO "django_geo_db_location" VALUES(59948,NULL,'Houston, TX 77071',25223,222,NULL,51,34432,0);
INSERT INTO "django_geo_db_location" VALUES(59949,NULL,'Houston, TX 77072',25223,222,NULL,51,34433,0);
INSERT INTO "django_geo_db_location" VALUES(59950,NULL,'Houston, TX 77073',25223,222,NULL,51,34434,0);
INSERT INTO "django_geo_db_location" VALUES(59951,NULL,'Houston, TX 77074',25223,222,NULL,51,34435,0);
INSERT INTO "django_geo_db_location" VALUES(59952,NULL,'Houston, TX 77075',25223,222,NULL,51,34436,0);
INSERT INTO "django_geo_db_location" VALUES(59953,NULL,'Houston, TX 77076',25223,222,NULL,51,34437,0);
INSERT INTO "django_geo_db_location" VALUES(59954,NULL,'Houston, TX 77077',25223,222,NULL,51,34438,0);
INSERT INTO "django_geo_db_location" VALUES(59955,NULL,'Houston, TX 77078',25223,222,NULL,51,34439,0);
INSERT INTO "django_geo_db_location" VALUES(59956,NULL,'Houston, TX 77079',25223,222,NULL,51,34440,0);
INSERT INTO "django_geo_db_location" VALUES(59957,NULL,'Houston, TX 77080',25223,222,NULL,51,34441,0);
INSERT INTO "django_geo_db_location" VALUES(59958,NULL,'Houston, TX 77081',25223,222,NULL,51,34442,0);
INSERT INTO "django_geo_db_location" VALUES(59959,NULL,'Houston, TX 77082',25223,222,NULL,51,34443,0);
INSERT INTO "django_geo_db_location" VALUES(59960,NULL,'Houston, TX 77083',25223,222,NULL,51,34444,0);
INSERT INTO "django_geo_db_location" VALUES(59961,NULL,'Houston, TX 77084',25223,222,NULL,51,34445,0);
INSERT INTO "django_geo_db_location" VALUES(59962,NULL,'Houston, TX 77085',25223,222,NULL,51,34446,0);
INSERT INTO "django_geo_db_location" VALUES(59963,NULL,'Houston, TX 77086',25223,222,NULL,51,34447,0);
INSERT INTO "django_geo_db_location" VALUES(59964,NULL,'Houston, TX 77087',25223,222,NULL,51,34448,0);
INSERT INTO "django_geo_db_location" VALUES(59965,NULL,'Houston, TX 77088',25223,222,NULL,51,34449,0);
INSERT INTO "django_geo_db_location" VALUES(59966,NULL,'Houston, TX 77089',25223,222,NULL,51,34450,0);
INSERT INTO "django_geo_db_location" VALUES(59967,NULL,'Houston, TX 77090',25223,222,NULL,51,34451,0);
INSERT INTO "django_geo_db_location" VALUES(59968,NULL,'Houston, TX 77091',25223,222,NULL,51,34452,0);
INSERT INTO "django_geo_db_location" VALUES(59969,NULL,'Houston, TX 77092',25223,222,NULL,51,34453,0);
INSERT INTO "django_geo_db_location" VALUES(59970,NULL,'Houston, TX 77093',25223,222,NULL,51,34454,0);
INSERT INTO "django_geo_db_location" VALUES(59971,NULL,'Houston, TX 77094',25223,222,NULL,51,34455,0);
INSERT INTO "django_geo_db_location" VALUES(59972,NULL,'Houston, TX 77095',25223,222,NULL,51,34456,0);
INSERT INTO "django_geo_db_location" VALUES(59973,NULL,'Houston, TX 77096',25223,222,NULL,51,34457,0);
INSERT INTO "django_geo_db_location" VALUES(59974,NULL,'Houston, TX 77097',25223,222,NULL,51,34458,0);
INSERT INTO "django_geo_db_location" VALUES(59975,NULL,'Houston, TX 77098',25223,222,NULL,51,34459,0);
INSERT INTO "django_geo_db_location" VALUES(59976,NULL,'Houston, TX 77099',25223,222,NULL,51,34460,0);
INSERT INTO "django_geo_db_location" VALUES(59977,NULL,'Houston, TX 77201',25223,222,NULL,51,34461,0);
INSERT INTO "django_geo_db_location" VALUES(59978,NULL,'Houston, TX 77202',25223,222,NULL,51,34462,0);
INSERT INTO "django_geo_db_location" VALUES(59979,NULL,'Houston, TX 77203',25223,222,NULL,51,34463,0);
INSERT INTO "django_geo_db_location" VALUES(59980,NULL,'Houston, TX 77204',25223,222,NULL,51,34464,0);
INSERT INTO "django_geo_db_location" VALUES(59981,NULL,'Houston, TX 77205',25223,222,NULL,51,34465,0);
INSERT INTO "django_geo_db_location" VALUES(59982,NULL,'Houston, TX 77206',25223,222,NULL,51,34466,0);
INSERT INTO "django_geo_db_location" VALUES(59983,NULL,'Houston, TX 77207',25223,222,NULL,51,34467,0);
INSERT INTO "django_geo_db_location" VALUES(59984,NULL,'Houston, TX 77208',25223,222,NULL,51,34468,0);
INSERT INTO "django_geo_db_location" VALUES(59985,NULL,'Houston, TX 77209',25223,222,NULL,51,34469,0);
INSERT INTO "django_geo_db_location" VALUES(59986,NULL,'Houston, TX 77210',25223,222,NULL,51,34470,0);
INSERT INTO "django_geo_db_location" VALUES(59987,NULL,'Houston, TX 77212',25223,222,NULL,51,34471,0);
INSERT INTO "django_geo_db_location" VALUES(59988,NULL,'Houston, TX 77213',25223,222,NULL,51,34472,0);
INSERT INTO "django_geo_db_location" VALUES(59989,NULL,'Houston, TX 77215',25223,222,NULL,51,34473,0);
INSERT INTO "django_geo_db_location" VALUES(59990,NULL,'Houston, TX 77216',25223,222,NULL,51,34474,0);
INSERT INTO "django_geo_db_location" VALUES(59991,NULL,'Houston, TX 77217',25223,222,NULL,51,34475,0);
INSERT INTO "django_geo_db_location" VALUES(59992,NULL,'Houston, TX 77218',25223,222,NULL,51,34476,0);
INSERT INTO "django_geo_db_location" VALUES(59993,NULL,'Houston, TX 77219',25223,222,NULL,51,34477,0);
INSERT INTO "django_geo_db_location" VALUES(59994,NULL,'Houston, TX 77220',25223,222,NULL,51,34478,0);
INSERT INTO "django_geo_db_location" VALUES(59995,NULL,'Houston, TX 77221',25223,222,NULL,51,34479,0);
INSERT INTO "django_geo_db_location" VALUES(59996,NULL,'Houston, TX 77222',25223,222,NULL,51,34480,0);
INSERT INTO "django_geo_db_location" VALUES(59997,NULL,'Houston, TX 77223',25223,222,NULL,51,34481,0);
INSERT INTO "django_geo_db_location" VALUES(59998,NULL,'Houston, TX 77224',25223,222,NULL,51,34482,0);
INSERT INTO "django_geo_db_location" VALUES(59999,NULL,'Houston, TX 77225',25223,222,NULL,51,34483,0);
INSERT INTO "django_geo_db_location" VALUES(60000,NULL,'Houston, TX 77226',25223,222,NULL,51,34484,0);
INSERT INTO "django_geo_db_location" VALUES(60001,NULL,'Houston, TX 77227',25223,222,NULL,51,34485,0);
INSERT INTO "django_geo_db_location" VALUES(60002,NULL,'Houston, TX 77228',25223,222,NULL,51,34486,0);
INSERT INTO "django_geo_db_location" VALUES(60003,NULL,'Houston, TX 77229',25223,222,NULL,51,34487,0);
INSERT INTO "django_geo_db_location" VALUES(60004,NULL,'Houston, TX 77230',25223,222,NULL,51,34488,0);
INSERT INTO "django_geo_db_location" VALUES(60005,NULL,'Houston, TX 77231',25223,222,NULL,51,34489,0);
INSERT INTO "django_geo_db_location" VALUES(60006,NULL,'Houston, TX 77233',25223,222,NULL,51,34490,0);
INSERT INTO "django_geo_db_location" VALUES(60007,NULL,'Houston, TX 77234',25223,222,NULL,51,34491,0);
INSERT INTO "django_geo_db_location" VALUES(60008,NULL,'Houston, TX 77235',25223,222,NULL,51,34492,0);
INSERT INTO "django_geo_db_location" VALUES(60009,NULL,'Houston, TX 77236',25223,222,NULL,51,34493,0);
INSERT INTO "django_geo_db_location" VALUES(60010,NULL,'Houston, TX 77237',25223,222,NULL,51,34494,0);
INSERT INTO "django_geo_db_location" VALUES(60011,NULL,'Houston, TX 77238',25223,222,NULL,51,34495,0);
INSERT INTO "django_geo_db_location" VALUES(60012,NULL,'Houston, TX 77240',25223,222,NULL,51,34496,0);
INSERT INTO "django_geo_db_location" VALUES(60013,NULL,'Houston, TX 77241',25223,222,NULL,51,34497,0);
INSERT INTO "django_geo_db_location" VALUES(60014,NULL,'Houston, TX 77242',25223,222,NULL,51,34498,0);
INSERT INTO "django_geo_db_location" VALUES(60015,NULL,'Houston, TX 77243',25223,222,NULL,51,34499,0);
INSERT INTO "django_geo_db_location" VALUES(60016,NULL,'Houston, TX 77244',25223,222,NULL,51,34500,0);
INSERT INTO "django_geo_db_location" VALUES(60017,NULL,'Houston, TX 77245',25223,222,NULL,51,34501,0);
INSERT INTO "django_geo_db_location" VALUES(60018,NULL,'Houston, TX 77248',25223,222,NULL,51,34502,0);
INSERT INTO "django_geo_db_location" VALUES(60019,NULL,'Houston, TX 77249',25223,222,NULL,51,34503,0);
INSERT INTO "django_geo_db_location" VALUES(60020,NULL,'Houston, TX 77251',25223,222,NULL,51,34504,0);
INSERT INTO "django_geo_db_location" VALUES(60021,NULL,'Houston, TX 77252',25223,222,NULL,51,34505,0);
INSERT INTO "django_geo_db_location" VALUES(60022,NULL,'Houston, TX 77253',25223,222,NULL,51,34506,0);
INSERT INTO "django_geo_db_location" VALUES(60023,NULL,'Houston, TX 77254',25223,222,NULL,51,34507,0);
INSERT INTO "django_geo_db_location" VALUES(60024,NULL,'Houston, TX 77255',25223,222,NULL,51,34508,0);
INSERT INTO "django_geo_db_location" VALUES(60025,NULL,'Houston, TX 77256',25223,222,NULL,51,34509,0);
INSERT INTO "django_geo_db_location" VALUES(60026,NULL,'Houston, TX 77257',25223,222,NULL,51,34510,0);
INSERT INTO "django_geo_db_location" VALUES(60027,NULL,'Houston, TX 77258',25223,222,NULL,51,34511,0);
INSERT INTO "django_geo_db_location" VALUES(60028,NULL,'Houston, TX 77259',25223,222,NULL,51,34512,0);
INSERT INTO "django_geo_db_location" VALUES(60029,NULL,'Houston, TX 77261',25223,222,NULL,51,34513,0);
INSERT INTO "django_geo_db_location" VALUES(60030,NULL,'Houston, TX 77262',25223,222,NULL,51,34514,0);
INSERT INTO "django_geo_db_location" VALUES(60031,NULL,'Houston, TX 77263',25223,222,NULL,51,34515,0);
INSERT INTO "django_geo_db_location" VALUES(60032,NULL,'Houston, TX 77265',25223,222,NULL,51,34516,0);
INSERT INTO "django_geo_db_location" VALUES(60033,NULL,'Houston, TX 77266',25223,222,NULL,51,34517,0);
INSERT INTO "django_geo_db_location" VALUES(60034,NULL,'Houston, TX 77267',25223,222,NULL,51,34518,0);
INSERT INTO "django_geo_db_location" VALUES(60035,NULL,'Houston, TX 77268',25223,222,NULL,51,34519,0);
INSERT INTO "django_geo_db_location" VALUES(60036,NULL,'Houston, TX 77269',25223,222,NULL,51,34520,0);
INSERT INTO "django_geo_db_location" VALUES(60037,NULL,'Houston, TX 77270',25223,222,NULL,51,34521,0);
INSERT INTO "django_geo_db_location" VALUES(60038,NULL,'Houston, TX 77271',25223,222,NULL,51,34522,0);
INSERT INTO "django_geo_db_location" VALUES(60039,NULL,'Houston, TX 77272',25223,222,NULL,51,34523,0);
INSERT INTO "django_geo_db_location" VALUES(60040,NULL,'Houston, TX 77273',25223,222,NULL,51,34524,0);
INSERT INTO "django_geo_db_location" VALUES(60041,NULL,'Houston, TX 77274',25223,222,NULL,51,34525,0);
INSERT INTO "django_geo_db_location" VALUES(60042,NULL,'Houston, TX 77275',25223,222,NULL,51,34526,0);
INSERT INTO "django_geo_db_location" VALUES(60043,NULL,'Houston, TX 77277',25223,222,NULL,51,34527,0);
INSERT INTO "django_geo_db_location" VALUES(60044,NULL,'Houston, TX 77279',25223,222,NULL,51,34528,0);
INSERT INTO "django_geo_db_location" VALUES(60045,NULL,'Houston, TX 77280',25223,222,NULL,51,34529,0);
INSERT INTO "django_geo_db_location" VALUES(60046,NULL,'Houston, TX 77281',25223,222,NULL,51,34530,0);
INSERT INTO "django_geo_db_location" VALUES(60047,NULL,'Houston, TX 77282',25223,222,NULL,51,34531,0);
INSERT INTO "django_geo_db_location" VALUES(60048,NULL,'Houston, TX 77284',25223,222,NULL,51,34532,0);
INSERT INTO "django_geo_db_location" VALUES(60049,NULL,'Houston, TX 77287',25223,222,NULL,51,34533,0);
INSERT INTO "django_geo_db_location" VALUES(60050,NULL,'Houston, TX 77288',25223,222,NULL,51,34534,0);
INSERT INTO "django_geo_db_location" VALUES(60051,NULL,'Houston, TX 77289',25223,222,NULL,51,34535,0);
INSERT INTO "django_geo_db_location" VALUES(60052,NULL,'Houston, TX 77290',25223,222,NULL,51,34536,0);
INSERT INTO "django_geo_db_location" VALUES(60053,NULL,'Houston, TX 77291',25223,222,NULL,51,34537,0);
INSERT INTO "django_geo_db_location" VALUES(60054,NULL,'Houston, TX 77292',25223,222,NULL,51,34538,0);
INSERT INTO "django_geo_db_location" VALUES(60055,NULL,'Houston, TX 77293',25223,222,NULL,51,34539,0);
INSERT INTO "django_geo_db_location" VALUES(60056,NULL,'Houston, TX 77297',25223,222,NULL,51,34540,0);
INSERT INTO "django_geo_db_location" VALUES(60057,NULL,'Houston, TX 77298',25223,222,NULL,51,34541,0);
INSERT INTO "django_geo_db_location" VALUES(60058,NULL,'Houston, TX 77299',25223,222,NULL,51,34542,0);
INSERT INTO "django_geo_db_location" VALUES(60059,NULL,'Conroe, TX',25224,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60060,NULL,'Conroe, TX 77301',25224,222,NULL,51,34543,0);
INSERT INTO "django_geo_db_location" VALUES(60061,NULL,'Conroe, TX 77302',25224,222,NULL,51,34544,0);
INSERT INTO "django_geo_db_location" VALUES(60062,NULL,'Conroe, TX 77303',25224,222,NULL,51,34545,0);
INSERT INTO "django_geo_db_location" VALUES(60063,NULL,'Conroe, TX 77304',25224,222,NULL,51,34546,0);
INSERT INTO "django_geo_db_location" VALUES(60064,NULL,'Conroe, TX 77305',25224,222,NULL,51,34547,0);
INSERT INTO "django_geo_db_location" VALUES(60065,NULL,'Conroe, TX 77306',25224,222,NULL,51,34548,0);
INSERT INTO "django_geo_db_location" VALUES(60066,NULL,'North Houston, TX',25225,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60067,NULL,'North Houston, TX 77315',25225,222,NULL,51,34549,0);
INSERT INTO "django_geo_db_location" VALUES(60068,NULL,'Montgomery, TX',25226,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60069,NULL,'Montgomery, TX 77316',25226,222,NULL,51,34550,0);
INSERT INTO "django_geo_db_location" VALUES(60070,NULL,'Willis, TX',25227,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60071,NULL,'Willis, TX 77318',25227,222,NULL,51,34551,0);
INSERT INTO "django_geo_db_location" VALUES(60072,NULL,'Huntsville, TX',25228,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60073,NULL,'Huntsville, TX 77320',25228,222,NULL,51,34552,0);
INSERT INTO "django_geo_db_location" VALUES(60074,NULL,'Humble, TX',25229,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60075,NULL,'Humble, TX 77325',25229,222,NULL,51,34553,0);
INSERT INTO "django_geo_db_location" VALUES(60076,NULL,'Ace, TX',25230,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60077,NULL,'Ace, TX 77326',25230,222,NULL,51,34554,0);
INSERT INTO "django_geo_db_location" VALUES(60078,NULL,'Cleveland, TX',25231,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60079,NULL,'Cleveland, TX 77327',25231,222,NULL,51,34555,0);
INSERT INTO "django_geo_db_location" VALUES(60080,NULL,'Cleveland, TX 77328',25231,222,NULL,51,34556,0);
INSERT INTO "django_geo_db_location" VALUES(60081,NULL,'Coldspring, TX',25232,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60082,NULL,'Coldspring, TX 77331',25232,222,NULL,51,34557,0);
INSERT INTO "django_geo_db_location" VALUES(60083,NULL,'Dallardsville, TX',25233,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60084,NULL,'Dallardsville, TX 77332',25233,222,NULL,51,34558,0);
INSERT INTO "django_geo_db_location" VALUES(60085,NULL,'Dobbin, TX',25234,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60086,NULL,'Dobbin, TX 77333',25234,222,NULL,51,34559,0);
INSERT INTO "django_geo_db_location" VALUES(60087,NULL,'Dodge, TX',25235,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60088,NULL,'Dodge, TX 77334',25235,222,NULL,51,34560,0);
INSERT INTO "django_geo_db_location" VALUES(60089,NULL,'Goodrich, TX',25236,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60090,NULL,'Goodrich, TX 77335',25236,222,NULL,51,34561,0);
INSERT INTO "django_geo_db_location" VALUES(60091,NULL,'Huffman, TX',25237,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60092,NULL,'Huffman, TX 77336',25237,222,NULL,51,34562,0);
INSERT INTO "django_geo_db_location" VALUES(60093,NULL,'Hufsmith, TX',25238,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60094,NULL,'Hufsmith, TX 77337',25238,222,NULL,51,34563,0);
INSERT INTO "django_geo_db_location" VALUES(60095,NULL,'Humble, TX 77338',25229,222,NULL,51,34564,0);
INSERT INTO "django_geo_db_location" VALUES(60096,NULL,'Humble, TX 77339',25229,222,NULL,51,34565,0);
INSERT INTO "django_geo_db_location" VALUES(60097,NULL,'Huntsville, TX 77340',25228,222,NULL,51,34566,0);
INSERT INTO "django_geo_db_location" VALUES(60098,NULL,'Huntsville, TX 77341',25228,222,NULL,51,34567,0);
INSERT INTO "django_geo_db_location" VALUES(60099,NULL,'Huntsville, TX 77342',25228,222,NULL,51,34568,0);
INSERT INTO "django_geo_db_location" VALUES(60100,NULL,'Huntsville, TX 77343',25228,222,NULL,51,34569,0);
INSERT INTO "django_geo_db_location" VALUES(60101,NULL,'Huntsville, TX 77344',25228,222,NULL,51,34570,0);
INSERT INTO "django_geo_db_location" VALUES(60102,NULL,'Humble, TX 77345',25229,222,NULL,51,34571,0);
INSERT INTO "django_geo_db_location" VALUES(60103,NULL,'Humble, TX 77346',25229,222,NULL,51,34572,0);
INSERT INTO "django_geo_db_location" VALUES(60104,NULL,'Humble, TX 77347',25229,222,NULL,51,34573,0);
INSERT INTO "django_geo_db_location" VALUES(60105,NULL,'Huntsville, TX 77348',25228,222,NULL,51,34574,0);
INSERT INTO "django_geo_db_location" VALUES(60106,NULL,'Huntsville, TX 77349',25228,222,NULL,51,34575,0);
INSERT INTO "django_geo_db_location" VALUES(60107,NULL,'Leggett, TX',25239,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60108,NULL,'Leggett, TX 77350',25239,222,NULL,51,34576,0);
INSERT INTO "django_geo_db_location" VALUES(60109,NULL,'Livingston, TX',25240,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60110,NULL,'Livingston, TX 77351',25240,222,NULL,51,34577,0);
INSERT INTO "django_geo_db_location" VALUES(60111,NULL,'Magnolia, TX',25241,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60112,NULL,'Magnolia, TX 77353',25241,222,NULL,51,34578,0);
INSERT INTO "django_geo_db_location" VALUES(60113,NULL,'Magnolia, TX 77354',25241,222,NULL,51,34579,0);
INSERT INTO "django_geo_db_location" VALUES(60114,NULL,'Magnolia, TX 77355',25241,222,NULL,51,34580,0);
INSERT INTO "django_geo_db_location" VALUES(60115,NULL,'Montgomery, TX 77356',25226,222,NULL,51,34581,0);
INSERT INTO "django_geo_db_location" VALUES(60116,NULL,'New Caney, TX',25242,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60117,NULL,'New Caney, TX 77357',25242,222,NULL,51,34582,0);
INSERT INTO "django_geo_db_location" VALUES(60118,NULL,'New Waverly, TX',25243,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60119,NULL,'New Waverly, TX 77358',25243,222,NULL,51,34583,0);
INSERT INTO "django_geo_db_location" VALUES(60120,NULL,'Oakhurst, TX',25244,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60121,NULL,'Oakhurst, TX 77359',25244,222,NULL,51,34584,0);
INSERT INTO "django_geo_db_location" VALUES(60122,NULL,'Onalaska, TX',25245,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60123,NULL,'Onalaska, TX 77360',25245,222,NULL,51,34585,0);
INSERT INTO "django_geo_db_location" VALUES(60124,NULL,'Pinehurst, TX',25246,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60125,NULL,'Pinehurst, TX 77362',25246,222,NULL,51,34586,0);
INSERT INTO "django_geo_db_location" VALUES(60126,NULL,'Plantersville, TX',25247,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60127,NULL,'Plantersville, TX 77363',25247,222,NULL,51,34587,0);
INSERT INTO "django_geo_db_location" VALUES(60128,NULL,'Pointblank, TX',25248,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60129,NULL,'Pointblank, TX 77364',25248,222,NULL,51,34588,0);
INSERT INTO "django_geo_db_location" VALUES(60130,NULL,'Porter, TX',25249,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60131,NULL,'Porter, TX 77365',25249,222,NULL,51,34589,0);
INSERT INTO "django_geo_db_location" VALUES(60132,NULL,'Riverside, TX',25250,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60133,NULL,'Riverside, TX 77367',25250,222,NULL,51,34590,0);
INSERT INTO "django_geo_db_location" VALUES(60134,NULL,'Romayor, TX',25251,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60135,NULL,'Romayor, TX 77368',25251,222,NULL,51,34591,0);
INSERT INTO "django_geo_db_location" VALUES(60136,NULL,'Rye, TX',25252,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60137,NULL,'Rye, TX 77369',25252,222,NULL,51,34592,0);
INSERT INTO "django_geo_db_location" VALUES(60138,NULL,'Shepherd, TX',25253,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60139,NULL,'Shepherd, TX 77371',25253,222,NULL,51,34593,0);
INSERT INTO "django_geo_db_location" VALUES(60140,NULL,'Splendora, TX',25254,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60141,NULL,'Splendora, TX 77372',25254,222,NULL,51,34594,0);
INSERT INTO "django_geo_db_location" VALUES(60142,NULL,'Spring, TX',25255,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60143,NULL,'Spring, TX 77373',25255,222,NULL,51,34595,0);
INSERT INTO "django_geo_db_location" VALUES(60144,NULL,'Thicket, TX',25256,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60145,NULL,'Thicket, TX 77374',25256,222,NULL,51,34596,0);
INSERT INTO "django_geo_db_location" VALUES(60146,NULL,'Tomball, TX',25257,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60147,NULL,'Tomball, TX 77375',25257,222,NULL,51,34597,0);
INSERT INTO "django_geo_db_location" VALUES(60148,NULL,'Votaw, TX',25258,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60149,NULL,'Votaw, TX 77376',25258,222,NULL,51,34598,0);
INSERT INTO "django_geo_db_location" VALUES(60150,NULL,'Tomball, TX 77377',25257,222,NULL,51,34599,0);
INSERT INTO "django_geo_db_location" VALUES(60151,NULL,'Willis, TX 77378',25227,222,NULL,51,34600,0);
INSERT INTO "django_geo_db_location" VALUES(60152,NULL,'Spring, TX 77379',25255,222,NULL,51,34601,0);
INSERT INTO "django_geo_db_location" VALUES(60153,NULL,'Spring, TX 77380',25255,222,NULL,51,34602,0);
INSERT INTO "django_geo_db_location" VALUES(60154,NULL,'Spring, TX 77381',25255,222,NULL,51,34603,0);
INSERT INTO "django_geo_db_location" VALUES(60155,NULL,'Spring, TX 77382',25255,222,NULL,51,34604,0);
INSERT INTO "django_geo_db_location" VALUES(60156,NULL,'Spring, TX 77383',25255,222,NULL,51,34605,0);
INSERT INTO "django_geo_db_location" VALUES(60157,NULL,'Conroe, TX 77384',25224,222,NULL,51,34606,0);
INSERT INTO "django_geo_db_location" VALUES(60158,NULL,'Conroe, TX 77385',25224,222,NULL,51,34607,0);
INSERT INTO "django_geo_db_location" VALUES(60159,NULL,'Spring, TX 77386',25255,222,NULL,51,34608,0);
INSERT INTO "django_geo_db_location" VALUES(60160,NULL,'Spring, TX 77387',25255,222,NULL,51,34609,0);
INSERT INTO "django_geo_db_location" VALUES(60161,NULL,'Spring, TX 77388',25255,222,NULL,51,34610,0);
INSERT INTO "django_geo_db_location" VALUES(60162,NULL,'Spring, TX 77389',25255,222,NULL,51,34611,0);
INSERT INTO "django_geo_db_location" VALUES(60163,NULL,'Spring, TX 77391',25255,222,NULL,51,34612,0);
INSERT INTO "django_geo_db_location" VALUES(60164,NULL,'Spring, TX 77393',25255,222,NULL,51,34613,0);
INSERT INTO "django_geo_db_location" VALUES(60165,NULL,'Humble, TX 77396',25229,222,NULL,51,34614,0);
INSERT INTO "django_geo_db_location" VALUES(60166,NULL,'Livingston, TX 77399',25240,222,NULL,51,34615,0);
INSERT INTO "django_geo_db_location" VALUES(60167,NULL,'Bellaire, TX',25259,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60168,NULL,'Bellaire, TX 77401',25259,222,NULL,51,34616,0);
INSERT INTO "django_geo_db_location" VALUES(60169,NULL,'Bellaire, TX 77402',25259,222,NULL,51,34617,0);
INSERT INTO "django_geo_db_location" VALUES(60170,NULL,'Bay City, TX',25260,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60171,NULL,'Bay City, TX 77404',25260,222,NULL,51,34618,0);
INSERT INTO "django_geo_db_location" VALUES(60172,NULL,'Richmond, TX',25261,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60173,NULL,'Richmond, TX 77406',25261,222,NULL,51,34619,0);
INSERT INTO "django_geo_db_location" VALUES(60174,NULL,'Cypress, TX',25262,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60175,NULL,'Cypress, TX 77410',25262,222,NULL,51,34620,0);
INSERT INTO "django_geo_db_location" VALUES(60176,NULL,'Alief, TX',25263,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60177,NULL,'Alief, TX 77411',25263,222,NULL,51,34621,0);
INSERT INTO "django_geo_db_location" VALUES(60178,NULL,'Altair, TX',25264,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60179,NULL,'Altair, TX 77412',25264,222,NULL,51,34622,0);
INSERT INTO "django_geo_db_location" VALUES(60180,NULL,'Barker, TX',25265,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60181,NULL,'Barker, TX 77413',25265,222,NULL,51,34623,0);
INSERT INTO "django_geo_db_location" VALUES(60182,NULL,'Bay City, TX 77414',25260,222,NULL,51,34624,0);
INSERT INTO "django_geo_db_location" VALUES(60183,NULL,'Cedar Lane, TX',25266,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60184,NULL,'Cedar Lane, TX 77415',25266,222,NULL,51,34625,0);
INSERT INTO "django_geo_db_location" VALUES(60185,NULL,'Beasley, TX',25267,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60186,NULL,'Beasley, TX 77417',25267,222,NULL,51,34626,0);
INSERT INTO "django_geo_db_location" VALUES(60187,NULL,'Bellville, TX',25268,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60188,NULL,'Bellville, TX 77418',25268,222,NULL,51,34627,0);
INSERT INTO "django_geo_db_location" VALUES(60189,NULL,'Blessing, TX',25269,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60190,NULL,'Blessing, TX 77419',25269,222,NULL,51,34628,0);
INSERT INTO "django_geo_db_location" VALUES(60191,NULL,'Boling, TX',25270,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60192,NULL,'Boling, TX 77420',25270,222,NULL,51,34629,0);
INSERT INTO "django_geo_db_location" VALUES(60193,NULL,'Brazoria, TX',25271,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60194,NULL,'Brazoria, TX 77422',25271,222,NULL,51,34630,0);
INSERT INTO "django_geo_db_location" VALUES(60195,NULL,'Brookshire, TX',25272,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60196,NULL,'Brookshire, TX 77423',25272,222,NULL,51,34631,0);
INSERT INTO "django_geo_db_location" VALUES(60197,NULL,'Chappell Hill, TX',25273,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60198,NULL,'Chappell Hill, TX 77426',25273,222,NULL,51,34632,0);
INSERT INTO "django_geo_db_location" VALUES(60199,NULL,'Collegeport, TX',25274,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60200,NULL,'Collegeport, TX 77428',25274,222,NULL,51,34633,0);
INSERT INTO "django_geo_db_location" VALUES(60201,NULL,'Cypress, TX 77429',25262,222,NULL,51,34634,0);
INSERT INTO "django_geo_db_location" VALUES(60202,NULL,'Damon, TX',25275,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60203,NULL,'Damon, TX 77430',25275,222,NULL,51,34635,0);
INSERT INTO "django_geo_db_location" VALUES(60204,NULL,'Danciger, TX',25276,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60205,NULL,'Danciger, TX 77431',25276,222,NULL,51,34636,0);
INSERT INTO "django_geo_db_location" VALUES(60206,NULL,'Danevang, TX',25277,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60207,NULL,'Danevang, TX 77432',25277,222,NULL,51,34637,0);
INSERT INTO "django_geo_db_location" VALUES(60208,NULL,'Cypress, TX 77433',25262,222,NULL,51,34638,0);
INSERT INTO "django_geo_db_location" VALUES(60209,NULL,'Eagle Lake, TX',25278,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60210,NULL,'Eagle Lake, TX 77434',25278,222,NULL,51,34639,0);
INSERT INTO "django_geo_db_location" VALUES(60211,NULL,'East Bernard, TX',25279,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60212,NULL,'East Bernard, TX 77435',25279,222,NULL,51,34640,0);
INSERT INTO "django_geo_db_location" VALUES(60213,NULL,'Egypt, TX',25280,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60214,NULL,'Egypt, TX 77436',25280,222,NULL,51,34641,0);
INSERT INTO "django_geo_db_location" VALUES(60215,NULL,'El Campo, TX',25281,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60216,NULL,'El Campo, TX 77437',25281,222,NULL,51,34642,0);
INSERT INTO "django_geo_db_location" VALUES(60217,NULL,'San Leon, TX',25282,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60218,NULL,'San Leon, TX 77439',25282,222,NULL,51,34643,0);
INSERT INTO "django_geo_db_location" VALUES(60219,NULL,'Elmaton, TX',25283,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60220,NULL,'Elmaton, TX 77440',25283,222,NULL,51,34644,0);
INSERT INTO "django_geo_db_location" VALUES(60221,NULL,'Fulshear, TX',25284,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60222,NULL,'Fulshear, TX 77441',25284,222,NULL,51,34645,0);
INSERT INTO "django_geo_db_location" VALUES(60223,NULL,'Garwood, TX',25285,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60224,NULL,'Garwood, TX 77442',25285,222,NULL,51,34646,0);
INSERT INTO "django_geo_db_location" VALUES(60225,NULL,'Glen Flora, TX',25286,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60226,NULL,'Glen Flora, TX 77443',25286,222,NULL,51,34647,0);
INSERT INTO "django_geo_db_location" VALUES(60227,NULL,'Guy, TX',25287,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60228,NULL,'Guy, TX 77444',25287,222,NULL,51,34648,0);
INSERT INTO "django_geo_db_location" VALUES(60229,NULL,'Hempstead, TX',25288,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60230,NULL,'Hempstead, TX 77445',25288,222,NULL,51,34649,0);
INSERT INTO "django_geo_db_location" VALUES(60231,NULL,'Prairie View, TX',25289,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60232,NULL,'Prairie View, TX 77446',25289,222,NULL,51,34650,0);
INSERT INTO "django_geo_db_location" VALUES(60233,NULL,'Hockley, TX',25290,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60234,NULL,'Hockley, TX 77447',25290,222,NULL,51,34651,0);
INSERT INTO "django_geo_db_location" VALUES(60235,NULL,'Hungerford, TX',25291,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60236,NULL,'Hungerford, TX 77448',25291,222,NULL,51,34652,0);
INSERT INTO "django_geo_db_location" VALUES(60237,NULL,'Katy, TX',25292,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60238,NULL,'Katy, TX 77449',25292,222,NULL,51,34653,0);
INSERT INTO "django_geo_db_location" VALUES(60239,NULL,'Katy, TX 77450',25292,222,NULL,51,34654,0);
INSERT INTO "django_geo_db_location" VALUES(60240,NULL,'Kendleton, TX',25293,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60241,NULL,'Kendleton, TX 77451',25293,222,NULL,51,34655,0);
INSERT INTO "django_geo_db_location" VALUES(60242,NULL,'Kenney, TX',25294,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60243,NULL,'Kenney, TX 77452',25294,222,NULL,51,34656,0);
INSERT INTO "django_geo_db_location" VALUES(60244,NULL,'Lane City, TX',25295,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60245,NULL,'Lane City, TX 77453',25295,222,NULL,51,34657,0);
INSERT INTO "django_geo_db_location" VALUES(60246,NULL,'Lissie, TX',25296,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60247,NULL,'Lissie, TX 77454',25296,222,NULL,51,34658,0);
INSERT INTO "django_geo_db_location" VALUES(60248,NULL,'Louise, TX',25297,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60249,NULL,'Louise, TX 77455',25297,222,NULL,51,34659,0);
INSERT INTO "django_geo_db_location" VALUES(60250,NULL,'Markham, TX',25298,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60251,NULL,'Markham, TX 77456',25298,222,NULL,51,34660,0);
INSERT INTO "django_geo_db_location" VALUES(60252,NULL,'Matagorda, TX',25299,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60253,NULL,'Matagorda, TX 77457',25299,222,NULL,51,34661,0);
INSERT INTO "django_geo_db_location" VALUES(60254,NULL,'Midfield, TX',25300,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60255,NULL,'Midfield, TX 77458',25300,222,NULL,51,34662,0);
INSERT INTO "django_geo_db_location" VALUES(60256,NULL,'Missouri City, TX',25301,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60257,NULL,'Missouri City, TX 77459',25301,222,NULL,51,34663,0);
INSERT INTO "django_geo_db_location" VALUES(60258,NULL,'Nada, TX',25302,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60259,NULL,'Nada, TX 77460',25302,222,NULL,51,34664,0);
INSERT INTO "django_geo_db_location" VALUES(60260,NULL,'Needville, TX',25303,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60261,NULL,'Needville, TX 77461',25303,222,NULL,51,34665,0);
INSERT INTO "django_geo_db_location" VALUES(60262,NULL,'Newgulf, TX',25304,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60263,NULL,'Newgulf, TX 77462',25304,222,NULL,51,34666,0);
INSERT INTO "django_geo_db_location" VALUES(60264,NULL,'Old Ocean, TX',25305,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60265,NULL,'Old Ocean, TX 77463',25305,222,NULL,51,34667,0);
INSERT INTO "django_geo_db_location" VALUES(60266,NULL,'Orchard, TX',25306,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60267,NULL,'Orchard, TX 77464',25306,222,NULL,51,34668,0);
INSERT INTO "django_geo_db_location" VALUES(60268,NULL,'Palacios, TX',25307,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60269,NULL,'Palacios, TX 77465',25307,222,NULL,51,34669,0);
INSERT INTO "django_geo_db_location" VALUES(60270,NULL,'Pattison, TX',25308,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60271,NULL,'Pattison, TX 77466',25308,222,NULL,51,34670,0);
INSERT INTO "django_geo_db_location" VALUES(60272,NULL,'Pierce, TX',25309,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60273,NULL,'Pierce, TX 77467',25309,222,NULL,51,34671,0);
INSERT INTO "django_geo_db_location" VALUES(60274,NULL,'Pledger, TX',25310,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60275,NULL,'Pledger, TX 77468',25310,222,NULL,51,34672,0);
INSERT INTO "django_geo_db_location" VALUES(60276,NULL,'Richmond, TX 77469',25261,222,NULL,51,34673,0);
INSERT INTO "django_geo_db_location" VALUES(60277,NULL,'Rock Island, TX',25311,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60278,NULL,'Rock Island, TX 77470',25311,222,NULL,51,34674,0);
INSERT INTO "django_geo_db_location" VALUES(60279,NULL,'Rosenberg, TX',25312,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60280,NULL,'Rosenberg, TX 77471',25312,222,NULL,51,34675,0);
INSERT INTO "django_geo_db_location" VALUES(60281,NULL,'San Felipe, TX',25313,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60282,NULL,'San Felipe, TX 77473',25313,222,NULL,51,34676,0);
INSERT INTO "django_geo_db_location" VALUES(60283,NULL,'Sealy, TX',25314,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60284,NULL,'Sealy, TX 77474',25314,222,NULL,51,34677,0);
INSERT INTO "django_geo_db_location" VALUES(60285,NULL,'Sheridan, TX',25315,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60286,NULL,'Sheridan, TX 77475',25315,222,NULL,51,34678,0);
INSERT INTO "django_geo_db_location" VALUES(60287,NULL,'Simonton, TX',25316,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60288,NULL,'Simonton, TX 77476',25316,222,NULL,51,34679,0);
INSERT INTO "django_geo_db_location" VALUES(60289,NULL,'Stafford, TX',25317,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60290,NULL,'Stafford, TX 77477',25317,222,NULL,51,34680,0);
INSERT INTO "django_geo_db_location" VALUES(60291,NULL,'Sugar Land, TX',25318,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60292,NULL,'Sugar Land, TX 77478',25318,222,NULL,51,34681,0);
INSERT INTO "django_geo_db_location" VALUES(60293,NULL,'Sugar Land, TX 77479',25318,222,NULL,51,34682,0);
INSERT INTO "django_geo_db_location" VALUES(60294,NULL,'Sweeny, TX',25319,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60295,NULL,'Sweeny, TX 77480',25319,222,NULL,51,34683,0);
INSERT INTO "django_geo_db_location" VALUES(60296,NULL,'Thompsons, TX',25320,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60297,NULL,'Thompsons, TX 77481',25320,222,NULL,51,34684,0);
INSERT INTO "django_geo_db_location" VALUES(60298,NULL,'Van Vleck, TX',25321,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60299,NULL,'Van Vleck, TX 77482',25321,222,NULL,51,34685,0);
INSERT INTO "django_geo_db_location" VALUES(60300,NULL,'Wadsworth, TX',25322,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60301,NULL,'Wadsworth, TX 77483',25322,222,NULL,51,34686,0);
INSERT INTO "django_geo_db_location" VALUES(60302,NULL,'Waller, TX',25323,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60303,NULL,'Waller, TX 77484',25323,222,NULL,51,34687,0);
INSERT INTO "django_geo_db_location" VALUES(60304,NULL,'Wallis, TX',25324,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60305,NULL,'Wallis, TX 77485',25324,222,NULL,51,34688,0);
INSERT INTO "django_geo_db_location" VALUES(60306,NULL,'West Columbia, TX',25325,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60307,NULL,'West Columbia, TX 77486',25325,222,NULL,51,34689,0);
INSERT INTO "django_geo_db_location" VALUES(60308,NULL,'Sugar Land, TX 77487',25318,222,NULL,51,34690,0);
INSERT INTO "django_geo_db_location" VALUES(60309,NULL,'Wharton, TX',25326,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60310,NULL,'Wharton, TX 77488',25326,222,NULL,51,34691,0);
INSERT INTO "django_geo_db_location" VALUES(60311,NULL,'Missouri City, TX 77489',25301,222,NULL,51,34692,0);
INSERT INTO "django_geo_db_location" VALUES(60312,NULL,'Katy, TX 77491',25292,222,NULL,51,34693,0);
INSERT INTO "django_geo_db_location" VALUES(60313,NULL,'Katy, TX 77492',25292,222,NULL,51,34694,0);
INSERT INTO "django_geo_db_location" VALUES(60314,NULL,'Katy, TX 77493',25292,222,NULL,51,34695,0);
INSERT INTO "django_geo_db_location" VALUES(60315,NULL,'Katy, TX 77494',25292,222,NULL,51,34696,0);
INSERT INTO "django_geo_db_location" VALUES(60316,NULL,'Sugar Land, TX 77496',25318,222,NULL,51,34697,0);
INSERT INTO "django_geo_db_location" VALUES(60317,NULL,'Stafford, TX 77497',25317,222,NULL,51,34698,0);
INSERT INTO "django_geo_db_location" VALUES(60318,NULL,'Pasadena, TX',25327,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60319,NULL,'Pasadena, TX 77501',25327,222,NULL,51,34699,0);
INSERT INTO "django_geo_db_location" VALUES(60320,NULL,'Pasadena, TX 77502',25327,222,NULL,51,34700,0);
INSERT INTO "django_geo_db_location" VALUES(60321,NULL,'Pasadena, TX 77503',25327,222,NULL,51,34701,0);
INSERT INTO "django_geo_db_location" VALUES(60322,NULL,'Pasadena, TX 77504',25327,222,NULL,51,34702,0);
INSERT INTO "django_geo_db_location" VALUES(60323,NULL,'Pasadena, TX 77505',25327,222,NULL,51,34703,0);
INSERT INTO "django_geo_db_location" VALUES(60324,NULL,'Pasadena, TX 77506',25327,222,NULL,51,34704,0);
INSERT INTO "django_geo_db_location" VALUES(60325,NULL,'Pasadena, TX 77507',25327,222,NULL,51,34705,0);
INSERT INTO "django_geo_db_location" VALUES(60326,NULL,'Pasadena, TX 77508',25327,222,NULL,51,34706,0);
INSERT INTO "django_geo_db_location" VALUES(60327,NULL,'Santa Fe, TX',25328,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60328,NULL,'Santa Fe, TX 77510',25328,222,NULL,51,34707,0);
INSERT INTO "django_geo_db_location" VALUES(60329,NULL,'Alvin, TX',25329,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60330,NULL,'Alvin, TX 77511',25329,222,NULL,51,34708,0);
INSERT INTO "django_geo_db_location" VALUES(60331,NULL,'Alvin, TX 77512',25329,222,NULL,51,34709,0);
INSERT INTO "django_geo_db_location" VALUES(60332,NULL,'Anahuac, TX',25330,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60333,NULL,'Anahuac, TX 77514',25330,222,NULL,51,34710,0);
INSERT INTO "django_geo_db_location" VALUES(60334,NULL,'Angleton, TX',25331,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60335,NULL,'Angleton, TX 77515',25331,222,NULL,51,34711,0);
INSERT INTO "django_geo_db_location" VALUES(60336,NULL,'Angleton, TX 77516',25331,222,NULL,51,34712,0);
INSERT INTO "django_geo_db_location" VALUES(60337,NULL,'Santa Fe, TX 77517',25328,222,NULL,51,34713,0);
INSERT INTO "django_geo_db_location" VALUES(60338,NULL,'Bacliff, TX',25332,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60339,NULL,'Bacliff, TX 77518',25332,222,NULL,51,34714,0);
INSERT INTO "django_geo_db_location" VALUES(60340,NULL,'Batson, TX',25333,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60341,NULL,'Batson, TX 77519',25333,222,NULL,51,34715,0);
INSERT INTO "django_geo_db_location" VALUES(60342,NULL,'Baytown, TX',25334,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60343,NULL,'Baytown, TX 77520',25334,222,NULL,51,34716,0);
INSERT INTO "django_geo_db_location" VALUES(60344,NULL,'Baytown, TX 77521',25334,222,NULL,51,34717,0);
INSERT INTO "django_geo_db_location" VALUES(60345,NULL,'Baytown, TX 77522',25334,222,NULL,51,34718,0);
INSERT INTO "django_geo_db_location" VALUES(60346,NULL,'Channelview, TX',25335,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60347,NULL,'Channelview, TX 77530',25335,222,NULL,51,34719,0);
INSERT INTO "django_geo_db_location" VALUES(60348,NULL,'Clute, TX',25336,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60349,NULL,'Clute, TX 77531',25336,222,NULL,51,34720,0);
INSERT INTO "django_geo_db_location" VALUES(60350,NULL,'Crosby, TX',25337,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60351,NULL,'Crosby, TX 77532',25337,222,NULL,51,34721,0);
INSERT INTO "django_geo_db_location" VALUES(60352,NULL,'Daisetta, TX',25338,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60353,NULL,'Daisetta, TX 77533',25338,222,NULL,51,34722,0);
INSERT INTO "django_geo_db_location" VALUES(60354,NULL,'Danbury, TX',25339,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60355,NULL,'Danbury, TX 77534',25339,222,NULL,51,34723,0);
INSERT INTO "django_geo_db_location" VALUES(60356,NULL,'Dayton, TX',25340,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60357,NULL,'Dayton, TX 77535',25340,222,NULL,51,34724,0);
INSERT INTO "django_geo_db_location" VALUES(60358,NULL,'Deer Park, TX',25341,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60359,NULL,'Deer Park, TX 77536',25341,222,NULL,51,34725,0);
INSERT INTO "django_geo_db_location" VALUES(60360,NULL,'Dickinson, TX',25342,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60361,NULL,'Dickinson, TX 77537',25342,222,NULL,51,34726,0);
INSERT INTO "django_geo_db_location" VALUES(60362,NULL,'Devers, TX',25343,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60363,NULL,'Devers, TX 77538',25343,222,NULL,51,34727,0);
INSERT INTO "django_geo_db_location" VALUES(60364,NULL,'Dickinson, TX 77539',25342,222,NULL,51,34728,0);
INSERT INTO "django_geo_db_location" VALUES(60365,NULL,'Freeport, TX',25344,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60366,NULL,'Freeport, TX 77541',25344,222,NULL,51,34729,0);
INSERT INTO "django_geo_db_location" VALUES(60367,NULL,'Freeport, TX 77542',25344,222,NULL,51,34730,0);
INSERT INTO "django_geo_db_location" VALUES(60368,NULL,'Fresno, TX',25345,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60369,NULL,'Fresno, TX 77545',25345,222,NULL,51,34731,0);
INSERT INTO "django_geo_db_location" VALUES(60370,NULL,'Friendswood, TX',25346,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60371,NULL,'Friendswood, TX 77546',25346,222,NULL,51,34732,0);
INSERT INTO "django_geo_db_location" VALUES(60372,NULL,'Galena Park, TX',25347,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60373,NULL,'Galena Park, TX 77547',25347,222,NULL,51,34733,0);
INSERT INTO "django_geo_db_location" VALUES(60374,NULL,'Friendswood, TX 77549',25346,222,NULL,51,34734,0);
INSERT INTO "django_geo_db_location" VALUES(60375,NULL,'Galveston, TX',25348,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60376,NULL,'Galveston, TX 77550',25348,222,NULL,51,34735,0);
INSERT INTO "django_geo_db_location" VALUES(60377,NULL,'Galveston, TX 77551',25348,222,NULL,51,34736,0);
INSERT INTO "django_geo_db_location" VALUES(60378,NULL,'Galveston, TX 77552',25348,222,NULL,51,34737,0);
INSERT INTO "django_geo_db_location" VALUES(60379,NULL,'Galveston, TX 77553',25348,222,NULL,51,34738,0);
INSERT INTO "django_geo_db_location" VALUES(60380,NULL,'Galveston, TX 77554',25348,222,NULL,51,34739,0);
INSERT INTO "django_geo_db_location" VALUES(60381,NULL,'Galveston, TX 77555',25348,222,NULL,51,34740,0);
INSERT INTO "django_geo_db_location" VALUES(60382,NULL,'Hankamer, TX',25349,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60383,NULL,'Hankamer, TX 77560',25349,222,NULL,51,34741,0);
INSERT INTO "django_geo_db_location" VALUES(60384,NULL,'Hardin, TX',25350,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60385,NULL,'Hardin, TX 77561',25350,222,NULL,51,34742,0);
INSERT INTO "django_geo_db_location" VALUES(60386,NULL,'Highlands, TX',25351,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60387,NULL,'Highlands, TX 77562',25351,222,NULL,51,34743,0);
INSERT INTO "django_geo_db_location" VALUES(60388,NULL,'Hitchcock, TX',25352,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60389,NULL,'Hitchcock, TX 77563',25352,222,NULL,51,34744,0);
INSERT INTO "django_geo_db_location" VALUES(60390,NULL,'Hull, TX',25353,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60391,NULL,'Hull, TX 77564',25353,222,NULL,51,34745,0);
INSERT INTO "django_geo_db_location" VALUES(60392,NULL,'Kemah, TX',25354,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60393,NULL,'Kemah, TX 77565',25354,222,NULL,51,34746,0);
INSERT INTO "django_geo_db_location" VALUES(60394,NULL,'Lake Jackson, TX',25355,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60395,NULL,'Lake Jackson, TX 77566',25355,222,NULL,51,34747,0);
INSERT INTO "django_geo_db_location" VALUES(60396,NULL,'League City, TX',25356,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60397,NULL,'League City, TX 77567',25356,222,NULL,51,34748,0);
INSERT INTO "django_geo_db_location" VALUES(60398,NULL,'La Marque, TX',25357,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60399,NULL,'La Marque, TX 77568',25357,222,NULL,51,34749,0);
INSERT INTO "django_geo_db_location" VALUES(60400,NULL,'La Porte, TX',25358,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60401,NULL,'La Porte, TX 77571',25358,222,NULL,51,34750,0);
INSERT INTO "django_geo_db_location" VALUES(60402,NULL,'La Porte, TX 77572',25358,222,NULL,51,34751,0);
INSERT INTO "django_geo_db_location" VALUES(60403,NULL,'League City, TX 77573',25356,222,NULL,51,34752,0);
INSERT INTO "django_geo_db_location" VALUES(60404,NULL,'League City, TX 77574',25356,222,NULL,51,34753,0);
INSERT INTO "django_geo_db_location" VALUES(60405,NULL,'Liberty, TX',25359,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60406,NULL,'Liberty, TX 77575',25359,222,NULL,51,34754,0);
INSERT INTO "django_geo_db_location" VALUES(60407,NULL,'Liverpool, TX',25360,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60408,NULL,'Liverpool, TX 77577',25360,222,NULL,51,34755,0);
INSERT INTO "django_geo_db_location" VALUES(60409,NULL,'Manvel, TX',25361,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60410,NULL,'Manvel, TX 77578',25361,222,NULL,51,34756,0);
INSERT INTO "django_geo_db_location" VALUES(60411,NULL,'Mont Belvieu, TX',25362,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60412,NULL,'Mont Belvieu, TX 77580',25362,222,NULL,51,34757,0);
INSERT INTO "django_geo_db_location" VALUES(60413,NULL,'Pearland, TX',25363,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60414,NULL,'Pearland, TX 77581',25363,222,NULL,51,34758,0);
INSERT INTO "django_geo_db_location" VALUES(60415,NULL,'Raywood, TX',25364,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60416,NULL,'Raywood, TX 77582',25364,222,NULL,51,34759,0);
INSERT INTO "django_geo_db_location" VALUES(60417,NULL,'Rosharon, TX',25365,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60418,NULL,'Rosharon, TX 77583',25365,222,NULL,51,34760,0);
INSERT INTO "django_geo_db_location" VALUES(60419,NULL,'Pearland, TX 77584',25363,222,NULL,51,34761,0);
INSERT INTO "django_geo_db_location" VALUES(60420,NULL,'Saratoga, TX',25366,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60421,NULL,'Saratoga, TX 77585',25366,222,NULL,51,34762,0);
INSERT INTO "django_geo_db_location" VALUES(60422,NULL,'Seabrook, TX',25367,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60423,NULL,'Seabrook, TX 77586',25367,222,NULL,51,34763,0);
INSERT INTO "django_geo_db_location" VALUES(60424,NULL,'South Houston, TX',25368,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60425,NULL,'South Houston, TX 77587',25368,222,NULL,51,34764,0);
INSERT INTO "django_geo_db_location" VALUES(60426,NULL,'Pearland, TX 77588',25363,222,NULL,51,34765,0);
INSERT INTO "django_geo_db_location" VALUES(60427,NULL,'Texas City, TX',25369,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60428,NULL,'Texas City, TX 77590',25369,222,NULL,51,34766,0);
INSERT INTO "django_geo_db_location" VALUES(60429,NULL,'Texas City, TX 77591',25369,222,NULL,51,34767,0);
INSERT INTO "django_geo_db_location" VALUES(60430,NULL,'Texas City, TX 77592',25369,222,NULL,51,34768,0);
INSERT INTO "django_geo_db_location" VALUES(60431,NULL,'League City, TX 77593',25356,222,NULL,51,34769,0);
INSERT INTO "django_geo_db_location" VALUES(60432,NULL,'Wallisville, TX',25370,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60433,NULL,'Wallisville, TX 77597',25370,222,NULL,51,34770,0);
INSERT INTO "django_geo_db_location" VALUES(60434,NULL,'Webster, TX',25371,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60435,NULL,'Webster, TX 77598',25371,222,NULL,51,34771,0);
INSERT INTO "django_geo_db_location" VALUES(60436,NULL,'Bridge City, TX',25372,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60437,NULL,'Bridge City, TX 77611',25372,222,NULL,51,34772,0);
INSERT INTO "django_geo_db_location" VALUES(60438,NULL,'Buna, TX',25373,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60439,NULL,'Buna, TX 77612',25373,222,NULL,51,34773,0);
INSERT INTO "django_geo_db_location" VALUES(60440,NULL,'China, TX',25374,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60441,NULL,'China, TX 77613',25374,222,NULL,51,34774,0);
INSERT INTO "django_geo_db_location" VALUES(60442,NULL,'Deweyville, TX',25375,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60443,NULL,'Deweyville, TX 77614',25375,222,NULL,51,34775,0);
INSERT INTO "django_geo_db_location" VALUES(60444,NULL,'Evadale, TX',25376,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60445,NULL,'Evadale, TX 77615',25376,222,NULL,51,34776,0);
INSERT INTO "django_geo_db_location" VALUES(60446,NULL,'Fred, TX',25377,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60447,NULL,'Fred, TX 77616',25377,222,NULL,51,34777,0);
INSERT INTO "django_geo_db_location" VALUES(60448,NULL,'Gilchrist, TX',25378,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60449,NULL,'Gilchrist, TX 77617',25378,222,NULL,51,34778,0);
INSERT INTO "django_geo_db_location" VALUES(60450,NULL,'Groves, TX',25379,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60451,NULL,'Groves, TX 77619',25379,222,NULL,51,34779,0);
INSERT INTO "django_geo_db_location" VALUES(60452,NULL,'Hamshire, TX',25380,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60453,NULL,'Hamshire, TX 77622',25380,222,NULL,51,34780,0);
INSERT INTO "django_geo_db_location" VALUES(60454,NULL,'High Island, TX',25381,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60455,NULL,'High Island, TX 77623',25381,222,NULL,51,34781,0);
INSERT INTO "django_geo_db_location" VALUES(60456,NULL,'Hillister, TX',25382,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60457,NULL,'Hillister, TX 77624',25382,222,NULL,51,34782,0);
INSERT INTO "django_geo_db_location" VALUES(60458,NULL,'Kountze, TX',25383,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60459,NULL,'Kountze, TX 77625',25383,222,NULL,51,34783,0);
INSERT INTO "django_geo_db_location" VALUES(60460,NULL,'Mauriceville, TX',25384,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60461,NULL,'Mauriceville, TX 77626',25384,222,NULL,51,34784,0);
INSERT INTO "django_geo_db_location" VALUES(60462,NULL,'Nederland, TX',25385,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60463,NULL,'Nederland, TX 77627',25385,222,NULL,51,34785,0);
INSERT INTO "django_geo_db_location" VALUES(60464,NULL,'Nome, TX',25386,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60465,NULL,'Nome, TX 77629',25386,222,NULL,51,34786,0);
INSERT INTO "django_geo_db_location" VALUES(60466,NULL,'Orange, TX',25387,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60467,NULL,'Orange, TX 77630',25387,222,NULL,51,34787,0);
INSERT INTO "django_geo_db_location" VALUES(60468,NULL,'Orange, TX 77631',25387,222,NULL,51,34788,0);
INSERT INTO "django_geo_db_location" VALUES(60469,NULL,'Orange, TX 77632',25387,222,NULL,51,34789,0);
INSERT INTO "django_geo_db_location" VALUES(60470,NULL,'Brenham, TX',25388,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60471,NULL,'Brenham, TX 77633',25388,222,NULL,51,34790,0);
INSERT INTO "django_geo_db_location" VALUES(60472,NULL,'Orangefield, TX',25389,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60473,NULL,'Orangefield, TX 77639',25389,222,NULL,51,34791,0);
INSERT INTO "django_geo_db_location" VALUES(60474,NULL,'Port Arthur, TX',25390,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60475,NULL,'Port Arthur, TX 77640',25390,222,NULL,51,34792,0);
INSERT INTO "django_geo_db_location" VALUES(60476,NULL,'Port Arthur, TX 77641',25390,222,NULL,51,34793,0);
INSERT INTO "django_geo_db_location" VALUES(60477,NULL,'Port Arthur, TX 77642',25390,222,NULL,51,34794,0);
INSERT INTO "django_geo_db_location" VALUES(60478,NULL,'Port Arthur, TX 77643',25390,222,NULL,51,34795,0);
INSERT INTO "django_geo_db_location" VALUES(60479,NULL,'Port Bolivar, TX',25391,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60480,NULL,'Port Bolivar, TX 77650',25391,222,NULL,51,34796,0);
INSERT INTO "django_geo_db_location" VALUES(60481,NULL,'Port Neches, TX',25392,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60482,NULL,'Port Neches, TX 77651',25392,222,NULL,51,34797,0);
INSERT INTO "django_geo_db_location" VALUES(60483,NULL,'Sabine Pass, TX',25393,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60484,NULL,'Sabine Pass, TX 77655',25393,222,NULL,51,34798,0);
INSERT INTO "django_geo_db_location" VALUES(60485,NULL,'Silsbee, TX',25394,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60486,NULL,'Silsbee, TX 77656',25394,222,NULL,51,34799,0);
INSERT INTO "django_geo_db_location" VALUES(60487,NULL,'Lumberton, TX',25395,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60488,NULL,'Lumberton, TX 77657',25395,222,NULL,51,34800,0);
INSERT INTO "django_geo_db_location" VALUES(60489,NULL,'Sour Lake, TX',25396,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60490,NULL,'Sour Lake, TX 77659',25396,222,NULL,51,34801,0);
INSERT INTO "django_geo_db_location" VALUES(60491,NULL,'Spurger, TX',25397,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60492,NULL,'Spurger, TX 77660',25397,222,NULL,51,34802,0);
INSERT INTO "django_geo_db_location" VALUES(60493,NULL,'Stowell, TX',25398,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60494,NULL,'Stowell, TX 77661',25398,222,NULL,51,34803,0);
INSERT INTO "django_geo_db_location" VALUES(60495,NULL,'Vidor, TX',25399,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60496,NULL,'Vidor, TX 77662',25399,222,NULL,51,34804,0);
INSERT INTO "django_geo_db_location" VALUES(60497,NULL,'Village Mills, TX',25400,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60498,NULL,'Village Mills, TX 77663',25400,222,NULL,51,34805,0);
INSERT INTO "django_geo_db_location" VALUES(60499,NULL,'Warren, TX',25401,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60500,NULL,'Warren, TX 77664',25401,222,NULL,51,34806,0);
INSERT INTO "django_geo_db_location" VALUES(60501,NULL,'Winnie, TX',25402,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60502,NULL,'Winnie, TX 77665',25402,222,NULL,51,34807,0);
INSERT INTO "django_geo_db_location" VALUES(60503,NULL,'Vidor, TX 77670',25399,222,NULL,51,34808,0);
INSERT INTO "django_geo_db_location" VALUES(60504,NULL,'Beaumont, TX',25403,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60505,NULL,'Beaumont, TX 77701',25403,222,NULL,51,34809,0);
INSERT INTO "django_geo_db_location" VALUES(60506,NULL,'Beaumont, TX 77702',25403,222,NULL,51,34810,0);
INSERT INTO "django_geo_db_location" VALUES(60507,NULL,'Beaumont, TX 77703',25403,222,NULL,51,34811,0);
INSERT INTO "django_geo_db_location" VALUES(60508,NULL,'Beaumont, TX 77704',25403,222,NULL,51,34812,0);
INSERT INTO "django_geo_db_location" VALUES(60509,NULL,'Beaumont, TX 77705',25403,222,NULL,51,34813,0);
INSERT INTO "django_geo_db_location" VALUES(60510,NULL,'Beaumont, TX 77706',25403,222,NULL,51,34814,0);
INSERT INTO "django_geo_db_location" VALUES(60511,NULL,'Beaumont, TX 77707',25403,222,NULL,51,34815,0);
INSERT INTO "django_geo_db_location" VALUES(60512,NULL,'Beaumont, TX 77708',25403,222,NULL,51,34816,0);
INSERT INTO "django_geo_db_location" VALUES(60513,NULL,'Voth, TX',25404,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60514,NULL,'Voth, TX 77709',25404,222,NULL,51,34817,0);
INSERT INTO "django_geo_db_location" VALUES(60515,NULL,'Beaumont, TX 77710',25403,222,NULL,51,34818,0);
INSERT INTO "django_geo_db_location" VALUES(60516,NULL,'Beaumont, TX 77713',25403,222,NULL,51,34819,0);
INSERT INTO "django_geo_db_location" VALUES(60517,NULL,'Beaumont, TX 77720',25403,222,NULL,51,34820,0);
INSERT INTO "django_geo_db_location" VALUES(60518,NULL,'Beaumont, TX 77725',25403,222,NULL,51,34821,0);
INSERT INTO "django_geo_db_location" VALUES(60519,NULL,'Beaumont, TX 77726',25403,222,NULL,51,34822,0);
INSERT INTO "django_geo_db_location" VALUES(60520,NULL,'Tomball, TX 77735',25257,222,NULL,51,34823,0);
INSERT INTO "django_geo_db_location" VALUES(60521,NULL,'Bryan, TX',25405,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60522,NULL,'Bryan, TX 77801',25405,222,NULL,51,34824,0);
INSERT INTO "django_geo_db_location" VALUES(60523,NULL,'Bryan, TX 77802',25405,222,NULL,51,34825,0);
INSERT INTO "django_geo_db_location" VALUES(60524,NULL,'Bryan, TX 77803',25405,222,NULL,51,34826,0);
INSERT INTO "django_geo_db_location" VALUES(60525,NULL,'Bryan, TX 77805',25405,222,NULL,51,34827,0);
INSERT INTO "django_geo_db_location" VALUES(60526,NULL,'Bryan, TX 77806',25405,222,NULL,51,34828,0);
INSERT INTO "django_geo_db_location" VALUES(60527,NULL,'Bryan, TX 77807',25405,222,NULL,51,34829,0);
INSERT INTO "django_geo_db_location" VALUES(60528,NULL,'Bryan, TX 77808',25405,222,NULL,51,34830,0);
INSERT INTO "django_geo_db_location" VALUES(60529,NULL,'Anderson, TX',25406,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60530,NULL,'Anderson, TX 77830',25406,222,NULL,51,34831,0);
INSERT INTO "django_geo_db_location" VALUES(60531,NULL,'Bedias, TX',25407,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60532,NULL,'Bedias, TX 77831',25407,222,NULL,51,34832,0);
INSERT INTO "django_geo_db_location" VALUES(60533,NULL,'Brenham, TX 77833',25388,222,NULL,51,34833,0);
INSERT INTO "django_geo_db_location" VALUES(60534,NULL,'Brenham, TX 77834',25388,222,NULL,51,34834,0);
INSERT INTO "django_geo_db_location" VALUES(60535,NULL,'Burton, TX',25408,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60536,NULL,'Burton, TX 77835',25408,222,NULL,51,34835,0);
INSERT INTO "django_geo_db_location" VALUES(60537,NULL,'Caldwell, TX',25409,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60538,NULL,'Caldwell, TX 77836',25409,222,NULL,51,34836,0);
INSERT INTO "django_geo_db_location" VALUES(60539,NULL,'Calvert, TX',25410,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60540,NULL,'Calvert, TX 77837',25410,222,NULL,51,34837,0);
INSERT INTO "django_geo_db_location" VALUES(60541,NULL,'Chriesman, TX',25411,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60542,NULL,'Chriesman, TX 77838',25411,222,NULL,51,34838,0);
INSERT INTO "django_geo_db_location" VALUES(60543,NULL,'Clay, TX',25412,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60544,NULL,'Clay, TX 77839',25412,222,NULL,51,34839,0);
INSERT INTO "django_geo_db_location" VALUES(60545,NULL,'College Station, TX',25413,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60546,NULL,'College Station, TX 77840',25413,222,NULL,51,34840,0);
INSERT INTO "django_geo_db_location" VALUES(60547,NULL,'College Station, TX 77841',25413,222,NULL,51,34841,0);
INSERT INTO "django_geo_db_location" VALUES(60548,NULL,'College Station, TX 77842',25413,222,NULL,51,34842,0);
INSERT INTO "django_geo_db_location" VALUES(60549,NULL,'College Station, TX 77843',25413,222,NULL,51,34843,0);
INSERT INTO "django_geo_db_location" VALUES(60550,NULL,'College Station, TX 77844',25413,222,NULL,51,34844,0);
INSERT INTO "django_geo_db_location" VALUES(60551,NULL,'College Station, TX 77845',25413,222,NULL,51,34845,0);
INSERT INTO "django_geo_db_location" VALUES(60552,NULL,'Concord, TX',25414,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60553,NULL,'Concord, TX 77850',25414,222,NULL,51,34846,0);
INSERT INTO "django_geo_db_location" VALUES(60554,NULL,'Deanville, TX',25415,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60555,NULL,'Deanville, TX 77852',25415,222,NULL,51,34847,0);
INSERT INTO "django_geo_db_location" VALUES(60556,NULL,'Dime Box, TX',25416,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60557,NULL,'Dime Box, TX 77853',25416,222,NULL,51,34848,0);
INSERT INTO "django_geo_db_location" VALUES(60558,NULL,'Flynn, TX',25417,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60559,NULL,'Flynn, TX 77855',25417,222,NULL,51,34849,0);
INSERT INTO "django_geo_db_location" VALUES(60560,NULL,'Franklin, TX',25418,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60561,NULL,'Franklin, TX 77856',25418,222,NULL,51,34850,0);
INSERT INTO "django_geo_db_location" VALUES(60562,NULL,'Gause, TX',25419,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60563,NULL,'Gause, TX 77857',25419,222,NULL,51,34851,0);
INSERT INTO "django_geo_db_location" VALUES(60564,NULL,'Hearne, TX',25420,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60565,NULL,'Hearne, TX 77859',25420,222,NULL,51,34852,0);
INSERT INTO "django_geo_db_location" VALUES(60566,NULL,'Iola, TX',25421,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60567,NULL,'Iola, TX 77861',25421,222,NULL,51,34853,0);
INSERT INTO "django_geo_db_location" VALUES(60568,NULL,'Kurten, TX',25422,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60569,NULL,'Kurten, TX 77862',25422,222,NULL,51,34854,0);
INSERT INTO "django_geo_db_location" VALUES(60570,NULL,'Lyons, TX',25423,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60571,NULL,'Lyons, TX 77863',25423,222,NULL,51,34855,0);
INSERT INTO "django_geo_db_location" VALUES(60572,NULL,'Madisonville, TX',25424,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60573,NULL,'Madisonville, TX 77864',25424,222,NULL,51,34856,0);
INSERT INTO "django_geo_db_location" VALUES(60574,NULL,'Marquez, TX',25425,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60575,NULL,'Marquez, TX 77865',25425,222,NULL,51,34857,0);
INSERT INTO "django_geo_db_location" VALUES(60576,NULL,'Millican, TX',25426,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60577,NULL,'Millican, TX 77866',25426,222,NULL,51,34858,0);
INSERT INTO "django_geo_db_location" VALUES(60578,NULL,'Mumford, TX',25427,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60579,NULL,'Mumford, TX 77867',25427,222,NULL,51,34859,0);
INSERT INTO "django_geo_db_location" VALUES(60580,NULL,'Navasota, TX',25428,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60581,NULL,'Navasota, TX 77868',25428,222,NULL,51,34860,0);
INSERT INTO "django_geo_db_location" VALUES(60582,NULL,'Navasota, TX 77869',25428,222,NULL,51,34861,0);
INSERT INTO "django_geo_db_location" VALUES(60583,NULL,'New Baden, TX',25429,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60584,NULL,'New Baden, TX 77870',25429,222,NULL,51,34862,0);
INSERT INTO "django_geo_db_location" VALUES(60585,NULL,'Normangee, TX',25430,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60586,NULL,'Normangee, TX 77871',25430,222,NULL,51,34863,0);
INSERT INTO "django_geo_db_location" VALUES(60587,NULL,'North Zulch, TX',25431,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60588,NULL,'North Zulch, TX 77872',25431,222,NULL,51,34864,0);
INSERT INTO "django_geo_db_location" VALUES(60589,NULL,'Richards, TX',25432,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60590,NULL,'Richards, TX 77873',25432,222,NULL,51,34865,0);
INSERT INTO "django_geo_db_location" VALUES(60591,NULL,'Waller, TX 77874',25323,222,NULL,51,34866,0);
INSERT INTO "django_geo_db_location" VALUES(60592,NULL,'Roans Prairie, TX',25433,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60593,NULL,'Roans Prairie, TX 77875',25433,222,NULL,51,34867,0);
INSERT INTO "django_geo_db_location" VALUES(60594,NULL,'Shiro, TX',25434,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60595,NULL,'Shiro, TX 77876',25434,222,NULL,51,34868,0);
INSERT INTO "django_geo_db_location" VALUES(60596,NULL,'Snook, TX',25435,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60597,NULL,'Snook, TX 77878',25435,222,NULL,51,34869,0);
INSERT INTO "django_geo_db_location" VALUES(60598,NULL,'Somerville, TX',25436,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60599,NULL,'Somerville, TX 77879',25436,222,NULL,51,34870,0);
INSERT INTO "django_geo_db_location" VALUES(60600,NULL,'Washington, TX',25437,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60601,NULL,'Washington, TX 77880',25437,222,NULL,51,34871,0);
INSERT INTO "django_geo_db_location" VALUES(60602,NULL,'Wellborn, TX',25438,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60603,NULL,'Wellborn, TX 77881',25438,222,NULL,51,34872,0);
INSERT INTO "django_geo_db_location" VALUES(60604,NULL,'Wheelock, TX',25439,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60605,NULL,'Wheelock, TX 77882',25439,222,NULL,51,34873,0);
INSERT INTO "django_geo_db_location" VALUES(60606,NULL,'Sienna Plantation, TX',25440,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60607,NULL,'Sienna Plantation, TX 77889',25440,222,NULL,51,34874,0);
INSERT INTO "django_geo_db_location" VALUES(60608,NULL,'Victoria, TX',25441,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60609,NULL,'Victoria, TX 77901',25441,222,NULL,51,34875,0);
INSERT INTO "django_geo_db_location" VALUES(60610,NULL,'Victoria, TX 77902',25441,222,NULL,51,34876,0);
INSERT INTO "django_geo_db_location" VALUES(60611,NULL,'Victoria, TX 77903',25441,222,NULL,51,34877,0);
INSERT INTO "django_geo_db_location" VALUES(60612,NULL,'Victoria, TX 77904',25441,222,NULL,51,34878,0);
INSERT INTO "django_geo_db_location" VALUES(60613,NULL,'Victoria, TX 77905',25441,222,NULL,51,34879,0);
INSERT INTO "django_geo_db_location" VALUES(60614,NULL,'Austwell, TX',25442,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60615,NULL,'Austwell, TX 77950',25442,222,NULL,51,34880,0);
INSERT INTO "django_geo_db_location" VALUES(60616,NULL,'Bloomington, TX',25443,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60617,NULL,'Bloomington, TX 77951',25443,222,NULL,51,34881,0);
INSERT INTO "django_geo_db_location" VALUES(60618,NULL,'Cuero, TX',25444,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60619,NULL,'Cuero, TX 77954',25444,222,NULL,51,34882,0);
INSERT INTO "django_geo_db_location" VALUES(60620,NULL,'Edna, TX',25445,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60621,NULL,'Edna, TX 77957',25445,222,NULL,51,34883,0);
INSERT INTO "django_geo_db_location" VALUES(60622,NULL,'Fannin, TX',25446,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60623,NULL,'Fannin, TX 77960',25446,222,NULL,51,34884,0);
INSERT INTO "django_geo_db_location" VALUES(60624,NULL,'Francitas, TX',25447,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60625,NULL,'Francitas, TX 77961',25447,222,NULL,51,34885,0);
INSERT INTO "django_geo_db_location" VALUES(60626,NULL,'Ganado, TX',25448,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60627,NULL,'Ganado, TX 77962',25448,222,NULL,51,34886,0);
INSERT INTO "django_geo_db_location" VALUES(60628,NULL,'Goliad, TX',25449,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60629,NULL,'Goliad, TX 77963',25449,222,NULL,51,34887,0);
INSERT INTO "django_geo_db_location" VALUES(60630,NULL,'Hallettsville, TX',25450,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60631,NULL,'Hallettsville, TX 77964',25450,222,NULL,51,34888,0);
INSERT INTO "django_geo_db_location" VALUES(60632,NULL,'Hallettsville, TX 77965',25450,222,NULL,51,34889,0);
INSERT INTO "django_geo_db_location" VALUES(60633,NULL,'Hochheim, TX',25451,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60634,NULL,'Hochheim, TX 77967',25451,222,NULL,51,34890,0);
INSERT INTO "django_geo_db_location" VALUES(60635,NULL,'Inez, TX',25452,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60636,NULL,'Inez, TX 77968',25452,222,NULL,51,34891,0);
INSERT INTO "django_geo_db_location" VALUES(60637,NULL,'La Salle, TX',25453,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60638,NULL,'La Salle, TX 77969',25453,222,NULL,51,34892,0);
INSERT INTO "django_geo_db_location" VALUES(60639,NULL,'La Ward, TX',25454,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60640,NULL,'La Ward, TX 77970',25454,222,NULL,51,34893,0);
INSERT INTO "django_geo_db_location" VALUES(60641,NULL,'Lolita, TX',25455,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60642,NULL,'Lolita, TX 77971',25455,222,NULL,51,34894,0);
INSERT INTO "django_geo_db_location" VALUES(60643,NULL,'Long Mott, TX',25456,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60644,NULL,'Long Mott, TX 77972',25456,222,NULL,51,34895,0);
INSERT INTO "django_geo_db_location" VALUES(60645,NULL,'Mcfaddin, TX',25457,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60646,NULL,'Mcfaddin, TX 77973',25457,222,NULL,51,34896,0);
INSERT INTO "django_geo_db_location" VALUES(60647,NULL,'Meyersville, TX',25458,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60648,NULL,'Meyersville, TX 77974',25458,222,NULL,51,34897,0);
INSERT INTO "django_geo_db_location" VALUES(60649,NULL,'Moulton, TX',25459,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60650,NULL,'Moulton, TX 77975',25459,222,NULL,51,34898,0);
INSERT INTO "django_geo_db_location" VALUES(60651,NULL,'Nursery, TX',25460,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60652,NULL,'Nursery, TX 77976',25460,222,NULL,51,34899,0);
INSERT INTO "django_geo_db_location" VALUES(60653,NULL,'Placedo, TX',25461,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60654,NULL,'Placedo, TX 77977',25461,222,NULL,51,34900,0);
INSERT INTO "django_geo_db_location" VALUES(60655,NULL,'Point Comfort, TX',25462,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60656,NULL,'Point Comfort, TX 77978',25462,222,NULL,51,34901,0);
INSERT INTO "django_geo_db_location" VALUES(60657,NULL,'Port Lavaca, TX',25463,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60658,NULL,'Port Lavaca, TX 77979',25463,222,NULL,51,34902,0);
INSERT INTO "django_geo_db_location" VALUES(60659,NULL,'Port O Connor, TX',25464,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60660,NULL,'Port O Connor, TX 77982',25464,222,NULL,51,34903,0);
INSERT INTO "django_geo_db_location" VALUES(60661,NULL,'Seadrift, TX',25465,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60662,NULL,'Seadrift, TX 77983',25465,222,NULL,51,34904,0);
INSERT INTO "django_geo_db_location" VALUES(60663,NULL,'Shiner, TX',25466,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60664,NULL,'Shiner, TX 77984',25466,222,NULL,51,34905,0);
INSERT INTO "django_geo_db_location" VALUES(60665,NULL,'Speaks, TX',25467,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60666,NULL,'Speaks, TX 77985',25467,222,NULL,51,34906,0);
INSERT INTO "django_geo_db_location" VALUES(60667,NULL,'Sublime, TX',25468,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60668,NULL,'Sublime, TX 77986',25468,222,NULL,51,34907,0);
INSERT INTO "django_geo_db_location" VALUES(60669,NULL,'Sweet Home, TX',25469,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60670,NULL,'Sweet Home, TX 77987',25469,222,NULL,51,34908,0);
INSERT INTO "django_geo_db_location" VALUES(60671,NULL,'Telferner, TX',25470,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60672,NULL,'Telferner, TX 77988',25470,222,NULL,51,34909,0);
INSERT INTO "django_geo_db_location" VALUES(60673,NULL,'Thomaston, TX',25471,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60674,NULL,'Thomaston, TX 77989',25471,222,NULL,51,34910,0);
INSERT INTO "django_geo_db_location" VALUES(60675,NULL,'Tivoli, TX',25472,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60676,NULL,'Tivoli, TX 77990',25472,222,NULL,51,34911,0);
INSERT INTO "django_geo_db_location" VALUES(60677,NULL,'Vanderbilt, TX',25473,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60678,NULL,'Vanderbilt, TX 77991',25473,222,NULL,51,34912,0);
INSERT INTO "django_geo_db_location" VALUES(60679,NULL,'Weesatche, TX',25474,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60680,NULL,'Weesatche, TX 77993',25474,222,NULL,51,34913,0);
INSERT INTO "django_geo_db_location" VALUES(60681,NULL,'Westhoff, TX',25475,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60682,NULL,'Westhoff, TX 77994',25475,222,NULL,51,34914,0);
INSERT INTO "django_geo_db_location" VALUES(60683,NULL,'Yoakum, TX',25476,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60684,NULL,'Yoakum, TX 77995',25476,222,NULL,51,34915,0);
INSERT INTO "django_geo_db_location" VALUES(60685,NULL,'Texas City, TX 77999',25369,222,NULL,51,34916,0);
INSERT INTO "django_geo_db_location" VALUES(60686,NULL,'Artesia Wells, TX',25477,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60687,NULL,'Artesia Wells, TX 78001',25477,222,NULL,51,34917,0);
INSERT INTO "django_geo_db_location" VALUES(60688,NULL,'Atascosa, TX',25478,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60689,NULL,'Atascosa, TX 78002',25478,222,NULL,51,34918,0);
INSERT INTO "django_geo_db_location" VALUES(60690,NULL,'Bandera, TX',25479,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60691,NULL,'Bandera, TX 78003',25479,222,NULL,51,34919,0);
INSERT INTO "django_geo_db_location" VALUES(60692,NULL,'Bergheim, TX',25480,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60693,NULL,'Bergheim, TX 78004',25480,222,NULL,51,34920,0);
INSERT INTO "django_geo_db_location" VALUES(60694,NULL,'Bigfoot, TX',25481,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60695,NULL,'Bigfoot, TX 78005',25481,222,NULL,51,34921,0);
INSERT INTO "django_geo_db_location" VALUES(60696,NULL,'Boerne, TX',25482,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60697,NULL,'Boerne, TX 78006',25482,222,NULL,51,34922,0);
INSERT INTO "django_geo_db_location" VALUES(60698,NULL,'Calliham, TX',25483,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60699,NULL,'Calliham, TX 78007',25483,222,NULL,51,34923,0);
INSERT INTO "django_geo_db_location" VALUES(60700,NULL,'Campbellton, TX',25484,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60701,NULL,'Campbellton, TX 78008',25484,222,NULL,51,34924,0);
INSERT INTO "django_geo_db_location" VALUES(60702,NULL,'Castroville, TX',25485,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60703,NULL,'Castroville, TX 78009',25485,222,NULL,51,34925,0);
INSERT INTO "django_geo_db_location" VALUES(60704,NULL,'Center Point, TX',25486,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60705,NULL,'Center Point, TX 78010',25486,222,NULL,51,34926,0);
INSERT INTO "django_geo_db_location" VALUES(60706,NULL,'Charlotte, TX',25487,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60707,NULL,'Charlotte, TX 78011',25487,222,NULL,51,34927,0);
INSERT INTO "django_geo_db_location" VALUES(60708,NULL,'Christine, TX',25488,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60709,NULL,'Christine, TX 78012',25488,222,NULL,51,34928,0);
INSERT INTO "django_geo_db_location" VALUES(60710,NULL,'Comfort, TX',25489,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60711,NULL,'Comfort, TX 78013',25489,222,NULL,51,34929,0);
INSERT INTO "django_geo_db_location" VALUES(60712,NULL,'Cotulla, TX',25490,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60713,NULL,'Cotulla, TX 78014',25490,222,NULL,51,34930,0);
INSERT INTO "django_geo_db_location" VALUES(60714,NULL,'Boerne, TX 78015',25482,222,NULL,51,34931,0);
INSERT INTO "django_geo_db_location" VALUES(60715,NULL,'Devine, TX',25491,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60716,NULL,'Devine, TX 78016',25491,222,NULL,51,34932,0);
INSERT INTO "django_geo_db_location" VALUES(60717,NULL,'Dilley, TX',25492,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60718,NULL,'Dilley, TX 78017',25492,222,NULL,51,34933,0);
INSERT INTO "django_geo_db_location" VALUES(60719,NULL,'Encinal, TX',25493,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60720,NULL,'Encinal, TX 78019',25493,222,NULL,51,34934,0);
INSERT INTO "django_geo_db_location" VALUES(60721,NULL,'Fowlerton, TX',25494,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60722,NULL,'Fowlerton, TX 78021',25494,222,NULL,51,34935,0);
INSERT INTO "django_geo_db_location" VALUES(60723,NULL,'George West, TX',25495,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60724,NULL,'George West, TX 78022',25495,222,NULL,51,34936,0);
INSERT INTO "django_geo_db_location" VALUES(60725,NULL,'Helotes, TX',25496,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60726,NULL,'Helotes, TX 78023',25496,222,NULL,51,34937,0);
INSERT INTO "django_geo_db_location" VALUES(60727,NULL,'Hunt, TX',25497,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60728,NULL,'Hunt, TX 78024',25497,222,NULL,51,34938,0);
INSERT INTO "django_geo_db_location" VALUES(60729,NULL,'Ingram, TX',25498,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60730,NULL,'Ingram, TX 78025',25498,222,NULL,51,34939,0);
INSERT INTO "django_geo_db_location" VALUES(60731,NULL,'Jourdanton, TX',25499,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60732,NULL,'Jourdanton, TX 78026',25499,222,NULL,51,34940,0);
INSERT INTO "django_geo_db_location" VALUES(60733,NULL,'Kendalia, TX',25500,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60734,NULL,'Kendalia, TX 78027',25500,222,NULL,51,34941,0);
INSERT INTO "django_geo_db_location" VALUES(60735,NULL,'Kerrville, TX',25501,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60736,NULL,'Kerrville, TX 78028',25501,222,NULL,51,34942,0);
INSERT INTO "django_geo_db_location" VALUES(60737,NULL,'Kerrville, TX 78029',25501,222,NULL,51,34943,0);
INSERT INTO "django_geo_db_location" VALUES(60738,NULL,'La Coste, TX',25502,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60739,NULL,'La Coste, TX 78039',25502,222,NULL,51,34944,0);
INSERT INTO "django_geo_db_location" VALUES(60740,NULL,'Laredo, TX',25503,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60741,NULL,'Laredo, TX 78040',25503,222,NULL,51,34945,0);
INSERT INTO "django_geo_db_location" VALUES(60742,NULL,'Laredo, TX 78041',25503,222,NULL,51,34946,0);
INSERT INTO "django_geo_db_location" VALUES(60743,NULL,'Laredo, TX 78042',25503,222,NULL,51,34947,0);
INSERT INTO "django_geo_db_location" VALUES(60744,NULL,'Laredo, TX 78043',25503,222,NULL,51,34948,0);
INSERT INTO "django_geo_db_location" VALUES(60745,NULL,'Laredo, TX 78044',25503,222,NULL,51,34949,0);
INSERT INTO "django_geo_db_location" VALUES(60746,NULL,'Laredo, TX 78045',25503,222,NULL,51,34950,0);
INSERT INTO "django_geo_db_location" VALUES(60747,NULL,'Laredo, TX 78046',25503,222,NULL,51,34951,0);
INSERT INTO "django_geo_db_location" VALUES(60748,NULL,'Laredo, TX 78047',25503,222,NULL,51,34952,0);
INSERT INTO "django_geo_db_location" VALUES(60749,NULL,'Laredo, TX 78049',25503,222,NULL,51,34953,0);
INSERT INTO "django_geo_db_location" VALUES(60750,NULL,'Leming, TX',25504,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60751,NULL,'Leming, TX 78050',25504,222,NULL,51,34954,0);
INSERT INTO "django_geo_db_location" VALUES(60752,NULL,'Lytle, TX',25505,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60753,NULL,'Lytle, TX 78052',25505,222,NULL,51,34955,0);
INSERT INTO "django_geo_db_location" VALUES(60754,NULL,'McCoy, TX',25506,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60755,NULL,'McCoy, TX 78053',25506,222,NULL,51,34956,0);
INSERT INTO "django_geo_db_location" VALUES(60756,NULL,'Macdona, TX',25507,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60757,NULL,'Macdona, TX 78054',25507,222,NULL,51,34957,0);
INSERT INTO "django_geo_db_location" VALUES(60758,NULL,'Medina, TX',25508,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60759,NULL,'Medina, TX 78055',25508,222,NULL,51,34958,0);
INSERT INTO "django_geo_db_location" VALUES(60760,NULL,'Mico, TX',25509,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60761,NULL,'Mico, TX 78056',25509,222,NULL,51,34959,0);
INSERT INTO "django_geo_db_location" VALUES(60762,NULL,'Moore, TX',25510,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60763,NULL,'Moore, TX 78057',25510,222,NULL,51,34960,0);
INSERT INTO "django_geo_db_location" VALUES(60764,NULL,'Mountain Home, TX',25511,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60765,NULL,'Mountain Home, TX 78058',25511,222,NULL,51,34961,0);
INSERT INTO "django_geo_db_location" VALUES(60766,NULL,'Natalia, TX',25512,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60767,NULL,'Natalia, TX 78059',25512,222,NULL,51,34962,0);
INSERT INTO "django_geo_db_location" VALUES(60768,NULL,'Oakville, TX',25513,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60769,NULL,'Oakville, TX 78060',25513,222,NULL,51,34963,0);
INSERT INTO "django_geo_db_location" VALUES(60770,NULL,'Pearsall, TX',25514,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60771,NULL,'Pearsall, TX 78061',25514,222,NULL,51,34964,0);
INSERT INTO "django_geo_db_location" VALUES(60772,NULL,'Peggy, TX',25515,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60773,NULL,'Peggy, TX 78062',25515,222,NULL,51,34965,0);
INSERT INTO "django_geo_db_location" VALUES(60774,NULL,'Pipe Creek, TX',25516,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60775,NULL,'Pipe Creek, TX 78063',25516,222,NULL,51,34966,0);
INSERT INTO "django_geo_db_location" VALUES(60776,NULL,'Pleasanton, TX',25517,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60777,NULL,'Pleasanton, TX 78064',25517,222,NULL,51,34967,0);
INSERT INTO "django_geo_db_location" VALUES(60778,NULL,'Poteet, TX',25518,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60779,NULL,'Poteet, TX 78065',25518,222,NULL,51,34968,0);
INSERT INTO "django_geo_db_location" VALUES(60780,NULL,'Rio Medina, TX',25519,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60781,NULL,'Rio Medina, TX 78066',25519,222,NULL,51,34969,0);
INSERT INTO "django_geo_db_location" VALUES(60782,NULL,'San Ygnacio, TX',25520,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60783,NULL,'San Ygnacio, TX 78067',25520,222,NULL,51,34970,0);
INSERT INTO "django_geo_db_location" VALUES(60784,NULL,'Somerset, TX',25521,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60785,NULL,'Somerset, TX 78069',25521,222,NULL,51,34971,0);
INSERT INTO "django_geo_db_location" VALUES(60786,NULL,'Spring Branch, TX',25522,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60787,NULL,'Spring Branch, TX 78070',25522,222,NULL,51,34972,0);
INSERT INTO "django_geo_db_location" VALUES(60788,NULL,'Three Rivers, TX',25523,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60789,NULL,'Three Rivers, TX 78071',25523,222,NULL,51,34973,0);
INSERT INTO "django_geo_db_location" VALUES(60790,NULL,'Tilden, TX',25524,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60791,NULL,'Tilden, TX 78072',25524,222,NULL,51,34974,0);
INSERT INTO "django_geo_db_location" VALUES(60792,NULL,'Von Ormy, TX',25525,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60793,NULL,'Von Ormy, TX 78073',25525,222,NULL,51,34975,0);
INSERT INTO "django_geo_db_location" VALUES(60794,NULL,'Waring, TX',25526,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60795,NULL,'Waring, TX 78074',25526,222,NULL,51,34976,0);
INSERT INTO "django_geo_db_location" VALUES(60796,NULL,'Whitsett, TX',25527,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60797,NULL,'Whitsett, TX 78075',25527,222,NULL,51,34977,0);
INSERT INTO "django_geo_db_location" VALUES(60798,NULL,'Zapata, TX',25528,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60799,NULL,'Zapata, TX 78076',25528,222,NULL,51,34978,0);
INSERT INTO "django_geo_db_location" VALUES(60800,NULL,'Judsonia, AR 78081',23572,222,NULL,4,34979,0);
INSERT INTO "django_geo_db_location" VALUES(60801,NULL,'Laredo, TX 78093',25503,222,NULL,51,34980,0);
INSERT INTO "django_geo_db_location" VALUES(60802,NULL,'Adkins, TX',25529,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60803,NULL,'Adkins, TX 78101',25529,222,NULL,51,34981,0);
INSERT INTO "django_geo_db_location" VALUES(60804,NULL,'Beeville, TX',25530,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60805,NULL,'Beeville, TX 78102',25530,222,NULL,51,34982,0);
INSERT INTO "django_geo_db_location" VALUES(60806,NULL,'Beeville, TX 78104',25530,222,NULL,51,34983,0);
INSERT INTO "django_geo_db_location" VALUES(60807,NULL,'Berclair, TX',25531,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60808,NULL,'Berclair, TX 78107',25531,222,NULL,51,34984,0);
INSERT INTO "django_geo_db_location" VALUES(60809,NULL,'Cibolo, TX',25532,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60810,NULL,'Cibolo, TX 78108',25532,222,NULL,51,34985,0);
INSERT INTO "django_geo_db_location" VALUES(60811,NULL,'Converse, TX',25533,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60812,NULL,'Converse, TX 78109',25533,222,NULL,51,34986,0);
INSERT INTO "django_geo_db_location" VALUES(60813,NULL,'Ecleto, TX',25534,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60814,NULL,'Ecleto, TX 78111',25534,222,NULL,51,34987,0);
INSERT INTO "django_geo_db_location" VALUES(60815,NULL,'Elmendorf, TX',25535,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60816,NULL,'Elmendorf, TX 78112',25535,222,NULL,51,34988,0);
INSERT INTO "django_geo_db_location" VALUES(60817,NULL,'Falls City, TX',25536,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60818,NULL,'Falls City, TX 78113',25536,222,NULL,51,34989,0);
INSERT INTO "django_geo_db_location" VALUES(60819,NULL,'Floresville, TX',25537,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60820,NULL,'Floresville, TX 78114',25537,222,NULL,51,34990,0);
INSERT INTO "django_geo_db_location" VALUES(60821,NULL,'Geronimo, TX',25538,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60822,NULL,'Geronimo, TX 78115',25538,222,NULL,51,34991,0);
INSERT INTO "django_geo_db_location" VALUES(60823,NULL,'Gillett, TX',25539,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60824,NULL,'Gillett, TX 78116',25539,222,NULL,51,34992,0);
INSERT INTO "django_geo_db_location" VALUES(60825,NULL,'Hobson, TX',25540,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60826,NULL,'Hobson, TX 78117',25540,222,NULL,51,34993,0);
INSERT INTO "django_geo_db_location" VALUES(60827,NULL,'Karnes City, TX',25541,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60828,NULL,'Karnes City, TX 78118',25541,222,NULL,51,34994,0);
INSERT INTO "django_geo_db_location" VALUES(60829,NULL,'Kenedy, TX',25542,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60830,NULL,'Kenedy, TX 78119',25542,222,NULL,51,34995,0);
INSERT INTO "django_geo_db_location" VALUES(60831,NULL,'La Vernia, TX',25543,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60832,NULL,'La Vernia, TX 78121',25543,222,NULL,51,34996,0);
INSERT INTO "django_geo_db_location" VALUES(60833,NULL,'Leesville, TX',25544,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60834,NULL,'Leesville, TX 78122',25544,222,NULL,51,34997,0);
INSERT INTO "django_geo_db_location" VALUES(60835,NULL,'McQueeney, TX',25545,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60836,NULL,'McQueeney, TX 78123',25545,222,NULL,51,34998,0);
INSERT INTO "django_geo_db_location" VALUES(60837,NULL,'Marion, TX',25546,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60838,NULL,'Marion, TX 78124',25546,222,NULL,51,34999,0);
INSERT INTO "django_geo_db_location" VALUES(60839,NULL,'Mineral, TX',25547,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60840,NULL,'Mineral, TX 78125',25547,222,NULL,51,35000,0);
INSERT INTO "django_geo_db_location" VALUES(60841,NULL,'San Antonio, TX',25548,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60842,NULL,'San Antonio, TX 78126',25548,222,NULL,51,35001,0);
INSERT INTO "django_geo_db_location" VALUES(60843,NULL,'New Braunfels, TX',25549,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60844,NULL,'New Braunfels, TX 78130',25549,222,NULL,51,35002,0);
INSERT INTO "django_geo_db_location" VALUES(60845,NULL,'New Braunfels, TX 78131',25549,222,NULL,51,35003,0);
INSERT INTO "django_geo_db_location" VALUES(60846,NULL,'New Braunfels, TX 78132',25549,222,NULL,51,35004,0);
INSERT INTO "django_geo_db_location" VALUES(60847,NULL,'Canyon Lake, TX',25550,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60848,NULL,'Canyon Lake, TX 78133',25550,222,NULL,51,35005,0);
INSERT INTO "django_geo_db_location" VALUES(60849,NULL,'New Braunfels, TX 78134',25549,222,NULL,51,35006,0);
INSERT INTO "django_geo_db_location" VALUES(60850,NULL,'New Braunfels, TX 78135',25549,222,NULL,51,35007,0);
INSERT INTO "django_geo_db_location" VALUES(60851,NULL,'McQueeney, TX 78136',25545,222,NULL,51,35008,0);
INSERT INTO "django_geo_db_location" VALUES(60852,NULL,'Nixon, TX',25551,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60853,NULL,'Nixon, TX 78140',25551,222,NULL,51,35009,0);
INSERT INTO "django_geo_db_location" VALUES(60854,NULL,'Nordheim, TX',25552,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60855,NULL,'Nordheim, TX 78141',25552,222,NULL,51,35010,0);
INSERT INTO "django_geo_db_location" VALUES(60856,NULL,'Normanna, TX',25553,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60857,NULL,'Normanna, TX 78142',25553,222,NULL,51,35011,0);
INSERT INTO "django_geo_db_location" VALUES(60858,NULL,'Pandora, TX',25554,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60859,NULL,'Pandora, TX 78143',25554,222,NULL,51,35012,0);
INSERT INTO "django_geo_db_location" VALUES(60860,NULL,'Panna Maria, TX',25555,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60861,NULL,'Panna Maria, TX 78144',25555,222,NULL,51,35013,0);
INSERT INTO "django_geo_db_location" VALUES(60862,NULL,'Pawnee, TX',25556,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60863,NULL,'Pawnee, TX 78145',25556,222,NULL,51,35014,0);
INSERT INTO "django_geo_db_location" VALUES(60864,NULL,'Pettus, TX',25557,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60865,NULL,'Pettus, TX 78146',25557,222,NULL,51,35015,0);
INSERT INTO "django_geo_db_location" VALUES(60866,NULL,'Poth, TX',25558,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60867,NULL,'Poth, TX 78147',25558,222,NULL,51,35016,0);
INSERT INTO "django_geo_db_location" VALUES(60868,NULL,'Universal City, TX',25559,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60869,NULL,'Universal City, TX 78148',25559,222,NULL,51,35017,0);
INSERT INTO "django_geo_db_location" VALUES(60870,NULL,'Universal City, TX 78150',25559,222,NULL,51,35018,0);
INSERT INTO "django_geo_db_location" VALUES(60871,NULL,'Runge, TX',25560,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60872,NULL,'Runge, TX 78151',25560,222,NULL,51,35019,0);
INSERT INTO "django_geo_db_location" VALUES(60873,NULL,'Saint Hedwig, TX',25561,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60874,NULL,'Saint Hedwig, TX 78152',25561,222,NULL,51,35020,0);
INSERT INTO "django_geo_db_location" VALUES(60875,NULL,'Schertz, TX',25562,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60876,NULL,'Schertz, TX 78154',25562,222,NULL,51,35021,0);
INSERT INTO "django_geo_db_location" VALUES(60877,NULL,'Seguin, TX',25563,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60878,NULL,'Seguin, TX 78155',25563,222,NULL,51,35022,0);
INSERT INTO "django_geo_db_location" VALUES(60879,NULL,'Seguin, TX 78156',25563,222,NULL,51,35023,0);
INSERT INTO "django_geo_db_location" VALUES(60880,NULL,'Smiley, TX',25564,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60881,NULL,'Smiley, TX 78159',25564,222,NULL,51,35024,0);
INSERT INTO "django_geo_db_location" VALUES(60882,NULL,'Stockdale, TX',25565,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60883,NULL,'Stockdale, TX 78160',25565,222,NULL,51,35025,0);
INSERT INTO "django_geo_db_location" VALUES(60884,NULL,'Sutherland Springs, TX',25566,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60885,NULL,'Sutherland Springs, TX 78161',25566,222,NULL,51,35026,0);
INSERT INTO "django_geo_db_location" VALUES(60886,NULL,'Tuleta, TX',25567,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60887,NULL,'Tuleta, TX 78162',25567,222,NULL,51,35027,0);
INSERT INTO "django_geo_db_location" VALUES(60888,NULL,'Bulverde, TX',25568,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60889,NULL,'Bulverde, TX 78163',25568,222,NULL,51,35028,0);
INSERT INTO "django_geo_db_location" VALUES(60890,NULL,'Yorktown, TX',25569,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60891,NULL,'Yorktown, TX 78164',25569,222,NULL,51,35029,0);
INSERT INTO "django_geo_db_location" VALUES(60892,NULL,'San Antonio, TX 78201',25548,222,NULL,51,35030,0);
INSERT INTO "django_geo_db_location" VALUES(60893,NULL,'San Antonio, TX 78202',25548,222,NULL,51,35031,0);
INSERT INTO "django_geo_db_location" VALUES(60894,NULL,'San Antonio, TX 78203',25548,222,NULL,51,35032,0);
INSERT INTO "django_geo_db_location" VALUES(60895,NULL,'San Antonio, TX 78204',25548,222,NULL,51,35033,0);
INSERT INTO "django_geo_db_location" VALUES(60896,NULL,'San Antonio, TX 78205',25548,222,NULL,51,35034,0);
INSERT INTO "django_geo_db_location" VALUES(60897,NULL,'San Antonio, TX 78206',25548,222,NULL,51,35035,0);
INSERT INTO "django_geo_db_location" VALUES(60898,NULL,'San Antonio, TX 78207',25548,222,NULL,51,35036,0);
INSERT INTO "django_geo_db_location" VALUES(60899,NULL,'San Antonio, TX 78208',25548,222,NULL,51,35037,0);
INSERT INTO "django_geo_db_location" VALUES(60900,NULL,'San Antonio, TX 78209',25548,222,NULL,51,35038,0);
INSERT INTO "django_geo_db_location" VALUES(60901,NULL,'San Antonio, TX 78210',25548,222,NULL,51,35039,0);
INSERT INTO "django_geo_db_location" VALUES(60902,NULL,'San Antonio, TX 78211',25548,222,NULL,51,35040,0);
INSERT INTO "django_geo_db_location" VALUES(60903,NULL,'San Antonio, TX 78212',25548,222,NULL,51,35041,0);
INSERT INTO "django_geo_db_location" VALUES(60904,NULL,'San Antonio, TX 78213',25548,222,NULL,51,35042,0);
INSERT INTO "django_geo_db_location" VALUES(60905,NULL,'San Antonio, TX 78214',25548,222,NULL,51,35043,0);
INSERT INTO "django_geo_db_location" VALUES(60906,NULL,'San Antonio, TX 78215',25548,222,NULL,51,35044,0);
INSERT INTO "django_geo_db_location" VALUES(60907,NULL,'San Antonio, TX 78216',25548,222,NULL,51,35045,0);
INSERT INTO "django_geo_db_location" VALUES(60908,NULL,'San Antonio, TX 78217',25548,222,NULL,51,35046,0);
INSERT INTO "django_geo_db_location" VALUES(60909,NULL,'San Antonio, TX 78218',25548,222,NULL,51,35047,0);
INSERT INTO "django_geo_db_location" VALUES(60910,NULL,'San Antonio, TX 78219',25548,222,NULL,51,35048,0);
INSERT INTO "django_geo_db_location" VALUES(60911,NULL,'San Antonio, TX 78220',25548,222,NULL,51,35049,0);
INSERT INTO "django_geo_db_location" VALUES(60912,NULL,'San Antonio, TX 78221',25548,222,NULL,51,35050,0);
INSERT INTO "django_geo_db_location" VALUES(60913,NULL,'San Antonio, TX 78222',25548,222,NULL,51,35051,0);
INSERT INTO "django_geo_db_location" VALUES(60914,NULL,'San Antonio, TX 78223',25548,222,NULL,51,35052,0);
INSERT INTO "django_geo_db_location" VALUES(60915,NULL,'San Antonio, TX 78224',25548,222,NULL,51,35053,0);
INSERT INTO "django_geo_db_location" VALUES(60916,NULL,'San Antonio, TX 78225',25548,222,NULL,51,35054,0);
INSERT INTO "django_geo_db_location" VALUES(60917,NULL,'San Antonio, TX 78226',25548,222,NULL,51,35055,0);
INSERT INTO "django_geo_db_location" VALUES(60918,NULL,'San Antonio, TX 78227',25548,222,NULL,51,35056,0);
INSERT INTO "django_geo_db_location" VALUES(60919,NULL,'San Antonio, TX 78228',25548,222,NULL,51,35057,0);
INSERT INTO "django_geo_db_location" VALUES(60920,NULL,'San Antonio, TX 78229',25548,222,NULL,51,35058,0);
INSERT INTO "django_geo_db_location" VALUES(60921,NULL,'San Antonio, TX 78230',25548,222,NULL,51,35059,0);
INSERT INTO "django_geo_db_location" VALUES(60922,NULL,'San Antonio, TX 78231',25548,222,NULL,51,35060,0);
INSERT INTO "django_geo_db_location" VALUES(60923,NULL,'San Antonio, TX 78232',25548,222,NULL,51,35061,0);
INSERT INTO "django_geo_db_location" VALUES(60924,NULL,'San Antonio, TX 78233',25548,222,NULL,51,35062,0);
INSERT INTO "django_geo_db_location" VALUES(60925,NULL,'San Antonio, TX 78234',25548,222,NULL,51,35063,0);
INSERT INTO "django_geo_db_location" VALUES(60926,NULL,'San Antonio, TX 78235',25548,222,NULL,51,35064,0);
INSERT INTO "django_geo_db_location" VALUES(60927,NULL,'San Antonio, TX 78236',25548,222,NULL,51,35065,0);
INSERT INTO "django_geo_db_location" VALUES(60928,NULL,'San Antonio, TX 78237',25548,222,NULL,51,35066,0);
INSERT INTO "django_geo_db_location" VALUES(60929,NULL,'San Antonio, TX 78238',25548,222,NULL,51,35067,0);
INSERT INTO "django_geo_db_location" VALUES(60930,NULL,'San Antonio, TX 78239',25548,222,NULL,51,35068,0);
INSERT INTO "django_geo_db_location" VALUES(60931,NULL,'San Antonio, TX 78240',25548,222,NULL,51,35069,0);
INSERT INTO "django_geo_db_location" VALUES(60932,NULL,'San Antonio, TX 78241',25548,222,NULL,51,35070,0);
INSERT INTO "django_geo_db_location" VALUES(60933,NULL,'San Antonio, TX 78242',25548,222,NULL,51,35071,0);
INSERT INTO "django_geo_db_location" VALUES(60934,NULL,'San Antonio, TX 78243',25548,222,NULL,51,35072,0);
INSERT INTO "django_geo_db_location" VALUES(60935,NULL,'San Antonio, TX 78244',25548,222,NULL,51,35073,0);
INSERT INTO "django_geo_db_location" VALUES(60936,NULL,'San Antonio, TX 78245',25548,222,NULL,51,35074,0);
INSERT INTO "django_geo_db_location" VALUES(60937,NULL,'San Antonio, TX 78246',25548,222,NULL,51,35075,0);
INSERT INTO "django_geo_db_location" VALUES(60938,NULL,'San Antonio, TX 78247',25548,222,NULL,51,35076,0);
INSERT INTO "django_geo_db_location" VALUES(60939,NULL,'San Antonio, TX 78248',25548,222,NULL,51,35077,0);
INSERT INTO "django_geo_db_location" VALUES(60940,NULL,'San Antonio, TX 78249',25548,222,NULL,51,35078,0);
INSERT INTO "django_geo_db_location" VALUES(60941,NULL,'San Antonio, TX 78250',25548,222,NULL,51,35079,0);
INSERT INTO "django_geo_db_location" VALUES(60942,NULL,'San Antonio, TX 78251',25548,222,NULL,51,35080,0);
INSERT INTO "django_geo_db_location" VALUES(60943,NULL,'San Antonio, TX 78252',25548,222,NULL,51,35081,0);
INSERT INTO "django_geo_db_location" VALUES(60944,NULL,'San Antonio, TX 78253',25548,222,NULL,51,35082,0);
INSERT INTO "django_geo_db_location" VALUES(60945,NULL,'San Antonio, TX 78254',25548,222,NULL,51,35083,0);
INSERT INTO "django_geo_db_location" VALUES(60946,NULL,'San Antonio, TX 78255',25548,222,NULL,51,35084,0);
INSERT INTO "django_geo_db_location" VALUES(60947,NULL,'San Antonio, TX 78256',25548,222,NULL,51,35085,0);
INSERT INTO "django_geo_db_location" VALUES(60948,NULL,'San Antonio, TX 78257',25548,222,NULL,51,35086,0);
INSERT INTO "django_geo_db_location" VALUES(60949,NULL,'San Antonio, TX 78258',25548,222,NULL,51,35087,0);
INSERT INTO "django_geo_db_location" VALUES(60950,NULL,'San Antonio, TX 78259',25548,222,NULL,51,35088,0);
INSERT INTO "django_geo_db_location" VALUES(60951,NULL,'San Antonio, TX 78260',25548,222,NULL,51,35089,0);
INSERT INTO "django_geo_db_location" VALUES(60952,NULL,'San Antonio, TX 78261',25548,222,NULL,51,35090,0);
INSERT INTO "django_geo_db_location" VALUES(60953,NULL,'San Antonio, TX 78262',25548,222,NULL,51,35091,0);
INSERT INTO "django_geo_db_location" VALUES(60954,NULL,'San Antonio, TX 78263',25548,222,NULL,51,35092,0);
INSERT INTO "django_geo_db_location" VALUES(60955,NULL,'San Antonio, TX 78264',25548,222,NULL,51,35093,0);
INSERT INTO "django_geo_db_location" VALUES(60956,NULL,'San Antonio, TX 78265',25548,222,NULL,51,35094,0);
INSERT INTO "django_geo_db_location" VALUES(60957,NULL,'San Antonio, TX 78266',25548,222,NULL,51,35095,0);
INSERT INTO "django_geo_db_location" VALUES(60958,NULL,'San Antonio, TX 78268',25548,222,NULL,51,35096,0);
INSERT INTO "django_geo_db_location" VALUES(60959,NULL,'San Antonio, TX 78269',25548,222,NULL,51,35097,0);
INSERT INTO "django_geo_db_location" VALUES(60960,NULL,'San Antonio, TX 78270',25548,222,NULL,51,35098,0);
INSERT INTO "django_geo_db_location" VALUES(60961,NULL,'San Antonio, TX 78275',25548,222,NULL,51,35099,0);
INSERT INTO "django_geo_db_location" VALUES(60962,NULL,'San Antonio, TX 78278',25548,222,NULL,51,35100,0);
INSERT INTO "django_geo_db_location" VALUES(60963,NULL,'San Antonio, TX 78279',25548,222,NULL,51,35101,0);
INSERT INTO "django_geo_db_location" VALUES(60964,NULL,'San Antonio, TX 78280',25548,222,NULL,51,35102,0);
INSERT INTO "django_geo_db_location" VALUES(60965,NULL,'San Antonio, TX 78283',25548,222,NULL,51,35103,0);
INSERT INTO "django_geo_db_location" VALUES(60966,NULL,'San Antonio, TX 78284',25548,222,NULL,51,35104,0);
INSERT INTO "django_geo_db_location" VALUES(60967,NULL,'San Antonio, TX 78285',25548,222,NULL,51,35105,0);
INSERT INTO "django_geo_db_location" VALUES(60968,NULL,'San Antonio, TX 78286',25548,222,NULL,51,35106,0);
INSERT INTO "django_geo_db_location" VALUES(60969,NULL,'San Antonio, TX 78287',25548,222,NULL,51,35107,0);
INSERT INTO "django_geo_db_location" VALUES(60970,NULL,'San Antonio, TX 78288',25548,222,NULL,51,35108,0);
INSERT INTO "django_geo_db_location" VALUES(60971,NULL,'San Antonio, TX 78289',25548,222,NULL,51,35109,0);
INSERT INTO "django_geo_db_location" VALUES(60972,NULL,'San Antonio, TX 78291',25548,222,NULL,51,35110,0);
INSERT INTO "django_geo_db_location" VALUES(60973,NULL,'San Antonio, TX 78292',25548,222,NULL,51,35111,0);
INSERT INTO "django_geo_db_location" VALUES(60974,NULL,'San Antonio, TX 78293',25548,222,NULL,51,35112,0);
INSERT INTO "django_geo_db_location" VALUES(60975,NULL,'San Antonio, TX 78294',25548,222,NULL,51,35113,0);
INSERT INTO "django_geo_db_location" VALUES(60976,NULL,'San Antonio, TX 78295',25548,222,NULL,51,35114,0);
INSERT INTO "django_geo_db_location" VALUES(60977,NULL,'San Antonio, TX 78296',25548,222,NULL,51,35115,0);
INSERT INTO "django_geo_db_location" VALUES(60978,NULL,'San Antonio, TX 78297',25548,222,NULL,51,35116,0);
INSERT INTO "django_geo_db_location" VALUES(60979,NULL,'San Antonio, TX 78298',25548,222,NULL,51,35117,0);
INSERT INTO "django_geo_db_location" VALUES(60980,NULL,'San Antonio, TX 78299',25548,222,NULL,51,35118,0);
INSERT INTO "django_geo_db_location" VALUES(60981,NULL,'McAllen, TX',25570,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60982,NULL,'McAllen, TX 78301',25570,222,NULL,51,35119,0);
INSERT INTO "django_geo_db_location" VALUES(60983,NULL,'Agua Dulce, TX',25571,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60984,NULL,'Agua Dulce, TX 78330',25571,222,NULL,51,35120,0);
INSERT INTO "django_geo_db_location" VALUES(60985,NULL,'Alice, TX',25572,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60986,NULL,'Alice, TX 78331',25572,222,NULL,51,35121,0);
INSERT INTO "django_geo_db_location" VALUES(60987,NULL,'Alice, TX 78332',25572,222,NULL,51,35122,0);
INSERT INTO "django_geo_db_location" VALUES(60988,NULL,'Alice, TX 78333',25572,222,NULL,51,35123,0);
INSERT INTO "django_geo_db_location" VALUES(60989,NULL,'Aransas Pass, TX',25573,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60990,NULL,'Aransas Pass, TX 78335',25573,222,NULL,51,35124,0);
INSERT INTO "django_geo_db_location" VALUES(60991,NULL,'Aransas Pass, TX 78336',25573,222,NULL,51,35125,0);
INSERT INTO "django_geo_db_location" VALUES(60992,NULL,'Rancho Alegre, TX',25574,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60993,NULL,'Rancho Alegre, TX 78337',25574,222,NULL,51,35126,0);
INSERT INTO "django_geo_db_location" VALUES(60994,NULL,'Armstrong, TX',25575,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60995,NULL,'Armstrong, TX 78338',25575,222,NULL,51,35127,0);
INSERT INTO "django_geo_db_location" VALUES(60996,NULL,'Banquete, TX',25576,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60997,NULL,'Banquete, TX 78339',25576,222,NULL,51,35128,0);
INSERT INTO "django_geo_db_location" VALUES(60998,NULL,'Bayside, TX',25577,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(60999,NULL,'Bayside, TX 78340',25577,222,NULL,51,35129,0);
INSERT INTO "django_geo_db_location" VALUES(61000,NULL,'Benavides, TX',25578,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61001,NULL,'Benavides, TX 78341',25578,222,NULL,51,35130,0);
INSERT INTO "django_geo_db_location" VALUES(61002,NULL,'Ben Bolt, TX',25579,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61003,NULL,'Ben Bolt, TX 78342',25579,222,NULL,51,35131,0);
INSERT INTO "django_geo_db_location" VALUES(61004,NULL,'Bishop, TX',25580,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61005,NULL,'Bishop, TX 78343',25580,222,NULL,51,35132,0);
INSERT INTO "django_geo_db_location" VALUES(61006,NULL,'Bruni, TX',25581,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61007,NULL,'Bruni, TX 78344',25581,222,NULL,51,35133,0);
INSERT INTO "django_geo_db_location" VALUES(61008,NULL,'Chapman Ranch, TX',25582,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61009,NULL,'Chapman Ranch, TX 78347',25582,222,NULL,51,35134,0);
INSERT INTO "django_geo_db_location" VALUES(61010,NULL,'Concepcion, TX',25583,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61011,NULL,'Concepcion, TX 78349',25583,222,NULL,51,35135,0);
INSERT INTO "django_geo_db_location" VALUES(61012,NULL,'Dinero, TX',25584,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61013,NULL,'Dinero, TX 78350',25584,222,NULL,51,35136,0);
INSERT INTO "django_geo_db_location" VALUES(61014,NULL,'Driscoll, TX',25585,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61015,NULL,'Driscoll, TX 78351',25585,222,NULL,51,35137,0);
INSERT INTO "django_geo_db_location" VALUES(61016,NULL,'Edroy, TX',25586,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61017,NULL,'Edroy, TX 78352',25586,222,NULL,51,35138,0);
INSERT INTO "django_geo_db_location" VALUES(61018,NULL,'Encino, TX',25587,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61019,NULL,'Encino, TX 78353',25587,222,NULL,51,35139,0);
INSERT INTO "django_geo_db_location" VALUES(61020,NULL,'Falfurrias, TX',25588,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61021,NULL,'Falfurrias, TX 78355',25588,222,NULL,51,35140,0);
INSERT INTO "django_geo_db_location" VALUES(61022,NULL,'Freer, TX',25589,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61023,NULL,'Freer, TX 78357',25589,222,NULL,51,35141,0);
INSERT INTO "django_geo_db_location" VALUES(61024,NULL,'Fulton, TX',25590,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61025,NULL,'Fulton, TX 78358',25590,222,NULL,51,35142,0);
INSERT INTO "django_geo_db_location" VALUES(61026,NULL,'Gregory, TX',25591,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61027,NULL,'Gregory, TX 78359',25591,222,NULL,51,35143,0);
INSERT INTO "django_geo_db_location" VALUES(61028,NULL,'Guerra, TX',25592,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61029,NULL,'Guerra, TX 78360',25592,222,NULL,51,35144,0);
INSERT INTO "django_geo_db_location" VALUES(61030,NULL,'Hebbronville, TX',25593,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61031,NULL,'Hebbronville, TX 78361',25593,222,NULL,51,35145,0);
INSERT INTO "django_geo_db_location" VALUES(61032,NULL,'Ingleside, TX',25594,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61033,NULL,'Ingleside, TX 78362',25594,222,NULL,51,35146,0);
INSERT INTO "django_geo_db_location" VALUES(61034,NULL,'Kingsville, TX',25595,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61035,NULL,'Kingsville, TX 78363',25595,222,NULL,51,35147,0);
INSERT INTO "django_geo_db_location" VALUES(61036,NULL,'Kingsville, TX 78364',25595,222,NULL,51,35148,0);
INSERT INTO "django_geo_db_location" VALUES(61037,NULL,'Mathis, TX',25596,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61038,NULL,'Mathis, TX 78368',25596,222,NULL,51,35149,0);
INSERT INTO "django_geo_db_location" VALUES(61039,NULL,'Mirando City, TX',25597,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61040,NULL,'Mirando City, TX 78369',25597,222,NULL,51,35150,0);
INSERT INTO "django_geo_db_location" VALUES(61041,NULL,'Odem, TX',25598,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61042,NULL,'Odem, TX 78370',25598,222,NULL,51,35151,0);
INSERT INTO "django_geo_db_location" VALUES(61043,NULL,'Oilton, TX',25599,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61044,NULL,'Oilton, TX 78371',25599,222,NULL,51,35152,0);
INSERT INTO "django_geo_db_location" VALUES(61045,NULL,'Orange Grove, TX',25600,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61046,NULL,'Orange Grove, TX 78372',25600,222,NULL,51,35153,0);
INSERT INTO "django_geo_db_location" VALUES(61047,NULL,'Port Aransas, TX',25601,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61048,NULL,'Port Aransas, TX 78373',25601,222,NULL,51,35154,0);
INSERT INTO "django_geo_db_location" VALUES(61049,NULL,'Portland, TX',25602,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61050,NULL,'Portland, TX 78374',25602,222,NULL,51,35155,0);
INSERT INTO "django_geo_db_location" VALUES(61051,NULL,'Premont, TX',25603,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61052,NULL,'Premont, TX 78375',25603,222,NULL,51,35156,0);
INSERT INTO "django_geo_db_location" VALUES(61053,NULL,'Realitos, TX',25604,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61054,NULL,'Realitos, TX 78376',25604,222,NULL,51,35157,0);
INSERT INTO "django_geo_db_location" VALUES(61055,NULL,'Refugio, TX',25605,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61056,NULL,'Refugio, TX 78377',25605,222,NULL,51,35158,0);
INSERT INTO "django_geo_db_location" VALUES(61057,NULL,'Riviera, TX',25606,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61058,NULL,'Riviera, TX 78379',25606,222,NULL,51,35159,0);
INSERT INTO "django_geo_db_location" VALUES(61059,NULL,'Robstown, TX',25607,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61060,NULL,'Robstown, TX 78380',25607,222,NULL,51,35160,0);
INSERT INTO "django_geo_db_location" VALUES(61061,NULL,'Rockport, TX',25608,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61062,NULL,'Rockport, TX 78381',25608,222,NULL,51,35161,0);
INSERT INTO "django_geo_db_location" VALUES(61063,NULL,'Rockport, TX 78382',25608,222,NULL,51,35162,0);
INSERT INTO "django_geo_db_location" VALUES(61064,NULL,'Sandia, TX',25609,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61065,NULL,'Sandia, TX 78383',25609,222,NULL,51,35163,0);
INSERT INTO "django_geo_db_location" VALUES(61066,NULL,'San Diego, TX',25610,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61067,NULL,'San Diego, TX 78384',25610,222,NULL,51,35164,0);
INSERT INTO "django_geo_db_location" VALUES(61068,NULL,'Sarita, TX',25611,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61069,NULL,'Sarita, TX 78385',25611,222,NULL,51,35165,0);
INSERT INTO "django_geo_db_location" VALUES(61070,NULL,'Sinton, TX',25612,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61071,NULL,'Sinton, TX 78387',25612,222,NULL,51,35166,0);
INSERT INTO "django_geo_db_location" VALUES(61072,NULL,'Skidmore, TX',25613,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61073,NULL,'Skidmore, TX 78389',25613,222,NULL,51,35167,0);
INSERT INTO "django_geo_db_location" VALUES(61074,NULL,'Taft, TX',25614,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61075,NULL,'Taft, TX 78390',25614,222,NULL,51,35168,0);
INSERT INTO "django_geo_db_location" VALUES(61076,NULL,'Tynan, TX',25615,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61077,NULL,'Tynan, TX 78391',25615,222,NULL,51,35169,0);
INSERT INTO "django_geo_db_location" VALUES(61078,NULL,'Woodsboro, TX',25616,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61079,NULL,'Woodsboro, TX 78393',25616,222,NULL,51,35170,0);
INSERT INTO "django_geo_db_location" VALUES(61080,NULL,'Corpus Christi, TX',25617,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61081,NULL,'Corpus Christi, TX 78401',25617,222,NULL,51,35171,0);
INSERT INTO "django_geo_db_location" VALUES(61082,NULL,'Corpus Christi, TX 78402',25617,222,NULL,51,35172,0);
INSERT INTO "django_geo_db_location" VALUES(61083,NULL,'Corpus Christi, TX 78403',25617,222,NULL,51,35173,0);
INSERT INTO "django_geo_db_location" VALUES(61084,NULL,'Corpus Christi, TX 78404',25617,222,NULL,51,35174,0);
INSERT INTO "django_geo_db_location" VALUES(61085,NULL,'Corpus Christi, TX 78405',25617,222,NULL,51,35175,0);
INSERT INTO "django_geo_db_location" VALUES(61086,NULL,'Corpus Christi, TX 78406',25617,222,NULL,51,35176,0);
INSERT INTO "django_geo_db_location" VALUES(61087,NULL,'Corpus Christi, TX 78407',25617,222,NULL,51,35177,0);
INSERT INTO "django_geo_db_location" VALUES(61088,NULL,'Corpus Christi, TX 78408',25617,222,NULL,51,35178,0);
INSERT INTO "django_geo_db_location" VALUES(61089,NULL,'Corpus Christi, TX 78409',25617,222,NULL,51,35179,0);
INSERT INTO "django_geo_db_location" VALUES(61090,NULL,'Corpus Christi, TX 78410',25617,222,NULL,51,35180,0);
INSERT INTO "django_geo_db_location" VALUES(61091,NULL,'Corpus Christi, TX 78411',25617,222,NULL,51,35181,0);
INSERT INTO "django_geo_db_location" VALUES(61092,NULL,'Corpus Christi, TX 78412',25617,222,NULL,51,35182,0);
INSERT INTO "django_geo_db_location" VALUES(61093,NULL,'Corpus Christi, TX 78413',25617,222,NULL,51,35183,0);
INSERT INTO "django_geo_db_location" VALUES(61094,NULL,'Corpus Christi, TX 78414',25617,222,NULL,51,35184,0);
INSERT INTO "django_geo_db_location" VALUES(61095,NULL,'Corpus Christi, TX 78415',25617,222,NULL,51,35185,0);
INSERT INTO "django_geo_db_location" VALUES(61096,NULL,'Corpus Christi, TX 78416',25617,222,NULL,51,35186,0);
INSERT INTO "django_geo_db_location" VALUES(61097,NULL,'Corpus Christi, TX 78417',25617,222,NULL,51,35187,0);
INSERT INTO "django_geo_db_location" VALUES(61098,NULL,'Corpus Christi, TX 78418',25617,222,NULL,51,35188,0);
INSERT INTO "django_geo_db_location" VALUES(61099,NULL,'Corpus Christi, TX 78419',25617,222,NULL,51,35189,0);
INSERT INTO "django_geo_db_location" VALUES(61100,NULL,'Corpus Christi, TX 78426',25617,222,NULL,51,35190,0);
INSERT INTO "django_geo_db_location" VALUES(61101,NULL,'Corpus Christi, TX 78427',25617,222,NULL,51,35191,0);
INSERT INTO "django_geo_db_location" VALUES(61102,NULL,'Corpus Christi, TX 78460',25617,222,NULL,51,35192,0);
INSERT INTO "django_geo_db_location" VALUES(61103,NULL,'Corpus Christi, TX 78461',25617,222,NULL,51,35193,0);
INSERT INTO "django_geo_db_location" VALUES(61104,NULL,'Corpus Christi, TX 78463',25617,222,NULL,51,35194,0);
INSERT INTO "django_geo_db_location" VALUES(61105,NULL,'Corpus Christi, TX 78465',25617,222,NULL,51,35195,0);
INSERT INTO "django_geo_db_location" VALUES(61106,NULL,'Corpus Christi, TX 78466',25617,222,NULL,51,35196,0);
INSERT INTO "django_geo_db_location" VALUES(61107,NULL,'Corpus Christi, TX 78467',25617,222,NULL,51,35197,0);
INSERT INTO "django_geo_db_location" VALUES(61108,NULL,'Corpus Christi, TX 78468',25617,222,NULL,51,35198,0);
INSERT INTO "django_geo_db_location" VALUES(61109,NULL,'Corpus Christi, TX 78469',25617,222,NULL,51,35199,0);
INSERT INTO "django_geo_db_location" VALUES(61110,NULL,'Corpus Christi, TX 78470',25617,222,NULL,51,35200,0);
INSERT INTO "django_geo_db_location" VALUES(61111,NULL,'Corpus Christi, TX 78471',25617,222,NULL,51,35201,0);
INSERT INTO "django_geo_db_location" VALUES(61112,NULL,'Corpus Christi, TX 78472',25617,222,NULL,51,35202,0);
INSERT INTO "django_geo_db_location" VALUES(61113,NULL,'Corpus Christi, TX 78473',25617,222,NULL,51,35203,0);
INSERT INTO "django_geo_db_location" VALUES(61114,NULL,'Corpus Christi, TX 78474',25617,222,NULL,51,35204,0);
INSERT INTO "django_geo_db_location" VALUES(61115,NULL,'Corpus Christi, TX 78475',25617,222,NULL,51,35205,0);
INSERT INTO "django_geo_db_location" VALUES(61116,NULL,'Corpus Christi, TX 78476',25617,222,NULL,51,35206,0);
INSERT INTO "django_geo_db_location" VALUES(61117,NULL,'Corpus Christi, TX 78477',25617,222,NULL,51,35207,0);
INSERT INTO "django_geo_db_location" VALUES(61118,NULL,'Corpus Christi, TX 78478',25617,222,NULL,51,35208,0);
INSERT INTO "django_geo_db_location" VALUES(61119,NULL,'Corpus Christi, TX 78480',25617,222,NULL,51,35209,0);
INSERT INTO "django_geo_db_location" VALUES(61120,NULL,'Mcallen, TX',25618,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61121,NULL,'Mcallen, TX 78501',25618,222,NULL,51,35210,0);
INSERT INTO "django_geo_db_location" VALUES(61122,NULL,'Mcallen, TX 78502',25618,222,NULL,51,35211,0);
INSERT INTO "django_geo_db_location" VALUES(61123,NULL,'Mcallen, TX 78503',25618,222,NULL,51,35212,0);
INSERT INTO "django_geo_db_location" VALUES(61124,NULL,'Mcallen, TX 78504',25618,222,NULL,51,35213,0);
INSERT INTO "django_geo_db_location" VALUES(61125,NULL,'Mcallen, TX 78505',25618,222,NULL,51,35214,0);
INSERT INTO "django_geo_db_location" VALUES(61126,NULL,'Mission, TX',25619,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61127,NULL,'Mission, TX 78512',25619,222,NULL,51,35215,0);
INSERT INTO "django_geo_db_location" VALUES(61128,NULL,'Alamo, TX',25620,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61129,NULL,'Alamo, TX 78516',25620,222,NULL,51,35216,0);
INSERT INTO "django_geo_db_location" VALUES(61130,NULL,'Brownsville, TX',25621,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61131,NULL,'Brownsville, TX 78520',25621,222,NULL,51,35217,0);
INSERT INTO "django_geo_db_location" VALUES(61132,NULL,'Brownsville, TX 78521',25621,222,NULL,51,35218,0);
INSERT INTO "django_geo_db_location" VALUES(61133,NULL,'Brownsville, TX 78522',25621,222,NULL,51,35219,0);
INSERT INTO "django_geo_db_location" VALUES(61134,NULL,'Brownsville, TX 78523',25621,222,NULL,51,35220,0);
INSERT INTO "django_geo_db_location" VALUES(61135,NULL,'Brownsville, TX 78526',25621,222,NULL,51,35221,0);
INSERT INTO "django_geo_db_location" VALUES(61136,NULL,'Combes, TX',25622,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61137,NULL,'Combes, TX 78535',25622,222,NULL,51,35222,0);
INSERT INTO "django_geo_db_location" VALUES(61138,NULL,'Delmita, TX',25623,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61139,NULL,'Delmita, TX 78536',25623,222,NULL,51,35223,0);
INSERT INTO "django_geo_db_location" VALUES(61140,NULL,'Donna, TX',25624,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61141,NULL,'Donna, TX 78537',25624,222,NULL,51,35224,0);
INSERT INTO "django_geo_db_location" VALUES(61142,NULL,'Edcouch, TX',25625,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61143,NULL,'Edcouch, TX 78538',25625,222,NULL,51,35225,0);
INSERT INTO "django_geo_db_location" VALUES(61144,NULL,'Edinburg, TX',25626,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61145,NULL,'Edinburg, TX 78539',25626,222,NULL,51,35226,0);
INSERT INTO "django_geo_db_location" VALUES(61146,NULL,'Edinburg, TX 78540',25626,222,NULL,51,35227,0);
INSERT INTO "django_geo_db_location" VALUES(61147,NULL,'Edinburg, TX 78541',25626,222,NULL,51,35228,0);
INSERT INTO "django_geo_db_location" VALUES(61148,NULL,'Elsa, TX',25627,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61149,NULL,'Elsa, TX 78543',25627,222,NULL,51,35229,0);
INSERT INTO "django_geo_db_location" VALUES(61150,NULL,'Falcon Heights, TX',25628,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61151,NULL,'Falcon Heights, TX 78545',25628,222,NULL,51,35230,0);
INSERT INTO "django_geo_db_location" VALUES(61152,NULL,'Garciasville, TX',25629,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61153,NULL,'Garciasville, TX 78547',25629,222,NULL,51,35231,0);
INSERT INTO "django_geo_db_location" VALUES(61154,NULL,'Grulla, TX',25630,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61155,NULL,'Grulla, TX 78548',25630,222,NULL,51,35232,0);
INSERT INTO "django_geo_db_location" VALUES(61156,NULL,'Hargill, TX',25631,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61157,NULL,'Hargill, TX 78549',25631,222,NULL,51,35233,0);
INSERT INTO "django_geo_db_location" VALUES(61158,NULL,'Harlingen, TX',25632,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61159,NULL,'Harlingen, TX 78550',25632,222,NULL,51,35234,0);
INSERT INTO "django_geo_db_location" VALUES(61160,NULL,'Harlingen, TX 78551',25632,222,NULL,51,35235,0);
INSERT INTO "django_geo_db_location" VALUES(61161,NULL,'Harlingen, TX 78552',25632,222,NULL,51,35236,0);
INSERT INTO "django_geo_db_location" VALUES(61162,NULL,'Harlingen, TX 78553',25632,222,NULL,51,35237,0);
INSERT INTO "django_geo_db_location" VALUES(61163,NULL,'McAllen, TX 78555',25570,222,NULL,51,35238,0);
INSERT INTO "django_geo_db_location" VALUES(61164,NULL,'Hidalgo, TX',25633,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61165,NULL,'Hidalgo, TX 78557',25633,222,NULL,51,35239,0);
INSERT INTO "django_geo_db_location" VALUES(61166,NULL,'La Blanca, TX',25634,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61167,NULL,'La Blanca, TX 78558',25634,222,NULL,51,35240,0);
INSERT INTO "django_geo_db_location" VALUES(61168,NULL,'La Feria, TX',25635,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61169,NULL,'La Feria, TX 78559',25635,222,NULL,51,35241,0);
INSERT INTO "django_geo_db_location" VALUES(61170,NULL,'La Joya, TX',25636,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61171,NULL,'La Joya, TX 78560',25636,222,NULL,51,35242,0);
INSERT INTO "django_geo_db_location" VALUES(61172,NULL,'Lasara, TX',25637,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61173,NULL,'Lasara, TX 78561',25637,222,NULL,51,35243,0);
INSERT INTO "django_geo_db_location" VALUES(61174,NULL,'La Villa, TX',25638,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61175,NULL,'La Villa, TX 78562',25638,222,NULL,51,35244,0);
INSERT INTO "django_geo_db_location" VALUES(61176,NULL,'Linn, TX',25639,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61177,NULL,'Linn, TX 78563',25639,222,NULL,51,35245,0);
INSERT INTO "django_geo_db_location" VALUES(61178,NULL,'Lopeno, TX',25640,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61179,NULL,'Lopeno, TX 78564',25640,222,NULL,51,35246,0);
INSERT INTO "django_geo_db_location" VALUES(61180,NULL,'Los Ebanos, TX',25641,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61181,NULL,'Los Ebanos, TX 78565',25641,222,NULL,51,35247,0);
INSERT INTO "django_geo_db_location" VALUES(61182,NULL,'Los Fresnos, TX',25642,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61183,NULL,'Los Fresnos, TX 78566',25642,222,NULL,51,35248,0);
INSERT INTO "django_geo_db_location" VALUES(61184,NULL,'Los Indios, TX',25643,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61185,NULL,'Los Indios, TX 78567',25643,222,NULL,51,35249,0);
INSERT INTO "django_geo_db_location" VALUES(61186,NULL,'Lozano, TX',25644,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61187,NULL,'Lozano, TX 78568',25644,222,NULL,51,35250,0);
INSERT INTO "django_geo_db_location" VALUES(61188,NULL,'Lyford, TX',25645,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61189,NULL,'Lyford, TX 78569',25645,222,NULL,51,35251,0);
INSERT INTO "django_geo_db_location" VALUES(61190,NULL,'Mercedes, TX',25646,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61191,NULL,'Mercedes, TX 78570',25646,222,NULL,51,35252,0);
INSERT INTO "django_geo_db_location" VALUES(61192,NULL,'Salado, TX 78571',25082,222,NULL,51,35253,0);
INSERT INTO "django_geo_db_location" VALUES(61193,NULL,'Mission, TX 78572',25619,222,NULL,51,35254,0);
INSERT INTO "django_geo_db_location" VALUES(61194,NULL,'Mission, TX 78573',25619,222,NULL,51,35255,0);
INSERT INTO "django_geo_db_location" VALUES(61195,NULL,'Sebastian, TX',25647,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61196,NULL,'Sebastian, TX 78574',25647,222,NULL,51,35256,0);
INSERT INTO "django_geo_db_location" VALUES(61197,NULL,'Olmito, TX',25648,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61198,NULL,'Olmito, TX 78575',25648,222,NULL,51,35257,0);
INSERT INTO "django_geo_db_location" VALUES(61199,NULL,'Penitas, TX',25649,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61200,NULL,'Penitas, TX 78576',25649,222,NULL,51,35258,0);
INSERT INTO "django_geo_db_location" VALUES(61201,NULL,'Pharr, TX',25650,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61202,NULL,'Pharr, TX 78577',25650,222,NULL,51,35259,0);
INSERT INTO "django_geo_db_location" VALUES(61203,NULL,'Port Isabel, TX',25651,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61204,NULL,'Port Isabel, TX 78578',25651,222,NULL,51,35260,0);
INSERT INTO "django_geo_db_location" VALUES(61205,NULL,'Progreso, TX',25652,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61206,NULL,'Progreso, TX 78579',25652,222,NULL,51,35261,0);
INSERT INTO "django_geo_db_location" VALUES(61207,NULL,'Raymondville, TX',25653,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61208,NULL,'Raymondville, TX 78580',25653,222,NULL,51,35262,0);
INSERT INTO "django_geo_db_location" VALUES(61209,NULL,'Rio Grande City, TX',25654,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61210,NULL,'Rio Grande City, TX 78582',25654,222,NULL,51,35263,0);
INSERT INTO "django_geo_db_location" VALUES(61211,NULL,'Rio Hondo, TX',25655,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61212,NULL,'Rio Hondo, TX 78583',25655,222,NULL,51,35264,0);
INSERT INTO "django_geo_db_location" VALUES(61213,NULL,'Roma, TX',25656,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61214,NULL,'Roma, TX 78584',25656,222,NULL,51,35265,0);
INSERT INTO "django_geo_db_location" VALUES(61215,NULL,'Salineno, TX',25657,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61216,NULL,'Salineno, TX 78585',25657,222,NULL,51,35266,0);
INSERT INTO "django_geo_db_location" VALUES(61217,NULL,'San Benito, TX',25658,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61218,NULL,'San Benito, TX 78586',25658,222,NULL,51,35267,0);
INSERT INTO "django_geo_db_location" VALUES(61219,NULL,'La Victoria, TX',25659,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61220,NULL,'La Victoria, TX 78587',25659,222,NULL,51,35268,0);
INSERT INTO "django_geo_db_location" VALUES(61221,NULL,'San Isidro, TX',25660,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61222,NULL,'San Isidro, TX 78588',25660,222,NULL,51,35269,0);
INSERT INTO "django_geo_db_location" VALUES(61223,NULL,'San Juan, TX',25661,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61224,NULL,'San Juan, TX 78589',25661,222,NULL,51,35270,0);
INSERT INTO "django_geo_db_location" VALUES(61225,NULL,'San Perlita, TX',25662,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61226,NULL,'San Perlita, TX 78590',25662,222,NULL,51,35271,0);
INSERT INTO "django_geo_db_location" VALUES(61227,NULL,'Santa Elena, TX',25663,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61228,NULL,'Santa Elena, TX 78591',25663,222,NULL,51,35272,0);
INSERT INTO "django_geo_db_location" VALUES(61229,NULL,'Santa Maria, TX',25664,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61230,NULL,'Santa Maria, TX 78592',25664,222,NULL,51,35273,0);
INSERT INTO "django_geo_db_location" VALUES(61231,NULL,'Santa Rosa, TX',25665,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61232,NULL,'Santa Rosa, TX 78593',25665,222,NULL,51,35274,0);
INSERT INTO "django_geo_db_location" VALUES(61233,NULL,'Sebastian, TX 78594',25647,222,NULL,51,35275,0);
INSERT INTO "django_geo_db_location" VALUES(61234,NULL,'Sullivan City, TX',25666,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61235,NULL,'Sullivan City, TX 78595',25666,222,NULL,51,35276,0);
INSERT INTO "django_geo_db_location" VALUES(61236,NULL,'Weslaco, TX',25667,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61237,NULL,'Weslaco, TX 78596',25667,222,NULL,51,35277,0);
INSERT INTO "django_geo_db_location" VALUES(61238,NULL,'South Padre Island, TX',25668,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61239,NULL,'South Padre Island, TX 78597',25668,222,NULL,51,35278,0);
INSERT INTO "django_geo_db_location" VALUES(61240,NULL,'Port Mansfield, TX',25669,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61241,NULL,'Port Mansfield, TX 78598',25669,222,NULL,51,35279,0);
INSERT INTO "django_geo_db_location" VALUES(61242,NULL,'Weslaco, TX 78599',25667,222,NULL,51,35280,0);
INSERT INTO "django_geo_db_location" VALUES(61243,NULL,'Bastrop, TX',25670,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61244,NULL,'Bastrop, TX 78602',25670,222,NULL,51,35281,0);
INSERT INTO "django_geo_db_location" VALUES(61245,NULL,'Bebe, TX',25671,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61246,NULL,'Bebe, TX 78603',25671,222,NULL,51,35282,0);
INSERT INTO "django_geo_db_location" VALUES(61247,NULL,'Belmont, TX',25672,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61248,NULL,'Belmont, TX 78604',25672,222,NULL,51,35283,0);
INSERT INTO "django_geo_db_location" VALUES(61249,NULL,'Bertram, TX',25673,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61250,NULL,'Bertram, TX 78605',25673,222,NULL,51,35284,0);
INSERT INTO "django_geo_db_location" VALUES(61251,NULL,'Blanco, TX',25674,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61252,NULL,'Blanco, TX 78606',25674,222,NULL,51,35285,0);
INSERT INTO "django_geo_db_location" VALUES(61253,NULL,'Bluffton, TX',25675,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61254,NULL,'Bluffton, TX 78607',25675,222,NULL,51,35286,0);
INSERT INTO "django_geo_db_location" VALUES(61255,NULL,'Briggs, TX',25676,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61256,NULL,'Briggs, TX 78608',25676,222,NULL,51,35287,0);
INSERT INTO "django_geo_db_location" VALUES(61257,NULL,'Buchanan Dam, TX',25677,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61258,NULL,'Buchanan Dam, TX 78609',25677,222,NULL,51,35288,0);
INSERT INTO "django_geo_db_location" VALUES(61259,NULL,'Buda, TX',25678,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61260,NULL,'Buda, TX 78610',25678,222,NULL,51,35289,0);
INSERT INTO "django_geo_db_location" VALUES(61261,NULL,'Burnet, TX',25679,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61262,NULL,'Burnet, TX 78611',25679,222,NULL,51,35290,0);
INSERT INTO "django_geo_db_location" VALUES(61263,NULL,'Cedar Creek, TX',25680,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61264,NULL,'Cedar Creek, TX 78612',25680,222,NULL,51,35291,0);
INSERT INTO "django_geo_db_location" VALUES(61265,NULL,'Cedar Park, TX',25681,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61266,NULL,'Cedar Park, TX 78613',25681,222,NULL,51,35292,0);
INSERT INTO "django_geo_db_location" VALUES(61267,NULL,'Cost, TX',25682,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61268,NULL,'Cost, TX 78614',25682,222,NULL,51,35293,0);
INSERT INTO "django_geo_db_location" VALUES(61269,NULL,'Coupland, TX',25683,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61270,NULL,'Coupland, TX 78615',25683,222,NULL,51,35294,0);
INSERT INTO "django_geo_db_location" VALUES(61271,NULL,'Dale, TX',25684,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61272,NULL,'Dale, TX 78616',25684,222,NULL,51,35295,0);
INSERT INTO "django_geo_db_location" VALUES(61273,NULL,'Del Valle, TX',25685,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61274,NULL,'Del Valle, TX 78617',25685,222,NULL,51,35296,0);
INSERT INTO "django_geo_db_location" VALUES(61275,NULL,'Doss, TX',25686,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61276,NULL,'Doss, TX 78618',25686,222,NULL,51,35297,0);
INSERT INTO "django_geo_db_location" VALUES(61277,NULL,'Driftwood, TX',25687,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61278,NULL,'Driftwood, TX 78619',25687,222,NULL,51,35298,0);
INSERT INTO "django_geo_db_location" VALUES(61279,NULL,'Dripping Springs, TX',25688,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61280,NULL,'Dripping Springs, TX 78620',25688,222,NULL,51,35299,0);
INSERT INTO "django_geo_db_location" VALUES(61281,NULL,'Elgin, TX',25689,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61282,NULL,'Elgin, TX 78621',25689,222,NULL,51,35300,0);
INSERT INTO "django_geo_db_location" VALUES(61283,NULL,'Fentress, TX',25690,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61284,NULL,'Fentress, TX 78622',25690,222,NULL,51,35301,0);
INSERT INTO "django_geo_db_location" VALUES(61285,NULL,'Fischer, TX',25691,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61286,NULL,'Fischer, TX 78623',25691,222,NULL,51,35302,0);
INSERT INTO "django_geo_db_location" VALUES(61287,NULL,'Fredericksburg, TX',25692,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61288,NULL,'Fredericksburg, TX 78624',25692,222,NULL,51,35303,0);
INSERT INTO "django_geo_db_location" VALUES(61289,NULL,'Georgetown, TX',25693,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61290,NULL,'Georgetown, TX 78626',25693,222,NULL,51,35304,0);
INSERT INTO "django_geo_db_location" VALUES(61291,NULL,'Georgetown, TX 78627',25693,222,NULL,51,35305,0);
INSERT INTO "django_geo_db_location" VALUES(61292,NULL,'Georgetown, TX 78628',25693,222,NULL,51,35306,0);
INSERT INTO "django_geo_db_location" VALUES(61293,NULL,'Gonzales, TX',25694,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61294,NULL,'Gonzales, TX 78629',25694,222,NULL,51,35307,0);
INSERT INTO "django_geo_db_location" VALUES(61295,NULL,'Cedar Park, TX 78630',25681,222,NULL,51,35308,0);
INSERT INTO "django_geo_db_location" VALUES(61296,NULL,'Harper, TX',25695,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61297,NULL,'Harper, TX 78631',25695,222,NULL,51,35309,0);
INSERT INTO "django_geo_db_location" VALUES(61298,NULL,'Harwood, TX',25696,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61299,NULL,'Harwood, TX 78632',25696,222,NULL,51,35310,0);
INSERT INTO "django_geo_db_location" VALUES(61300,NULL,'Hutto, TX',25697,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61301,NULL,'Hutto, TX 78634',25697,222,NULL,51,35311,0);
INSERT INTO "django_geo_db_location" VALUES(61302,NULL,'Hye, TX',25698,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61303,NULL,'Hye, TX 78635',25698,222,NULL,51,35312,0);
INSERT INTO "django_geo_db_location" VALUES(61304,NULL,'Johnson City, TX',25699,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61305,NULL,'Johnson City, TX 78636',25699,222,NULL,51,35313,0);
INSERT INTO "django_geo_db_location" VALUES(61306,NULL,'Kingsbury, TX',25700,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61307,NULL,'Kingsbury, TX 78638',25700,222,NULL,51,35314,0);
INSERT INTO "django_geo_db_location" VALUES(61308,NULL,'Kingsland, TX',25701,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61309,NULL,'Kingsland, TX 78639',25701,222,NULL,51,35315,0);
INSERT INTO "django_geo_db_location" VALUES(61310,NULL,'Kyle, TX',25702,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61311,NULL,'Kyle, TX 78640',25702,222,NULL,51,35316,0);
INSERT INTO "django_geo_db_location" VALUES(61312,NULL,'Leander, TX',25703,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61313,NULL,'Leander, TX 78641',25703,222,NULL,51,35317,0);
INSERT INTO "django_geo_db_location" VALUES(61314,NULL,'Liberty Hill, TX',25704,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61315,NULL,'Liberty Hill, TX 78642',25704,222,NULL,51,35318,0);
INSERT INTO "django_geo_db_location" VALUES(61316,NULL,'Llano, TX',25705,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61317,NULL,'Llano, TX 78643',25705,222,NULL,51,35319,0);
INSERT INTO "django_geo_db_location" VALUES(61318,NULL,'Lockhart, TX',25706,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61319,NULL,'Lockhart, TX 78644',25706,222,NULL,51,35320,0);
INSERT INTO "django_geo_db_location" VALUES(61320,NULL,'Leander, TX 78645',25703,222,NULL,51,35321,0);
INSERT INTO "django_geo_db_location" VALUES(61321,NULL,'Leander, TX 78646',25703,222,NULL,51,35322,0);
INSERT INTO "django_geo_db_location" VALUES(61322,NULL,'Luling, TX',25707,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61323,NULL,'Luling, TX 78648',25707,222,NULL,51,35323,0);
INSERT INTO "django_geo_db_location" VALUES(61324,NULL,'McDade, TX',25708,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61325,NULL,'McDade, TX 78650',25708,222,NULL,51,35324,0);
INSERT INTO "django_geo_db_location" VALUES(61326,NULL,'McNeil, TX',25709,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61327,NULL,'McNeil, TX 78651',25709,222,NULL,51,35325,0);
INSERT INTO "django_geo_db_location" VALUES(61328,NULL,'Manchaca, TX',25710,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61329,NULL,'Manchaca, TX 78652',25710,222,NULL,51,35326,0);
INSERT INTO "django_geo_db_location" VALUES(61330,NULL,'Manor, TX',25711,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61331,NULL,'Manor, TX 78653',25711,222,NULL,51,35327,0);
INSERT INTO "django_geo_db_location" VALUES(61332,NULL,'Marble Falls, TX',25712,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61333,NULL,'Marble Falls, TX 78654',25712,222,NULL,51,35328,0);
INSERT INTO "django_geo_db_location" VALUES(61334,NULL,'Martindale, TX',25713,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61335,NULL,'Martindale, TX 78655',25713,222,NULL,51,35329,0);
INSERT INTO "django_geo_db_location" VALUES(61336,NULL,'Maxwell, TX',25714,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61337,NULL,'Maxwell, TX 78656',25714,222,NULL,51,35330,0);
INSERT INTO "django_geo_db_location" VALUES(61338,NULL,'Marble Falls, TX 78657',25712,222,NULL,51,35331,0);
INSERT INTO "django_geo_db_location" VALUES(61339,NULL,'Ottine, TX',25715,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61340,NULL,'Ottine, TX 78658',25715,222,NULL,51,35332,0);
INSERT INTO "django_geo_db_location" VALUES(61341,NULL,'Paige, TX',25716,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61342,NULL,'Paige, TX 78659',25716,222,NULL,51,35333,0);
INSERT INTO "django_geo_db_location" VALUES(61343,NULL,'Pflugerville, TX',25717,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61344,NULL,'Pflugerville, TX 78660',25717,222,NULL,51,35334,0);
INSERT INTO "django_geo_db_location" VALUES(61345,NULL,'Prairie Lea, TX',25718,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61346,NULL,'Prairie Lea, TX 78661',25718,222,NULL,51,35335,0);
INSERT INTO "django_geo_db_location" VALUES(61347,NULL,'Red Rock, TX',25719,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61348,NULL,'Red Rock, TX 78662',25719,222,NULL,51,35336,0);
INSERT INTO "django_geo_db_location" VALUES(61349,NULL,'Round Mountain, TX',25720,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61350,NULL,'Round Mountain, TX 78663',25720,222,NULL,51,35337,0);
INSERT INTO "django_geo_db_location" VALUES(61351,NULL,'Round Rock, TX',25721,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61352,NULL,'Round Rock, TX 78664',25721,222,NULL,51,35338,0);
INSERT INTO "django_geo_db_location" VALUES(61353,NULL,'Sandy, TX',25722,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61354,NULL,'Sandy, TX 78665',25722,222,NULL,51,35339,0);
INSERT INTO "django_geo_db_location" VALUES(61355,NULL,'San Marcos, TX',25723,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61356,NULL,'San Marcos, TX 78666',25723,222,NULL,51,35340,0);
INSERT INTO "django_geo_db_location" VALUES(61357,NULL,'San Marcos, TX 78667',25723,222,NULL,51,35341,0);
INSERT INTO "django_geo_db_location" VALUES(61358,NULL,'Spicewood, TX',25724,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61359,NULL,'Spicewood, TX 78669',25724,222,NULL,51,35342,0);
INSERT INTO "django_geo_db_location" VALUES(61360,NULL,'Staples, TX',25725,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61361,NULL,'Staples, TX 78670',25725,222,NULL,51,35343,0);
INSERT INTO "django_geo_db_location" VALUES(61362,NULL,'Stonewall, TX',25726,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61363,NULL,'Stonewall, TX 78671',25726,222,NULL,51,35344,0);
INSERT INTO "django_geo_db_location" VALUES(61364,NULL,'Tow, TX',25727,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61365,NULL,'Tow, TX 78672',25727,222,NULL,51,35345,0);
INSERT INTO "django_geo_db_location" VALUES(61366,NULL,'Walburg, TX',25728,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61367,NULL,'Walburg, TX 78673',25728,222,NULL,51,35346,0);
INSERT INTO "django_geo_db_location" VALUES(61368,NULL,'Weir, TX',25729,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61369,NULL,'Weir, TX 78674',25729,222,NULL,51,35347,0);
INSERT INTO "django_geo_db_location" VALUES(61370,NULL,'Willow City, TX',25730,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61371,NULL,'Willow City, TX 78675',25730,222,NULL,51,35348,0);
INSERT INTO "django_geo_db_location" VALUES(61372,NULL,'Wimberley, TX',25731,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61373,NULL,'Wimberley, TX 78676',25731,222,NULL,51,35349,0);
INSERT INTO "django_geo_db_location" VALUES(61374,NULL,'Wrightsboro, TX',25732,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61375,NULL,'Wrightsboro, TX 78677',25732,222,NULL,51,35350,0);
INSERT INTO "django_geo_db_location" VALUES(61376,NULL,'Round Rock, TX 78680',25721,222,NULL,51,35351,0);
INSERT INTO "django_geo_db_location" VALUES(61377,NULL,'Round Rock, TX 78681',25721,222,NULL,51,35352,0);
INSERT INTO "django_geo_db_location" VALUES(61378,NULL,'Round Rock, TX 78682',25721,222,NULL,51,35353,0);
INSERT INTO "django_geo_db_location" VALUES(61379,NULL,'Round Rock, TX 78683',25721,222,NULL,51,35354,0);
INSERT INTO "django_geo_db_location" VALUES(61380,NULL,'Pflugerville, TX 78691',25717,222,NULL,51,35355,0);
INSERT INTO "django_geo_db_location" VALUES(61381,NULL,'Austin, TX 78701',24059,222,NULL,51,35356,0);
INSERT INTO "django_geo_db_location" VALUES(61382,NULL,'Austin, TX 78702',24059,222,NULL,51,35357,0);
INSERT INTO "django_geo_db_location" VALUES(61383,NULL,'Austin, TX 78703',24059,222,NULL,51,35358,0);
INSERT INTO "django_geo_db_location" VALUES(61384,NULL,'Austin, TX 78704',24059,222,NULL,51,35359,0);
INSERT INTO "django_geo_db_location" VALUES(61385,NULL,'Austin, TX 78705',24059,222,NULL,51,35360,0);
INSERT INTO "django_geo_db_location" VALUES(61386,NULL,'Austin, TX 78708',24059,222,NULL,51,35361,0);
INSERT INTO "django_geo_db_location" VALUES(61387,NULL,'Austin, TX 78709',24059,222,NULL,51,35362,0);
INSERT INTO "django_geo_db_location" VALUES(61388,NULL,'Austin, TX 78710',24059,222,NULL,51,35363,0);
INSERT INTO "django_geo_db_location" VALUES(61389,NULL,'Austin, TX 78711',24059,222,NULL,51,35364,0);
INSERT INTO "django_geo_db_location" VALUES(61390,NULL,'Austin, TX 78712',24059,222,NULL,51,35365,0);
INSERT INTO "django_geo_db_location" VALUES(61391,NULL,'Austin, TX 78713',24059,222,NULL,51,35366,0);
INSERT INTO "django_geo_db_location" VALUES(61392,NULL,'Austin, TX 78714',24059,222,NULL,51,35367,0);
INSERT INTO "django_geo_db_location" VALUES(61393,NULL,'Austin, TX 78715',24059,222,NULL,51,35368,0);
INSERT INTO "django_geo_db_location" VALUES(61394,NULL,'Austin, TX 78716',24059,222,NULL,51,35369,0);
INSERT INTO "django_geo_db_location" VALUES(61395,NULL,'Austin, TX 78717',24059,222,NULL,51,35370,0);
INSERT INTO "django_geo_db_location" VALUES(61396,NULL,'Austin, TX 78718',24059,222,NULL,51,35371,0);
INSERT INTO "django_geo_db_location" VALUES(61397,NULL,'Austin, TX 78719',24059,222,NULL,51,35372,0);
INSERT INTO "django_geo_db_location" VALUES(61398,NULL,'Austin, TX 78720',24059,222,NULL,51,35373,0);
INSERT INTO "django_geo_db_location" VALUES(61399,NULL,'Austin, TX 78721',24059,222,NULL,51,35374,0);
INSERT INTO "django_geo_db_location" VALUES(61400,NULL,'Austin, TX 78722',24059,222,NULL,51,35375,0);
INSERT INTO "django_geo_db_location" VALUES(61401,NULL,'Austin, TX 78723',24059,222,NULL,51,35376,0);
INSERT INTO "django_geo_db_location" VALUES(61402,NULL,'Austin, TX 78724',24059,222,NULL,51,35377,0);
INSERT INTO "django_geo_db_location" VALUES(61403,NULL,'Austin, TX 78725',24059,222,NULL,51,35378,0);
INSERT INTO "django_geo_db_location" VALUES(61404,NULL,'Austin, TX 78726',24059,222,NULL,51,35379,0);
INSERT INTO "django_geo_db_location" VALUES(61405,NULL,'Austin, TX 78727',24059,222,NULL,51,35380,0);
INSERT INTO "django_geo_db_location" VALUES(61406,NULL,'Austin, TX 78728',24059,222,NULL,51,35381,0);
INSERT INTO "django_geo_db_location" VALUES(61407,NULL,'Austin, TX 78729',24059,222,NULL,51,35382,0);
INSERT INTO "django_geo_db_location" VALUES(61408,NULL,'Austin, TX 78730',24059,222,NULL,51,35383,0);
INSERT INTO "django_geo_db_location" VALUES(61409,NULL,'Austin, TX 78731',24059,222,NULL,51,35384,0);
INSERT INTO "django_geo_db_location" VALUES(61410,NULL,'Austin, TX 78732',24059,222,NULL,51,35385,0);
INSERT INTO "django_geo_db_location" VALUES(61411,NULL,'Austin, TX 78733',24059,222,NULL,51,35386,0);
INSERT INTO "django_geo_db_location" VALUES(61412,NULL,'Austin, TX 78734',24059,222,NULL,51,35387,0);
INSERT INTO "django_geo_db_location" VALUES(61413,NULL,'Austin, TX 78735',24059,222,NULL,51,35388,0);
INSERT INTO "django_geo_db_location" VALUES(61414,NULL,'Austin, TX 78736',24059,222,NULL,51,35389,0);
INSERT INTO "django_geo_db_location" VALUES(61415,NULL,'Austin, TX 78737',24059,222,NULL,51,35390,0);
INSERT INTO "django_geo_db_location" VALUES(61416,NULL,'Austin, TX 78738',24059,222,NULL,51,35391,0);
INSERT INTO "django_geo_db_location" VALUES(61417,NULL,'Austin, TX 78739',24059,222,NULL,51,35392,0);
INSERT INTO "django_geo_db_location" VALUES(61418,NULL,'Austin, TX 78741',24059,222,NULL,51,35393,0);
INSERT INTO "django_geo_db_location" VALUES(61419,NULL,'Austin, TX 78742',24059,222,NULL,51,35394,0);
INSERT INTO "django_geo_db_location" VALUES(61420,NULL,'Austin, TX 78744',24059,222,NULL,51,35395,0);
INSERT INTO "django_geo_db_location" VALUES(61421,NULL,'Austin, TX 78745',24059,222,NULL,51,35396,0);
INSERT INTO "django_geo_db_location" VALUES(61422,NULL,'Austin, TX 78746',24059,222,NULL,51,35397,0);
INSERT INTO "django_geo_db_location" VALUES(61423,NULL,'Austin, TX 78747',24059,222,NULL,51,35398,0);
INSERT INTO "django_geo_db_location" VALUES(61424,NULL,'Austin, TX 78748',24059,222,NULL,51,35399,0);
INSERT INTO "django_geo_db_location" VALUES(61425,NULL,'Austin, TX 78749',24059,222,NULL,51,35400,0);
INSERT INTO "django_geo_db_location" VALUES(61426,NULL,'Austin, TX 78750',24059,222,NULL,51,35401,0);
INSERT INTO "django_geo_db_location" VALUES(61427,NULL,'Austin, TX 78751',24059,222,NULL,51,35402,0);
INSERT INTO "django_geo_db_location" VALUES(61428,NULL,'Austin, TX 78752',24059,222,NULL,51,35403,0);
INSERT INTO "django_geo_db_location" VALUES(61429,NULL,'Austin, TX 78753',24059,222,NULL,51,35404,0);
INSERT INTO "django_geo_db_location" VALUES(61430,NULL,'Austin, TX 78754',24059,222,NULL,51,35405,0);
INSERT INTO "django_geo_db_location" VALUES(61431,NULL,'Austin, TX 78755',24059,222,NULL,51,35406,0);
INSERT INTO "django_geo_db_location" VALUES(61432,NULL,'Austin, TX 78756',24059,222,NULL,51,35407,0);
INSERT INTO "django_geo_db_location" VALUES(61433,NULL,'Austin, TX 78757',24059,222,NULL,51,35408,0);
INSERT INTO "django_geo_db_location" VALUES(61434,NULL,'Austin, TX 78758',24059,222,NULL,51,35409,0);
INSERT INTO "django_geo_db_location" VALUES(61435,NULL,'Austin, TX 78759',24059,222,NULL,51,35410,0);
INSERT INTO "django_geo_db_location" VALUES(61436,NULL,'Austin, TX 78760',24059,222,NULL,51,35411,0);
INSERT INTO "django_geo_db_location" VALUES(61437,NULL,'Austin, TX 78761',24059,222,NULL,51,35412,0);
INSERT INTO "django_geo_db_location" VALUES(61438,NULL,'Austin, TX 78762',24059,222,NULL,51,35413,0);
INSERT INTO "django_geo_db_location" VALUES(61439,NULL,'Austin, TX 78763',24059,222,NULL,51,35414,0);
INSERT INTO "django_geo_db_location" VALUES(61440,NULL,'Austin, TX 78764',24059,222,NULL,51,35415,0);
INSERT INTO "django_geo_db_location" VALUES(61441,NULL,'Austin, TX 78765',24059,222,NULL,51,35416,0);
INSERT INTO "django_geo_db_location" VALUES(61442,NULL,'Austin, TX 78766',24059,222,NULL,51,35417,0);
INSERT INTO "django_geo_db_location" VALUES(61443,NULL,'Austin, TX 78767',24059,222,NULL,51,35418,0);
INSERT INTO "django_geo_db_location" VALUES(61444,NULL,'Austin, TX 78768',24059,222,NULL,51,35419,0);
INSERT INTO "django_geo_db_location" VALUES(61445,NULL,'Austin, TX 78769',24059,222,NULL,51,35420,0);
INSERT INTO "django_geo_db_location" VALUES(61446,NULL,'Austin, TX 78771',24059,222,NULL,51,35421,0);
INSERT INTO "django_geo_db_location" VALUES(61447,NULL,'Austin, TX 78772',24059,222,NULL,51,35422,0);
INSERT INTO "django_geo_db_location" VALUES(61448,NULL,'Austin, TX 78773',24059,222,NULL,51,35423,0);
INSERT INTO "django_geo_db_location" VALUES(61449,NULL,'Austin, TX 78774',24059,222,NULL,51,35424,0);
INSERT INTO "django_geo_db_location" VALUES(61450,NULL,'Austin, TX 78778',24059,222,NULL,51,35425,0);
INSERT INTO "django_geo_db_location" VALUES(61451,NULL,'Austin, TX 78779',24059,222,NULL,51,35426,0);
INSERT INTO "django_geo_db_location" VALUES(61452,NULL,'Austin, TX 78780',24059,222,NULL,51,35427,0);
INSERT INTO "django_geo_db_location" VALUES(61453,NULL,'Austin, TX 78781',24059,222,NULL,51,35428,0);
INSERT INTO "django_geo_db_location" VALUES(61454,NULL,'Austin, TX 78782',24059,222,NULL,51,35429,0);
INSERT INTO "django_geo_db_location" VALUES(61455,NULL,'Austin, TX 78783',24059,222,NULL,51,35430,0);
INSERT INTO "django_geo_db_location" VALUES(61456,NULL,'Austin, TX 78785',24059,222,NULL,51,35431,0);
INSERT INTO "django_geo_db_location" VALUES(61457,NULL,'Austin, TX 78786',24059,222,NULL,51,35432,0);
INSERT INTO "django_geo_db_location" VALUES(61458,NULL,'Austin, TX 78787',24059,222,NULL,51,35433,0);
INSERT INTO "django_geo_db_location" VALUES(61459,NULL,'Austin, TX 78788',24059,222,NULL,51,35434,0);
INSERT INTO "django_geo_db_location" VALUES(61460,NULL,'Austin, TX 78789',24059,222,NULL,51,35435,0);
INSERT INTO "django_geo_db_location" VALUES(61461,NULL,'Uvalde, TX',25733,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61462,NULL,'Uvalde, TX 78801',25733,222,NULL,51,35436,0);
INSERT INTO "django_geo_db_location" VALUES(61463,NULL,'Uvalde, TX 78802',25733,222,NULL,51,35437,0);
INSERT INTO "django_geo_db_location" VALUES(61464,NULL,'Asherton, TX',25734,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61465,NULL,'Asherton, TX 78827',25734,222,NULL,51,35438,0);
INSERT INTO "django_geo_db_location" VALUES(61466,NULL,'Barksdale, TX',25735,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61467,NULL,'Barksdale, TX 78828',25735,222,NULL,51,35439,0);
INSERT INTO "django_geo_db_location" VALUES(61468,NULL,'Batesville, TX',25736,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61469,NULL,'Batesville, TX 78829',25736,222,NULL,51,35440,0);
INSERT INTO "django_geo_db_location" VALUES(61470,NULL,'Big Wells, TX',25737,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61471,NULL,'Big Wells, TX 78830',25737,222,NULL,51,35441,0);
INSERT INTO "django_geo_db_location" VALUES(61472,NULL,'Brackettville, TX',25738,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61473,NULL,'Brackettville, TX 78832',25738,222,NULL,51,35442,0);
INSERT INTO "django_geo_db_location" VALUES(61474,NULL,'Camp Wood, TX',25739,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61475,NULL,'Camp Wood, TX 78833',25739,222,NULL,51,35443,0);
INSERT INTO "django_geo_db_location" VALUES(61476,NULL,'Carrizo Springs, TX',25740,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61477,NULL,'Carrizo Springs, TX 78834',25740,222,NULL,51,35444,0);
INSERT INTO "django_geo_db_location" VALUES(61478,NULL,'Burton, TX 78835',25408,222,NULL,51,35445,0);
INSERT INTO "django_geo_db_location" VALUES(61479,NULL,'Catarina, TX',25741,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61480,NULL,'Catarina, TX 78836',25741,222,NULL,51,35446,0);
INSERT INTO "django_geo_db_location" VALUES(61481,NULL,'Comstock, TX',25742,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61482,NULL,'Comstock, TX 78837',25742,222,NULL,51,35447,0);
INSERT INTO "django_geo_db_location" VALUES(61483,NULL,'Concan, TX',25743,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61484,NULL,'Concan, TX 78838',25743,222,NULL,51,35448,0);
INSERT INTO "django_geo_db_location" VALUES(61485,NULL,'Crystal City, TX',25744,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61486,NULL,'Crystal City, TX 78839',25744,222,NULL,51,35449,0);
INSERT INTO "django_geo_db_location" VALUES(61487,NULL,'Del Rio, TX',25745,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61488,NULL,'Del Rio, TX 78840',25745,222,NULL,51,35450,0);
INSERT INTO "django_geo_db_location" VALUES(61489,NULL,'Del Rio, TX 78841',25745,222,NULL,51,35451,0);
INSERT INTO "django_geo_db_location" VALUES(61490,NULL,'Del Rio, TX 78842',25745,222,NULL,51,35452,0);
INSERT INTO "django_geo_db_location" VALUES(61491,NULL,'Laughlin A F B, TX',25746,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61492,NULL,'Laughlin A F B, TX 78843',25746,222,NULL,51,35453,0);
INSERT INTO "django_geo_db_location" VALUES(61493,NULL,'Del Rio, TX 78847',25745,222,NULL,51,35454,0);
INSERT INTO "django_geo_db_location" VALUES(61494,NULL,'D Hanis, TX',25747,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61495,NULL,'D Hanis, TX 78850',25747,222,NULL,51,35455,0);
INSERT INTO "django_geo_db_location" VALUES(61496,NULL,'Dryden, TX',25748,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61497,NULL,'Dryden, TX 78851',25748,222,NULL,51,35456,0);
INSERT INTO "django_geo_db_location" VALUES(61498,NULL,'Eagle Pass, TX',25749,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61499,NULL,'Eagle Pass, TX 78852',25749,222,NULL,51,35457,0);
INSERT INTO "django_geo_db_location" VALUES(61500,NULL,'Eagle Pass, TX 78853',25749,222,NULL,51,35458,0);
INSERT INTO "django_geo_db_location" VALUES(61501,NULL,'El Indio, TX',25750,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61502,NULL,'El Indio, TX 78860',25750,222,NULL,51,35459,0);
INSERT INTO "django_geo_db_location" VALUES(61503,NULL,'Hondo, TX',25751,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61504,NULL,'Hondo, TX 78861',25751,222,NULL,51,35460,0);
INSERT INTO "django_geo_db_location" VALUES(61505,NULL,'Knippa, TX',25752,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61506,NULL,'Knippa, TX 78870',25752,222,NULL,51,35461,0);
INSERT INTO "django_geo_db_location" VALUES(61507,NULL,'Langtry, TX',25753,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61508,NULL,'Langtry, TX 78871',25753,222,NULL,51,35462,0);
INSERT INTO "django_geo_db_location" VALUES(61509,NULL,'La Pryor, TX',25754,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61510,NULL,'La Pryor, TX 78872',25754,222,NULL,51,35463,0);
INSERT INTO "django_geo_db_location" VALUES(61511,NULL,'Leakey, TX',25755,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61512,NULL,'Leakey, TX 78873',25755,222,NULL,51,35464,0);
INSERT INTO "django_geo_db_location" VALUES(61513,NULL,'Quemado, TX',25756,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61514,NULL,'Quemado, TX 78877',25756,222,NULL,51,35465,0);
INSERT INTO "django_geo_db_location" VALUES(61515,NULL,'Rio Frio, TX',25757,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61516,NULL,'Rio Frio, TX 78879',25757,222,NULL,51,35466,0);
INSERT INTO "django_geo_db_location" VALUES(61517,NULL,'Rocksprings, TX',25758,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61518,NULL,'Rocksprings, TX 78880',25758,222,NULL,51,35467,0);
INSERT INTO "django_geo_db_location" VALUES(61519,NULL,'Sabinal, TX',25759,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61520,NULL,'Sabinal, TX 78881',25759,222,NULL,51,35468,0);
INSERT INTO "django_geo_db_location" VALUES(61521,NULL,'Tarpley, TX',25760,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61522,NULL,'Tarpley, TX 78883',25760,222,NULL,51,35469,0);
INSERT INTO "django_geo_db_location" VALUES(61523,NULL,'Utopia, TX',25761,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61524,NULL,'Utopia, TX 78884',25761,222,NULL,51,35470,0);
INSERT INTO "django_geo_db_location" VALUES(61525,NULL,'Vanderpool, TX',25762,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61526,NULL,'Vanderpool, TX 78885',25762,222,NULL,51,35471,0);
INSERT INTO "django_geo_db_location" VALUES(61527,NULL,'Yancey, TX',25763,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61528,NULL,'Yancey, TX 78886',25763,222,NULL,51,35472,0);
INSERT INTO "django_geo_db_location" VALUES(61529,NULL,'Bleiblerville, TX',25764,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61530,NULL,'Bleiblerville, TX 78931',25764,222,NULL,51,35473,0);
INSERT INTO "django_geo_db_location" VALUES(61531,NULL,'Carmine, TX',25765,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61532,NULL,'Carmine, TX 78932',25765,222,NULL,51,35474,0);
INSERT INTO "django_geo_db_location" VALUES(61533,NULL,'Cat Spring, TX',25766,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61534,NULL,'Cat Spring, TX 78933',25766,222,NULL,51,35475,0);
INSERT INTO "django_geo_db_location" VALUES(61535,NULL,'Columbus, TX',25767,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61536,NULL,'Columbus, TX 78934',25767,222,NULL,51,35476,0);
INSERT INTO "django_geo_db_location" VALUES(61537,NULL,'Alleyton, TX',25768,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61538,NULL,'Alleyton, TX 78935',25768,222,NULL,51,35477,0);
INSERT INTO "django_geo_db_location" VALUES(61539,NULL,'Ellinger, TX',25769,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61540,NULL,'Ellinger, TX 78938',25769,222,NULL,51,35478,0);
INSERT INTO "django_geo_db_location" VALUES(61541,NULL,'Fayetteville, TX',25770,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61542,NULL,'Fayetteville, TX 78940',25770,222,NULL,51,35479,0);
INSERT INTO "django_geo_db_location" VALUES(61543,NULL,'Flatonia, TX',25771,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61544,NULL,'Flatonia, TX 78941',25771,222,NULL,51,35480,0);
INSERT INTO "django_geo_db_location" VALUES(61545,NULL,'Giddings, TX',25772,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61546,NULL,'Giddings, TX 78942',25772,222,NULL,51,35481,0);
INSERT INTO "django_geo_db_location" VALUES(61547,NULL,'Glidden, TX',25773,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61548,NULL,'Glidden, TX 78943',25773,222,NULL,51,35482,0);
INSERT INTO "django_geo_db_location" VALUES(61549,NULL,'Industry, TX',25774,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61550,NULL,'Industry, TX 78944',25774,222,NULL,51,35483,0);
INSERT INTO "django_geo_db_location" VALUES(61551,NULL,'La Grange, TX',25775,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61552,NULL,'La Grange, TX 78945',25775,222,NULL,51,35484,0);
INSERT INTO "django_geo_db_location" VALUES(61553,NULL,'Ledbetter, TX',25776,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61554,NULL,'Ledbetter, TX 78946',25776,222,NULL,51,35485,0);
INSERT INTO "django_geo_db_location" VALUES(61555,NULL,'Lexington, TX',25777,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61556,NULL,'Lexington, TX 78947',25777,222,NULL,51,35486,0);
INSERT INTO "django_geo_db_location" VALUES(61557,NULL,'Lincoln, TX',25778,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61558,NULL,'Lincoln, TX 78948',25778,222,NULL,51,35487,0);
INSERT INTO "django_geo_db_location" VALUES(61559,NULL,'Muldoon, TX',25779,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61560,NULL,'Muldoon, TX 78949',25779,222,NULL,51,35488,0);
INSERT INTO "django_geo_db_location" VALUES(61561,NULL,'New Ulm, TX',25780,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61562,NULL,'New Ulm, TX 78950',25780,222,NULL,51,35489,0);
INSERT INTO "django_geo_db_location" VALUES(61563,NULL,'Oakland, TX',25781,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61564,NULL,'Oakland, TX 78951',25781,222,NULL,51,35490,0);
INSERT INTO "django_geo_db_location" VALUES(61565,NULL,'Plum, TX',25782,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61566,NULL,'Plum, TX 78952',25782,222,NULL,51,35491,0);
INSERT INTO "django_geo_db_location" VALUES(61567,NULL,'Rosanky, TX',25783,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61568,NULL,'Rosanky, TX 78953',25783,222,NULL,51,35492,0);
INSERT INTO "django_geo_db_location" VALUES(61569,NULL,'Round Top, TX',25784,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61570,NULL,'Round Top, TX 78954',25784,222,NULL,51,35493,0);
INSERT INTO "django_geo_db_location" VALUES(61571,NULL,'Schulenburg, TX',25785,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61572,NULL,'Schulenburg, TX 78956',25785,222,NULL,51,35494,0);
INSERT INTO "django_geo_db_location" VALUES(61573,NULL,'Smithville, TX',25786,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61574,NULL,'Smithville, TX 78957',25786,222,NULL,51,35495,0);
INSERT INTO "django_geo_db_location" VALUES(61575,NULL,'Waelder, TX',25787,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61576,NULL,'Waelder, TX 78959',25787,222,NULL,51,35496,0);
INSERT INTO "django_geo_db_location" VALUES(61577,NULL,'Warda, TX',25788,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61578,NULL,'Warda, TX 78960',25788,222,NULL,51,35497,0);
INSERT INTO "django_geo_db_location" VALUES(61579,NULL,'Round Top, TX 78961',25784,222,NULL,51,35498,0);
INSERT INTO "django_geo_db_location" VALUES(61580,NULL,'Weimar, TX',25789,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61581,NULL,'Weimar, TX 78962',25789,222,NULL,51,35499,0);
INSERT INTO "django_geo_db_location" VALUES(61582,NULL,'West Point, TX',25790,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61583,NULL,'West Point, TX 78963',25790,222,NULL,51,35500,0);
INSERT INTO "django_geo_db_location" VALUES(61584,NULL,'Austin, TX 78972',24059,222,NULL,51,35501,0);
INSERT INTO "django_geo_db_location" VALUES(61585,NULL,'Adrian, TX',25791,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61586,NULL,'Adrian, TX 79001',25791,222,NULL,51,35502,0);
INSERT INTO "django_geo_db_location" VALUES(61587,NULL,'Alanreed, TX',25792,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61588,NULL,'Alanreed, TX 79002',25792,222,NULL,51,35503,0);
INSERT INTO "django_geo_db_location" VALUES(61589,NULL,'Allison, TX',25793,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61590,NULL,'Allison, TX 79003',25793,222,NULL,51,35504,0);
INSERT INTO "django_geo_db_location" VALUES(61591,NULL,'Booker, TX',25794,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61592,NULL,'Booker, TX 79005',25794,222,NULL,51,35505,0);
INSERT INTO "django_geo_db_location" VALUES(61593,NULL,'Borger, TX',25795,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61594,NULL,'Borger, TX 79007',25795,222,NULL,51,35506,0);
INSERT INTO "django_geo_db_location" VALUES(61595,NULL,'Borger, TX 79008',25795,222,NULL,51,35507,0);
INSERT INTO "django_geo_db_location" VALUES(61596,NULL,'Bovina, TX',25796,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61597,NULL,'Bovina, TX 79009',25796,222,NULL,51,35508,0);
INSERT INTO "django_geo_db_location" VALUES(61598,NULL,'Boys Ranch, TX',25797,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61599,NULL,'Boys Ranch, TX 79010',25797,222,NULL,51,35509,0);
INSERT INTO "django_geo_db_location" VALUES(61600,NULL,'Briscoe, TX',25798,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61601,NULL,'Briscoe, TX 79011',25798,222,NULL,51,35510,0);
INSERT INTO "django_geo_db_location" VALUES(61602,NULL,'Bushland, TX',25799,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61603,NULL,'Bushland, TX 79012',25799,222,NULL,51,35511,0);
INSERT INTO "django_geo_db_location" VALUES(61604,NULL,'Cactus, TX',25800,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61605,NULL,'Cactus, TX 79013',25800,222,NULL,51,35512,0);
INSERT INTO "django_geo_db_location" VALUES(61606,NULL,'Canadian, TX',25801,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61607,NULL,'Canadian, TX 79014',25801,222,NULL,51,35513,0);
INSERT INTO "django_geo_db_location" VALUES(61608,NULL,'Canyon, TX',25802,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61609,NULL,'Canyon, TX 79015',25802,222,NULL,51,35514,0);
INSERT INTO "django_geo_db_location" VALUES(61610,NULL,'Canyon, TX 79016',25802,222,NULL,51,35515,0);
INSERT INTO "django_geo_db_location" VALUES(61611,NULL,'Channing, TX',25803,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61612,NULL,'Channing, TX 79018',25803,222,NULL,51,35516,0);
INSERT INTO "django_geo_db_location" VALUES(61613,NULL,'Claude, TX',25804,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61614,NULL,'Claude, TX 79019',25804,222,NULL,51,35517,0);
INSERT INTO "django_geo_db_location" VALUES(61615,NULL,'Cotton Center, TX',25805,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61616,NULL,'Cotton Center, TX 79021',25805,222,NULL,51,35518,0);
INSERT INTO "django_geo_db_location" VALUES(61617,NULL,'Dalhart, TX',25806,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61618,NULL,'Dalhart, TX 79022',25806,222,NULL,51,35519,0);
INSERT INTO "django_geo_db_location" VALUES(61619,NULL,'Darrouzett, TX',25807,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61620,NULL,'Darrouzett, TX 79024',25807,222,NULL,51,35520,0);
INSERT INTO "django_geo_db_location" VALUES(61621,NULL,'Dawn, TX',25808,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61622,NULL,'Dawn, TX 79025',25808,222,NULL,51,35521,0);
INSERT INTO "django_geo_db_location" VALUES(61623,NULL,'Dimmitt, TX',25809,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61624,NULL,'Dimmitt, TX 79027',25809,222,NULL,51,35522,0);
INSERT INTO "django_geo_db_location" VALUES(61625,NULL,'Dumas, TX',25810,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61626,NULL,'Dumas, TX 79029',25810,222,NULL,51,35523,0);
INSERT INTO "django_geo_db_location" VALUES(61627,NULL,'Earth, TX',25811,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61628,NULL,'Earth, TX 79031',25811,222,NULL,51,35524,0);
INSERT INTO "django_geo_db_location" VALUES(61629,NULL,'Edmonson, TX',25812,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61630,NULL,'Edmonson, TX 79032',25812,222,NULL,51,35525,0);
INSERT INTO "django_geo_db_location" VALUES(61631,NULL,'Farnsworth, TX',25813,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61632,NULL,'Farnsworth, TX 79033',25813,222,NULL,51,35526,0);
INSERT INTO "django_geo_db_location" VALUES(61633,NULL,'Follett, TX',25814,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61634,NULL,'Follett, TX 79034',25814,222,NULL,51,35527,0);
INSERT INTO "django_geo_db_location" VALUES(61635,NULL,'Friona, TX',25815,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61636,NULL,'Friona, TX 79035',25815,222,NULL,51,35528,0);
INSERT INTO "django_geo_db_location" VALUES(61637,NULL,'Fritch, TX',25816,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61638,NULL,'Fritch, TX 79036',25816,222,NULL,51,35529,0);
INSERT INTO "django_geo_db_location" VALUES(61639,NULL,'Groom, TX',25817,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61640,NULL,'Groom, TX 79039',25817,222,NULL,51,35530,0);
INSERT INTO "django_geo_db_location" VALUES(61641,NULL,'Gruver, TX',25818,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61642,NULL,'Gruver, TX 79040',25818,222,NULL,51,35531,0);
INSERT INTO "django_geo_db_location" VALUES(61643,NULL,'Hale Center, TX',25819,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61644,NULL,'Hale Center, TX 79041',25819,222,NULL,51,35532,0);
INSERT INTO "django_geo_db_location" VALUES(61645,NULL,'Happy, TX',25820,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61646,NULL,'Happy, TX 79042',25820,222,NULL,51,35533,0);
INSERT INTO "django_geo_db_location" VALUES(61647,NULL,'Hart, TX',25821,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61648,NULL,'Hart, TX 79043',25821,222,NULL,51,35534,0);
INSERT INTO "django_geo_db_location" VALUES(61649,NULL,'Hartley, TX',25822,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61650,NULL,'Hartley, TX 79044',25822,222,NULL,51,35535,0);
INSERT INTO "django_geo_db_location" VALUES(61651,NULL,'Hereford, TX',25823,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61652,NULL,'Hereford, TX 79045',25823,222,NULL,51,35536,0);
INSERT INTO "django_geo_db_location" VALUES(61653,NULL,'Higgins, TX',25824,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61654,NULL,'Higgins, TX 79046',25824,222,NULL,51,35537,0);
INSERT INTO "django_geo_db_location" VALUES(61655,NULL,'Kerrick, OK',25825,222,NULL,36,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61656,NULL,'Kerrick, OK 79051',25825,222,NULL,36,35538,0);
INSERT INTO "django_geo_db_location" VALUES(61657,NULL,'Kress, TX',25826,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61658,NULL,'Kress, TX 79052',25826,222,NULL,51,35539,0);
INSERT INTO "django_geo_db_location" VALUES(61659,NULL,'Lazbuddie, TX',25827,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61660,NULL,'Lazbuddie, TX 79053',25827,222,NULL,51,35540,0);
INSERT INTO "django_geo_db_location" VALUES(61661,NULL,'Lefors, TX',25828,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61662,NULL,'Lefors, TX 79054',25828,222,NULL,51,35541,0);
INSERT INTO "django_geo_db_location" VALUES(61663,NULL,'Lipscomb, TX',25829,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61664,NULL,'Lipscomb, TX 79056',25829,222,NULL,51,35542,0);
INSERT INTO "django_geo_db_location" VALUES(61665,NULL,'Mclean, TX',25830,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61666,NULL,'Mclean, TX 79057',25830,222,NULL,51,35543,0);
INSERT INTO "django_geo_db_location" VALUES(61667,NULL,'Masterson, TX',25831,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61668,NULL,'Masterson, TX 79058',25831,222,NULL,51,35544,0);
INSERT INTO "django_geo_db_location" VALUES(61669,NULL,'Miami, TX',25832,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61670,NULL,'Miami, TX 79059',25832,222,NULL,51,35545,0);
INSERT INTO "django_geo_db_location" VALUES(61671,NULL,'Mobeetie, TX',25833,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61672,NULL,'Mobeetie, TX 79061',25833,222,NULL,51,35546,0);
INSERT INTO "django_geo_db_location" VALUES(61673,NULL,'Morse, TX',25834,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61674,NULL,'Morse, TX 79062',25834,222,NULL,51,35547,0);
INSERT INTO "django_geo_db_location" VALUES(61675,NULL,'Nazareth, TX',25835,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61676,NULL,'Nazareth, TX 79063',25835,222,NULL,51,35548,0);
INSERT INTO "django_geo_db_location" VALUES(61677,NULL,'Olton, TX',25836,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61678,NULL,'Olton, TX 79064',25836,222,NULL,51,35549,0);
INSERT INTO "django_geo_db_location" VALUES(61679,NULL,'Pampa, TX',25837,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61680,NULL,'Pampa, TX 79065',25837,222,NULL,51,35550,0);
INSERT INTO "django_geo_db_location" VALUES(61681,NULL,'Pampa, TX 79066',25837,222,NULL,51,35551,0);
INSERT INTO "django_geo_db_location" VALUES(61682,NULL,'Panhandle, TX',25838,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61683,NULL,'Panhandle, TX 79068',25838,222,NULL,51,35552,0);
INSERT INTO "django_geo_db_location" VALUES(61684,NULL,'Perryton, TX',25839,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61685,NULL,'Perryton, TX 79070',25839,222,NULL,51,35553,0);
INSERT INTO "django_geo_db_location" VALUES(61686,NULL,'Plainview, TX',25840,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61687,NULL,'Plainview, TX 79072',25840,222,NULL,51,35554,0);
INSERT INTO "django_geo_db_location" VALUES(61688,NULL,'Plainview, TX 79073',25840,222,NULL,51,35555,0);
INSERT INTO "django_geo_db_location" VALUES(61689,NULL,'Samnorwood, TX',25841,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61690,NULL,'Samnorwood, TX 79077',25841,222,NULL,51,35556,0);
INSERT INTO "django_geo_db_location" VALUES(61691,NULL,'Sanford, TX',25842,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61692,NULL,'Sanford, TX 79078',25842,222,NULL,51,35557,0);
INSERT INTO "django_geo_db_location" VALUES(61693,NULL,'Shamrock, TX',25843,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61694,NULL,'Shamrock, TX 79079',25843,222,NULL,51,35558,0);
INSERT INTO "django_geo_db_location" VALUES(61695,NULL,'Skellytown, TX',25844,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61696,NULL,'Skellytown, TX 79080',25844,222,NULL,51,35559,0);
INSERT INTO "django_geo_db_location" VALUES(61697,NULL,'Spearman, TX',25845,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61698,NULL,'Spearman, TX 79081',25845,222,NULL,51,35560,0);
INSERT INTO "django_geo_db_location" VALUES(61699,NULL,'Springlake, TX',25846,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61700,NULL,'Springlake, TX 79082',25846,222,NULL,51,35561,0);
INSERT INTO "django_geo_db_location" VALUES(61701,NULL,'Stinnett, TX',25847,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61702,NULL,'Stinnett, TX 79083',25847,222,NULL,51,35562,0);
INSERT INTO "django_geo_db_location" VALUES(61703,NULL,'Stratford, TX',25848,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61704,NULL,'Stratford, TX 79084',25848,222,NULL,51,35563,0);
INSERT INTO "django_geo_db_location" VALUES(61705,NULL,'Summerfield, TX',25849,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61706,NULL,'Summerfield, TX 79085',25849,222,NULL,51,35564,0);
INSERT INTO "django_geo_db_location" VALUES(61707,NULL,'Sunray, TX',25850,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61708,NULL,'Sunray, TX 79086',25850,222,NULL,51,35565,0);
INSERT INTO "django_geo_db_location" VALUES(61709,NULL,'Texline, TX',25851,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61710,NULL,'Texline, TX 79087',25851,222,NULL,51,35566,0);
INSERT INTO "django_geo_db_location" VALUES(61711,NULL,'Tulia, TX',25852,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61712,NULL,'Tulia, TX 79088',25852,222,NULL,51,35567,0);
INSERT INTO "django_geo_db_location" VALUES(61713,NULL,'Umbarger, TX',25853,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61714,NULL,'Umbarger, TX 79091',25853,222,NULL,51,35568,0);
INSERT INTO "django_geo_db_location" VALUES(61715,NULL,'Vega, TX',25854,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61716,NULL,'Vega, TX 79092',25854,222,NULL,51,35569,0);
INSERT INTO "django_geo_db_location" VALUES(61717,NULL,'Waka, TX',25855,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61718,NULL,'Waka, TX 79093',25855,222,NULL,51,35570,0);
INSERT INTO "django_geo_db_location" VALUES(61719,NULL,'Wayside, TX',25856,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61720,NULL,'Wayside, TX 79094',25856,222,NULL,51,35571,0);
INSERT INTO "django_geo_db_location" VALUES(61721,NULL,'Wellington, TX',25857,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61722,NULL,'Wellington, TX 79095',25857,222,NULL,51,35572,0);
INSERT INTO "django_geo_db_location" VALUES(61723,NULL,'Wheeler, TX',25858,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61724,NULL,'Wheeler, TX 79096',25858,222,NULL,51,35573,0);
INSERT INTO "django_geo_db_location" VALUES(61725,NULL,'White Deer, TX',25859,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61726,NULL,'White Deer, TX 79097',25859,222,NULL,51,35574,0);
INSERT INTO "django_geo_db_location" VALUES(61727,NULL,'Wildorado, TX',25860,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61728,NULL,'Wildorado, TX 79098',25860,222,NULL,51,35575,0);
INSERT INTO "django_geo_db_location" VALUES(61729,NULL,'Amarillo, TX',25861,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61730,NULL,'Amarillo, TX 79101',25861,222,NULL,51,35576,0);
INSERT INTO "django_geo_db_location" VALUES(61731,NULL,'Amarillo, TX 79102',25861,222,NULL,51,35577,0);
INSERT INTO "django_geo_db_location" VALUES(61732,NULL,'Amarillo, TX 79103',25861,222,NULL,51,35578,0);
INSERT INTO "django_geo_db_location" VALUES(61733,NULL,'Amarillo, TX 79104',25861,222,NULL,51,35579,0);
INSERT INTO "django_geo_db_location" VALUES(61734,NULL,'Amarillo, TX 79105',25861,222,NULL,51,35580,0);
INSERT INTO "django_geo_db_location" VALUES(61735,NULL,'Amarillo, TX 79106',25861,222,NULL,51,35581,0);
INSERT INTO "django_geo_db_location" VALUES(61736,NULL,'Amarillo, TX 79107',25861,222,NULL,51,35582,0);
INSERT INTO "django_geo_db_location" VALUES(61737,NULL,'Amarillo, TX 79108',25861,222,NULL,51,35583,0);
INSERT INTO "django_geo_db_location" VALUES(61738,NULL,'Amarillo, TX 79109',25861,222,NULL,51,35584,0);
INSERT INTO "django_geo_db_location" VALUES(61739,NULL,'Amarillo, TX 79110',25861,222,NULL,51,35585,0);
INSERT INTO "django_geo_db_location" VALUES(61740,NULL,'Amarillo, TX 79111',25861,222,NULL,51,35586,0);
INSERT INTO "django_geo_db_location" VALUES(61741,NULL,'Amarillo, TX 79114',25861,222,NULL,51,35587,0);
INSERT INTO "django_geo_db_location" VALUES(61742,NULL,'Amarillo, TX 79116',25861,222,NULL,51,35588,0);
INSERT INTO "django_geo_db_location" VALUES(61743,NULL,'Amarillo, TX 79117',25861,222,NULL,51,35589,0);
INSERT INTO "django_geo_db_location" VALUES(61744,NULL,'Amarillo, TX 79118',25861,222,NULL,51,35590,0);
INSERT INTO "django_geo_db_location" VALUES(61745,NULL,'Amarillo, TX 79119',25861,222,NULL,51,35591,0);
INSERT INTO "django_geo_db_location" VALUES(61746,NULL,'Amarillo, TX 79120',25861,222,NULL,51,35592,0);
INSERT INTO "django_geo_db_location" VALUES(61747,NULL,'Amarillo, TX 79121',25861,222,NULL,51,35593,0);
INSERT INTO "django_geo_db_location" VALUES(61748,NULL,'Amarillo, TX 79123',25861,222,NULL,51,35594,0);
INSERT INTO "django_geo_db_location" VALUES(61749,NULL,'Amarillo, TX 79124',25861,222,NULL,51,35595,0);
INSERT INTO "django_geo_db_location" VALUES(61750,NULL,'Amarillo, TX 79159',25861,222,NULL,51,35596,0);
INSERT INTO "django_geo_db_location" VALUES(61751,NULL,'Amarillo, TX 79160',25861,222,NULL,51,35597,0);
INSERT INTO "django_geo_db_location" VALUES(61752,NULL,'Amarillo, TX 79163',25861,222,NULL,51,35598,0);
INSERT INTO "django_geo_db_location" VALUES(61753,NULL,'Amarillo, TX 79164',25861,222,NULL,51,35599,0);
INSERT INTO "django_geo_db_location" VALUES(61754,NULL,'Amarillo, TX 79165',25861,222,NULL,51,35600,0);
INSERT INTO "django_geo_db_location" VALUES(61755,NULL,'Amarillo, TX 79166',25861,222,NULL,51,35601,0);
INSERT INTO "django_geo_db_location" VALUES(61756,NULL,'Amarillo, TX 79167',25861,222,NULL,51,35602,0);
INSERT INTO "django_geo_db_location" VALUES(61757,NULL,'Amarillo, TX 79168',25861,222,NULL,51,35603,0);
INSERT INTO "django_geo_db_location" VALUES(61758,NULL,'Amarillo, TX 79170',25861,222,NULL,51,35604,0);
INSERT INTO "django_geo_db_location" VALUES(61759,NULL,'Amarillo, TX 79171',25861,222,NULL,51,35605,0);
INSERT INTO "django_geo_db_location" VALUES(61760,NULL,'Amarillo, TX 79172',25861,222,NULL,51,35606,0);
INSERT INTO "django_geo_db_location" VALUES(61761,NULL,'Amarillo, TX 79174',25861,222,NULL,51,35607,0);
INSERT INTO "django_geo_db_location" VALUES(61762,NULL,'Amarillo, TX 79175',25861,222,NULL,51,35608,0);
INSERT INTO "django_geo_db_location" VALUES(61763,NULL,'Amarillo, TX 79178',25861,222,NULL,51,35609,0);
INSERT INTO "django_geo_db_location" VALUES(61764,NULL,'Amarillo, TX 79180',25861,222,NULL,51,35610,0);
INSERT INTO "django_geo_db_location" VALUES(61765,NULL,'Amarillo, TX 79181',25861,222,NULL,51,35611,0);
INSERT INTO "django_geo_db_location" VALUES(61766,NULL,'Amarillo, TX 79182',25861,222,NULL,51,35612,0);
INSERT INTO "django_geo_db_location" VALUES(61767,NULL,'Amarillo, TX 79184',25861,222,NULL,51,35613,0);
INSERT INTO "django_geo_db_location" VALUES(61768,NULL,'Amarillo, TX 79185',25861,222,NULL,51,35614,0);
INSERT INTO "django_geo_db_location" VALUES(61769,NULL,'Amarillo, TX 79186',25861,222,NULL,51,35615,0);
INSERT INTO "django_geo_db_location" VALUES(61770,NULL,'Amarillo, TX 79187',25861,222,NULL,51,35616,0);
INSERT INTO "django_geo_db_location" VALUES(61771,NULL,'Amarillo, TX 79189',25861,222,NULL,51,35617,0);
INSERT INTO "django_geo_db_location" VALUES(61772,NULL,'Childress, TX',25862,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61773,NULL,'Childress, TX 79201',25862,222,NULL,51,35618,0);
INSERT INTO "django_geo_db_location" VALUES(61774,NULL,'Afton, TX',25863,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61775,NULL,'Afton, TX 79220',25863,222,NULL,51,35619,0);
INSERT INTO "django_geo_db_location" VALUES(61776,NULL,'Aiken, TX',25864,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61777,NULL,'Aiken, TX 79221',25864,222,NULL,51,35620,0);
INSERT INTO "django_geo_db_location" VALUES(61778,NULL,'Carey, TX',25865,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61779,NULL,'Carey, TX 79222',25865,222,NULL,51,35621,0);
INSERT INTO "django_geo_db_location" VALUES(61780,NULL,'Cee Vee, TX',25866,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61781,NULL,'Cee Vee, TX 79223',25866,222,NULL,51,35622,0);
INSERT INTO "django_geo_db_location" VALUES(61782,NULL,'Chalk, TX',25867,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61783,NULL,'Chalk, TX 79224',25867,222,NULL,51,35623,0);
INSERT INTO "django_geo_db_location" VALUES(61784,NULL,'Chillicothe, TX',25868,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61785,NULL,'Chillicothe, TX 79225',25868,222,NULL,51,35624,0);
INSERT INTO "django_geo_db_location" VALUES(61786,NULL,'Clarendon, TX',25869,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61787,NULL,'Clarendon, TX 79226',25869,222,NULL,51,35625,0);
INSERT INTO "django_geo_db_location" VALUES(61788,NULL,'Crowell, TX',25870,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61789,NULL,'Crowell, TX 79227',25870,222,NULL,51,35626,0);
INSERT INTO "django_geo_db_location" VALUES(61790,NULL,'Dickens, TX',25871,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61791,NULL,'Dickens, TX 79229',25871,222,NULL,51,35627,0);
INSERT INTO "django_geo_db_location" VALUES(61792,NULL,'Dodson, TX',25872,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61793,NULL,'Dodson, TX 79230',25872,222,NULL,51,35628,0);
INSERT INTO "django_geo_db_location" VALUES(61794,NULL,'Dougherty, TX',25873,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61795,NULL,'Dougherty, TX 79231',25873,222,NULL,51,35629,0);
INSERT INTO "django_geo_db_location" VALUES(61796,NULL,'Dumont, TX',25874,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61797,NULL,'Dumont, TX 79232',25874,222,NULL,51,35630,0);
INSERT INTO "django_geo_db_location" VALUES(61798,NULL,'Estelline, TX',25875,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61799,NULL,'Estelline, TX 79233',25875,222,NULL,51,35631,0);
INSERT INTO "django_geo_db_location" VALUES(61800,NULL,'Flomot, TX',25876,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61801,NULL,'Flomot, TX 79234',25876,222,NULL,51,35632,0);
INSERT INTO "django_geo_db_location" VALUES(61802,NULL,'Floydada, TX',25877,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61803,NULL,'Floydada, TX 79235',25877,222,NULL,51,35633,0);
INSERT INTO "django_geo_db_location" VALUES(61804,NULL,'Guthrie, TX',25878,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61805,NULL,'Guthrie, TX 79236',25878,222,NULL,51,35634,0);
INSERT INTO "django_geo_db_location" VALUES(61806,NULL,'Hedley, TX',25879,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61807,NULL,'Hedley, TX 79237',25879,222,NULL,51,35635,0);
INSERT INTO "django_geo_db_location" VALUES(61808,NULL,'Kirkland, TX',25880,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61809,NULL,'Kirkland, TX 79238',25880,222,NULL,51,35636,0);
INSERT INTO "django_geo_db_location" VALUES(61810,NULL,'Lakeview, TX',25881,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61811,NULL,'Lakeview, TX 79239',25881,222,NULL,51,35637,0);
INSERT INTO "django_geo_db_location" VALUES(61812,NULL,'Lelia Lake, TX',25882,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61813,NULL,'Lelia Lake, TX 79240',25882,222,NULL,51,35638,0);
INSERT INTO "django_geo_db_location" VALUES(61814,NULL,'Lockney, TX',25883,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61815,NULL,'Lockney, TX 79241',25883,222,NULL,51,35639,0);
INSERT INTO "django_geo_db_location" VALUES(61816,NULL,'Mcadoo, TX',25884,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61817,NULL,'Mcadoo, TX 79243',25884,222,NULL,51,35640,0);
INSERT INTO "django_geo_db_location" VALUES(61818,NULL,'Matador, TX',25885,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61819,NULL,'Matador, TX 79244',25885,222,NULL,51,35641,0);
INSERT INTO "django_geo_db_location" VALUES(61820,NULL,'Memphis, TX',25886,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61821,NULL,'Memphis, TX 79245',25886,222,NULL,51,35642,0);
INSERT INTO "django_geo_db_location" VALUES(61822,NULL,'Odell, TX',25887,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61823,NULL,'Odell, TX 79247',25887,222,NULL,51,35643,0);
INSERT INTO "django_geo_db_location" VALUES(61824,NULL,'Paducah, TX',25888,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61825,NULL,'Paducah, TX 79248',25888,222,NULL,51,35644,0);
INSERT INTO "django_geo_db_location" VALUES(61826,NULL,'Petersburg, TX',25889,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61827,NULL,'Petersburg, TX 79250',25889,222,NULL,51,35645,0);
INSERT INTO "django_geo_db_location" VALUES(61828,NULL,'Quail, TX',25890,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61829,NULL,'Quail, TX 79251',25890,222,NULL,51,35646,0);
INSERT INTO "django_geo_db_location" VALUES(61830,NULL,'Quanah, TX',25891,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61831,NULL,'Quanah, TX 79252',25891,222,NULL,51,35647,0);
INSERT INTO "django_geo_db_location" VALUES(61832,NULL,'Quitaque, TX',25892,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61833,NULL,'Quitaque, TX 79255',25892,222,NULL,51,35648,0);
INSERT INTO "django_geo_db_location" VALUES(61834,NULL,'Roaring Springs, TX',25893,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61835,NULL,'Roaring Springs, TX 79256',25893,222,NULL,51,35649,0);
INSERT INTO "django_geo_db_location" VALUES(61836,NULL,'Silverton, TX',25894,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61837,NULL,'Silverton, TX 79257',25894,222,NULL,51,35650,0);
INSERT INTO "django_geo_db_location" VALUES(61838,NULL,'South Plains, TX',25895,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61839,NULL,'South Plains, TX 79258',25895,222,NULL,51,35651,0);
INSERT INTO "django_geo_db_location" VALUES(61840,NULL,'Tell, TX',25896,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61841,NULL,'Tell, TX 79259',25896,222,NULL,51,35652,0);
INSERT INTO "django_geo_db_location" VALUES(61842,NULL,'Turkey, TX',25897,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61843,NULL,'Turkey, TX 79261',25897,222,NULL,51,35653,0);
INSERT INTO "django_geo_db_location" VALUES(61844,NULL,'Earth, TX 79301',25811,222,NULL,51,35654,0);
INSERT INTO "django_geo_db_location" VALUES(61845,NULL,'Abernathy, TX',25898,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61846,NULL,'Abernathy, TX 79311',25898,222,NULL,51,35655,0);
INSERT INTO "django_geo_db_location" VALUES(61847,NULL,'Amherst, TX',25899,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61848,NULL,'Amherst, TX 79312',25899,222,NULL,51,35656,0);
INSERT INTO "django_geo_db_location" VALUES(61849,NULL,'Anton, TX',25900,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61850,NULL,'Anton, TX 79313',25900,222,NULL,51,35657,0);
INSERT INTO "django_geo_db_location" VALUES(61851,NULL,'Bledsoe, TX',25901,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61852,NULL,'Bledsoe, TX 79314',25901,222,NULL,51,35658,0);
INSERT INTO "django_geo_db_location" VALUES(61853,NULL,'Brownfield, TX',25902,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61854,NULL,'Brownfield, TX 79316',25902,222,NULL,51,35659,0);
INSERT INTO "django_geo_db_location" VALUES(61855,NULL,'Bula, TX',25903,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61856,NULL,'Bula, TX 79320',25903,222,NULL,51,35660,0);
INSERT INTO "django_geo_db_location" VALUES(61857,NULL,'Sudan, TX',25904,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61858,NULL,'Sudan, TX 79321',25904,222,NULL,51,35661,0);
INSERT INTO "django_geo_db_location" VALUES(61859,NULL,'Crosbyton, TX',25905,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61860,NULL,'Crosbyton, TX 79322',25905,222,NULL,51,35662,0);
INSERT INTO "django_geo_db_location" VALUES(61861,NULL,'Denver City, TX',25906,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61862,NULL,'Denver City, TX 79323',25906,222,NULL,51,35663,0);
INSERT INTO "django_geo_db_location" VALUES(61863,NULL,'Enochs, TX',25907,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61864,NULL,'Enochs, TX 79324',25907,222,NULL,51,35664,0);
INSERT INTO "django_geo_db_location" VALUES(61865,NULL,'Farwell, TX',25908,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61866,NULL,'Farwell, TX 79325',25908,222,NULL,51,35665,0);
INSERT INTO "django_geo_db_location" VALUES(61867,NULL,'Fieldton, TX',25909,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61868,NULL,'Fieldton, TX 79326',25909,222,NULL,51,35666,0);
INSERT INTO "django_geo_db_location" VALUES(61869,NULL,'Idalou, TX',25910,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61870,NULL,'Idalou, TX 79329',25910,222,NULL,51,35667,0);
INSERT INTO "django_geo_db_location" VALUES(61871,NULL,'Justiceburg, TX',25911,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61872,NULL,'Justiceburg, TX 79330',25911,222,NULL,51,35668,0);
INSERT INTO "django_geo_db_location" VALUES(61873,NULL,'Lamesa, TX',25912,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61874,NULL,'Lamesa, TX 79331',25912,222,NULL,51,35669,0);
INSERT INTO "django_geo_db_location" VALUES(61875,NULL,'Levelland, TX',25913,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61876,NULL,'Levelland, TX 79336',25913,222,NULL,51,35670,0);
INSERT INTO "django_geo_db_location" VALUES(61877,NULL,'Levelland, TX 79338',25913,222,NULL,51,35671,0);
INSERT INTO "django_geo_db_location" VALUES(61878,NULL,'Littlefield, TX',25914,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61879,NULL,'Littlefield, TX 79339',25914,222,NULL,51,35672,0);
INSERT INTO "django_geo_db_location" VALUES(61880,NULL,'Loop, TX',25915,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61881,NULL,'Loop, TX 79342',25915,222,NULL,51,35673,0);
INSERT INTO "django_geo_db_location" VALUES(61882,NULL,'Lorenzo, TX',25916,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61883,NULL,'Lorenzo, TX 79343',25916,222,NULL,51,35674,0);
INSERT INTO "django_geo_db_location" VALUES(61884,NULL,'Maple, TX',25917,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61885,NULL,'Maple, TX 79344',25917,222,NULL,51,35675,0);
INSERT INTO "django_geo_db_location" VALUES(61886,NULL,'Meadow, TX',25918,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61887,NULL,'Meadow, TX 79345',25918,222,NULL,51,35676,0);
INSERT INTO "django_geo_db_location" VALUES(61888,NULL,'Morton, TX',25919,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61889,NULL,'Morton, TX 79346',25919,222,NULL,51,35677,0);
INSERT INTO "django_geo_db_location" VALUES(61890,NULL,'Muleshoe, TX',25920,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61891,NULL,'Muleshoe, TX 79347',25920,222,NULL,51,35678,0);
INSERT INTO "django_geo_db_location" VALUES(61892,NULL,'New Deal, TX',25921,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61893,NULL,'New Deal, TX 79350',25921,222,NULL,51,35679,0);
INSERT INTO "django_geo_db_location" VALUES(61894,NULL,'Odonnell, TX',25922,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61895,NULL,'Odonnell, TX 79351',25922,222,NULL,51,35680,0);
INSERT INTO "django_geo_db_location" VALUES(61896,NULL,'Pep, TX',25923,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61897,NULL,'Pep, TX 79353',25923,222,NULL,51,35681,0);
INSERT INTO "django_geo_db_location" VALUES(61898,NULL,'Plains, TX',25924,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61899,NULL,'Plains, TX 79355',25924,222,NULL,51,35682,0);
INSERT INTO "django_geo_db_location" VALUES(61900,NULL,'Post, TX',25925,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61901,NULL,'Post, TX 79356',25925,222,NULL,51,35683,0);
INSERT INTO "django_geo_db_location" VALUES(61902,NULL,'Ralls, TX',25926,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61903,NULL,'Ralls, TX 79357',25926,222,NULL,51,35684,0);
INSERT INTO "django_geo_db_location" VALUES(61904,NULL,'Ropesville, TX',25927,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61905,NULL,'Ropesville, TX 79358',25927,222,NULL,51,35685,0);
INSERT INTO "django_geo_db_location" VALUES(61906,NULL,'Seagraves, TX',25928,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61907,NULL,'Seagraves, TX 79359',25928,222,NULL,51,35686,0);
INSERT INTO "django_geo_db_location" VALUES(61908,NULL,'Seminole, TX',25929,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61909,NULL,'Seminole, TX 79360',25929,222,NULL,51,35687,0);
INSERT INTO "django_geo_db_location" VALUES(61910,NULL,'Shallowater, TX',25930,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61911,NULL,'Shallowater, TX 79363',25930,222,NULL,51,35688,0);
INSERT INTO "django_geo_db_location" VALUES(61912,NULL,'Slaton, TX',25931,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61913,NULL,'Slaton, TX 79364',25931,222,NULL,51,35689,0);
INSERT INTO "django_geo_db_location" VALUES(61914,NULL,'Ransom Canyon, TX',25932,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61915,NULL,'Ransom Canyon, TX 79366',25932,222,NULL,51,35690,0);
INSERT INTO "django_geo_db_location" VALUES(61916,NULL,'Smyer, TX',25933,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61917,NULL,'Smyer, TX 79367',25933,222,NULL,51,35691,0);
INSERT INTO "django_geo_db_location" VALUES(61918,NULL,'Seminole, TX 79368',25929,222,NULL,51,35692,0);
INSERT INTO "django_geo_db_location" VALUES(61919,NULL,'Spade, TX',25934,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61920,NULL,'Spade, TX 79369',25934,222,NULL,51,35693,0);
INSERT INTO "django_geo_db_location" VALUES(61921,NULL,'Spur, TX',25935,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61922,NULL,'Spur, TX 79370',25935,222,NULL,51,35694,0);
INSERT INTO "django_geo_db_location" VALUES(61923,NULL,'Sudan, TX 79371',25904,222,NULL,51,35695,0);
INSERT INTO "django_geo_db_location" VALUES(61924,NULL,'Sundown, TX',25936,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61925,NULL,'Sundown, TX 79372',25936,222,NULL,51,35696,0);
INSERT INTO "django_geo_db_location" VALUES(61926,NULL,'Tahoka, TX',25937,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61927,NULL,'Tahoka, TX 79373',25937,222,NULL,51,35697,0);
INSERT INTO "django_geo_db_location" VALUES(61928,NULL,'Tokio, TX',25938,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61929,NULL,'Tokio, TX 79376',25938,222,NULL,51,35698,0);
INSERT INTO "django_geo_db_location" VALUES(61930,NULL,'Welch, TX',25939,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61931,NULL,'Welch, TX 79377',25939,222,NULL,51,35699,0);
INSERT INTO "django_geo_db_location" VALUES(61932,NULL,'Wellman, TX',25940,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61933,NULL,'Wellman, TX 79378',25940,222,NULL,51,35700,0);
INSERT INTO "django_geo_db_location" VALUES(61934,NULL,'Whiteface, TX',25941,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61935,NULL,'Whiteface, TX 79379',25941,222,NULL,51,35701,0);
INSERT INTO "django_geo_db_location" VALUES(61936,NULL,'Whitharral, TX',25942,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61937,NULL,'Whitharral, TX 79380',25942,222,NULL,51,35702,0);
INSERT INTO "django_geo_db_location" VALUES(61938,NULL,'Wilson, TX',25943,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61939,NULL,'Wilson, TX 79381',25943,222,NULL,51,35703,0);
INSERT INTO "django_geo_db_location" VALUES(61940,NULL,'Wolfforth, TX',25944,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61941,NULL,'Wolfforth, TX 79382',25944,222,NULL,51,35704,0);
INSERT INTO "django_geo_db_location" VALUES(61942,NULL,'New Home, TX',25945,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61943,NULL,'New Home, TX 79383',25945,222,NULL,51,35705,0);
INSERT INTO "django_geo_db_location" VALUES(61944,NULL,'Lubbock, TX',25946,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61945,NULL,'Lubbock, TX 79401',25946,222,NULL,51,35706,0);
INSERT INTO "django_geo_db_location" VALUES(61946,NULL,'Lubbock, TX 79402',25946,222,NULL,51,35707,0);
INSERT INTO "django_geo_db_location" VALUES(61947,NULL,'Lubbock, TX 79403',25946,222,NULL,51,35708,0);
INSERT INTO "django_geo_db_location" VALUES(61948,NULL,'Lubbock, TX 79404',25946,222,NULL,51,35709,0);
INSERT INTO "django_geo_db_location" VALUES(61949,NULL,'Lubbock, TX 79405',25946,222,NULL,51,35710,0);
INSERT INTO "django_geo_db_location" VALUES(61950,NULL,'Lubbock, TX 79406',25946,222,NULL,51,35711,0);
INSERT INTO "django_geo_db_location" VALUES(61951,NULL,'Lubbock, TX 79407',25946,222,NULL,51,35712,0);
INSERT INTO "django_geo_db_location" VALUES(61952,NULL,'Lubbock, TX 79408',25946,222,NULL,51,35713,0);
INSERT INTO "django_geo_db_location" VALUES(61953,NULL,'Lubbock, TX 79409',25946,222,NULL,51,35714,0);
INSERT INTO "django_geo_db_location" VALUES(61954,NULL,'Lubbock, TX 79410',25946,222,NULL,51,35715,0);
INSERT INTO "django_geo_db_location" VALUES(61955,NULL,'Lubbock, TX 79411',25946,222,NULL,51,35716,0);
INSERT INTO "django_geo_db_location" VALUES(61956,NULL,'Lubbock, TX 79412',25946,222,NULL,51,35717,0);
INSERT INTO "django_geo_db_location" VALUES(61957,NULL,'Lubbock, TX 79413',25946,222,NULL,51,35718,0);
INSERT INTO "django_geo_db_location" VALUES(61958,NULL,'Lubbock, TX 79414',25946,222,NULL,51,35719,0);
INSERT INTO "django_geo_db_location" VALUES(61959,NULL,'Lubbock, TX 79415',25946,222,NULL,51,35720,0);
INSERT INTO "django_geo_db_location" VALUES(61960,NULL,'Lubbock, TX 79416',25946,222,NULL,51,35721,0);
INSERT INTO "django_geo_db_location" VALUES(61961,NULL,'Lubbock, TX 79423',25946,222,NULL,51,35722,0);
INSERT INTO "django_geo_db_location" VALUES(61962,NULL,'Lubbock, TX 79424',25946,222,NULL,51,35723,0);
INSERT INTO "django_geo_db_location" VALUES(61963,NULL,'Lubbock, TX 79430',25946,222,NULL,51,35724,0);
INSERT INTO "django_geo_db_location" VALUES(61964,NULL,'Lubbock, TX 79452',25946,222,NULL,51,35725,0);
INSERT INTO "django_geo_db_location" VALUES(61965,NULL,'Lubbock, TX 79453',25946,222,NULL,51,35726,0);
INSERT INTO "django_geo_db_location" VALUES(61966,NULL,'Lubbock, TX 79457',25946,222,NULL,51,35727,0);
INSERT INTO "django_geo_db_location" VALUES(61967,NULL,'Lubbock, TX 79464',25946,222,NULL,51,35728,0);
INSERT INTO "django_geo_db_location" VALUES(61968,NULL,'Lubbock, TX 79490',25946,222,NULL,51,35729,0);
INSERT INTO "django_geo_db_location" VALUES(61969,NULL,'Lubbock, TX 79491',25946,222,NULL,51,35730,0);
INSERT INTO "django_geo_db_location" VALUES(61970,NULL,'Lubbock, TX 79493',25946,222,NULL,51,35731,0);
INSERT INTO "django_geo_db_location" VALUES(61971,NULL,'Lubbock, TX 79499',25946,222,NULL,51,35732,0);
INSERT INTO "django_geo_db_location" VALUES(61972,NULL,'Anson, TX',25947,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61973,NULL,'Anson, TX 79501',25947,222,NULL,51,35733,0);
INSERT INTO "django_geo_db_location" VALUES(61974,NULL,'Aspermont, TX',25948,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61975,NULL,'Aspermont, TX 79502',25948,222,NULL,51,35734,0);
INSERT INTO "django_geo_db_location" VALUES(61976,NULL,'Avoca, TX',25949,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61977,NULL,'Avoca, TX 79503',25949,222,NULL,51,35735,0);
INSERT INTO "django_geo_db_location" VALUES(61978,NULL,'Baird, TX',25950,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61979,NULL,'Baird, TX 79504',25950,222,NULL,51,35736,0);
INSERT INTO "django_geo_db_location" VALUES(61980,NULL,'Benjamin, TX',25951,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61981,NULL,'Benjamin, TX 79505',25951,222,NULL,51,35737,0);
INSERT INTO "django_geo_db_location" VALUES(61982,NULL,'Blackwell, TX',25952,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61983,NULL,'Blackwell, TX 79506',25952,222,NULL,51,35738,0);
INSERT INTO "django_geo_db_location" VALUES(61984,NULL,'Buffalo Gap, TX',25953,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61985,NULL,'Buffalo Gap, TX 79508',25953,222,NULL,51,35739,0);
INSERT INTO "django_geo_db_location" VALUES(61986,NULL,'Clyde, TX',25954,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61987,NULL,'Clyde, TX 79510',25954,222,NULL,51,35740,0);
INSERT INTO "django_geo_db_location" VALUES(61988,NULL,'Coahoma, TX',25955,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61989,NULL,'Coahoma, TX 79511',25955,222,NULL,51,35741,0);
INSERT INTO "django_geo_db_location" VALUES(61990,NULL,'Colorado City, TX',25956,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61991,NULL,'Colorado City, TX 79512',25956,222,NULL,51,35742,0);
INSERT INTO "django_geo_db_location" VALUES(61992,NULL,'Dunn, TX',25957,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61993,NULL,'Dunn, TX 79516',25957,222,NULL,51,35743,0);
INSERT INTO "django_geo_db_location" VALUES(61994,NULL,'Fluvanna, TX',25958,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61995,NULL,'Fluvanna, TX 79517',25958,222,NULL,51,35744,0);
INSERT INTO "django_geo_db_location" VALUES(61996,NULL,'Girard, TX',25959,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61997,NULL,'Girard, TX 79518',25959,222,NULL,51,35745,0);
INSERT INTO "django_geo_db_location" VALUES(61998,NULL,'Goldsboro, TX',25960,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(61999,NULL,'Goldsboro, TX 79519',25960,222,NULL,51,35746,0);
INSERT INTO "django_geo_db_location" VALUES(62000,NULL,'Hamlin, TX',25961,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62001,NULL,'Hamlin, TX 79520',25961,222,NULL,51,35747,0);
INSERT INTO "django_geo_db_location" VALUES(62002,NULL,'Haskell, TX',25962,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62003,NULL,'Haskell, TX 79521',25962,222,NULL,51,35748,0);
INSERT INTO "django_geo_db_location" VALUES(62004,NULL,'Hawley, TX',25963,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62005,NULL,'Hawley, TX 79525',25963,222,NULL,51,35749,0);
INSERT INTO "django_geo_db_location" VALUES(62006,NULL,'Hermleigh, TX',25964,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62007,NULL,'Hermleigh, TX 79526',25964,222,NULL,51,35750,0);
INSERT INTO "django_geo_db_location" VALUES(62008,NULL,'Ira, TX',25965,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62009,NULL,'Ira, TX 79527',25965,222,NULL,51,35751,0);
INSERT INTO "django_geo_db_location" VALUES(62010,NULL,'Jayton, TX',25966,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62011,NULL,'Jayton, TX 79528',25966,222,NULL,51,35752,0);
INSERT INTO "django_geo_db_location" VALUES(62012,NULL,'Knox City, TX',25967,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62013,NULL,'Knox City, TX 79529',25967,222,NULL,51,35753,0);
INSERT INTO "django_geo_db_location" VALUES(62014,NULL,'Lawn, TX',25968,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62015,NULL,'Lawn, TX 79530',25968,222,NULL,51,35754,0);
INSERT INTO "django_geo_db_location" VALUES(62016,NULL,'Loraine, TX',25969,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62017,NULL,'Loraine, TX 79532',25969,222,NULL,51,35755,0);
INSERT INTO "django_geo_db_location" VALUES(62018,NULL,'Lueders, TX',25970,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62019,NULL,'Lueders, TX 79533',25970,222,NULL,51,35756,0);
INSERT INTO "django_geo_db_location" VALUES(62020,NULL,'McCaulley, TX',25971,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62021,NULL,'McCaulley, TX 79534',25971,222,NULL,51,35757,0);
INSERT INTO "django_geo_db_location" VALUES(62022,NULL,'Maryneal, TX',25972,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62023,NULL,'Maryneal, TX 79535',25972,222,NULL,51,35758,0);
INSERT INTO "django_geo_db_location" VALUES(62024,NULL,'Merkel, TX',25973,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62025,NULL,'Merkel, TX 79536',25973,222,NULL,51,35759,0);
INSERT INTO "django_geo_db_location" VALUES(62026,NULL,'Nolan, TX',25974,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62027,NULL,'Nolan, TX 79537',25974,222,NULL,51,35760,0);
INSERT INTO "django_geo_db_location" VALUES(62028,NULL,'Novice, TX',25975,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62029,NULL,'Novice, TX 79538',25975,222,NULL,51,35761,0);
INSERT INTO "django_geo_db_location" VALUES(62030,NULL,'O Brien, TX',25976,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62031,NULL,'O Brien, TX 79539',25976,222,NULL,51,35762,0);
INSERT INTO "django_geo_db_location" VALUES(62032,NULL,'Old Glory, TX',25977,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62033,NULL,'Old Glory, TX 79540',25977,222,NULL,51,35763,0);
INSERT INTO "django_geo_db_location" VALUES(62034,NULL,'Ovalo, TX',25978,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62035,NULL,'Ovalo, TX 79541',25978,222,NULL,51,35764,0);
INSERT INTO "django_geo_db_location" VALUES(62036,NULL,'Roby, TX',25979,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62037,NULL,'Roby, TX 79543',25979,222,NULL,51,35765,0);
INSERT INTO "django_geo_db_location" VALUES(62038,NULL,'Rochester, TX',25980,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62039,NULL,'Rochester, TX 79544',25980,222,NULL,51,35766,0);
INSERT INTO "django_geo_db_location" VALUES(62040,NULL,'Roscoe, TX',25981,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62041,NULL,'Roscoe, TX 79545',25981,222,NULL,51,35767,0);
INSERT INTO "django_geo_db_location" VALUES(62042,NULL,'Rotan, TX',25982,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62043,NULL,'Rotan, TX 79546',25982,222,NULL,51,35768,0);
INSERT INTO "django_geo_db_location" VALUES(62044,NULL,'Rule, TX',25983,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62045,NULL,'Rule, TX 79547',25983,222,NULL,51,35769,0);
INSERT INTO "django_geo_db_location" VALUES(62046,NULL,'Rule, TX 79548',25983,222,NULL,51,35770,0);
INSERT INTO "django_geo_db_location" VALUES(62047,NULL,'Snyder, TX',25984,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62048,NULL,'Snyder, TX 79549',25984,222,NULL,51,35771,0);
INSERT INTO "django_geo_db_location" VALUES(62049,NULL,'Snyder, TX 79550',25984,222,NULL,51,35772,0);
INSERT INTO "django_geo_db_location" VALUES(62050,NULL,'Stamford, TX',25985,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62051,NULL,'Stamford, TX 79552',25985,222,NULL,51,35773,0);
INSERT INTO "django_geo_db_location" VALUES(62052,NULL,'Stamford, TX 79553',25985,222,NULL,51,35774,0);
INSERT INTO "django_geo_db_location" VALUES(62053,NULL,'Sweetwater, TX',25986,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62054,NULL,'Sweetwater, TX 79556',25986,222,NULL,51,35775,0);
INSERT INTO "django_geo_db_location" VALUES(62055,NULL,'Sylvester, TX',25987,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62056,NULL,'Sylvester, TX 79560',25987,222,NULL,51,35776,0);
INSERT INTO "django_geo_db_location" VALUES(62057,NULL,'Trent, TX',25988,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62058,NULL,'Trent, TX 79561',25988,222,NULL,51,35777,0);
INSERT INTO "django_geo_db_location" VALUES(62059,NULL,'Tuscola, TX',25989,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62060,NULL,'Tuscola, TX 79562',25989,222,NULL,51,35778,0);
INSERT INTO "django_geo_db_location" VALUES(62061,NULL,'Tye, TX',25990,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62062,NULL,'Tye, TX 79563',25990,222,NULL,51,35779,0);
INSERT INTO "django_geo_db_location" VALUES(62063,NULL,'Westbrook, TX',25991,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62064,NULL,'Westbrook, TX 79565',25991,222,NULL,51,35780,0);
INSERT INTO "django_geo_db_location" VALUES(62065,NULL,'Wingate, TX',25992,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62066,NULL,'Wingate, TX 79566',25992,222,NULL,51,35781,0);
INSERT INTO "django_geo_db_location" VALUES(62067,NULL,'Winters, TX',25993,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62068,NULL,'Winters, TX 79567',25993,222,NULL,51,35782,0);
INSERT INTO "django_geo_db_location" VALUES(62069,NULL,'Haskell, TX 79571',25962,222,NULL,51,35783,0);
INSERT INTO "django_geo_db_location" VALUES(62070,NULL,'Abilene, TX',25994,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62071,NULL,'Abilene, TX 79601',25994,222,NULL,51,35784,0);
INSERT INTO "django_geo_db_location" VALUES(62072,NULL,'Abilene, TX 79602',25994,222,NULL,51,35785,0);
INSERT INTO "django_geo_db_location" VALUES(62073,NULL,'Abilene, TX 79603',25994,222,NULL,51,35786,0);
INSERT INTO "django_geo_db_location" VALUES(62074,NULL,'Abilene, TX 79604',25994,222,NULL,51,35787,0);
INSERT INTO "django_geo_db_location" VALUES(62075,NULL,'Abilene, TX 79605',25994,222,NULL,51,35788,0);
INSERT INTO "django_geo_db_location" VALUES(62076,NULL,'Abilene, TX 79606',25994,222,NULL,51,35789,0);
INSERT INTO "django_geo_db_location" VALUES(62077,NULL,'Dyess AFB, TX',25995,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62078,NULL,'Dyess AFB, TX 79607',25995,222,NULL,51,35790,0);
INSERT INTO "django_geo_db_location" VALUES(62079,NULL,'Abilene, TX 79608',25994,222,NULL,51,35791,0);
INSERT INTO "django_geo_db_location" VALUES(62080,NULL,'Ozona, TX 79643',25214,222,NULL,51,35792,0);
INSERT INTO "django_geo_db_location" VALUES(62081,NULL,'Abilene, TX 79697',25994,222,NULL,51,35793,0);
INSERT INTO "django_geo_db_location" VALUES(62082,NULL,'Abilene, TX 79698',25994,222,NULL,51,35794,0);
INSERT INTO "django_geo_db_location" VALUES(62083,NULL,'Abilene, TX 79699',25994,222,NULL,51,35795,0);
INSERT INTO "django_geo_db_location" VALUES(62084,NULL,'Midland, TX',25996,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62085,NULL,'Midland, TX 79701',25996,222,NULL,51,35796,0);
INSERT INTO "django_geo_db_location" VALUES(62086,NULL,'Midland, TX 79702',25996,222,NULL,51,35797,0);
INSERT INTO "django_geo_db_location" VALUES(62087,NULL,'Midland, TX 79703',25996,222,NULL,51,35798,0);
INSERT INTO "django_geo_db_location" VALUES(62088,NULL,'Midland, TX 79704',25996,222,NULL,51,35799,0);
INSERT INTO "django_geo_db_location" VALUES(62089,NULL,'Midland, TX 79705',25996,222,NULL,51,35800,0);
INSERT INTO "django_geo_db_location" VALUES(62090,NULL,'Midland, TX 79706',25996,222,NULL,51,35801,0);
INSERT INTO "django_geo_db_location" VALUES(62091,NULL,'Midland, TX 79707',25996,222,NULL,51,35802,0);
INSERT INTO "django_geo_db_location" VALUES(62092,NULL,'Midland, TX 79708',25996,222,NULL,51,35803,0);
INSERT INTO "django_geo_db_location" VALUES(62093,NULL,'Midland, TX 79710',25996,222,NULL,51,35804,0);
INSERT INTO "django_geo_db_location" VALUES(62094,NULL,'Midland, TX 79711',25996,222,NULL,51,35805,0);
INSERT INTO "django_geo_db_location" VALUES(62095,NULL,'Midland, TX 79712',25996,222,NULL,51,35806,0);
INSERT INTO "django_geo_db_location" VALUES(62096,NULL,'Ackerly, TX',25997,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62097,NULL,'Ackerly, TX 79713',25997,222,NULL,51,35807,0);
INSERT INTO "django_geo_db_location" VALUES(62098,NULL,'Andrews, TX',25998,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62099,NULL,'Andrews, TX 79714',25998,222,NULL,51,35808,0);
INSERT INTO "django_geo_db_location" VALUES(62100,NULL,'Balmorhea, TX',25999,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62101,NULL,'Balmorhea, TX 79718',25999,222,NULL,51,35809,0);
INSERT INTO "django_geo_db_location" VALUES(62102,NULL,'Barstow, TX',26000,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62103,NULL,'Barstow, TX 79719',26000,222,NULL,51,35810,0);
INSERT INTO "django_geo_db_location" VALUES(62104,NULL,'Big Spring, TX',26001,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62105,NULL,'Big Spring, TX 79720',26001,222,NULL,51,35811,0);
INSERT INTO "django_geo_db_location" VALUES(62106,NULL,'Big Spring, TX 79721',26001,222,NULL,51,35812,0);
INSERT INTO "django_geo_db_location" VALUES(62107,NULL,'Coyanosa, TX',26002,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62108,NULL,'Coyanosa, TX 79730',26002,222,NULL,51,35813,0);
INSERT INTO "django_geo_db_location" VALUES(62109,NULL,'Crane, TX',26003,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62110,NULL,'Crane, TX 79731',26003,222,NULL,51,35814,0);
INSERT INTO "django_geo_db_location" VALUES(62111,NULL,'Forsan, TX',26004,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62112,NULL,'Forsan, TX 79733',26004,222,NULL,51,35815,0);
INSERT INTO "django_geo_db_location" VALUES(62113,NULL,'Fort Davis, TX',26005,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62114,NULL,'Fort Davis, TX 79734',26005,222,NULL,51,35816,0);
INSERT INTO "django_geo_db_location" VALUES(62115,NULL,'Fort Stockton, TX',26006,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62116,NULL,'Fort Stockton, TX 79735',26006,222,NULL,51,35817,0);
INSERT INTO "django_geo_db_location" VALUES(62117,NULL,'Gail, TX',26007,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62118,NULL,'Gail, TX 79738',26007,222,NULL,51,35818,0);
INSERT INTO "django_geo_db_location" VALUES(62119,NULL,'Garden City, TX',26008,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62120,NULL,'Garden City, TX 79739',26008,222,NULL,51,35819,0);
INSERT INTO "django_geo_db_location" VALUES(62121,NULL,'Girvin, TX',26009,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62122,NULL,'Girvin, TX 79740',26009,222,NULL,51,35820,0);
INSERT INTO "django_geo_db_location" VALUES(62123,NULL,'Goldsmith, TX',26010,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62124,NULL,'Goldsmith, TX 79741',26010,222,NULL,51,35821,0);
INSERT INTO "django_geo_db_location" VALUES(62125,NULL,'Grandfalls, TX',26011,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62126,NULL,'Grandfalls, TX 79742',26011,222,NULL,51,35822,0);
INSERT INTO "django_geo_db_location" VALUES(62127,NULL,'Imperial, TX',26012,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62128,NULL,'Imperial, TX 79743',26012,222,NULL,51,35823,0);
INSERT INTO "django_geo_db_location" VALUES(62129,NULL,'Iraan, TX',26013,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62130,NULL,'Iraan, TX 79744',26013,222,NULL,51,35824,0);
INSERT INTO "django_geo_db_location" VALUES(62131,NULL,'Kermit, TX',26014,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62132,NULL,'Kermit, TX 79745',26014,222,NULL,51,35825,0);
INSERT INTO "django_geo_db_location" VALUES(62133,NULL,'Knott, TX',26015,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62134,NULL,'Knott, TX 79748',26015,222,NULL,51,35826,0);
INSERT INTO "django_geo_db_location" VALUES(62135,NULL,'Lenorah, TX',26016,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62136,NULL,'Lenorah, TX 79749',26016,222,NULL,51,35827,0);
INSERT INTO "django_geo_db_location" VALUES(62137,NULL,'McCamey, TX',26017,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62138,NULL,'McCamey, TX 79752',26017,222,NULL,51,35828,0);
INSERT INTO "django_geo_db_location" VALUES(62139,NULL,'Mentone, TX',26018,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62140,NULL,'Mentone, TX 79754',26018,222,NULL,51,35829,0);
INSERT INTO "django_geo_db_location" VALUES(62141,NULL,'Midkiff, TX',26019,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62142,NULL,'Midkiff, TX 79755',26019,222,NULL,51,35830,0);
INSERT INTO "django_geo_db_location" VALUES(62143,NULL,'Monahans, TX',26020,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62144,NULL,'Monahans, TX 79756',26020,222,NULL,51,35831,0);
INSERT INTO "django_geo_db_location" VALUES(62145,NULL,'Wickett, TX',26021,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62146,NULL,'Wickett, TX 79757',26021,222,NULL,51,35832,0);
INSERT INTO "django_geo_db_location" VALUES(62147,NULL,'Gardendale, TX',26022,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62148,NULL,'Gardendale, TX 79758',26022,222,NULL,51,35833,0);
INSERT INTO "django_geo_db_location" VALUES(62149,NULL,'Notrees, TX',26023,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62150,NULL,'Notrees, TX 79759',26023,222,NULL,51,35834,0);
INSERT INTO "django_geo_db_location" VALUES(62151,NULL,'Odessa, TX',26024,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62152,NULL,'Odessa, TX 79760',26024,222,NULL,51,35835,0);
INSERT INTO "django_geo_db_location" VALUES(62153,NULL,'Odessa, TX 79761',26024,222,NULL,51,35836,0);
INSERT INTO "django_geo_db_location" VALUES(62154,NULL,'Odessa, TX 79762',26024,222,NULL,51,35837,0);
INSERT INTO "django_geo_db_location" VALUES(62155,NULL,'Odessa, TX 79763',26024,222,NULL,51,35838,0);
INSERT INTO "django_geo_db_location" VALUES(62156,NULL,'Odessa, TX 79764',26024,222,NULL,51,35839,0);
INSERT INTO "django_geo_db_location" VALUES(62157,NULL,'Odessa, TX 79765',26024,222,NULL,51,35840,0);
INSERT INTO "django_geo_db_location" VALUES(62158,NULL,'Odessa, TX 79766',26024,222,NULL,51,35841,0);
INSERT INTO "django_geo_db_location" VALUES(62159,NULL,'Odessa, TX 79768',26024,222,NULL,51,35842,0);
INSERT INTO "django_geo_db_location" VALUES(62160,NULL,'Odessa, TX 79769',26024,222,NULL,51,35843,0);
INSERT INTO "django_geo_db_location" VALUES(62161,NULL,'Orla, TX',26025,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62162,NULL,'Orla, TX 79770',26025,222,NULL,51,35844,0);
INSERT INTO "django_geo_db_location" VALUES(62163,NULL,'Pecos, TX',26026,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62164,NULL,'Pecos, TX 79772',26026,222,NULL,51,35845,0);
INSERT INTO "django_geo_db_location" VALUES(62165,NULL,'Penwell, TX',26027,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62166,NULL,'Penwell, TX 79776',26027,222,NULL,51,35846,0);
INSERT INTO "django_geo_db_location" VALUES(62167,NULL,'Pyote, TX',26028,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62168,NULL,'Pyote, TX 79777',26028,222,NULL,51,35847,0);
INSERT INTO "django_geo_db_location" VALUES(62169,NULL,'Rankin, TX',26029,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62170,NULL,'Rankin, TX 79778',26029,222,NULL,51,35848,0);
INSERT INTO "django_geo_db_location" VALUES(62171,NULL,'Royalty, TX',26030,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62172,NULL,'Royalty, TX 79779',26030,222,NULL,51,35849,0);
INSERT INTO "django_geo_db_location" VALUES(62173,NULL,'Saragosa, TX',26031,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62174,NULL,'Saragosa, TX 79780',26031,222,NULL,51,35850,0);
INSERT INTO "django_geo_db_location" VALUES(62175,NULL,'Sheffield, TX',26032,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62176,NULL,'Sheffield, TX 79781',26032,222,NULL,51,35851,0);
INSERT INTO "django_geo_db_location" VALUES(62177,NULL,'Stanton, TX',26033,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62178,NULL,'Stanton, TX 79782',26033,222,NULL,51,35852,0);
INSERT INTO "django_geo_db_location" VALUES(62179,NULL,'Tarzan, TX',26034,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62180,NULL,'Tarzan, TX 79783',26034,222,NULL,51,35853,0);
INSERT INTO "django_geo_db_location" VALUES(62181,NULL,'Toyah, TX',26035,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62182,NULL,'Toyah, TX 79785',26035,222,NULL,51,35854,0);
INSERT INTO "django_geo_db_location" VALUES(62183,NULL,'Toyahvale, TX',26036,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62184,NULL,'Toyahvale, TX 79786',26036,222,NULL,51,35855,0);
INSERT INTO "django_geo_db_location" VALUES(62185,NULL,'Wickett, TX 79788',26021,222,NULL,51,35856,0);
INSERT INTO "django_geo_db_location" VALUES(62186,NULL,'Wink, TX',26037,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62187,NULL,'Wink, TX 79789',26037,222,NULL,51,35857,0);
INSERT INTO "django_geo_db_location" VALUES(62188,NULL,'Anthony, TX',26038,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62189,NULL,'Anthony, TX 79821',26038,222,NULL,51,35858,0);
INSERT INTO "django_geo_db_location" VALUES(62190,NULL,'Alpine, TX',26039,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62191,NULL,'Alpine, TX 79830',26039,222,NULL,51,35859,0);
INSERT INTO "django_geo_db_location" VALUES(62192,NULL,'Alpine, TX 79831',26039,222,NULL,51,35860,0);
INSERT INTO "django_geo_db_location" VALUES(62193,NULL,'Alpine, TX 79832',26039,222,NULL,51,35861,0);
INSERT INTO "django_geo_db_location" VALUES(62194,NULL,'Big Bend National Park, TX',26040,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62195,NULL,'Big Bend National Park, TX 79834',26040,222,NULL,51,35862,0);
INSERT INTO "django_geo_db_location" VALUES(62196,NULL,'Canutillo, TX',26041,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62197,NULL,'Canutillo, TX 79835',26041,222,NULL,51,35863,0);
INSERT INTO "django_geo_db_location" VALUES(62198,NULL,'Clint, TX',26042,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62199,NULL,'Clint, TX 79836',26042,222,NULL,51,35864,0);
INSERT INTO "django_geo_db_location" VALUES(62200,NULL,'Dell City, TX',26043,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62201,NULL,'Dell City, TX 79837',26043,222,NULL,51,35865,0);
INSERT INTO "django_geo_db_location" VALUES(62202,NULL,'Fabens, TX',26044,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62203,NULL,'Fabens, TX 79838',26044,222,NULL,51,35866,0);
INSERT INTO "django_geo_db_location" VALUES(62204,NULL,'Fort Hancock, TX',26045,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62205,NULL,'Fort Hancock, TX 79839',26045,222,NULL,51,35867,0);
INSERT INTO "django_geo_db_location" VALUES(62206,NULL,'Sierra Blanca, TX',26046,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62207,NULL,'Sierra Blanca, TX 79841',26046,222,NULL,51,35868,0);
INSERT INTO "django_geo_db_location" VALUES(62208,NULL,'Marathon, TX',26047,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62209,NULL,'Marathon, TX 79842',26047,222,NULL,51,35869,0);
INSERT INTO "django_geo_db_location" VALUES(62210,NULL,'Marfa, TX',26048,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62211,NULL,'Marfa, TX 79843',26048,222,NULL,51,35870,0);
INSERT INTO "django_geo_db_location" VALUES(62212,NULL,'Presidio, TX',26049,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62213,NULL,'Presidio, TX 79845',26049,222,NULL,51,35871,0);
INSERT INTO "django_geo_db_location" VALUES(62214,NULL,'Redford, TX',26050,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62215,NULL,'Redford, TX 79846',26050,222,NULL,51,35872,0);
INSERT INTO "django_geo_db_location" VALUES(62216,NULL,'Salt Flat, TX',26051,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62217,NULL,'Salt Flat, TX 79847',26051,222,NULL,51,35873,0);
INSERT INTO "django_geo_db_location" VALUES(62218,NULL,'Sanderson, TX',26052,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62219,NULL,'Sanderson, TX 79848',26052,222,NULL,51,35874,0);
INSERT INTO "django_geo_db_location" VALUES(62220,NULL,'San Elizario, TX',26053,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62221,NULL,'San Elizario, TX 79849',26053,222,NULL,51,35875,0);
INSERT INTO "django_geo_db_location" VALUES(62222,NULL,'Shafter, TX',26054,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62223,NULL,'Shafter, TX 79850',26054,222,NULL,51,35876,0);
INSERT INTO "django_geo_db_location" VALUES(62224,NULL,'Sierra Blanca, TX 79851',26046,222,NULL,51,35877,0);
INSERT INTO "django_geo_db_location" VALUES(62225,NULL,'Terlingua, TX',26055,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62226,NULL,'Terlingua, TX 79852',26055,222,NULL,51,35878,0);
INSERT INTO "django_geo_db_location" VALUES(62227,NULL,'Tornillo, TX',26056,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62228,NULL,'Tornillo, TX 79853',26056,222,NULL,51,35879,0);
INSERT INTO "django_geo_db_location" VALUES(62229,NULL,'Valentine, TX',26057,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62230,NULL,'Valentine, TX 79854',26057,222,NULL,51,35880,0);
INSERT INTO "django_geo_db_location" VALUES(62231,NULL,'Van Horn, TX',26058,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62232,NULL,'Van Horn, TX 79855',26058,222,NULL,51,35881,0);
INSERT INTO "django_geo_db_location" VALUES(62233,NULL,'Fabens, TX 79858',26044,222,NULL,51,35882,0);
INSERT INTO "django_geo_db_location" VALUES(62234,NULL,'Alpine, TX 79870',26039,222,NULL,51,35883,0);
INSERT INTO "django_geo_db_location" VALUES(62235,NULL,'El Paso, TX',26059,222,NULL,51,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62236,NULL,'El Paso, TX 79901',26059,222,NULL,51,35884,0);
INSERT INTO "django_geo_db_location" VALUES(62237,NULL,'El Paso, TX 79902',26059,222,NULL,51,35885,0);
INSERT INTO "django_geo_db_location" VALUES(62238,NULL,'El Paso, TX 79903',26059,222,NULL,51,35886,0);
INSERT INTO "django_geo_db_location" VALUES(62239,NULL,'El Paso, TX 79904',26059,222,NULL,51,35887,0);
INSERT INTO "django_geo_db_location" VALUES(62240,NULL,'El Paso, TX 79905',26059,222,NULL,51,35888,0);
INSERT INTO "django_geo_db_location" VALUES(62241,NULL,'El Paso, TX 79906',26059,222,NULL,51,35889,0);
INSERT INTO "django_geo_db_location" VALUES(62242,NULL,'El Paso, TX 79907',26059,222,NULL,51,35890,0);
INSERT INTO "django_geo_db_location" VALUES(62243,NULL,'El Paso, TX 79908',26059,222,NULL,51,35891,0);
INSERT INTO "django_geo_db_location" VALUES(62244,NULL,'El Paso, TX 79910',26059,222,NULL,51,35892,0);
INSERT INTO "django_geo_db_location" VALUES(62245,NULL,'El Paso, TX 79911',26059,222,NULL,51,35893,0);
INSERT INTO "django_geo_db_location" VALUES(62246,NULL,'El Paso, TX 79912',26059,222,NULL,51,35894,0);
INSERT INTO "django_geo_db_location" VALUES(62247,NULL,'El Paso, TX 79913',26059,222,NULL,51,35895,0);
INSERT INTO "django_geo_db_location" VALUES(62248,NULL,'El Paso, TX 79914',26059,222,NULL,51,35896,0);
INSERT INTO "django_geo_db_location" VALUES(62249,NULL,'El Paso, TX 79915',26059,222,NULL,51,35897,0);
INSERT INTO "django_geo_db_location" VALUES(62250,NULL,'El Paso, TX 79916',26059,222,NULL,51,35898,0);
INSERT INTO "django_geo_db_location" VALUES(62251,NULL,'El Paso, TX 79917',26059,222,NULL,51,35899,0);
INSERT INTO "django_geo_db_location" VALUES(62252,NULL,'El Paso, TX 79918',26059,222,NULL,51,35900,0);
INSERT INTO "django_geo_db_location" VALUES(62253,NULL,'El Paso, TX 79920',26059,222,NULL,51,35901,0);
INSERT INTO "django_geo_db_location" VALUES(62254,NULL,'El Paso, NM',26060,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62255,NULL,'El Paso, NM 79922',26060,222,NULL,31,35902,0);
INSERT INTO "django_geo_db_location" VALUES(62256,NULL,'El Paso, TX 79923',26059,222,NULL,51,35903,0);
INSERT INTO "django_geo_db_location" VALUES(62257,NULL,'El Paso, TX 79924',26059,222,NULL,51,35904,0);
INSERT INTO "django_geo_db_location" VALUES(62258,NULL,'El Paso, TX 79925',26059,222,NULL,51,35905,0);
INSERT INTO "django_geo_db_location" VALUES(62259,NULL,'El Paso, TX 79926',26059,222,NULL,51,35906,0);
INSERT INTO "django_geo_db_location" VALUES(62260,NULL,'El Paso, TX 79927',26059,222,NULL,51,35907,0);
INSERT INTO "django_geo_db_location" VALUES(62261,NULL,'El Paso, TX 79928',26059,222,NULL,51,35908,0);
INSERT INTO "django_geo_db_location" VALUES(62262,NULL,'El Paso, TX 79929',26059,222,NULL,51,35909,0);
INSERT INTO "django_geo_db_location" VALUES(62263,NULL,'El Paso, TX 79930',26059,222,NULL,51,35910,0);
INSERT INTO "django_geo_db_location" VALUES(62264,NULL,'El Paso, TX 79931',26059,222,NULL,51,35911,0);
INSERT INTO "django_geo_db_location" VALUES(62265,NULL,'El Paso, TX 79932',26059,222,NULL,51,35912,0);
INSERT INTO "django_geo_db_location" VALUES(62266,NULL,'El Paso, TX 79934',26059,222,NULL,51,35913,0);
INSERT INTO "django_geo_db_location" VALUES(62267,NULL,'El Paso, TX 79935',26059,222,NULL,51,35914,0);
INSERT INTO "django_geo_db_location" VALUES(62268,NULL,'El Paso, TX 79936',26059,222,NULL,51,35915,0);
INSERT INTO "django_geo_db_location" VALUES(62269,NULL,'El Paso, TX 79937',26059,222,NULL,51,35916,0);
INSERT INTO "django_geo_db_location" VALUES(62270,NULL,'El Paso, TX 79938',26059,222,NULL,51,35917,0);
INSERT INTO "django_geo_db_location" VALUES(62271,NULL,'El Paso, TX 79940',26059,222,NULL,51,35918,0);
INSERT INTO "django_geo_db_location" VALUES(62272,NULL,'El Paso, TX 79941',26059,222,NULL,51,35919,0);
INSERT INTO "django_geo_db_location" VALUES(62273,NULL,'El Paso, TX 79942',26059,222,NULL,51,35920,0);
INSERT INTO "django_geo_db_location" VALUES(62274,NULL,'El Paso, TX 79943',26059,222,NULL,51,35921,0);
INSERT INTO "django_geo_db_location" VALUES(62275,NULL,'El Paso, TX 79944',26059,222,NULL,51,35922,0);
INSERT INTO "django_geo_db_location" VALUES(62276,NULL,'El Paso, TX 79945',26059,222,NULL,51,35923,0);
INSERT INTO "django_geo_db_location" VALUES(62277,NULL,'El Paso, TX 79946',26059,222,NULL,51,35924,0);
INSERT INTO "django_geo_db_location" VALUES(62278,NULL,'El Paso, TX 79947',26059,222,NULL,51,35925,0);
INSERT INTO "django_geo_db_location" VALUES(62279,NULL,'El Paso, TX 79948',26059,222,NULL,51,35926,0);
INSERT INTO "django_geo_db_location" VALUES(62280,NULL,'El Paso, TX 79949',26059,222,NULL,51,35927,0);
INSERT INTO "django_geo_db_location" VALUES(62281,NULL,'El Paso, TX 79950',26059,222,NULL,51,35928,0);
INSERT INTO "django_geo_db_location" VALUES(62282,NULL,'El Paso, TX 79951',26059,222,NULL,51,35929,0);
INSERT INTO "django_geo_db_location" VALUES(62283,NULL,'El Paso, TX 79952',26059,222,NULL,51,35930,0);
INSERT INTO "django_geo_db_location" VALUES(62284,NULL,'El Paso, TX 79953',26059,222,NULL,51,35931,0);
INSERT INTO "django_geo_db_location" VALUES(62285,NULL,'El Paso, TX 79954',26059,222,NULL,51,35932,0);
INSERT INTO "django_geo_db_location" VALUES(62286,NULL,'El Paso, TX 79955',26059,222,NULL,51,35933,0);
INSERT INTO "django_geo_db_location" VALUES(62287,NULL,'El Paso, TX 79958',26059,222,NULL,51,35934,0);
INSERT INTO "django_geo_db_location" VALUES(62288,NULL,'El Paso, TX 79960',26059,222,NULL,51,35935,0);
INSERT INTO "django_geo_db_location" VALUES(62289,NULL,'El Paso, TX 79961',26059,222,NULL,51,35936,0);
INSERT INTO "django_geo_db_location" VALUES(62290,NULL,'El Paso, TX 79966',26059,222,NULL,51,35937,0);
INSERT INTO "django_geo_db_location" VALUES(62291,NULL,'El Paso, TX 79968',26059,222,NULL,51,35938,0);
INSERT INTO "django_geo_db_location" VALUES(62292,NULL,'El Paso, TX 79973',26059,222,NULL,51,35939,0);
INSERT INTO "django_geo_db_location" VALUES(62293,NULL,'El Paso, TX 79974',26059,222,NULL,51,35940,0);
INSERT INTO "django_geo_db_location" VALUES(62294,NULL,'El Paso, TX 79975',26059,222,NULL,51,35941,0);
INSERT INTO "django_geo_db_location" VALUES(62295,NULL,'El Paso, TX 79976',26059,222,NULL,51,35942,0);
INSERT INTO "django_geo_db_location" VALUES(62296,NULL,'El Paso, TX 79977',26059,222,NULL,51,35943,0);
INSERT INTO "django_geo_db_location" VALUES(62297,NULL,'El Paso, TX 79978',26059,222,NULL,51,35944,0);
INSERT INTO "django_geo_db_location" VALUES(62298,NULL,'El Paso, TX 79980',26059,222,NULL,51,35945,0);
INSERT INTO "django_geo_db_location" VALUES(62299,NULL,'El Paso, TX 79982',26059,222,NULL,51,35946,0);
INSERT INTO "django_geo_db_location" VALUES(62300,NULL,'El Paso, TX 79983',26059,222,NULL,51,35947,0);
INSERT INTO "django_geo_db_location" VALUES(62301,NULL,'El Paso, TX 79984',26059,222,NULL,51,35948,0);
INSERT INTO "django_geo_db_location" VALUES(62302,NULL,'El Paso, TX 79985',26059,222,NULL,51,35949,0);
INSERT INTO "django_geo_db_location" VALUES(62303,NULL,'El Paso, TX 79986',26059,222,NULL,51,35950,0);
INSERT INTO "django_geo_db_location" VALUES(62304,NULL,'El Paso, TX 79987',26059,222,NULL,51,35951,0);
INSERT INTO "django_geo_db_location" VALUES(62305,NULL,'El Paso, TX 79988',26059,222,NULL,51,35952,0);
INSERT INTO "django_geo_db_location" VALUES(62306,NULL,'El Paso, TX 79989',26059,222,NULL,51,35953,0);
INSERT INTO "django_geo_db_location" VALUES(62307,NULL,'El Paso, TX 79990',26059,222,NULL,51,35954,0);
INSERT INTO "django_geo_db_location" VALUES(62308,NULL,'El Paso, TX 79991',26059,222,NULL,51,35955,0);
INSERT INTO "django_geo_db_location" VALUES(62309,NULL,'El Paso, TX 79992',26059,222,NULL,51,35956,0);
INSERT INTO "django_geo_db_location" VALUES(62310,NULL,'El Paso, TX 79993',26059,222,NULL,51,35957,0);
INSERT INTO "django_geo_db_location" VALUES(62311,NULL,'El Paso, TX 79994',26059,222,NULL,51,35958,0);
INSERT INTO "django_geo_db_location" VALUES(62312,NULL,'El Paso, TX 79995',26059,222,NULL,51,35959,0);
INSERT INTO "django_geo_db_location" VALUES(62313,NULL,'El Paso, TX 79996',26059,222,NULL,51,35960,0);
INSERT INTO "django_geo_db_location" VALUES(62314,NULL,'El Paso, TX 79997',26059,222,NULL,51,35961,0);
INSERT INTO "django_geo_db_location" VALUES(62315,NULL,'El Paso, TX 79998',26059,222,NULL,51,35962,0);
INSERT INTO "django_geo_db_location" VALUES(62316,NULL,'El Paso, TX 79999',26059,222,NULL,51,35963,0);
INSERT INTO "django_geo_db_location" VALUES(62317,NULL,'Aurora, CO',26061,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62318,NULL,'Aurora, CO 80000',26061,222,NULL,7,35964,0);
INSERT INTO "django_geo_db_location" VALUES(62319,NULL,'Arvada, CO',26062,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62320,NULL,'Arvada, CO 80001',26062,222,NULL,7,35965,0);
INSERT INTO "django_geo_db_location" VALUES(62321,NULL,'Arvada, CO 80002',26062,222,NULL,7,35966,0);
INSERT INTO "django_geo_db_location" VALUES(62322,NULL,'Arvada, CO 80003',26062,222,NULL,7,35967,0);
INSERT INTO "django_geo_db_location" VALUES(62323,NULL,'Arvada, CO 80004',26062,222,NULL,7,35968,0);
INSERT INTO "django_geo_db_location" VALUES(62324,NULL,'Arvada, CO 80005',26062,222,NULL,7,35969,0);
INSERT INTO "django_geo_db_location" VALUES(62325,NULL,'Arvada, CO 80006',26062,222,NULL,7,35970,0);
INSERT INTO "django_geo_db_location" VALUES(62326,NULL,'Arvada, CO 80007',26062,222,NULL,7,35971,0);
INSERT INTO "django_geo_db_location" VALUES(62327,NULL,'Aurora, CO 80010',26061,222,NULL,7,35972,0);
INSERT INTO "django_geo_db_location" VALUES(62328,NULL,'Aurora, CO 80011',26061,222,NULL,7,35973,0);
INSERT INTO "django_geo_db_location" VALUES(62329,NULL,'Aurora, CO 80012',26061,222,NULL,7,35974,0);
INSERT INTO "django_geo_db_location" VALUES(62330,NULL,'Aurora, CO 80013',26061,222,NULL,7,35975,0);
INSERT INTO "django_geo_db_location" VALUES(62331,NULL,'Aurora, CO 80014',26061,222,NULL,7,35976,0);
INSERT INTO "django_geo_db_location" VALUES(62332,NULL,'Aurora, CO 80015',26061,222,NULL,7,35977,0);
INSERT INTO "django_geo_db_location" VALUES(62333,NULL,'Aurora, CO 80016',26061,222,NULL,7,35978,0);
INSERT INTO "django_geo_db_location" VALUES(62334,NULL,'Aurora, CO 80017',26061,222,NULL,7,35979,0);
INSERT INTO "django_geo_db_location" VALUES(62335,NULL,'Aurora, CO 80018',26061,222,NULL,7,35980,0);
INSERT INTO "django_geo_db_location" VALUES(62336,NULL,'Aurora, CO 80019',26061,222,NULL,7,35981,0);
INSERT INTO "django_geo_db_location" VALUES(62337,NULL,'Broomfield, CO',26063,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62338,NULL,'Broomfield, CO 80020',26063,222,NULL,7,35982,0);
INSERT INTO "django_geo_db_location" VALUES(62339,NULL,'Broomfield, CO 80021',26063,222,NULL,7,35983,0);
INSERT INTO "django_geo_db_location" VALUES(62340,NULL,'Commerce City, CO',26064,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62341,NULL,'Commerce City, CO 80022',26064,222,NULL,7,35984,0);
INSERT INTO "django_geo_db_location" VALUES(62342,NULL,'Dupont, CO',26065,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62343,NULL,'Dupont, CO 80024',26065,222,NULL,7,35985,0);
INSERT INTO "django_geo_db_location" VALUES(62344,NULL,'Eldorado Springs, CO',26066,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62345,NULL,'Eldorado Springs, CO 80025',26066,222,NULL,7,35986,0);
INSERT INTO "django_geo_db_location" VALUES(62346,NULL,'Lafayette, CO',26067,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62347,NULL,'Lafayette, CO 80026',26067,222,NULL,7,35987,0);
INSERT INTO "django_geo_db_location" VALUES(62348,NULL,'Louisville, CO',26068,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62349,NULL,'Louisville, CO 80027',26068,222,NULL,7,35988,0);
INSERT INTO "django_geo_db_location" VALUES(62350,NULL,'Louisville, CO 80028',26068,222,NULL,7,35989,0);
INSERT INTO "django_geo_db_location" VALUES(62351,NULL,'Westminster, CO',26069,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62352,NULL,'Westminster, CO 80030',26069,222,NULL,7,35990,0);
INSERT INTO "django_geo_db_location" VALUES(62353,NULL,'Westminster, CO 80031',26069,222,NULL,7,35991,0);
INSERT INTO "django_geo_db_location" VALUES(62354,NULL,'Wheat Ridge, CO',26070,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62355,NULL,'Wheat Ridge, CO 80033',26070,222,NULL,7,35992,0);
INSERT INTO "django_geo_db_location" VALUES(62356,NULL,'Wheat Ridge, CO 80034',26070,222,NULL,7,35993,0);
INSERT INTO "django_geo_db_location" VALUES(62357,NULL,'Westminster, CO 80035',26069,222,NULL,7,35994,0);
INSERT INTO "django_geo_db_location" VALUES(62358,NULL,'Westminster, CO 80036',26069,222,NULL,7,35995,0);
INSERT INTO "django_geo_db_location" VALUES(62359,NULL,'Commerce City, CO 80037',26064,222,NULL,7,35996,0);
INSERT INTO "django_geo_db_location" VALUES(62360,NULL,'Broomfield, CO 80038',26063,222,NULL,7,35997,0);
INSERT INTO "django_geo_db_location" VALUES(62361,NULL,'Aurora, CO 80040',26061,222,NULL,7,35998,0);
INSERT INTO "django_geo_db_location" VALUES(62362,NULL,'Aurora, CO 80041',26061,222,NULL,7,35999,0);
INSERT INTO "django_geo_db_location" VALUES(62363,NULL,'Aurora, CO 80042',26061,222,NULL,7,36000,0);
INSERT INTO "django_geo_db_location" VALUES(62364,NULL,'Aurora, CO 80044',26061,222,NULL,7,36001,0);
INSERT INTO "django_geo_db_location" VALUES(62365,NULL,'Aurora, CO 80045',26061,222,NULL,7,36002,0);
INSERT INTO "django_geo_db_location" VALUES(62366,NULL,'Aurora, CO 80046',26061,222,NULL,7,36003,0);
INSERT INTO "django_geo_db_location" VALUES(62367,NULL,'Aurora, CO 80047',26061,222,NULL,7,36004,0);
INSERT INTO "django_geo_db_location" VALUES(62368,NULL,'Westminster, CO 80061',26069,222,NULL,7,36005,0);
INSERT INTO "django_geo_db_location" VALUES(62369,NULL,'Agate, CO',26071,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62370,NULL,'Agate, CO 80101',26071,222,NULL,7,36006,0);
INSERT INTO "django_geo_db_location" VALUES(62371,NULL,'Bennett, CO',26072,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62372,NULL,'Bennett, CO 80102',26072,222,NULL,7,36007,0);
INSERT INTO "django_geo_db_location" VALUES(62373,NULL,'Byers, CO',26073,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62374,NULL,'Byers, CO 80103',26073,222,NULL,7,36008,0);
INSERT INTO "django_geo_db_location" VALUES(62375,NULL,'Castle Rock, CO',26074,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62376,NULL,'Castle Rock, CO 80104',26074,222,NULL,7,36009,0);
INSERT INTO "django_geo_db_location" VALUES(62377,NULL,'Deer Trail, CO',26075,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62378,NULL,'Deer Trail, CO 80105',26075,222,NULL,7,36010,0);
INSERT INTO "django_geo_db_location" VALUES(62379,NULL,'Elbert, CO',26076,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62380,NULL,'Elbert, CO 80106',26076,222,NULL,7,36011,0);
INSERT INTO "django_geo_db_location" VALUES(62381,NULL,'Elizabeth, CO',26077,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62382,NULL,'Elizabeth, CO 80107',26077,222,NULL,7,36012,0);
INSERT INTO "django_geo_db_location" VALUES(62383,NULL,'Castle Rock, CO 80108',26074,222,NULL,7,36013,0);
INSERT INTO "django_geo_db_location" VALUES(62384,NULL,'Castle Rock, CO 80109',26074,222,NULL,7,36014,0);
INSERT INTO "django_geo_db_location" VALUES(62385,NULL,'Englewood, CO',26078,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62386,NULL,'Englewood, CO 80110',26078,222,NULL,7,36015,0);
INSERT INTO "django_geo_db_location" VALUES(62387,NULL,'Englewood, CO 80111',26078,222,NULL,7,36016,0);
INSERT INTO "django_geo_db_location" VALUES(62388,NULL,'Englewood, CO 80112',26078,222,NULL,7,36017,0);
INSERT INTO "django_geo_db_location" VALUES(62389,NULL,'Aurora, CO 80115',26061,222,NULL,7,36018,0);
INSERT INTO "django_geo_db_location" VALUES(62390,NULL,'Franktown, CO',26079,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62391,NULL,'Franktown, CO 80116',26079,222,NULL,7,36019,0);
INSERT INTO "django_geo_db_location" VALUES(62392,NULL,'Kiowa, CO',26080,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62393,NULL,'Kiowa, CO 80117',26080,222,NULL,7,36020,0);
INSERT INTO "django_geo_db_location" VALUES(62394,NULL,'Larkspur, CO',26081,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62395,NULL,'Larkspur, CO 80118',26081,222,NULL,7,36021,0);
INSERT INTO "django_geo_db_location" VALUES(62396,NULL,'Littleton, CO',26082,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62397,NULL,'Littleton, CO 80120',26082,222,NULL,7,36022,0);
INSERT INTO "django_geo_db_location" VALUES(62398,NULL,'Littleton, CO 80121',26082,222,NULL,7,36023,0);
INSERT INTO "django_geo_db_location" VALUES(62399,NULL,'Littleton, CO 80122',26082,222,NULL,7,36024,0);
INSERT INTO "django_geo_db_location" VALUES(62400,NULL,'Littleton, CO 80123',26082,222,NULL,7,36025,0);
INSERT INTO "django_geo_db_location" VALUES(62401,NULL,'Littleton, CO 80124',26082,222,NULL,7,36026,0);
INSERT INTO "django_geo_db_location" VALUES(62402,NULL,'Littleton, CO 80125',26082,222,NULL,7,36027,0);
INSERT INTO "django_geo_db_location" VALUES(62403,NULL,'Littleton, CO 80126',26082,222,NULL,7,36028,0);
INSERT INTO "django_geo_db_location" VALUES(62404,NULL,'Littleton, CO 80127',26082,222,NULL,7,36029,0);
INSERT INTO "django_geo_db_location" VALUES(62405,NULL,'Littleton, CO 80128',26082,222,NULL,7,36030,0);
INSERT INTO "django_geo_db_location" VALUES(62406,NULL,'Littleton, CO 80129',26082,222,NULL,7,36031,0);
INSERT INTO "django_geo_db_location" VALUES(62407,NULL,'Lone Tree, CO',26083,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62408,NULL,'Lone Tree, CO 80130',26083,222,NULL,7,36032,0);
INSERT INTO "django_geo_db_location" VALUES(62409,NULL,'Louviers, CO',26084,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62410,NULL,'Louviers, CO 80131',26084,222,NULL,7,36033,0);
INSERT INTO "django_geo_db_location" VALUES(62411,NULL,'Monument, CO',26085,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62412,NULL,'Monument, CO 80132',26085,222,NULL,7,36034,0);
INSERT INTO "django_geo_db_location" VALUES(62413,NULL,'Palmer Lake, CO',26086,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62414,NULL,'Palmer Lake, CO 80133',26086,222,NULL,7,36035,0);
INSERT INTO "django_geo_db_location" VALUES(62415,NULL,'Parker, CO',26087,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62416,NULL,'Parker, CO 80134',26087,222,NULL,7,36036,0);
INSERT INTO "django_geo_db_location" VALUES(62417,NULL,'Sedalia, CO',26088,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62418,NULL,'Sedalia, CO 80135',26088,222,NULL,7,36037,0);
INSERT INTO "django_geo_db_location" VALUES(62419,NULL,'Strasburg, CO',26089,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62420,NULL,'Strasburg, CO 80136',26089,222,NULL,7,36038,0);
INSERT INTO "django_geo_db_location" VALUES(62421,NULL,'Watkins, CO',26090,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62422,NULL,'Watkins, CO 80137',26090,222,NULL,7,36039,0);
INSERT INTO "django_geo_db_location" VALUES(62423,NULL,'Parker, CO 80138',26087,222,NULL,7,36040,0);
INSERT INTO "django_geo_db_location" VALUES(62424,NULL,'Parker, CO 80139',26087,222,NULL,7,36041,0);
INSERT INTO "django_geo_db_location" VALUES(62425,NULL,'Englewood, CO 80150',26078,222,NULL,7,36042,0);
INSERT INTO "django_geo_db_location" VALUES(62426,NULL,'Englewood, CO 80151',26078,222,NULL,7,36043,0);
INSERT INTO "django_geo_db_location" VALUES(62427,NULL,'Englewood, CO 80154',26078,222,NULL,7,36044,0);
INSERT INTO "django_geo_db_location" VALUES(62428,NULL,'Englewood, CO 80155',26078,222,NULL,7,36045,0);
INSERT INTO "django_geo_db_location" VALUES(62429,NULL,'Littleton, CO 80160',26082,222,NULL,7,36046,0);
INSERT INTO "django_geo_db_location" VALUES(62430,NULL,'Littleton, CO 80161',26082,222,NULL,7,36047,0);
INSERT INTO "django_geo_db_location" VALUES(62431,NULL,'Littleton, CO 80162',26082,222,NULL,7,36048,0);
INSERT INTO "django_geo_db_location" VALUES(62432,NULL,'Littleton, CO 80163',26082,222,NULL,7,36049,0);
INSERT INTO "django_geo_db_location" VALUES(62433,NULL,'Littleton, CO 80165',26082,222,NULL,7,36050,0);
INSERT INTO "django_geo_db_location" VALUES(62434,NULL,'Littleton, CO 80166',26082,222,NULL,7,36051,0);
INSERT INTO "django_geo_db_location" VALUES(62435,NULL,'Denver, CO',26091,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62436,NULL,'Denver, CO 80201',26091,222,NULL,7,36052,0);
INSERT INTO "django_geo_db_location" VALUES(62437,NULL,'Denver, CO 80202',26091,222,NULL,7,36053,0);
INSERT INTO "django_geo_db_location" VALUES(62438,NULL,'Denver, CO 80203',26091,222,NULL,7,36054,0);
INSERT INTO "django_geo_db_location" VALUES(62439,NULL,'Denver, CO 80204',26091,222,NULL,7,36055,0);
INSERT INTO "django_geo_db_location" VALUES(62440,NULL,'Denver, CO 80205',26091,222,NULL,7,36056,0);
INSERT INTO "django_geo_db_location" VALUES(62441,NULL,'Denver, CO 80206',26091,222,NULL,7,36057,0);
INSERT INTO "django_geo_db_location" VALUES(62442,NULL,'Denver, CO 80207',26091,222,NULL,7,36058,0);
INSERT INTO "django_geo_db_location" VALUES(62443,NULL,'Denver, CO 80208',26091,222,NULL,7,36059,0);
INSERT INTO "django_geo_db_location" VALUES(62444,NULL,'Denver, CO 80209',26091,222,NULL,7,36060,0);
INSERT INTO "django_geo_db_location" VALUES(62445,NULL,'Denver, CO 80210',26091,222,NULL,7,36061,0);
INSERT INTO "django_geo_db_location" VALUES(62446,NULL,'Denver, CO 80211',26091,222,NULL,7,36062,0);
INSERT INTO "django_geo_db_location" VALUES(62447,NULL,'Denver, CO 80212',26091,222,NULL,7,36063,0);
INSERT INTO "django_geo_db_location" VALUES(62448,NULL,'Denver, CO 80214',26091,222,NULL,7,36064,0);
INSERT INTO "django_geo_db_location" VALUES(62449,NULL,'Denver, CO 80215',26091,222,NULL,7,36065,0);
INSERT INTO "django_geo_db_location" VALUES(62450,NULL,'Denver, CO 80216',26091,222,NULL,7,36066,0);
INSERT INTO "django_geo_db_location" VALUES(62451,NULL,'Denver, CO 80217',26091,222,NULL,7,36067,0);
INSERT INTO "django_geo_db_location" VALUES(62452,NULL,'Denver, CO 80218',26091,222,NULL,7,36068,0);
INSERT INTO "django_geo_db_location" VALUES(62453,NULL,'Denver, CO 80219',26091,222,NULL,7,36069,0);
INSERT INTO "django_geo_db_location" VALUES(62454,NULL,'Denver, CO 80220',26091,222,NULL,7,36070,0);
INSERT INTO "django_geo_db_location" VALUES(62455,NULL,'Denver, CO 80221',26091,222,NULL,7,36071,0);
INSERT INTO "django_geo_db_location" VALUES(62456,NULL,'Denver, CO 80222',26091,222,NULL,7,36072,0);
INSERT INTO "django_geo_db_location" VALUES(62457,NULL,'Denver, CO 80223',26091,222,NULL,7,36073,0);
INSERT INTO "django_geo_db_location" VALUES(62458,NULL,'Denver, CO 80224',26091,222,NULL,7,36074,0);
INSERT INTO "django_geo_db_location" VALUES(62459,NULL,'Denver, CO 80225',26091,222,NULL,7,36075,0);
INSERT INTO "django_geo_db_location" VALUES(62460,NULL,'Denver, CO 80226',26091,222,NULL,7,36076,0);
INSERT INTO "django_geo_db_location" VALUES(62461,NULL,'Denver, CO 80227',26091,222,NULL,7,36077,0);
INSERT INTO "django_geo_db_location" VALUES(62462,NULL,'Denver, CO 80228',26091,222,NULL,7,36078,0);
INSERT INTO "django_geo_db_location" VALUES(62463,NULL,'Denver, CO 80229',26091,222,NULL,7,36079,0);
INSERT INTO "django_geo_db_location" VALUES(62464,NULL,'Denver, CO 80230',26091,222,NULL,7,36080,0);
INSERT INTO "django_geo_db_location" VALUES(62465,NULL,'Denver, CO 80231',26091,222,NULL,7,36081,0);
INSERT INTO "django_geo_db_location" VALUES(62466,NULL,'Denver, CO 80232',26091,222,NULL,7,36082,0);
INSERT INTO "django_geo_db_location" VALUES(62467,NULL,'Denver, CO 80233',26091,222,NULL,7,36083,0);
INSERT INTO "django_geo_db_location" VALUES(62468,NULL,'Denver, CO 80234',26091,222,NULL,7,36084,0);
INSERT INTO "django_geo_db_location" VALUES(62469,NULL,'Denver, CO 80235',26091,222,NULL,7,36085,0);
INSERT INTO "django_geo_db_location" VALUES(62470,NULL,'Denver, CO 80236',26091,222,NULL,7,36086,0);
INSERT INTO "django_geo_db_location" VALUES(62471,NULL,'Denver, CO 80237',26091,222,NULL,7,36087,0);
INSERT INTO "django_geo_db_location" VALUES(62472,NULL,'Denver, CO 80238',26091,222,NULL,7,36088,0);
INSERT INTO "django_geo_db_location" VALUES(62473,NULL,'Denver, CO 80239',26091,222,NULL,7,36089,0);
INSERT INTO "django_geo_db_location" VALUES(62474,NULL,'Denver, CO 80241',26091,222,NULL,7,36090,0);
INSERT INTO "django_geo_db_location" VALUES(62475,NULL,'Denver, CO 80243',26091,222,NULL,7,36091,0);
INSERT INTO "django_geo_db_location" VALUES(62476,NULL,'Denver, CO 80244',26091,222,NULL,7,36092,0);
INSERT INTO "django_geo_db_location" VALUES(62477,NULL,'Denver, CO 80246',26091,222,NULL,7,36093,0);
INSERT INTO "django_geo_db_location" VALUES(62478,NULL,'Denver, CO 80247',26091,222,NULL,7,36094,0);
INSERT INTO "django_geo_db_location" VALUES(62479,NULL,'Denver, CO 80248',26091,222,NULL,7,36095,0);
INSERT INTO "django_geo_db_location" VALUES(62480,NULL,'Denver, CO 80249',26091,222,NULL,7,36096,0);
INSERT INTO "django_geo_db_location" VALUES(62481,NULL,'Denver, CO 80250',26091,222,NULL,7,36097,0);
INSERT INTO "django_geo_db_location" VALUES(62482,NULL,'Denver, CO 80251',26091,222,NULL,7,36098,0);
INSERT INTO "django_geo_db_location" VALUES(62483,NULL,'Denver, CO 80252',26091,222,NULL,7,36099,0);
INSERT INTO "django_geo_db_location" VALUES(62484,NULL,'Denver, CO 80254',26091,222,NULL,7,36100,0);
INSERT INTO "django_geo_db_location" VALUES(62485,NULL,'Denver, CO 80255',26091,222,NULL,7,36101,0);
INSERT INTO "django_geo_db_location" VALUES(62486,NULL,'Denver, CO 80256',26091,222,NULL,7,36102,0);
INSERT INTO "django_geo_db_location" VALUES(62487,NULL,'Denver, CO 80257',26091,222,NULL,7,36103,0);
INSERT INTO "django_geo_db_location" VALUES(62488,NULL,'Denver, CO 80259',26091,222,NULL,7,36104,0);
INSERT INTO "django_geo_db_location" VALUES(62489,NULL,'Denver, CO 80260',26091,222,NULL,7,36105,0);
INSERT INTO "django_geo_db_location" VALUES(62490,NULL,'Denver, CO 80261',26091,222,NULL,7,36106,0);
INSERT INTO "django_geo_db_location" VALUES(62491,NULL,'Denver, CO 80262',26091,222,NULL,7,36107,0);
INSERT INTO "django_geo_db_location" VALUES(62492,NULL,'Denver, CO 80263',26091,222,NULL,7,36108,0);
INSERT INTO "django_geo_db_location" VALUES(62493,NULL,'Denver, CO 80264',26091,222,NULL,7,36109,0);
INSERT INTO "django_geo_db_location" VALUES(62494,NULL,'Denver, CO 80265',26091,222,NULL,7,36110,0);
INSERT INTO "django_geo_db_location" VALUES(62495,NULL,'Denver, CO 80266',26091,222,NULL,7,36111,0);
INSERT INTO "django_geo_db_location" VALUES(62496,NULL,'Denver, CO 80270',26091,222,NULL,7,36112,0);
INSERT INTO "django_geo_db_location" VALUES(62497,NULL,'Denver, CO 80271',26091,222,NULL,7,36113,0);
INSERT INTO "django_geo_db_location" VALUES(62498,NULL,'Denver, CO 80273',26091,222,NULL,7,36114,0);
INSERT INTO "django_geo_db_location" VALUES(62499,NULL,'Denver, CO 80274',26091,222,NULL,7,36115,0);
INSERT INTO "django_geo_db_location" VALUES(62500,NULL,'Denver, CO 80275',26091,222,NULL,7,36116,0);
INSERT INTO "django_geo_db_location" VALUES(62501,NULL,'Denver, CO 80279',26091,222,NULL,7,36117,0);
INSERT INTO "django_geo_db_location" VALUES(62502,NULL,'Denver, CO 80280',26091,222,NULL,7,36118,0);
INSERT INTO "django_geo_db_location" VALUES(62503,NULL,'Denver, CO 80281',26091,222,NULL,7,36119,0);
INSERT INTO "django_geo_db_location" VALUES(62504,NULL,'Denver, CO 80290',26091,222,NULL,7,36120,0);
INSERT INTO "django_geo_db_location" VALUES(62505,NULL,'Denver, CO 80291',26091,222,NULL,7,36121,0);
INSERT INTO "django_geo_db_location" VALUES(62506,NULL,'Denver, CO 80292',26091,222,NULL,7,36122,0);
INSERT INTO "django_geo_db_location" VALUES(62507,NULL,'Denver, CO 80293',26091,222,NULL,7,36123,0);
INSERT INTO "django_geo_db_location" VALUES(62508,NULL,'Denver, CO 80294',26091,222,NULL,7,36124,0);
INSERT INTO "django_geo_db_location" VALUES(62509,NULL,'Denver, CO 80295',26091,222,NULL,7,36125,0);
INSERT INTO "django_geo_db_location" VALUES(62510,NULL,'Sherrelwood, CO',26092,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62511,NULL,'Sherrelwood, CO 80296',26092,222,NULL,7,36126,0);
INSERT INTO "django_geo_db_location" VALUES(62512,NULL,'Denver, CO 80299',26091,222,NULL,7,36127,0);
INSERT INTO "django_geo_db_location" VALUES(62513,NULL,'Boulder, CO',26093,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62514,NULL,'Boulder, CO 80301',26093,222,NULL,7,36128,0);
INSERT INTO "django_geo_db_location" VALUES(62515,NULL,'Boulder, CO 80302',26093,222,NULL,7,36129,0);
INSERT INTO "django_geo_db_location" VALUES(62516,NULL,'Boulder, CO 80303',26093,222,NULL,7,36130,0);
INSERT INTO "django_geo_db_location" VALUES(62517,NULL,'Boulder, CO 80304',26093,222,NULL,7,36131,0);
INSERT INTO "django_geo_db_location" VALUES(62518,NULL,'Boulder, CO 80305',26093,222,NULL,7,36132,0);
INSERT INTO "django_geo_db_location" VALUES(62519,NULL,'Boulder, CO 80306',26093,222,NULL,7,36133,0);
INSERT INTO "django_geo_db_location" VALUES(62520,NULL,'Boulder, CO 80307',26093,222,NULL,7,36134,0);
INSERT INTO "django_geo_db_location" VALUES(62521,NULL,'Boulder, CO 80308',26093,222,NULL,7,36135,0);
INSERT INTO "django_geo_db_location" VALUES(62522,NULL,'Boulder, CO 80309',26093,222,NULL,7,36136,0);
INSERT INTO "django_geo_db_location" VALUES(62523,NULL,'Boulder, CO 80310',26093,222,NULL,7,36137,0);
INSERT INTO "django_geo_db_location" VALUES(62524,NULL,'Boulder, CO 80314',26093,222,NULL,7,36138,0);
INSERT INTO "django_geo_db_location" VALUES(62525,NULL,'Boulder, CO 80321',26093,222,NULL,7,36139,0);
INSERT INTO "django_geo_db_location" VALUES(62526,NULL,'Boulder, CO 80322',26093,222,NULL,7,36140,0);
INSERT INTO "django_geo_db_location" VALUES(62527,NULL,'Boulder, CO 80323',26093,222,NULL,7,36141,0);
INSERT INTO "django_geo_db_location" VALUES(62528,NULL,'Boulder, CO 80328',26093,222,NULL,7,36142,0);
INSERT INTO "django_geo_db_location" VALUES(62529,NULL,'Boulder, CO 80329',26093,222,NULL,7,36143,0);
INSERT INTO "django_geo_db_location" VALUES(62530,NULL,'Golden, CO',26094,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62531,NULL,'Golden, CO 80401',26094,222,NULL,7,36144,0);
INSERT INTO "django_geo_db_location" VALUES(62532,NULL,'Golden, CO 80402',26094,222,NULL,7,36145,0);
INSERT INTO "django_geo_db_location" VALUES(62533,NULL,'Golden, CO 80403',26094,222,NULL,7,36146,0);
INSERT INTO "django_geo_db_location" VALUES(62534,NULL,'Golden, CO 80419',26094,222,NULL,7,36147,0);
INSERT INTO "django_geo_db_location" VALUES(62535,NULL,'Alma, CO',26095,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62536,NULL,'Alma, CO 80420',26095,222,NULL,7,36148,0);
INSERT INTO "django_geo_db_location" VALUES(62537,NULL,'Bailey, CO',26096,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62538,NULL,'Bailey, CO 80421',26096,222,NULL,7,36149,0);
INSERT INTO "django_geo_db_location" VALUES(62539,NULL,'Black Hawk, CO',26097,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62540,NULL,'Black Hawk, CO 80422',26097,222,NULL,7,36150,0);
INSERT INTO "django_geo_db_location" VALUES(62541,NULL,'Bond, CO',26098,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62542,NULL,'Bond, CO 80423',26098,222,NULL,7,36151,0);
INSERT INTO "django_geo_db_location" VALUES(62543,NULL,'Breckenridge, CO',26099,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62544,NULL,'Breckenridge, CO 80424',26099,222,NULL,7,36152,0);
INSERT INTO "django_geo_db_location" VALUES(62545,NULL,'Buffalo Creek, CO',26100,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62546,NULL,'Buffalo Creek, CO 80425',26100,222,NULL,7,36153,0);
INSERT INTO "django_geo_db_location" VALUES(62547,NULL,'Burns, CO',26101,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62548,NULL,'Burns, CO 80426',26101,222,NULL,7,36154,0);
INSERT INTO "django_geo_db_location" VALUES(62549,NULL,'Central City, CO',26102,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62550,NULL,'Central City, CO 80427',26102,222,NULL,7,36155,0);
INSERT INTO "django_geo_db_location" VALUES(62551,NULL,'Clark, CO',26103,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62552,NULL,'Clark, CO 80428',26103,222,NULL,7,36156,0);
INSERT INTO "django_geo_db_location" VALUES(62553,NULL,'Climax, CO',26104,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62554,NULL,'Climax, CO 80429',26104,222,NULL,7,36157,0);
INSERT INTO "django_geo_db_location" VALUES(62555,NULL,'Coalmont, CO',26105,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62556,NULL,'Coalmont, CO 80430',26105,222,NULL,7,36158,0);
INSERT INTO "django_geo_db_location" VALUES(62557,NULL,'Como, CO',26106,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62558,NULL,'Como, CO 80432',26106,222,NULL,7,36159,0);
INSERT INTO "django_geo_db_location" VALUES(62559,NULL,'Conifer, CO',26107,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62560,NULL,'Conifer, CO 80433',26107,222,NULL,7,36160,0);
INSERT INTO "django_geo_db_location" VALUES(62561,NULL,'Cowdrey, CO',26108,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62562,NULL,'Cowdrey, CO 80434',26108,222,NULL,7,36161,0);
INSERT INTO "django_geo_db_location" VALUES(62563,NULL,'Dillon, CO',26109,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62564,NULL,'Dillon, CO 80435',26109,222,NULL,7,36162,0);
INSERT INTO "django_geo_db_location" VALUES(62565,NULL,'Dumont, CO',26110,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62566,NULL,'Dumont, CO 80436',26110,222,NULL,7,36163,0);
INSERT INTO "django_geo_db_location" VALUES(62567,NULL,'Evergreen, CO',26111,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62568,NULL,'Evergreen, CO 80437',26111,222,NULL,7,36164,0);
INSERT INTO "django_geo_db_location" VALUES(62569,NULL,'Empire, CO',26112,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62570,NULL,'Empire, CO 80438',26112,222,NULL,7,36165,0);
INSERT INTO "django_geo_db_location" VALUES(62571,NULL,'Evergreen, CO 80439',26111,222,NULL,7,36166,0);
INSERT INTO "django_geo_db_location" VALUES(62572,NULL,'Fairplay, CO',26113,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62573,NULL,'Fairplay, CO 80440',26113,222,NULL,7,36167,0);
INSERT INTO "django_geo_db_location" VALUES(62574,NULL,'Fraser, CO',26114,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62575,NULL,'Fraser, CO 80442',26114,222,NULL,7,36168,0);
INSERT INTO "django_geo_db_location" VALUES(62576,NULL,'Frisco, CO',26115,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62577,NULL,'Frisco, CO 80443',26115,222,NULL,7,36169,0);
INSERT INTO "django_geo_db_location" VALUES(62578,NULL,'Georgetown, CO',26116,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62579,NULL,'Georgetown, CO 80444',26116,222,NULL,7,36170,0);
INSERT INTO "django_geo_db_location" VALUES(62580,NULL,'Granby, CO',26117,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62581,NULL,'Granby, CO 80446',26117,222,NULL,7,36171,0);
INSERT INTO "django_geo_db_location" VALUES(62582,NULL,'Grand Lake, CO',26118,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62583,NULL,'Grand Lake, CO 80447',26118,222,NULL,7,36172,0);
INSERT INTO "django_geo_db_location" VALUES(62584,NULL,'Grant, CO',26119,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62585,NULL,'Grant, CO 80448',26119,222,NULL,7,36173,0);
INSERT INTO "django_geo_db_location" VALUES(62586,NULL,'Hartsel, CO',26120,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62587,NULL,'Hartsel, CO 80449',26120,222,NULL,7,36174,0);
INSERT INTO "django_geo_db_location" VALUES(62588,NULL,'Hot Sulphur Springs, CO',26121,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62589,NULL,'Hot Sulphur Springs, CO 80451',26121,222,NULL,7,36175,0);
INSERT INTO "django_geo_db_location" VALUES(62590,NULL,'Idaho Springs, CO',26122,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62591,NULL,'Idaho Springs, CO 80452',26122,222,NULL,7,36176,0);
INSERT INTO "django_geo_db_location" VALUES(62592,NULL,'Idledale, CO',26123,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62593,NULL,'Idledale, CO 80453',26123,222,NULL,7,36177,0);
INSERT INTO "django_geo_db_location" VALUES(62594,NULL,'Indian Hills, CO',26124,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62595,NULL,'Indian Hills, CO 80454',26124,222,NULL,7,36178,0);
INSERT INTO "django_geo_db_location" VALUES(62596,NULL,'Jamestown, CO',26125,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62597,NULL,'Jamestown, CO 80455',26125,222,NULL,7,36179,0);
INSERT INTO "django_geo_db_location" VALUES(62598,NULL,'Jefferson, CO',26126,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62599,NULL,'Jefferson, CO 80456',26126,222,NULL,7,36180,0);
INSERT INTO "django_geo_db_location" VALUES(62600,NULL,'Kittredge, CO',26127,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62601,NULL,'Kittredge, CO 80457',26127,222,NULL,7,36181,0);
INSERT INTO "django_geo_db_location" VALUES(62602,NULL,'Kremmling, CO',26128,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62603,NULL,'Kremmling, CO 80459',26128,222,NULL,7,36182,0);
INSERT INTO "django_geo_db_location" VALUES(62604,NULL,'Leadville, CO',26129,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62605,NULL,'Leadville, CO 80461',26129,222,NULL,7,36183,0);
INSERT INTO "django_geo_db_location" VALUES(62606,NULL,'McCoy, CO',26130,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62607,NULL,'McCoy, CO 80463',26130,222,NULL,7,36184,0);
INSERT INTO "django_geo_db_location" VALUES(62608,NULL,'Morrison, CO',26131,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62609,NULL,'Morrison, CO 80465',26131,222,NULL,7,36185,0);
INSERT INTO "django_geo_db_location" VALUES(62610,NULL,'Nederland, CO',26132,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62611,NULL,'Nederland, CO 80466',26132,222,NULL,7,36186,0);
INSERT INTO "django_geo_db_location" VALUES(62612,NULL,'Oak Creek, CO',26133,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62613,NULL,'Oak Creek, CO 80467',26133,222,NULL,7,36187,0);
INSERT INTO "django_geo_db_location" VALUES(62614,NULL,'Parshall, CO',26134,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62615,NULL,'Parshall, CO 80468',26134,222,NULL,7,36188,0);
INSERT INTO "django_geo_db_location" VALUES(62616,NULL,'Phippsburg, CO',26135,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62617,NULL,'Phippsburg, CO 80469',26135,222,NULL,7,36189,0);
INSERT INTO "django_geo_db_location" VALUES(62618,NULL,'Pine, CO',26136,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62619,NULL,'Pine, CO 80470',26136,222,NULL,7,36190,0);
INSERT INTO "django_geo_db_location" VALUES(62620,NULL,'Pinecliffe, CO',26137,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62621,NULL,'Pinecliffe, CO 80471',26137,222,NULL,7,36191,0);
INSERT INTO "django_geo_db_location" VALUES(62622,NULL,'Rand, CO',26138,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62623,NULL,'Rand, CO 80473',26138,222,NULL,7,36192,0);
INSERT INTO "django_geo_db_location" VALUES(62624,NULL,'Rollinsville, CO',26139,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62625,NULL,'Rollinsville, CO 80474',26139,222,NULL,7,36193,0);
INSERT INTO "django_geo_db_location" VALUES(62626,NULL,'Shawnee, CO',26140,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62627,NULL,'Shawnee, CO 80475',26140,222,NULL,7,36194,0);
INSERT INTO "django_geo_db_location" VALUES(62628,NULL,'Silver Plume, CO',26141,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62629,NULL,'Silver Plume, CO 80476',26141,222,NULL,7,36195,0);
INSERT INTO "django_geo_db_location" VALUES(62630,NULL,'Steamboat Springs, CO',26142,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62631,NULL,'Steamboat Springs, CO 80477',26142,222,NULL,7,36196,0);
INSERT INTO "django_geo_db_location" VALUES(62632,NULL,'Tabernash, CO',26143,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62633,NULL,'Tabernash, CO 80478',26143,222,NULL,7,36197,0);
INSERT INTO "django_geo_db_location" VALUES(62634,NULL,'Toponas, CO',26144,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62635,NULL,'Toponas, CO 80479',26144,222,NULL,7,36198,0);
INSERT INTO "django_geo_db_location" VALUES(62636,NULL,'Walden, CO',26145,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62637,NULL,'Walden, CO 80480',26145,222,NULL,7,36199,0);
INSERT INTO "django_geo_db_location" VALUES(62638,NULL,'Ward, CO',26146,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62639,NULL,'Ward, CO 80481',26146,222,NULL,7,36200,0);
INSERT INTO "django_geo_db_location" VALUES(62640,NULL,'Winter Park, CO',26147,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62641,NULL,'Winter Park, CO 80482',26147,222,NULL,7,36201,0);
INSERT INTO "django_geo_db_location" VALUES(62642,NULL,'Yampa, CO',26148,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62643,NULL,'Yampa, CO 80483',26148,222,NULL,7,36202,0);
INSERT INTO "django_geo_db_location" VALUES(62644,NULL,'Steamboat Springs, CO 80487',26142,222,NULL,7,36203,0);
INSERT INTO "django_geo_db_location" VALUES(62645,NULL,'Steamboat Springs, CO 80488',26142,222,NULL,7,36204,0);
INSERT INTO "django_geo_db_location" VALUES(62646,NULL,'Silverthorne, CO',26149,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62647,NULL,'Silverthorne, CO 80497',26149,222,NULL,7,36205,0);
INSERT INTO "django_geo_db_location" VALUES(62648,NULL,'Silverthorne, CO 80498',26149,222,NULL,7,36206,0);
INSERT INTO "django_geo_db_location" VALUES(62649,NULL,'Longmont, CO',26150,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62650,NULL,'Longmont, CO 80501',26150,222,NULL,7,36207,0);
INSERT INTO "django_geo_db_location" VALUES(62651,NULL,'Longmont, CO 80502',26150,222,NULL,7,36208,0);
INSERT INTO "django_geo_db_location" VALUES(62652,NULL,'Longmont, CO 80503',26150,222,NULL,7,36209,0);
INSERT INTO "django_geo_db_location" VALUES(62653,NULL,'Longmont, CO 80504',26150,222,NULL,7,36210,0);
INSERT INTO "django_geo_db_location" VALUES(62654,NULL,'Colorado Springs, CO',26151,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62655,NULL,'Colorado Springs, CO 80509',26151,222,NULL,7,36211,0);
INSERT INTO "django_geo_db_location" VALUES(62656,NULL,'Allenspark, CO',26152,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62657,NULL,'Allenspark, CO 80510',26152,222,NULL,7,36212,0);
INSERT INTO "django_geo_db_location" VALUES(62658,NULL,'Estes Park, CO',26153,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62659,NULL,'Estes Park, CO 80511',26153,222,NULL,7,36213,0);
INSERT INTO "django_geo_db_location" VALUES(62660,NULL,'Bellvue, CO',26154,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62661,NULL,'Bellvue, CO 80512',26154,222,NULL,7,36214,0);
INSERT INTO "django_geo_db_location" VALUES(62662,NULL,'Berthoud, CO',26155,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62663,NULL,'Berthoud, CO 80513',26155,222,NULL,7,36215,0);
INSERT INTO "django_geo_db_location" VALUES(62664,NULL,'Dacono, CO',26156,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62665,NULL,'Dacono, CO 80514',26156,222,NULL,7,36216,0);
INSERT INTO "django_geo_db_location" VALUES(62666,NULL,'Drake, CO',26157,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62667,NULL,'Drake, CO 80515',26157,222,NULL,7,36217,0);
INSERT INTO "django_geo_db_location" VALUES(62668,NULL,'Erie, CO',26158,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62669,NULL,'Erie, CO 80516',26158,222,NULL,7,36218,0);
INSERT INTO "django_geo_db_location" VALUES(62670,NULL,'Estes Park, CO 80517',26153,222,NULL,7,36219,0);
INSERT INTO "django_geo_db_location" VALUES(62671,NULL,'Firestone, CO',26159,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62672,NULL,'Firestone, CO 80520',26159,222,NULL,7,36220,0);
INSERT INTO "django_geo_db_location" VALUES(62673,NULL,'Fort Collins, CO',26160,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62674,NULL,'Fort Collins, CO 80521',26160,222,NULL,7,36221,0);
INSERT INTO "django_geo_db_location" VALUES(62675,NULL,'Fort Collins, CO 80522',26160,222,NULL,7,36222,0);
INSERT INTO "django_geo_db_location" VALUES(62676,NULL,'Fort Collins, CO 80523',26160,222,NULL,7,36223,0);
INSERT INTO "django_geo_db_location" VALUES(62677,NULL,'Fort Collins, CO 80524',26160,222,NULL,7,36224,0);
INSERT INTO "django_geo_db_location" VALUES(62678,NULL,'Fort Collins, CO 80525',26160,222,NULL,7,36225,0);
INSERT INTO "django_geo_db_location" VALUES(62679,NULL,'Fort Collins, CO 80526',26160,222,NULL,7,36226,0);
INSERT INTO "django_geo_db_location" VALUES(62680,NULL,'Fort Collins, CO 80527',26160,222,NULL,7,36227,0);
INSERT INTO "django_geo_db_location" VALUES(62681,NULL,'Fort Collins, CO 80528',26160,222,NULL,7,36228,0);
INSERT INTO "django_geo_db_location" VALUES(62682,NULL,'Frederick, CO',26161,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62683,NULL,'Frederick, CO 80530',26161,222,NULL,7,36229,0);
INSERT INTO "django_geo_db_location" VALUES(62684,NULL,'Glen Haven, CO',26162,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62685,NULL,'Glen Haven, CO 80532',26162,222,NULL,7,36230,0);
INSERT INTO "django_geo_db_location" VALUES(62686,NULL,'Hygiene, CO',26163,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62687,NULL,'Hygiene, CO 80533',26163,222,NULL,7,36231,0);
INSERT INTO "django_geo_db_location" VALUES(62688,NULL,'Johnstown, CO',26164,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62689,NULL,'Johnstown, CO 80534',26164,222,NULL,7,36232,0);
INSERT INTO "django_geo_db_location" VALUES(62690,NULL,'Laporte, CO',26165,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62691,NULL,'Laporte, CO 80535',26165,222,NULL,7,36233,0);
INSERT INTO "django_geo_db_location" VALUES(62692,NULL,'Livermore, CO',26166,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62693,NULL,'Livermore, CO 80536',26166,222,NULL,7,36234,0);
INSERT INTO "django_geo_db_location" VALUES(62694,NULL,'Loveland, CO',26167,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62695,NULL,'Loveland, CO 80537',26167,222,NULL,7,36235,0);
INSERT INTO "django_geo_db_location" VALUES(62696,NULL,'Loveland, CO 80538',26167,222,NULL,7,36236,0);
INSERT INTO "django_geo_db_location" VALUES(62697,NULL,'Loveland, CO 80539',26167,222,NULL,7,36237,0);
INSERT INTO "django_geo_db_location" VALUES(62698,NULL,'Lyons, CO',26168,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62699,NULL,'Lyons, CO 80540',26168,222,NULL,7,36238,0);
INSERT INTO "django_geo_db_location" VALUES(62700,NULL,'Masonville, CO',26169,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62701,NULL,'Masonville, CO 80541',26169,222,NULL,7,36239,0);
INSERT INTO "django_geo_db_location" VALUES(62702,NULL,'Mead, CO',26170,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62703,NULL,'Mead, CO 80542',26170,222,NULL,7,36240,0);
INSERT INTO "django_geo_db_location" VALUES(62704,NULL,'Milliken, CO',26171,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62705,NULL,'Milliken, CO 80543',26171,222,NULL,7,36241,0);
INSERT INTO "django_geo_db_location" VALUES(62706,NULL,'Niwot, CO',26172,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62707,NULL,'Niwot, CO 80544',26172,222,NULL,7,36242,0);
INSERT INTO "django_geo_db_location" VALUES(62708,NULL,'Red Feather Lakes, CO',26173,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62709,NULL,'Red Feather Lakes, CO 80545',26173,222,NULL,7,36243,0);
INSERT INTO "django_geo_db_location" VALUES(62710,NULL,'Severance, CO',26174,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62711,NULL,'Severance, CO 80546',26174,222,NULL,7,36244,0);
INSERT INTO "django_geo_db_location" VALUES(62712,NULL,'Timnath, CO',26175,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62713,NULL,'Timnath, CO 80547',26175,222,NULL,7,36245,0);
INSERT INTO "django_geo_db_location" VALUES(62714,NULL,'Wellington, CO',26176,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62715,NULL,'Wellington, CO 80549',26176,222,NULL,7,36246,0);
INSERT INTO "django_geo_db_location" VALUES(62716,NULL,'Windsor, CO',26177,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62717,NULL,'Windsor, CO 80550',26177,222,NULL,7,36247,0);
INSERT INTO "django_geo_db_location" VALUES(62718,NULL,'Windsor, CO 80551',26177,222,NULL,7,36248,0);
INSERT INTO "django_geo_db_location" VALUES(62719,NULL,'Fort Collins, CO 80553',26160,222,NULL,7,36249,0);
INSERT INTO "django_geo_db_location" VALUES(62720,NULL,'Brighton, CO',26178,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62721,NULL,'Brighton, CO 80601',26178,222,NULL,7,36250,0);
INSERT INTO "django_geo_db_location" VALUES(62722,NULL,'Thornton, CO',26179,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62723,NULL,'Thornton, CO 80602',26179,222,NULL,7,36251,0);
INSERT INTO "django_geo_db_location" VALUES(62724,NULL,'Lochbuie, CO',26180,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62725,NULL,'Lochbuie, CO 80603',26180,222,NULL,7,36252,0);
INSERT INTO "django_geo_db_location" VALUES(62726,NULL,'Ault, CO',26181,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62727,NULL,'Ault, CO 80610',26181,222,NULL,7,36253,0);
INSERT INTO "django_geo_db_location" VALUES(62728,NULL,'Briggsdale, CO',26182,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62729,NULL,'Briggsdale, CO 80611',26182,222,NULL,7,36254,0);
INSERT INTO "django_geo_db_location" VALUES(62730,NULL,'Carr, CO',26183,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62731,NULL,'Carr, CO 80612',26183,222,NULL,7,36255,0);
INSERT INTO "django_geo_db_location" VALUES(62732,NULL,'Eastlake, CO',26184,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62733,NULL,'Eastlake, CO 80614',26184,222,NULL,7,36256,0);
INSERT INTO "django_geo_db_location" VALUES(62734,NULL,'Eaton, CO',26185,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62735,NULL,'Eaton, CO 80615',26185,222,NULL,7,36257,0);
INSERT INTO "django_geo_db_location" VALUES(62736,NULL,'Evans, CO',26186,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62737,NULL,'Evans, CO 80620',26186,222,NULL,7,36258,0);
INSERT INTO "django_geo_db_location" VALUES(62738,NULL,'Fort Lupton, CO',26187,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62739,NULL,'Fort Lupton, CO 80621',26187,222,NULL,7,36259,0);
INSERT INTO "django_geo_db_location" VALUES(62740,NULL,'Galeton, CO',26188,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62741,NULL,'Galeton, CO 80622',26188,222,NULL,7,36260,0);
INSERT INTO "django_geo_db_location" VALUES(62742,NULL,'Gilcrest, CO',26189,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62743,NULL,'Gilcrest, CO 80623',26189,222,NULL,7,36261,0);
INSERT INTO "django_geo_db_location" VALUES(62744,NULL,'Gill, CO',26190,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62745,NULL,'Gill, CO 80624',26190,222,NULL,7,36262,0);
INSERT INTO "django_geo_db_location" VALUES(62746,NULL,'Greeley, CO',26191,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62747,NULL,'Greeley, CO 80630',26191,222,NULL,7,36263,0);
INSERT INTO "django_geo_db_location" VALUES(62748,NULL,'Greeley, CO 80631',26191,222,NULL,7,36264,0);
INSERT INTO "django_geo_db_location" VALUES(62749,NULL,'Greeley, CO 80632',26191,222,NULL,7,36265,0);
INSERT INTO "django_geo_db_location" VALUES(62750,NULL,'Greeley, CO 80633',26191,222,NULL,7,36266,0);
INSERT INTO "django_geo_db_location" VALUES(62751,NULL,'Greeley, CO 80634',26191,222,NULL,7,36267,0);
INSERT INTO "django_geo_db_location" VALUES(62752,NULL,'Greeley, CO 80638',26191,222,NULL,7,36268,0);
INSERT INTO "django_geo_db_location" VALUES(62753,NULL,'Greeley, CO 80639',26191,222,NULL,7,36269,0);
INSERT INTO "django_geo_db_location" VALUES(62754,NULL,'Henderson, CO',26192,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62755,NULL,'Henderson, CO 80640',26192,222,NULL,7,36270,0);
INSERT INTO "django_geo_db_location" VALUES(62756,NULL,'Hudson, CO',26193,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62757,NULL,'Hudson, CO 80642',26193,222,NULL,7,36271,0);
INSERT INTO "django_geo_db_location" VALUES(62758,NULL,'Keenesburg, CO',26194,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62759,NULL,'Keenesburg, CO 80643',26194,222,NULL,7,36272,0);
INSERT INTO "django_geo_db_location" VALUES(62760,NULL,'Kersey, CO',26195,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62761,NULL,'Kersey, CO 80644',26195,222,NULL,7,36273,0);
INSERT INTO "django_geo_db_location" VALUES(62762,NULL,'La Salle, CO',26196,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62763,NULL,'La Salle, CO 80645',26196,222,NULL,7,36274,0);
INSERT INTO "django_geo_db_location" VALUES(62764,NULL,'Lucerne, CO',26197,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62765,NULL,'Lucerne, CO 80646',26197,222,NULL,7,36275,0);
INSERT INTO "django_geo_db_location" VALUES(62766,NULL,'Nunn, CO',26198,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62767,NULL,'Nunn, CO 80648',26198,222,NULL,7,36276,0);
INSERT INTO "django_geo_db_location" VALUES(62768,NULL,'Orchard, CO',26199,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62769,NULL,'Orchard, CO 80649',26199,222,NULL,7,36277,0);
INSERT INTO "django_geo_db_location" VALUES(62770,NULL,'Pierce, CO',26200,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62771,NULL,'Pierce, CO 80650',26200,222,NULL,7,36278,0);
INSERT INTO "django_geo_db_location" VALUES(62772,NULL,'Platteville, CO',26201,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62773,NULL,'Platteville, CO 80651',26201,222,NULL,7,36279,0);
INSERT INTO "django_geo_db_location" VALUES(62774,NULL,'Roggen, CO',26202,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62775,NULL,'Roggen, CO 80652',26202,222,NULL,7,36280,0);
INSERT INTO "django_geo_db_location" VALUES(62776,NULL,'Weldona, CO',26203,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62777,NULL,'Weldona, CO 80653',26203,222,NULL,7,36281,0);
INSERT INTO "django_geo_db_location" VALUES(62778,NULL,'Wiggins, CO',26204,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62779,NULL,'Wiggins, CO 80654',26204,222,NULL,7,36282,0);
INSERT INTO "django_geo_db_location" VALUES(62780,NULL,'Fort Morgan, CO',26205,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62781,NULL,'Fort Morgan, CO 80701',26205,222,NULL,7,36283,0);
INSERT INTO "django_geo_db_location" VALUES(62782,NULL,'Log Lane Village, CO',26206,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62783,NULL,'Log Lane Village, CO 80705',26206,222,NULL,7,36284,0);
INSERT INTO "django_geo_db_location" VALUES(62784,NULL,'Akron, CO',26207,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62785,NULL,'Akron, CO 80720',26207,222,NULL,7,36285,0);
INSERT INTO "django_geo_db_location" VALUES(62786,NULL,'Amherst, CO',26208,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62787,NULL,'Amherst, CO 80721',26208,222,NULL,7,36286,0);
INSERT INTO "django_geo_db_location" VALUES(62788,NULL,'Atwood, CO',26209,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62789,NULL,'Atwood, CO 80722',26209,222,NULL,7,36287,0);
INSERT INTO "django_geo_db_location" VALUES(62790,NULL,'Brush, CO',26210,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62791,NULL,'Brush, CO 80723',26210,222,NULL,7,36288,0);
INSERT INTO "django_geo_db_location" VALUES(62792,NULL,'Crook, CO',26211,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62793,NULL,'Crook, CO 80726',26211,222,NULL,7,36289,0);
INSERT INTO "django_geo_db_location" VALUES(62794,NULL,'Eckley, CO',26212,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62795,NULL,'Eckley, CO 80727',26212,222,NULL,7,36290,0);
INSERT INTO "django_geo_db_location" VALUES(62796,NULL,'Fleming, CO',26213,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62797,NULL,'Fleming, CO 80728',26213,222,NULL,7,36291,0);
INSERT INTO "django_geo_db_location" VALUES(62798,NULL,'Grover, CO',26214,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62799,NULL,'Grover, CO 80729',26214,222,NULL,7,36292,0);
INSERT INTO "django_geo_db_location" VALUES(62800,NULL,'Haxtun, CO',26215,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62801,NULL,'Haxtun, CO 80731',26215,222,NULL,7,36293,0);
INSERT INTO "django_geo_db_location" VALUES(62802,NULL,'Hereford, CO',26216,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62803,NULL,'Hereford, CO 80732',26216,222,NULL,7,36294,0);
INSERT INTO "django_geo_db_location" VALUES(62804,NULL,'Hillrose, CO',26217,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62805,NULL,'Hillrose, CO 80733',26217,222,NULL,7,36295,0);
INSERT INTO "django_geo_db_location" VALUES(62806,NULL,'Holyoke, CO',26218,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62807,NULL,'Holyoke, CO 80734',26218,222,NULL,7,36296,0);
INSERT INTO "django_geo_db_location" VALUES(62808,NULL,'Idalia, CO',26219,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62809,NULL,'Idalia, CO 80735',26219,222,NULL,7,36297,0);
INSERT INTO "django_geo_db_location" VALUES(62810,NULL,'Iliff, CO',26220,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62811,NULL,'Iliff, CO 80736',26220,222,NULL,7,36298,0);
INSERT INTO "django_geo_db_location" VALUES(62812,NULL,'Julesburg, CO',26221,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62813,NULL,'Julesburg, CO 80737',26221,222,NULL,7,36299,0);
INSERT INTO "django_geo_db_location" VALUES(62814,NULL,'Lindon, CO',26222,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62815,NULL,'Lindon, CO 80740',26222,222,NULL,7,36300,0);
INSERT INTO "django_geo_db_location" VALUES(62816,NULL,'Merino, CO',26223,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62817,NULL,'Merino, CO 80741',26223,222,NULL,7,36301,0);
INSERT INTO "django_geo_db_location" VALUES(62818,NULL,'New Raymer, CO',26224,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62819,NULL,'New Raymer, CO 80742',26224,222,NULL,7,36302,0);
INSERT INTO "django_geo_db_location" VALUES(62820,NULL,'Otis, CO',26225,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62821,NULL,'Otis, CO 80743',26225,222,NULL,7,36303,0);
INSERT INTO "django_geo_db_location" VALUES(62822,NULL,'Ovid, CO',26226,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62823,NULL,'Ovid, CO 80744',26226,222,NULL,7,36304,0);
INSERT INTO "django_geo_db_location" VALUES(62824,NULL,'Padroni, CO',26227,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62825,NULL,'Padroni, CO 80745',26227,222,NULL,7,36305,0);
INSERT INTO "django_geo_db_location" VALUES(62826,NULL,'Paoli, CO',26228,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62827,NULL,'Paoli, CO 80746',26228,222,NULL,7,36306,0);
INSERT INTO "django_geo_db_location" VALUES(62828,NULL,'Peetz, CO',26229,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62829,NULL,'Peetz, CO 80747',26229,222,NULL,7,36307,0);
INSERT INTO "django_geo_db_location" VALUES(62830,NULL,'Sedgwick, CO',26230,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62831,NULL,'Sedgwick, CO 80749',26230,222,NULL,7,36308,0);
INSERT INTO "django_geo_db_location" VALUES(62832,NULL,'Snyder, CO',26231,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62833,NULL,'Snyder, CO 80750',26231,222,NULL,7,36309,0);
INSERT INTO "django_geo_db_location" VALUES(62834,NULL,'Sterling, CO',26232,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62835,NULL,'Sterling, CO 80751',26232,222,NULL,7,36310,0);
INSERT INTO "django_geo_db_location" VALUES(62836,NULL,'Stoneham, CO',26233,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62837,NULL,'Stoneham, CO 80754',26233,222,NULL,7,36311,0);
INSERT INTO "django_geo_db_location" VALUES(62838,NULL,'Vernon, CO',26234,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62839,NULL,'Vernon, CO 80755',26234,222,NULL,7,36312,0);
INSERT INTO "django_geo_db_location" VALUES(62840,NULL,'Woodrow, CO',26235,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62841,NULL,'Woodrow, CO 80757',26235,222,NULL,7,36313,0);
INSERT INTO "django_geo_db_location" VALUES(62842,NULL,'Wray, CO',26236,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62843,NULL,'Wray, CO 80758',26236,222,NULL,7,36314,0);
INSERT INTO "django_geo_db_location" VALUES(62844,NULL,'Yuma, CO',26237,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62845,NULL,'Yuma, CO 80759',26237,222,NULL,7,36315,0);
INSERT INTO "django_geo_db_location" VALUES(62846,NULL,'Anton, CO',26238,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62847,NULL,'Anton, CO 80801',26238,222,NULL,7,36316,0);
INSERT INTO "django_geo_db_location" VALUES(62848,NULL,'Arapahoe, CO',26239,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62849,NULL,'Arapahoe, CO 80802',26239,222,NULL,7,36317,0);
INSERT INTO "django_geo_db_location" VALUES(62850,NULL,'Arriba, CO',26240,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62851,NULL,'Arriba, CO 80804',26240,222,NULL,7,36318,0);
INSERT INTO "django_geo_db_location" VALUES(62852,NULL,'Bethune, CO',26241,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62853,NULL,'Bethune, CO 80805',26241,222,NULL,7,36319,0);
INSERT INTO "django_geo_db_location" VALUES(62854,NULL,'Burlington, CO',26242,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62855,NULL,'Burlington, CO 80807',26242,222,NULL,7,36320,0);
INSERT INTO "django_geo_db_location" VALUES(62856,NULL,'Calhan, CO',26243,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62857,NULL,'Calhan, CO 80808',26243,222,NULL,7,36321,0);
INSERT INTO "django_geo_db_location" VALUES(62858,NULL,'Cascade, CO',26244,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62859,NULL,'Cascade, CO 80809',26244,222,NULL,7,36322,0);
INSERT INTO "django_geo_db_location" VALUES(62860,NULL,'Cheyenne Wells, CO',26245,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62861,NULL,'Cheyenne Wells, CO 80810',26245,222,NULL,7,36323,0);
INSERT INTO "django_geo_db_location" VALUES(62862,NULL,'Cope, CO',26246,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62863,NULL,'Cope, CO 80812',26246,222,NULL,7,36324,0);
INSERT INTO "django_geo_db_location" VALUES(62864,NULL,'Cripple Creek, CO',26247,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62865,NULL,'Cripple Creek, CO 80813',26247,222,NULL,7,36325,0);
INSERT INTO "django_geo_db_location" VALUES(62866,NULL,'Divide, CO',26248,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62867,NULL,'Divide, CO 80814',26248,222,NULL,7,36326,0);
INSERT INTO "django_geo_db_location" VALUES(62868,NULL,'Flagler, CO',26249,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62869,NULL,'Flagler, CO 80815',26249,222,NULL,7,36327,0);
INSERT INTO "django_geo_db_location" VALUES(62870,NULL,'Florissant, CO',26250,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62871,NULL,'Florissant, CO 80816',26250,222,NULL,7,36328,0);
INSERT INTO "django_geo_db_location" VALUES(62872,NULL,'Fountain, CO',26251,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62873,NULL,'Fountain, CO 80817',26251,222,NULL,7,36329,0);
INSERT INTO "django_geo_db_location" VALUES(62874,NULL,'Genoa, CO',26252,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62875,NULL,'Genoa, CO 80818',26252,222,NULL,7,36330,0);
INSERT INTO "django_geo_db_location" VALUES(62876,NULL,'Green Mountain Falls, CO',26253,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62877,NULL,'Green Mountain Falls, CO 80819',26253,222,NULL,7,36331,0);
INSERT INTO "django_geo_db_location" VALUES(62878,NULL,'Guffey, CO',26254,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62879,NULL,'Guffey, CO 80820',26254,222,NULL,7,36332,0);
INSERT INTO "django_geo_db_location" VALUES(62880,NULL,'Hugo, CO',26255,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62881,NULL,'Hugo, CO 80821',26255,222,NULL,7,36333,0);
INSERT INTO "django_geo_db_location" VALUES(62882,NULL,'Joes, CO',26256,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62883,NULL,'Joes, CO 80822',26256,222,NULL,7,36334,0);
INSERT INTO "django_geo_db_location" VALUES(62884,NULL,'Karval, CO',26257,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62885,NULL,'Karval, CO 80823',26257,222,NULL,7,36335,0);
INSERT INTO "django_geo_db_location" VALUES(62886,NULL,'Kirk, CO',26258,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62887,NULL,'Kirk, CO 80824',26258,222,NULL,7,36336,0);
INSERT INTO "django_geo_db_location" VALUES(62888,NULL,'Kit Carson, CO',26259,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62889,NULL,'Kit Carson, CO 80825',26259,222,NULL,7,36337,0);
INSERT INTO "django_geo_db_location" VALUES(62890,NULL,'Limon, CO',26260,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62891,NULL,'Limon, CO 80826',26260,222,NULL,7,36338,0);
INSERT INTO "django_geo_db_location" VALUES(62892,NULL,'Lake George, CO',26261,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62893,NULL,'Lake George, CO 80827',26261,222,NULL,7,36339,0);
INSERT INTO "django_geo_db_location" VALUES(62894,NULL,'Limon, CO 80828',26260,222,NULL,7,36340,0);
INSERT INTO "django_geo_db_location" VALUES(62895,NULL,'Manitou Springs, CO',26262,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62896,NULL,'Manitou Springs, CO 80829',26262,222,NULL,7,36341,0);
INSERT INTO "django_geo_db_location" VALUES(62897,NULL,'Matheson, CO',26263,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62898,NULL,'Matheson, CO 80830',26263,222,NULL,7,36342,0);
INSERT INTO "django_geo_db_location" VALUES(62899,NULL,'Peyton, CO',26264,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62900,NULL,'Peyton, CO 80831',26264,222,NULL,7,36343,0);
INSERT INTO "django_geo_db_location" VALUES(62901,NULL,'Ramah, CO',26265,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62902,NULL,'Ramah, CO 80832',26265,222,NULL,7,36344,0);
INSERT INTO "django_geo_db_location" VALUES(62903,NULL,'Rush, CO',26266,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62904,NULL,'Rush, CO 80833',26266,222,NULL,7,36345,0);
INSERT INTO "django_geo_db_location" VALUES(62905,NULL,'Seibert, CO',26267,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62906,NULL,'Seibert, CO 80834',26267,222,NULL,7,36346,0);
INSERT INTO "django_geo_db_location" VALUES(62907,NULL,'Simla, CO',26268,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62908,NULL,'Simla, CO 80835',26268,222,NULL,7,36347,0);
INSERT INTO "django_geo_db_location" VALUES(62909,NULL,'Stratton, CO',26269,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62910,NULL,'Stratton, CO 80836',26269,222,NULL,7,36348,0);
INSERT INTO "django_geo_db_location" VALUES(62911,NULL,'U S A F Academy, CO',26270,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62912,NULL,'U S A F Academy, CO 80840',26270,222,NULL,7,36349,0);
INSERT INTO "django_geo_db_location" VALUES(62913,NULL,'U S A F Academy, CO 80841',26270,222,NULL,7,36350,0);
INSERT INTO "django_geo_db_location" VALUES(62914,NULL,'Victor, CO',26271,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62915,NULL,'Victor, CO 80860',26271,222,NULL,7,36351,0);
INSERT INTO "django_geo_db_location" VALUES(62916,NULL,'Vona, CO',26272,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62917,NULL,'Vona, CO 80861',26272,222,NULL,7,36352,0);
INSERT INTO "django_geo_db_location" VALUES(62918,NULL,'Wild Horse, CO',26273,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62919,NULL,'Wild Horse, CO 80862',26273,222,NULL,7,36353,0);
INSERT INTO "django_geo_db_location" VALUES(62920,NULL,'Woodland Park, CO',26274,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62921,NULL,'Woodland Park, CO 80863',26274,222,NULL,7,36354,0);
INSERT INTO "django_geo_db_location" VALUES(62922,NULL,'Yoder, CO',26275,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62923,NULL,'Yoder, CO 80864',26275,222,NULL,7,36355,0);
INSERT INTO "django_geo_db_location" VALUES(62924,NULL,'Woodland Park, CO 80866',26274,222,NULL,7,36356,0);
INSERT INTO "django_geo_db_location" VALUES(62925,NULL,'Colorado Springs, CO 80901',26151,222,NULL,7,36357,0);
INSERT INTO "django_geo_db_location" VALUES(62926,NULL,'Colorado Springs, CO 80902',26151,222,NULL,7,36358,0);
INSERT INTO "django_geo_db_location" VALUES(62927,NULL,'Colorado Springs, CO 80903',26151,222,NULL,7,36359,0);
INSERT INTO "django_geo_db_location" VALUES(62928,NULL,'Colorado Springs, CO 80904',26151,222,NULL,7,36360,0);
INSERT INTO "django_geo_db_location" VALUES(62929,NULL,'Colorado Springs, CO 80905',26151,222,NULL,7,36361,0);
INSERT INTO "django_geo_db_location" VALUES(62930,NULL,'Colorado Springs, CO 80906',26151,222,NULL,7,36362,0);
INSERT INTO "django_geo_db_location" VALUES(62931,NULL,'Colorado Springs, CO 80907',26151,222,NULL,7,36363,0);
INSERT INTO "django_geo_db_location" VALUES(62932,NULL,'Colorado Springs, CO 80908',26151,222,NULL,7,36364,0);
INSERT INTO "django_geo_db_location" VALUES(62933,NULL,'Colorado Springs, CO 80909',26151,222,NULL,7,36365,0);
INSERT INTO "django_geo_db_location" VALUES(62934,NULL,'Colorado Springs, CO 80910',26151,222,NULL,7,36366,0);
INSERT INTO "django_geo_db_location" VALUES(62935,NULL,'Colorado Springs, CO 80911',26151,222,NULL,7,36367,0);
INSERT INTO "django_geo_db_location" VALUES(62936,NULL,'Colorado Springs, CO 80912',26151,222,NULL,7,36368,0);
INSERT INTO "django_geo_db_location" VALUES(62937,NULL,'Colorado Springs, CO 80913',26151,222,NULL,7,36369,0);
INSERT INTO "django_geo_db_location" VALUES(62938,NULL,'Colorado Springs, CO 80914',26151,222,NULL,7,36370,0);
INSERT INTO "django_geo_db_location" VALUES(62939,NULL,'Colorado Springs, CO 80915',26151,222,NULL,7,36371,0);
INSERT INTO "django_geo_db_location" VALUES(62940,NULL,'Colorado Springs, CO 80916',26151,222,NULL,7,36372,0);
INSERT INTO "django_geo_db_location" VALUES(62941,NULL,'Colorado Springs, CO 80917',26151,222,NULL,7,36373,0);
INSERT INTO "django_geo_db_location" VALUES(62942,NULL,'Colorado Springs, CO 80918',26151,222,NULL,7,36374,0);
INSERT INTO "django_geo_db_location" VALUES(62943,NULL,'Colorado Springs, CO 80919',26151,222,NULL,7,36375,0);
INSERT INTO "django_geo_db_location" VALUES(62944,NULL,'Colorado Springs, CO 80920',26151,222,NULL,7,36376,0);
INSERT INTO "django_geo_db_location" VALUES(62945,NULL,'Colorado Springs, CO 80921',26151,222,NULL,7,36377,0);
INSERT INTO "django_geo_db_location" VALUES(62946,NULL,'Colorado Springs, CO 80922',26151,222,NULL,7,36378,0);
INSERT INTO "django_geo_db_location" VALUES(62947,NULL,'Breckenridge, CO 80924',26099,222,NULL,7,36379,0);
INSERT INTO "django_geo_db_location" VALUES(62948,NULL,'Colorado Springs, CO 80925',26151,222,NULL,7,36380,0);
INSERT INTO "django_geo_db_location" VALUES(62949,NULL,'Colorado Springs, CO 80926',26151,222,NULL,7,36381,0);
INSERT INTO "django_geo_db_location" VALUES(62950,NULL,'Colorado Springs, CO 80928',26151,222,NULL,7,36382,0);
INSERT INTO "django_geo_db_location" VALUES(62951,NULL,'Colorado Springs, CO 80929',26151,222,NULL,7,36383,0);
INSERT INTO "django_geo_db_location" VALUES(62952,NULL,'Colorado Springs, CO 80930',26151,222,NULL,7,36384,0);
INSERT INTO "django_geo_db_location" VALUES(62953,NULL,'Colorado Springs, CO 80931',26151,222,NULL,7,36385,0);
INSERT INTO "django_geo_db_location" VALUES(62954,NULL,'Colorado Springs, CO 80932',26151,222,NULL,7,36386,0);
INSERT INTO "django_geo_db_location" VALUES(62955,NULL,'Colorado Springs, CO 80933',26151,222,NULL,7,36387,0);
INSERT INTO "django_geo_db_location" VALUES(62956,NULL,'Colorado Springs, CO 80934',26151,222,NULL,7,36388,0);
INSERT INTO "django_geo_db_location" VALUES(62957,NULL,'Colorado Springs, CO 80935',26151,222,NULL,7,36389,0);
INSERT INTO "django_geo_db_location" VALUES(62958,NULL,'Colorado Springs, CO 80936',26151,222,NULL,7,36390,0);
INSERT INTO "django_geo_db_location" VALUES(62959,NULL,'Colorado Springs, CO 80937',26151,222,NULL,7,36391,0);
INSERT INTO "django_geo_db_location" VALUES(62960,NULL,'Colorado Springs, CO 80940',26151,222,NULL,7,36392,0);
INSERT INTO "django_geo_db_location" VALUES(62961,NULL,'Colorado Springs, CO 80941',26151,222,NULL,7,36393,0);
INSERT INTO "django_geo_db_location" VALUES(62962,NULL,'Colorado Springs, CO 80942',26151,222,NULL,7,36394,0);
INSERT INTO "django_geo_db_location" VALUES(62963,NULL,'Colorado Springs, CO 80943',26151,222,NULL,7,36395,0);
INSERT INTO "django_geo_db_location" VALUES(62964,NULL,'Colorado Springs, CO 80944',26151,222,NULL,7,36396,0);
INSERT INTO "django_geo_db_location" VALUES(62965,NULL,'Colorado Springs, CO 80945',26151,222,NULL,7,36397,0);
INSERT INTO "django_geo_db_location" VALUES(62966,NULL,'Colorado Springs, CO 80946',26151,222,NULL,7,36398,0);
INSERT INTO "django_geo_db_location" VALUES(62967,NULL,'Colorado Springs, CO 80947',26151,222,NULL,7,36399,0);
INSERT INTO "django_geo_db_location" VALUES(62968,NULL,'Colorado Springs, CO 80949',26151,222,NULL,7,36400,0);
INSERT INTO "django_geo_db_location" VALUES(62969,NULL,'Colorado Springs, CO 80950',26151,222,NULL,7,36401,0);
INSERT INTO "django_geo_db_location" VALUES(62970,NULL,'Colorado Springs, CO 80960',26151,222,NULL,7,36402,0);
INSERT INTO "django_geo_db_location" VALUES(62971,NULL,'Colorado Springs, CO 80962',26151,222,NULL,7,36403,0);
INSERT INTO "django_geo_db_location" VALUES(62972,NULL,'Colorado Springs, CO 80970',26151,222,NULL,7,36404,0);
INSERT INTO "django_geo_db_location" VALUES(62973,NULL,'Colorado Springs, CO 80977',26151,222,NULL,7,36405,0);
INSERT INTO "django_geo_db_location" VALUES(62974,NULL,'Colorado Springs, CO 80995',26151,222,NULL,7,36406,0);
INSERT INTO "django_geo_db_location" VALUES(62975,NULL,'Colorado Springs, CO 80997',26151,222,NULL,7,36407,0);
INSERT INTO "django_geo_db_location" VALUES(62976,NULL,'Pueblo, CO',26276,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62977,NULL,'Pueblo, CO 81001',26276,222,NULL,7,36408,0);
INSERT INTO "django_geo_db_location" VALUES(62978,NULL,'Pueblo, CO 81002',26276,222,NULL,7,36409,0);
INSERT INTO "django_geo_db_location" VALUES(62979,NULL,'Pueblo, CO 81003',26276,222,NULL,7,36410,0);
INSERT INTO "django_geo_db_location" VALUES(62980,NULL,'Pueblo, CO 81004',26276,222,NULL,7,36411,0);
INSERT INTO "django_geo_db_location" VALUES(62981,NULL,'Pueblo, CO 81005',26276,222,NULL,7,36412,0);
INSERT INTO "django_geo_db_location" VALUES(62982,NULL,'Pueblo, CO 81006',26276,222,NULL,7,36413,0);
INSERT INTO "django_geo_db_location" VALUES(62983,NULL,'Pueblo, CO 81007',26276,222,NULL,7,36414,0);
INSERT INTO "django_geo_db_location" VALUES(62984,NULL,'Pueblo, CO 81008',26276,222,NULL,7,36415,0);
INSERT INTO "django_geo_db_location" VALUES(62985,NULL,'Pueblo, CO 81009',26276,222,NULL,7,36416,0);
INSERT INTO "django_geo_db_location" VALUES(62986,NULL,'Pueblo, CO 81010',26276,222,NULL,7,36417,0);
INSERT INTO "django_geo_db_location" VALUES(62987,NULL,'Pueblo, CO 81011',26276,222,NULL,7,36418,0);
INSERT INTO "django_geo_db_location" VALUES(62988,NULL,'Pueblo, CO 81012',26276,222,NULL,7,36419,0);
INSERT INTO "django_geo_db_location" VALUES(62989,NULL,'Pueblo, CO 81013',26276,222,NULL,7,36420,0);
INSERT INTO "django_geo_db_location" VALUES(62990,NULL,'Pueblo, CO 81014',26276,222,NULL,7,36421,0);
INSERT INTO "django_geo_db_location" VALUES(62991,NULL,'Pueblo, CO 81015',26276,222,NULL,7,36422,0);
INSERT INTO "django_geo_db_location" VALUES(62992,NULL,'Colorado City, CO',26277,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62993,NULL,'Colorado City, CO 81019',26277,222,NULL,7,36423,0);
INSERT INTO "django_geo_db_location" VALUES(62994,NULL,'Aguilar, CO',26278,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62995,NULL,'Aguilar, CO 81020',26278,222,NULL,7,36424,0);
INSERT INTO "django_geo_db_location" VALUES(62996,NULL,'Arlington, CO',26279,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62997,NULL,'Arlington, CO 81021',26279,222,NULL,7,36425,0);
INSERT INTO "django_geo_db_location" VALUES(62998,NULL,'Avondale, CO',26280,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(62999,NULL,'Avondale, CO 81022',26280,222,NULL,7,36426,0);
INSERT INTO "django_geo_db_location" VALUES(63000,NULL,'Beulah, CO',26281,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63001,NULL,'Beulah, CO 81023',26281,222,NULL,7,36427,0);
INSERT INTO "django_geo_db_location" VALUES(63002,NULL,'Boncarbo, CO',26282,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63003,NULL,'Boncarbo, CO 81024',26282,222,NULL,7,36428,0);
INSERT INTO "django_geo_db_location" VALUES(63004,NULL,'Boone, CO',26283,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63005,NULL,'Boone, CO 81025',26283,222,NULL,7,36429,0);
INSERT INTO "django_geo_db_location" VALUES(63006,NULL,'Branson, CO',26284,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63007,NULL,'Branson, CO 81027',26284,222,NULL,7,36430,0);
INSERT INTO "django_geo_db_location" VALUES(63008,NULL,'Campo, CO',26285,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63009,NULL,'Campo, CO 81029',26285,222,NULL,7,36431,0);
INSERT INTO "django_geo_db_location" VALUES(63010,NULL,'Cheraw, CO',26286,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63011,NULL,'Cheraw, CO 81030',26286,222,NULL,7,36432,0);
INSERT INTO "django_geo_db_location" VALUES(63012,NULL,'Crowley, CO',26287,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63013,NULL,'Crowley, CO 81033',26287,222,NULL,7,36433,0);
INSERT INTO "django_geo_db_location" VALUES(63014,NULL,'Crowley, CO 81034',26287,222,NULL,7,36434,0);
INSERT INTO "django_geo_db_location" VALUES(63015,NULL,'Eads, CO',26288,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63016,NULL,'Eads, CO 81036',26288,222,NULL,7,36435,0);
INSERT INTO "django_geo_db_location" VALUES(63017,NULL,'Fort Lyon, CO',26289,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63018,NULL,'Fort Lyon, CO 81038',26289,222,NULL,7,36436,0);
INSERT INTO "django_geo_db_location" VALUES(63019,NULL,'Fowler, CO',26290,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63020,NULL,'Fowler, CO 81039',26290,222,NULL,7,36437,0);
INSERT INTO "django_geo_db_location" VALUES(63021,NULL,'Gardner, CO',26291,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63022,NULL,'Gardner, CO 81040',26291,222,NULL,7,36438,0);
INSERT INTO "django_geo_db_location" VALUES(63023,NULL,'Granada, CO',26292,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63024,NULL,'Granada, CO 81041',26292,222,NULL,7,36439,0);
INSERT INTO "django_geo_db_location" VALUES(63025,NULL,'Gulnare, CO',26293,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63026,NULL,'Gulnare, CO 81042',26293,222,NULL,7,36440,0);
INSERT INTO "django_geo_db_location" VALUES(63027,NULL,'Hartman, CO',26294,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63028,NULL,'Hartman, CO 81043',26294,222,NULL,7,36441,0);
INSERT INTO "django_geo_db_location" VALUES(63029,NULL,'Hasty, CO',26295,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63030,NULL,'Hasty, CO 81044',26295,222,NULL,7,36442,0);
INSERT INTO "django_geo_db_location" VALUES(63031,NULL,'Haswell, CO',26296,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63032,NULL,'Haswell, CO 81045',26296,222,NULL,7,36443,0);
INSERT INTO "django_geo_db_location" VALUES(63033,NULL,'Hoehne, CO',26297,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63034,NULL,'Hoehne, CO 81046',26297,222,NULL,7,36444,0);
INSERT INTO "django_geo_db_location" VALUES(63035,NULL,'Holly, CO',26298,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63036,NULL,'Holly, CO 81047',26298,222,NULL,7,36445,0);
INSERT INTO "django_geo_db_location" VALUES(63037,NULL,'Kim, CO',26299,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63038,NULL,'Kim, CO 81049',26299,222,NULL,7,36446,0);
INSERT INTO "django_geo_db_location" VALUES(63039,NULL,'La Junta, CO',26300,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63040,NULL,'La Junta, CO 81050',26300,222,NULL,7,36447,0);
INSERT INTO "django_geo_db_location" VALUES(63041,NULL,'Lamar, CO',26301,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63042,NULL,'Lamar, CO 81052',26301,222,NULL,7,36448,0);
INSERT INTO "django_geo_db_location" VALUES(63043,NULL,'Las Animas, CO',26302,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63044,NULL,'Las Animas, CO 81054',26302,222,NULL,7,36449,0);
INSERT INTO "django_geo_db_location" VALUES(63045,NULL,'La Veta, CO',26303,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63046,NULL,'La Veta, CO 81055',26303,222,NULL,7,36450,0);
INSERT INTO "django_geo_db_location" VALUES(63047,NULL,'McClave, CO',26304,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63048,NULL,'McClave, CO 81057',26304,222,NULL,7,36451,0);
INSERT INTO "django_geo_db_location" VALUES(63049,NULL,'Manzanola, CO',26305,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63050,NULL,'Manzanola, CO 81058',26305,222,NULL,7,36452,0);
INSERT INTO "django_geo_db_location" VALUES(63051,NULL,'Model, CO',26306,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63052,NULL,'Model, CO 81059',26306,222,NULL,7,36453,0);
INSERT INTO "django_geo_db_location" VALUES(63053,NULL,'Olney Springs, CO',26307,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63054,NULL,'Olney Springs, CO 81062',26307,222,NULL,7,36454,0);
INSERT INTO "django_geo_db_location" VALUES(63055,NULL,'Ordway, CO',26308,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63056,NULL,'Ordway, CO 81063',26308,222,NULL,7,36455,0);
INSERT INTO "django_geo_db_location" VALUES(63057,NULL,'Pritchett, CO',26309,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63058,NULL,'Pritchett, CO 81064',26309,222,NULL,7,36456,0);
INSERT INTO "django_geo_db_location" VALUES(63059,NULL,'Red Wing, CO',26310,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63060,NULL,'Red Wing, CO 81066',26310,222,NULL,7,36457,0);
INSERT INTO "django_geo_db_location" VALUES(63061,NULL,'Rocky Ford, CO',26311,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63062,NULL,'Rocky Ford, CO 81067',26311,222,NULL,7,36458,0);
INSERT INTO "django_geo_db_location" VALUES(63063,NULL,'Rye, CO',26312,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63064,NULL,'Rye, CO 81069',26312,222,NULL,7,36459,0);
INSERT INTO "django_geo_db_location" VALUES(63065,NULL,'Sheridan Lake, CO',26313,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63066,NULL,'Sheridan Lake, CO 81071',26313,222,NULL,7,36460,0);
INSERT INTO "django_geo_db_location" VALUES(63067,NULL,'Springfield, CO',26314,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63068,NULL,'Springfield, CO 81073',26314,222,NULL,7,36461,0);
INSERT INTO "django_geo_db_location" VALUES(63069,NULL,'Starkville, CO',26315,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63070,NULL,'Starkville, CO 81074',26315,222,NULL,7,36462,0);
INSERT INTO "django_geo_db_location" VALUES(63071,NULL,'Sugar City, CO',26316,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63072,NULL,'Sugar City, CO 81076',26316,222,NULL,7,36463,0);
INSERT INTO "django_geo_db_location" VALUES(63073,NULL,'Swink, CO',26317,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63074,NULL,'Swink, CO 81077',26317,222,NULL,7,36464,0);
INSERT INTO "django_geo_db_location" VALUES(63075,NULL,'Colorado City, CO 81079',26277,222,NULL,7,36465,0);
INSERT INTO "django_geo_db_location" VALUES(63076,NULL,'Trinchera, CO',26318,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63077,NULL,'Trinchera, CO 81081',26318,222,NULL,7,36466,0);
INSERT INTO "django_geo_db_location" VALUES(63078,NULL,'Trinidad, CO',26319,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63079,NULL,'Trinidad, CO 81082',26319,222,NULL,7,36467,0);
INSERT INTO "django_geo_db_location" VALUES(63080,NULL,'Two Buttes, CO',26320,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63081,NULL,'Two Buttes, CO 81084',26320,222,NULL,7,36468,0);
INSERT INTO "django_geo_db_location" VALUES(63082,NULL,'Vilas, CO',26321,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63083,NULL,'Vilas, CO 81087',26321,222,NULL,7,36469,0);
INSERT INTO "django_geo_db_location" VALUES(63084,NULL,'Walsenburg, CO',26322,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63085,NULL,'Walsenburg, CO 81089',26322,222,NULL,7,36470,0);
INSERT INTO "django_geo_db_location" VALUES(63086,NULL,'Walsh, CO',26323,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63087,NULL,'Walsh, CO 81090',26323,222,NULL,7,36471,0);
INSERT INTO "django_geo_db_location" VALUES(63088,NULL,'Weston, CO',26324,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63089,NULL,'Weston, CO 81091',26324,222,NULL,7,36472,0);
INSERT INTO "django_geo_db_location" VALUES(63090,NULL,'Wiley, CO',26325,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63091,NULL,'Wiley, CO 81092',26325,222,NULL,7,36473,0);
INSERT INTO "django_geo_db_location" VALUES(63092,NULL,'Alamosa, CO',26326,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63093,NULL,'Alamosa, CO 81101',26326,222,NULL,7,36474,0);
INSERT INTO "django_geo_db_location" VALUES(63094,NULL,'Alamosa, CO 81102',26326,222,NULL,7,36475,0);
INSERT INTO "django_geo_db_location" VALUES(63095,NULL,'Antonito, CO',26327,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63096,NULL,'Antonito, CO 81120',26327,222,NULL,7,36476,0);
INSERT INTO "django_geo_db_location" VALUES(63097,NULL,'Arboles, CO',26328,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63098,NULL,'Arboles, CO 81121',26328,222,NULL,7,36477,0);
INSERT INTO "django_geo_db_location" VALUES(63099,NULL,'Bayfield, CO',26329,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63100,NULL,'Bayfield, CO 81122',26329,222,NULL,7,36478,0);
INSERT INTO "django_geo_db_location" VALUES(63101,NULL,'Blanca, CO',26330,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63102,NULL,'Blanca, CO 81123',26330,222,NULL,7,36479,0);
INSERT INTO "django_geo_db_location" VALUES(63103,NULL,'Capulin, CO',26331,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63104,NULL,'Capulin, CO 81124',26331,222,NULL,7,36480,0);
INSERT INTO "django_geo_db_location" VALUES(63105,NULL,'Center, CO',26332,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63106,NULL,'Center, CO 81125',26332,222,NULL,7,36481,0);
INSERT INTO "django_geo_db_location" VALUES(63107,NULL,'Chama, CO',26333,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63108,NULL,'Chama, CO 81126',26333,222,NULL,7,36482,0);
INSERT INTO "django_geo_db_location" VALUES(63109,NULL,'Chimney Rock, CO',26334,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63110,NULL,'Chimney Rock, CO 81127',26334,222,NULL,7,36483,0);
INSERT INTO "django_geo_db_location" VALUES(63111,NULL,'Chromo, CO',26335,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63112,NULL,'Chromo, CO 81128',26335,222,NULL,7,36484,0);
INSERT INTO "django_geo_db_location" VALUES(63113,NULL,'Conejos, CO',26336,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63114,NULL,'Conejos, CO 81129',26336,222,NULL,7,36485,0);
INSERT INTO "django_geo_db_location" VALUES(63115,NULL,'Creede, CO',26337,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63116,NULL,'Creede, CO 81130',26337,222,NULL,7,36486,0);
INSERT INTO "django_geo_db_location" VALUES(63117,NULL,'Crestone, CO',26338,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63118,NULL,'Crestone, CO 81131',26338,222,NULL,7,36487,0);
INSERT INTO "django_geo_db_location" VALUES(63119,NULL,'Del Norte, CO',26339,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63120,NULL,'Del Norte, CO 81132',26339,222,NULL,7,36488,0);
INSERT INTO "django_geo_db_location" VALUES(63121,NULL,'Fort Garland, CO',26340,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63122,NULL,'Fort Garland, CO 81133',26340,222,NULL,7,36489,0);
INSERT INTO "django_geo_db_location" VALUES(63123,NULL,'Garcia, CO',26341,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63124,NULL,'Garcia, CO 81134',26341,222,NULL,7,36490,0);
INSERT INTO "django_geo_db_location" VALUES(63125,NULL,'Homelake, CO',26342,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63126,NULL,'Homelake, CO 81135',26342,222,NULL,7,36491,0);
INSERT INTO "django_geo_db_location" VALUES(63127,NULL,'Hooper, CO',26343,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63128,NULL,'Hooper, CO 81136',26343,222,NULL,7,36492,0);
INSERT INTO "django_geo_db_location" VALUES(63129,NULL,'Ignacio, CO',26344,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63130,NULL,'Ignacio, CO 81137',26344,222,NULL,7,36493,0);
INSERT INTO "django_geo_db_location" VALUES(63131,NULL,'Jaroso, CO',26345,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63132,NULL,'Jaroso, CO 81138',26345,222,NULL,7,36494,0);
INSERT INTO "django_geo_db_location" VALUES(63133,NULL,'La Jara, CO',26346,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63134,NULL,'La Jara, CO 81140',26346,222,NULL,7,36495,0);
INSERT INTO "django_geo_db_location" VALUES(63135,NULL,'Manassa, CO',26347,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63136,NULL,'Manassa, CO 81141',26347,222,NULL,7,36496,0);
INSERT INTO "django_geo_db_location" VALUES(63137,NULL,'Moffat, CO',26348,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63138,NULL,'Moffat, CO 81143',26348,222,NULL,7,36497,0);
INSERT INTO "django_geo_db_location" VALUES(63139,NULL,'Monte Vista, CO',26349,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63140,NULL,'Monte Vista, CO 81144',26349,222,NULL,7,36498,0);
INSERT INTO "django_geo_db_location" VALUES(63141,NULL,'Mosca, CO',26350,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63142,NULL,'Mosca, CO 81146',26350,222,NULL,7,36499,0);
INSERT INTO "django_geo_db_location" VALUES(63143,NULL,'Pagosa Springs, CO',26351,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63144,NULL,'Pagosa Springs, CO 81147',26351,222,NULL,7,36500,0);
INSERT INTO "django_geo_db_location" VALUES(63145,NULL,'Romeo, CO',26352,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63146,NULL,'Romeo, CO 81148',26352,222,NULL,7,36501,0);
INSERT INTO "django_geo_db_location" VALUES(63147,NULL,'Saguache, CO',26353,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63148,NULL,'Saguache, CO 81149',26353,222,NULL,7,36502,0);
INSERT INTO "django_geo_db_location" VALUES(63149,NULL,'Sanford, CO',26354,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63150,NULL,'Sanford, CO 81151',26354,222,NULL,7,36503,0);
INSERT INTO "django_geo_db_location" VALUES(63151,NULL,'San Luis, CO',26355,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63152,NULL,'San Luis, CO 81152',26355,222,NULL,7,36504,0);
INSERT INTO "django_geo_db_location" VALUES(63153,NULL,'San Pablo, CO',26356,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63154,NULL,'San Pablo, CO 81153',26356,222,NULL,7,36505,0);
INSERT INTO "django_geo_db_location" VALUES(63155,NULL,'South Fork, CO',26357,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63156,NULL,'South Fork, CO 81154',26357,222,NULL,7,36506,0);
INSERT INTO "django_geo_db_location" VALUES(63157,NULL,'Villa Grove, CO',26358,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63158,NULL,'Villa Grove, CO 81155',26358,222,NULL,7,36507,0);
INSERT INTO "django_geo_db_location" VALUES(63159,NULL,'Pagosa Springs, CO 81157',26351,222,NULL,7,36508,0);
INSERT INTO "django_geo_db_location" VALUES(63160,NULL,'Salida, CO',26359,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63161,NULL,'Salida, CO 81201',26359,222,NULL,7,36509,0);
INSERT INTO "django_geo_db_location" VALUES(63162,NULL,'Almont, CO',26360,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63163,NULL,'Almont, CO 81210',26360,222,NULL,7,36510,0);
INSERT INTO "django_geo_db_location" VALUES(63164,NULL,'Buena Vista, CO',26361,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63165,NULL,'Buena Vista, CO 81211',26361,222,NULL,7,36511,0);
INSERT INTO "django_geo_db_location" VALUES(63166,NULL,'Canon City, CO',26362,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63167,NULL,'Canon City, CO 81212',26362,222,NULL,7,36512,0);
INSERT INTO "django_geo_db_location" VALUES(63168,NULL,'Canon City, CO 81215',26362,222,NULL,7,36513,0);
INSERT INTO "django_geo_db_location" VALUES(63169,NULL,'Cimarron, CO',26363,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63170,NULL,'Cimarron, CO 81220',26363,222,NULL,7,36514,0);
INSERT INTO "django_geo_db_location" VALUES(63171,NULL,'Coal Creek, CO',26364,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63172,NULL,'Coal Creek, CO 81221',26364,222,NULL,7,36515,0);
INSERT INTO "django_geo_db_location" VALUES(63173,NULL,'Coaldale, CO',26365,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63174,NULL,'Coaldale, CO 81222',26365,222,NULL,7,36516,0);
INSERT INTO "django_geo_db_location" VALUES(63175,NULL,'Cotopaxi, CO',26366,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63176,NULL,'Cotopaxi, CO 81223',26366,222,NULL,7,36517,0);
INSERT INTO "django_geo_db_location" VALUES(63177,NULL,'Crested Butte, CO',26367,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63178,NULL,'Crested Butte, CO 81224',26367,222,NULL,7,36518,0);
INSERT INTO "django_geo_db_location" VALUES(63179,NULL,'Crested Butte, CO 81225',26367,222,NULL,7,36519,0);
INSERT INTO "django_geo_db_location" VALUES(63180,NULL,'Florence, CO',26368,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63181,NULL,'Florence, CO 81226',26368,222,NULL,7,36520,0);
INSERT INTO "django_geo_db_location" VALUES(63182,NULL,'Monarch, CO',26369,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63183,NULL,'Monarch, CO 81227',26369,222,NULL,7,36521,0);
INSERT INTO "django_geo_db_location" VALUES(63184,NULL,'Granite, CO',26370,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63185,NULL,'Granite, CO 81228',26370,222,NULL,7,36522,0);
INSERT INTO "django_geo_db_location" VALUES(63186,NULL,'Gunnison, CO',26371,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63187,NULL,'Gunnison, CO 81230',26371,222,NULL,7,36523,0);
INSERT INTO "django_geo_db_location" VALUES(63188,NULL,'Gunnison, CO 81231',26371,222,NULL,7,36524,0);
INSERT INTO "django_geo_db_location" VALUES(63189,NULL,'Hillside, CO',26372,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63190,NULL,'Hillside, CO 81232',26372,222,NULL,7,36525,0);
INSERT INTO "django_geo_db_location" VALUES(63191,NULL,'Howard, CO',26373,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63192,NULL,'Howard, CO 81233',26373,222,NULL,7,36526,0);
INSERT INTO "django_geo_db_location" VALUES(63193,NULL,'Lake City, CO',26374,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63194,NULL,'Lake City, CO 81235',26374,222,NULL,7,36527,0);
INSERT INTO "django_geo_db_location" VALUES(63195,NULL,'Nathrop, CO',26375,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63196,NULL,'Nathrop, CO 81236',26375,222,NULL,7,36528,0);
INSERT INTO "django_geo_db_location" VALUES(63197,NULL,'Ohio City, CO',26376,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63198,NULL,'Ohio City, CO 81237',26376,222,NULL,7,36529,0);
INSERT INTO "django_geo_db_location" VALUES(63199,NULL,'Parlin, CO',26377,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63200,NULL,'Parlin, CO 81239',26377,222,NULL,7,36530,0);
INSERT INTO "django_geo_db_location" VALUES(63201,NULL,'Penrose, CO',26378,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63202,NULL,'Penrose, CO 81240',26378,222,NULL,7,36531,0);
INSERT INTO "django_geo_db_location" VALUES(63203,NULL,'Pitkin, CO',26379,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63204,NULL,'Pitkin, CO 81241',26379,222,NULL,7,36532,0);
INSERT INTO "django_geo_db_location" VALUES(63205,NULL,'Poncha Springs, CO',26380,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63206,NULL,'Poncha Springs, CO 81242',26380,222,NULL,7,36533,0);
INSERT INTO "django_geo_db_location" VALUES(63207,NULL,'Powderhorn, CO',26381,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63208,NULL,'Powderhorn, CO 81243',26381,222,NULL,7,36534,0);
INSERT INTO "django_geo_db_location" VALUES(63209,NULL,'Rockvale, CO',26382,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63210,NULL,'Rockvale, CO 81244',26382,222,NULL,7,36535,0);
INSERT INTO "django_geo_db_location" VALUES(63211,NULL,'Canon City, CO 81246',26362,222,NULL,7,36536,0);
INSERT INTO "django_geo_db_location" VALUES(63212,NULL,'Gunnison, CO 81247',26371,222,NULL,7,36537,0);
INSERT INTO "django_geo_db_location" VALUES(63213,NULL,'Sargents, CO',26383,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63214,NULL,'Sargents, CO 81248',26383,222,NULL,7,36538,0);
INSERT INTO "django_geo_db_location" VALUES(63215,NULL,'Twin Lakes, CO',26384,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63216,NULL,'Twin Lakes, CO 81251',26384,222,NULL,7,36539,0);
INSERT INTO "django_geo_db_location" VALUES(63217,NULL,'Westcliffe, CO',26385,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63218,NULL,'Westcliffe, CO 81252',26385,222,NULL,7,36540,0);
INSERT INTO "django_geo_db_location" VALUES(63219,NULL,'Wetmore, CO',26386,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63220,NULL,'Wetmore, CO 81253',26386,222,NULL,7,36541,0);
INSERT INTO "django_geo_db_location" VALUES(63221,NULL,'Basalt, CO',26387,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63222,NULL,'Basalt, CO 81260',26387,222,NULL,7,36542,0);
INSERT INTO "django_geo_db_location" VALUES(63223,NULL,'Florence, CO 81290',26368,222,NULL,7,36543,0);
INSERT INTO "django_geo_db_location" VALUES(63224,NULL,'Durango, CO',26388,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63225,NULL,'Durango, CO 81301',26388,222,NULL,7,36544,0);
INSERT INTO "django_geo_db_location" VALUES(63226,NULL,'Durango, CO 81302',26388,222,NULL,7,36545,0);
INSERT INTO "django_geo_db_location" VALUES(63227,NULL,'Durango, CO 81303',26388,222,NULL,7,36546,0);
INSERT INTO "django_geo_db_location" VALUES(63228,NULL,'Durango, CO 81310',26388,222,NULL,7,36547,0);
INSERT INTO "django_geo_db_location" VALUES(63229,NULL,'Cahone, CO',26389,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63230,NULL,'Cahone, CO 81320',26389,222,NULL,7,36548,0);
INSERT INTO "django_geo_db_location" VALUES(63231,NULL,'Cortez, CO',26390,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63232,NULL,'Cortez, CO 81321',26390,222,NULL,7,36549,0);
INSERT INTO "django_geo_db_location" VALUES(63233,NULL,'Dolores, CO',26391,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63234,NULL,'Dolores, CO 81323',26391,222,NULL,7,36550,0);
INSERT INTO "django_geo_db_location" VALUES(63235,NULL,'Dove Creek, CO',26392,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63236,NULL,'Dove Creek, CO 81324',26392,222,NULL,7,36551,0);
INSERT INTO "django_geo_db_location" VALUES(63237,NULL,'Egnar, CO',26393,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63238,NULL,'Egnar, CO 81325',26393,222,NULL,7,36552,0);
INSERT INTO "django_geo_db_location" VALUES(63239,NULL,'Hesperus, CO',26394,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63240,NULL,'Hesperus, CO 81326',26394,222,NULL,7,36553,0);
INSERT INTO "django_geo_db_location" VALUES(63241,NULL,'Lewis, CO',26395,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63242,NULL,'Lewis, CO 81327',26395,222,NULL,7,36554,0);
INSERT INTO "django_geo_db_location" VALUES(63243,NULL,'Mancos, CO',26396,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63244,NULL,'Mancos, CO 81328',26396,222,NULL,7,36555,0);
INSERT INTO "django_geo_db_location" VALUES(63245,NULL,'Marvel, CO',26397,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63246,NULL,'Marvel, CO 81329',26397,222,NULL,7,36556,0);
INSERT INTO "django_geo_db_location" VALUES(63247,NULL,'Mesa Verde National Park, CO',26398,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63248,NULL,'Mesa Verde National Park, CO 81330',26398,222,NULL,7,36557,0);
INSERT INTO "django_geo_db_location" VALUES(63249,NULL,'Pleasant View, CO',26399,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63250,NULL,'Pleasant View, CO 81331',26399,222,NULL,7,36558,0);
INSERT INTO "django_geo_db_location" VALUES(63251,NULL,'Rico, CO',26400,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63252,NULL,'Rico, CO 81332',26400,222,NULL,7,36559,0);
INSERT INTO "django_geo_db_location" VALUES(63253,NULL,'Towaoc, CO',26401,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63254,NULL,'Towaoc, CO 81334',26401,222,NULL,7,36560,0);
INSERT INTO "django_geo_db_location" VALUES(63255,NULL,'Yellow Jacket, CO',26402,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63256,NULL,'Yellow Jacket, CO 81335',26402,222,NULL,7,36561,0);
INSERT INTO "django_geo_db_location" VALUES(63257,NULL,'Montrose, CO',26403,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63258,NULL,'Montrose, CO 81401',26403,222,NULL,7,36562,0);
INSERT INTO "django_geo_db_location" VALUES(63259,NULL,'Montrose, CO 81402',26403,222,NULL,7,36563,0);
INSERT INTO "django_geo_db_location" VALUES(63260,NULL,'Austin, CO',26404,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63261,NULL,'Austin, CO 81410',26404,222,NULL,7,36564,0);
INSERT INTO "django_geo_db_location" VALUES(63262,NULL,'Bedrock, CO',26405,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63263,NULL,'Bedrock, CO 81411',26405,222,NULL,7,36565,0);
INSERT INTO "django_geo_db_location" VALUES(63264,NULL,'Cedaredge, CO',26406,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63265,NULL,'Cedaredge, CO 81413',26406,222,NULL,7,36566,0);
INSERT INTO "django_geo_db_location" VALUES(63266,NULL,'Cory, CO',26407,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63267,NULL,'Cory, CO 81414',26407,222,NULL,7,36567,0);
INSERT INTO "django_geo_db_location" VALUES(63268,NULL,'Crawford, CO',26408,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63269,NULL,'Crawford, CO 81415',26408,222,NULL,7,36568,0);
INSERT INTO "django_geo_db_location" VALUES(63270,NULL,'Delta, CO',26409,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63271,NULL,'Delta, CO 81416',26409,222,NULL,7,36569,0);
INSERT INTO "django_geo_db_location" VALUES(63272,NULL,'Eckert, CO',26410,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63273,NULL,'Eckert, CO 81418',26410,222,NULL,7,36570,0);
INSERT INTO "django_geo_db_location" VALUES(63274,NULL,'Hotchkiss, CO',26411,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63275,NULL,'Hotchkiss, CO 81419',26411,222,NULL,7,36571,0);
INSERT INTO "django_geo_db_location" VALUES(63276,NULL,'Lazear, CO',26412,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63277,NULL,'Lazear, CO 81420',26412,222,NULL,7,36572,0);
INSERT INTO "django_geo_db_location" VALUES(63278,NULL,'Maher, CO',26413,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63279,NULL,'Maher, CO 81421',26413,222,NULL,7,36573,0);
INSERT INTO "django_geo_db_location" VALUES(63280,NULL,'Naturita, CO',26414,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63281,NULL,'Naturita, CO 81422',26414,222,NULL,7,36574,0);
INSERT INTO "django_geo_db_location" VALUES(63282,NULL,'Norwood, CO',26415,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63283,NULL,'Norwood, CO 81423',26415,222,NULL,7,36575,0);
INSERT INTO "django_geo_db_location" VALUES(63284,NULL,'Nucla, CO',26416,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63285,NULL,'Nucla, CO 81424',26416,222,NULL,7,36576,0);
INSERT INTO "django_geo_db_location" VALUES(63286,NULL,'Olathe, CO',26417,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63287,NULL,'Olathe, CO 81425',26417,222,NULL,7,36577,0);
INSERT INTO "django_geo_db_location" VALUES(63288,NULL,'Ophir, CO',26418,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63289,NULL,'Ophir, CO 81426',26418,222,NULL,7,36578,0);
INSERT INTO "django_geo_db_location" VALUES(63290,NULL,'Ouray, CO',26419,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63291,NULL,'Ouray, CO 81427',26419,222,NULL,7,36579,0);
INSERT INTO "django_geo_db_location" VALUES(63292,NULL,'Paonia, CO',26420,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63293,NULL,'Paonia, CO 81428',26420,222,NULL,7,36580,0);
INSERT INTO "django_geo_db_location" VALUES(63294,NULL,'Paradox, CO',26421,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63295,NULL,'Paradox, CO 81429',26421,222,NULL,7,36581,0);
INSERT INTO "django_geo_db_location" VALUES(63296,NULL,'Placerville, CO',26422,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63297,NULL,'Placerville, CO 81430',26422,222,NULL,7,36582,0);
INSERT INTO "django_geo_db_location" VALUES(63298,NULL,'Redvale, CO',26423,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63299,NULL,'Redvale, CO 81431',26423,222,NULL,7,36583,0);
INSERT INTO "django_geo_db_location" VALUES(63300,NULL,'Ridgway, CO',26424,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63301,NULL,'Ridgway, CO 81432',26424,222,NULL,7,36584,0);
INSERT INTO "django_geo_db_location" VALUES(63302,NULL,'Silverton, CO',26425,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63303,NULL,'Silverton, CO 81433',26425,222,NULL,7,36585,0);
INSERT INTO "django_geo_db_location" VALUES(63304,NULL,'Somerset, CO',26426,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63305,NULL,'Somerset, CO 81434',26426,222,NULL,7,36586,0);
INSERT INTO "django_geo_db_location" VALUES(63306,NULL,'Telluride, CO',26427,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63307,NULL,'Telluride, CO 81435',26427,222,NULL,7,36587,0);
INSERT INTO "django_geo_db_location" VALUES(63308,NULL,'Grand Junction, CO',26428,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63309,NULL,'Grand Junction, CO 81501',26428,222,NULL,7,36588,0);
INSERT INTO "django_geo_db_location" VALUES(63310,NULL,'Grand Junction, CO 81502',26428,222,NULL,7,36589,0);
INSERT INTO "django_geo_db_location" VALUES(63311,NULL,'Grand Junction, CO 81503',26428,222,NULL,7,36590,0);
INSERT INTO "django_geo_db_location" VALUES(63312,NULL,'Grand Junction, CO 81504',26428,222,NULL,7,36591,0);
INSERT INTO "django_geo_db_location" VALUES(63313,NULL,'Grand Junction, CO 81505',26428,222,NULL,7,36592,0);
INSERT INTO "django_geo_db_location" VALUES(63314,NULL,'Grand Junction, CO 81506',26428,222,NULL,7,36593,0);
INSERT INTO "django_geo_db_location" VALUES(63315,NULL,'Snowmass Village, CO',26429,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63316,NULL,'Snowmass Village, CO 81516',26429,222,NULL,7,36594,0);
INSERT INTO "django_geo_db_location" VALUES(63317,NULL,'Clifton, CO',26430,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63318,NULL,'Clifton, CO 81520',26430,222,NULL,7,36595,0);
INSERT INTO "django_geo_db_location" VALUES(63319,NULL,'Fruita, CO',26431,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63320,NULL,'Fruita, CO 81521',26431,222,NULL,7,36596,0);
INSERT INTO "django_geo_db_location" VALUES(63321,NULL,'Gateway, CO',26432,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63322,NULL,'Gateway, CO 81522',26432,222,NULL,7,36597,0);
INSERT INTO "django_geo_db_location" VALUES(63323,NULL,'Glade Park, CO',26433,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63324,NULL,'Glade Park, CO 81523',26433,222,NULL,7,36598,0);
INSERT INTO "django_geo_db_location" VALUES(63325,NULL,'Loma, CO',26434,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63326,NULL,'Loma, CO 81524',26434,222,NULL,7,36599,0);
INSERT INTO "django_geo_db_location" VALUES(63327,NULL,'Mack, CO',26435,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63328,NULL,'Mack, CO 81525',26435,222,NULL,7,36600,0);
INSERT INTO "django_geo_db_location" VALUES(63329,NULL,'Palisade, CO',26436,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63330,NULL,'Palisade, CO 81526',26436,222,NULL,7,36601,0);
INSERT INTO "django_geo_db_location" VALUES(63331,NULL,'Whitewater, CO',26437,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63332,NULL,'Whitewater, CO 81527',26437,222,NULL,7,36602,0);
INSERT INTO "django_geo_db_location" VALUES(63333,NULL,'Glenwood Springs, CO',26438,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63334,NULL,'Glenwood Springs, CO 81601',26438,222,NULL,7,36603,0);
INSERT INTO "django_geo_db_location" VALUES(63335,NULL,'Glenwood Springs, CO 81602',26438,222,NULL,7,36604,0);
INSERT INTO "django_geo_db_location" VALUES(63336,NULL,'Dinosaur, CO',26439,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63337,NULL,'Dinosaur, CO 81610',26439,222,NULL,7,36605,0);
INSERT INTO "django_geo_db_location" VALUES(63338,NULL,'Aspen, CO',26440,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63339,NULL,'Aspen, CO 81611',26440,222,NULL,7,36606,0);
INSERT INTO "django_geo_db_location" VALUES(63340,NULL,'Aspen, CO 81612',26440,222,NULL,7,36607,0);
INSERT INTO "django_geo_db_location" VALUES(63341,NULL,'Snowmass Village, CO 81613',26429,222,NULL,7,36608,0);
INSERT INTO "django_geo_db_location" VALUES(63342,NULL,'Snowmass Village, CO 81615',26429,222,NULL,7,36609,0);
INSERT INTO "django_geo_db_location" VALUES(63343,NULL,'Avon, CO',26441,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63344,NULL,'Avon, CO 81620',26441,222,NULL,7,36610,0);
INSERT INTO "django_geo_db_location" VALUES(63345,NULL,'Basalt, CO 81621',26387,222,NULL,7,36611,0);
INSERT INTO "django_geo_db_location" VALUES(63346,NULL,'Carbondale, CO',26442,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63347,NULL,'Carbondale, CO 81623',26442,222,NULL,7,36612,0);
INSERT INTO "django_geo_db_location" VALUES(63348,NULL,'Collbran, CO',26443,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63349,NULL,'Collbran, CO 81624',26443,222,NULL,7,36613,0);
INSERT INTO "django_geo_db_location" VALUES(63350,NULL,'Craig, CO',26444,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63351,NULL,'Craig, CO 81625',26444,222,NULL,7,36614,0);
INSERT INTO "django_geo_db_location" VALUES(63352,NULL,'Craig, CO 81626',26444,222,NULL,7,36615,0);
INSERT INTO "django_geo_db_location" VALUES(63353,NULL,'El Jebel, CO',26445,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63354,NULL,'El Jebel, CO 81628',26445,222,NULL,7,36616,0);
INSERT INTO "django_geo_db_location" VALUES(63355,NULL,'De Beque, CO',26446,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63356,NULL,'De Beque, CO 81630',26446,222,NULL,7,36617,0);
INSERT INTO "django_geo_db_location" VALUES(63357,NULL,'Eagle, CO',26447,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63358,NULL,'Eagle, CO 81631',26447,222,NULL,7,36618,0);
INSERT INTO "django_geo_db_location" VALUES(63359,NULL,'Edwards, CO',26448,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63360,NULL,'Edwards, CO 81632',26448,222,NULL,7,36619,0);
INSERT INTO "django_geo_db_location" VALUES(63361,NULL,'Dinosaur, CO 81633',26439,222,NULL,7,36620,0);
INSERT INTO "django_geo_db_location" VALUES(63362,NULL,'Parachute, CO',26449,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63363,NULL,'Parachute, CO 81635',26449,222,NULL,7,36621,0);
INSERT INTO "django_geo_db_location" VALUES(63364,NULL,'Battlement Mesa, CO',26450,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63365,NULL,'Battlement Mesa, CO 81636',26450,222,NULL,7,36622,0);
INSERT INTO "django_geo_db_location" VALUES(63366,NULL,'Gypsum, CO',26451,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63367,NULL,'Gypsum, CO 81637',26451,222,NULL,7,36623,0);
INSERT INTO "django_geo_db_location" VALUES(63368,NULL,'Hamilton, CO',26452,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63369,NULL,'Hamilton, CO 81638',26452,222,NULL,7,36624,0);
INSERT INTO "django_geo_db_location" VALUES(63370,NULL,'Hayden, CO',26453,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63371,NULL,'Hayden, CO 81639',26453,222,NULL,7,36625,0);
INSERT INTO "django_geo_db_location" VALUES(63372,NULL,'Maybell, CO',26454,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63373,NULL,'Maybell, CO 81640',26454,222,NULL,7,36626,0);
INSERT INTO "django_geo_db_location" VALUES(63374,NULL,'Meeker, CO',26455,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63375,NULL,'Meeker, CO 81641',26455,222,NULL,7,36627,0);
INSERT INTO "django_geo_db_location" VALUES(63376,NULL,'Meredith, CO',26456,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63377,NULL,'Meredith, CO 81642',26456,222,NULL,7,36628,0);
INSERT INTO "django_geo_db_location" VALUES(63378,NULL,'Mesa, CO',26457,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63379,NULL,'Mesa, CO 81643',26457,222,NULL,7,36629,0);
INSERT INTO "django_geo_db_location" VALUES(63380,NULL,'Minturn, CO',26458,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63381,NULL,'Minturn, CO 81645',26458,222,NULL,7,36630,0);
INSERT INTO "django_geo_db_location" VALUES(63382,NULL,'Molina, CO',26459,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63383,NULL,'Molina, CO 81646',26459,222,NULL,7,36631,0);
INSERT INTO "django_geo_db_location" VALUES(63384,NULL,'New Castle, CO',26460,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63385,NULL,'New Castle, CO 81647',26460,222,NULL,7,36632,0);
INSERT INTO "django_geo_db_location" VALUES(63386,NULL,'Rangely, CO',26461,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63387,NULL,'Rangely, CO 81648',26461,222,NULL,7,36633,0);
INSERT INTO "django_geo_db_location" VALUES(63388,NULL,'Red Cliff, CO',26462,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63389,NULL,'Red Cliff, CO 81649',26462,222,NULL,7,36634,0);
INSERT INTO "django_geo_db_location" VALUES(63390,NULL,'Rifle, CO',26463,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63391,NULL,'Rifle, CO 81650',26463,222,NULL,7,36635,0);
INSERT INTO "django_geo_db_location" VALUES(63392,NULL,'Silt, CO',26464,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63393,NULL,'Silt, CO 81652',26464,222,NULL,7,36636,0);
INSERT INTO "django_geo_db_location" VALUES(63394,NULL,'Slater, CO',26465,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63395,NULL,'Slater, CO 81653',26465,222,NULL,7,36637,0);
INSERT INTO "django_geo_db_location" VALUES(63396,NULL,'Snowmass, CO',26466,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63397,NULL,'Snowmass, CO 81654',26466,222,NULL,7,36638,0);
INSERT INTO "django_geo_db_location" VALUES(63398,NULL,'Wolcott, CO',26467,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63399,NULL,'Wolcott, CO 81655',26467,222,NULL,7,36639,0);
INSERT INTO "django_geo_db_location" VALUES(63400,NULL,'Woody Creek, CO',26468,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63401,NULL,'Woody Creek, CO 81656',26468,222,NULL,7,36640,0);
INSERT INTO "django_geo_db_location" VALUES(63402,NULL,'Vail, CO',26469,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63403,NULL,'Vail, CO 81657',26469,222,NULL,7,36641,0);
INSERT INTO "django_geo_db_location" VALUES(63404,NULL,'Vail, CO 81658',26469,222,NULL,7,36642,0);
INSERT INTO "django_geo_db_location" VALUES(63405,NULL,'Cheyenne, WY',26470,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63406,NULL,'Cheyenne, WY 82001',26470,222,NULL,59,36643,0);
INSERT INTO "django_geo_db_location" VALUES(63407,NULL,'Cheyenne, WY 82002',26470,222,NULL,59,36644,0);
INSERT INTO "django_geo_db_location" VALUES(63408,NULL,'Cheyenne, WY 82003',26470,222,NULL,59,36645,0);
INSERT INTO "django_geo_db_location" VALUES(63409,NULL,'Fe Warren AFB, WY',26471,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63410,NULL,'Fe Warren AFB, WY 82005',26471,222,NULL,59,36646,0);
INSERT INTO "django_geo_db_location" VALUES(63411,NULL,'Cheyenne, WY 82006',26470,222,NULL,59,36647,0);
INSERT INTO "django_geo_db_location" VALUES(63412,NULL,'Cheyenne, WY 82007',26470,222,NULL,59,36648,0);
INSERT INTO "django_geo_db_location" VALUES(63413,NULL,'Cheyenne, WY 82008',26470,222,NULL,59,36649,0);
INSERT INTO "django_geo_db_location" VALUES(63414,NULL,'Cheyenne, WY 82009',26470,222,NULL,59,36650,0);
INSERT INTO "django_geo_db_location" VALUES(63415,NULL,'Cheyenne, WY 82010',26470,222,NULL,59,36651,0);
INSERT INTO "django_geo_db_location" VALUES(63416,NULL,'Albin, WY',26472,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63417,NULL,'Albin, WY 82050',26472,222,NULL,59,36652,0);
INSERT INTO "django_geo_db_location" VALUES(63418,NULL,'Bosler, WY',26473,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63419,NULL,'Bosler, WY 82051',26473,222,NULL,59,36653,0);
INSERT INTO "django_geo_db_location" VALUES(63420,NULL,'Buford, WY',26474,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63421,NULL,'Buford, WY 82052',26474,222,NULL,59,36654,0);
INSERT INTO "django_geo_db_location" VALUES(63422,NULL,'Burns, WY',26475,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63423,NULL,'Burns, WY 82053',26475,222,NULL,59,36655,0);
INSERT INTO "django_geo_db_location" VALUES(63424,NULL,'Carpenter, WY',26476,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63425,NULL,'Carpenter, WY 82054',26476,222,NULL,59,36656,0);
INSERT INTO "django_geo_db_location" VALUES(63426,NULL,'Centennial, WY',26477,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63427,NULL,'Centennial, WY 82055',26477,222,NULL,59,36657,0);
INSERT INTO "django_geo_db_location" VALUES(63428,NULL,'Garrett, WY',26478,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63429,NULL,'Garrett, WY 82058',26478,222,NULL,59,36658,0);
INSERT INTO "django_geo_db_location" VALUES(63430,NULL,'Granite Canon, WY',26479,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63431,NULL,'Granite Canon, WY 82059',26479,222,NULL,59,36659,0);
INSERT INTO "django_geo_db_location" VALUES(63432,NULL,'Hillsdale, WY',26480,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63433,NULL,'Hillsdale, WY 82060',26480,222,NULL,59,36660,0);
INSERT INTO "django_geo_db_location" VALUES(63434,NULL,'Horse Creek, WY',26481,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63435,NULL,'Horse Creek, WY 82061',26481,222,NULL,59,36661,0);
INSERT INTO "django_geo_db_location" VALUES(63436,NULL,'Jelm, CO',26482,222,NULL,7,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63437,NULL,'Jelm, CO 82063',26482,222,NULL,7,36662,0);
INSERT INTO "django_geo_db_location" VALUES(63438,NULL,'Laramie, WY',26483,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63439,NULL,'Laramie, WY 82070',26483,222,NULL,59,36663,0);
INSERT INTO "django_geo_db_location" VALUES(63440,NULL,'Laramie, WY 82071',26483,222,NULL,59,36664,0);
INSERT INTO "django_geo_db_location" VALUES(63441,NULL,'Laramie, WY 82072',26483,222,NULL,59,36665,0);
INSERT INTO "django_geo_db_location" VALUES(63442,NULL,'Laramie, WY 82073',26483,222,NULL,59,36666,0);
INSERT INTO "django_geo_db_location" VALUES(63443,NULL,'Meriden, WY',26484,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63444,NULL,'Meriden, WY 82081',26484,222,NULL,59,36667,0);
INSERT INTO "django_geo_db_location" VALUES(63445,NULL,'Pine Bluffs, NE',26485,222,NULL,27,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63446,NULL,'Pine Bluffs, NE 82082',26485,222,NULL,27,36668,0);
INSERT INTO "django_geo_db_location" VALUES(63447,NULL,'Rock River, WY',26486,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63448,NULL,'Rock River, WY 82083',26486,222,NULL,59,36669,0);
INSERT INTO "django_geo_db_location" VALUES(63449,NULL,'Tie Siding, WY',26487,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63450,NULL,'Tie Siding, WY 82084',26487,222,NULL,59,36670,0);
INSERT INTO "django_geo_db_location" VALUES(63451,NULL,'Yellowstone National Park, WY',26488,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63452,NULL,'Yellowstone National Park, WY 82190',26488,222,NULL,59,36671,0);
INSERT INTO "django_geo_db_location" VALUES(63453,NULL,'Wheatland, WY',26489,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63454,NULL,'Wheatland, WY 82201',26489,222,NULL,59,36672,0);
INSERT INTO "django_geo_db_location" VALUES(63455,NULL,'Chugwater, WY',26490,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63456,NULL,'Chugwater, WY 82210',26490,222,NULL,59,36673,0);
INSERT INTO "django_geo_db_location" VALUES(63457,NULL,'Fort Laramie, WY',26491,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63458,NULL,'Fort Laramie, WY 82212',26491,222,NULL,59,36674,0);
INSERT INTO "django_geo_db_location" VALUES(63459,NULL,'Glendo, WY',26492,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63460,NULL,'Glendo, WY 82213',26492,222,NULL,59,36675,0);
INSERT INTO "django_geo_db_location" VALUES(63461,NULL,'Guernsey, WY',26493,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63462,NULL,'Guernsey, WY 82214',26493,222,NULL,59,36676,0);
INSERT INTO "django_geo_db_location" VALUES(63463,NULL,'Hartville, WY',26494,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63464,NULL,'Hartville, WY 82215',26494,222,NULL,59,36677,0);
INSERT INTO "django_geo_db_location" VALUES(63465,NULL,'Hawk Springs, WY',26495,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63466,NULL,'Hawk Springs, WY 82217',26495,222,NULL,59,36678,0);
INSERT INTO "django_geo_db_location" VALUES(63467,NULL,'Huntley, WY',26496,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63468,NULL,'Huntley, WY 82218',26496,222,NULL,59,36679,0);
INSERT INTO "django_geo_db_location" VALUES(63469,NULL,'Jay Em, WY',26497,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63470,NULL,'Jay Em, WY 82219',26497,222,NULL,59,36680,0);
INSERT INTO "django_geo_db_location" VALUES(63471,NULL,'Lagrange, WY',26498,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63472,NULL,'Lagrange, WY 82221',26498,222,NULL,59,36681,0);
INSERT INTO "django_geo_db_location" VALUES(63473,NULL,'Lance Creek, WY',26499,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63474,NULL,'Lance Creek, WY 82222',26499,222,NULL,59,36682,0);
INSERT INTO "django_geo_db_location" VALUES(63475,NULL,'Lingle, WY',26500,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63476,NULL,'Lingle, WY 82223',26500,222,NULL,59,36683,0);
INSERT INTO "django_geo_db_location" VALUES(63477,NULL,'Lost Springs, WY',26501,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63478,NULL,'Lost Springs, WY 82224',26501,222,NULL,59,36684,0);
INSERT INTO "django_geo_db_location" VALUES(63479,NULL,'Lusk, WY',26502,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63480,NULL,'Lusk, WY 82225',26502,222,NULL,59,36685,0);
INSERT INTO "django_geo_db_location" VALUES(63481,NULL,'Lusk, WY 82226',26502,222,NULL,59,36686,0);
INSERT INTO "django_geo_db_location" VALUES(63482,NULL,'Manville, WY',26503,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63483,NULL,'Manville, WY 82227',26503,222,NULL,59,36687,0);
INSERT INTO "django_geo_db_location" VALUES(63484,NULL,'Shawnee, WY',26504,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63485,NULL,'Shawnee, WY 82229',26504,222,NULL,59,36688,0);
INSERT INTO "django_geo_db_location" VALUES(63486,NULL,'Torrington, WY',26505,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63487,NULL,'Torrington, WY 82240',26505,222,NULL,59,36689,0);
INSERT INTO "django_geo_db_location" VALUES(63488,NULL,'Van Tassell, WY',26506,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63489,NULL,'Van Tassell, WY 82242',26506,222,NULL,59,36690,0);
INSERT INTO "django_geo_db_location" VALUES(63490,NULL,'Veteran, WY',26507,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63491,NULL,'Veteran, WY 82243',26507,222,NULL,59,36691,0);
INSERT INTO "django_geo_db_location" VALUES(63492,NULL,'Yoder, WY',26508,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63493,NULL,'Yoder, WY 82244',26508,222,NULL,59,36692,0);
INSERT INTO "django_geo_db_location" VALUES(63494,NULL,'Rawlins, WY',26509,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63495,NULL,'Rawlins, WY 82301',26509,222,NULL,59,36693,0);
INSERT INTO "django_geo_db_location" VALUES(63496,NULL,'Jeffrey City, WY',26510,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63497,NULL,'Jeffrey City, WY 82310',26510,222,NULL,59,36694,0);
INSERT INTO "django_geo_db_location" VALUES(63498,NULL,'Baggs, WY',26511,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63499,NULL,'Baggs, WY 82321',26511,222,NULL,59,36695,0);
INSERT INTO "django_geo_db_location" VALUES(63500,NULL,'Bairoil, WY',26512,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63501,NULL,'Bairoil, WY 82322',26512,222,NULL,59,36696,0);
INSERT INTO "django_geo_db_location" VALUES(63502,NULL,'Dixon, WY',26513,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63503,NULL,'Dixon, WY 82323',26513,222,NULL,59,36697,0);
INSERT INTO "django_geo_db_location" VALUES(63504,NULL,'Elk Mountain, WY',26514,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63505,NULL,'Elk Mountain, WY 82324',26514,222,NULL,59,36698,0);
INSERT INTO "django_geo_db_location" VALUES(63506,NULL,'Encampment, WY',26515,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63507,NULL,'Encampment, WY 82325',26515,222,NULL,59,36699,0);
INSERT INTO "django_geo_db_location" VALUES(63508,NULL,'Hanna, WY',26516,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63509,NULL,'Hanna, WY 82327',26516,222,NULL,59,36700,0);
INSERT INTO "django_geo_db_location" VALUES(63510,NULL,'Medicine Bow, WY',26517,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63511,NULL,'Medicine Bow, WY 82329',26517,222,NULL,59,36701,0);
INSERT INTO "django_geo_db_location" VALUES(63512,NULL,'Saratoga, WY',26518,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63513,NULL,'Saratoga, WY 82331',26518,222,NULL,59,36702,0);
INSERT INTO "django_geo_db_location" VALUES(63514,NULL,'Savery, WY',26519,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63515,NULL,'Savery, WY 82332',26519,222,NULL,59,36703,0);
INSERT INTO "django_geo_db_location" VALUES(63516,NULL,'Sinclair, WY',26520,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63517,NULL,'Sinclair, WY 82334',26520,222,NULL,59,36704,0);
INSERT INTO "django_geo_db_location" VALUES(63518,NULL,'Walcott, WY',26521,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63519,NULL,'Walcott, WY 82335',26521,222,NULL,59,36705,0);
INSERT INTO "django_geo_db_location" VALUES(63520,NULL,'Wamsutter, WY',26522,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63521,NULL,'Wamsutter, WY 82336',26522,222,NULL,59,36706,0);
INSERT INTO "django_geo_db_location" VALUES(63522,NULL,'Sinclair, WY 82354',26520,222,NULL,59,36707,0);
INSERT INTO "django_geo_db_location" VALUES(63523,NULL,'Worland, WY',26523,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63524,NULL,'Worland, WY 82401',26523,222,NULL,59,36708,0);
INSERT INTO "django_geo_db_location" VALUES(63525,NULL,'Basin, WY',26524,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63526,NULL,'Basin, WY 82410',26524,222,NULL,59,36709,0);
INSERT INTO "django_geo_db_location" VALUES(63527,NULL,'Burlington, WY',26525,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63528,NULL,'Burlington, WY 82411',26525,222,NULL,59,36710,0);
INSERT INTO "django_geo_db_location" VALUES(63529,NULL,'Byron, WY',26526,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63530,NULL,'Byron, WY 82412',26526,222,NULL,59,36711,0);
INSERT INTO "django_geo_db_location" VALUES(63531,NULL,'Cody, WY',26527,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63532,NULL,'Cody, WY 82414',26527,222,NULL,59,36712,0);
INSERT INTO "django_geo_db_location" VALUES(63533,NULL,'Cowley, WY',26528,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63534,NULL,'Cowley, WY 82420',26528,222,NULL,59,36713,0);
INSERT INTO "django_geo_db_location" VALUES(63535,NULL,'Deaver, WY',26529,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63536,NULL,'Deaver, WY 82421',26529,222,NULL,59,36714,0);
INSERT INTO "django_geo_db_location" VALUES(63537,NULL,'Emblem, WY',26530,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63538,NULL,'Emblem, WY 82422',26530,222,NULL,59,36715,0);
INSERT INTO "django_geo_db_location" VALUES(63539,NULL,'Frannie, WY',26531,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63540,NULL,'Frannie, WY 82423',26531,222,NULL,59,36716,0);
INSERT INTO "django_geo_db_location" VALUES(63541,NULL,'Greybull, WY',26532,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63542,NULL,'Greybull, WY 82426',26532,222,NULL,59,36717,0);
INSERT INTO "django_geo_db_location" VALUES(63543,NULL,'Hamilton Dome, WY',26533,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63544,NULL,'Hamilton Dome, WY 82427',26533,222,NULL,59,36718,0);
INSERT INTO "django_geo_db_location" VALUES(63545,NULL,'Hyattville, WY',26534,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63546,NULL,'Hyattville, WY 82428',26534,222,NULL,59,36719,0);
INSERT INTO "django_geo_db_location" VALUES(63547,NULL,'Kirby, WY',26535,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63548,NULL,'Kirby, WY 82430',26535,222,NULL,59,36720,0);
INSERT INTO "django_geo_db_location" VALUES(63549,NULL,'Lovell, WY',26536,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63550,NULL,'Lovell, WY 82431',26536,222,NULL,59,36721,0);
INSERT INTO "django_geo_db_location" VALUES(63551,NULL,'Manderson, WY',26537,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63552,NULL,'Manderson, WY 82432',26537,222,NULL,59,36722,0);
INSERT INTO "django_geo_db_location" VALUES(63553,NULL,'Meeteetse, WY',26538,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63554,NULL,'Meeteetse, WY 82433',26538,222,NULL,59,36723,0);
INSERT INTO "django_geo_db_location" VALUES(63555,NULL,'Otto, WY',26539,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63556,NULL,'Otto, WY 82434',26539,222,NULL,59,36724,0);
INSERT INTO "django_geo_db_location" VALUES(63557,NULL,'Powell, WY',26540,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63558,NULL,'Powell, WY 82435',26540,222,NULL,59,36725,0);
INSERT INTO "django_geo_db_location" VALUES(63559,NULL,'Ralston, WY',26541,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63560,NULL,'Ralston, WY 82440',26541,222,NULL,59,36726,0);
INSERT INTO "django_geo_db_location" VALUES(63561,NULL,'Shell, WY',26542,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63562,NULL,'Shell, WY 82441',26542,222,NULL,59,36727,0);
INSERT INTO "django_geo_db_location" VALUES(63563,NULL,'Ten Sleep, WY',26543,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63564,NULL,'Ten Sleep, WY 82442',26543,222,NULL,59,36728,0);
INSERT INTO "django_geo_db_location" VALUES(63565,NULL,'Thermopolis, WY',26544,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63566,NULL,'Thermopolis, WY 82443',26544,222,NULL,59,36729,0);
INSERT INTO "django_geo_db_location" VALUES(63567,NULL,'Wapiti, WY',26545,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63568,NULL,'Wapiti, WY 82450',26545,222,NULL,59,36730,0);
INSERT INTO "django_geo_db_location" VALUES(63569,NULL,'Riverton, WY',26546,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63570,NULL,'Riverton, WY 82501',26546,222,NULL,59,36731,0);
INSERT INTO "django_geo_db_location" VALUES(63571,NULL,'Vista West, WY',26547,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63572,NULL,'Vista West, WY 82504',26547,222,NULL,59,36732,0);
INSERT INTO "django_geo_db_location" VALUES(63573,NULL,'Arapahoe, WY',26548,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63574,NULL,'Arapahoe, WY 82510',26548,222,NULL,59,36733,0);
INSERT INTO "django_geo_db_location" VALUES(63575,NULL,'Crowheart, WY',26549,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63576,NULL,'Crowheart, WY 82512',26549,222,NULL,59,36734,0);
INSERT INTO "django_geo_db_location" VALUES(63577,NULL,'Dubois, WY',26550,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63578,NULL,'Dubois, WY 82513',26550,222,NULL,59,36735,0);
INSERT INTO "django_geo_db_location" VALUES(63579,NULL,'Fort Washakie, WY',26551,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63580,NULL,'Fort Washakie, WY 82514',26551,222,NULL,59,36736,0);
INSERT INTO "django_geo_db_location" VALUES(63581,NULL,'Hudson, WY',26552,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63582,NULL,'Hudson, WY 82515',26552,222,NULL,59,36737,0);
INSERT INTO "django_geo_db_location" VALUES(63583,NULL,'Kinnear, WY',26553,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63584,NULL,'Kinnear, WY 82516',26553,222,NULL,59,36738,0);
INSERT INTO "django_geo_db_location" VALUES(63585,NULL,'Lander, WY',26554,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63586,NULL,'Lander, WY 82520',26554,222,NULL,59,36739,0);
INSERT INTO "django_geo_db_location" VALUES(63587,NULL,'Pavillion, WY',26555,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63588,NULL,'Pavillion, WY 82523',26555,222,NULL,59,36740,0);
INSERT INTO "django_geo_db_location" VALUES(63589,NULL,'Saint Stephens, WY',26556,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63590,NULL,'Saint Stephens, WY 82524',26556,222,NULL,59,36741,0);
INSERT INTO "django_geo_db_location" VALUES(63591,NULL,'Casper, WY',26557,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63592,NULL,'Casper, WY 82601',26557,222,NULL,59,36742,0);
INSERT INTO "django_geo_db_location" VALUES(63593,NULL,'Casper, WY 82602',26557,222,NULL,59,36743,0);
INSERT INTO "django_geo_db_location" VALUES(63594,NULL,'Casper, WY 82604',26557,222,NULL,59,36744,0);
INSERT INTO "django_geo_db_location" VALUES(63595,NULL,'Casper, WY 82605',26557,222,NULL,59,36745,0);
INSERT INTO "django_geo_db_location" VALUES(63596,NULL,'Casper, WY 82609',26557,222,NULL,59,36746,0);
INSERT INTO "django_geo_db_location" VALUES(63597,NULL,'Shirley Basin, WY',26558,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63598,NULL,'Shirley Basin, WY 82615',26558,222,NULL,59,36747,0);
INSERT INTO "django_geo_db_location" VALUES(63599,NULL,'Alcova, WY',26559,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63600,NULL,'Alcova, WY 82620',26559,222,NULL,59,36748,0);
INSERT INTO "django_geo_db_location" VALUES(63601,NULL,'Arminto, WY',26560,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63602,NULL,'Arminto, WY 82630',26560,222,NULL,59,36749,0);
INSERT INTO "django_geo_db_location" VALUES(63603,NULL,'Bill, WY',26561,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63604,NULL,'Bill, WY 82631',26561,222,NULL,59,36750,0);
INSERT INTO "django_geo_db_location" VALUES(63605,NULL,'Douglas, WY',26562,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63606,NULL,'Douglas, WY 82633',26562,222,NULL,59,36751,0);
INSERT INTO "django_geo_db_location" VALUES(63607,NULL,'Edgerton, WY',26563,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63608,NULL,'Edgerton, WY 82635',26563,222,NULL,59,36752,0);
INSERT INTO "django_geo_db_location" VALUES(63609,NULL,'Evansville, WY',26564,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63610,NULL,'Evansville, WY 82636',26564,222,NULL,59,36753,0);
INSERT INTO "django_geo_db_location" VALUES(63611,NULL,'Glenrock, WY',26565,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63612,NULL,'Glenrock, WY 82637',26565,222,NULL,59,36754,0);
INSERT INTO "django_geo_db_location" VALUES(63613,NULL,'Hiland, WY',26566,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63614,NULL,'Hiland, WY 82638',26566,222,NULL,59,36755,0);
INSERT INTO "django_geo_db_location" VALUES(63615,NULL,'Kaycee, WY',26567,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63616,NULL,'Kaycee, WY 82639',26567,222,NULL,59,36756,0);
INSERT INTO "django_geo_db_location" VALUES(63617,NULL,'Linch, WY',26568,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63618,NULL,'Linch, WY 82640',26568,222,NULL,59,36757,0);
INSERT INTO "django_geo_db_location" VALUES(63619,NULL,'Lysite, WY',26569,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63620,NULL,'Lysite, WY 82642',26569,222,NULL,59,36758,0);
INSERT INTO "django_geo_db_location" VALUES(63621,NULL,'Midwest, WY',26570,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63622,NULL,'Midwest, WY 82643',26570,222,NULL,59,36759,0);
INSERT INTO "django_geo_db_location" VALUES(63623,NULL,'Mills, WY',26571,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63624,NULL,'Mills, WY 82644',26571,222,NULL,59,36760,0);
INSERT INTO "django_geo_db_location" VALUES(63625,NULL,'Natrona, WY',26572,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63626,NULL,'Natrona, WY 82646',26572,222,NULL,59,36761,0);
INSERT INTO "django_geo_db_location" VALUES(63627,NULL,'Powder River, WY',26573,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63628,NULL,'Powder River, WY 82648',26573,222,NULL,59,36762,0);
INSERT INTO "django_geo_db_location" VALUES(63629,NULL,'Shoshoni, WY',26574,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63630,NULL,'Shoshoni, WY 82649',26574,222,NULL,59,36763,0);
INSERT INTO "django_geo_db_location" VALUES(63631,NULL,'Newcastle, WY',26575,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63632,NULL,'Newcastle, WY 82701',26575,222,NULL,59,36764,0);
INSERT INTO "django_geo_db_location" VALUES(63633,NULL,'Laramie, WY 82703',26483,222,NULL,59,36765,0);
INSERT INTO "django_geo_db_location" VALUES(63634,NULL,'Aladdin, WY',26576,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63635,NULL,'Aladdin, WY 82710',26576,222,NULL,59,36766,0);
INSERT INTO "django_geo_db_location" VALUES(63636,NULL,'Alva, WY',26577,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63637,NULL,'Alva, WY 82711',26577,222,NULL,59,36767,0);
INSERT INTO "django_geo_db_location" VALUES(63638,NULL,'Beulah, WY',26578,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63639,NULL,'Beulah, WY 82712',26578,222,NULL,59,36768,0);
INSERT INTO "django_geo_db_location" VALUES(63640,NULL,'Carlile, WY',26579,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63641,NULL,'Carlile, WY 82713',26579,222,NULL,59,36769,0);
INSERT INTO "django_geo_db_location" VALUES(63642,NULL,'Devils Tower, WY',26580,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63643,NULL,'Devils Tower, WY 82714',26580,222,NULL,59,36770,0);
INSERT INTO "django_geo_db_location" VALUES(63644,NULL,'Four Corners, WY',26581,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63645,NULL,'Four Corners, WY 82715',26581,222,NULL,59,36771,0);
INSERT INTO "django_geo_db_location" VALUES(63646,NULL,'Gillette, WY',26582,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63647,NULL,'Gillette, WY 82716',26582,222,NULL,59,36772,0);
INSERT INTO "django_geo_db_location" VALUES(63648,NULL,'Gillette, WY 82717',26582,222,NULL,59,36773,0);
INSERT INTO "django_geo_db_location" VALUES(63649,NULL,'Gillette, WY 82718',26582,222,NULL,59,36774,0);
INSERT INTO "django_geo_db_location" VALUES(63650,NULL,'Hulett, WY',26583,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63651,NULL,'Hulett, WY 82720',26583,222,NULL,59,36775,0);
INSERT INTO "django_geo_db_location" VALUES(63652,NULL,'Moorcroft, WY',26584,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63653,NULL,'Moorcroft, WY 82721',26584,222,NULL,59,36776,0);
INSERT INTO "django_geo_db_location" VALUES(63654,NULL,'Osage, WY',26585,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63655,NULL,'Osage, WY 82723',26585,222,NULL,59,36777,0);
INSERT INTO "django_geo_db_location" VALUES(63656,NULL,'Recluse, WY',26586,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63657,NULL,'Recluse, WY 82725',26586,222,NULL,59,36778,0);
INSERT INTO "django_geo_db_location" VALUES(63658,NULL,'Rozet, WY',26587,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63659,NULL,'Rozet, WY 82727',26587,222,NULL,59,36779,0);
INSERT INTO "django_geo_db_location" VALUES(63660,NULL,'Sundance, WY',26588,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63661,NULL,'Sundance, WY 82729',26588,222,NULL,59,36780,0);
INSERT INTO "django_geo_db_location" VALUES(63662,NULL,'Upton, WY',26589,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63663,NULL,'Upton, WY 82730',26589,222,NULL,59,36781,0);
INSERT INTO "django_geo_db_location" VALUES(63664,NULL,'Weston, WY',26590,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63665,NULL,'Weston, WY 82731',26590,222,NULL,59,36782,0);
INSERT INTO "django_geo_db_location" VALUES(63666,NULL,'Wright, WY',26591,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63667,NULL,'Wright, WY 82732',26591,222,NULL,59,36783,0);
INSERT INTO "django_geo_db_location" VALUES(63668,NULL,'Sundance, WY 82779',26588,222,NULL,59,36784,0);
INSERT INTO "django_geo_db_location" VALUES(63669,NULL,'Sheridan, WY',26592,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63670,NULL,'Sheridan, WY 82801',26592,222,NULL,59,36785,0);
INSERT INTO "django_geo_db_location" VALUES(63671,NULL,'Arvada, WY',26593,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63672,NULL,'Arvada, WY 82831',26593,222,NULL,59,36786,0);
INSERT INTO "django_geo_db_location" VALUES(63673,NULL,'Banner, WY',26594,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63674,NULL,'Banner, WY 82832',26594,222,NULL,59,36787,0);
INSERT INTO "django_geo_db_location" VALUES(63675,NULL,'Big Horn, WY',26595,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63676,NULL,'Big Horn, WY 82833',26595,222,NULL,59,36788,0);
INSERT INTO "django_geo_db_location" VALUES(63677,NULL,'Buffalo, WY',26596,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63678,NULL,'Buffalo, WY 82834',26596,222,NULL,59,36789,0);
INSERT INTO "django_geo_db_location" VALUES(63679,NULL,'Clearmont, WY',26597,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63680,NULL,'Clearmont, WY 82835',26597,222,NULL,59,36790,0);
INSERT INTO "django_geo_db_location" VALUES(63681,NULL,'Dayton, WY',26598,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63682,NULL,'Dayton, WY 82836',26598,222,NULL,59,36791,0);
INSERT INTO "django_geo_db_location" VALUES(63683,NULL,'Leiter, WY',26599,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63684,NULL,'Leiter, WY 82837',26599,222,NULL,59,36792,0);
INSERT INTO "django_geo_db_location" VALUES(63685,NULL,'Parkman, WY',26600,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63686,NULL,'Parkman, WY 82838',26600,222,NULL,59,36793,0);
INSERT INTO "django_geo_db_location" VALUES(63687,NULL,'Ranchester, WY',26601,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63688,NULL,'Ranchester, WY 82839',26601,222,NULL,59,36794,0);
INSERT INTO "django_geo_db_location" VALUES(63689,NULL,'Saddlestring, WY',26602,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63690,NULL,'Saddlestring, WY 82840',26602,222,NULL,59,36795,0);
INSERT INTO "django_geo_db_location" VALUES(63691,NULL,'Story, WY',26603,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63692,NULL,'Story, WY 82842',26603,222,NULL,59,36796,0);
INSERT INTO "django_geo_db_location" VALUES(63693,NULL,'Wolf, WY',26604,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63694,NULL,'Wolf, WY 82844',26604,222,NULL,59,36797,0);
INSERT INTO "django_geo_db_location" VALUES(63695,NULL,'Wyarno, WY',26605,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63696,NULL,'Wyarno, WY 82845',26605,222,NULL,59,36798,0);
INSERT INTO "django_geo_db_location" VALUES(63697,NULL,'Rock Springs, WY',26606,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63698,NULL,'Rock Springs, WY 82901',26606,222,NULL,59,36799,0);
INSERT INTO "django_geo_db_location" VALUES(63699,NULL,'Rock Springs, WY 82902',26606,222,NULL,59,36800,0);
INSERT INTO "django_geo_db_location" VALUES(63700,NULL,'Bondurant, WY',26607,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63701,NULL,'Bondurant, WY 82922',26607,222,NULL,59,36801,0);
INSERT INTO "django_geo_db_location" VALUES(63702,NULL,'Boulder, WY',26608,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63703,NULL,'Boulder, WY 82923',26608,222,NULL,59,36802,0);
INSERT INTO "django_geo_db_location" VALUES(63704,NULL,'Cora, WY',26609,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63705,NULL,'Cora, WY 82925',26609,222,NULL,59,36803,0);
INSERT INTO "django_geo_db_location" VALUES(63706,NULL,'Little America, WY',26610,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63707,NULL,'Little America, WY 82929',26610,222,NULL,59,36804,0);
INSERT INTO "django_geo_db_location" VALUES(63708,NULL,'Evanston, WY',26611,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63709,NULL,'Evanston, WY 82930',26611,222,NULL,59,36805,0);
INSERT INTO "django_geo_db_location" VALUES(63710,NULL,'Evanston, WY 82931',26611,222,NULL,59,36806,0);
INSERT INTO "django_geo_db_location" VALUES(63711,NULL,'Farson, WY',26612,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63712,NULL,'Farson, WY 82932',26612,222,NULL,59,36807,0);
INSERT INTO "django_geo_db_location" VALUES(63713,NULL,'Fort Bridger, WY',26613,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63714,NULL,'Fort Bridger, WY 82933',26613,222,NULL,59,36808,0);
INSERT INTO "django_geo_db_location" VALUES(63715,NULL,'Granger, WY',26614,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63716,NULL,'Granger, WY 82934',26614,222,NULL,59,36809,0);
INSERT INTO "django_geo_db_location" VALUES(63717,NULL,'Green River, WY',26615,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63718,NULL,'Green River, WY 82935',26615,222,NULL,59,36810,0);
INSERT INTO "django_geo_db_location" VALUES(63719,NULL,'Lontetree, WY',26616,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63720,NULL,'Lontetree, WY 82936',26616,222,NULL,59,36811,0);
INSERT INTO "django_geo_db_location" VALUES(63721,NULL,'Lyman, WY',26617,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63722,NULL,'Lyman, WY 82937',26617,222,NULL,59,36812,0);
INSERT INTO "django_geo_db_location" VALUES(63723,NULL,'McKinnon, WY',26618,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63724,NULL,'McKinnon, WY 82938',26618,222,NULL,59,36813,0);
INSERT INTO "django_geo_db_location" VALUES(63725,NULL,'Mountain View, WY',26619,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63726,NULL,'Mountain View, WY 82939',26619,222,NULL,59,36814,0);
INSERT INTO "django_geo_db_location" VALUES(63727,NULL,'Pinedale, WY',26620,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63728,NULL,'Pinedale, WY 82941',26620,222,NULL,59,36815,0);
INSERT INTO "django_geo_db_location" VALUES(63729,NULL,'Point Of Rocks, WY',26621,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63730,NULL,'Point Of Rocks, WY 82942',26621,222,NULL,59,36816,0);
INSERT INTO "django_geo_db_location" VALUES(63731,NULL,'Reliance, WY',26622,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63732,NULL,'Reliance, WY 82943',26622,222,NULL,59,36817,0);
INSERT INTO "django_geo_db_location" VALUES(63733,NULL,'Robertson, WY',26623,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63734,NULL,'Robertson, WY 82944',26623,222,NULL,59,36818,0);
INSERT INTO "django_geo_db_location" VALUES(63735,NULL,'Superior, WY',26624,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63736,NULL,'Superior, WY 82945',26624,222,NULL,59,36819,0);
INSERT INTO "django_geo_db_location" VALUES(63737,NULL,'Jackson, WY',26625,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63738,NULL,'Jackson, WY 83001',26625,222,NULL,59,36820,0);
INSERT INTO "django_geo_db_location" VALUES(63739,NULL,'Jackson, WY 83002',26625,222,NULL,59,36821,0);
INSERT INTO "django_geo_db_location" VALUES(63740,NULL,'Kelly, WY',26626,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63741,NULL,'Kelly, WY 83011',26626,222,NULL,59,36822,0);
INSERT INTO "django_geo_db_location" VALUES(63742,NULL,'Moose, WY',26627,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63743,NULL,'Moose, WY 83012',26627,222,NULL,59,36823,0);
INSERT INTO "django_geo_db_location" VALUES(63744,NULL,'Moran, WY',26628,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63745,NULL,'Moran, WY 83013',26628,222,NULL,59,36824,0);
INSERT INTO "django_geo_db_location" VALUES(63746,NULL,'Wilson, WY',26629,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63747,NULL,'Wilson, WY 83014',26629,222,NULL,59,36825,0);
INSERT INTO "django_geo_db_location" VALUES(63748,NULL,'Teton Village, WY',26630,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63749,NULL,'Teton Village, WY 83025',26630,222,NULL,59,36826,0);
INSERT INTO "django_geo_db_location" VALUES(63750,NULL,'Kemmerer, WY',26631,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63751,NULL,'Kemmerer, WY 83101',26631,222,NULL,59,36827,0);
INSERT INTO "django_geo_db_location" VALUES(63752,NULL,'Afton, WY',26632,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63753,NULL,'Afton, WY 83110',26632,222,NULL,59,36828,0);
INSERT INTO "django_geo_db_location" VALUES(63754,NULL,'Auburn, WY',26633,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63755,NULL,'Auburn, WY 83111',26633,222,NULL,59,36829,0);
INSERT INTO "django_geo_db_location" VALUES(63756,NULL,'Bedford, WY',26634,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63757,NULL,'Bedford, WY 83112',26634,222,NULL,59,36830,0);
INSERT INTO "django_geo_db_location" VALUES(63758,NULL,'Big Piney, WY',26635,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63759,NULL,'Big Piney, WY 83113',26635,222,NULL,59,36831,0);
INSERT INTO "django_geo_db_location" VALUES(63760,NULL,'Cokeville, WY',26636,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63761,NULL,'Cokeville, WY 83114',26636,222,NULL,59,36832,0);
INSERT INTO "django_geo_db_location" VALUES(63762,NULL,'Daniel, WY',26637,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63763,NULL,'Daniel, WY 83115',26637,222,NULL,59,36833,0);
INSERT INTO "django_geo_db_location" VALUES(63764,NULL,'Diamondville, WY',26638,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63765,NULL,'Diamondville, WY 83116',26638,222,NULL,59,36834,0);
INSERT INTO "django_geo_db_location" VALUES(63766,NULL,'Etna, WY',26639,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63767,NULL,'Etna, WY 83118',26639,222,NULL,59,36835,0);
INSERT INTO "django_geo_db_location" VALUES(63768,NULL,'Fairview, WY',26640,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63769,NULL,'Fairview, WY 83119',26640,222,NULL,59,36836,0);
INSERT INTO "django_geo_db_location" VALUES(63770,NULL,'Freedom, ID',26641,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63771,NULL,'Freedom, ID 83120',26641,222,NULL,16,36837,0);
INSERT INTO "django_geo_db_location" VALUES(63772,NULL,'Frontier, WY',26642,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63773,NULL,'Frontier, WY 83121',26642,222,NULL,59,36838,0);
INSERT INTO "django_geo_db_location" VALUES(63774,NULL,'Grover, WY',26643,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63775,NULL,'Grover, WY 83122',26643,222,NULL,59,36839,0);
INSERT INTO "django_geo_db_location" VALUES(63776,NULL,'La Barge, WY',26644,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63777,NULL,'La Barge, WY 83123',26644,222,NULL,59,36840,0);
INSERT INTO "django_geo_db_location" VALUES(63778,NULL,'Opal, WY',26645,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63779,NULL,'Opal, WY 83124',26645,222,NULL,59,36841,0);
INSERT INTO "django_geo_db_location" VALUES(63780,NULL,'Smoot, WY',26646,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63781,NULL,'Smoot, WY 83126',26646,222,NULL,59,36842,0);
INSERT INTO "django_geo_db_location" VALUES(63782,NULL,'Thayne, WY',26647,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63783,NULL,'Thayne, WY 83127',26647,222,NULL,59,36843,0);
INSERT INTO "django_geo_db_location" VALUES(63784,NULL,'Alpine, WY',26648,222,NULL,59,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63785,NULL,'Alpine, WY 83128',26648,222,NULL,59,36844,0);
INSERT INTO "django_geo_db_location" VALUES(63786,NULL,'Pocatello, ID',26649,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63787,NULL,'Pocatello, ID 83201',26649,222,NULL,16,36845,0);
INSERT INTO "django_geo_db_location" VALUES(63788,NULL,'Pocatello, ID 83202',26649,222,NULL,16,36846,0);
INSERT INTO "django_geo_db_location" VALUES(63789,NULL,'Fort Hall, ID',26650,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63790,NULL,'Fort Hall, ID 83203',26650,222,NULL,16,36847,0);
INSERT INTO "django_geo_db_location" VALUES(63791,NULL,'Pocatello, ID 83204',26649,222,NULL,16,36848,0);
INSERT INTO "django_geo_db_location" VALUES(63792,NULL,'Pocatello, ID 83205',26649,222,NULL,16,36849,0);
INSERT INTO "django_geo_db_location" VALUES(63793,NULL,'Pocatello, ID 83206',26649,222,NULL,16,36850,0);
INSERT INTO "django_geo_db_location" VALUES(63794,NULL,'Pocatello, ID 83209',26649,222,NULL,16,36851,0);
INSERT INTO "django_geo_db_location" VALUES(63795,NULL,'Aberdeen, ID',26651,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63796,NULL,'Aberdeen, ID 83210',26651,222,NULL,16,36852,0);
INSERT INTO "django_geo_db_location" VALUES(63797,NULL,'American Falls, ID',26652,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63798,NULL,'American Falls, ID 83211',26652,222,NULL,16,36853,0);
INSERT INTO "django_geo_db_location" VALUES(63799,NULL,'Arbon, ID',26653,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63800,NULL,'Arbon, ID 83212',26653,222,NULL,16,36854,0);
INSERT INTO "django_geo_db_location" VALUES(63801,NULL,'Arco, ID',26654,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63802,NULL,'Arco, ID 83213',26654,222,NULL,16,36855,0);
INSERT INTO "django_geo_db_location" VALUES(63803,NULL,'Arimo, ID',26655,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63804,NULL,'Arimo, ID 83214',26655,222,NULL,16,36856,0);
INSERT INTO "django_geo_db_location" VALUES(63805,NULL,'Atomic City, ID',26656,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63806,NULL,'Atomic City, ID 83215',26656,222,NULL,16,36857,0);
INSERT INTO "django_geo_db_location" VALUES(63807,NULL,'Bancroft, ID',26657,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63808,NULL,'Bancroft, ID 83217',26657,222,NULL,16,36858,0);
INSERT INTO "django_geo_db_location" VALUES(63809,NULL,'Basalt, ID',26658,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63810,NULL,'Basalt, ID 83218',26658,222,NULL,16,36859,0);
INSERT INTO "django_geo_db_location" VALUES(63811,NULL,'Bern, ID',26659,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63812,NULL,'Bern, ID 83220',26659,222,NULL,16,36860,0);
INSERT INTO "django_geo_db_location" VALUES(63813,NULL,'Blackfoot, ID',26660,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63814,NULL,'Blackfoot, ID 83221',26660,222,NULL,16,36861,0);
INSERT INTO "django_geo_db_location" VALUES(63815,NULL,'Bloomington, ID',26661,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63816,NULL,'Bloomington, ID 83223',26661,222,NULL,16,36862,0);
INSERT INTO "django_geo_db_location" VALUES(63817,NULL,'Challis, ID',26662,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63818,NULL,'Challis, ID 83226',26662,222,NULL,16,36863,0);
INSERT INTO "django_geo_db_location" VALUES(63819,NULL,'Clayton, ID',26663,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63820,NULL,'Clayton, ID 83227',26663,222,NULL,16,36864,0);
INSERT INTO "django_geo_db_location" VALUES(63821,NULL,'Clifton, ID',26664,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63822,NULL,'Clifton, ID 83228',26664,222,NULL,16,36865,0);
INSERT INTO "django_geo_db_location" VALUES(63823,NULL,'Cobalt, ID',26665,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63824,NULL,'Cobalt, ID 83229',26665,222,NULL,16,36866,0);
INSERT INTO "django_geo_db_location" VALUES(63825,NULL,'Conda, ID',26666,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63826,NULL,'Conda, ID 83230',26666,222,NULL,16,36867,0);
INSERT INTO "django_geo_db_location" VALUES(63827,NULL,'Dayton, ID',26667,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63828,NULL,'Dayton, ID 83232',26667,222,NULL,16,36868,0);
INSERT INTO "django_geo_db_location" VALUES(63829,NULL,'Dingle, ID',26668,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63830,NULL,'Dingle, ID 83233',26668,222,NULL,16,36869,0);
INSERT INTO "django_geo_db_location" VALUES(63831,NULL,'Downey, ID',26669,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63832,NULL,'Downey, ID 83234',26669,222,NULL,16,36870,0);
INSERT INTO "django_geo_db_location" VALUES(63833,NULL,'Ellis, ID',26670,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63834,NULL,'Ellis, ID 83235',26670,222,NULL,16,36871,0);
INSERT INTO "django_geo_db_location" VALUES(63835,NULL,'Firth, ID',26671,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63836,NULL,'Firth, ID 83236',26671,222,NULL,16,36872,0);
INSERT INTO "django_geo_db_location" VALUES(63837,NULL,'Franklin, ID',26672,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63838,NULL,'Franklin, ID 83237',26672,222,NULL,16,36873,0);
INSERT INTO "django_geo_db_location" VALUES(63839,NULL,'Geneva, ID',26673,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63840,NULL,'Geneva, ID 83238',26673,222,NULL,16,36874,0);
INSERT INTO "django_geo_db_location" VALUES(63841,NULL,'Georgetown, ID',26674,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63842,NULL,'Georgetown, ID 83239',26674,222,NULL,16,36875,0);
INSERT INTO "django_geo_db_location" VALUES(63843,NULL,'Grace, ID',26675,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63844,NULL,'Grace, ID 83241',26675,222,NULL,16,36876,0);
INSERT INTO "django_geo_db_location" VALUES(63845,NULL,'Holbrook, ID',26676,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63846,NULL,'Holbrook, ID 83243',26676,222,NULL,16,36877,0);
INSERT INTO "django_geo_db_location" VALUES(63847,NULL,'Howe, ID',26677,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63848,NULL,'Howe, ID 83244',26677,222,NULL,16,36878,0);
INSERT INTO "django_geo_db_location" VALUES(63849,NULL,'Inkom, ID',26678,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63850,NULL,'Inkom, ID 83245',26678,222,NULL,16,36879,0);
INSERT INTO "django_geo_db_location" VALUES(63851,NULL,'Lava Hot Springs, ID',26679,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63852,NULL,'Lava Hot Springs, ID 83246',26679,222,NULL,16,36880,0);
INSERT INTO "django_geo_db_location" VALUES(63853,NULL,'McCammon, ID',26680,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63854,NULL,'McCammon, ID 83250',26680,222,NULL,16,36881,0);
INSERT INTO "django_geo_db_location" VALUES(63855,NULL,'Mackay, ID',26681,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63856,NULL,'Mackay, ID 83251',26681,222,NULL,16,36882,0);
INSERT INTO "django_geo_db_location" VALUES(63857,NULL,'Malad City, ID',26682,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63858,NULL,'Malad City, ID 83252',26682,222,NULL,16,36883,0);
INSERT INTO "django_geo_db_location" VALUES(63859,NULL,'May, ID',26683,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63860,NULL,'May, ID 83253',26683,222,NULL,16,36884,0);
INSERT INTO "django_geo_db_location" VALUES(63861,NULL,'Montpelier, ID',26684,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63862,NULL,'Montpelier, ID 83254',26684,222,NULL,16,36885,0);
INSERT INTO "django_geo_db_location" VALUES(63863,NULL,'Moore, ID',26685,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63864,NULL,'Moore, ID 83255',26685,222,NULL,16,36886,0);
INSERT INTO "django_geo_db_location" VALUES(63865,NULL,'Moreland, ID',26686,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63866,NULL,'Moreland, ID 83256',26686,222,NULL,16,36887,0);
INSERT INTO "django_geo_db_location" VALUES(63867,NULL,'Paris, ID',26687,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63868,NULL,'Paris, ID 83261',26687,222,NULL,16,36888,0);
INSERT INTO "django_geo_db_location" VALUES(63869,NULL,'Pingree, ID',26688,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63870,NULL,'Pingree, ID 83262',26688,222,NULL,16,36889,0);
INSERT INTO "django_geo_db_location" VALUES(63871,NULL,'Preston, ID',26689,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63872,NULL,'Preston, ID 83263',26689,222,NULL,16,36890,0);
INSERT INTO "django_geo_db_location" VALUES(63873,NULL,'Rockland, ID',26690,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63874,NULL,'Rockland, ID 83271',26690,222,NULL,16,36891,0);
INSERT INTO "django_geo_db_location" VALUES(63875,NULL,'Saint Charles, ID',26691,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63876,NULL,'Saint Charles, ID 83272',26691,222,NULL,16,36892,0);
INSERT INTO "django_geo_db_location" VALUES(63877,NULL,'Shelley, ID',26692,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63878,NULL,'Shelley, ID 83274',26692,222,NULL,16,36893,0);
INSERT INTO "django_geo_db_location" VALUES(63879,NULL,'Soda Springs, ID',26693,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63880,NULL,'Soda Springs, ID 83276',26693,222,NULL,16,36894,0);
INSERT INTO "django_geo_db_location" VALUES(63881,NULL,'Springfield, ID',26694,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63882,NULL,'Springfield, ID 83277',26694,222,NULL,16,36895,0);
INSERT INTO "django_geo_db_location" VALUES(63883,NULL,'Stanley, ID',26695,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63884,NULL,'Stanley, ID 83278',26695,222,NULL,16,36896,0);
INSERT INTO "django_geo_db_location" VALUES(63885,NULL,'Swanlake, ID',26696,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63886,NULL,'Swanlake, ID 83281',26696,222,NULL,16,36897,0);
INSERT INTO "django_geo_db_location" VALUES(63887,NULL,'Thatcher, ID',26697,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63888,NULL,'Thatcher, ID 83283',26697,222,NULL,16,36898,0);
INSERT INTO "django_geo_db_location" VALUES(63889,NULL,'Wayan, ID',26698,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63890,NULL,'Wayan, ID 83285',26698,222,NULL,16,36899,0);
INSERT INTO "django_geo_db_location" VALUES(63891,NULL,'Weston, ID',26699,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63892,NULL,'Weston, ID 83286',26699,222,NULL,16,36900,0);
INSERT INTO "django_geo_db_location" VALUES(63893,NULL,'Fish Haven, ID',26700,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63894,NULL,'Fish Haven, ID 83287',26700,222,NULL,16,36901,0);
INSERT INTO "django_geo_db_location" VALUES(63895,NULL,'Twin Falls, ID',26701,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63896,NULL,'Twin Falls, ID 83301',26701,222,NULL,16,36902,0);
INSERT INTO "django_geo_db_location" VALUES(63897,NULL,'Rogerson, ID',26702,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63898,NULL,'Rogerson, ID 83302',26702,222,NULL,16,36903,0);
INSERT INTO "django_geo_db_location" VALUES(63899,NULL,'Twin Falls, ID 83303',26701,222,NULL,16,36904,0);
INSERT INTO "django_geo_db_location" VALUES(63900,NULL,'Albion, ID',26703,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63901,NULL,'Albion, ID 83311',26703,222,NULL,16,36905,0);
INSERT INTO "django_geo_db_location" VALUES(63902,NULL,'Almo, ID',26704,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63903,NULL,'Almo, ID 83312',26704,222,NULL,16,36906,0);
INSERT INTO "django_geo_db_location" VALUES(63904,NULL,'Bellevue, ID',26705,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63905,NULL,'Bellevue, ID 83313',26705,222,NULL,16,36907,0);
INSERT INTO "django_geo_db_location" VALUES(63906,NULL,'Bliss, ID',26706,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63907,NULL,'Bliss, ID 83314',26706,222,NULL,16,36908,0);
INSERT INTO "django_geo_db_location" VALUES(63908,NULL,'Buhl, ID',26707,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63909,NULL,'Buhl, ID 83316',26707,222,NULL,16,36909,0);
INSERT INTO "django_geo_db_location" VALUES(63910,NULL,'Burley, ID',26708,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63911,NULL,'Burley, ID 83318',26708,222,NULL,16,36910,0);
INSERT INTO "django_geo_db_location" VALUES(63912,NULL,'Carey, ID',26709,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63913,NULL,'Carey, ID 83320',26709,222,NULL,16,36911,0);
INSERT INTO "django_geo_db_location" VALUES(63914,NULL,'Castleford, ID',26710,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63915,NULL,'Castleford, ID 83321',26710,222,NULL,16,36912,0);
INSERT INTO "django_geo_db_location" VALUES(63916,NULL,'Corral, ID',26711,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63917,NULL,'Corral, ID 83322',26711,222,NULL,16,36913,0);
INSERT INTO "django_geo_db_location" VALUES(63918,NULL,'Declo, ID',26712,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63919,NULL,'Declo, ID 83323',26712,222,NULL,16,36914,0);
INSERT INTO "django_geo_db_location" VALUES(63920,NULL,'Dietrich, ID',26713,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63921,NULL,'Dietrich, ID 83324',26713,222,NULL,16,36915,0);
INSERT INTO "django_geo_db_location" VALUES(63922,NULL,'Eden, ID',26714,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63923,NULL,'Eden, ID 83325',26714,222,NULL,16,36916,0);
INSERT INTO "django_geo_db_location" VALUES(63924,NULL,'Fairfield, ID',26715,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63925,NULL,'Fairfield, ID 83327',26715,222,NULL,16,36917,0);
INSERT INTO "django_geo_db_location" VALUES(63926,NULL,'Filer, ID',26716,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63927,NULL,'Filer, ID 83328',26716,222,NULL,16,36918,0);
INSERT INTO "django_geo_db_location" VALUES(63928,NULL,'Gooding, ID',26717,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63929,NULL,'Gooding, ID 83330',26717,222,NULL,16,36919,0);
INSERT INTO "django_geo_db_location" VALUES(63930,NULL,'Hagerman, ID',26718,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63931,NULL,'Hagerman, ID 83332',26718,222,NULL,16,36920,0);
INSERT INTO "django_geo_db_location" VALUES(63932,NULL,'Hailey, ID',26719,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63933,NULL,'Hailey, ID 83333',26719,222,NULL,16,36921,0);
INSERT INTO "django_geo_db_location" VALUES(63934,NULL,'Hansen, ID',26720,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63935,NULL,'Hansen, ID 83334',26720,222,NULL,16,36922,0);
INSERT INTO "django_geo_db_location" VALUES(63936,NULL,'Hazelton, ID',26721,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63937,NULL,'Hazelton, ID 83335',26721,222,NULL,16,36923,0);
INSERT INTO "django_geo_db_location" VALUES(63938,NULL,'Heyburn, ID',26722,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63939,NULL,'Heyburn, ID 83336',26722,222,NULL,16,36924,0);
INSERT INTO "django_geo_db_location" VALUES(63940,NULL,'Hill City, ID',26723,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63941,NULL,'Hill City, ID 83337',26723,222,NULL,16,36925,0);
INSERT INTO "django_geo_db_location" VALUES(63942,NULL,'Jerome, ID',26724,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63943,NULL,'Jerome, ID 83338',26724,222,NULL,16,36926,0);
INSERT INTO "django_geo_db_location" VALUES(63944,NULL,'Ketchum, ID',26725,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63945,NULL,'Ketchum, ID 83340',26725,222,NULL,16,36927,0);
INSERT INTO "django_geo_db_location" VALUES(63946,NULL,'Kimberly, ID',26726,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63947,NULL,'Kimberly, ID 83341',26726,222,NULL,16,36928,0);
INSERT INTO "django_geo_db_location" VALUES(63948,NULL,'Malta, ID',26727,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63949,NULL,'Malta, ID 83342',26727,222,NULL,16,36929,0);
INSERT INTO "django_geo_db_location" VALUES(63950,NULL,'Minidoka, ID',26728,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63951,NULL,'Minidoka, ID 83343',26728,222,NULL,16,36930,0);
INSERT INTO "django_geo_db_location" VALUES(63952,NULL,'Murtaugh, ID',26729,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63953,NULL,'Murtaugh, ID 83344',26729,222,NULL,16,36931,0);
INSERT INTO "django_geo_db_location" VALUES(63954,NULL,'Oakley, ID',26730,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63955,NULL,'Oakley, ID 83346',26730,222,NULL,16,36932,0);
INSERT INTO "django_geo_db_location" VALUES(63956,NULL,'Paul, ID',26731,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63957,NULL,'Paul, ID 83347',26731,222,NULL,16,36933,0);
INSERT INTO "django_geo_db_location" VALUES(63958,NULL,'Picabo, ID',26732,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63959,NULL,'Picabo, ID 83348',26732,222,NULL,16,36934,0);
INSERT INTO "django_geo_db_location" VALUES(63960,NULL,'Richfield, ID',26733,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63961,NULL,'Richfield, ID 83349',26733,222,NULL,16,36935,0);
INSERT INTO "django_geo_db_location" VALUES(63962,NULL,'Rupert, ID',26734,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63963,NULL,'Rupert, ID 83350',26734,222,NULL,16,36936,0);
INSERT INTO "django_geo_db_location" VALUES(63964,NULL,'Shoshone, ID',26735,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63965,NULL,'Shoshone, ID 83352',26735,222,NULL,16,36937,0);
INSERT INTO "django_geo_db_location" VALUES(63966,NULL,'Sun Valley, ID',26736,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63967,NULL,'Sun Valley, ID 83353',26736,222,NULL,16,36938,0);
INSERT INTO "django_geo_db_location" VALUES(63968,NULL,'Sun Valley, ID 83354',26736,222,NULL,16,36939,0);
INSERT INTO "django_geo_db_location" VALUES(63969,NULL,'Wendell, ID',26737,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63970,NULL,'Wendell, ID 83355',26737,222,NULL,16,36940,0);
INSERT INTO "django_geo_db_location" VALUES(63971,NULL,'Idaho Falls, ID',26738,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63972,NULL,'Idaho Falls, ID 83401',26738,222,NULL,16,36941,0);
INSERT INTO "django_geo_db_location" VALUES(63973,NULL,'Idaho Falls, ID 83402',26738,222,NULL,16,36942,0);
INSERT INTO "django_geo_db_location" VALUES(63974,NULL,'Idaho Falls, ID 83403',26738,222,NULL,16,36943,0);
INSERT INTO "django_geo_db_location" VALUES(63975,NULL,'Idaho Falls, ID 83404',26738,222,NULL,16,36944,0);
INSERT INTO "django_geo_db_location" VALUES(63976,NULL,'Idaho Falls, ID 83405',26738,222,NULL,16,36945,0);
INSERT INTO "django_geo_db_location" VALUES(63977,NULL,'Idaho Falls, ID 83406',26738,222,NULL,16,36946,0);
INSERT INTO "django_geo_db_location" VALUES(63978,NULL,'Idaho Falls, ID 83415',26738,222,NULL,16,36947,0);
INSERT INTO "django_geo_db_location" VALUES(63979,NULL,'Ashton, ID',26739,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63980,NULL,'Ashton, ID 83420',26739,222,NULL,16,36948,0);
INSERT INTO "django_geo_db_location" VALUES(63981,NULL,'Chester, ID',26740,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63982,NULL,'Chester, ID 83421',26740,222,NULL,16,36949,0);
INSERT INTO "django_geo_db_location" VALUES(63983,NULL,'Driggs, ID',26741,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63984,NULL,'Driggs, ID 83422',26741,222,NULL,16,36950,0);
INSERT INTO "django_geo_db_location" VALUES(63985,NULL,'Dubois, ID',26742,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63986,NULL,'Dubois, ID 83423',26742,222,NULL,16,36951,0);
INSERT INTO "django_geo_db_location" VALUES(63987,NULL,'Felt, ID',26743,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63988,NULL,'Felt, ID 83424',26743,222,NULL,16,36952,0);
INSERT INTO "django_geo_db_location" VALUES(63989,NULL,'Hamer, ID',26744,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63990,NULL,'Hamer, ID 83425',26744,222,NULL,16,36953,0);
INSERT INTO "django_geo_db_location" VALUES(63991,NULL,'Iona, ID',26745,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63992,NULL,'Iona, ID 83427',26745,222,NULL,16,36954,0);
INSERT INTO "django_geo_db_location" VALUES(63993,NULL,'Irwin, ID',26746,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63994,NULL,'Irwin, ID 83428',26746,222,NULL,16,36955,0);
INSERT INTO "django_geo_db_location" VALUES(63995,NULL,'Island Park, ID',26747,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63996,NULL,'Island Park, ID 83429',26747,222,NULL,16,36956,0);
INSERT INTO "django_geo_db_location" VALUES(63997,NULL,'Lewisville, ID',26748,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(63998,NULL,'Lewisville, ID 83431',26748,222,NULL,16,36957,0);
INSERT INTO "django_geo_db_location" VALUES(63999,NULL,'Macks Inn, ID',26749,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64000,NULL,'Macks Inn, ID 83433',26749,222,NULL,16,36958,0);
INSERT INTO "django_geo_db_location" VALUES(64001,NULL,'Menan, ID',26750,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64002,NULL,'Menan, ID 83434',26750,222,NULL,16,36959,0);
INSERT INTO "django_geo_db_location" VALUES(64003,NULL,'Monteview, ID',26751,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64004,NULL,'Monteview, ID 83435',26751,222,NULL,16,36960,0);
INSERT INTO "django_geo_db_location" VALUES(64005,NULL,'Newdale, ID',26752,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64006,NULL,'Newdale, ID 83436',26752,222,NULL,16,36961,0);
INSERT INTO "django_geo_db_location" VALUES(64007,NULL,'Parker, ID',26753,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64008,NULL,'Parker, ID 83438',26753,222,NULL,16,36962,0);
INSERT INTO "django_geo_db_location" VALUES(64009,NULL,'Rexburg, ID',26754,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64010,NULL,'Rexburg, ID 83440',26754,222,NULL,16,36963,0);
INSERT INTO "django_geo_db_location" VALUES(64011,NULL,'Rexburg, ID 83441',26754,222,NULL,16,36964,0);
INSERT INTO "django_geo_db_location" VALUES(64012,NULL,'Rigby, ID',26755,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64013,NULL,'Rigby, ID 83442',26755,222,NULL,16,36965,0);
INSERT INTO "django_geo_db_location" VALUES(64014,NULL,'Ririe, ID',26756,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64015,NULL,'Ririe, ID 83443',26756,222,NULL,16,36966,0);
INSERT INTO "django_geo_db_location" VALUES(64016,NULL,'Roberts, ID',26757,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64017,NULL,'Roberts, ID 83444',26757,222,NULL,16,36967,0);
INSERT INTO "django_geo_db_location" VALUES(64018,NULL,'Saint Anthony, ID',26758,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64019,NULL,'Saint Anthony, ID 83445',26758,222,NULL,16,36968,0);
INSERT INTO "django_geo_db_location" VALUES(64020,NULL,'Spencer, ID',26759,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64021,NULL,'Spencer, ID 83446',26759,222,NULL,16,36969,0);
INSERT INTO "django_geo_db_location" VALUES(64022,NULL,'Squirrel, ID',26760,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64023,NULL,'Squirrel, ID 83447',26760,222,NULL,16,36970,0);
INSERT INTO "django_geo_db_location" VALUES(64024,NULL,'Sugar City, ID',26761,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64025,NULL,'Sugar City, ID 83448',26761,222,NULL,16,36971,0);
INSERT INTO "django_geo_db_location" VALUES(64026,NULL,'Swan Valley, ID',26762,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64027,NULL,'Swan Valley, ID 83449',26762,222,NULL,16,36972,0);
INSERT INTO "django_geo_db_location" VALUES(64028,NULL,'Terreton, ID',26763,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64029,NULL,'Terreton, ID 83450',26763,222,NULL,16,36973,0);
INSERT INTO "django_geo_db_location" VALUES(64030,NULL,'Teton, ID',26764,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64031,NULL,'Teton, ID 83451',26764,222,NULL,16,36974,0);
INSERT INTO "django_geo_db_location" VALUES(64032,NULL,'Tetonia, ID',26765,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64033,NULL,'Tetonia, ID 83452',26765,222,NULL,16,36975,0);
INSERT INTO "django_geo_db_location" VALUES(64034,NULL,'Ucon, ID',26766,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64035,NULL,'Ucon, ID 83454',26766,222,NULL,16,36976,0);
INSERT INTO "django_geo_db_location" VALUES(64036,NULL,'Victor, ID',26767,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64037,NULL,'Victor, ID 83455',26767,222,NULL,16,36977,0);
INSERT INTO "django_geo_db_location" VALUES(64038,NULL,'Rexburg, ID 83460',26754,222,NULL,16,36978,0);
INSERT INTO "django_geo_db_location" VALUES(64039,NULL,'Carmen, ID',26768,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64040,NULL,'Carmen, ID 83462',26768,222,NULL,16,36979,0);
INSERT INTO "django_geo_db_location" VALUES(64041,NULL,'Gibbonsville, ID',26769,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64042,NULL,'Gibbonsville, ID 83463',26769,222,NULL,16,36980,0);
INSERT INTO "django_geo_db_location" VALUES(64043,NULL,'Leadore, ID',26770,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64044,NULL,'Leadore, ID 83464',26770,222,NULL,16,36981,0);
INSERT INTO "django_geo_db_location" VALUES(64045,NULL,'Lemhi, ID',26771,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64046,NULL,'Lemhi, ID 83465',26771,222,NULL,16,36982,0);
INSERT INTO "django_geo_db_location" VALUES(64047,NULL,'North Fork, ID',26772,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64048,NULL,'North Fork, ID 83466',26772,222,NULL,16,36983,0);
INSERT INTO "django_geo_db_location" VALUES(64049,NULL,'Salmon, ID',26773,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64050,NULL,'Salmon, ID 83467',26773,222,NULL,16,36984,0);
INSERT INTO "django_geo_db_location" VALUES(64051,NULL,'Tendoy, ID',26774,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64052,NULL,'Tendoy, ID 83468',26774,222,NULL,16,36985,0);
INSERT INTO "django_geo_db_location" VALUES(64053,NULL,'Shoup, ID',26775,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64054,NULL,'Shoup, ID 83469',26775,222,NULL,16,36986,0);
INSERT INTO "django_geo_db_location" VALUES(64055,NULL,'Lewiston, ID',26776,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64056,NULL,'Lewiston, ID 83501',26776,222,NULL,16,36987,0);
INSERT INTO "django_geo_db_location" VALUES(64057,NULL,'Ahsahka, ID',26777,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64058,NULL,'Ahsahka, ID 83520',26777,222,NULL,16,36988,0);
INSERT INTO "django_geo_db_location" VALUES(64059,NULL,'Cottonwood, ID',26778,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64060,NULL,'Cottonwood, ID 83522',26778,222,NULL,16,36989,0);
INSERT INTO "django_geo_db_location" VALUES(64061,NULL,'Craigmont, ID',26779,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64062,NULL,'Craigmont, ID 83523',26779,222,NULL,16,36990,0);
INSERT INTO "django_geo_db_location" VALUES(64063,NULL,'Culdesac, ID',26780,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64064,NULL,'Culdesac, ID 83524',26780,222,NULL,16,36991,0);
INSERT INTO "django_geo_db_location" VALUES(64065,NULL,'Elk City, ID',26781,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64066,NULL,'Elk City, ID 83525',26781,222,NULL,16,36992,0);
INSERT INTO "django_geo_db_location" VALUES(64067,NULL,'Ferdinand, ID',26782,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64068,NULL,'Ferdinand, ID 83526',26782,222,NULL,16,36993,0);
INSERT INTO "django_geo_db_location" VALUES(64069,NULL,'Grangeville, ID',26783,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64070,NULL,'Grangeville, ID 83530',26783,222,NULL,16,36994,0);
INSERT INTO "django_geo_db_location" VALUES(64071,NULL,'Fenn, ID',26784,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64072,NULL,'Fenn, ID 83531',26784,222,NULL,16,36995,0);
INSERT INTO "django_geo_db_location" VALUES(64073,NULL,'Greencreek, ID',26785,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64074,NULL,'Greencreek, ID 83533',26785,222,NULL,16,36996,0);
INSERT INTO "django_geo_db_location" VALUES(64075,NULL,'Culdesac, ID 83534',26780,222,NULL,16,36997,0);
INSERT INTO "django_geo_db_location" VALUES(64076,NULL,'Juliaetta, ID',26786,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64077,NULL,'Juliaetta, ID 83535',26786,222,NULL,16,36998,0);
INSERT INTO "django_geo_db_location" VALUES(64078,NULL,'Kamiah, ID',26787,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64079,NULL,'Kamiah, ID 83536',26787,222,NULL,16,36999,0);
INSERT INTO "django_geo_db_location" VALUES(64080,NULL,'Kendrick, ID',26788,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64081,NULL,'Kendrick, ID 83537',26788,222,NULL,16,37000,0);
INSERT INTO "django_geo_db_location" VALUES(64082,NULL,'Kooskia, ID',26789,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64083,NULL,'Kooskia, ID 83539',26789,222,NULL,16,37001,0);
INSERT INTO "django_geo_db_location" VALUES(64084,NULL,'Lapwai, ID',26790,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64085,NULL,'Lapwai, ID 83540',26790,222,NULL,16,37002,0);
INSERT INTO "django_geo_db_location" VALUES(64086,NULL,'Lenore, ID',26791,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64087,NULL,'Lenore, ID 83541',26791,222,NULL,16,37003,0);
INSERT INTO "django_geo_db_location" VALUES(64088,NULL,'Lucile, ID',26792,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64089,NULL,'Lucile, ID 83542',26792,222,NULL,16,37004,0);
INSERT INTO "django_geo_db_location" VALUES(64090,NULL,'Nezperce, ID',26793,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64091,NULL,'Nezperce, ID 83543',26793,222,NULL,16,37005,0);
INSERT INTO "django_geo_db_location" VALUES(64092,NULL,'Orofino, ID',26794,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64093,NULL,'Orofino, ID 83544',26794,222,NULL,16,37006,0);
INSERT INTO "django_geo_db_location" VALUES(64094,NULL,'Peck, ID',26795,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64095,NULL,'Peck, ID 83545',26795,222,NULL,16,37007,0);
INSERT INTO "django_geo_db_location" VALUES(64096,NULL,'Pierce, ID',26796,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64097,NULL,'Pierce, ID 83546',26796,222,NULL,16,37008,0);
INSERT INTO "django_geo_db_location" VALUES(64098,NULL,'Pollock, ID',26797,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64099,NULL,'Pollock, ID 83547',26797,222,NULL,16,37009,0);
INSERT INTO "django_geo_db_location" VALUES(64100,NULL,'Reubens, ID',26798,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64101,NULL,'Reubens, ID 83548',26798,222,NULL,16,37010,0);
INSERT INTO "django_geo_db_location" VALUES(64102,NULL,'Riggins, ID',26799,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64103,NULL,'Riggins, ID 83549',26799,222,NULL,16,37011,0);
INSERT INTO "django_geo_db_location" VALUES(64104,NULL,'Spalding, ID',26800,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64105,NULL,'Spalding, ID 83551',26800,222,NULL,16,37012,0);
INSERT INTO "django_geo_db_location" VALUES(64106,NULL,'Stites, ID',26801,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64107,NULL,'Stites, ID 83552',26801,222,NULL,16,37013,0);
INSERT INTO "django_geo_db_location" VALUES(64108,NULL,'Weippe, ID',26802,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64109,NULL,'Weippe, ID 83553',26802,222,NULL,16,37014,0);
INSERT INTO "django_geo_db_location" VALUES(64110,NULL,'White Bird, ID',26803,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64111,NULL,'White Bird, ID 83554',26803,222,NULL,16,37015,0);
INSERT INTO "django_geo_db_location" VALUES(64112,NULL,'Winchester, ID',26804,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64113,NULL,'Winchester, ID 83555',26804,222,NULL,16,37016,0);
INSERT INTO "django_geo_db_location" VALUES(64114,NULL,'Atlanta, ID',26805,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64115,NULL,'Atlanta, ID 83601',26805,222,NULL,16,37017,0);
INSERT INTO "django_geo_db_location" VALUES(64116,NULL,'Banks, ID',26806,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64117,NULL,'Banks, ID 83602',26806,222,NULL,16,37018,0);
INSERT INTO "django_geo_db_location" VALUES(64118,NULL,'Bruneau, ID',26807,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64119,NULL,'Bruneau, ID 83604',26807,222,NULL,16,37019,0);
INSERT INTO "django_geo_db_location" VALUES(64120,NULL,'Caldwell, ID',26808,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64121,NULL,'Caldwell, ID 83605',26808,222,NULL,16,37020,0);
INSERT INTO "django_geo_db_location" VALUES(64122,NULL,'Caldwell, ID 83606',26808,222,NULL,16,37021,0);
INSERT INTO "django_geo_db_location" VALUES(64123,NULL,'Caldwell, ID 83607',26808,222,NULL,16,37022,0);
INSERT INTO "django_geo_db_location" VALUES(64124,NULL,'Cambridge, ID',26809,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64125,NULL,'Cambridge, ID 83610',26809,222,NULL,16,37023,0);
INSERT INTO "django_geo_db_location" VALUES(64126,NULL,'Cascade, ID',26810,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64127,NULL,'Cascade, ID 83611',26810,222,NULL,16,37024,0);
INSERT INTO "django_geo_db_location" VALUES(64128,NULL,'Council, ID',26811,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64129,NULL,'Council, ID 83612',26811,222,NULL,16,37025,0);
INSERT INTO "django_geo_db_location" VALUES(64130,NULL,'Donnelly, ID',26812,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64131,NULL,'Donnelly, ID 83615',26812,222,NULL,16,37026,0);
INSERT INTO "django_geo_db_location" VALUES(64132,NULL,'Eagle, ID',26813,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64133,NULL,'Eagle, ID 83616',26813,222,NULL,16,37027,0);
INSERT INTO "django_geo_db_location" VALUES(64134,NULL,'Emmett, ID',26814,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64135,NULL,'Emmett, ID 83617',26814,222,NULL,16,37028,0);
INSERT INTO "django_geo_db_location" VALUES(64136,NULL,'Fruitland, ID',26815,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64137,NULL,'Fruitland, ID 83619',26815,222,NULL,16,37029,0);
INSERT INTO "django_geo_db_location" VALUES(64138,NULL,'Fruitvale, ID',26816,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64139,NULL,'Fruitvale, ID 83620',26816,222,NULL,16,37030,0);
INSERT INTO "django_geo_db_location" VALUES(64140,NULL,'Garden Valley, ID',26817,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64141,NULL,'Garden Valley, ID 83622',26817,222,NULL,16,37031,0);
INSERT INTO "django_geo_db_location" VALUES(64142,NULL,'Glenns Ferry, ID',26818,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64143,NULL,'Glenns Ferry, ID 83623',26818,222,NULL,16,37032,0);
INSERT INTO "django_geo_db_location" VALUES(64144,NULL,'Grand View, ID',26819,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64145,NULL,'Grand View, ID 83624',26819,222,NULL,16,37033,0);
INSERT INTO "django_geo_db_location" VALUES(64146,NULL,'Greenleaf, ID',26820,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64147,NULL,'Greenleaf, ID 83626',26820,222,NULL,16,37034,0);
INSERT INTO "django_geo_db_location" VALUES(64148,NULL,'Hammett, ID',26821,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64149,NULL,'Hammett, ID 83627',26821,222,NULL,16,37035,0);
INSERT INTO "django_geo_db_location" VALUES(64150,NULL,'Homedale, ID',26822,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64151,NULL,'Homedale, ID 83628',26822,222,NULL,16,37036,0);
INSERT INTO "django_geo_db_location" VALUES(64152,NULL,'Horseshoe Bend, ID',26823,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64153,NULL,'Horseshoe Bend, ID 83629',26823,222,NULL,16,37037,0);
INSERT INTO "django_geo_db_location" VALUES(64154,NULL,'Huston, ID',26824,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64155,NULL,'Huston, ID 83630',26824,222,NULL,16,37038,0);
INSERT INTO "django_geo_db_location" VALUES(64156,NULL,'Idaho City, ID',26825,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64157,NULL,'Idaho City, ID 83631',26825,222,NULL,16,37039,0);
INSERT INTO "django_geo_db_location" VALUES(64158,NULL,'Indian Valley, ID',26826,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64159,NULL,'Indian Valley, ID 83632',26826,222,NULL,16,37040,0);
INSERT INTO "django_geo_db_location" VALUES(64160,NULL,'King Hill, ID',26827,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64161,NULL,'King Hill, ID 83633',26827,222,NULL,16,37041,0);
INSERT INTO "django_geo_db_location" VALUES(64162,NULL,'Kuna, ID',26828,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64163,NULL,'Kuna, ID 83634',26828,222,NULL,16,37042,0);
INSERT INTO "django_geo_db_location" VALUES(64164,NULL,'Lake Fork, ID',26829,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64165,NULL,'Lake Fork, ID 83635',26829,222,NULL,16,37043,0);
INSERT INTO "django_geo_db_location" VALUES(64166,NULL,'Letha, ID',26830,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64167,NULL,'Letha, ID 83636',26830,222,NULL,16,37044,0);
INSERT INTO "django_geo_db_location" VALUES(64168,NULL,'Lowman, ID',26831,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64169,NULL,'Lowman, ID 83637',26831,222,NULL,16,37045,0);
INSERT INTO "django_geo_db_location" VALUES(64170,NULL,'McCall, ID',26832,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64171,NULL,'McCall, ID 83638',26832,222,NULL,16,37046,0);
INSERT INTO "django_geo_db_location" VALUES(64172,NULL,'Marsing, ID',26833,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64173,NULL,'Marsing, ID 83639',26833,222,NULL,16,37047,0);
INSERT INTO "django_geo_db_location" VALUES(64174,NULL,'Melba, ID',26834,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64175,NULL,'Melba, ID 83641',26834,222,NULL,16,37048,0);
INSERT INTO "django_geo_db_location" VALUES(64176,NULL,'Meridian, ID',26835,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64177,NULL,'Meridian, ID 83642',26835,222,NULL,16,37049,0);
INSERT INTO "django_geo_db_location" VALUES(64178,NULL,'Mesa, ID',26836,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64179,NULL,'Mesa, ID 83643',26836,222,NULL,16,37050,0);
INSERT INTO "django_geo_db_location" VALUES(64180,NULL,'Middleton, ID',26837,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64181,NULL,'Middleton, ID 83644',26837,222,NULL,16,37051,0);
INSERT INTO "django_geo_db_location" VALUES(64182,NULL,'Midvale, ID',26838,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64183,NULL,'Midvale, ID 83645',26838,222,NULL,16,37052,0);
INSERT INTO "django_geo_db_location" VALUES(64184,NULL,'Mountain Home, ID',26839,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64185,NULL,'Mountain Home, ID 83647',26839,222,NULL,16,37053,0);
INSERT INTO "django_geo_db_location" VALUES(64186,NULL,'Mountain Home A F B, ID',26840,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64187,NULL,'Mountain Home A F B, ID 83648',26840,222,NULL,16,37054,0);
INSERT INTO "django_geo_db_location" VALUES(64188,NULL,'Murphy, ID',26841,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64189,NULL,'Murphy, ID 83650',26841,222,NULL,16,37055,0);
INSERT INTO "django_geo_db_location" VALUES(64190,NULL,'Nampa, ID',26842,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64191,NULL,'Nampa, ID 83651',26842,222,NULL,16,37056,0);
INSERT INTO "django_geo_db_location" VALUES(64192,NULL,'Nampa, ID 83652',26842,222,NULL,16,37057,0);
INSERT INTO "django_geo_db_location" VALUES(64193,NULL,'Nampa, ID 83653',26842,222,NULL,16,37058,0);
INSERT INTO "django_geo_db_location" VALUES(64194,NULL,'New Meadows, ID',26843,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64195,NULL,'New Meadows, ID 83654',26843,222,NULL,16,37059,0);
INSERT INTO "django_geo_db_location" VALUES(64196,NULL,'New Plymouth, ID',26844,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64197,NULL,'New Plymouth, ID 83655',26844,222,NULL,16,37060,0);
INSERT INTO "django_geo_db_location" VALUES(64198,NULL,'Notus, ID',26845,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64199,NULL,'Notus, ID 83656',26845,222,NULL,16,37061,0);
INSERT INTO "django_geo_db_location" VALUES(64200,NULL,'Ola, ID',26846,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64201,NULL,'Ola, ID 83657',26846,222,NULL,16,37062,0);
INSERT INTO "django_geo_db_location" VALUES(64202,NULL,'Parma, ID',26847,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64203,NULL,'Parma, ID 83660',26847,222,NULL,16,37063,0);
INSERT INTO "django_geo_db_location" VALUES(64204,NULL,'Payette, ID',26848,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64205,NULL,'Payette, ID 83661',26848,222,NULL,16,37064,0);
INSERT INTO "django_geo_db_location" VALUES(64206,NULL,'Placerville, ID',26849,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64207,NULL,'Placerville, ID 83666',26849,222,NULL,16,37065,0);
INSERT INTO "django_geo_db_location" VALUES(64208,NULL,'Star, ID',26850,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64209,NULL,'Star, ID 83669',26850,222,NULL,16,37066,0);
INSERT INTO "django_geo_db_location" VALUES(64210,NULL,'Sweet, ID',26851,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64211,NULL,'Sweet, ID 83670',26851,222,NULL,16,37067,0);
INSERT INTO "django_geo_db_location" VALUES(64212,NULL,'Warren, ID',26852,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64213,NULL,'Warren, ID 83671',26852,222,NULL,16,37068,0);
INSERT INTO "django_geo_db_location" VALUES(64214,NULL,'Weiser, ID',26853,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64215,NULL,'Weiser, ID 83672',26853,222,NULL,16,37069,0);
INSERT INTO "django_geo_db_location" VALUES(64216,NULL,'Wilder, ID',26854,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64217,NULL,'Wilder, ID 83676',26854,222,NULL,16,37070,0);
INSERT INTO "django_geo_db_location" VALUES(64218,NULL,'Yellow Pine, ID',26855,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64219,NULL,'Yellow Pine, ID 83677',26855,222,NULL,16,37071,0);
INSERT INTO "django_geo_db_location" VALUES(64220,NULL,'Meridian, ID 83680',26835,222,NULL,16,37072,0);
INSERT INTO "django_geo_db_location" VALUES(64221,NULL,'Nampa, ID 83686',26842,222,NULL,16,37073,0);
INSERT INTO "django_geo_db_location" VALUES(64222,NULL,'Nampa, ID 83687',26842,222,NULL,16,37074,0);
INSERT INTO "django_geo_db_location" VALUES(64223,NULL,'Boise, ID',26856,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64224,NULL,'Boise, ID 83701',26856,222,NULL,16,37075,0);
INSERT INTO "django_geo_db_location" VALUES(64225,NULL,'Boise, ID 83702',26856,222,NULL,16,37076,0);
INSERT INTO "django_geo_db_location" VALUES(64226,NULL,'Boise, ID 83703',26856,222,NULL,16,37077,0);
INSERT INTO "django_geo_db_location" VALUES(64227,NULL,'Boise, ID 83704',26856,222,NULL,16,37078,0);
INSERT INTO "django_geo_db_location" VALUES(64228,NULL,'Boise, ID 83705',26856,222,NULL,16,37079,0);
INSERT INTO "django_geo_db_location" VALUES(64229,NULL,'Boise, ID 83706',26856,222,NULL,16,37080,0);
INSERT INTO "django_geo_db_location" VALUES(64230,NULL,'Boise, ID 83707',26856,222,NULL,16,37081,0);
INSERT INTO "django_geo_db_location" VALUES(64231,NULL,'Boise, ID 83708',26856,222,NULL,16,37082,0);
INSERT INTO "django_geo_db_location" VALUES(64232,NULL,'Boise, ID 83709',26856,222,NULL,16,37083,0);
INSERT INTO "django_geo_db_location" VALUES(64233,NULL,'Boise, ID 83711',26856,222,NULL,16,37084,0);
INSERT INTO "django_geo_db_location" VALUES(64234,NULL,'Boise, ID 83712',26856,222,NULL,16,37085,0);
INSERT INTO "django_geo_db_location" VALUES(64235,NULL,'Boise, ID 83713',26856,222,NULL,16,37086,0);
INSERT INTO "django_geo_db_location" VALUES(64236,NULL,'Boise, ID 83714',26856,222,NULL,16,37087,0);
INSERT INTO "django_geo_db_location" VALUES(64237,NULL,'Boise, ID 83715',26856,222,NULL,16,37088,0);
INSERT INTO "django_geo_db_location" VALUES(64238,NULL,'Boise, ID 83716',26856,222,NULL,16,37089,0);
INSERT INTO "django_geo_db_location" VALUES(64239,NULL,'Boise, ID 83717',26856,222,NULL,16,37090,0);
INSERT INTO "django_geo_db_location" VALUES(64240,NULL,'Boise, ID 83719',26856,222,NULL,16,37091,0);
INSERT INTO "django_geo_db_location" VALUES(64241,NULL,'Boise, ID 83720',26856,222,NULL,16,37092,0);
INSERT INTO "django_geo_db_location" VALUES(64242,NULL,'Boise, ID 83721',26856,222,NULL,16,37093,0);
INSERT INTO "django_geo_db_location" VALUES(64243,NULL,'Boise, ID 83722',26856,222,NULL,16,37094,0);
INSERT INTO "django_geo_db_location" VALUES(64244,NULL,'Boise, ID 83723',26856,222,NULL,16,37095,0);
INSERT INTO "django_geo_db_location" VALUES(64245,NULL,'Boise, ID 83724',26856,222,NULL,16,37096,0);
INSERT INTO "django_geo_db_location" VALUES(64246,NULL,'Boise, ID 83725',26856,222,NULL,16,37097,0);
INSERT INTO "django_geo_db_location" VALUES(64247,NULL,'Boise, ID 83726',26856,222,NULL,16,37098,0);
INSERT INTO "django_geo_db_location" VALUES(64248,NULL,'Boise, ID 83727',26856,222,NULL,16,37099,0);
INSERT INTO "django_geo_db_location" VALUES(64249,NULL,'Boise, ID 83728',26856,222,NULL,16,37100,0);
INSERT INTO "django_geo_db_location" VALUES(64250,NULL,'Boise, ID 83729',26856,222,NULL,16,37101,0);
INSERT INTO "django_geo_db_location" VALUES(64251,NULL,'Boise, ID 83730',26856,222,NULL,16,37102,0);
INSERT INTO "django_geo_db_location" VALUES(64252,NULL,'Boise, ID 83731',26856,222,NULL,16,37103,0);
INSERT INTO "django_geo_db_location" VALUES(64253,NULL,'Boise, ID 83732',26856,222,NULL,16,37104,0);
INSERT INTO "django_geo_db_location" VALUES(64254,NULL,'Boise, ID 83733',26856,222,NULL,16,37105,0);
INSERT INTO "django_geo_db_location" VALUES(64255,NULL,'Boise, ID 83735',26856,222,NULL,16,37106,0);
INSERT INTO "django_geo_db_location" VALUES(64256,NULL,'Boise, ID 83744',26856,222,NULL,16,37107,0);
INSERT INTO "django_geo_db_location" VALUES(64257,NULL,'Boise, ID 83756',26856,222,NULL,16,37108,0);
INSERT INTO "django_geo_db_location" VALUES(64258,NULL,'Boise, ID 83757',26856,222,NULL,16,37109,0);
INSERT INTO "django_geo_db_location" VALUES(64259,NULL,'Boise, ID 83788',26856,222,NULL,16,37110,0);
INSERT INTO "django_geo_db_location" VALUES(64260,NULL,'Boise, ID 83799',26856,222,NULL,16,37111,0);
INSERT INTO "django_geo_db_location" VALUES(64261,NULL,'Athol, ID',26857,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64262,NULL,'Athol, ID 83801',26857,222,NULL,16,37112,0);
INSERT INTO "django_geo_db_location" VALUES(64263,NULL,'Avery, ID',26858,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64264,NULL,'Avery, ID 83802',26858,222,NULL,16,37113,0);
INSERT INTO "django_geo_db_location" VALUES(64265,NULL,'Bayview, ID',26859,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64266,NULL,'Bayview, ID 83803',26859,222,NULL,16,37114,0);
INSERT INTO "django_geo_db_location" VALUES(64267,NULL,'Blanchard, ID',26860,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64268,NULL,'Blanchard, ID 83804',26860,222,NULL,16,37115,0);
INSERT INTO "django_geo_db_location" VALUES(64269,NULL,'Bonners Ferry, ID',26861,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64270,NULL,'Bonners Ferry, ID 83805',26861,222,NULL,16,37116,0);
INSERT INTO "django_geo_db_location" VALUES(64271,NULL,'Bovill, ID',26862,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64272,NULL,'Bovill, ID 83806',26862,222,NULL,16,37117,0);
INSERT INTO "django_geo_db_location" VALUES(64273,NULL,'Calder, ID',26863,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64274,NULL,'Calder, ID 83808',26863,222,NULL,16,37118,0);
INSERT INTO "django_geo_db_location" VALUES(64275,NULL,'Careywood, ID',26864,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64276,NULL,'Careywood, ID 83809',26864,222,NULL,16,37119,0);
INSERT INTO "django_geo_db_location" VALUES(64277,NULL,'Cataldo, ID',26865,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64278,NULL,'Cataldo, ID 83810',26865,222,NULL,16,37120,0);
INSERT INTO "django_geo_db_location" VALUES(64279,NULL,'Clark Fork, ID',26866,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64280,NULL,'Clark Fork, ID 83811',26866,222,NULL,16,37121,0);
INSERT INTO "django_geo_db_location" VALUES(64281,NULL,'Clarkia, ID',26867,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64282,NULL,'Clarkia, ID 83812',26867,222,NULL,16,37122,0);
INSERT INTO "django_geo_db_location" VALUES(64283,NULL,'Cocolalla, ID',26868,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64284,NULL,'Cocolalla, ID 83813',26868,222,NULL,16,37123,0);
INSERT INTO "django_geo_db_location" VALUES(64285,NULL,'Coeur D Alene, ID',26869,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64286,NULL,'Coeur D Alene, ID 83814',26869,222,NULL,16,37124,0);
INSERT INTO "django_geo_db_location" VALUES(64287,NULL,'Coeur D Alene, ID 83815',26869,222,NULL,16,37125,0);
INSERT INTO "django_geo_db_location" VALUES(64288,NULL,'Coeur D Alene, ID 83816',26869,222,NULL,16,37126,0);
INSERT INTO "django_geo_db_location" VALUES(64289,NULL,'Coolin, ID',26870,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64290,NULL,'Coolin, ID 83821',26870,222,NULL,16,37127,0);
INSERT INTO "django_geo_db_location" VALUES(64291,NULL,'Oldtown, ID',26871,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64292,NULL,'Oldtown, ID 83822',26871,222,NULL,16,37128,0);
INSERT INTO "django_geo_db_location" VALUES(64293,NULL,'Deary, ID',26872,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64294,NULL,'Deary, ID 83823',26872,222,NULL,16,37129,0);
INSERT INTO "django_geo_db_location" VALUES(64295,NULL,'Desmet, ID',26873,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64296,NULL,'Desmet, ID 83824',26873,222,NULL,16,37130,0);
INSERT INTO "django_geo_db_location" VALUES(64297,NULL,'Dover, ID',26874,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64298,NULL,'Dover, ID 83825',26874,222,NULL,16,37131,0);
INSERT INTO "django_geo_db_location" VALUES(64299,NULL,'Eastport, ID',26875,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64300,NULL,'Eastport, ID 83826',26875,222,NULL,16,37132,0);
INSERT INTO "django_geo_db_location" VALUES(64301,NULL,'Elk River, ID',26876,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64302,NULL,'Elk River, ID 83827',26876,222,NULL,16,37133,0);
INSERT INTO "django_geo_db_location" VALUES(64303,NULL,'Fernwood, ID',26877,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64304,NULL,'Fernwood, ID 83830',26877,222,NULL,16,37134,0);
INSERT INTO "django_geo_db_location" VALUES(64305,NULL,'Genesee, ID',26878,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64306,NULL,'Genesee, ID 83832',26878,222,NULL,16,37135,0);
INSERT INTO "django_geo_db_location" VALUES(64307,NULL,'Harrison, ID',26879,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64308,NULL,'Harrison, ID 83833',26879,222,NULL,16,37136,0);
INSERT INTO "django_geo_db_location" VALUES(64309,NULL,'Harvard, ID',26880,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64310,NULL,'Harvard, ID 83834',26880,222,NULL,16,37137,0);
INSERT INTO "django_geo_db_location" VALUES(64311,NULL,'Hayden, ID',26881,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64312,NULL,'Hayden, ID 83835',26881,222,NULL,16,37138,0);
INSERT INTO "django_geo_db_location" VALUES(64313,NULL,'Hope, ID',26882,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64314,NULL,'Hope, ID 83836',26882,222,NULL,16,37139,0);
INSERT INTO "django_geo_db_location" VALUES(64315,NULL,'Kellogg, ID',26883,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64316,NULL,'Kellogg, ID 83837',26883,222,NULL,16,37140,0);
INSERT INTO "django_geo_db_location" VALUES(64317,NULL,'Kingston, ID',26884,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64318,NULL,'Kingston, ID 83839',26884,222,NULL,16,37141,0);
INSERT INTO "django_geo_db_location" VALUES(64319,NULL,'Kootenai, ID',26885,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64320,NULL,'Kootenai, ID 83840',26885,222,NULL,16,37142,0);
INSERT INTO "django_geo_db_location" VALUES(64321,NULL,'Laclede, ID',26886,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64322,NULL,'Laclede, ID 83841',26886,222,NULL,16,37143,0);
INSERT INTO "django_geo_db_location" VALUES(64323,NULL,'Medimont, ID',26887,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64324,NULL,'Medimont, ID 83842',26887,222,NULL,16,37144,0);
INSERT INTO "django_geo_db_location" VALUES(64325,NULL,'Moscow, ID',26888,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64326,NULL,'Moscow, ID 83843',26888,222,NULL,16,37145,0);
INSERT INTO "django_geo_db_location" VALUES(64327,NULL,'Moscow, ID 83844',26888,222,NULL,16,37146,0);
INSERT INTO "django_geo_db_location" VALUES(64328,NULL,'Moyie Springs, ID',26889,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64329,NULL,'Moyie Springs, ID 83845',26889,222,NULL,16,37147,0);
INSERT INTO "django_geo_db_location" VALUES(64330,NULL,'Mullan, ID',26890,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64331,NULL,'Mullan, ID 83846',26890,222,NULL,16,37148,0);
INSERT INTO "django_geo_db_location" VALUES(64332,NULL,'Naples, ID',26891,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64333,NULL,'Naples, ID 83847',26891,222,NULL,16,37149,0);
INSERT INTO "django_geo_db_location" VALUES(64334,NULL,'Nordman, ID',26892,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64335,NULL,'Nordman, ID 83848',26892,222,NULL,16,37150,0);
INSERT INTO "django_geo_db_location" VALUES(64336,NULL,'Osburn, ID',26893,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64337,NULL,'Osburn, ID 83849',26893,222,NULL,16,37151,0);
INSERT INTO "django_geo_db_location" VALUES(64338,NULL,'Pinehurst, ID',26894,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64339,NULL,'Pinehurst, ID 83850',26894,222,NULL,16,37152,0);
INSERT INTO "django_geo_db_location" VALUES(64340,NULL,'Plummer, ID',26895,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64341,NULL,'Plummer, ID 83851',26895,222,NULL,16,37153,0);
INSERT INTO "django_geo_db_location" VALUES(64342,NULL,'Ponderay, ID',26896,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64343,NULL,'Ponderay, ID 83852',26896,222,NULL,16,37154,0);
INSERT INTO "django_geo_db_location" VALUES(64344,NULL,'Porthill, ID',26897,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64345,NULL,'Porthill, ID 83853',26897,222,NULL,16,37155,0);
INSERT INTO "django_geo_db_location" VALUES(64346,NULL,'Post Falls, ID',26898,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64347,NULL,'Post Falls, ID 83854',26898,222,NULL,16,37156,0);
INSERT INTO "django_geo_db_location" VALUES(64348,NULL,'Potlatch, ID',26899,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64349,NULL,'Potlatch, ID 83855',26899,222,NULL,16,37157,0);
INSERT INTO "django_geo_db_location" VALUES(64350,NULL,'Priest River, ID',26900,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64351,NULL,'Priest River, ID 83856',26900,222,NULL,16,37158,0);
INSERT INTO "django_geo_db_location" VALUES(64352,NULL,'Princeton, ID',26901,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64353,NULL,'Princeton, ID 83857',26901,222,NULL,16,37159,0);
INSERT INTO "django_geo_db_location" VALUES(64354,NULL,'Rathdrum, ID',26902,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64355,NULL,'Rathdrum, ID 83858',26902,222,NULL,16,37160,0);
INSERT INTO "django_geo_db_location" VALUES(64356,NULL,'Sagle, ID',26903,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64357,NULL,'Sagle, ID 83860',26903,222,NULL,16,37161,0);
INSERT INTO "django_geo_db_location" VALUES(64358,NULL,'Saint Maries, ID',26904,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64359,NULL,'Saint Maries, ID 83861',26904,222,NULL,16,37162,0);
INSERT INTO "django_geo_db_location" VALUES(64360,NULL,'Samuels, ID',26905,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64361,NULL,'Samuels, ID 83862',26905,222,NULL,16,37163,0);
INSERT INTO "django_geo_db_location" VALUES(64362,NULL,'Sandpoint, ID',26906,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64363,NULL,'Sandpoint, ID 83864',26906,222,NULL,16,37164,0);
INSERT INTO "django_geo_db_location" VALUES(64364,NULL,'Colburn, ID',26907,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64365,NULL,'Colburn, ID 83865',26907,222,NULL,16,37165,0);
INSERT INTO "django_geo_db_location" VALUES(64366,NULL,'Santa, ID',26908,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64367,NULL,'Santa, ID 83866',26908,222,NULL,16,37166,0);
INSERT INTO "django_geo_db_location" VALUES(64368,NULL,'Silverton, ID',26909,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64369,NULL,'Silverton, ID 83867',26909,222,NULL,16,37167,0);
INSERT INTO "django_geo_db_location" VALUES(64370,NULL,'Smelterville, ID',26910,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64371,NULL,'Smelterville, ID 83868',26910,222,NULL,16,37168,0);
INSERT INTO "django_geo_db_location" VALUES(64372,NULL,'Spirit Lake, ID',26911,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64373,NULL,'Spirit Lake, ID 83869',26911,222,NULL,16,37169,0);
INSERT INTO "django_geo_db_location" VALUES(64374,NULL,'Tensed, ID',26912,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64375,NULL,'Tensed, ID 83870',26912,222,NULL,16,37170,0);
INSERT INTO "django_geo_db_location" VALUES(64376,NULL,'Troy, ID',26913,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64377,NULL,'Troy, ID 83871',26913,222,NULL,16,37171,0);
INSERT INTO "django_geo_db_location" VALUES(64378,NULL,'Viola, ID',26914,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64379,NULL,'Viola, ID 83872',26914,222,NULL,16,37172,0);
INSERT INTO "django_geo_db_location" VALUES(64380,NULL,'Wallace, ID',26915,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64381,NULL,'Wallace, ID 83873',26915,222,NULL,16,37173,0);
INSERT INTO "django_geo_db_location" VALUES(64382,NULL,'Murray, ID',26916,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64383,NULL,'Murray, ID 83874',26916,222,NULL,16,37174,0);
INSERT INTO "django_geo_db_location" VALUES(64384,NULL,'Worley, ID',26917,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64385,NULL,'Worley, ID 83876',26917,222,NULL,16,37175,0);
INSERT INTO "django_geo_db_location" VALUES(64386,NULL,'Post Falls, ID 83877',26898,222,NULL,16,37176,0);
INSERT INTO "django_geo_db_location" VALUES(64387,NULL,'Sandpoint, ID 83888',26906,222,NULL,16,37177,0);
INSERT INTO "django_geo_db_location" VALUES(64388,NULL,'Altamont, UT',26918,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64389,NULL,'Altamont, UT 84001',26918,222,NULL,52,37178,0);
INSERT INTO "django_geo_db_location" VALUES(64390,NULL,'Altonah, UT',26919,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64391,NULL,'Altonah, UT 84002',26919,222,NULL,52,37179,0);
INSERT INTO "django_geo_db_location" VALUES(64392,NULL,'American Fork, UT',26920,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64393,NULL,'American Fork, UT 84003',26920,222,NULL,52,37180,0);
INSERT INTO "django_geo_db_location" VALUES(64394,NULL,'Alpine, UT',26921,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64395,NULL,'Alpine, UT 84004',26921,222,NULL,52,37181,0);
INSERT INTO "django_geo_db_location" VALUES(64396,NULL,'Bingham Canyon, UT',26922,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64397,NULL,'Bingham Canyon, UT 84006',26922,222,NULL,52,37182,0);
INSERT INTO "django_geo_db_location" VALUES(64398,NULL,'Bluebell, UT',26923,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64399,NULL,'Bluebell, UT 84007',26923,222,NULL,52,37183,0);
INSERT INTO "django_geo_db_location" VALUES(64400,NULL,'Bonanza, UT',26924,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64401,NULL,'Bonanza, UT 84008',26924,222,NULL,52,37184,0);
INSERT INTO "django_geo_db_location" VALUES(64402,NULL,'Bountiful, UT',26925,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64403,NULL,'Bountiful, UT 84010',26925,222,NULL,52,37185,0);
INSERT INTO "django_geo_db_location" VALUES(64404,NULL,'Bountiful, UT 84011',26925,222,NULL,52,37186,0);
INSERT INTO "django_geo_db_location" VALUES(64405,NULL,'Cedar Valley, UT',26926,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64406,NULL,'Cedar Valley, UT 84013',26926,222,NULL,52,37187,0);
INSERT INTO "django_geo_db_location" VALUES(64407,NULL,'Centerville, UT',26927,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64408,NULL,'Centerville, UT 84014',26927,222,NULL,52,37188,0);
INSERT INTO "django_geo_db_location" VALUES(64409,NULL,'Clearfield, UT',26928,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64410,NULL,'Clearfield, UT 84015',26928,222,NULL,52,37189,0);
INSERT INTO "django_geo_db_location" VALUES(64411,NULL,'Clearfield, UT 84016',26928,222,NULL,52,37190,0);
INSERT INTO "django_geo_db_location" VALUES(64412,NULL,'Coalville, UT',26929,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64413,NULL,'Coalville, UT 84017',26929,222,NULL,52,37191,0);
INSERT INTO "django_geo_db_location" VALUES(64414,NULL,'Croydon, UT',26930,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64415,NULL,'Croydon, UT 84018',26930,222,NULL,52,37192,0);
INSERT INTO "django_geo_db_location" VALUES(64416,NULL,'Draper, UT',26931,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64417,NULL,'Draper, UT 84020',26931,222,NULL,52,37193,0);
INSERT INTO "django_geo_db_location" VALUES(64418,NULL,'Duchesne, UT',26932,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64419,NULL,'Duchesne, UT 84021',26932,222,NULL,52,37194,0);
INSERT INTO "django_geo_db_location" VALUES(64420,NULL,'Dugway, UT',26933,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64421,NULL,'Dugway, UT 84022',26933,222,NULL,52,37195,0);
INSERT INTO "django_geo_db_location" VALUES(64422,NULL,'Dutch John, UT',26934,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64423,NULL,'Dutch John, UT 84023',26934,222,NULL,52,37196,0);
INSERT INTO "django_geo_db_location" VALUES(64424,NULL,'Echo, UT',26935,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64425,NULL,'Echo, UT 84024',26935,222,NULL,52,37197,0);
INSERT INTO "django_geo_db_location" VALUES(64426,NULL,'Farmington, UT',26936,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64427,NULL,'Farmington, UT 84025',26936,222,NULL,52,37198,0);
INSERT INTO "django_geo_db_location" VALUES(64428,NULL,'Fort Duchesne, UT',26937,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64429,NULL,'Fort Duchesne, UT 84026',26937,222,NULL,52,37199,0);
INSERT INTO "django_geo_db_location" VALUES(64430,NULL,'Fruitland, UT',26938,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64431,NULL,'Fruitland, UT 84027',26938,222,NULL,52,37200,0);
INSERT INTO "django_geo_db_location" VALUES(64432,NULL,'Garden City, UT',26939,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64433,NULL,'Garden City, UT 84028',26939,222,NULL,52,37201,0);
INSERT INTO "django_geo_db_location" VALUES(64434,NULL,'Grantsville, UT',26940,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64435,NULL,'Grantsville, UT 84029',26940,222,NULL,52,37202,0);
INSERT INTO "django_geo_db_location" VALUES(64436,NULL,'Gusher, UT',26941,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64437,NULL,'Gusher, UT 84030',26941,222,NULL,52,37203,0);
INSERT INTO "django_geo_db_location" VALUES(64438,NULL,'Hanna, UT',26942,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64439,NULL,'Hanna, UT 84031',26942,222,NULL,52,37204,0);
INSERT INTO "django_geo_db_location" VALUES(64440,NULL,'Heber City, UT',26943,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64441,NULL,'Heber City, UT 84032',26943,222,NULL,52,37205,0);
INSERT INTO "django_geo_db_location" VALUES(64442,NULL,'Henefer, UT',26944,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64443,NULL,'Henefer, UT 84033',26944,222,NULL,52,37206,0);
INSERT INTO "django_geo_db_location" VALUES(64444,NULL,'Ibapah, UT',26945,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64445,NULL,'Ibapah, UT 84034',26945,222,NULL,52,37207,0);
INSERT INTO "django_geo_db_location" VALUES(64446,NULL,'Jensen, UT',26946,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64447,NULL,'Jensen, UT 84035',26946,222,NULL,52,37208,0);
INSERT INTO "django_geo_db_location" VALUES(64448,NULL,'Kamas, UT',26947,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64449,NULL,'Kamas, UT 84036',26947,222,NULL,52,37209,0);
INSERT INTO "django_geo_db_location" VALUES(64450,NULL,'Kaysville, UT',26948,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64451,NULL,'Kaysville, UT 84037',26948,222,NULL,52,37210,0);
INSERT INTO "django_geo_db_location" VALUES(64452,NULL,'Laketown, UT',26949,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64453,NULL,'Laketown, UT 84038',26949,222,NULL,52,37211,0);
INSERT INTO "django_geo_db_location" VALUES(64454,NULL,'Lapoint, UT',26950,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64455,NULL,'Lapoint, UT 84039',26950,222,NULL,52,37212,0);
INSERT INTO "django_geo_db_location" VALUES(64456,NULL,'Layton, UT',26951,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64457,NULL,'Layton, UT 84040',26951,222,NULL,52,37213,0);
INSERT INTO "django_geo_db_location" VALUES(64458,NULL,'Layton, UT 84041',26951,222,NULL,52,37214,0);
INSERT INTO "django_geo_db_location" VALUES(64459,NULL,'Lindon, UT',26952,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64460,NULL,'Lindon, UT 84042',26952,222,NULL,52,37215,0);
INSERT INTO "django_geo_db_location" VALUES(64461,NULL,'Lehi, UT',26953,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64462,NULL,'Lehi, UT 84043',26953,222,NULL,52,37216,0);
INSERT INTO "django_geo_db_location" VALUES(64463,NULL,'Magna, UT',26954,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64464,NULL,'Magna, UT 84044',26954,222,NULL,52,37217,0);
INSERT INTO "django_geo_db_location" VALUES(64465,NULL,'Manila, UT',26955,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64466,NULL,'Manila, UT 84046',26955,222,NULL,52,37218,0);
INSERT INTO "django_geo_db_location" VALUES(64467,NULL,'Midvale, UT',26956,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64468,NULL,'Midvale, UT 84047',26956,222,NULL,52,37219,0);
INSERT INTO "django_geo_db_location" VALUES(64469,NULL,'Midway, UT',26957,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64470,NULL,'Midway, UT 84049',26957,222,NULL,52,37220,0);
INSERT INTO "django_geo_db_location" VALUES(64471,NULL,'Morgan, UT',26958,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64472,NULL,'Morgan, UT 84050',26958,222,NULL,52,37221,0);
INSERT INTO "django_geo_db_location" VALUES(64473,NULL,'Mountain Home, UT',26959,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64474,NULL,'Mountain Home, UT 84051',26959,222,NULL,52,37222,0);
INSERT INTO "django_geo_db_location" VALUES(64475,NULL,'Myton, UT',26960,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64476,NULL,'Myton, UT 84052',26960,222,NULL,52,37223,0);
INSERT INTO "django_geo_db_location" VALUES(64477,NULL,'Neola, UT',26961,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64478,NULL,'Neola, UT 84053',26961,222,NULL,52,37224,0);
INSERT INTO "django_geo_db_location" VALUES(64479,NULL,'North Salt Lake, UT',26962,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64480,NULL,'North Salt Lake, UT 84054',26962,222,NULL,52,37225,0);
INSERT INTO "django_geo_db_location" VALUES(64481,NULL,'Oakley, UT',26963,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64482,NULL,'Oakley, UT 84055',26963,222,NULL,52,37226,0);
INSERT INTO "django_geo_db_location" VALUES(64483,NULL,'Hill AFB, UT',26964,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64484,NULL,'Hill AFB, UT 84056',26964,222,NULL,52,37227,0);
INSERT INTO "django_geo_db_location" VALUES(64485,NULL,'Orem, UT',26965,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64486,NULL,'Orem, UT 84057',26965,222,NULL,52,37228,0);
INSERT INTO "django_geo_db_location" VALUES(64487,NULL,'Orem, UT 84058',26965,222,NULL,52,37229,0);
INSERT INTO "django_geo_db_location" VALUES(64488,NULL,'Orem, UT 84059',26965,222,NULL,52,37230,0);
INSERT INTO "django_geo_db_location" VALUES(64489,NULL,'Park City, UT',26966,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64490,NULL,'Park City, UT 84060',26966,222,NULL,52,37231,0);
INSERT INTO "django_geo_db_location" VALUES(64491,NULL,'Peoa, UT',26967,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64492,NULL,'Peoa, UT 84061',26967,222,NULL,52,37232,0);
INSERT INTO "django_geo_db_location" VALUES(64493,NULL,'Pleasant Grove, UT',26968,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64494,NULL,'Pleasant Grove, UT 84062',26968,222,NULL,52,37233,0);
INSERT INTO "django_geo_db_location" VALUES(64495,NULL,'Randlett, UT',26969,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64496,NULL,'Randlett, UT 84063',26969,222,NULL,52,37234,0);
INSERT INTO "django_geo_db_location" VALUES(64497,NULL,'Randolph, UT',26970,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64498,NULL,'Randolph, UT 84064',26970,222,NULL,52,37235,0);
INSERT INTO "django_geo_db_location" VALUES(64499,NULL,'Riverton, UT',26971,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64500,NULL,'Riverton, UT 84065',26971,222,NULL,52,37236,0);
INSERT INTO "django_geo_db_location" VALUES(64501,NULL,'Roosevelt, UT',26972,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64502,NULL,'Roosevelt, UT 84066',26972,222,NULL,52,37237,0);
INSERT INTO "django_geo_db_location" VALUES(64503,NULL,'Roy, UT',26973,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64504,NULL,'Roy, UT 84067',26973,222,NULL,52,37238,0);
INSERT INTO "django_geo_db_location" VALUES(64505,NULL,'Park City, UT 84068',26966,222,NULL,52,37239,0);
INSERT INTO "django_geo_db_location" VALUES(64506,NULL,'Rush Valley, UT',26974,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64507,NULL,'Rush Valley, UT 84069',26974,222,NULL,52,37240,0);
INSERT INTO "django_geo_db_location" VALUES(64508,NULL,'Sandy, UT',26975,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64509,NULL,'Sandy, UT 84070',26975,222,NULL,52,37241,0);
INSERT INTO "django_geo_db_location" VALUES(64510,NULL,'Stockton, UT',26976,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64511,NULL,'Stockton, UT 84071',26976,222,NULL,52,37242,0);
INSERT INTO "django_geo_db_location" VALUES(64512,NULL,'Tabiona, UT',26977,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64513,NULL,'Tabiona, UT 84072',26977,222,NULL,52,37243,0);
INSERT INTO "django_geo_db_location" VALUES(64514,NULL,'Talmage, UT',26978,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64515,NULL,'Talmage, UT 84073',26978,222,NULL,52,37244,0);
INSERT INTO "django_geo_db_location" VALUES(64516,NULL,'Tooele, UT',26979,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64517,NULL,'Tooele, UT 84074',26979,222,NULL,52,37245,0);
INSERT INTO "django_geo_db_location" VALUES(64518,NULL,'Syracuse, UT',26980,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64519,NULL,'Syracuse, UT 84075',26980,222,NULL,52,37246,0);
INSERT INTO "django_geo_db_location" VALUES(64520,NULL,'Tridell, UT',26981,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64521,NULL,'Tridell, UT 84076',26981,222,NULL,52,37247,0);
INSERT INTO "django_geo_db_location" VALUES(64522,NULL,'Vernal, UT',26982,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64523,NULL,'Vernal, UT 84078',26982,222,NULL,52,37248,0);
INSERT INTO "django_geo_db_location" VALUES(64524,NULL,'Vernal, UT 84079',26982,222,NULL,52,37249,0);
INSERT INTO "django_geo_db_location" VALUES(64525,NULL,'Vernon, UT',26983,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64526,NULL,'Vernon, UT 84080',26983,222,NULL,52,37250,0);
INSERT INTO "django_geo_db_location" VALUES(64527,NULL,'Wallsburg, UT',26984,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64528,NULL,'Wallsburg, UT 84082',26984,222,NULL,52,37251,0);
INSERT INTO "django_geo_db_location" VALUES(64529,NULL,'Wendover, UT',26985,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64530,NULL,'Wendover, UT 84083',26985,222,NULL,52,37252,0);
INSERT INTO "django_geo_db_location" VALUES(64531,NULL,'West Jordan, UT',26986,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64532,NULL,'West Jordan, UT 84084',26986,222,NULL,52,37253,0);
INSERT INTO "django_geo_db_location" VALUES(64533,NULL,'Whiterocks, UT',26987,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64534,NULL,'Whiterocks, UT 84085',26987,222,NULL,52,37254,0);
INSERT INTO "django_geo_db_location" VALUES(64535,NULL,'Woodruff, UT',26988,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64536,NULL,'Woodruff, UT 84086',26988,222,NULL,52,37255,0);
INSERT INTO "django_geo_db_location" VALUES(64537,NULL,'Woods Cross, UT',26989,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64538,NULL,'Woods Cross, UT 84087',26989,222,NULL,52,37256,0);
INSERT INTO "django_geo_db_location" VALUES(64539,NULL,'West Jordan, UT 84088',26986,222,NULL,52,37257,0);
INSERT INTO "django_geo_db_location" VALUES(64540,NULL,'Clearfield, UT 84089',26928,222,NULL,52,37258,0);
INSERT INTO "django_geo_db_location" VALUES(64541,NULL,'Sandy, UT 84090',26975,222,NULL,52,37259,0);
INSERT INTO "django_geo_db_location" VALUES(64542,NULL,'Sandy, UT 84091',26975,222,NULL,52,37260,0);
INSERT INTO "django_geo_db_location" VALUES(64543,NULL,'Sandy, UT 84092',26975,222,NULL,52,37261,0);
INSERT INTO "django_geo_db_location" VALUES(64544,NULL,'Sandy, UT 84093',26975,222,NULL,52,37262,0);
INSERT INTO "django_geo_db_location" VALUES(64545,NULL,'Sandy, UT 84094',26975,222,NULL,52,37263,0);
INSERT INTO "django_geo_db_location" VALUES(64546,NULL,'South Jordan, UT',26990,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64547,NULL,'South Jordan, UT 84095',26990,222,NULL,52,37264,0);
INSERT INTO "django_geo_db_location" VALUES(64548,NULL,'Orem, UT 84097',26965,222,NULL,52,37265,0);
INSERT INTO "django_geo_db_location" VALUES(64549,NULL,'Park City, UT 84098',26966,222,NULL,52,37266,0);
INSERT INTO "django_geo_db_location" VALUES(64550,NULL,'Salt Lake City, UT',26991,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64551,NULL,'Salt Lake City, UT 84101',26991,222,NULL,52,37267,0);
INSERT INTO "django_geo_db_location" VALUES(64552,NULL,'Salt Lake City, UT 84102',26991,222,NULL,52,37268,0);
INSERT INTO "django_geo_db_location" VALUES(64553,NULL,'Salt Lake City, UT 84103',26991,222,NULL,52,37269,0);
INSERT INTO "django_geo_db_location" VALUES(64554,NULL,'Salt Lake City, UT 84104',26991,222,NULL,52,37270,0);
INSERT INTO "django_geo_db_location" VALUES(64555,NULL,'Salt Lake City, UT 84105',26991,222,NULL,52,37271,0);
INSERT INTO "django_geo_db_location" VALUES(64556,NULL,'Salt Lake City, UT 84106',26991,222,NULL,52,37272,0);
INSERT INTO "django_geo_db_location" VALUES(64557,NULL,'Salt Lake City, UT 84107',26991,222,NULL,52,37273,0);
INSERT INTO "django_geo_db_location" VALUES(64558,NULL,'Salt Lake City, UT 84108',26991,222,NULL,52,37274,0);
INSERT INTO "django_geo_db_location" VALUES(64559,NULL,'Salt Lake City, UT 84109',26991,222,NULL,52,37275,0);
INSERT INTO "django_geo_db_location" VALUES(64560,NULL,'Salt Lake City, UT 84110',26991,222,NULL,52,37276,0);
INSERT INTO "django_geo_db_location" VALUES(64561,NULL,'Salt Lake City, UT 84111',26991,222,NULL,52,37277,0);
INSERT INTO "django_geo_db_location" VALUES(64562,NULL,'Salt Lake City, UT 84112',26991,222,NULL,52,37278,0);
INSERT INTO "django_geo_db_location" VALUES(64563,NULL,'Salt Lake City, UT 84113',26991,222,NULL,52,37279,0);
INSERT INTO "django_geo_db_location" VALUES(64564,NULL,'Salt Lake City, UT 84114',26991,222,NULL,52,37280,0);
INSERT INTO "django_geo_db_location" VALUES(64565,NULL,'Salt Lake City, UT 84115',26991,222,NULL,52,37281,0);
INSERT INTO "django_geo_db_location" VALUES(64566,NULL,'Salt Lake City, UT 84116',26991,222,NULL,52,37282,0);
INSERT INTO "django_geo_db_location" VALUES(64567,NULL,'Salt Lake City, UT 84117',26991,222,NULL,52,37283,0);
INSERT INTO "django_geo_db_location" VALUES(64568,NULL,'Salt Lake City, UT 84118',26991,222,NULL,52,37284,0);
INSERT INTO "django_geo_db_location" VALUES(64569,NULL,'Salt Lake City, UT 84119',26991,222,NULL,52,37285,0);
INSERT INTO "django_geo_db_location" VALUES(64570,NULL,'Salt Lake City, UT 84120',26991,222,NULL,52,37286,0);
INSERT INTO "django_geo_db_location" VALUES(64571,NULL,'Salt Lake City, UT 84121',26991,222,NULL,52,37287,0);
INSERT INTO "django_geo_db_location" VALUES(64572,NULL,'Salt Lake City, UT 84122',26991,222,NULL,52,37288,0);
INSERT INTO "django_geo_db_location" VALUES(64573,NULL,'Salt Lake City, UT 84123',26991,222,NULL,52,37289,0);
INSERT INTO "django_geo_db_location" VALUES(64574,NULL,'Salt Lake City, UT 84124',26991,222,NULL,52,37290,0);
INSERT INTO "django_geo_db_location" VALUES(64575,NULL,'Salt Lake City, UT 84125',26991,222,NULL,52,37291,0);
INSERT INTO "django_geo_db_location" VALUES(64576,NULL,'Salt Lake City, UT 84126',26991,222,NULL,52,37292,0);
INSERT INTO "django_geo_db_location" VALUES(64577,NULL,'Salt Lake City, UT 84127',26991,222,NULL,52,37293,0);
INSERT INTO "django_geo_db_location" VALUES(64578,NULL,'Salt Lake City, UT 84128',26991,222,NULL,52,37294,0);
INSERT INTO "django_geo_db_location" VALUES(64579,NULL,'Salt Lake City, UT 84130',26991,222,NULL,52,37295,0);
INSERT INTO "django_geo_db_location" VALUES(64580,NULL,'Salt Lake City, UT 84131',26991,222,NULL,52,37296,0);
INSERT INTO "django_geo_db_location" VALUES(64581,NULL,'Salt Lake City, UT 84132',26991,222,NULL,52,37297,0);
INSERT INTO "django_geo_db_location" VALUES(64582,NULL,'Salt Lake City, UT 84133',26991,222,NULL,52,37298,0);
INSERT INTO "django_geo_db_location" VALUES(64583,NULL,'Salt Lake City, UT 84134',26991,222,NULL,52,37299,0);
INSERT INTO "django_geo_db_location" VALUES(64584,NULL,'Salt Lake City, UT 84135',26991,222,NULL,52,37300,0);
INSERT INTO "django_geo_db_location" VALUES(64585,NULL,'Salt Lake City, UT 84136',26991,222,NULL,52,37301,0);
INSERT INTO "django_geo_db_location" VALUES(64586,NULL,'Salt Lake City, UT 84137',26991,222,NULL,52,37302,0);
INSERT INTO "django_geo_db_location" VALUES(64587,NULL,'Salt Lake City, UT 84138',26991,222,NULL,52,37303,0);
INSERT INTO "django_geo_db_location" VALUES(64588,NULL,'Salt Lake City, UT 84139',26991,222,NULL,52,37304,0);
INSERT INTO "django_geo_db_location" VALUES(64589,NULL,'Salt Lake City, UT 84140',26991,222,NULL,52,37305,0);
INSERT INTO "django_geo_db_location" VALUES(64590,NULL,'Salt Lake City, UT 84141',26991,222,NULL,52,37306,0);
INSERT INTO "django_geo_db_location" VALUES(64591,NULL,'Salt Lake City, UT 84142',26991,222,NULL,52,37307,0);
INSERT INTO "django_geo_db_location" VALUES(64592,NULL,'Salt Lake City, UT 84143',26991,222,NULL,52,37308,0);
INSERT INTO "django_geo_db_location" VALUES(64593,NULL,'Salt Lake City, UT 84144',26991,222,NULL,52,37309,0);
INSERT INTO "django_geo_db_location" VALUES(64594,NULL,'Salt Lake City, UT 84145',26991,222,NULL,52,37310,0);
INSERT INTO "django_geo_db_location" VALUES(64595,NULL,'Salt Lake City, UT 84147',26991,222,NULL,52,37311,0);
INSERT INTO "django_geo_db_location" VALUES(64596,NULL,'Salt Lake City, UT 84148',26991,222,NULL,52,37312,0);
INSERT INTO "django_geo_db_location" VALUES(64597,NULL,'Salt Lake City, UT 84150',26991,222,NULL,52,37313,0);
INSERT INTO "django_geo_db_location" VALUES(64598,NULL,'Salt Lake City, UT 84151',26991,222,NULL,52,37314,0);
INSERT INTO "django_geo_db_location" VALUES(64599,NULL,'Salt Lake City, UT 84152',26991,222,NULL,52,37315,0);
INSERT INTO "django_geo_db_location" VALUES(64600,NULL,'Salt Lake City, UT 84153',26991,222,NULL,52,37316,0);
INSERT INTO "django_geo_db_location" VALUES(64601,NULL,'Salt Lake City, UT 84157',26991,222,NULL,52,37317,0);
INSERT INTO "django_geo_db_location" VALUES(64602,NULL,'Salt Lake City, UT 84158',26991,222,NULL,52,37318,0);
INSERT INTO "django_geo_db_location" VALUES(64603,NULL,'Salt Lake City, UT 84165',26991,222,NULL,52,37319,0);
INSERT INTO "django_geo_db_location" VALUES(64604,NULL,'Salt Lake City, UT 84170',26991,222,NULL,52,37320,0);
INSERT INTO "django_geo_db_location" VALUES(64605,NULL,'Salt Lake City, UT 84171',26991,222,NULL,52,37321,0);
INSERT INTO "django_geo_db_location" VALUES(64606,NULL,'Salt Lake City, UT 84180',26991,222,NULL,52,37322,0);
INSERT INTO "django_geo_db_location" VALUES(64607,NULL,'Salt Lake City, UT 84184',26991,222,NULL,52,37323,0);
INSERT INTO "django_geo_db_location" VALUES(64608,NULL,'Salt Lake City, UT 84185',26991,222,NULL,52,37324,0);
INSERT INTO "django_geo_db_location" VALUES(64609,NULL,'Salt Lake City, UT 84189',26991,222,NULL,52,37325,0);
INSERT INTO "django_geo_db_location" VALUES(64610,NULL,'Salt Lake City, UT 84190',26991,222,NULL,52,37326,0);
INSERT INTO "django_geo_db_location" VALUES(64611,NULL,'Salt Lake City, UT 84199',26991,222,NULL,52,37327,0);
INSERT INTO "django_geo_db_location" VALUES(64612,NULL,'Ogden, UT',26992,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64613,NULL,'Ogden, UT 84201',26992,222,NULL,52,37328,0);
INSERT INTO "django_geo_db_location" VALUES(64614,NULL,'Ogden, UT 84244',26992,222,NULL,52,37329,0);
INSERT INTO "django_geo_db_location" VALUES(64615,NULL,'Green River, UT',26993,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64616,NULL,'Green River, UT 84252',26993,222,NULL,52,37330,0);
INSERT INTO "django_geo_db_location" VALUES(64617,NULL,'Bear River City, UT',26994,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64618,NULL,'Bear River City, UT 84301',26994,222,NULL,52,37331,0);
INSERT INTO "django_geo_db_location" VALUES(64619,NULL,'Brigham City, UT',26995,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64620,NULL,'Brigham City, UT 84302',26995,222,NULL,52,37332,0);
INSERT INTO "django_geo_db_location" VALUES(64621,NULL,'Cache Junction, UT',26996,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64622,NULL,'Cache Junction, UT 84304',26996,222,NULL,52,37333,0);
INSERT INTO "django_geo_db_location" VALUES(64623,NULL,'Clarkston, UT',26997,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64624,NULL,'Clarkston, UT 84305',26997,222,NULL,52,37334,0);
INSERT INTO "django_geo_db_location" VALUES(64625,NULL,'Collinston, UT',26998,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64626,NULL,'Collinston, UT 84306',26998,222,NULL,52,37335,0);
INSERT INTO "django_geo_db_location" VALUES(64627,NULL,'Corinne, UT',26999,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64628,NULL,'Corinne, UT 84307',26999,222,NULL,52,37336,0);
INSERT INTO "django_geo_db_location" VALUES(64629,NULL,'Cornish, UT',27000,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64630,NULL,'Cornish, UT 84308',27000,222,NULL,52,37337,0);
INSERT INTO "django_geo_db_location" VALUES(64631,NULL,'Deweyville, UT',27001,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64632,NULL,'Deweyville, UT 84309',27001,222,NULL,52,37338,0);
INSERT INTO "django_geo_db_location" VALUES(64633,NULL,'Eden, UT',27002,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64634,NULL,'Eden, UT 84310',27002,222,NULL,52,37339,0);
INSERT INTO "django_geo_db_location" VALUES(64635,NULL,'Fielding, UT',27003,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64636,NULL,'Fielding, UT 84311',27003,222,NULL,52,37340,0);
INSERT INTO "django_geo_db_location" VALUES(64637,NULL,'Garland, UT',27004,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64638,NULL,'Garland, UT 84312',27004,222,NULL,52,37341,0);
INSERT INTO "django_geo_db_location" VALUES(64639,NULL,'Grouse Creek, UT',27005,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64640,NULL,'Grouse Creek, UT 84313',27005,222,NULL,52,37342,0);
INSERT INTO "django_geo_db_location" VALUES(64641,NULL,'Honeyville, UT',27006,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64642,NULL,'Honeyville, UT 84314',27006,222,NULL,52,37343,0);
INSERT INTO "django_geo_db_location" VALUES(64643,NULL,'Hooper, UT',27007,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64644,NULL,'Hooper, UT 84315',27007,222,NULL,52,37344,0);
INSERT INTO "django_geo_db_location" VALUES(64645,NULL,'Howell, UT',27008,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64646,NULL,'Howell, UT 84316',27008,222,NULL,52,37345,0);
INSERT INTO "django_geo_db_location" VALUES(64647,NULL,'Huntsville, UT',27009,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64648,NULL,'Huntsville, UT 84317',27009,222,NULL,52,37346,0);
INSERT INTO "django_geo_db_location" VALUES(64649,NULL,'Hyde Park, UT',27010,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64650,NULL,'Hyde Park, UT 84318',27010,222,NULL,52,37347,0);
INSERT INTO "django_geo_db_location" VALUES(64651,NULL,'Hyrum, UT',27011,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64652,NULL,'Hyrum, UT 84319',27011,222,NULL,52,37348,0);
INSERT INTO "django_geo_db_location" VALUES(64653,NULL,'Lewiston, UT',27012,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64654,NULL,'Lewiston, UT 84320',27012,222,NULL,52,37349,0);
INSERT INTO "django_geo_db_location" VALUES(64655,NULL,'Logan, UT',27013,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64656,NULL,'Logan, UT 84321',27013,222,NULL,52,37350,0);
INSERT INTO "django_geo_db_location" VALUES(64657,NULL,'Logan, UT 84322',27013,222,NULL,52,37351,0);
INSERT INTO "django_geo_db_location" VALUES(64658,NULL,'Logan, UT 84323',27013,222,NULL,52,37352,0);
INSERT INTO "django_geo_db_location" VALUES(64659,NULL,'Mantua, UT',27014,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64660,NULL,'Mantua, UT 84324',27014,222,NULL,52,37353,0);
INSERT INTO "django_geo_db_location" VALUES(64661,NULL,'Mendon, UT',27015,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64662,NULL,'Mendon, UT 84325',27015,222,NULL,52,37354,0);
INSERT INTO "django_geo_db_location" VALUES(64663,NULL,'Millville, UT',27016,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64664,NULL,'Millville, UT 84326',27016,222,NULL,52,37355,0);
INSERT INTO "django_geo_db_location" VALUES(64665,NULL,'Newton, UT',27017,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64666,NULL,'Newton, UT 84327',27017,222,NULL,52,37356,0);
INSERT INTO "django_geo_db_location" VALUES(64667,NULL,'Paradise, UT',27018,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64668,NULL,'Paradise, UT 84328',27018,222,NULL,52,37357,0);
INSERT INTO "django_geo_db_location" VALUES(64669,NULL,'Park Valley, UT',27019,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64670,NULL,'Park Valley, UT 84329',27019,222,NULL,52,37358,0);
INSERT INTO "django_geo_db_location" VALUES(64671,NULL,'Plymouth, UT',27020,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64672,NULL,'Plymouth, UT 84330',27020,222,NULL,52,37359,0);
INSERT INTO "django_geo_db_location" VALUES(64673,NULL,'Portage, UT',27021,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64674,NULL,'Portage, UT 84331',27021,222,NULL,52,37360,0);
INSERT INTO "django_geo_db_location" VALUES(64675,NULL,'Providence, UT',27022,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64676,NULL,'Providence, UT 84332',27022,222,NULL,52,37361,0);
INSERT INTO "django_geo_db_location" VALUES(64677,NULL,'Richmond, UT',27023,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64678,NULL,'Richmond, UT 84333',27023,222,NULL,52,37362,0);
INSERT INTO "django_geo_db_location" VALUES(64679,NULL,'Riverside, UT',27024,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64680,NULL,'Riverside, UT 84334',27024,222,NULL,52,37363,0);
INSERT INTO "django_geo_db_location" VALUES(64681,NULL,'Smithfield, UT',27025,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64682,NULL,'Smithfield, UT 84335',27025,222,NULL,52,37364,0);
INSERT INTO "django_geo_db_location" VALUES(64683,NULL,'Snowville, UT',27026,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64684,NULL,'Snowville, UT 84336',27026,222,NULL,52,37365,0);
INSERT INTO "django_geo_db_location" VALUES(64685,NULL,'Tremonton, UT',27027,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64686,NULL,'Tremonton, UT 84337',27027,222,NULL,52,37366,0);
INSERT INTO "django_geo_db_location" VALUES(64687,NULL,'Trenton, UT',27028,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64688,NULL,'Trenton, UT 84338',27028,222,NULL,52,37367,0);
INSERT INTO "django_geo_db_location" VALUES(64689,NULL,'Wellsville, UT',27029,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64690,NULL,'Wellsville, UT 84339',27029,222,NULL,52,37368,0);
INSERT INTO "django_geo_db_location" VALUES(64691,NULL,'Willard, UT',27030,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64692,NULL,'Willard, UT 84340',27030,222,NULL,52,37369,0);
INSERT INTO "django_geo_db_location" VALUES(64693,NULL,'Logan, UT 84341',27013,222,NULL,52,37370,0);
INSERT INTO "django_geo_db_location" VALUES(64694,NULL,'South Willard, UT',27031,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64695,NULL,'South Willard, UT 84346',27031,222,NULL,52,37371,0);
INSERT INTO "django_geo_db_location" VALUES(64696,NULL,'Ogden, UT 84401',26992,222,NULL,52,37372,0);
INSERT INTO "django_geo_db_location" VALUES(64697,NULL,'Ogden, UT 84402',26992,222,NULL,52,37373,0);
INSERT INTO "django_geo_db_location" VALUES(64698,NULL,'Ogden, UT 84403',26992,222,NULL,52,37374,0);
INSERT INTO "django_geo_db_location" VALUES(64699,NULL,'Ogden, UT 84404',26992,222,NULL,52,37375,0);
INSERT INTO "django_geo_db_location" VALUES(64700,NULL,'Ogden, UT 84405',26992,222,NULL,52,37376,0);
INSERT INTO "django_geo_db_location" VALUES(64701,NULL,'Ogden, UT 84407',26992,222,NULL,52,37377,0);
INSERT INTO "django_geo_db_location" VALUES(64702,NULL,'Ogden, UT 84408',26992,222,NULL,52,37378,0);
INSERT INTO "django_geo_db_location" VALUES(64703,NULL,'Ogden, UT 84409',26992,222,NULL,52,37379,0);
INSERT INTO "django_geo_db_location" VALUES(64704,NULL,'Ogden, UT 84412',26992,222,NULL,52,37380,0);
INSERT INTO "django_geo_db_location" VALUES(64705,NULL,'Ogden, UT 84414',26992,222,NULL,52,37381,0);
INSERT INTO "django_geo_db_location" VALUES(64706,NULL,'Ogden, UT 84415',26992,222,NULL,52,37382,0);
INSERT INTO "django_geo_db_location" VALUES(64707,NULL,'Price, UT',27032,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64708,NULL,'Price, UT 84501',27032,222,NULL,52,37383,0);
INSERT INTO "django_geo_db_location" VALUES(64709,NULL,'Aneth, UT',27033,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64710,NULL,'Aneth, UT 84510',27033,222,NULL,52,37384,0);
INSERT INTO "django_geo_db_location" VALUES(64711,NULL,'Blanding, UT',27034,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64712,NULL,'Blanding, UT 84511',27034,222,NULL,52,37385,0);
INSERT INTO "django_geo_db_location" VALUES(64713,NULL,'Bluff, UT',27035,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64714,NULL,'Bluff, UT 84512',27035,222,NULL,52,37386,0);
INSERT INTO "django_geo_db_location" VALUES(64715,NULL,'Castle Dale, UT',27036,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64716,NULL,'Castle Dale, UT 84513',27036,222,NULL,52,37387,0);
INSERT INTO "django_geo_db_location" VALUES(64717,NULL,'Cisco, UT',27037,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64718,NULL,'Cisco, UT 84515',27037,222,NULL,52,37388,0);
INSERT INTO "django_geo_db_location" VALUES(64719,NULL,'Clawson, UT',27038,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64720,NULL,'Clawson, UT 84516',27038,222,NULL,52,37389,0);
INSERT INTO "django_geo_db_location" VALUES(64721,NULL,'Cleveland, UT',27039,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64722,NULL,'Cleveland, UT 84518',27039,222,NULL,52,37390,0);
INSERT INTO "django_geo_db_location" VALUES(64723,NULL,'East Carbon, UT',27040,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64724,NULL,'East Carbon, UT 84520',27040,222,NULL,52,37391,0);
INSERT INTO "django_geo_db_location" VALUES(64725,NULL,'Elmo, UT',27041,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64726,NULL,'Elmo, UT 84521',27041,222,NULL,52,37392,0);
INSERT INTO "django_geo_db_location" VALUES(64727,NULL,'Emery, UT',27042,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64728,NULL,'Emery, UT 84522',27042,222,NULL,52,37393,0);
INSERT INTO "django_geo_db_location" VALUES(64729,NULL,'Ferron, UT',27043,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64730,NULL,'Ferron, UT 84523',27043,222,NULL,52,37394,0);
INSERT INTO "django_geo_db_location" VALUES(64731,NULL,'Green River, UT 84525',26993,222,NULL,52,37395,0);
INSERT INTO "django_geo_db_location" VALUES(64732,NULL,'Helper, UT',27044,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64733,NULL,'Helper, UT 84526',27044,222,NULL,52,37396,0);
INSERT INTO "django_geo_db_location" VALUES(64734,NULL,'Hiawatha, UT',27045,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64735,NULL,'Hiawatha, UT 84527',27045,222,NULL,52,37397,0);
INSERT INTO "django_geo_db_location" VALUES(64736,NULL,'Huntington, UT',27046,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64737,NULL,'Huntington, UT 84528',27046,222,NULL,52,37398,0);
INSERT INTO "django_geo_db_location" VALUES(64738,NULL,'Kenilworth, UT',27047,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64739,NULL,'Kenilworth, UT 84529',27047,222,NULL,52,37399,0);
INSERT INTO "django_geo_db_location" VALUES(64740,NULL,'La Sal, UT',27048,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64741,NULL,'La Sal, UT 84530',27048,222,NULL,52,37400,0);
INSERT INTO "django_geo_db_location" VALUES(64742,NULL,'Mexican Hat, UT',27049,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64743,NULL,'Mexican Hat, UT 84531',27049,222,NULL,52,37401,0);
INSERT INTO "django_geo_db_location" VALUES(64744,NULL,'Moab, UT',27050,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64745,NULL,'Moab, UT 84532',27050,222,NULL,52,37402,0);
INSERT INTO "django_geo_db_location" VALUES(64746,NULL,'Lake Powell, UT',27051,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64747,NULL,'Lake Powell, UT 84533',27051,222,NULL,52,37403,0);
INSERT INTO "django_geo_db_location" VALUES(64748,NULL,'Montezuma Creek, UT',27052,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64749,NULL,'Montezuma Creek, UT 84534',27052,222,NULL,52,37404,0);
INSERT INTO "django_geo_db_location" VALUES(64750,NULL,'Monticello, UT',27053,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64751,NULL,'Monticello, UT 84535',27053,222,NULL,52,37405,0);
INSERT INTO "django_geo_db_location" VALUES(64752,NULL,'Monument Valley, AZ',27054,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64753,NULL,'Monument Valley, AZ 84536',27054,222,NULL,3,37406,0);
INSERT INTO "django_geo_db_location" VALUES(64754,NULL,'Orangeville, UT',27055,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64755,NULL,'Orangeville, UT 84537',27055,222,NULL,52,37407,0);
INSERT INTO "django_geo_db_location" VALUES(64756,NULL,'Sunnyside, UT',27056,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64757,NULL,'Sunnyside, UT 84539',27056,222,NULL,52,37408,0);
INSERT INTO "django_geo_db_location" VALUES(64758,NULL,'Thompson, UT',27057,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64759,NULL,'Thompson, UT 84540',27057,222,NULL,52,37409,0);
INSERT INTO "django_geo_db_location" VALUES(64760,NULL,'Wellington, UT',27058,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64761,NULL,'Wellington, UT 84542',27058,222,NULL,52,37410,0);
INSERT INTO "django_geo_db_location" VALUES(64762,NULL,'Provo, UT',27059,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64763,NULL,'Provo, UT 84601',27059,222,NULL,52,37411,0);
INSERT INTO "django_geo_db_location" VALUES(64764,NULL,'Provo, UT 84602',27059,222,NULL,52,37412,0);
INSERT INTO "django_geo_db_location" VALUES(64765,NULL,'Provo, UT 84603',27059,222,NULL,52,37413,0);
INSERT INTO "django_geo_db_location" VALUES(64766,NULL,'Provo, UT 84604',27059,222,NULL,52,37414,0);
INSERT INTO "django_geo_db_location" VALUES(64767,NULL,'Provo, UT 84605',27059,222,NULL,52,37415,0);
INSERT INTO "django_geo_db_location" VALUES(64768,NULL,'Provo, UT 84606',27059,222,NULL,52,37416,0);
INSERT INTO "django_geo_db_location" VALUES(64769,NULL,'Aurora, UT',27060,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64770,NULL,'Aurora, UT 84620',27060,222,NULL,52,37417,0);
INSERT INTO "django_geo_db_location" VALUES(64771,NULL,'Axtell, UT',27061,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64772,NULL,'Axtell, UT 84621',27061,222,NULL,52,37418,0);
INSERT INTO "django_geo_db_location" VALUES(64773,NULL,'Centerfield, UT',27062,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64774,NULL,'Centerfield, UT 84622',27062,222,NULL,52,37419,0);
INSERT INTO "django_geo_db_location" VALUES(64775,NULL,'Chester, UT',27063,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64776,NULL,'Chester, UT 84623',27063,222,NULL,52,37420,0);
INSERT INTO "django_geo_db_location" VALUES(64777,NULL,'Delta, UT',27064,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64778,NULL,'Delta, UT 84624',27064,222,NULL,52,37421,0);
INSERT INTO "django_geo_db_location" VALUES(64779,NULL,'Elberta, UT',27065,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64780,NULL,'Elberta, UT 84626',27065,222,NULL,52,37422,0);
INSERT INTO "django_geo_db_location" VALUES(64781,NULL,'Ephraim, UT',27066,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64782,NULL,'Ephraim, UT 84627',27066,222,NULL,52,37423,0);
INSERT INTO "django_geo_db_location" VALUES(64783,NULL,'Eureka, UT',27067,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64784,NULL,'Eureka, UT 84628',27067,222,NULL,52,37424,0);
INSERT INTO "django_geo_db_location" VALUES(64785,NULL,'Fairview, UT',27068,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64786,NULL,'Fairview, UT 84629',27068,222,NULL,52,37425,0);
INSERT INTO "django_geo_db_location" VALUES(64787,NULL,'Fayette, UT',27069,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64788,NULL,'Fayette, UT 84630',27069,222,NULL,52,37426,0);
INSERT INTO "django_geo_db_location" VALUES(64789,NULL,'Fillmore, UT',27070,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64790,NULL,'Fillmore, UT 84631',27070,222,NULL,52,37427,0);
INSERT INTO "django_geo_db_location" VALUES(64791,NULL,'Fountain Green, UT',27071,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64792,NULL,'Fountain Green, UT 84632',27071,222,NULL,52,37428,0);
INSERT INTO "django_geo_db_location" VALUES(64793,NULL,'Goshen, UT',27072,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64794,NULL,'Goshen, UT 84633',27072,222,NULL,52,37429,0);
INSERT INTO "django_geo_db_location" VALUES(64795,NULL,'Gunnison, UT',27073,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64796,NULL,'Gunnison, UT 84634',27073,222,NULL,52,37430,0);
INSERT INTO "django_geo_db_location" VALUES(64797,NULL,'Hinckley, UT',27074,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64798,NULL,'Hinckley, UT 84635',27074,222,NULL,52,37431,0);
INSERT INTO "django_geo_db_location" VALUES(64799,NULL,'Holden, UT',27075,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64800,NULL,'Holden, UT 84636',27075,222,NULL,52,37432,0);
INSERT INTO "django_geo_db_location" VALUES(64801,NULL,'Kanosh, UT',27076,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64802,NULL,'Kanosh, UT 84637',27076,222,NULL,52,37433,0);
INSERT INTO "django_geo_db_location" VALUES(64803,NULL,'Leamington, UT',27077,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64804,NULL,'Leamington, UT 84638',27077,222,NULL,52,37434,0);
INSERT INTO "django_geo_db_location" VALUES(64805,NULL,'Levan, UT',27078,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64806,NULL,'Levan, UT 84639',27078,222,NULL,52,37435,0);
INSERT INTO "django_geo_db_location" VALUES(64807,NULL,'Lynndyl, UT',27079,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64808,NULL,'Lynndyl, UT 84640',27079,222,NULL,52,37436,0);
INSERT INTO "django_geo_db_location" VALUES(64809,NULL,'Manti, UT',27080,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64810,NULL,'Manti, UT 84642',27080,222,NULL,52,37437,0);
INSERT INTO "django_geo_db_location" VALUES(64811,NULL,'Mayfield, UT',27081,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64812,NULL,'Mayfield, UT 84643',27081,222,NULL,52,37438,0);
INSERT INTO "django_geo_db_location" VALUES(64813,NULL,'Meadow, UT',27082,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64814,NULL,'Meadow, UT 84644',27082,222,NULL,52,37439,0);
INSERT INTO "django_geo_db_location" VALUES(64815,NULL,'Mona, UT',27083,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64816,NULL,'Mona, UT 84645',27083,222,NULL,52,37440,0);
INSERT INTO "django_geo_db_location" VALUES(64817,NULL,'Moroni, UT',27084,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64818,NULL,'Moroni, UT 84646',27084,222,NULL,52,37441,0);
INSERT INTO "django_geo_db_location" VALUES(64819,NULL,'Mount Pleasant, UT',27085,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64820,NULL,'Mount Pleasant, UT 84647',27085,222,NULL,52,37442,0);
INSERT INTO "django_geo_db_location" VALUES(64821,NULL,'Nephi, UT',27086,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64822,NULL,'Nephi, UT 84648',27086,222,NULL,52,37443,0);
INSERT INTO "django_geo_db_location" VALUES(64823,NULL,'Oak City, UT',27087,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64824,NULL,'Oak City, UT 84649',27087,222,NULL,52,37444,0);
INSERT INTO "django_geo_db_location" VALUES(64825,NULL,'Oasis, UT',27088,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64826,NULL,'Oasis, UT 84650',27088,222,NULL,52,37445,0);
INSERT INTO "django_geo_db_location" VALUES(64827,NULL,'Payson, UT',27089,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64828,NULL,'Payson, UT 84651',27089,222,NULL,52,37446,0);
INSERT INTO "django_geo_db_location" VALUES(64829,NULL,'Redmond, UT',27090,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64830,NULL,'Redmond, UT 84652',27090,222,NULL,52,37447,0);
INSERT INTO "django_geo_db_location" VALUES(64831,NULL,'Salem, UT',27091,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64832,NULL,'Salem, UT 84653',27091,222,NULL,52,37448,0);
INSERT INTO "django_geo_db_location" VALUES(64833,NULL,'Salina, UT',27092,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64834,NULL,'Salina, UT 84654',27092,222,NULL,52,37449,0);
INSERT INTO "django_geo_db_location" VALUES(64835,NULL,'Santaquin, UT',27093,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64836,NULL,'Santaquin, UT 84655',27093,222,NULL,52,37450,0);
INSERT INTO "django_geo_db_location" VALUES(64837,NULL,'Scipio, UT',27094,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64838,NULL,'Scipio, UT 84656',27094,222,NULL,52,37451,0);
INSERT INTO "django_geo_db_location" VALUES(64839,NULL,'Sigurd, UT',27095,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64840,NULL,'Sigurd, UT 84657',27095,222,NULL,52,37452,0);
INSERT INTO "django_geo_db_location" VALUES(64841,NULL,'Spanish Fork, UT',27096,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64842,NULL,'Spanish Fork, UT 84660',27096,222,NULL,52,37453,0);
INSERT INTO "django_geo_db_location" VALUES(64843,NULL,'Spring City, UT',27097,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64844,NULL,'Spring City, UT 84662',27097,222,NULL,52,37454,0);
INSERT INTO "django_geo_db_location" VALUES(64845,NULL,'Springville, UT',27098,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64846,NULL,'Springville, UT 84663',27098,222,NULL,52,37455,0);
INSERT INTO "django_geo_db_location" VALUES(64847,NULL,'Mapleton, UT',27099,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64848,NULL,'Mapleton, UT 84664',27099,222,NULL,52,37456,0);
INSERT INTO "django_geo_db_location" VALUES(64849,NULL,'Sterling, UT',27100,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64850,NULL,'Sterling, UT 84665',27100,222,NULL,52,37457,0);
INSERT INTO "django_geo_db_location" VALUES(64851,NULL,'Wales, UT',27101,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64852,NULL,'Wales, UT 84667',27101,222,NULL,52,37458,0);
INSERT INTO "django_geo_db_location" VALUES(64853,NULL,'Richfield, UT',27102,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64854,NULL,'Richfield, UT 84701',27102,222,NULL,52,37459,0);
INSERT INTO "django_geo_db_location" VALUES(64855,NULL,'Alton, UT',27103,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64856,NULL,'Alton, UT 84710',27103,222,NULL,52,37460,0);
INSERT INTO "django_geo_db_location" VALUES(64857,NULL,'Annabella, UT',27104,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64858,NULL,'Annabella, UT 84711',27104,222,NULL,52,37461,0);
INSERT INTO "django_geo_db_location" VALUES(64859,NULL,'Antimony, UT',27105,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64860,NULL,'Antimony, UT 84712',27105,222,NULL,52,37462,0);
INSERT INTO "django_geo_db_location" VALUES(64861,NULL,'Beaver, UT',27106,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64862,NULL,'Beaver, UT 84713',27106,222,NULL,52,37463,0);
INSERT INTO "django_geo_db_location" VALUES(64863,NULL,'Beryl, UT',27107,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64864,NULL,'Beryl, UT 84714',27107,222,NULL,52,37464,0);
INSERT INTO "django_geo_db_location" VALUES(64865,NULL,'Bicknell, UT',27108,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64866,NULL,'Bicknell, UT 84715',27108,222,NULL,52,37465,0);
INSERT INTO "django_geo_db_location" VALUES(64867,NULL,'Boulder, UT',27109,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64868,NULL,'Boulder, UT 84716',27109,222,NULL,52,37466,0);
INSERT INTO "django_geo_db_location" VALUES(64869,NULL,'Bryce Canyon, UT',27110,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64870,NULL,'Bryce Canyon, UT 84717',27110,222,NULL,52,37467,0);
INSERT INTO "django_geo_db_location" VALUES(64871,NULL,'Cannonville, UT',27111,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64872,NULL,'Cannonville, UT 84718',27111,222,NULL,52,37468,0);
INSERT INTO "django_geo_db_location" VALUES(64873,NULL,'Brian Head, UT',27112,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64874,NULL,'Brian Head, UT 84719',27112,222,NULL,52,37469,0);
INSERT INTO "django_geo_db_location" VALUES(64875,NULL,'Cedar City, UT',27113,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64876,NULL,'Cedar City, UT 84720',27113,222,NULL,52,37470,0);
INSERT INTO "django_geo_db_location" VALUES(64877,NULL,'Cedar City, UT 84721',27113,222,NULL,52,37471,0);
INSERT INTO "django_geo_db_location" VALUES(64878,NULL,'Central, UT',27114,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64879,NULL,'Central, UT 84722',27114,222,NULL,52,37472,0);
INSERT INTO "django_geo_db_location" VALUES(64880,NULL,'Circleville, UT',27115,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64881,NULL,'Circleville, UT 84723',27115,222,NULL,52,37473,0);
INSERT INTO "django_geo_db_location" VALUES(64882,NULL,'Elsinore, UT',27116,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64883,NULL,'Elsinore, UT 84724',27116,222,NULL,52,37474,0);
INSERT INTO "django_geo_db_location" VALUES(64884,NULL,'Enterprise, UT',27117,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64885,NULL,'Enterprise, UT 84725',27117,222,NULL,52,37475,0);
INSERT INTO "django_geo_db_location" VALUES(64886,NULL,'Escalante, UT',27118,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64887,NULL,'Escalante, UT 84726',27118,222,NULL,52,37476,0);
INSERT INTO "django_geo_db_location" VALUES(64888,NULL,'Garrison, UT',27119,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64889,NULL,'Garrison, UT 84728',27119,222,NULL,52,37477,0);
INSERT INTO "django_geo_db_location" VALUES(64890,NULL,'Glendale, UT',27120,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64891,NULL,'Glendale, UT 84729',27120,222,NULL,52,37478,0);
INSERT INTO "django_geo_db_location" VALUES(64892,NULL,'Glenwood, UT',27121,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64893,NULL,'Glenwood, UT 84730',27121,222,NULL,52,37479,0);
INSERT INTO "django_geo_db_location" VALUES(64894,NULL,'Greenville, UT',27122,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64895,NULL,'Greenville, UT 84731',27122,222,NULL,52,37480,0);
INSERT INTO "django_geo_db_location" VALUES(64896,NULL,'Greenwich, UT',27123,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64897,NULL,'Greenwich, UT 84732',27123,222,NULL,52,37481,0);
INSERT INTO "django_geo_db_location" VALUES(64898,NULL,'Gunlock, UT',27124,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64899,NULL,'Gunlock, UT 84733',27124,222,NULL,52,37482,0);
INSERT INTO "django_geo_db_location" VALUES(64900,NULL,'Hanksville, UT',27125,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64901,NULL,'Hanksville, UT 84734',27125,222,NULL,52,37483,0);
INSERT INTO "django_geo_db_location" VALUES(64902,NULL,'Hatch, UT',27126,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64903,NULL,'Hatch, UT 84735',27126,222,NULL,52,37484,0);
INSERT INTO "django_geo_db_location" VALUES(64904,NULL,'Henrieville, UT',27127,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64905,NULL,'Henrieville, UT 84736',27127,222,NULL,52,37485,0);
INSERT INTO "django_geo_db_location" VALUES(64906,NULL,'Hurricane, UT',27128,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64907,NULL,'Hurricane, UT 84737',27128,222,NULL,52,37486,0);
INSERT INTO "django_geo_db_location" VALUES(64908,NULL,'Ivins, UT',27129,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64909,NULL,'Ivins, UT 84738',27129,222,NULL,52,37487,0);
INSERT INTO "django_geo_db_location" VALUES(64910,NULL,'Joseph, UT',27130,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64911,NULL,'Joseph, UT 84739',27130,222,NULL,52,37488,0);
INSERT INTO "django_geo_db_location" VALUES(64912,NULL,'Junction, UT',27131,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64913,NULL,'Junction, UT 84740',27131,222,NULL,52,37489,0);
INSERT INTO "django_geo_db_location" VALUES(64914,NULL,'Kanab, UT',27132,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64915,NULL,'Kanab, UT 84741',27132,222,NULL,52,37490,0);
INSERT INTO "django_geo_db_location" VALUES(64916,NULL,'Kanarraville, UT',27133,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64917,NULL,'Kanarraville, UT 84742',27133,222,NULL,52,37491,0);
INSERT INTO "django_geo_db_location" VALUES(64918,NULL,'Kingston, UT',27134,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64919,NULL,'Kingston, UT 84743',27134,222,NULL,52,37492,0);
INSERT INTO "django_geo_db_location" VALUES(64920,NULL,'Koosharem, UT',27135,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64921,NULL,'Koosharem, UT 84744',27135,222,NULL,52,37493,0);
INSERT INTO "django_geo_db_location" VALUES(64922,NULL,'La Verkin, UT',27136,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64923,NULL,'La Verkin, UT 84745',27136,222,NULL,52,37494,0);
INSERT INTO "django_geo_db_location" VALUES(64924,NULL,'Leeds, UT',27137,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64925,NULL,'Leeds, UT 84746',27137,222,NULL,52,37495,0);
INSERT INTO "django_geo_db_location" VALUES(64926,NULL,'Loa, UT',27138,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64927,NULL,'Loa, UT 84747',27138,222,NULL,52,37496,0);
INSERT INTO "django_geo_db_location" VALUES(64928,NULL,'Lyman, UT',27139,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64929,NULL,'Lyman, UT 84749',27139,222,NULL,52,37497,0);
INSERT INTO "django_geo_db_location" VALUES(64930,NULL,'Marysvale, UT',27140,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64931,NULL,'Marysvale, UT 84750',27140,222,NULL,52,37498,0);
INSERT INTO "django_geo_db_location" VALUES(64932,NULL,'Milford, UT',27141,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64933,NULL,'Milford, UT 84751',27141,222,NULL,52,37499,0);
INSERT INTO "django_geo_db_location" VALUES(64934,NULL,'Minersville, UT',27142,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64935,NULL,'Minersville, UT 84752',27142,222,NULL,52,37500,0);
INSERT INTO "django_geo_db_location" VALUES(64936,NULL,'Modena, UT',27143,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64937,NULL,'Modena, UT 84753',27143,222,NULL,52,37501,0);
INSERT INTO "django_geo_db_location" VALUES(64938,NULL,'Monroe, UT',27144,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64939,NULL,'Monroe, UT 84754',27144,222,NULL,52,37502,0);
INSERT INTO "django_geo_db_location" VALUES(64940,NULL,'Mount Carmel, UT',27145,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64941,NULL,'Mount Carmel, UT 84755',27145,222,NULL,52,37503,0);
INSERT INTO "django_geo_db_location" VALUES(64942,NULL,'Newcastle, UT',27146,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64943,NULL,'Newcastle, UT 84756',27146,222,NULL,52,37504,0);
INSERT INTO "django_geo_db_location" VALUES(64944,NULL,'New Harmony, UT',27147,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64945,NULL,'New Harmony, UT 84757',27147,222,NULL,52,37505,0);
INSERT INTO "django_geo_db_location" VALUES(64946,NULL,'Orderville, UT',27148,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64947,NULL,'Orderville, UT 84758',27148,222,NULL,52,37506,0);
INSERT INTO "django_geo_db_location" VALUES(64948,NULL,'Panguitch, UT',27149,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64949,NULL,'Panguitch, UT 84759',27149,222,NULL,52,37507,0);
INSERT INTO "django_geo_db_location" VALUES(64950,NULL,'Paragonah, UT',27150,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64951,NULL,'Paragonah, UT 84760',27150,222,NULL,52,37508,0);
INSERT INTO "django_geo_db_location" VALUES(64952,NULL,'Parowan, UT',27151,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64953,NULL,'Parowan, UT 84761',27151,222,NULL,52,37509,0);
INSERT INTO "django_geo_db_location" VALUES(64954,NULL,'Duck Creek Village, UT',27152,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64955,NULL,'Duck Creek Village, UT 84762',27152,222,NULL,52,37510,0);
INSERT INTO "django_geo_db_location" VALUES(64956,NULL,'Rockville, UT',27153,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64957,NULL,'Rockville, UT 84763',27153,222,NULL,52,37511,0);
INSERT INTO "django_geo_db_location" VALUES(64958,NULL,'Bryce, UT',27154,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64959,NULL,'Bryce, UT 84764',27154,222,NULL,52,37512,0);
INSERT INTO "django_geo_db_location" VALUES(64960,NULL,'Santa Clara, UT',27155,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64961,NULL,'Santa Clara, UT 84765',27155,222,NULL,52,37513,0);
INSERT INTO "django_geo_db_location" VALUES(64962,NULL,'Sevier, UT',27156,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64963,NULL,'Sevier, UT 84766',27156,222,NULL,52,37514,0);
INSERT INTO "django_geo_db_location" VALUES(64964,NULL,'Springdale, UT',27157,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64965,NULL,'Springdale, UT 84767',27157,222,NULL,52,37515,0);
INSERT INTO "django_geo_db_location" VALUES(64966,NULL,'Saint George, UT',27158,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64967,NULL,'Saint George, UT 84770',27158,222,NULL,52,37516,0);
INSERT INTO "django_geo_db_location" VALUES(64968,NULL,'Saint George, UT 84771',27158,222,NULL,52,37517,0);
INSERT INTO "django_geo_db_location" VALUES(64969,NULL,'Summit, UT',27159,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64970,NULL,'Summit, UT 84772',27159,222,NULL,52,37518,0);
INSERT INTO "django_geo_db_location" VALUES(64971,NULL,'Teasdale, UT',27160,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64972,NULL,'Teasdale, UT 84773',27160,222,NULL,52,37519,0);
INSERT INTO "django_geo_db_location" VALUES(64973,NULL,'Toquerville, UT',27161,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64974,NULL,'Toquerville, UT 84774',27161,222,NULL,52,37520,0);
INSERT INTO "django_geo_db_location" VALUES(64975,NULL,'Torrey, UT',27162,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64976,NULL,'Torrey, UT 84775',27162,222,NULL,52,37521,0);
INSERT INTO "django_geo_db_location" VALUES(64977,NULL,'Tropic, UT',27163,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64978,NULL,'Tropic, UT 84776',27163,222,NULL,52,37522,0);
INSERT INTO "django_geo_db_location" VALUES(64979,NULL,'Virgin, UT',27164,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64980,NULL,'Virgin, UT 84779',27164,222,NULL,52,37523,0);
INSERT INTO "django_geo_db_location" VALUES(64981,NULL,'Washington, UT',27165,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64982,NULL,'Washington, UT 84780',27165,222,NULL,52,37524,0);
INSERT INTO "django_geo_db_location" VALUES(64983,NULL,'Pine Valley, UT',27166,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64984,NULL,'Pine Valley, UT 84781',27166,222,NULL,52,37525,0);
INSERT INTO "django_geo_db_location" VALUES(64985,NULL,'Veyo, UT',27167,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64986,NULL,'Veyo, UT 84782',27167,222,NULL,52,37526,0);
INSERT INTO "django_geo_db_location" VALUES(64987,NULL,'Dammeron Valley, UT',27168,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64988,NULL,'Dammeron Valley, UT 84783',27168,222,NULL,52,37527,0);
INSERT INTO "django_geo_db_location" VALUES(64989,NULL,'Hildale, UT',27169,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64990,NULL,'Hildale, UT 84784',27169,222,NULL,52,37528,0);
INSERT INTO "django_geo_db_location" VALUES(64991,NULL,'Saint George, UT 84790',27158,222,NULL,52,37529,0);
INSERT INTO "django_geo_db_location" VALUES(64992,NULL,'Saint George, UT 84791',27158,222,NULL,52,37530,0);
INSERT INTO "django_geo_db_location" VALUES(64993,NULL,'Logan, UT 84821',27013,222,NULL,52,37531,0);
INSERT INTO "django_geo_db_location" VALUES(64994,NULL,'North Salt Lake, UT 84910',26962,222,NULL,52,37532,0);
INSERT INTO "django_geo_db_location" VALUES(64995,NULL,'Clinton, UT',27170,222,NULL,52,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64996,NULL,'Clinton, UT 84915',27170,222,NULL,52,37533,0);
INSERT INTO "django_geo_db_location" VALUES(64997,NULL,'Lyman, UT 84947',27139,222,NULL,52,37534,0);
INSERT INTO "django_geo_db_location" VALUES(64998,NULL,'Phoenix, AZ',27171,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(64999,NULL,'Phoenix, AZ 85001',27171,222,NULL,3,37535,0);
INSERT INTO "django_geo_db_location" VALUES(65000,NULL,'Phoenix, AZ 85002',27171,222,NULL,3,37536,0);
INSERT INTO "django_geo_db_location" VALUES(65001,NULL,'Phoenix, AZ 85003',27171,222,NULL,3,37537,0);
INSERT INTO "django_geo_db_location" VALUES(65002,NULL,'Phoenix, AZ 85004',27171,222,NULL,3,37538,0);
INSERT INTO "django_geo_db_location" VALUES(65003,NULL,'Phoenix, AZ 85005',27171,222,NULL,3,37539,0);
INSERT INTO "django_geo_db_location" VALUES(65004,NULL,'Phoenix, AZ 85006',27171,222,NULL,3,37540,0);
INSERT INTO "django_geo_db_location" VALUES(65005,NULL,'Phoenix, AZ 85007',27171,222,NULL,3,37541,0);
INSERT INTO "django_geo_db_location" VALUES(65006,NULL,'Phoenix, AZ 85008',27171,222,NULL,3,37542,0);
INSERT INTO "django_geo_db_location" VALUES(65007,NULL,'Phoenix, AZ 85009',27171,222,NULL,3,37543,0);
INSERT INTO "django_geo_db_location" VALUES(65008,NULL,'Phoenix, AZ 85010',27171,222,NULL,3,37544,0);
INSERT INTO "django_geo_db_location" VALUES(65009,NULL,'Phoenix, AZ 85011',27171,222,NULL,3,37545,0);
INSERT INTO "django_geo_db_location" VALUES(65010,NULL,'Phoenix, AZ 85012',27171,222,NULL,3,37546,0);
INSERT INTO "django_geo_db_location" VALUES(65011,NULL,'Phoenix, AZ 85013',27171,222,NULL,3,37547,0);
INSERT INTO "django_geo_db_location" VALUES(65012,NULL,'Phoenix, AZ 85014',27171,222,NULL,3,37548,0);
INSERT INTO "django_geo_db_location" VALUES(65013,NULL,'Phoenix, AZ 85015',27171,222,NULL,3,37549,0);
INSERT INTO "django_geo_db_location" VALUES(65014,NULL,'Phoenix, AZ 85016',27171,222,NULL,3,37550,0);
INSERT INTO "django_geo_db_location" VALUES(65015,NULL,'Phoenix, AZ 85017',27171,222,NULL,3,37551,0);
INSERT INTO "django_geo_db_location" VALUES(65016,NULL,'Phoenix, AZ 85018',27171,222,NULL,3,37552,0);
INSERT INTO "django_geo_db_location" VALUES(65017,NULL,'Phoenix, AZ 85019',27171,222,NULL,3,37553,0);
INSERT INTO "django_geo_db_location" VALUES(65018,NULL,'Phoenix, AZ 85020',27171,222,NULL,3,37554,0);
INSERT INTO "django_geo_db_location" VALUES(65019,NULL,'Phoenix, AZ 85021',27171,222,NULL,3,37555,0);
INSERT INTO "django_geo_db_location" VALUES(65020,NULL,'Phoenix, AZ 85022',27171,222,NULL,3,37556,0);
INSERT INTO "django_geo_db_location" VALUES(65021,NULL,'Phoenix, AZ 85023',27171,222,NULL,3,37557,0);
INSERT INTO "django_geo_db_location" VALUES(65022,NULL,'Phoenix, AZ 85024',27171,222,NULL,3,37558,0);
INSERT INTO "django_geo_db_location" VALUES(65023,NULL,'Phoenix, AZ 85025',27171,222,NULL,3,37559,0);
INSERT INTO "django_geo_db_location" VALUES(65024,NULL,'Phoenix, AZ 85026',27171,222,NULL,3,37560,0);
INSERT INTO "django_geo_db_location" VALUES(65025,NULL,'Phoenix, AZ 85027',27171,222,NULL,3,37561,0);
INSERT INTO "django_geo_db_location" VALUES(65026,NULL,'Phoenix, AZ 85028',27171,222,NULL,3,37562,0);
INSERT INTO "django_geo_db_location" VALUES(65027,NULL,'Phoenix, AZ 85029',27171,222,NULL,3,37563,0);
INSERT INTO "django_geo_db_location" VALUES(65028,NULL,'Phoenix, AZ 85030',27171,222,NULL,3,37564,0);
INSERT INTO "django_geo_db_location" VALUES(65029,NULL,'Phoenix, AZ 85031',27171,222,NULL,3,37565,0);
INSERT INTO "django_geo_db_location" VALUES(65030,NULL,'Phoenix, AZ 85032',27171,222,NULL,3,37566,0);
INSERT INTO "django_geo_db_location" VALUES(65031,NULL,'Phoenix, AZ 85033',27171,222,NULL,3,37567,0);
INSERT INTO "django_geo_db_location" VALUES(65032,NULL,'Phoenix, AZ 85034',27171,222,NULL,3,37568,0);
INSERT INTO "django_geo_db_location" VALUES(65033,NULL,'Phoenix, AZ 85035',27171,222,NULL,3,37569,0);
INSERT INTO "django_geo_db_location" VALUES(65034,NULL,'Phoenix, AZ 85036',27171,222,NULL,3,37570,0);
INSERT INTO "django_geo_db_location" VALUES(65035,NULL,'Phoenix, AZ 85037',27171,222,NULL,3,37571,0);
INSERT INTO "django_geo_db_location" VALUES(65036,NULL,'Phoenix, AZ 85038',27171,222,NULL,3,37572,0);
INSERT INTO "django_geo_db_location" VALUES(65037,NULL,'Phoenix, AZ 85039',27171,222,NULL,3,37573,0);
INSERT INTO "django_geo_db_location" VALUES(65038,NULL,'Phoenix, AZ 85040',27171,222,NULL,3,37574,0);
INSERT INTO "django_geo_db_location" VALUES(65039,NULL,'Phoenix, AZ 85041',27171,222,NULL,3,37575,0);
INSERT INTO "django_geo_db_location" VALUES(65040,NULL,'Phoenix, AZ 85042',27171,222,NULL,3,37576,0);
INSERT INTO "django_geo_db_location" VALUES(65041,NULL,'Phoenix, AZ 85043',27171,222,NULL,3,37577,0);
INSERT INTO "django_geo_db_location" VALUES(65042,NULL,'Phoenix, AZ 85044',27171,222,NULL,3,37578,0);
INSERT INTO "django_geo_db_location" VALUES(65043,NULL,'Phoenix, AZ 85045',27171,222,NULL,3,37579,0);
INSERT INTO "django_geo_db_location" VALUES(65044,NULL,'Phoenix, AZ 85046',27171,222,NULL,3,37580,0);
INSERT INTO "django_geo_db_location" VALUES(65045,NULL,'Phoenix, AZ 85048',27171,222,NULL,3,37581,0);
INSERT INTO "django_geo_db_location" VALUES(65046,NULL,'Phoenix, AZ 85050',27171,222,NULL,3,37582,0);
INSERT INTO "django_geo_db_location" VALUES(65047,NULL,'Phoenix, AZ 85051',27171,222,NULL,3,37583,0);
INSERT INTO "django_geo_db_location" VALUES(65048,NULL,'Phoenix, AZ 85053',27171,222,NULL,3,37584,0);
INSERT INTO "django_geo_db_location" VALUES(65049,NULL,'Phoenix, AZ 85054',27171,222,NULL,3,37585,0);
INSERT INTO "django_geo_db_location" VALUES(65050,NULL,'Phoenix, AZ 85055',27171,222,NULL,3,37586,0);
INSERT INTO "django_geo_db_location" VALUES(65051,NULL,'Phoenix, AZ 85060',27171,222,NULL,3,37587,0);
INSERT INTO "django_geo_db_location" VALUES(65052,NULL,'Phoenix, AZ 85061',27171,222,NULL,3,37588,0);
INSERT INTO "django_geo_db_location" VALUES(65053,NULL,'Phoenix, AZ 85062',27171,222,NULL,3,37589,0);
INSERT INTO "django_geo_db_location" VALUES(65054,NULL,'Phoenix, AZ 85063',27171,222,NULL,3,37590,0);
INSERT INTO "django_geo_db_location" VALUES(65055,NULL,'Phoenix, AZ 85064',27171,222,NULL,3,37591,0);
INSERT INTO "django_geo_db_location" VALUES(65056,NULL,'Phoenix, AZ 85065',27171,222,NULL,3,37592,0);
INSERT INTO "django_geo_db_location" VALUES(65057,NULL,'Phoenix, AZ 85066',27171,222,NULL,3,37593,0);
INSERT INTO "django_geo_db_location" VALUES(65058,NULL,'Phoenix, AZ 85067',27171,222,NULL,3,37594,0);
INSERT INTO "django_geo_db_location" VALUES(65059,NULL,'Phoenix, AZ 85068',27171,222,NULL,3,37595,0);
INSERT INTO "django_geo_db_location" VALUES(65060,NULL,'Phoenix, AZ 85069',27171,222,NULL,3,37596,0);
INSERT INTO "django_geo_db_location" VALUES(65061,NULL,'Phoenix, AZ 85070',27171,222,NULL,3,37597,0);
INSERT INTO "django_geo_db_location" VALUES(65062,NULL,'Phoenix, AZ 85071',27171,222,NULL,3,37598,0);
INSERT INTO "django_geo_db_location" VALUES(65063,NULL,'Phoenix, AZ 85072',27171,222,NULL,3,37599,0);
INSERT INTO "django_geo_db_location" VALUES(65064,NULL,'Phoenix, AZ 85073',27171,222,NULL,3,37600,0);
INSERT INTO "django_geo_db_location" VALUES(65065,NULL,'Phoenix, AZ 85074',27171,222,NULL,3,37601,0);
INSERT INTO "django_geo_db_location" VALUES(65066,NULL,'Phoenix, AZ 85075',27171,222,NULL,3,37602,0);
INSERT INTO "django_geo_db_location" VALUES(65067,NULL,'Phoenix, AZ 85076',27171,222,NULL,3,37603,0);
INSERT INTO "django_geo_db_location" VALUES(65068,NULL,'Phoenix, AZ 85077',27171,222,NULL,3,37604,0);
INSERT INTO "django_geo_db_location" VALUES(65069,NULL,'Phoenix, AZ 85078',27171,222,NULL,3,37605,0);
INSERT INTO "django_geo_db_location" VALUES(65070,NULL,'Phoenix, AZ 85079',27171,222,NULL,3,37606,0);
INSERT INTO "django_geo_db_location" VALUES(65071,NULL,'Phoenix, AZ 85080',27171,222,NULL,3,37607,0);
INSERT INTO "django_geo_db_location" VALUES(65072,NULL,'Phoenix, AZ 85082',27171,222,NULL,3,37608,0);
INSERT INTO "django_geo_db_location" VALUES(65073,NULL,'Phoenix, AZ 85085',27171,222,NULL,3,37609,0);
INSERT INTO "django_geo_db_location" VALUES(65074,NULL,'Anthem, AZ',27172,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65075,NULL,'Anthem, AZ 85086',27172,222,NULL,3,37610,0);
INSERT INTO "django_geo_db_location" VALUES(65076,NULL,'New River, AZ',27173,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65077,NULL,'New River, AZ 85087',27173,222,NULL,3,37611,0);
INSERT INTO "django_geo_db_location" VALUES(65078,NULL,'New River, AZ 85089',27173,222,NULL,3,37612,0);
INSERT INTO "django_geo_db_location" VALUES(65079,NULL,'Phoenix, AZ 85097',27171,222,NULL,3,37613,0);
INSERT INTO "django_geo_db_location" VALUES(65080,NULL,'Phoenix, AZ 85098',27171,222,NULL,3,37614,0);
INSERT INTO "django_geo_db_location" VALUES(65081,NULL,'Phoenix, AZ 85099',27171,222,NULL,3,37615,0);
INSERT INTO "django_geo_db_location" VALUES(65082,NULL,'Mesa, AZ',27174,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65083,NULL,'Mesa, AZ 85123',27174,222,NULL,3,37616,0);
INSERT INTO "django_geo_db_location" VALUES(65084,NULL,'Mesa, AZ 85200',27174,222,NULL,3,37617,0);
INSERT INTO "django_geo_db_location" VALUES(65085,NULL,'Mesa, AZ 85201',27174,222,NULL,3,37618,0);
INSERT INTO "django_geo_db_location" VALUES(65086,NULL,'Mesa, AZ 85202',27174,222,NULL,3,37619,0);
INSERT INTO "django_geo_db_location" VALUES(65087,NULL,'Mesa, AZ 85203',27174,222,NULL,3,37620,0);
INSERT INTO "django_geo_db_location" VALUES(65088,NULL,'Mesa, AZ 85204',27174,222,NULL,3,37621,0);
INSERT INTO "django_geo_db_location" VALUES(65089,NULL,'Mesa, AZ 85205',27174,222,NULL,3,37622,0);
INSERT INTO "django_geo_db_location" VALUES(65090,NULL,'Mesa, AZ 85206',27174,222,NULL,3,37623,0);
INSERT INTO "django_geo_db_location" VALUES(65091,NULL,'Mesa, AZ 85207',27174,222,NULL,3,37624,0);
INSERT INTO "django_geo_db_location" VALUES(65092,NULL,'Mesa, AZ 85208',27174,222,NULL,3,37625,0);
INSERT INTO "django_geo_db_location" VALUES(65093,NULL,'Mesa, AZ 85210',27174,222,NULL,3,37626,0);
INSERT INTO "django_geo_db_location" VALUES(65094,NULL,'Mesa, AZ 85211',27174,222,NULL,3,37627,0);
INSERT INTO "django_geo_db_location" VALUES(65095,NULL,'Mesa, AZ 85212',27174,222,NULL,3,37628,0);
INSERT INTO "django_geo_db_location" VALUES(65096,NULL,'Mesa, AZ 85213',27174,222,NULL,3,37629,0);
INSERT INTO "django_geo_db_location" VALUES(65097,NULL,'Mesa, AZ 85214',27174,222,NULL,3,37630,0);
INSERT INTO "django_geo_db_location" VALUES(65098,NULL,'Mesa, AZ 85215',27174,222,NULL,3,37631,0);
INSERT INTO "django_geo_db_location" VALUES(65099,NULL,'Mesa, AZ 85216',27174,222,NULL,3,37632,0);
INSERT INTO "django_geo_db_location" VALUES(65100,NULL,'Apache Junction, AZ',27175,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65101,NULL,'Apache Junction, AZ 85217',27175,222,NULL,3,37633,0);
INSERT INTO "django_geo_db_location" VALUES(65102,NULL,'Gold Camp, AZ',27176,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65103,NULL,'Gold Camp, AZ 85218',27176,222,NULL,3,37634,0);
INSERT INTO "django_geo_db_location" VALUES(65104,NULL,'Apache Junction, AZ 85219',27175,222,NULL,3,37635,0);
INSERT INTO "django_geo_db_location" VALUES(65105,NULL,'Apache Junction, AZ 85220',27175,222,NULL,3,37636,0);
INSERT INTO "django_geo_db_location" VALUES(65106,NULL,'Bapchule, AZ',27177,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65107,NULL,'Bapchule, AZ 85221',27177,222,NULL,3,37637,0);
INSERT INTO "django_geo_db_location" VALUES(65108,NULL,'Casa Grande, AZ',27178,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65109,NULL,'Casa Grande, AZ 85222',27178,222,NULL,3,37638,0);
INSERT INTO "django_geo_db_location" VALUES(65110,NULL,'Arizona City, AZ',27179,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65111,NULL,'Arizona City, AZ 85223',27179,222,NULL,3,37639,0);
INSERT INTO "django_geo_db_location" VALUES(65112,NULL,'Chandler, AZ',27180,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65113,NULL,'Chandler, AZ 85224',27180,222,NULL,3,37640,0);
INSERT INTO "django_geo_db_location" VALUES(65114,NULL,'Chandler, AZ 85225',27180,222,NULL,3,37641,0);
INSERT INTO "django_geo_db_location" VALUES(65115,NULL,'Chandler, AZ 85226',27180,222,NULL,3,37642,0);
INSERT INTO "django_geo_db_location" VALUES(65116,NULL,'Chandler Heights, AZ',27181,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65117,NULL,'Chandler Heights, AZ 85227',27181,222,NULL,3,37643,0);
INSERT INTO "django_geo_db_location" VALUES(65118,NULL,'Coolidge, AZ',27182,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65119,NULL,'Coolidge, AZ 85228',27182,222,NULL,3,37644,0);
INSERT INTO "django_geo_db_location" VALUES(65120,NULL,'Casa Grande, AZ 85230',27178,222,NULL,3,37645,0);
INSERT INTO "django_geo_db_location" VALUES(65121,NULL,'Eloy, AZ',27183,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65122,NULL,'Eloy, AZ 85231',27183,222,NULL,3,37646,0);
INSERT INTO "django_geo_db_location" VALUES(65123,NULL,'Florence, AZ',27184,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65124,NULL,'Florence, AZ 85232',27184,222,NULL,3,37647,0);
INSERT INTO "django_geo_db_location" VALUES(65125,NULL,'Gilbert, AZ',27185,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65126,NULL,'Gilbert, AZ 85233',27185,222,NULL,3,37648,0);
INSERT INTO "django_geo_db_location" VALUES(65127,NULL,'Gilbert, AZ 85234',27185,222,NULL,3,37649,0);
INSERT INTO "django_geo_db_location" VALUES(65128,NULL,'Hayden, AZ',27186,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65129,NULL,'Hayden, AZ 85235',27186,222,NULL,3,37650,0);
INSERT INTO "django_geo_db_location" VALUES(65130,NULL,'Higley, AZ',27187,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65131,NULL,'Higley, AZ 85236',27187,222,NULL,3,37651,0);
INSERT INTO "django_geo_db_location" VALUES(65132,NULL,'Kearny, AZ',27188,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65133,NULL,'Kearny, AZ 85237',27188,222,NULL,3,37652,0);
INSERT INTO "django_geo_db_location" VALUES(65134,NULL,'Maricopa, AZ',27189,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65135,NULL,'Maricopa, AZ 85239',27189,222,NULL,3,37653,0);
INSERT INTO "django_geo_db_location" VALUES(65136,NULL,'Chandler, AZ 85240',27180,222,NULL,3,37654,0);
INSERT INTO "django_geo_db_location" VALUES(65137,NULL,'Picacho, AZ',27190,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65138,NULL,'Picacho, AZ 85241',27190,222,NULL,3,37655,0);
INSERT INTO "django_geo_db_location" VALUES(65139,NULL,'Queen Creek, AZ',27191,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65140,NULL,'Queen Creek, AZ 85242',27191,222,NULL,3,37656,0);
INSERT INTO "django_geo_db_location" VALUES(65141,NULL,'Chandler, AZ 85244',27180,222,NULL,3,37657,0);
INSERT INTO "django_geo_db_location" VALUES(65142,NULL,'Red Rock, AZ',27192,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65143,NULL,'Red Rock, AZ 85245',27192,222,NULL,3,37658,0);
INSERT INTO "django_geo_db_location" VALUES(65144,NULL,'Chandler, AZ 85246',27180,222,NULL,3,37659,0);
INSERT INTO "django_geo_db_location" VALUES(65145,NULL,'Sacaton, AZ',27193,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65146,NULL,'Sacaton, AZ 85247',27193,222,NULL,3,37660,0);
INSERT INTO "django_geo_db_location" VALUES(65147,NULL,'Chandler, AZ 85248',27180,222,NULL,3,37661,0);
INSERT INTO "django_geo_db_location" VALUES(65148,NULL,'Chandler, AZ 85249',27180,222,NULL,3,37662,0);
INSERT INTO "django_geo_db_location" VALUES(65149,NULL,'Scottsdale, AZ',27194,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65150,NULL,'Scottsdale, AZ 85250',27194,222,NULL,3,37663,0);
INSERT INTO "django_geo_db_location" VALUES(65151,NULL,'Scottsdale, AZ 85251',27194,222,NULL,3,37664,0);
INSERT INTO "django_geo_db_location" VALUES(65152,NULL,'Scottsdale, AZ 85252',27194,222,NULL,3,37665,0);
INSERT INTO "django_geo_db_location" VALUES(65153,NULL,'Paradise Valley, AZ',27195,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65154,NULL,'Paradise Valley, AZ 85253',27195,222,NULL,3,37666,0);
INSERT INTO "django_geo_db_location" VALUES(65155,NULL,'Scottsdale, AZ 85254',27194,222,NULL,3,37667,0);
INSERT INTO "django_geo_db_location" VALUES(65156,NULL,'Scottsdale, AZ 85255',27194,222,NULL,3,37668,0);
INSERT INTO "django_geo_db_location" VALUES(65157,NULL,'Scottsdale, AZ 85256',27194,222,NULL,3,37669,0);
INSERT INTO "django_geo_db_location" VALUES(65158,NULL,'Scottsdale, AZ 85257',27194,222,NULL,3,37670,0);
INSERT INTO "django_geo_db_location" VALUES(65159,NULL,'Scottsdale, AZ 85258',27194,222,NULL,3,37671,0);
INSERT INTO "django_geo_db_location" VALUES(65160,NULL,'Scottsdale, AZ 85259',27194,222,NULL,3,37672,0);
INSERT INTO "django_geo_db_location" VALUES(65161,NULL,'Scottsdale, AZ 85260',27194,222,NULL,3,37673,0);
INSERT INTO "django_geo_db_location" VALUES(65162,NULL,'Scottsdale, AZ 85261',27194,222,NULL,3,37674,0);
INSERT INTO "django_geo_db_location" VALUES(65163,NULL,'Scottsdale, AZ 85262',27194,222,NULL,3,37675,0);
INSERT INTO "django_geo_db_location" VALUES(65164,NULL,'Rio Verde, AZ',27196,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65165,NULL,'Rio Verde, AZ 85263',27196,222,NULL,3,37676,0);
INSERT INTO "django_geo_db_location" VALUES(65166,NULL,'Fort Mcdowell, AZ',27197,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65167,NULL,'Fort Mcdowell, AZ 85264',27197,222,NULL,3,37677,0);
INSERT INTO "django_geo_db_location" VALUES(65168,NULL,'Scottsdale, AZ 85266',27194,222,NULL,3,37678,0);
INSERT INTO "django_geo_db_location" VALUES(65169,NULL,'Scottsdale, AZ 85267',27194,222,NULL,3,37679,0);
INSERT INTO "django_geo_db_location" VALUES(65170,NULL,'Fountain Hills, AZ',27198,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65171,NULL,'Fountain Hills, AZ 85268',27198,222,NULL,3,37680,0);
INSERT INTO "django_geo_db_location" VALUES(65172,NULL,'Fountain Hills, AZ 85269',27198,222,NULL,3,37681,0);
INSERT INTO "django_geo_db_location" VALUES(65173,NULL,'Scottsdale, AZ 85271',27194,222,NULL,3,37682,0);
INSERT INTO "django_geo_db_location" VALUES(65174,NULL,'Stanfield, AZ',27199,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65175,NULL,'Stanfield, AZ 85272',27199,222,NULL,3,37683,0);
INSERT INTO "django_geo_db_location" VALUES(65176,NULL,'Superior, AZ',27200,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65177,NULL,'Superior, AZ 85273',27200,222,NULL,3,37684,0);
INSERT INTO "django_geo_db_location" VALUES(65178,NULL,'Mesa, AZ 85274',27174,222,NULL,3,37685,0);
INSERT INTO "django_geo_db_location" VALUES(65179,NULL,'Mesa, AZ 85275',27174,222,NULL,3,37686,0);
INSERT INTO "django_geo_db_location" VALUES(65180,NULL,'Mesa, AZ 85277',27174,222,NULL,3,37687,0);
INSERT INTO "django_geo_db_location" VALUES(65181,NULL,'Apache Junction, AZ 85278',27175,222,NULL,3,37688,0);
INSERT INTO "django_geo_db_location" VALUES(65182,NULL,'Florence, AZ 85279',27184,222,NULL,3,37689,0);
INSERT INTO "django_geo_db_location" VALUES(65183,NULL,'Tempe, AZ',27201,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65184,NULL,'Tempe, AZ 85280',27201,222,NULL,3,37690,0);
INSERT INTO "django_geo_db_location" VALUES(65185,NULL,'Tempe, AZ 85281',27201,222,NULL,3,37691,0);
INSERT INTO "django_geo_db_location" VALUES(65186,NULL,'Tempe, AZ 85282',27201,222,NULL,3,37692,0);
INSERT INTO "django_geo_db_location" VALUES(65187,NULL,'Tempe, AZ 85283',27201,222,NULL,3,37693,0);
INSERT INTO "django_geo_db_location" VALUES(65188,NULL,'Tempe, AZ 85284',27201,222,NULL,3,37694,0);
INSERT INTO "django_geo_db_location" VALUES(65189,NULL,'Tempe, AZ 85285',27201,222,NULL,3,37695,0);
INSERT INTO "django_geo_db_location" VALUES(65190,NULL,'New River, AZ 85286',27173,222,NULL,3,37696,0);
INSERT INTO "django_geo_db_location" VALUES(65191,NULL,'Tempe, AZ 85287',27201,222,NULL,3,37697,0);
INSERT INTO "django_geo_db_location" VALUES(65192,NULL,'Scottsdale, AZ 85288',27194,222,NULL,3,37698,0);
INSERT INTO "django_geo_db_location" VALUES(65193,NULL,'Tempe, AZ 85289',27201,222,NULL,3,37699,0);
INSERT INTO "django_geo_db_location" VALUES(65194,NULL,'Tortilla Flat, AZ',27202,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65195,NULL,'Tortilla Flat, AZ 85290',27202,222,NULL,3,37700,0);
INSERT INTO "django_geo_db_location" VALUES(65196,NULL,'Valley Farms, AZ',27203,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65197,NULL,'Valley Farms, AZ 85291',27203,222,NULL,3,37701,0);
INSERT INTO "django_geo_db_location" VALUES(65198,NULL,'Winkelman, AZ',27204,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65199,NULL,'Winkelman, AZ 85292',27204,222,NULL,3,37702,0);
INSERT INTO "django_geo_db_location" VALUES(65200,NULL,'Gilbert, AZ 85296',27185,222,NULL,3,37703,0);
INSERT INTO "django_geo_db_location" VALUES(65201,NULL,'Gilbert, AZ 85297',27185,222,NULL,3,37704,0);
INSERT INTO "django_geo_db_location" VALUES(65202,NULL,'Gilbert, AZ 85299',27185,222,NULL,3,37705,0);
INSERT INTO "django_geo_db_location" VALUES(65203,NULL,'Glendale, AZ',27205,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65204,NULL,'Glendale, AZ 85301',27205,222,NULL,3,37706,0);
INSERT INTO "django_geo_db_location" VALUES(65205,NULL,'Glendale, AZ 85302',27205,222,NULL,3,37707,0);
INSERT INTO "django_geo_db_location" VALUES(65206,NULL,'Glendale, AZ 85303',27205,222,NULL,3,37708,0);
INSERT INTO "django_geo_db_location" VALUES(65207,NULL,'Glendale, AZ 85304',27205,222,NULL,3,37709,0);
INSERT INTO "django_geo_db_location" VALUES(65208,NULL,'Glendale, AZ 85305',27205,222,NULL,3,37710,0);
INSERT INTO "django_geo_db_location" VALUES(65209,NULL,'Glendale, AZ 85306',27205,222,NULL,3,37711,0);
INSERT INTO "django_geo_db_location" VALUES(65210,NULL,'Glendale, AZ 85307',27205,222,NULL,3,37712,0);
INSERT INTO "django_geo_db_location" VALUES(65211,NULL,'Glendale, AZ 85308',27205,222,NULL,3,37713,0);
INSERT INTO "django_geo_db_location" VALUES(65212,NULL,'Luke AFB, AZ',27206,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65213,NULL,'Luke AFB, AZ 85309',27206,222,NULL,3,37714,0);
INSERT INTO "django_geo_db_location" VALUES(65214,NULL,'Glendale, AZ 85310',27205,222,NULL,3,37715,0);
INSERT INTO "django_geo_db_location" VALUES(65215,NULL,'Glendale, AZ 85311',27205,222,NULL,3,37716,0);
INSERT INTO "django_geo_db_location" VALUES(65216,NULL,'Glendale, AZ 85312',27205,222,NULL,3,37717,0);
INSERT INTO "django_geo_db_location" VALUES(65217,NULL,'Glendale, AZ 85313',27205,222,NULL,3,37718,0);
INSERT INTO "django_geo_db_location" VALUES(65218,NULL,'Carefree, AZ',27207,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65219,NULL,'Carefree, AZ 85317',27207,222,NULL,3,37719,0);
INSERT INTO "django_geo_db_location" VALUES(65220,NULL,'Glendale, AZ 85318',27205,222,NULL,3,37720,0);
INSERT INTO "django_geo_db_location" VALUES(65221,NULL,'Aguila, AZ',27208,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65222,NULL,'Aguila, AZ 85320',27208,222,NULL,3,37721,0);
INSERT INTO "django_geo_db_location" VALUES(65223,NULL,'Ajo, AZ',27209,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65224,NULL,'Ajo, AZ 85321',27209,222,NULL,3,37722,0);
INSERT INTO "django_geo_db_location" VALUES(65225,NULL,'Arlington, AZ',27210,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65226,NULL,'Arlington, AZ 85322',27210,222,NULL,3,37723,0);
INSERT INTO "django_geo_db_location" VALUES(65227,NULL,'Avondale, AZ',27211,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65228,NULL,'Avondale, AZ 85323',27211,222,NULL,3,37724,0);
INSERT INTO "django_geo_db_location" VALUES(65229,NULL,'Black Canyon City, AZ',27212,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65230,NULL,'Black Canyon City, AZ 85324',27212,222,NULL,3,37725,0);
INSERT INTO "django_geo_db_location" VALUES(65231,NULL,'Bouse, AZ',27213,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65232,NULL,'Bouse, AZ 85325',27213,222,NULL,3,37726,0);
INSERT INTO "django_geo_db_location" VALUES(65233,NULL,'Buckeye, AZ',27214,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65234,NULL,'Buckeye, AZ 85326',27214,222,NULL,3,37727,0);
INSERT INTO "django_geo_db_location" VALUES(65235,NULL,'Cave Creek, AZ',27215,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65236,NULL,'Cave Creek, AZ 85327',27215,222,NULL,3,37728,0);
INSERT INTO "django_geo_db_location" VALUES(65237,NULL,'Cibola, AZ',27216,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65238,NULL,'Cibola, AZ 85328',27216,222,NULL,3,37729,0);
INSERT INTO "django_geo_db_location" VALUES(65239,NULL,'Cashion, AZ',27217,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65240,NULL,'Cashion, AZ 85329',27217,222,NULL,3,37730,0);
INSERT INTO "django_geo_db_location" VALUES(65241,NULL,'Wickenburg, AZ',27218,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65242,NULL,'Wickenburg, AZ 85330',27218,222,NULL,3,37731,0);
INSERT INTO "django_geo_db_location" VALUES(65243,NULL,'Cave Creek, AZ 85331',27215,222,NULL,3,37732,0);
INSERT INTO "django_geo_db_location" VALUES(65244,NULL,'Congress, AZ',27219,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65245,NULL,'Congress, AZ 85332',27219,222,NULL,3,37733,0);
INSERT INTO "django_geo_db_location" VALUES(65246,NULL,'Dateland, AZ',27220,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65247,NULL,'Dateland, AZ 85333',27220,222,NULL,3,37734,0);
INSERT INTO "django_geo_db_location" VALUES(65248,NULL,'Ehrenberg, AZ',27221,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65249,NULL,'Ehrenberg, AZ 85334',27221,222,NULL,3,37735,0);
INSERT INTO "django_geo_db_location" VALUES(65250,NULL,'El Mirage, AZ',27222,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65251,NULL,'El Mirage, AZ 85335',27222,222,NULL,3,37736,0);
INSERT INTO "django_geo_db_location" VALUES(65252,NULL,'Gadsden, AZ',27223,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65253,NULL,'Gadsden, AZ 85336',27223,222,NULL,3,37737,0);
INSERT INTO "django_geo_db_location" VALUES(65254,NULL,'Gila Bend, AZ',27224,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65255,NULL,'Gila Bend, AZ 85337',27224,222,NULL,3,37738,0);
INSERT INTO "django_geo_db_location" VALUES(65256,NULL,'Goodyear, AZ',27225,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65257,NULL,'Goodyear, AZ 85338',27225,222,NULL,3,37739,0);
INSERT INTO "django_geo_db_location" VALUES(65258,NULL,'Laveen, AZ',27226,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65259,NULL,'Laveen, AZ 85339',27226,222,NULL,3,37740,0);
INSERT INTO "django_geo_db_location" VALUES(65260,NULL,'Litchfield Park, AZ',27227,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65261,NULL,'Litchfield Park, AZ 85340',27227,222,NULL,3,37741,0);
INSERT INTO "django_geo_db_location" VALUES(65262,NULL,'Lukeville, AZ',27228,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65263,NULL,'Lukeville, AZ 85341',27228,222,NULL,3,37742,0);
INSERT INTO "django_geo_db_location" VALUES(65264,NULL,'Morristown, AZ',27229,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65265,NULL,'Morristown, AZ 85342',27229,222,NULL,3,37743,0);
INSERT INTO "django_geo_db_location" VALUES(65266,NULL,'Palo Verde, AZ',27230,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65267,NULL,'Palo Verde, AZ 85343',27230,222,NULL,3,37744,0);
INSERT INTO "django_geo_db_location" VALUES(65268,NULL,'Parker, AZ',27231,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65269,NULL,'Parker, AZ 85344',27231,222,NULL,3,37745,0);
INSERT INTO "django_geo_db_location" VALUES(65270,NULL,'Peoria, AZ',27232,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65271,NULL,'Peoria, AZ 85345',27232,222,NULL,3,37746,0);
INSERT INTO "django_geo_db_location" VALUES(65272,NULL,'Quartzsite, AZ',27233,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65273,NULL,'Quartzsite, AZ 85346',27233,222,NULL,3,37747,0);
INSERT INTO "django_geo_db_location" VALUES(65274,NULL,'Roll, AZ',27234,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65275,NULL,'Roll, AZ 85347',27234,222,NULL,3,37748,0);
INSERT INTO "django_geo_db_location" VALUES(65276,NULL,'Salome, AZ',27235,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65277,NULL,'Salome, AZ 85348',27235,222,NULL,3,37749,0);
INSERT INTO "django_geo_db_location" VALUES(65278,NULL,'San Luis, AZ',27236,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65279,NULL,'San Luis, AZ 85349',27236,222,NULL,3,37750,0);
INSERT INTO "django_geo_db_location" VALUES(65280,NULL,'Somerton, AZ',27237,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65281,NULL,'Somerton, AZ 85350',27237,222,NULL,3,37751,0);
INSERT INTO "django_geo_db_location" VALUES(65282,NULL,'Sun City, AZ',27238,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65283,NULL,'Sun City, AZ 85351',27238,222,NULL,3,37752,0);
INSERT INTO "django_geo_db_location" VALUES(65284,NULL,'Tacna, AZ',27239,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65285,NULL,'Tacna, AZ 85352',27239,222,NULL,3,37753,0);
INSERT INTO "django_geo_db_location" VALUES(65286,NULL,'Tolleson, AZ',27240,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65287,NULL,'Tolleson, AZ 85353',27240,222,NULL,3,37754,0);
INSERT INTO "django_geo_db_location" VALUES(65288,NULL,'Tonopah, AZ',27241,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65289,NULL,'Tonopah, AZ 85354',27241,222,NULL,3,37755,0);
INSERT INTO "django_geo_db_location" VALUES(65290,NULL,'Waddell, AZ',27242,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65291,NULL,'Waddell, AZ 85355',27242,222,NULL,3,37756,0);
INSERT INTO "django_geo_db_location" VALUES(65292,NULL,'Wellton, AZ',27243,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65293,NULL,'Wellton, AZ 85356',27243,222,NULL,3,37757,0);
INSERT INTO "django_geo_db_location" VALUES(65294,NULL,'Wenden, AZ',27244,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65295,NULL,'Wenden, AZ 85357',27244,222,NULL,3,37758,0);
INSERT INTO "django_geo_db_location" VALUES(65296,NULL,'Wickenburg, AZ 85358',27218,222,NULL,3,37759,0);
INSERT INTO "django_geo_db_location" VALUES(65297,NULL,'Quartzsite, AZ 85359',27233,222,NULL,3,37760,0);
INSERT INTO "django_geo_db_location" VALUES(65298,NULL,'Wikieup, AZ',27245,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65299,NULL,'Wikieup, AZ 85360',27245,222,NULL,3,37761,0);
INSERT INTO "django_geo_db_location" VALUES(65300,NULL,'Wittmann, AZ',27246,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65301,NULL,'Wittmann, AZ 85361',27246,222,NULL,3,37762,0);
INSERT INTO "django_geo_db_location" VALUES(65302,NULL,'Yarnell, AZ',27247,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65303,NULL,'Yarnell, AZ 85362',27247,222,NULL,3,37763,0);
INSERT INTO "django_geo_db_location" VALUES(65304,NULL,'Youngtown, AZ',27248,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65305,NULL,'Youngtown, AZ 85363',27248,222,NULL,3,37764,0);
INSERT INTO "django_geo_db_location" VALUES(65306,NULL,'Yuma, AZ',27249,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65307,NULL,'Yuma, AZ 85364',27249,222,NULL,3,37765,0);
INSERT INTO "django_geo_db_location" VALUES(65308,NULL,'Yuma, AZ 85365',27249,222,NULL,3,37766,0);
INSERT INTO "django_geo_db_location" VALUES(65309,NULL,'Yuma, AZ 85366',27249,222,NULL,3,37767,0);
INSERT INTO "django_geo_db_location" VALUES(65310,NULL,'Yuma, AZ 85367',27249,222,NULL,3,37768,0);
INSERT INTO "django_geo_db_location" VALUES(65311,NULL,'Yuma, AZ 85369',27249,222,NULL,3,37769,0);
INSERT INTO "django_geo_db_location" VALUES(65312,NULL,'Poston, AZ',27250,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65313,NULL,'Poston, AZ 85371',27250,222,NULL,3,37770,0);
INSERT INTO "django_geo_db_location" VALUES(65314,NULL,'Sun City, AZ 85372',27238,222,NULL,3,37771,0);
INSERT INTO "django_geo_db_location" VALUES(65315,NULL,'Sun City, AZ 85373',27238,222,NULL,3,37772,0);
INSERT INTO "django_geo_db_location" VALUES(65316,NULL,'Surprise, AZ',27251,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65317,NULL,'Surprise, AZ 85374',27251,222,NULL,3,37773,0);
INSERT INTO "django_geo_db_location" VALUES(65318,NULL,'Sun City West, AZ',27252,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65319,NULL,'Sun City West, AZ 85375',27252,222,NULL,3,37774,0);
INSERT INTO "django_geo_db_location" VALUES(65320,NULL,'Sun City West, AZ 85376',27252,222,NULL,3,37775,0);
INSERT INTO "django_geo_db_location" VALUES(65321,NULL,'Carefree, AZ 85377',27207,222,NULL,3,37776,0);
INSERT INTO "django_geo_db_location" VALUES(65322,NULL,'Surprise, AZ 85378',27251,222,NULL,3,37777,0);
INSERT INTO "django_geo_db_location" VALUES(65323,NULL,'Surprise, AZ 85379',27251,222,NULL,3,37778,0);
INSERT INTO "django_geo_db_location" VALUES(65324,NULL,'Peoria, AZ 85380',27232,222,NULL,3,37779,0);
INSERT INTO "django_geo_db_location" VALUES(65325,NULL,'Peoria, AZ 85381',27232,222,NULL,3,37780,0);
INSERT INTO "django_geo_db_location" VALUES(65326,NULL,'Peoria, AZ 85382',27232,222,NULL,3,37781,0);
INSERT INTO "django_geo_db_location" VALUES(65327,NULL,'Peoria, AZ 85383',27232,222,NULL,3,37782,0);
INSERT INTO "django_geo_db_location" VALUES(65328,NULL,'Peoria, AZ 85385',27232,222,NULL,3,37783,0);
INSERT INTO "django_geo_db_location" VALUES(65329,NULL,'Surprise, AZ 85387',27251,222,NULL,3,37784,0);
INSERT INTO "django_geo_db_location" VALUES(65330,NULL,'Wickenburg, AZ 85390',27218,222,NULL,3,37785,0);
INSERT INTO "django_geo_db_location" VALUES(65331,NULL,'Peoria, AZ 85395',27232,222,NULL,3,37786,0);
INSERT INTO "django_geo_db_location" VALUES(65332,NULL,'San Luis, AZ 85439',27236,222,NULL,3,37787,0);
INSERT INTO "django_geo_db_location" VALUES(65333,NULL,'Globe, AZ',27253,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65334,NULL,'Globe, AZ 85501',27253,222,NULL,3,37788,0);
INSERT INTO "django_geo_db_location" VALUES(65335,NULL,'Globe, AZ 85502',27253,222,NULL,3,37789,0);
INSERT INTO "django_geo_db_location" VALUES(65336,NULL,'Thatcher, AZ',27254,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65337,NULL,'Thatcher, AZ 85522',27254,222,NULL,3,37790,0);
INSERT INTO "django_geo_db_location" VALUES(65338,NULL,'Bylas, AZ',27255,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65339,NULL,'Bylas, AZ 85530',27255,222,NULL,3,37791,0);
INSERT INTO "django_geo_db_location" VALUES(65340,NULL,'Central, AZ',27256,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65341,NULL,'Central, AZ 85531',27256,222,NULL,3,37792,0);
INSERT INTO "django_geo_db_location" VALUES(65342,NULL,'Claypool, AZ',27257,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65343,NULL,'Claypool, AZ 85532',27257,222,NULL,3,37793,0);
INSERT INTO "django_geo_db_location" VALUES(65344,NULL,'Clifton, AZ',27258,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65345,NULL,'Clifton, AZ 85533',27258,222,NULL,3,37794,0);
INSERT INTO "django_geo_db_location" VALUES(65346,NULL,'Duncan, AZ',27259,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65347,NULL,'Duncan, AZ 85534',27259,222,NULL,3,37795,0);
INSERT INTO "django_geo_db_location" VALUES(65348,NULL,'Eden, AZ',27260,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65349,NULL,'Eden, AZ 85535',27260,222,NULL,3,37796,0);
INSERT INTO "django_geo_db_location" VALUES(65350,NULL,'Fort Thomas, AZ',27261,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65351,NULL,'Fort Thomas, AZ 85536',27261,222,NULL,3,37797,0);
INSERT INTO "django_geo_db_location" VALUES(65352,NULL,'Miami, AZ',27262,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65353,NULL,'Miami, AZ 85539',27262,222,NULL,3,37798,0);
INSERT INTO "django_geo_db_location" VALUES(65354,NULL,'Morenci, AZ',27263,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65355,NULL,'Morenci, AZ 85540',27263,222,NULL,3,37799,0);
INSERT INTO "django_geo_db_location" VALUES(65356,NULL,'Payson, AZ',27264,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65357,NULL,'Payson, AZ 85541',27264,222,NULL,3,37800,0);
INSERT INTO "django_geo_db_location" VALUES(65358,NULL,'Peridot, AZ',27265,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65359,NULL,'Peridot, AZ 85542',27265,222,NULL,3,37801,0);
INSERT INTO "django_geo_db_location" VALUES(65360,NULL,'Pima, AZ',27266,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65361,NULL,'Pima, AZ 85543',27266,222,NULL,3,37802,0);
INSERT INTO "django_geo_db_location" VALUES(65362,NULL,'Pine, AZ',27267,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65363,NULL,'Pine, AZ 85544',27267,222,NULL,3,37803,0);
INSERT INTO "django_geo_db_location" VALUES(65364,NULL,'Roosevelt, AZ',27268,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65365,NULL,'Roosevelt, AZ 85545',27268,222,NULL,3,37804,0);
INSERT INTO "django_geo_db_location" VALUES(65366,NULL,'Safford, AZ',27269,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65367,NULL,'Safford, AZ 85546',27269,222,NULL,3,37805,0);
INSERT INTO "django_geo_db_location" VALUES(65368,NULL,'Payson, AZ 85547',27264,222,NULL,3,37806,0);
INSERT INTO "django_geo_db_location" VALUES(65369,NULL,'Safford, AZ 85548',27269,222,NULL,3,37807,0);
INSERT INTO "django_geo_db_location" VALUES(65370,NULL,'San Carlos, AZ',27270,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65371,NULL,'San Carlos, AZ 85550',27270,222,NULL,3,37808,0);
INSERT INTO "django_geo_db_location" VALUES(65372,NULL,'Solomon, AZ',27271,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65373,NULL,'Solomon, AZ 85551',27271,222,NULL,3,37809,0);
INSERT INTO "django_geo_db_location" VALUES(65374,NULL,'Thatcher, AZ 85552',27254,222,NULL,3,37810,0);
INSERT INTO "django_geo_db_location" VALUES(65375,NULL,'Tonto Basin, AZ',27272,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65376,NULL,'Tonto Basin, AZ 85553',27272,222,NULL,3,37811,0);
INSERT INTO "django_geo_db_location" VALUES(65377,NULL,'Young, AZ',27273,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65378,NULL,'Young, AZ 85554',27273,222,NULL,3,37812,0);
INSERT INTO "django_geo_db_location" VALUES(65379,NULL,'Arivaca, AZ',27274,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65380,NULL,'Arivaca, AZ 85601',27274,222,NULL,3,37813,0);
INSERT INTO "django_geo_db_location" VALUES(65381,NULL,'Benson, AZ',27275,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65382,NULL,'Benson, AZ 85602',27275,222,NULL,3,37814,0);
INSERT INTO "django_geo_db_location" VALUES(65383,NULL,'Bisbee, AZ',27276,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65384,NULL,'Bisbee, AZ 85603',27276,222,NULL,3,37815,0);
INSERT INTO "django_geo_db_location" VALUES(65385,NULL,'Bowie, AZ',27277,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65386,NULL,'Bowie, AZ 85605',27277,222,NULL,3,37816,0);
INSERT INTO "django_geo_db_location" VALUES(65387,NULL,'Cochise, AZ',27278,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65388,NULL,'Cochise, AZ 85606',27278,222,NULL,3,37817,0);
INSERT INTO "django_geo_db_location" VALUES(65389,NULL,'Douglas, AZ',27279,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65390,NULL,'Douglas, AZ 85607',27279,222,NULL,3,37818,0);
INSERT INTO "django_geo_db_location" VALUES(65391,NULL,'Douglas, AZ 85608',27279,222,NULL,3,37819,0);
INSERT INTO "django_geo_db_location" VALUES(65392,NULL,'Dragoon, AZ',27280,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65393,NULL,'Dragoon, AZ 85609',27280,222,NULL,3,37820,0);
INSERT INTO "django_geo_db_location" VALUES(65394,NULL,'Elfrida, AZ',27281,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65395,NULL,'Elfrida, AZ 85610',27281,222,NULL,3,37821,0);
INSERT INTO "django_geo_db_location" VALUES(65396,NULL,'Elgin, AZ',27282,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65397,NULL,'Elgin, AZ 85611',27282,222,NULL,3,37822,0);
INSERT INTO "django_geo_db_location" VALUES(65398,NULL,'Fort Huachuca, AZ',27283,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65399,NULL,'Fort Huachuca, AZ 85613',27283,222,NULL,3,37823,0);
INSERT INTO "django_geo_db_location" VALUES(65400,NULL,'Green Valley, AZ',27284,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65401,NULL,'Green Valley, AZ 85614',27284,222,NULL,3,37824,0);
INSERT INTO "django_geo_db_location" VALUES(65402,NULL,'Hereford, AZ',27285,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65403,NULL,'Hereford, AZ 85615',27285,222,NULL,3,37825,0);
INSERT INTO "django_geo_db_location" VALUES(65404,NULL,'Huachuca City, AZ',27286,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65405,NULL,'Huachuca City, AZ 85616',27286,222,NULL,3,37826,0);
INSERT INTO "django_geo_db_location" VALUES(65406,NULL,'McNeal, AZ',27287,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65407,NULL,'McNeal, AZ 85617',27287,222,NULL,3,37827,0);
INSERT INTO "django_geo_db_location" VALUES(65408,NULL,'Mammoth, AZ',27288,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65409,NULL,'Mammoth, AZ 85618',27288,222,NULL,3,37828,0);
INSERT INTO "django_geo_db_location" VALUES(65410,NULL,'Mount Lemmon, AZ',27289,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65411,NULL,'Mount Lemmon, AZ 85619',27289,222,NULL,3,37829,0);
INSERT INTO "django_geo_db_location" VALUES(65412,NULL,'Naco, AZ',27290,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65413,NULL,'Naco, AZ 85620',27290,222,NULL,3,37830,0);
INSERT INTO "django_geo_db_location" VALUES(65414,NULL,'Nogales, AZ',27291,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65415,NULL,'Nogales, AZ 85621',27291,222,NULL,3,37831,0);
INSERT INTO "django_geo_db_location" VALUES(65416,NULL,'Green Valley, AZ 85622',27284,222,NULL,3,37832,0);
INSERT INTO "django_geo_db_location" VALUES(65417,NULL,'Oracle, AZ',27292,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65418,NULL,'Oracle, AZ 85623',27292,222,NULL,3,37833,0);
INSERT INTO "django_geo_db_location" VALUES(65419,NULL,'Patagonia, AZ',27293,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65420,NULL,'Patagonia, AZ 85624',27293,222,NULL,3,37834,0);
INSERT INTO "django_geo_db_location" VALUES(65421,NULL,'Pearce, AZ',27294,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65422,NULL,'Pearce, AZ 85625',27294,222,NULL,3,37835,0);
INSERT INTO "django_geo_db_location" VALUES(65423,NULL,'Pirtleville, AZ',27295,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65424,NULL,'Pirtleville, AZ 85626',27295,222,NULL,3,37836,0);
INSERT INTO "django_geo_db_location" VALUES(65425,NULL,'Pomerene, AZ',27296,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65426,NULL,'Pomerene, AZ 85627',27296,222,NULL,3,37837,0);
INSERT INTO "django_geo_db_location" VALUES(65427,NULL,'Nogales, AZ 85628',27291,222,NULL,3,37838,0);
INSERT INTO "django_geo_db_location" VALUES(65428,NULL,'Sahuarita, AZ',27297,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65429,NULL,'Sahuarita, AZ 85629',27297,222,NULL,3,37839,0);
INSERT INTO "django_geo_db_location" VALUES(65430,NULL,'Saint David, AZ',27298,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65431,NULL,'Saint David, AZ 85630',27298,222,NULL,3,37840,0);
INSERT INTO "django_geo_db_location" VALUES(65432,NULL,'San Manuel, AZ',27299,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65433,NULL,'San Manuel, AZ 85631',27299,222,NULL,3,37841,0);
INSERT INTO "django_geo_db_location" VALUES(65434,NULL,'San Simon, AZ',27300,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65435,NULL,'San Simon, AZ 85632',27300,222,NULL,3,37842,0);
INSERT INTO "django_geo_db_location" VALUES(65436,NULL,'Sasabe, AZ',27301,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65437,NULL,'Sasabe, AZ 85633',27301,222,NULL,3,37843,0);
INSERT INTO "django_geo_db_location" VALUES(65438,NULL,'Sells, AZ',27302,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65439,NULL,'Sells, AZ 85634',27302,222,NULL,3,37844,0);
INSERT INTO "django_geo_db_location" VALUES(65440,NULL,'Sierra Vista, AZ',27303,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65441,NULL,'Sierra Vista, AZ 85635',27303,222,NULL,3,37845,0);
INSERT INTO "django_geo_db_location" VALUES(65442,NULL,'Sierra Vista, AZ 85636',27303,222,NULL,3,37846,0);
INSERT INTO "django_geo_db_location" VALUES(65443,NULL,'Sonoita, AZ',27304,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65444,NULL,'Sonoita, AZ 85637',27304,222,NULL,3,37847,0);
INSERT INTO "django_geo_db_location" VALUES(65445,NULL,'Tombstone, AZ',27305,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65446,NULL,'Tombstone, AZ 85638',27305,222,NULL,3,37848,0);
INSERT INTO "django_geo_db_location" VALUES(65447,NULL,'Topawa, AZ',27306,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65448,NULL,'Topawa, AZ 85639',27306,222,NULL,3,37849,0);
INSERT INTO "django_geo_db_location" VALUES(65449,NULL,'Tumacacori, AZ',27307,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65450,NULL,'Tumacacori, AZ 85640',27307,222,NULL,3,37850,0);
INSERT INTO "django_geo_db_location" VALUES(65451,NULL,'Vail, AZ',27308,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65452,NULL,'Vail, AZ 85641',27308,222,NULL,3,37851,0);
INSERT INTO "django_geo_db_location" VALUES(65453,NULL,'Willcox, AZ',27309,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65454,NULL,'Willcox, AZ 85643',27309,222,NULL,3,37852,0);
INSERT INTO "django_geo_db_location" VALUES(65455,NULL,'Willcox, AZ 85644',27309,222,NULL,3,37853,0);
INSERT INTO "django_geo_db_location" VALUES(65456,NULL,'Amado, AZ',27310,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65457,NULL,'Amado, AZ 85645',27310,222,NULL,3,37854,0);
INSERT INTO "django_geo_db_location" VALUES(65458,NULL,'Tubac, AZ',27311,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65459,NULL,'Tubac, AZ 85646',27311,222,NULL,3,37855,0);
INSERT INTO "django_geo_db_location" VALUES(65460,NULL,'Rio Rico, AZ',27312,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65461,NULL,'Rio Rico, AZ 85648',27312,222,NULL,3,37856,0);
INSERT INTO "django_geo_db_location" VALUES(65462,NULL,'Sierra Vista, AZ 85650',27303,222,NULL,3,37857,0);
INSERT INTO "django_geo_db_location" VALUES(65463,NULL,'Cortaro, AZ',27313,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65464,NULL,'Cortaro, AZ 85652',27313,222,NULL,3,37858,0);
INSERT INTO "django_geo_db_location" VALUES(65465,NULL,'Marana, AZ',27314,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65466,NULL,'Marana, AZ 85653',27314,222,NULL,3,37859,0);
INSERT INTO "django_geo_db_location" VALUES(65467,NULL,'Rillito, AZ',27315,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65468,NULL,'Rillito, AZ 85654',27315,222,NULL,3,37860,0);
INSERT INTO "django_geo_db_location" VALUES(65469,NULL,'Douglas, AZ 85655',27279,222,NULL,3,37861,0);
INSERT INTO "django_geo_db_location" VALUES(65470,NULL,'Nogales, AZ 85662',27291,222,NULL,3,37862,0);
INSERT INTO "django_geo_db_location" VALUES(65471,NULL,'Fort Huachuca, AZ 85670',27283,222,NULL,3,37863,0);
INSERT INTO "django_geo_db_location" VALUES(65472,NULL,'Sierra Vista, AZ 85671',27303,222,NULL,3,37864,0);
INSERT INTO "django_geo_db_location" VALUES(65473,NULL,'Tucson, AZ',27316,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65474,NULL,'Tucson, AZ 85701',27316,222,NULL,3,37865,0);
INSERT INTO "django_geo_db_location" VALUES(65475,NULL,'Tucson, AZ 85702',27316,222,NULL,3,37866,0);
INSERT INTO "django_geo_db_location" VALUES(65476,NULL,'Tucson, AZ 85703',27316,222,NULL,3,37867,0);
INSERT INTO "django_geo_db_location" VALUES(65477,NULL,'Tucson, AZ 85704',27316,222,NULL,3,37868,0);
INSERT INTO "django_geo_db_location" VALUES(65478,NULL,'Tucson, AZ 85705',27316,222,NULL,3,37869,0);
INSERT INTO "django_geo_db_location" VALUES(65479,NULL,'Tucson, AZ 85706',27316,222,NULL,3,37870,0);
INSERT INTO "django_geo_db_location" VALUES(65480,NULL,'Tucson, AZ 85707',27316,222,NULL,3,37871,0);
INSERT INTO "django_geo_db_location" VALUES(65481,NULL,'Tucson, AZ 85708',27316,222,NULL,3,37872,0);
INSERT INTO "django_geo_db_location" VALUES(65482,NULL,'Tucson, AZ 85709',27316,222,NULL,3,37873,0);
INSERT INTO "django_geo_db_location" VALUES(65483,NULL,'Tucson, AZ 85710',27316,222,NULL,3,37874,0);
INSERT INTO "django_geo_db_location" VALUES(65484,NULL,'Tucson, AZ 85711',27316,222,NULL,3,37875,0);
INSERT INTO "django_geo_db_location" VALUES(65485,NULL,'Tucson, AZ 85712',27316,222,NULL,3,37876,0);
INSERT INTO "django_geo_db_location" VALUES(65486,NULL,'Tucson, AZ 85713',27316,222,NULL,3,37877,0);
INSERT INTO "django_geo_db_location" VALUES(65487,NULL,'Tucson, AZ 85714',27316,222,NULL,3,37878,0);
INSERT INTO "django_geo_db_location" VALUES(65488,NULL,'Tucson, AZ 85715',27316,222,NULL,3,37879,0);
INSERT INTO "django_geo_db_location" VALUES(65489,NULL,'Tucson, AZ 85716',27316,222,NULL,3,37880,0);
INSERT INTO "django_geo_db_location" VALUES(65490,NULL,'Tucson, AZ 85717',27316,222,NULL,3,37881,0);
INSERT INTO "django_geo_db_location" VALUES(65491,NULL,'Tucson, AZ 85718',27316,222,NULL,3,37882,0);
INSERT INTO "django_geo_db_location" VALUES(65492,NULL,'Tucson, AZ 85719',27316,222,NULL,3,37883,0);
INSERT INTO "django_geo_db_location" VALUES(65493,NULL,'Tucson, AZ 85720',27316,222,NULL,3,37884,0);
INSERT INTO "django_geo_db_location" VALUES(65494,NULL,'Tucson, AZ 85721',27316,222,NULL,3,37885,0);
INSERT INTO "django_geo_db_location" VALUES(65495,NULL,'Tucson, AZ 85722',27316,222,NULL,3,37886,0);
INSERT INTO "django_geo_db_location" VALUES(65496,NULL,'Tucson, AZ 85723',27316,222,NULL,3,37887,0);
INSERT INTO "django_geo_db_location" VALUES(65497,NULL,'Tucson, AZ 85724',27316,222,NULL,3,37888,0);
INSERT INTO "django_geo_db_location" VALUES(65498,NULL,'Tucson, AZ 85725',27316,222,NULL,3,37889,0);
INSERT INTO "django_geo_db_location" VALUES(65499,NULL,'Tucson, AZ 85726',27316,222,NULL,3,37890,0);
INSERT INTO "django_geo_db_location" VALUES(65500,NULL,'Tucson, AZ 85728',27316,222,NULL,3,37891,0);
INSERT INTO "django_geo_db_location" VALUES(65501,NULL,'Tucson, AZ 85730',27316,222,NULL,3,37892,0);
INSERT INTO "django_geo_db_location" VALUES(65502,NULL,'Tucson, AZ 85731',27316,222,NULL,3,37893,0);
INSERT INTO "django_geo_db_location" VALUES(65503,NULL,'Tucson, AZ 85732',27316,222,NULL,3,37894,0);
INSERT INTO "django_geo_db_location" VALUES(65504,NULL,'Tucson, AZ 85733',27316,222,NULL,3,37895,0);
INSERT INTO "django_geo_db_location" VALUES(65505,NULL,'Tucson, AZ 85734',27316,222,NULL,3,37896,0);
INSERT INTO "django_geo_db_location" VALUES(65506,NULL,'Tucson, AZ 85735',27316,222,NULL,3,37897,0);
INSERT INTO "django_geo_db_location" VALUES(65507,NULL,'Tucson, AZ 85736',27316,222,NULL,3,37898,0);
INSERT INTO "django_geo_db_location" VALUES(65508,NULL,'Tucson, AZ 85737',27316,222,NULL,3,37899,0);
INSERT INTO "django_geo_db_location" VALUES(65509,NULL,'Catalina, AZ',27317,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65510,NULL,'Catalina, AZ 85738',27317,222,NULL,3,37900,0);
INSERT INTO "django_geo_db_location" VALUES(65511,NULL,'Tucson, AZ 85739',27316,222,NULL,3,37901,0);
INSERT INTO "django_geo_db_location" VALUES(65512,NULL,'Tucson, AZ 85740',27316,222,NULL,3,37902,0);
INSERT INTO "django_geo_db_location" VALUES(65513,NULL,'Tucson, AZ 85741',27316,222,NULL,3,37903,0);
INSERT INTO "django_geo_db_location" VALUES(65514,NULL,'Tucson, AZ 85742',27316,222,NULL,3,37904,0);
INSERT INTO "django_geo_db_location" VALUES(65515,NULL,'Tucson, AZ 85743',27316,222,NULL,3,37905,0);
INSERT INTO "django_geo_db_location" VALUES(65516,NULL,'Tucson, AZ 85744',27316,222,NULL,3,37906,0);
INSERT INTO "django_geo_db_location" VALUES(65517,NULL,'Tucson, AZ 85745',27316,222,NULL,3,37907,0);
INSERT INTO "django_geo_db_location" VALUES(65518,NULL,'Tucson, AZ 85746',27316,222,NULL,3,37908,0);
INSERT INTO "django_geo_db_location" VALUES(65519,NULL,'Tucson, AZ 85747',27316,222,NULL,3,37909,0);
INSERT INTO "django_geo_db_location" VALUES(65520,NULL,'Tucson, AZ 85748',27316,222,NULL,3,37910,0);
INSERT INTO "django_geo_db_location" VALUES(65521,NULL,'Tucson, AZ 85749',27316,222,NULL,3,37911,0);
INSERT INTO "django_geo_db_location" VALUES(65522,NULL,'Tucson, AZ 85750',27316,222,NULL,3,37912,0);
INSERT INTO "django_geo_db_location" VALUES(65523,NULL,'Tucson, AZ 85751',27316,222,NULL,3,37913,0);
INSERT INTO "django_geo_db_location" VALUES(65524,NULL,'Tucson, AZ 85752',27316,222,NULL,3,37914,0);
INSERT INTO "django_geo_db_location" VALUES(65525,NULL,'Tucson, AZ 85754',27316,222,NULL,3,37915,0);
INSERT INTO "django_geo_db_location" VALUES(65526,NULL,'Tucson, AZ 85775',27316,222,NULL,3,37916,0);
INSERT INTO "django_geo_db_location" VALUES(65527,NULL,'Tucson, AZ 85777',27316,222,NULL,3,37917,0);
INSERT INTO "django_geo_db_location" VALUES(65528,NULL,'New River, AZ 85807',27173,222,NULL,3,37918,0);
INSERT INTO "django_geo_db_location" VALUES(65529,NULL,'Show Low, AZ',27318,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65530,NULL,'Show Low, AZ 85901',27318,222,NULL,3,37919,0);
INSERT INTO "django_geo_db_location" VALUES(65531,NULL,'Show Low, AZ 85902',27318,222,NULL,3,37920,0);
INSERT INTO "django_geo_db_location" VALUES(65532,NULL,'Cibecue, AZ',27319,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65533,NULL,'Cibecue, AZ 85911',27319,222,NULL,3,37921,0);
INSERT INTO "django_geo_db_location" VALUES(65534,NULL,'White Mountain Lake, AZ',27320,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65535,NULL,'White Mountain Lake, AZ 85912',27320,222,NULL,3,37922,0);
INSERT INTO "django_geo_db_location" VALUES(65536,NULL,'Alpine, AZ',27321,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65537,NULL,'Alpine, AZ 85920',27321,222,NULL,3,37923,0);
INSERT INTO "django_geo_db_location" VALUES(65538,NULL,'Blue, AZ',27322,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65539,NULL,'Blue, AZ 85922',27322,222,NULL,3,37924,0);
INSERT INTO "django_geo_db_location" VALUES(65540,NULL,'Clay Springs, AZ',27323,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65541,NULL,'Clay Springs, AZ 85923',27323,222,NULL,3,37925,0);
INSERT INTO "django_geo_db_location" VALUES(65542,NULL,'Concho, AZ',27324,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65543,NULL,'Concho, AZ 85924',27324,222,NULL,3,37926,0);
INSERT INTO "django_geo_db_location" VALUES(65544,NULL,'Eagar, AZ',27325,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65545,NULL,'Eagar, AZ 85925',27325,222,NULL,3,37927,0);
INSERT INTO "django_geo_db_location" VALUES(65546,NULL,'Fort Apache, AZ',27326,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65547,NULL,'Fort Apache, AZ 85926',27326,222,NULL,3,37928,0);
INSERT INTO "django_geo_db_location" VALUES(65548,NULL,'Greer, AZ',27327,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65549,NULL,'Greer, AZ 85927',27327,222,NULL,3,37929,0);
INSERT INTO "django_geo_db_location" VALUES(65550,NULL,'Heber, AZ',27328,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65551,NULL,'Heber, AZ 85928',27328,222,NULL,3,37930,0);
INSERT INTO "django_geo_db_location" VALUES(65552,NULL,'Lakeside, AZ',27329,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65553,NULL,'Lakeside, AZ 85929',27329,222,NULL,3,37931,0);
INSERT INTO "django_geo_db_location" VALUES(65554,NULL,'Mcnary, AZ',27330,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65555,NULL,'Mcnary, AZ 85930',27330,222,NULL,3,37932,0);
INSERT INTO "django_geo_db_location" VALUES(65556,NULL,'Forest Lakes, AZ',27331,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65557,NULL,'Forest Lakes, AZ 85931',27331,222,NULL,3,37933,0);
INSERT INTO "django_geo_db_location" VALUES(65558,NULL,'Nutrioso, AZ',27332,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65559,NULL,'Nutrioso, AZ 85932',27332,222,NULL,3,37934,0);
INSERT INTO "django_geo_db_location" VALUES(65560,NULL,'Overgaard, AZ',27333,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65561,NULL,'Overgaard, AZ 85933',27333,222,NULL,3,37935,0);
INSERT INTO "django_geo_db_location" VALUES(65562,NULL,'Pinedale, AZ',27334,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65563,NULL,'Pinedale, AZ 85934',27334,222,NULL,3,37936,0);
INSERT INTO "django_geo_db_location" VALUES(65564,NULL,'Pinetop, AZ',27335,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65565,NULL,'Pinetop, AZ 85935',27335,222,NULL,3,37937,0);
INSERT INTO "django_geo_db_location" VALUES(65566,NULL,'Saint Johns, AZ',27336,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65567,NULL,'Saint Johns, AZ 85936',27336,222,NULL,3,37938,0);
INSERT INTO "django_geo_db_location" VALUES(65568,NULL,'Snowflake, AZ',27337,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65569,NULL,'Snowflake, AZ 85937',27337,222,NULL,3,37939,0);
INSERT INTO "django_geo_db_location" VALUES(65570,NULL,'Springerville, AZ',27338,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65571,NULL,'Springerville, AZ 85938',27338,222,NULL,3,37940,0);
INSERT INTO "django_geo_db_location" VALUES(65572,NULL,'Taylor, AZ',27339,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65573,NULL,'Taylor, AZ 85939',27339,222,NULL,3,37941,0);
INSERT INTO "django_geo_db_location" VALUES(65574,NULL,'Vernon, AZ',27340,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65575,NULL,'Vernon, AZ 85940',27340,222,NULL,3,37942,0);
INSERT INTO "django_geo_db_location" VALUES(65576,NULL,'Whiteriver, AZ',27341,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65577,NULL,'Whiteriver, AZ 85941',27341,222,NULL,3,37943,0);
INSERT INTO "django_geo_db_location" VALUES(65578,NULL,'Woodruff, AZ',27342,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65579,NULL,'Woodruff, AZ 85942',27342,222,NULL,3,37944,0);
INSERT INTO "django_geo_db_location" VALUES(65580,NULL,'Flagstaff, AZ',27343,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65581,NULL,'Flagstaff, AZ 86001',27343,222,NULL,3,37945,0);
INSERT INTO "django_geo_db_location" VALUES(65582,NULL,'Flagstaff, AZ 86002',27343,222,NULL,3,37946,0);
INSERT INTO "django_geo_db_location" VALUES(65583,NULL,'Flagstaff, AZ 86003',27343,222,NULL,3,37947,0);
INSERT INTO "django_geo_db_location" VALUES(65584,NULL,'Flagstaff, AZ 86004',27343,222,NULL,3,37948,0);
INSERT INTO "django_geo_db_location" VALUES(65585,NULL,'Flagstaff, AZ 86011',27343,222,NULL,3,37949,0);
INSERT INTO "django_geo_db_location" VALUES(65586,NULL,'Bellemont, AZ',27344,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65587,NULL,'Bellemont, AZ 86015',27344,222,NULL,3,37950,0);
INSERT INTO "django_geo_db_location" VALUES(65588,NULL,'Gray Mountain, AZ',27345,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65589,NULL,'Gray Mountain, AZ 86016',27345,222,NULL,3,37951,0);
INSERT INTO "django_geo_db_location" VALUES(65590,NULL,'Munds Park, AZ',27346,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65591,NULL,'Munds Park, AZ 86017',27346,222,NULL,3,37952,0);
INSERT INTO "django_geo_db_location" VALUES(65592,NULL,'Parks, AZ',27347,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65593,NULL,'Parks, AZ 86018',27347,222,NULL,3,37953,0);
INSERT INTO "django_geo_db_location" VALUES(65594,NULL,'Cameron, AZ',27348,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65595,NULL,'Cameron, AZ 86020',27348,222,NULL,3,37954,0);
INSERT INTO "django_geo_db_location" VALUES(65596,NULL,'Colorado City, AZ',27349,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65597,NULL,'Colorado City, AZ 86021',27349,222,NULL,3,37955,0);
INSERT INTO "django_geo_db_location" VALUES(65598,NULL,'Fredonia, AZ',27350,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65599,NULL,'Fredonia, AZ 86022',27350,222,NULL,3,37956,0);
INSERT INTO "django_geo_db_location" VALUES(65600,NULL,'Grand Canyon, AZ',27351,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65601,NULL,'Grand Canyon, AZ 86023',27351,222,NULL,3,37957,0);
INSERT INTO "django_geo_db_location" VALUES(65602,NULL,'Happy Jack, AZ',27352,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65603,NULL,'Happy Jack, AZ 86024',27352,222,NULL,3,37958,0);
INSERT INTO "django_geo_db_location" VALUES(65604,NULL,'Holbrook, AZ',27353,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65605,NULL,'Holbrook, AZ 86025',27353,222,NULL,3,37959,0);
INSERT INTO "django_geo_db_location" VALUES(65606,NULL,'Petrified Forest Natl Pk, AZ',27354,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65607,NULL,'Petrified Forest Natl Pk, AZ 86028',27354,222,NULL,3,37960,0);
INSERT INTO "django_geo_db_location" VALUES(65608,NULL,'Sun Valley, AZ',27355,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65609,NULL,'Sun Valley, AZ 86029',27355,222,NULL,3,37961,0);
INSERT INTO "django_geo_db_location" VALUES(65610,NULL,'Hotevilla, AZ',27356,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65611,NULL,'Hotevilla, AZ 86030',27356,222,NULL,3,37962,0);
INSERT INTO "django_geo_db_location" VALUES(65612,NULL,'Indian Wells, AZ',27357,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65613,NULL,'Indian Wells, AZ 86031',27357,222,NULL,3,37963,0);
INSERT INTO "django_geo_db_location" VALUES(65614,NULL,'Joseph City, AZ',27358,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65615,NULL,'Joseph City, AZ 86032',27358,222,NULL,3,37964,0);
INSERT INTO "django_geo_db_location" VALUES(65616,NULL,'Kayenta, AZ',27359,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65617,NULL,'Kayenta, AZ 86033',27359,222,NULL,3,37965,0);
INSERT INTO "django_geo_db_location" VALUES(65618,NULL,'Keams Canyon, AZ',27360,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65619,NULL,'Keams Canyon, AZ 86034',27360,222,NULL,3,37966,0);
INSERT INTO "django_geo_db_location" VALUES(65620,NULL,'Leupp, AZ',27361,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65621,NULL,'Leupp, AZ 86035',27361,222,NULL,3,37967,0);
INSERT INTO "django_geo_db_location" VALUES(65622,NULL,'Marble Canyon, AZ',27362,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65623,NULL,'Marble Canyon, AZ 86036',27362,222,NULL,3,37968,0);
INSERT INTO "django_geo_db_location" VALUES(65624,NULL,'Mormon Lake, AZ',27363,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65625,NULL,'Mormon Lake, AZ 86038',27363,222,NULL,3,37969,0);
INSERT INTO "django_geo_db_location" VALUES(65626,NULL,'Kykotsmovi Village, AZ',27364,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65627,NULL,'Kykotsmovi Village, AZ 86039',27364,222,NULL,3,37970,0);
INSERT INTO "django_geo_db_location" VALUES(65628,NULL,'Page, AZ',27365,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65629,NULL,'Page, AZ 86040',27365,222,NULL,3,37971,0);
INSERT INTO "django_geo_db_location" VALUES(65630,NULL,'Polacca, AZ',27366,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65631,NULL,'Polacca, AZ 86042',27366,222,NULL,3,37972,0);
INSERT INTO "django_geo_db_location" VALUES(65632,NULL,'Second Mesa, AZ',27367,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65633,NULL,'Second Mesa, AZ 86043',27367,222,NULL,3,37973,0);
INSERT INTO "django_geo_db_location" VALUES(65634,NULL,'Tonalea, AZ',27368,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65635,NULL,'Tonalea, AZ 86044',27368,222,NULL,3,37974,0);
INSERT INTO "django_geo_db_location" VALUES(65636,NULL,'Tuba City, AZ',27369,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65637,NULL,'Tuba City, AZ 86045',27369,222,NULL,3,37975,0);
INSERT INTO "django_geo_db_location" VALUES(65638,NULL,'Williams, AZ',27370,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65639,NULL,'Williams, AZ 86046',27370,222,NULL,3,37976,0);
INSERT INTO "django_geo_db_location" VALUES(65640,NULL,'Winslow, AZ',27371,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65641,NULL,'Winslow, AZ 86047',27371,222,NULL,3,37977,0);
INSERT INTO "django_geo_db_location" VALUES(65642,NULL,'North Rim, AZ',27372,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65643,NULL,'North Rim, AZ 86052',27372,222,NULL,3,37978,0);
INSERT INTO "django_geo_db_location" VALUES(65644,NULL,'Kaibito, AZ',27373,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65645,NULL,'Kaibito, AZ 86053',27373,222,NULL,3,37979,0);
INSERT INTO "django_geo_db_location" VALUES(65646,NULL,'Shonto, AZ',27374,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65647,NULL,'Shonto, AZ 86054',27374,222,NULL,3,37980,0);
INSERT INTO "django_geo_db_location" VALUES(65648,NULL,'Bagdad, AZ',27375,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65649,NULL,'Bagdad, AZ 86231',27375,222,NULL,3,37981,0);
INSERT INTO "django_geo_db_location" VALUES(65650,NULL,'Prescott, AZ',27376,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65651,NULL,'Prescott, AZ 86301',27376,222,NULL,3,37982,0);
INSERT INTO "django_geo_db_location" VALUES(65652,NULL,'Prescott, AZ 86302',27376,222,NULL,3,37983,0);
INSERT INTO "django_geo_db_location" VALUES(65653,NULL,'Prescott, AZ 86303',27376,222,NULL,3,37984,0);
INSERT INTO "django_geo_db_location" VALUES(65654,NULL,'Prescott, AZ 86304',27376,222,NULL,3,37985,0);
INSERT INTO "django_geo_db_location" VALUES(65655,NULL,'Prescott, AZ 86305',27376,222,NULL,3,37986,0);
INSERT INTO "django_geo_db_location" VALUES(65656,NULL,'Prescott Valley, AZ',27377,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65657,NULL,'Prescott Valley, AZ 86312',27377,222,NULL,3,37987,0);
INSERT INTO "django_geo_db_location" VALUES(65658,NULL,'Prescott, AZ 86313',27376,222,NULL,3,37988,0);
INSERT INTO "django_geo_db_location" VALUES(65659,NULL,'Prescott Valley, AZ 86314',27377,222,NULL,3,37989,0);
INSERT INTO "django_geo_db_location" VALUES(65660,NULL,'Ash Fork, AZ',27378,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65661,NULL,'Ash Fork, AZ 86320',27378,222,NULL,3,37990,0);
INSERT INTO "django_geo_db_location" VALUES(65662,NULL,'Bagdad, AZ 86321',27375,222,NULL,3,37991,0);
INSERT INTO "django_geo_db_location" VALUES(65663,NULL,'Camp Verde, AZ',27379,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65664,NULL,'Camp Verde, AZ 86322',27379,222,NULL,3,37992,0);
INSERT INTO "django_geo_db_location" VALUES(65665,NULL,'Chino Valley, AZ',27380,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65666,NULL,'Chino Valley, AZ 86323',27380,222,NULL,3,37993,0);
INSERT INTO "django_geo_db_location" VALUES(65667,NULL,'Clarkdale, AZ',27381,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65668,NULL,'Clarkdale, AZ 86324',27381,222,NULL,3,37994,0);
INSERT INTO "django_geo_db_location" VALUES(65669,NULL,'Cornville, AZ',27382,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65670,NULL,'Cornville, AZ 86325',27382,222,NULL,3,37995,0);
INSERT INTO "django_geo_db_location" VALUES(65671,NULL,'Cottonwood, AZ',27383,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65672,NULL,'Cottonwood, AZ 86326',27383,222,NULL,3,37996,0);
INSERT INTO "django_geo_db_location" VALUES(65673,NULL,'Dewey, AZ',27384,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65674,NULL,'Dewey, AZ 86327',27384,222,NULL,3,37997,0);
INSERT INTO "django_geo_db_location" VALUES(65675,NULL,'Humboldt, AZ',27385,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65676,NULL,'Humboldt, AZ 86329',27385,222,NULL,3,37998,0);
INSERT INTO "django_geo_db_location" VALUES(65677,NULL,'Iron Springs, AZ',27386,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65678,NULL,'Iron Springs, AZ 86330',27386,222,NULL,3,37999,0);
INSERT INTO "django_geo_db_location" VALUES(65679,NULL,'Jerome, AZ',27387,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65680,NULL,'Jerome, AZ 86331',27387,222,NULL,3,38000,0);
INSERT INTO "django_geo_db_location" VALUES(65681,NULL,'Kirkland, AZ',27388,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65682,NULL,'Kirkland, AZ 86332',27388,222,NULL,3,38001,0);
INSERT INTO "django_geo_db_location" VALUES(65683,NULL,'Mayer, AZ',27389,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65684,NULL,'Mayer, AZ 86333',27389,222,NULL,3,38002,0);
INSERT INTO "django_geo_db_location" VALUES(65685,NULL,'Paulden, AZ',27390,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65686,NULL,'Paulden, AZ 86334',27390,222,NULL,3,38003,0);
INSERT INTO "django_geo_db_location" VALUES(65687,NULL,'Rimrock, AZ',27391,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65688,NULL,'Rimrock, AZ 86335',27391,222,NULL,3,38004,0);
INSERT INTO "django_geo_db_location" VALUES(65689,NULL,'Sedona, AZ',27392,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65690,NULL,'Sedona, AZ 86336',27392,222,NULL,3,38005,0);
INSERT INTO "django_geo_db_location" VALUES(65691,NULL,'Seligman, AZ',27393,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65692,NULL,'Seligman, AZ 86337',27393,222,NULL,3,38006,0);
INSERT INTO "django_geo_db_location" VALUES(65693,NULL,'Skull Valley, AZ',27394,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65694,NULL,'Skull Valley, AZ 86338',27394,222,NULL,3,38007,0);
INSERT INTO "django_geo_db_location" VALUES(65695,NULL,'Sedona, AZ 86339',27392,222,NULL,3,38008,0);
INSERT INTO "django_geo_db_location" VALUES(65696,NULL,'Sedona, AZ 86340',27392,222,NULL,3,38009,0);
INSERT INTO "django_geo_db_location" VALUES(65697,NULL,'Sedona, AZ 86341',27392,222,NULL,3,38010,0);
INSERT INTO "django_geo_db_location" VALUES(65698,NULL,'Lake Montezuma, AZ',27395,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65699,NULL,'Lake Montezuma, AZ 86342',27395,222,NULL,3,38011,0);
INSERT INTO "django_geo_db_location" VALUES(65700,NULL,'Crown King, AZ',27396,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65701,NULL,'Crown King, AZ 86343',27396,222,NULL,3,38012,0);
INSERT INTO "django_geo_db_location" VALUES(65702,NULL,'Paulden, AZ 86344',27390,222,NULL,3,38013,0);
INSERT INTO "django_geo_db_location" VALUES(65703,NULL,'Sedona, AZ 86351',27392,222,NULL,3,38014,0);
INSERT INTO "django_geo_db_location" VALUES(65704,NULL,'Bagdad, AZ 86361',27375,222,NULL,3,38015,0);
INSERT INTO "django_geo_db_location" VALUES(65705,NULL,'Cottonwood, AZ 86366',27383,222,NULL,3,38016,0);
INSERT INTO "django_geo_db_location" VALUES(65706,NULL,'Kingman, AZ',27397,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65707,NULL,'Kingman, AZ 86401',27397,222,NULL,3,38017,0);
INSERT INTO "django_geo_db_location" VALUES(65708,NULL,'Kingman, AZ 86402',27397,222,NULL,3,38018,0);
INSERT INTO "django_geo_db_location" VALUES(65709,NULL,'Lake Havasu City, AZ',27398,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65710,NULL,'Lake Havasu City, AZ 86403',27398,222,NULL,3,38019,0);
INSERT INTO "django_geo_db_location" VALUES(65711,NULL,'Lake Havasu City, AZ 86404',27398,222,NULL,3,38020,0);
INSERT INTO "django_geo_db_location" VALUES(65712,NULL,'Lake Havasu City, AZ 86405',27398,222,NULL,3,38021,0);
INSERT INTO "django_geo_db_location" VALUES(65713,NULL,'Lake Havasu City, AZ 86406',27398,222,NULL,3,38022,0);
INSERT INTO "django_geo_db_location" VALUES(65714,NULL,'Hackberry, AZ',27399,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65715,NULL,'Hackberry, AZ 86411',27399,222,NULL,3,38023,0);
INSERT INTO "django_geo_db_location" VALUES(65716,NULL,'Hualapai, AZ',27400,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65717,NULL,'Hualapai, AZ 86412',27400,222,NULL,3,38024,0);
INSERT INTO "django_geo_db_location" VALUES(65718,NULL,'Golden Valley, AZ',27401,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65719,NULL,'Golden Valley, AZ 86413',27401,222,NULL,3,38025,0);
INSERT INTO "django_geo_db_location" VALUES(65720,NULL,'Bullhead City, AZ',27402,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65721,NULL,'Bullhead City, AZ 86422',27402,222,NULL,3,38026,0);
INSERT INTO "django_geo_db_location" VALUES(65722,NULL,'Fort Mohave, AZ',27403,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65723,NULL,'Fort Mohave, AZ 86426',27403,222,NULL,3,38027,0);
INSERT INTO "django_geo_db_location" VALUES(65724,NULL,'Fort Mohave, AZ 86427',27403,222,NULL,3,38028,0);
INSERT INTO "django_geo_db_location" VALUES(65725,NULL,'Bullhead City, AZ 86429',27402,222,NULL,3,38029,0);
INSERT INTO "django_geo_db_location" VALUES(65726,NULL,'Bullhead City, AZ 86430',27402,222,NULL,3,38030,0);
INSERT INTO "django_geo_db_location" VALUES(65727,NULL,'Chloride, AZ',27404,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65728,NULL,'Chloride, AZ 86431',27404,222,NULL,3,38031,0);
INSERT INTO "django_geo_db_location" VALUES(65729,NULL,'Littlefield, AZ',27405,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65730,NULL,'Littlefield, AZ 86432',27405,222,NULL,3,38032,0);
INSERT INTO "django_geo_db_location" VALUES(65731,NULL,'Oatman, AZ',27406,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65732,NULL,'Oatman, AZ 86433',27406,222,NULL,3,38033,0);
INSERT INTO "django_geo_db_location" VALUES(65733,NULL,'Peach Springs, AZ',27407,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65734,NULL,'Peach Springs, AZ 86434',27407,222,NULL,3,38034,0);
INSERT INTO "django_geo_db_location" VALUES(65735,NULL,'Supai, AZ',27408,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65736,NULL,'Supai, AZ 86435',27408,222,NULL,3,38035,0);
INSERT INTO "django_geo_db_location" VALUES(65737,NULL,'Topock, AZ',27409,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65738,NULL,'Topock, AZ 86436',27409,222,NULL,3,38036,0);
INSERT INTO "django_geo_db_location" VALUES(65739,NULL,'Valentine, AZ',27410,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65740,NULL,'Valentine, AZ 86437',27410,222,NULL,3,38037,0);
INSERT INTO "django_geo_db_location" VALUES(65741,NULL,'Yucca, AZ',27411,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65742,NULL,'Yucca, AZ 86438',27411,222,NULL,3,38038,0);
INSERT INTO "django_geo_db_location" VALUES(65743,NULL,'Bullhead City, AZ 86439',27402,222,NULL,3,38039,0);
INSERT INTO "django_geo_db_location" VALUES(65744,NULL,'Mohave Valley, AZ',27412,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65745,NULL,'Mohave Valley, AZ 86440',27412,222,NULL,3,38040,0);
INSERT INTO "django_geo_db_location" VALUES(65746,NULL,'Dolan Springs, AZ',27413,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65747,NULL,'Dolan Springs, AZ 86441',27413,222,NULL,3,38041,0);
INSERT INTO "django_geo_db_location" VALUES(65748,NULL,'Bullhead City, AZ 86442',27402,222,NULL,3,38042,0);
INSERT INTO "django_geo_db_location" VALUES(65749,NULL,'Temple Bar Marina, AZ',27414,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65750,NULL,'Temple Bar Marina, AZ 86443',27414,222,NULL,3,38043,0);
INSERT INTO "django_geo_db_location" VALUES(65751,NULL,'Meadview, AZ',27415,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65752,NULL,'Meadview, AZ 86444',27415,222,NULL,3,38044,0);
INSERT INTO "django_geo_db_location" VALUES(65753,NULL,'Willow Beach, AZ',27416,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65754,NULL,'Willow Beach, AZ 86445',27416,222,NULL,3,38045,0);
INSERT INTO "django_geo_db_location" VALUES(65755,NULL,'Mohave Valley, AZ 86446',27412,222,NULL,3,38046,0);
INSERT INTO "django_geo_db_location" VALUES(65756,NULL,'Chambers, AZ',27417,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65757,NULL,'Chambers, AZ 86502',27417,222,NULL,3,38047,0);
INSERT INTO "django_geo_db_location" VALUES(65758,NULL,'Chinle, AZ',27418,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65759,NULL,'Chinle, AZ 86503',27418,222,NULL,3,38048,0);
INSERT INTO "django_geo_db_location" VALUES(65760,NULL,'Fort Defiance, AZ',27419,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65761,NULL,'Fort Defiance, AZ 86504',27419,222,NULL,3,38049,0);
INSERT INTO "django_geo_db_location" VALUES(65762,NULL,'Ganado, AZ',27420,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65763,NULL,'Ganado, AZ 86505',27420,222,NULL,3,38050,0);
INSERT INTO "django_geo_db_location" VALUES(65764,NULL,'Houck, AZ',27421,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65765,NULL,'Houck, AZ 86506',27421,222,NULL,3,38051,0);
INSERT INTO "django_geo_db_location" VALUES(65766,NULL,'Lukachukai, AZ',27422,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65767,NULL,'Lukachukai, AZ 86507',27422,222,NULL,3,38052,0);
INSERT INTO "django_geo_db_location" VALUES(65768,NULL,'Lupton, AZ',27423,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65769,NULL,'Lupton, AZ 86508',27423,222,NULL,3,38053,0);
INSERT INTO "django_geo_db_location" VALUES(65770,NULL,'Pinon, AZ',27424,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65771,NULL,'Pinon, AZ 86510',27424,222,NULL,3,38054,0);
INSERT INTO "django_geo_db_location" VALUES(65772,NULL,'Saint Michaels, AZ',27425,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65773,NULL,'Saint Michaels, AZ 86511',27425,222,NULL,3,38055,0);
INSERT INTO "django_geo_db_location" VALUES(65774,NULL,'Sanders, AZ',27426,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65775,NULL,'Sanders, AZ 86512',27426,222,NULL,3,38056,0);
INSERT INTO "django_geo_db_location" VALUES(65776,NULL,'Teec Nos Pos, AZ',27427,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65777,NULL,'Teec Nos Pos, AZ 86514',27427,222,NULL,3,38057,0);
INSERT INTO "django_geo_db_location" VALUES(65778,NULL,'Window Rock, AZ',27428,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65779,NULL,'Window Rock, AZ 86515',27428,222,NULL,3,38058,0);
INSERT INTO "django_geo_db_location" VALUES(65780,NULL,'Blue Gap, AZ',27429,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65781,NULL,'Blue Gap, AZ 86520',27429,222,NULL,3,38059,0);
INSERT INTO "django_geo_db_location" VALUES(65782,NULL,'Dennehotso, AZ',27430,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65783,NULL,'Dennehotso, AZ 86535',27430,222,NULL,3,38060,0);
INSERT INTO "django_geo_db_location" VALUES(65784,NULL,'Many Farms, AZ',27431,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65785,NULL,'Many Farms, AZ 86538',27431,222,NULL,3,38061,0);
INSERT INTO "django_geo_db_location" VALUES(65786,NULL,'Nazlini, AZ',27432,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65787,NULL,'Nazlini, AZ 86540',27432,222,NULL,3,38062,0);
INSERT INTO "django_geo_db_location" VALUES(65788,NULL,'Red Valley, AZ',27433,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65789,NULL,'Red Valley, AZ 86544',27433,222,NULL,3,38063,0);
INSERT INTO "django_geo_db_location" VALUES(65790,NULL,'Rock Point, AZ',27434,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65791,NULL,'Rock Point, AZ 86545',27434,222,NULL,3,38064,0);
INSERT INTO "django_geo_db_location" VALUES(65792,NULL,'Round Rock, AZ',27435,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65793,NULL,'Round Rock, AZ 86547',27435,222,NULL,3,38065,0);
INSERT INTO "django_geo_db_location" VALUES(65794,NULL,'Sawmill, AZ',27436,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65795,NULL,'Sawmill, AZ 86549',27436,222,NULL,3,38066,0);
INSERT INTO "django_geo_db_location" VALUES(65796,NULL,'Big Park, AZ',27437,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65797,NULL,'Big Park, AZ 86551',27437,222,NULL,3,38067,0);
INSERT INTO "django_geo_db_location" VALUES(65798,NULL,'Tsaile, AZ',27438,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65799,NULL,'Tsaile, AZ 86556',27438,222,NULL,3,38068,0);
INSERT INTO "django_geo_db_location" VALUES(65800,NULL,'Jerome, AZ 86631',27387,222,NULL,3,38069,0);
INSERT INTO "django_geo_db_location" VALUES(65801,NULL,'Algodones, NM',27439,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65802,NULL,'Algodones, NM 87001',27439,222,NULL,31,38070,0);
INSERT INTO "django_geo_db_location" VALUES(65803,NULL,'Belen, NM',27440,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65804,NULL,'Belen, NM 87002',27440,222,NULL,31,38071,0);
INSERT INTO "django_geo_db_location" VALUES(65805,NULL,'Bernalillo, NM',27441,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65806,NULL,'Bernalillo, NM 87004',27441,222,NULL,31,38072,0);
INSERT INTO "django_geo_db_location" VALUES(65807,NULL,'Bluewater, NM',27442,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65808,NULL,'Bluewater, NM 87005',27442,222,NULL,31,38073,0);
INSERT INTO "django_geo_db_location" VALUES(65809,NULL,'Bosque, NM',27443,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65810,NULL,'Bosque, NM 87006',27443,222,NULL,31,38074,0);
INSERT INTO "django_geo_db_location" VALUES(65811,NULL,'Casa Blanca, NM',27444,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65812,NULL,'Casa Blanca, NM 87007',27444,222,NULL,31,38075,0);
INSERT INTO "django_geo_db_location" VALUES(65813,NULL,'Cedar Crest, NM',27445,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65814,NULL,'Cedar Crest, NM 87008',27445,222,NULL,31,38076,0);
INSERT INTO "django_geo_db_location" VALUES(65815,NULL,'Cedarvale, NM',27446,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65816,NULL,'Cedarvale, NM 87009',27446,222,NULL,31,38077,0);
INSERT INTO "django_geo_db_location" VALUES(65817,NULL,'Cerrillos, NM',27447,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65818,NULL,'Cerrillos, NM 87010',27447,222,NULL,31,38078,0);
INSERT INTO "django_geo_db_location" VALUES(65819,NULL,'Claunch, NM',27448,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65820,NULL,'Claunch, NM 87011',27448,222,NULL,31,38079,0);
INSERT INTO "django_geo_db_location" VALUES(65821,NULL,'Coyote, NM',27449,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65822,NULL,'Coyote, NM 87012',27449,222,NULL,31,38080,0);
INSERT INTO "django_geo_db_location" VALUES(65823,NULL,'Cuba, NM',27450,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65824,NULL,'Cuba, NM 87013',27450,222,NULL,31,38081,0);
INSERT INTO "django_geo_db_location" VALUES(65825,NULL,'Cubero, NM',27451,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65826,NULL,'Cubero, NM 87014',27451,222,NULL,31,38082,0);
INSERT INTO "django_geo_db_location" VALUES(65827,NULL,'Edgewood, NM',27452,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65828,NULL,'Edgewood, NM 87015',27452,222,NULL,31,38083,0);
INSERT INTO "django_geo_db_location" VALUES(65829,NULL,'Estancia, NM',27453,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65830,NULL,'Estancia, NM 87016',27453,222,NULL,31,38084,0);
INSERT INTO "django_geo_db_location" VALUES(65831,NULL,'Gallina, NM',27454,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65832,NULL,'Gallina, NM 87017',27454,222,NULL,31,38085,0);
INSERT INTO "django_geo_db_location" VALUES(65833,NULL,'Counselor, NM',27455,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65834,NULL,'Counselor, NM 87018',27455,222,NULL,31,38086,0);
INSERT INTO "django_geo_db_location" VALUES(65835,NULL,'Grants, NM',27456,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65836,NULL,'Grants, NM 87020',27456,222,NULL,31,38087,0);
INSERT INTO "django_geo_db_location" VALUES(65837,NULL,'Milan, NM',27457,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65838,NULL,'Milan, NM 87021',27457,222,NULL,31,38088,0);
INSERT INTO "django_geo_db_location" VALUES(65839,NULL,'Isleta, NM',27458,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65840,NULL,'Isleta, NM 87022',27458,222,NULL,31,38089,0);
INSERT INTO "django_geo_db_location" VALUES(65841,NULL,'Jarales, NM',27459,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65842,NULL,'Jarales, NM 87023',27459,222,NULL,31,38090,0);
INSERT INTO "django_geo_db_location" VALUES(65843,NULL,'Jemez Pueblo, NM',27460,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65844,NULL,'Jemez Pueblo, NM 87024',27460,222,NULL,31,38091,0);
INSERT INTO "django_geo_db_location" VALUES(65845,NULL,'Jemez Springs, NM',27461,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65846,NULL,'Jemez Springs, NM 87025',27461,222,NULL,31,38092,0);
INSERT INTO "django_geo_db_location" VALUES(65847,NULL,'Laguna, NM',27462,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65848,NULL,'Laguna, NM 87026',27462,222,NULL,31,38093,0);
INSERT INTO "django_geo_db_location" VALUES(65849,NULL,'La Jara, NM',27463,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65850,NULL,'La Jara, NM 87027',27463,222,NULL,31,38094,0);
INSERT INTO "django_geo_db_location" VALUES(65851,NULL,'La Joya, NM',27464,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65852,NULL,'La Joya, NM 87028',27464,222,NULL,31,38095,0);
INSERT INTO "django_geo_db_location" VALUES(65853,NULL,'Lindrith, NM',27465,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65854,NULL,'Lindrith, NM 87029',27465,222,NULL,31,38096,0);
INSERT INTO "django_geo_db_location" VALUES(65855,NULL,'Los Lunas, NM',27466,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65856,NULL,'Los Lunas, NM 87031',27466,222,NULL,31,38097,0);
INSERT INTO "django_geo_db_location" VALUES(65857,NULL,'McIntosh, NM',27467,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65858,NULL,'McIntosh, NM 87032',27467,222,NULL,31,38098,0);
INSERT INTO "django_geo_db_location" VALUES(65859,NULL,'Pueblo Of Acoma, NM',27468,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65860,NULL,'Pueblo Of Acoma, NM 87034',27468,222,NULL,31,38099,0);
INSERT INTO "django_geo_db_location" VALUES(65861,NULL,'Moriarty, NM',27469,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65862,NULL,'Moriarty, NM 87035',27469,222,NULL,31,38100,0);
INSERT INTO "django_geo_db_location" VALUES(65863,NULL,'Mountainair, NM',27470,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65864,NULL,'Mountainair, NM 87036',27470,222,NULL,31,38101,0);
INSERT INTO "django_geo_db_location" VALUES(65865,NULL,'Nageezi, NM',27471,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65866,NULL,'Nageezi, NM 87037',27471,222,NULL,31,38102,0);
INSERT INTO "django_geo_db_location" VALUES(65867,NULL,'New Laguna, NM',27472,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65868,NULL,'New Laguna, NM 87038',27472,222,NULL,31,38103,0);
INSERT INTO "django_geo_db_location" VALUES(65869,NULL,'Paguate, NM',27473,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65870,NULL,'Paguate, NM 87040',27473,222,NULL,31,38104,0);
INSERT INTO "django_geo_db_location" VALUES(65871,NULL,'Pena Blanca, NM',27474,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65872,NULL,'Pena Blanca, NM 87041',27474,222,NULL,31,38105,0);
INSERT INTO "django_geo_db_location" VALUES(65873,NULL,'Peralta, NM',27475,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65874,NULL,'Peralta, NM 87042',27475,222,NULL,31,38106,0);
INSERT INTO "django_geo_db_location" VALUES(65875,NULL,'Placitas, NM',27476,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65876,NULL,'Placitas, NM 87043',27476,222,NULL,31,38107,0);
INSERT INTO "django_geo_db_location" VALUES(65877,NULL,'Ponderosa, NM',27477,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65878,NULL,'Ponderosa, NM 87044',27477,222,NULL,31,38108,0);
INSERT INTO "django_geo_db_location" VALUES(65879,NULL,'Prewitt, NM',27478,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65880,NULL,'Prewitt, NM 87045',27478,222,NULL,31,38109,0);
INSERT INTO "django_geo_db_location" VALUES(65881,NULL,'Regina, NM',27479,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65882,NULL,'Regina, NM 87046',27479,222,NULL,31,38110,0);
INSERT INTO "django_geo_db_location" VALUES(65883,NULL,'Sandia Park, NM',27480,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65884,NULL,'Sandia Park, NM 87047',27480,222,NULL,31,38111,0);
INSERT INTO "django_geo_db_location" VALUES(65885,NULL,'Corrales, NM',27481,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65886,NULL,'Corrales, NM 87048',27481,222,NULL,31,38112,0);
INSERT INTO "django_geo_db_location" VALUES(65887,NULL,'San Fidel, NM',27482,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65888,NULL,'San Fidel, NM 87049',27482,222,NULL,31,38113,0);
INSERT INTO "django_geo_db_location" VALUES(65889,NULL,'San Rafael, NM',27483,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65890,NULL,'San Rafael, NM 87051',27483,222,NULL,31,38114,0);
INSERT INTO "django_geo_db_location" VALUES(65891,NULL,'Santo Domingo Pueblo, NM',27484,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65892,NULL,'Santo Domingo Pueblo, NM 87052',27484,222,NULL,31,38115,0);
INSERT INTO "django_geo_db_location" VALUES(65893,NULL,'San Ysidro, NM',27485,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65894,NULL,'San Ysidro, NM 87053',27485,222,NULL,31,38116,0);
INSERT INTO "django_geo_db_location" VALUES(65895,NULL,'Stanley, NM',27486,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65896,NULL,'Stanley, NM 87056',27486,222,NULL,31,38117,0);
INSERT INTO "django_geo_db_location" VALUES(65897,NULL,'Tajique, NM',27487,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65898,NULL,'Tajique, NM 87057',27487,222,NULL,31,38118,0);
INSERT INTO "django_geo_db_location" VALUES(65899,NULL,'Tijeras, NM',27488,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65900,NULL,'Tijeras, NM 87059',27488,222,NULL,31,38119,0);
INSERT INTO "django_geo_db_location" VALUES(65901,NULL,'Tome, NM',27489,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65902,NULL,'Tome, NM 87060',27489,222,NULL,31,38120,0);
INSERT INTO "django_geo_db_location" VALUES(65903,NULL,'Torreon, NM',27490,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65904,NULL,'Torreon, NM 87061',27490,222,NULL,31,38121,0);
INSERT INTO "django_geo_db_location" VALUES(65905,NULL,'Veguita, NM',27491,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65906,NULL,'Veguita, NM 87062',27491,222,NULL,31,38122,0);
INSERT INTO "django_geo_db_location" VALUES(65907,NULL,'Willard, NM',27492,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65908,NULL,'Willard, NM 87063',27492,222,NULL,31,38123,0);
INSERT INTO "django_geo_db_location" VALUES(65909,NULL,'Youngsville, NM',27493,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65910,NULL,'Youngsville, NM 87064',27493,222,NULL,31,38124,0);
INSERT INTO "django_geo_db_location" VALUES(65911,NULL,'Bosque Farms, NM',27494,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65912,NULL,'Bosque Farms, NM 87068',27494,222,NULL,31,38125,0);
INSERT INTO "django_geo_db_location" VALUES(65913,NULL,'Clines Corners, NM',27495,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65914,NULL,'Clines Corners, NM 87070',27495,222,NULL,31,38126,0);
INSERT INTO "django_geo_db_location" VALUES(65915,NULL,'Cochiti Pueblo, NM',27496,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65916,NULL,'Cochiti Pueblo, NM 87072',27496,222,NULL,31,38127,0);
INSERT INTO "django_geo_db_location" VALUES(65917,NULL,'Cochiti Lake, NM',27497,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65918,NULL,'Cochiti Lake, NM 87083',27497,222,NULL,31,38128,0);
INSERT INTO "django_geo_db_location" VALUES(65919,NULL,'Albuquerque, NM',27498,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65920,NULL,'Albuquerque, NM 87101',27498,222,NULL,31,38129,0);
INSERT INTO "django_geo_db_location" VALUES(65921,NULL,'Albuquerque, NM 87102',27498,222,NULL,31,38130,0);
INSERT INTO "django_geo_db_location" VALUES(65922,NULL,'Albuquerque, NM 87103',27498,222,NULL,31,38131,0);
INSERT INTO "django_geo_db_location" VALUES(65923,NULL,'Albuquerque, NM 87104',27498,222,NULL,31,38132,0);
INSERT INTO "django_geo_db_location" VALUES(65924,NULL,'Albuquerque, NM 87105',27498,222,NULL,31,38133,0);
INSERT INTO "django_geo_db_location" VALUES(65925,NULL,'Albuquerque, NM 87106',27498,222,NULL,31,38134,0);
INSERT INTO "django_geo_db_location" VALUES(65926,NULL,'Albuquerque, NM 87107',27498,222,NULL,31,38135,0);
INSERT INTO "django_geo_db_location" VALUES(65927,NULL,'Albuquerque, NM 87108',27498,222,NULL,31,38136,0);
INSERT INTO "django_geo_db_location" VALUES(65928,NULL,'Albuquerque, NM 87109',27498,222,NULL,31,38137,0);
INSERT INTO "django_geo_db_location" VALUES(65929,NULL,'Albuquerque, NM 87110',27498,222,NULL,31,38138,0);
INSERT INTO "django_geo_db_location" VALUES(65930,NULL,'Albuquerque, NM 87111',27498,222,NULL,31,38139,0);
INSERT INTO "django_geo_db_location" VALUES(65931,NULL,'Albuquerque, NM 87112',27498,222,NULL,31,38140,0);
INSERT INTO "django_geo_db_location" VALUES(65932,NULL,'Albuquerque, NM 87113',27498,222,NULL,31,38141,0);
INSERT INTO "django_geo_db_location" VALUES(65933,NULL,'Albuquerque, NM 87114',27498,222,NULL,31,38142,0);
INSERT INTO "django_geo_db_location" VALUES(65934,NULL,'Albuquerque, NM 87115',27498,222,NULL,31,38143,0);
INSERT INTO "django_geo_db_location" VALUES(65935,NULL,'Albuquerque, NM 87116',27498,222,NULL,31,38144,0);
INSERT INTO "django_geo_db_location" VALUES(65936,NULL,'Kirtland AFB, NM',27499,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65937,NULL,'Kirtland AFB, NM 87117',27499,222,NULL,31,38145,0);
INSERT INTO "django_geo_db_location" VALUES(65938,NULL,'Albuquerque, NM 87118',27498,222,NULL,31,38146,0);
INSERT INTO "django_geo_db_location" VALUES(65939,NULL,'Albuquerque, NM 87119',27498,222,NULL,31,38147,0);
INSERT INTO "django_geo_db_location" VALUES(65940,NULL,'Albuquerque, NM 87120',27498,222,NULL,31,38148,0);
INSERT INTO "django_geo_db_location" VALUES(65941,NULL,'Albuquerque, NM 87121',27498,222,NULL,31,38149,0);
INSERT INTO "django_geo_db_location" VALUES(65942,NULL,'Albuquerque, NM 87122',27498,222,NULL,31,38150,0);
INSERT INTO "django_geo_db_location" VALUES(65943,NULL,'Albuquerque, NM 87123',27498,222,NULL,31,38151,0);
INSERT INTO "django_geo_db_location" VALUES(65944,NULL,'Rio Rancho, NM',27500,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65945,NULL,'Rio Rancho, NM 87124',27500,222,NULL,31,38152,0);
INSERT INTO "django_geo_db_location" VALUES(65946,NULL,'Albuquerque, NM 87125',27498,222,NULL,31,38153,0);
INSERT INTO "django_geo_db_location" VALUES(65947,NULL,'Albuquerque, NM 87131',27498,222,NULL,31,38154,0);
INSERT INTO "django_geo_db_location" VALUES(65948,NULL,'Albuquerque, NM 87140',27498,222,NULL,31,38155,0);
INSERT INTO "django_geo_db_location" VALUES(65949,NULL,'Rio Rancho, NM 87144',27500,222,NULL,31,38156,0);
INSERT INTO "django_geo_db_location" VALUES(65950,NULL,'Albuquerque, NM 87153',27498,222,NULL,31,38157,0);
INSERT INTO "django_geo_db_location" VALUES(65951,NULL,'Albuquerque, NM 87154',27498,222,NULL,31,38158,0);
INSERT INTO "django_geo_db_location" VALUES(65952,NULL,'Albuquerque, NM 87158',27498,222,NULL,31,38159,0);
INSERT INTO "django_geo_db_location" VALUES(65953,NULL,'Rio Rancho, NM 87174',27500,222,NULL,31,38160,0);
INSERT INTO "django_geo_db_location" VALUES(65954,NULL,'Albuquerque, NM 87176',27498,222,NULL,31,38161,0);
INSERT INTO "django_geo_db_location" VALUES(65955,NULL,'Albuquerque, NM 87180',27498,222,NULL,31,38162,0);
INSERT INTO "django_geo_db_location" VALUES(65956,NULL,'Albuquerque, NM 87181',27498,222,NULL,31,38163,0);
INSERT INTO "django_geo_db_location" VALUES(65957,NULL,'Albuquerque, NM 87184',27498,222,NULL,31,38164,0);
INSERT INTO "django_geo_db_location" VALUES(65958,NULL,'Albuquerque, NM 87185',27498,222,NULL,31,38165,0);
INSERT INTO "django_geo_db_location" VALUES(65959,NULL,'Albuquerque, NM 87187',27498,222,NULL,31,38166,0);
INSERT INTO "django_geo_db_location" VALUES(65960,NULL,'Albuquerque, NM 87190',27498,222,NULL,31,38167,0);
INSERT INTO "django_geo_db_location" VALUES(65961,NULL,'Albuquerque, NM 87191',27498,222,NULL,31,38168,0);
INSERT INTO "django_geo_db_location" VALUES(65962,NULL,'Albuquerque, NM 87192',27498,222,NULL,31,38169,0);
INSERT INTO "django_geo_db_location" VALUES(65963,NULL,'Albuquerque, NM 87193',27498,222,NULL,31,38170,0);
INSERT INTO "django_geo_db_location" VALUES(65964,NULL,'Albuquerque, NM 87194',27498,222,NULL,31,38171,0);
INSERT INTO "django_geo_db_location" VALUES(65965,NULL,'Albuquerque, NM 87195',27498,222,NULL,31,38172,0);
INSERT INTO "django_geo_db_location" VALUES(65966,NULL,'Albuquerque, NM 87196',27498,222,NULL,31,38173,0);
INSERT INTO "django_geo_db_location" VALUES(65967,NULL,'Albuquerque, NM 87197',27498,222,NULL,31,38174,0);
INSERT INTO "django_geo_db_location" VALUES(65968,NULL,'Albuquerque, NM 87198',27498,222,NULL,31,38175,0);
INSERT INTO "django_geo_db_location" VALUES(65969,NULL,'Albuquerque, NM 87199',27498,222,NULL,31,38176,0);
INSERT INTO "django_geo_db_location" VALUES(65970,NULL,'Albuquerque, NM 87201',27498,222,NULL,31,38177,0);
INSERT INTO "django_geo_db_location" VALUES(65971,NULL,'Gallup, NM',27501,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65972,NULL,'Gallup, NM 87301',27501,222,NULL,31,38178,0);
INSERT INTO "django_geo_db_location" VALUES(65973,NULL,'Gallup, NM 87302',27501,222,NULL,31,38179,0);
INSERT INTO "django_geo_db_location" VALUES(65974,NULL,'Gallup, NM 87305',27501,222,NULL,31,38180,0);
INSERT INTO "django_geo_db_location" VALUES(65975,NULL,'Brimhall, NM',27502,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65976,NULL,'Brimhall, NM 87310',27502,222,NULL,31,38181,0);
INSERT INTO "django_geo_db_location" VALUES(65977,NULL,'Church Rock, NM',27503,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65978,NULL,'Church Rock, NM 87311',27503,222,NULL,31,38182,0);
INSERT INTO "django_geo_db_location" VALUES(65979,NULL,'Continental Divide, NM',27504,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65980,NULL,'Continental Divide, NM 87312',27504,222,NULL,31,38183,0);
INSERT INTO "django_geo_db_location" VALUES(65981,NULL,'Crownpoint, NM',27505,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65982,NULL,'Crownpoint, NM 87313',27505,222,NULL,31,38184,0);
INSERT INTO "django_geo_db_location" VALUES(65983,NULL,'Fence Lake, NM',27506,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65984,NULL,'Fence Lake, NM 87315',27506,222,NULL,31,38185,0);
INSERT INTO "django_geo_db_location" VALUES(65985,NULL,'Fort Wingate, NM',27507,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65986,NULL,'Fort Wingate, NM 87316',27507,222,NULL,31,38186,0);
INSERT INTO "django_geo_db_location" VALUES(65987,NULL,'Gamerco, NM',27508,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65988,NULL,'Gamerco, NM 87317',27508,222,NULL,31,38187,0);
INSERT INTO "django_geo_db_location" VALUES(65989,NULL,'Mentmore, NM',27509,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65990,NULL,'Mentmore, NM 87319',27509,222,NULL,31,38188,0);
INSERT INTO "django_geo_db_location" VALUES(65991,NULL,'Mexican Springs, NM',27510,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65992,NULL,'Mexican Springs, NM 87320',27510,222,NULL,31,38189,0);
INSERT INTO "django_geo_db_location" VALUES(65993,NULL,'Ramah, NM',27511,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65994,NULL,'Ramah, NM 87321',27511,222,NULL,31,38190,0);
INSERT INTO "django_geo_db_location" VALUES(65995,NULL,'Rehoboth, NM',27512,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65996,NULL,'Rehoboth, NM 87322',27512,222,NULL,31,38191,0);
INSERT INTO "django_geo_db_location" VALUES(65997,NULL,'Thoreau, NM',27513,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(65998,NULL,'Thoreau, NM 87323',27513,222,NULL,31,38192,0);
INSERT INTO "django_geo_db_location" VALUES(65999,NULL,'Tohatchi, NM',27514,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66000,NULL,'Tohatchi, NM 87325',27514,222,NULL,31,38193,0);
INSERT INTO "django_geo_db_location" VALUES(66001,NULL,'Vanderwagen, NM',27515,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66002,NULL,'Vanderwagen, NM 87326',27515,222,NULL,31,38194,0);
INSERT INTO "django_geo_db_location" VALUES(66003,NULL,'Zuni, NM',27516,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66004,NULL,'Zuni, NM 87327',27516,222,NULL,31,38195,0);
INSERT INTO "django_geo_db_location" VALUES(66005,NULL,'Navajo, AZ',27517,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66006,NULL,'Navajo, AZ 87328',27517,222,NULL,3,38196,0);
INSERT INTO "django_geo_db_location" VALUES(66007,NULL,'Jamestown, NM',27518,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66008,NULL,'Jamestown, NM 87347',27518,222,NULL,31,38197,0);
INSERT INTO "django_geo_db_location" VALUES(66009,NULL,'Pinehill, NM',27519,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66010,NULL,'Pinehill, NM 87357',27519,222,NULL,31,38198,0);
INSERT INTO "django_geo_db_location" VALUES(66011,NULL,'Sheep Springs, NM',27520,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66012,NULL,'Sheep Springs, NM 87364',27520,222,NULL,31,38199,0);
INSERT INTO "django_geo_db_location" VALUES(66013,NULL,'Smith Lake, NM',27521,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66014,NULL,'Smith Lake, NM 87365',27521,222,NULL,31,38200,0);
INSERT INTO "django_geo_db_location" VALUES(66015,NULL,'Yatahey, NM',27522,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66016,NULL,'Yatahey, NM 87375',27522,222,NULL,31,38201,0);
INSERT INTO "django_geo_db_location" VALUES(66017,NULL,'Navajo, NM',27523,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66018,NULL,'Navajo, NM 87378',27523,222,NULL,31,38202,0);
INSERT INTO "django_geo_db_location" VALUES(66019,NULL,'Farmington, NM',27524,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66020,NULL,'Farmington, NM 87401',27524,222,NULL,31,38203,0);
INSERT INTO "django_geo_db_location" VALUES(66021,NULL,'Farmington, NM 87402',27524,222,NULL,31,38204,0);
INSERT INTO "django_geo_db_location" VALUES(66022,NULL,'Aztec, NM',27525,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66023,NULL,'Aztec, NM 87410',27525,222,NULL,31,38205,0);
INSERT INTO "django_geo_db_location" VALUES(66024,NULL,'Blanco, NM',27526,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66025,NULL,'Blanco, NM 87412',27526,222,NULL,31,38206,0);
INSERT INTO "django_geo_db_location" VALUES(66026,NULL,'Bloomfield, NM',27527,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66027,NULL,'Bloomfield, NM 87413',27527,222,NULL,31,38207,0);
INSERT INTO "django_geo_db_location" VALUES(66028,NULL,'Flora Vista, NM',27528,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66029,NULL,'Flora Vista, NM 87415',27528,222,NULL,31,38208,0);
INSERT INTO "django_geo_db_location" VALUES(66030,NULL,'Fruitland, NM',27529,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66031,NULL,'Fruitland, NM 87416',27529,222,NULL,31,38209,0);
INSERT INTO "django_geo_db_location" VALUES(66032,NULL,'Kirtland, NM',27530,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66033,NULL,'Kirtland, NM 87417',27530,222,NULL,31,38210,0);
INSERT INTO "django_geo_db_location" VALUES(66034,NULL,'La Plata, NM',27531,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66035,NULL,'La Plata, NM 87418',27531,222,NULL,31,38211,0);
INSERT INTO "django_geo_db_location" VALUES(66036,NULL,'Navajo Dam, NM',27532,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66037,NULL,'Navajo Dam, NM 87419',27532,222,NULL,31,38212,0);
INSERT INTO "django_geo_db_location" VALUES(66038,NULL,'Shiprock, NM',27533,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66039,NULL,'Shiprock, NM 87420',27533,222,NULL,31,38213,0);
INSERT INTO "django_geo_db_location" VALUES(66040,NULL,'Waterflow, NM',27534,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66041,NULL,'Waterflow, NM 87421',27534,222,NULL,31,38214,0);
INSERT INTO "django_geo_db_location" VALUES(66042,NULL,'Newcomb, NM',27535,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66043,NULL,'Newcomb, NM 87455',27535,222,NULL,31,38215,0);
INSERT INTO "django_geo_db_location" VALUES(66044,NULL,'Sanostee, NM',27536,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66045,NULL,'Sanostee, NM 87461',27536,222,NULL,31,38216,0);
INSERT INTO "django_geo_db_location" VALUES(66046,NULL,'Farmington, NM 87499',27524,222,NULL,31,38217,0);
INSERT INTO "django_geo_db_location" VALUES(66047,NULL,'Santa Fe, NM',27537,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66048,NULL,'Santa Fe, NM 87501',27537,222,NULL,31,38218,0);
INSERT INTO "django_geo_db_location" VALUES(66049,NULL,'Santa Fe, NM 87502',27537,222,NULL,31,38219,0);
INSERT INTO "django_geo_db_location" VALUES(66050,NULL,'Santa Fe, NM 87503',27537,222,NULL,31,38220,0);
INSERT INTO "django_geo_db_location" VALUES(66051,NULL,'Santa Fe, NM 87504',27537,222,NULL,31,38221,0);
INSERT INTO "django_geo_db_location" VALUES(66052,NULL,'Santa Fe, NM 87505',27537,222,NULL,31,38222,0);
INSERT INTO "django_geo_db_location" VALUES(66053,NULL,'Santa Fe, NM 87506',27537,222,NULL,31,38223,0);
INSERT INTO "django_geo_db_location" VALUES(66054,NULL,'Santa Fe, NM 87507',27537,222,NULL,31,38224,0);
INSERT INTO "django_geo_db_location" VALUES(66055,NULL,'Santa Fe, NM 87508',27537,222,NULL,31,38225,0);
INSERT INTO "django_geo_db_location" VALUES(66056,NULL,'Santa Fe, NM 87509',27537,222,NULL,31,38226,0);
INSERT INTO "django_geo_db_location" VALUES(66057,NULL,'Abiquiu, NM',27538,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66058,NULL,'Abiquiu, NM 87510',27538,222,NULL,31,38227,0);
INSERT INTO "django_geo_db_location" VALUES(66059,NULL,'Alcalde, NM',27539,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66060,NULL,'Alcalde, NM 87511',27539,222,NULL,31,38228,0);
INSERT INTO "django_geo_db_location" VALUES(66061,NULL,'Amalia, NM',27540,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66062,NULL,'Amalia, NM 87512',27540,222,NULL,31,38229,0);
INSERT INTO "django_geo_db_location" VALUES(66063,NULL,'Arroyo Hondo, NM',27541,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66064,NULL,'Arroyo Hondo, NM 87513',27541,222,NULL,31,38230,0);
INSERT INTO "django_geo_db_location" VALUES(66065,NULL,'Arroyo Seco, NM',27542,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66066,NULL,'Arroyo Seco, NM 87514',27542,222,NULL,31,38231,0);
INSERT INTO "django_geo_db_location" VALUES(66067,NULL,'Canjilon, NM',27543,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66068,NULL,'Canjilon, NM 87515',27543,222,NULL,31,38232,0);
INSERT INTO "django_geo_db_location" VALUES(66069,NULL,'Canones, NM',27544,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66070,NULL,'Canones, NM 87516',27544,222,NULL,31,38233,0);
INSERT INTO "django_geo_db_location" VALUES(66071,NULL,'Carson, NM',27545,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66072,NULL,'Carson, NM 87517',27545,222,NULL,31,38234,0);
INSERT INTO "django_geo_db_location" VALUES(66073,NULL,'Cebolla, NM',27546,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66074,NULL,'Cebolla, NM 87518',27546,222,NULL,31,38235,0);
INSERT INTO "django_geo_db_location" VALUES(66075,NULL,'Cerro, NM',27547,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66076,NULL,'Cerro, NM 87519',27547,222,NULL,31,38236,0);
INSERT INTO "django_geo_db_location" VALUES(66077,NULL,'Chama, NM',27548,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66078,NULL,'Chama, NM 87520',27548,222,NULL,31,38237,0);
INSERT INTO "django_geo_db_location" VALUES(66079,NULL,'Chamisal, NM',27549,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66080,NULL,'Chamisal, NM 87521',27549,222,NULL,31,38238,0);
INSERT INTO "django_geo_db_location" VALUES(66081,NULL,'Chimayo, NM',27550,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66082,NULL,'Chimayo, NM 87522',27550,222,NULL,31,38239,0);
INSERT INTO "django_geo_db_location" VALUES(66083,NULL,'Cordova, NM',27551,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66084,NULL,'Cordova, NM 87523',27551,222,NULL,31,38240,0);
INSERT INTO "django_geo_db_location" VALUES(66085,NULL,'Costilla, NM',27552,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66086,NULL,'Costilla, NM 87524',27552,222,NULL,31,38241,0);
INSERT INTO "django_geo_db_location" VALUES(66087,NULL,'Taos Ski Valley, NM',27553,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66088,NULL,'Taos Ski Valley, NM 87525',27553,222,NULL,31,38242,0);
INSERT INTO "django_geo_db_location" VALUES(66089,NULL,'Dixon, NM',27554,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66090,NULL,'Dixon, NM 87527',27554,222,NULL,31,38243,0);
INSERT INTO "django_geo_db_location" VALUES(66091,NULL,'Dulce, NM',27555,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66092,NULL,'Dulce, NM 87528',27555,222,NULL,31,38244,0);
INSERT INTO "django_geo_db_location" VALUES(66093,NULL,'El Prado, NM',27556,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66094,NULL,'El Prado, NM 87529',27556,222,NULL,31,38245,0);
INSERT INTO "django_geo_db_location" VALUES(66095,NULL,'El Rito, NM',27557,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66096,NULL,'El Rito, NM 87530',27557,222,NULL,31,38246,0);
INSERT INTO "django_geo_db_location" VALUES(66097,NULL,'Embudo, NM',27558,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66098,NULL,'Embudo, NM 87531',27558,222,NULL,31,38247,0);
INSERT INTO "django_geo_db_location" VALUES(66099,NULL,'Espanola, NM',27559,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66100,NULL,'Espanola, NM 87532',27559,222,NULL,31,38248,0);
INSERT INTO "django_geo_db_location" VALUES(66101,NULL,'Espanola, NM 87533',27559,222,NULL,31,38249,0);
INSERT INTO "django_geo_db_location" VALUES(66102,NULL,'Glorieta, NM',27560,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66103,NULL,'Glorieta, NM 87535',27560,222,NULL,31,38250,0);
INSERT INTO "django_geo_db_location" VALUES(66104,NULL,'Hernandez, NM',27561,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66105,NULL,'Hernandez, NM 87537',27561,222,NULL,31,38251,0);
INSERT INTO "django_geo_db_location" VALUES(66106,NULL,'Ilfeld, NM',27562,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66107,NULL,'Ilfeld, NM 87538',27562,222,NULL,31,38252,0);
INSERT INTO "django_geo_db_location" VALUES(66108,NULL,'La Madera, NM',27563,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66109,NULL,'La Madera, NM 87539',27563,222,NULL,31,38253,0);
INSERT INTO "django_geo_db_location" VALUES(66110,NULL,'Lamy, NM',27564,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66111,NULL,'Lamy, NM 87540',27564,222,NULL,31,38254,0);
INSERT INTO "django_geo_db_location" VALUES(66112,NULL,'Llano, NM',27565,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66113,NULL,'Llano, NM 87543',27565,222,NULL,31,38255,0);
INSERT INTO "django_geo_db_location" VALUES(66114,NULL,'Los Alamos, NM',27566,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66115,NULL,'Los Alamos, NM 87544',27566,222,NULL,31,38256,0);
INSERT INTO "django_geo_db_location" VALUES(66116,NULL,'Los Alamos, NM 87545',27566,222,NULL,31,38257,0);
INSERT INTO "django_geo_db_location" VALUES(66117,NULL,'Medanales, NM',27567,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66118,NULL,'Medanales, NM 87548',27567,222,NULL,31,38258,0);
INSERT INTO "django_geo_db_location" VALUES(66119,NULL,'Ojo Caliente, NM',27568,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66120,NULL,'Ojo Caliente, NM 87549',27568,222,NULL,31,38259,0);
INSERT INTO "django_geo_db_location" VALUES(66121,NULL,'Los Ojos, NM',27569,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66122,NULL,'Los Ojos, NM 87551',27569,222,NULL,31,38260,0);
INSERT INTO "django_geo_db_location" VALUES(66123,NULL,'Pecos, NM',27570,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66124,NULL,'Pecos, NM 87552',27570,222,NULL,31,38261,0);
INSERT INTO "django_geo_db_location" VALUES(66125,NULL,'Penasco, NM',27571,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66126,NULL,'Penasco, NM 87553',27571,222,NULL,31,38262,0);
INSERT INTO "django_geo_db_location" VALUES(66127,NULL,'Petaca, NM',27572,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66128,NULL,'Petaca, NM 87554',27572,222,NULL,31,38263,0);
INSERT INTO "django_geo_db_location" VALUES(66129,NULL,'Questa, NM',27573,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66130,NULL,'Questa, NM 87556',27573,222,NULL,31,38264,0);
INSERT INTO "django_geo_db_location" VALUES(66131,NULL,'Ranchos De Taos, NM',27574,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66132,NULL,'Ranchos De Taos, NM 87557',27574,222,NULL,31,38265,0);
INSERT INTO "django_geo_db_location" VALUES(66133,NULL,'Red River, NM',27575,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66134,NULL,'Red River, NM 87558',27575,222,NULL,31,38266,0);
INSERT INTO "django_geo_db_location" VALUES(66135,NULL,'Ribera, NM',27576,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66136,NULL,'Ribera, NM 87560',27576,222,NULL,31,38267,0);
INSERT INTO "django_geo_db_location" VALUES(66137,NULL,'Rowe, NM',27577,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66138,NULL,'Rowe, NM 87562',27577,222,NULL,31,38268,0);
INSERT INTO "django_geo_db_location" VALUES(66139,NULL,'San Cristobal, NM',27578,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66140,NULL,'San Cristobal, NM 87564',27578,222,NULL,31,38269,0);
INSERT INTO "django_geo_db_location" VALUES(66141,NULL,'San Jose, NM',27579,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66142,NULL,'San Jose, NM 87565',27579,222,NULL,31,38270,0);
INSERT INTO "django_geo_db_location" VALUES(66143,NULL,'San Juan Pueblo, NM',27580,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66144,NULL,'San Juan Pueblo, NM 87566',27580,222,NULL,31,38271,0);
INSERT INTO "django_geo_db_location" VALUES(66145,NULL,'Santa Cruz, NM',27581,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66146,NULL,'Santa Cruz, NM 87567',27581,222,NULL,31,38272,0);
INSERT INTO "django_geo_db_location" VALUES(66147,NULL,'Serafina, NM',27582,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66148,NULL,'Serafina, NM 87569',27582,222,NULL,31,38273,0);
INSERT INTO "django_geo_db_location" VALUES(66149,NULL,'Taos, NM',27583,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66150,NULL,'Taos, NM 87571',27583,222,NULL,31,38274,0);
INSERT INTO "django_geo_db_location" VALUES(66151,NULL,'Tererro, NM',27584,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66152,NULL,'Tererro, NM 87573',27584,222,NULL,31,38275,0);
INSERT INTO "django_geo_db_location" VALUES(66153,NULL,'Tesuque, NM',27585,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66154,NULL,'Tesuque, NM 87574',27585,222,NULL,31,38276,0);
INSERT INTO "django_geo_db_location" VALUES(66155,NULL,'Tierra Amarilla, NM',27586,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66156,NULL,'Tierra Amarilla, NM 87575',27586,222,NULL,31,38277,0);
INSERT INTO "django_geo_db_location" VALUES(66157,NULL,'Trampas, NM',27587,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66158,NULL,'Trampas, NM 87576',27587,222,NULL,31,38278,0);
INSERT INTO "django_geo_db_location" VALUES(66159,NULL,'Tres Piedras, NM',27588,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66160,NULL,'Tres Piedras, NM 87577',27588,222,NULL,31,38279,0);
INSERT INTO "django_geo_db_location" VALUES(66161,NULL,'Truchas, NM',27589,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66162,NULL,'Truchas, NM 87578',27589,222,NULL,31,38280,0);
INSERT INTO "django_geo_db_location" VALUES(66163,NULL,'Vadito, NM',27590,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66164,NULL,'Vadito, NM 87579',27590,222,NULL,31,38281,0);
INSERT INTO "django_geo_db_location" VALUES(66165,NULL,'Valdez, NM',27591,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66166,NULL,'Valdez, NM 87580',27591,222,NULL,31,38282,0);
INSERT INTO "django_geo_db_location" VALUES(66167,NULL,'Vallecitos, NM',27592,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66168,NULL,'Vallecitos, NM 87581',27592,222,NULL,31,38283,0);
INSERT INTO "django_geo_db_location" VALUES(66169,NULL,'Velarde, NM',27593,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66170,NULL,'Velarde, NM 87582',27593,222,NULL,31,38284,0);
INSERT INTO "django_geo_db_location" VALUES(66171,NULL,'Villanueva, NM',27594,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66172,NULL,'Villanueva, NM 87583',27594,222,NULL,31,38285,0);
INSERT INTO "django_geo_db_location" VALUES(66173,NULL,'Santa Fe, NM 87585',27537,222,NULL,31,38286,0);
INSERT INTO "django_geo_db_location" VALUES(66174,NULL,'Santa Fe, NM 87592',27537,222,NULL,31,38287,0);
INSERT INTO "django_geo_db_location" VALUES(66175,NULL,'Santa Fe, NM 87594',27537,222,NULL,31,38288,0);
INSERT INTO "django_geo_db_location" VALUES(66176,NULL,'Las Vegas, NM',27595,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66177,NULL,'Las Vegas, NM 87701',27595,222,NULL,31,38289,0);
INSERT INTO "django_geo_db_location" VALUES(66178,NULL,'Angel Fire, NM',27596,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66179,NULL,'Angel Fire, NM 87710',27596,222,NULL,31,38290,0);
INSERT INTO "django_geo_db_location" VALUES(66180,NULL,'Anton Chico, NM',27597,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66181,NULL,'Anton Chico, NM 87711',27597,222,NULL,31,38291,0);
INSERT INTO "django_geo_db_location" VALUES(66182,NULL,'Buena Vista, NM',27598,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66183,NULL,'Buena Vista, NM 87712',27598,222,NULL,31,38292,0);
INSERT INTO "django_geo_db_location" VALUES(66184,NULL,'Chacon, NM',27599,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66185,NULL,'Chacon, NM 87713',27599,222,NULL,31,38293,0);
INSERT INTO "django_geo_db_location" VALUES(66186,NULL,'Cimarron, NM',27600,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66187,NULL,'Cimarron, NM 87714',27600,222,NULL,31,38294,0);
INSERT INTO "django_geo_db_location" VALUES(66188,NULL,'Cleveland, NM',27601,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66189,NULL,'Cleveland, NM 87715',27601,222,NULL,31,38295,0);
INSERT INTO "django_geo_db_location" VALUES(66190,NULL,'Eagle Nest, NM',27602,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66191,NULL,'Eagle Nest, NM 87718',27602,222,NULL,31,38296,0);
INSERT INTO "django_geo_db_location" VALUES(66192,NULL,'Guadalupita, NM',27603,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66193,NULL,'Guadalupita, NM 87722',27603,222,NULL,31,38297,0);
INSERT INTO "django_geo_db_location" VALUES(66194,NULL,'Holman, NM',27604,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66195,NULL,'Holman, NM 87723',27604,222,NULL,31,38298,0);
INSERT INTO "django_geo_db_location" VALUES(66196,NULL,'La Loma, NM',27605,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66197,NULL,'La Loma, NM 87724',27605,222,NULL,31,38299,0);
INSERT INTO "django_geo_db_location" VALUES(66198,NULL,'Maxwell, NM',27606,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66199,NULL,'Maxwell, NM 87728',27606,222,NULL,31,38300,0);
INSERT INTO "django_geo_db_location" VALUES(66200,NULL,'Miami, NM',27607,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66201,NULL,'Miami, NM 87729',27607,222,NULL,31,38301,0);
INSERT INTO "django_geo_db_location" VALUES(66202,NULL,'Mills, NM',27608,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66203,NULL,'Mills, NM 87730',27608,222,NULL,31,38302,0);
INSERT INTO "django_geo_db_location" VALUES(66204,NULL,'Montezuma, NM',27609,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66205,NULL,'Montezuma, NM 87731',27609,222,NULL,31,38303,0);
INSERT INTO "django_geo_db_location" VALUES(66206,NULL,'Mora, NM',27610,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66207,NULL,'Mora, NM 87732',27610,222,NULL,31,38304,0);
INSERT INTO "django_geo_db_location" VALUES(66208,NULL,'Mosquero, NM',27611,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66209,NULL,'Mosquero, NM 87733',27611,222,NULL,31,38305,0);
INSERT INTO "django_geo_db_location" VALUES(66210,NULL,'Ocate, NM',27612,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66211,NULL,'Ocate, NM 87734',27612,222,NULL,31,38306,0);
INSERT INTO "django_geo_db_location" VALUES(66212,NULL,'Ojo Feliz, NM',27613,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66213,NULL,'Ojo Feliz, NM 87735',27613,222,NULL,31,38307,0);
INSERT INTO "django_geo_db_location" VALUES(66214,NULL,'Rainsville, NM',27614,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66215,NULL,'Rainsville, NM 87736',27614,222,NULL,31,38308,0);
INSERT INTO "django_geo_db_location" VALUES(66216,NULL,'Raton, NM',27615,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66217,NULL,'Raton, NM 87740',27615,222,NULL,31,38309,0);
INSERT INTO "django_geo_db_location" VALUES(66218,NULL,'Rociada, NM',27616,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66219,NULL,'Rociada, NM 87742',27616,222,NULL,31,38310,0);
INSERT INTO "django_geo_db_location" VALUES(66220,NULL,'Roy, NM',27617,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66221,NULL,'Roy, NM 87743',27617,222,NULL,31,38311,0);
INSERT INTO "django_geo_db_location" VALUES(66222,NULL,'Sapello, NM',27618,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66223,NULL,'Sapello, NM 87745',27618,222,NULL,31,38312,0);
INSERT INTO "django_geo_db_location" VALUES(66224,NULL,'Solano, NM',27619,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66225,NULL,'Solano, NM 87746',27619,222,NULL,31,38313,0);
INSERT INTO "django_geo_db_location" VALUES(66226,NULL,'Springer, NM',27620,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66227,NULL,'Springer, NM 87747',27620,222,NULL,31,38314,0);
INSERT INTO "django_geo_db_location" VALUES(66228,NULL,'Ute Park, NM',27621,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66229,NULL,'Ute Park, NM 87749',27621,222,NULL,31,38315,0);
INSERT INTO "django_geo_db_location" VALUES(66230,NULL,'Valmora, NM',27622,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66231,NULL,'Valmora, NM 87750',27622,222,NULL,31,38316,0);
INSERT INTO "django_geo_db_location" VALUES(66232,NULL,'Wagon Mound, NM',27623,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66233,NULL,'Wagon Mound, NM 87752',27623,222,NULL,31,38317,0);
INSERT INTO "django_geo_db_location" VALUES(66234,NULL,'Watrous, NM',27624,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66235,NULL,'Watrous, NM 87753',27624,222,NULL,31,38318,0);
INSERT INTO "django_geo_db_location" VALUES(66236,NULL,'Socorro, NM',27625,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66237,NULL,'Socorro, NM 87801',27625,222,NULL,31,38319,0);
INSERT INTO "django_geo_db_location" VALUES(66238,NULL,'Aragon, NM',27626,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66239,NULL,'Aragon, NM 87820',27626,222,NULL,31,38320,0);
INSERT INTO "django_geo_db_location" VALUES(66240,NULL,'Datil, NM',27627,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66241,NULL,'Datil, NM 87821',27627,222,NULL,31,38321,0);
INSERT INTO "django_geo_db_location" VALUES(66242,NULL,'Lemitar, NM',27628,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66243,NULL,'Lemitar, NM 87823',27628,222,NULL,31,38322,0);
INSERT INTO "django_geo_db_location" VALUES(66244,NULL,'Luna, NM',27629,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66245,NULL,'Luna, NM 87824',27629,222,NULL,31,38323,0);
INSERT INTO "django_geo_db_location" VALUES(66246,NULL,'Magdalena, NM',27630,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66247,NULL,'Magdalena, NM 87825',27630,222,NULL,31,38324,0);
INSERT INTO "django_geo_db_location" VALUES(66248,NULL,'Pie Town, NM',27631,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66249,NULL,'Pie Town, NM 87827',27631,222,NULL,31,38325,0);
INSERT INTO "django_geo_db_location" VALUES(66250,NULL,'Polvadera, NM',27632,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66251,NULL,'Polvadera, NM 87828',27632,222,NULL,31,38326,0);
INSERT INTO "django_geo_db_location" VALUES(66252,NULL,'Quemado, NM',27633,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66253,NULL,'Quemado, NM 87829',27633,222,NULL,31,38327,0);
INSERT INTO "django_geo_db_location" VALUES(66254,NULL,'Reserve, NM',27634,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66255,NULL,'Reserve, NM 87830',27634,222,NULL,31,38328,0);
INSERT INTO "django_geo_db_location" VALUES(66256,NULL,'San Acacia, NM',27635,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66257,NULL,'San Acacia, NM 87831',27635,222,NULL,31,38329,0);
INSERT INTO "django_geo_db_location" VALUES(66258,NULL,'San Antonio, NM',27636,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66259,NULL,'San Antonio, NM 87832',27636,222,NULL,31,38330,0);
INSERT INTO "django_geo_db_location" VALUES(66260,NULL,'Truth Or Consequences, NM',27637,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66261,NULL,'Truth Or Consequences, NM 87901',27637,222,NULL,31,38331,0);
INSERT INTO "django_geo_db_location" VALUES(66262,NULL,'Truth or Consequences, NM',27638,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66263,NULL,'Truth or Consequences, NM 87910',27638,222,NULL,31,38332,0);
INSERT INTO "django_geo_db_location" VALUES(66264,NULL,'Arrey, NM',27639,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66265,NULL,'Arrey, NM 87930',27639,222,NULL,31,38333,0);
INSERT INTO "django_geo_db_location" VALUES(66266,NULL,'Caballo, NM',27640,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66267,NULL,'Caballo, NM 87931',27640,222,NULL,31,38334,0);
INSERT INTO "django_geo_db_location" VALUES(66268,NULL,'Derry, NM',27641,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66269,NULL,'Derry, NM 87933',27641,222,NULL,31,38335,0);
INSERT INTO "django_geo_db_location" VALUES(66270,NULL,'Elephant Butte, NM',27642,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66271,NULL,'Elephant Butte, NM 87935',27642,222,NULL,31,38336,0);
INSERT INTO "django_geo_db_location" VALUES(66272,NULL,'Garfield, NM',27643,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66273,NULL,'Garfield, NM 87936',27643,222,NULL,31,38337,0);
INSERT INTO "django_geo_db_location" VALUES(66274,NULL,'Hatch, NM',27644,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66275,NULL,'Hatch, NM 87937',27644,222,NULL,31,38338,0);
INSERT INTO "django_geo_db_location" VALUES(66276,NULL,'Monticello, NM',27645,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66277,NULL,'Monticello, NM 87939',27645,222,NULL,31,38339,0);
INSERT INTO "django_geo_db_location" VALUES(66278,NULL,'Rincon, NM',27646,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66279,NULL,'Rincon, NM 87940',27646,222,NULL,31,38340,0);
INSERT INTO "django_geo_db_location" VALUES(66280,NULL,'Salem, NM',27647,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66281,NULL,'Salem, NM 87941',27647,222,NULL,31,38341,0);
INSERT INTO "django_geo_db_location" VALUES(66282,NULL,'Williamsburg, NM',27648,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66283,NULL,'Williamsburg, NM 87942',27648,222,NULL,31,38342,0);
INSERT INTO "django_geo_db_location" VALUES(66284,NULL,'Winston, NM',27649,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66285,NULL,'Winston, NM 87943',27649,222,NULL,31,38343,0);
INSERT INTO "django_geo_db_location" VALUES(66286,NULL,'Williamsburg, NM 87945',27648,222,NULL,31,38344,0);
INSERT INTO "django_geo_db_location" VALUES(66287,NULL,'Las Cruces, NM',27650,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66288,NULL,'Las Cruces, NM 88001',27650,222,NULL,31,38345,0);
INSERT INTO "django_geo_db_location" VALUES(66289,NULL,'White Sands Missile Range, NM',27651,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66290,NULL,'White Sands Missile Range, NM 88002',27651,222,NULL,31,38346,0);
INSERT INTO "django_geo_db_location" VALUES(66291,NULL,'Las Cruces, NM 88003',27650,222,NULL,31,38347,0);
INSERT INTO "django_geo_db_location" VALUES(66292,NULL,'Las Cruces, NM 88004',27650,222,NULL,31,38348,0);
INSERT INTO "django_geo_db_location" VALUES(66293,NULL,'Las Cruces, NM 88005',27650,222,NULL,31,38349,0);
INSERT INTO "django_geo_db_location" VALUES(66294,NULL,'Las Cruces, NM 88006',27650,222,NULL,31,38350,0);
INSERT INTO "django_geo_db_location" VALUES(66295,NULL,'Las Cruces, NM 88007',27650,222,NULL,31,38351,0);
INSERT INTO "django_geo_db_location" VALUES(66296,NULL,'Santa Teresa, NM',27652,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66297,NULL,'Santa Teresa, NM 88008',27652,222,NULL,31,38352,0);
INSERT INTO "django_geo_db_location" VALUES(66298,NULL,'Playas, NM',27653,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66299,NULL,'Playas, NM 88009',27653,222,NULL,31,38353,0);
INSERT INTO "django_geo_db_location" VALUES(66300,NULL,'Las Cruces, NM 88011',27650,222,NULL,31,38354,0);
INSERT INTO "django_geo_db_location" VALUES(66301,NULL,'Las Cruces, NM 88012',27650,222,NULL,31,38355,0);
INSERT INTO "django_geo_db_location" VALUES(66302,NULL,'Sunland Park, NM',27654,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66303,NULL,'Sunland Park, NM 88018',27654,222,NULL,31,38356,0);
INSERT INTO "django_geo_db_location" VALUES(66304,NULL,'Animas, NM',27655,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66305,NULL,'Animas, NM 88020',27655,222,NULL,31,38357,0);
INSERT INTO "django_geo_db_location" VALUES(66306,NULL,'Anthony, NM',27656,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66307,NULL,'Anthony, NM 88021',27656,222,NULL,31,38358,0);
INSERT INTO "django_geo_db_location" VALUES(66308,NULL,'Arenas Valley, NM',27657,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66309,NULL,'Arenas Valley, NM 88022',27657,222,NULL,31,38359,0);
INSERT INTO "django_geo_db_location" VALUES(66310,NULL,'Bayard, NM',27658,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66311,NULL,'Bayard, NM 88023',27658,222,NULL,31,38360,0);
INSERT INTO "django_geo_db_location" VALUES(66312,NULL,'Berino, NM',27659,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66313,NULL,'Berino, NM 88024',27659,222,NULL,31,38361,0);
INSERT INTO "django_geo_db_location" VALUES(66314,NULL,'Buckhorn, NM',27660,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66315,NULL,'Buckhorn, NM 88025',27660,222,NULL,31,38362,0);
INSERT INTO "django_geo_db_location" VALUES(66316,NULL,'Santa Clara, NM',27661,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66317,NULL,'Santa Clara, NM 88026',27661,222,NULL,31,38363,0);
INSERT INTO "django_geo_db_location" VALUES(66318,NULL,'Chamberino, NM',27662,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66319,NULL,'Chamberino, NM 88027',27662,222,NULL,31,38364,0);
INSERT INTO "django_geo_db_location" VALUES(66320,NULL,'Cliff, NM',27663,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66321,NULL,'Cliff, NM 88028',27663,222,NULL,31,38365,0);
INSERT INTO "django_geo_db_location" VALUES(66322,NULL,'Columbus, NM',27664,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66323,NULL,'Columbus, NM 88029',27664,222,NULL,31,38366,0);
INSERT INTO "django_geo_db_location" VALUES(66324,NULL,'Deming, NM',27665,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66325,NULL,'Deming, NM 88030',27665,222,NULL,31,38367,0);
INSERT INTO "django_geo_db_location" VALUES(66326,NULL,'Deming, NM 88031',27665,222,NULL,31,38368,0);
INSERT INTO "django_geo_db_location" VALUES(66327,NULL,'Dona Ana, NM',27666,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66328,NULL,'Dona Ana, NM 88032',27666,222,NULL,31,38369,0);
INSERT INTO "django_geo_db_location" VALUES(66329,NULL,'Fairacres, NM',27667,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66330,NULL,'Fairacres, NM 88033',27667,222,NULL,31,38370,0);
INSERT INTO "django_geo_db_location" VALUES(66331,NULL,'Faywood, NM',27668,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66332,NULL,'Faywood, NM 88034',27668,222,NULL,31,38371,0);
INSERT INTO "django_geo_db_location" VALUES(66333,NULL,'Fort Bayard, NM',27669,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66334,NULL,'Fort Bayard, NM 88036',27669,222,NULL,31,38372,0);
INSERT INTO "django_geo_db_location" VALUES(66335,NULL,'Gila, NM',27670,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66336,NULL,'Gila, NM 88038',27670,222,NULL,31,38373,0);
INSERT INTO "django_geo_db_location" VALUES(66337,NULL,'Glenwood, NM',27671,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66338,NULL,'Glenwood, NM 88039',27671,222,NULL,31,38374,0);
INSERT INTO "django_geo_db_location" VALUES(66339,NULL,'Hachita, NM',27672,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66340,NULL,'Hachita, NM 88040',27672,222,NULL,31,38375,0);
INSERT INTO "django_geo_db_location" VALUES(66341,NULL,'Hanover, NM',27673,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66342,NULL,'Hanover, NM 88041',27673,222,NULL,31,38376,0);
INSERT INTO "django_geo_db_location" VALUES(66343,NULL,'Hillsboro, NM',27674,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66344,NULL,'Hillsboro, NM 88042',27674,222,NULL,31,38377,0);
INSERT INTO "django_geo_db_location" VALUES(66345,NULL,'Hurley, NM',27675,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66346,NULL,'Hurley, NM 88043',27675,222,NULL,31,38378,0);
INSERT INTO "django_geo_db_location" VALUES(66347,NULL,'La Mesa, NM',27676,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66348,NULL,'La Mesa, NM 88044',27676,222,NULL,31,38379,0);
INSERT INTO "django_geo_db_location" VALUES(66349,NULL,'Lordsburg, NM',27677,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66350,NULL,'Lordsburg, NM 88045',27677,222,NULL,31,38380,0);
INSERT INTO "django_geo_db_location" VALUES(66351,NULL,'Mesilla, NM',27678,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66352,NULL,'Mesilla, NM 88046',27678,222,NULL,31,38381,0);
INSERT INTO "django_geo_db_location" VALUES(66353,NULL,'Mesilla Park, NM',27679,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66354,NULL,'Mesilla Park, NM 88047',27679,222,NULL,31,38382,0);
INSERT INTO "django_geo_db_location" VALUES(66355,NULL,'Mesquite, NM',27680,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66356,NULL,'Mesquite, NM 88048',27680,222,NULL,31,38383,0);
INSERT INTO "django_geo_db_location" VALUES(66357,NULL,'Mimbres, NM',27681,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66358,NULL,'Mimbres, NM 88049',27681,222,NULL,31,38384,0);
INSERT INTO "django_geo_db_location" VALUES(66359,NULL,'Mule Creek, NM',27682,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66360,NULL,'Mule Creek, NM 88051',27682,222,NULL,31,38385,0);
INSERT INTO "django_geo_db_location" VALUES(66361,NULL,'Organ, NM',27683,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66362,NULL,'Organ, NM 88052',27683,222,NULL,31,38386,0);
INSERT INTO "django_geo_db_location" VALUES(66363,NULL,'Pinos Altos, NM',27684,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66364,NULL,'Pinos Altos, NM 88053',27684,222,NULL,31,38387,0);
INSERT INTO "django_geo_db_location" VALUES(66365,NULL,'Radium Springs, NM',27685,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66366,NULL,'Radium Springs, NM 88054',27685,222,NULL,31,38388,0);
INSERT INTO "django_geo_db_location" VALUES(66367,NULL,'Redrock, NM',27686,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66368,NULL,'Redrock, NM 88055',27686,222,NULL,31,38389,0);
INSERT INTO "django_geo_db_location" VALUES(66369,NULL,'Rodeo, NM',27687,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66370,NULL,'Rodeo, NM 88056',27687,222,NULL,31,38390,0);
INSERT INTO "django_geo_db_location" VALUES(66371,NULL,'San Miguel, NM',27688,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66372,NULL,'San Miguel, NM 88058',27688,222,NULL,31,38391,0);
INSERT INTO "django_geo_db_location" VALUES(66373,NULL,'Silver City, NM',27689,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66374,NULL,'Silver City, NM 88061',27689,222,NULL,31,38392,0);
INSERT INTO "django_geo_db_location" VALUES(66375,NULL,'Silver City, NM 88062',27689,222,NULL,31,38393,0);
INSERT INTO "django_geo_db_location" VALUES(66376,NULL,'Sunland Park, NM 88063',27654,222,NULL,31,38394,0);
INSERT INTO "django_geo_db_location" VALUES(66377,NULL,'Tyrone, NM',27690,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66378,NULL,'Tyrone, NM 88065',27690,222,NULL,31,38395,0);
INSERT INTO "django_geo_db_location" VALUES(66379,NULL,'Vado, NM',27691,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66380,NULL,'Vado, NM 88072',27691,222,NULL,31,38396,0);
INSERT INTO "django_geo_db_location" VALUES(66381,NULL,'Chaparral, NM',27692,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66382,NULL,'Chaparral, NM 88081',27692,222,NULL,31,38397,0);
INSERT INTO "django_geo_db_location" VALUES(66383,NULL,'Las Cruces, NM 88085',27650,222,NULL,31,38398,0);
INSERT INTO "django_geo_db_location" VALUES(66384,NULL,'Grady, NM',27693,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66385,NULL,'Grady, NM 88100',27693,222,NULL,31,38399,0);
INSERT INTO "django_geo_db_location" VALUES(66386,NULL,'Clovis, NM',27694,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66387,NULL,'Clovis, NM 88101',27694,222,NULL,31,38400,0);
INSERT INTO "django_geo_db_location" VALUES(66388,NULL,'Clovis, NM 88102',27694,222,NULL,31,38401,0);
INSERT INTO "django_geo_db_location" VALUES(66389,NULL,'Cannon AFB, NM',27695,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66390,NULL,'Cannon AFB, NM 88103',27695,222,NULL,31,38402,0);
INSERT INTO "django_geo_db_location" VALUES(66391,NULL,'Broadview, NM',27696,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66392,NULL,'Broadview, NM 88112',27696,222,NULL,31,38403,0);
INSERT INTO "django_geo_db_location" VALUES(66393,NULL,'Causey, NM',27697,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66394,NULL,'Causey, NM 88113',27697,222,NULL,31,38404,0);
INSERT INTO "django_geo_db_location" VALUES(66395,NULL,'Crossroads, NM',27698,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66396,NULL,'Crossroads, NM 88114',27698,222,NULL,31,38405,0);
INSERT INTO "django_geo_db_location" VALUES(66397,NULL,'Dora, NM',27699,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66398,NULL,'Dora, NM 88115',27699,222,NULL,31,38406,0);
INSERT INTO "django_geo_db_location" VALUES(66399,NULL,'Elida, NM',27700,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66400,NULL,'Elida, NM 88116',27700,222,NULL,31,38407,0);
INSERT INTO "django_geo_db_location" VALUES(66401,NULL,'Floyd, NM',27701,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66402,NULL,'Floyd, NM 88118',27701,222,NULL,31,38408,0);
INSERT INTO "django_geo_db_location" VALUES(66403,NULL,'Fort Sumner, NM',27702,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66404,NULL,'Fort Sumner, NM 88119',27702,222,NULL,31,38409,0);
INSERT INTO "django_geo_db_location" VALUES(66405,NULL,'Grady, NM 88120',27693,222,NULL,31,38410,0);
INSERT INTO "django_geo_db_location" VALUES(66406,NULL,'House, NM',27703,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66407,NULL,'House, NM 88121',27703,222,NULL,31,38411,0);
INSERT INTO "django_geo_db_location" VALUES(66408,NULL,'Kenna, NM',27704,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66409,NULL,'Kenna, NM 88122',27704,222,NULL,31,38412,0);
INSERT INTO "django_geo_db_location" VALUES(66410,NULL,'Lingo, NM',27705,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66411,NULL,'Lingo, NM 88123',27705,222,NULL,31,38413,0);
INSERT INTO "django_geo_db_location" VALUES(66412,NULL,'Melrose, NM',27706,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66413,NULL,'Melrose, NM 88124',27706,222,NULL,31,38414,0);
INSERT INTO "django_geo_db_location" VALUES(66414,NULL,'Milnesand, NM',27707,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66415,NULL,'Milnesand, NM 88125',27707,222,NULL,31,38415,0);
INSERT INTO "django_geo_db_location" VALUES(66416,NULL,'Pep, NM',27708,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66417,NULL,'Pep, NM 88126',27708,222,NULL,31,38416,0);
INSERT INTO "django_geo_db_location" VALUES(66418,NULL,'Portales, NM',27709,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66419,NULL,'Portales, NM 88130',27709,222,NULL,31,38417,0);
INSERT INTO "django_geo_db_location" VALUES(66420,NULL,'Rogers, NM',27710,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66421,NULL,'Rogers, NM 88132',27710,222,NULL,31,38418,0);
INSERT INTO "django_geo_db_location" VALUES(66422,NULL,'Saint Vrain, NM',27711,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66423,NULL,'Saint Vrain, NM 88133',27711,222,NULL,31,38419,0);
INSERT INTO "django_geo_db_location" VALUES(66424,NULL,'Taiban, NM',27712,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66425,NULL,'Taiban, NM 88134',27712,222,NULL,31,38420,0);
INSERT INTO "django_geo_db_location" VALUES(66426,NULL,'Texico, NM',27713,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66427,NULL,'Texico, NM 88135',27713,222,NULL,31,38421,0);
INSERT INTO "django_geo_db_location" VALUES(66428,NULL,'Yeso, NM',27714,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66429,NULL,'Yeso, NM 88136',27714,222,NULL,31,38422,0);
INSERT INTO "django_geo_db_location" VALUES(66430,NULL,'Roswell, NM',27715,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66431,NULL,'Roswell, NM 88201',27715,222,NULL,31,38423,0);
INSERT INTO "django_geo_db_location" VALUES(66432,NULL,'Roswell, NM 88202',27715,222,NULL,31,38424,0);
INSERT INTO "django_geo_db_location" VALUES(66433,NULL,'Roswell, NM 88203',27715,222,NULL,31,38425,0);
INSERT INTO "django_geo_db_location" VALUES(66434,NULL,'Artesia, NM',27716,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66435,NULL,'Artesia, NM 88210',27716,222,NULL,31,38426,0);
INSERT INTO "django_geo_db_location" VALUES(66436,NULL,'Artesia, NM 88211',27716,222,NULL,31,38427,0);
INSERT INTO "django_geo_db_location" VALUES(66437,NULL,'Caprock, NM',27717,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66438,NULL,'Caprock, NM 88213',27717,222,NULL,31,38428,0);
INSERT INTO "django_geo_db_location" VALUES(66439,NULL,'Carlsbad, NM',27718,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66440,NULL,'Carlsbad, NM 88220',27718,222,NULL,31,38429,0);
INSERT INTO "django_geo_db_location" VALUES(66441,NULL,'Carlsbad, NM 88221',27718,222,NULL,31,38430,0);
INSERT INTO "django_geo_db_location" VALUES(66442,NULL,'Dexter, NM',27719,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66443,NULL,'Dexter, NM 88230',27719,222,NULL,31,38431,0);
INSERT INTO "django_geo_db_location" VALUES(66444,NULL,'Eunice, NM',27720,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66445,NULL,'Eunice, NM 88231',27720,222,NULL,31,38432,0);
INSERT INTO "django_geo_db_location" VALUES(66446,NULL,'Hagerman, NM',27721,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66447,NULL,'Hagerman, NM 88232',27721,222,NULL,31,38433,0);
INSERT INTO "django_geo_db_location" VALUES(66448,NULL,'Hobbs, NM',27722,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66449,NULL,'Hobbs, NM 88240',27722,222,NULL,31,38434,0);
INSERT INTO "django_geo_db_location" VALUES(66450,NULL,'Hobbs, NM 88241',27722,222,NULL,31,38435,0);
INSERT INTO "django_geo_db_location" VALUES(66451,NULL,'Hobbs, NM 88242',27722,222,NULL,31,38436,0);
INSERT INTO "django_geo_db_location" VALUES(66452,NULL,'Hobbs, NM 88244',27722,222,NULL,31,38437,0);
INSERT INTO "django_geo_db_location" VALUES(66453,NULL,'Hope, NM',27723,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66454,NULL,'Hope, NM 88250',27723,222,NULL,31,38438,0);
INSERT INTO "django_geo_db_location" VALUES(66455,NULL,'Jal, NM',27724,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66456,NULL,'Jal, NM 88252',27724,222,NULL,31,38439,0);
INSERT INTO "django_geo_db_location" VALUES(66457,NULL,'Lake Arthur, NM',27725,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66458,NULL,'Lake Arthur, NM 88253',27725,222,NULL,31,38440,0);
INSERT INTO "django_geo_db_location" VALUES(66459,NULL,'Lakewood, NM',27726,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66460,NULL,'Lakewood, NM 88254',27726,222,NULL,31,38441,0);
INSERT INTO "django_geo_db_location" VALUES(66461,NULL,'Loco Hills, NM',27727,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66462,NULL,'Loco Hills, NM 88255',27727,222,NULL,31,38442,0);
INSERT INTO "django_geo_db_location" VALUES(66463,NULL,'Loving, NM',27728,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66464,NULL,'Loving, NM 88256',27728,222,NULL,31,38443,0);
INSERT INTO "django_geo_db_location" VALUES(66465,NULL,'Lovington, NM',27729,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66466,NULL,'Lovington, NM 88260',27729,222,NULL,31,38444,0);
INSERT INTO "django_geo_db_location" VALUES(66467,NULL,'McDonald, NM',27730,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66468,NULL,'McDonald, NM 88262',27730,222,NULL,31,38445,0);
INSERT INTO "django_geo_db_location" VALUES(66469,NULL,'Malaga, NM',27731,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66470,NULL,'Malaga, NM 88263',27731,222,NULL,31,38446,0);
INSERT INTO "django_geo_db_location" VALUES(66471,NULL,'Maljamar, NM',27732,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66472,NULL,'Maljamar, NM 88264',27732,222,NULL,31,38447,0);
INSERT INTO "django_geo_db_location" VALUES(66473,NULL,'Monument, NM',27733,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66474,NULL,'Monument, NM 88265',27733,222,NULL,31,38448,0);
INSERT INTO "django_geo_db_location" VALUES(66475,NULL,'Tatum, NM',27734,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66476,NULL,'Tatum, NM 88267',27734,222,NULL,31,38449,0);
INSERT INTO "django_geo_db_location" VALUES(66477,NULL,'Whites City, NM',27735,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66478,NULL,'Whites City, NM 88268',27735,222,NULL,31,38450,0);
INSERT INTO "django_geo_db_location" VALUES(66479,NULL,'Carrizozo, NM',27736,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66480,NULL,'Carrizozo, NM 88301',27736,222,NULL,31,38451,0);
INSERT INTO "django_geo_db_location" VALUES(66481,NULL,'Alamogordo, NM',27737,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66482,NULL,'Alamogordo, NM 88310',27737,222,NULL,31,38452,0);
INSERT INTO "django_geo_db_location" VALUES(66483,NULL,'Alamogordo, NM 88311',27737,222,NULL,31,38453,0);
INSERT INTO "django_geo_db_location" VALUES(66484,NULL,'Alto, NM',27738,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66485,NULL,'Alto, NM 88312',27738,222,NULL,31,38454,0);
INSERT INTO "django_geo_db_location" VALUES(66486,NULL,'Bent, NM',27739,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66487,NULL,'Bent, NM 88314',27739,222,NULL,31,38455,0);
INSERT INTO "django_geo_db_location" VALUES(66488,NULL,'Boles Acres, NM',27740,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66489,NULL,'Boles Acres, NM 88315',27740,222,NULL,31,38456,0);
INSERT INTO "django_geo_db_location" VALUES(66490,NULL,'Capitan, NM',27741,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66491,NULL,'Capitan, NM 88316',27741,222,NULL,31,38457,0);
INSERT INTO "django_geo_db_location" VALUES(66492,NULL,'Cloudcroft, NM',27742,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66493,NULL,'Cloudcroft, NM 88317',27742,222,NULL,31,38458,0);
INSERT INTO "django_geo_db_location" VALUES(66494,NULL,'Corona, NM',27743,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66495,NULL,'Corona, NM 88318',27743,222,NULL,31,38459,0);
INSERT INTO "django_geo_db_location" VALUES(66496,NULL,'Encino, NM',27744,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66497,NULL,'Encino, NM 88321',27744,222,NULL,31,38460,0);
INSERT INTO "django_geo_db_location" VALUES(66498,NULL,'Fort Stanton, NM',27745,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66499,NULL,'Fort Stanton, NM 88323',27745,222,NULL,31,38461,0);
INSERT INTO "django_geo_db_location" VALUES(66500,NULL,'Glencoe, NM',27746,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66501,NULL,'Glencoe, NM 88324',27746,222,NULL,31,38462,0);
INSERT INTO "django_geo_db_location" VALUES(66502,NULL,'High Rolls Mountain Park, NM',27747,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66503,NULL,'High Rolls Mountain Park, NM 88325',27747,222,NULL,31,38463,0);
INSERT INTO "django_geo_db_location" VALUES(66504,NULL,'Holloman Air Force Base, NM',27748,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66505,NULL,'Holloman Air Force Base, NM 88330',27748,222,NULL,31,38464,0);
INSERT INTO "django_geo_db_location" VALUES(66506,NULL,'La Luz, NM',27749,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66507,NULL,'La Luz, NM 88332',27749,222,NULL,31,38465,0);
INSERT INTO "django_geo_db_location" VALUES(66508,NULL,'Hondo, NM',27750,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66509,NULL,'Hondo, NM 88336',27750,222,NULL,31,38466,0);
INSERT INTO "django_geo_db_location" VALUES(66510,NULL,'La Luz, NM 88337',27749,222,NULL,31,38467,0);
INSERT INTO "django_geo_db_location" VALUES(66511,NULL,'Lincoln, NM',27751,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66512,NULL,'Lincoln, NM 88338',27751,222,NULL,31,38468,0);
INSERT INTO "django_geo_db_location" VALUES(66513,NULL,'Mayhill, NM',27752,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66514,NULL,'Mayhill, NM 88339',27752,222,NULL,31,38469,0);
INSERT INTO "django_geo_db_location" VALUES(66515,NULL,'Mescalero, NM',27753,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66516,NULL,'Mescalero, NM 88340',27753,222,NULL,31,38470,0);
INSERT INTO "django_geo_db_location" VALUES(66517,NULL,'Nogal, NM',27754,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66518,NULL,'Nogal, NM 88341',27754,222,NULL,31,38471,0);
INSERT INTO "django_geo_db_location" VALUES(66519,NULL,'Orogrande, NM',27755,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66520,NULL,'Orogrande, NM 88342',27755,222,NULL,31,38472,0);
INSERT INTO "django_geo_db_location" VALUES(66521,NULL,'Picacho, NM',27756,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66522,NULL,'Picacho, NM 88343',27756,222,NULL,31,38473,0);
INSERT INTO "django_geo_db_location" VALUES(66523,NULL,'Pinon, NM',27757,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66524,NULL,'Pinon, NM 88344',27757,222,NULL,31,38474,0);
INSERT INTO "django_geo_db_location" VALUES(66525,NULL,'Ruidoso, NM',27758,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66526,NULL,'Ruidoso, NM 88345',27758,222,NULL,31,38475,0);
INSERT INTO "django_geo_db_location" VALUES(66527,NULL,'Ruidoso Downs, NM',27759,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66528,NULL,'Ruidoso Downs, NM 88346',27759,222,NULL,31,38476,0);
INSERT INTO "django_geo_db_location" VALUES(66529,NULL,'Sacramento, NM',27760,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66530,NULL,'Sacramento, NM 88347',27760,222,NULL,31,38477,0);
INSERT INTO "django_geo_db_location" VALUES(66531,NULL,'San Patricio, NM',27761,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66532,NULL,'San Patricio, NM 88348',27761,222,NULL,31,38478,0);
INSERT INTO "django_geo_db_location" VALUES(66533,NULL,'Sunspot, NM',27762,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66534,NULL,'Sunspot, NM 88349',27762,222,NULL,31,38479,0);
INSERT INTO "django_geo_db_location" VALUES(66535,NULL,'Timberon, NM',27763,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66536,NULL,'Timberon, NM 88350',27763,222,NULL,31,38480,0);
INSERT INTO "django_geo_db_location" VALUES(66537,NULL,'Tinnie, NM',27764,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66538,NULL,'Tinnie, NM 88351',27764,222,NULL,31,38481,0);
INSERT INTO "django_geo_db_location" VALUES(66539,NULL,'Tularosa, NM',27765,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66540,NULL,'Tularosa, NM 88352',27765,222,NULL,31,38482,0);
INSERT INTO "django_geo_db_location" VALUES(66541,NULL,'Vaughn, NM',27766,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66542,NULL,'Vaughn, NM 88353',27766,222,NULL,31,38483,0);
INSERT INTO "django_geo_db_location" VALUES(66543,NULL,'Weed, NM',27767,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66544,NULL,'Weed, NM 88354',27767,222,NULL,31,38484,0);
INSERT INTO "django_geo_db_location" VALUES(66545,NULL,'Ruidoso, NM 88355',27758,222,NULL,31,38485,0);
INSERT INTO "django_geo_db_location" VALUES(66546,NULL,'Tucumcari, NM',27768,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66547,NULL,'Tucumcari, NM 88401',27768,222,NULL,31,38486,0);
INSERT INTO "django_geo_db_location" VALUES(66548,NULL,'Amistad, NM',27769,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66549,NULL,'Amistad, NM 88410',27769,222,NULL,31,38487,0);
INSERT INTO "django_geo_db_location" VALUES(66550,NULL,'Bard, NM',27770,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66551,NULL,'Bard, NM 88411',27770,222,NULL,31,38488,0);
INSERT INTO "django_geo_db_location" VALUES(66552,NULL,'Capulin, NM',27771,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66553,NULL,'Capulin, NM 88414',27771,222,NULL,31,38489,0);
INSERT INTO "django_geo_db_location" VALUES(66554,NULL,'Clayton, NM',27772,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66555,NULL,'Clayton, NM 88415',27772,222,NULL,31,38490,0);
INSERT INTO "django_geo_db_location" VALUES(66556,NULL,'Conchas Dam, NM',27773,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66557,NULL,'Conchas Dam, NM 88416',27773,222,NULL,31,38491,0);
INSERT INTO "django_geo_db_location" VALUES(66558,NULL,'Cuervo, NM',27774,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66559,NULL,'Cuervo, NM 88417',27774,222,NULL,31,38492,0);
INSERT INTO "django_geo_db_location" VALUES(66560,NULL,'Des Moines, NM',27775,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66561,NULL,'Des Moines, NM 88418',27775,222,NULL,31,38493,0);
INSERT INTO "django_geo_db_location" VALUES(66562,NULL,'Folsom, NM',27776,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66563,NULL,'Folsom, NM 88419',27776,222,NULL,31,38494,0);
INSERT INTO "django_geo_db_location" VALUES(66564,NULL,'Garita, NM',27777,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66565,NULL,'Garita, NM 88421',27777,222,NULL,31,38495,0);
INSERT INTO "django_geo_db_location" VALUES(66566,NULL,'Gladstone, NM',27778,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66567,NULL,'Gladstone, NM 88422',27778,222,NULL,31,38496,0);
INSERT INTO "django_geo_db_location" VALUES(66568,NULL,'Grenville, NM',27779,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66569,NULL,'Grenville, NM 88424',27779,222,NULL,31,38497,0);
INSERT INTO "django_geo_db_location" VALUES(66570,NULL,'Logan, NM',27780,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66571,NULL,'Logan, NM 88426',27780,222,NULL,31,38498,0);
INSERT INTO "django_geo_db_location" VALUES(66572,NULL,'McAlister, NM',27781,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66573,NULL,'McAlister, NM 88427',27781,222,NULL,31,38499,0);
INSERT INTO "django_geo_db_location" VALUES(66574,NULL,'Mount Dora, NM',27782,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66575,NULL,'Mount Dora, NM 88429',27782,222,NULL,31,38500,0);
INSERT INTO "django_geo_db_location" VALUES(66576,NULL,'Nara Visa, NM',27783,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66577,NULL,'Nara Visa, NM 88430',27783,222,NULL,31,38501,0);
INSERT INTO "django_geo_db_location" VALUES(66578,NULL,'Newkirk, NM',27784,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66579,NULL,'Newkirk, NM 88431',27784,222,NULL,31,38502,0);
INSERT INTO "django_geo_db_location" VALUES(66580,NULL,'Quay, NM',27785,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66581,NULL,'Quay, NM 88433',27785,222,NULL,31,38503,0);
INSERT INTO "django_geo_db_location" VALUES(66582,NULL,'San Jon, NM',27786,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66583,NULL,'San Jon, NM 88434',27786,222,NULL,31,38504,0);
INSERT INTO "django_geo_db_location" VALUES(66584,NULL,'Santa Rosa, NM',27787,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66585,NULL,'Santa Rosa, NM 88435',27787,222,NULL,31,38505,0);
INSERT INTO "django_geo_db_location" VALUES(66586,NULL,'Sedan, NM',27788,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66587,NULL,'Sedan, NM 88436',27788,222,NULL,31,38506,0);
INSERT INTO "django_geo_db_location" VALUES(66588,NULL,'Seneca, NM',27789,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66589,NULL,'Seneca, NM 88437',27789,222,NULL,31,38507,0);
INSERT INTO "django_geo_db_location" VALUES(66590,NULL,'Trementina, NM',27790,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66591,NULL,'Trementina, NM 88439',27790,222,NULL,31,38508,0);
INSERT INTO "django_geo_db_location" VALUES(66592,NULL,'Bell Ranch, NM',27791,222,NULL,31,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66593,NULL,'Bell Ranch, NM 88441',27791,222,NULL,31,38509,0);
INSERT INTO "django_geo_db_location" VALUES(66594,NULL,'El Paso, TX 88510',26059,222,NULL,51,38510,0);
INSERT INTO "django_geo_db_location" VALUES(66595,NULL,'El Paso, TX 88511',26059,222,NULL,51,38511,0);
INSERT INTO "django_geo_db_location" VALUES(66596,NULL,'El Paso, TX 88512',26059,222,NULL,51,38512,0);
INSERT INTO "django_geo_db_location" VALUES(66597,NULL,'El Paso, TX 88513',26059,222,NULL,51,38513,0);
INSERT INTO "django_geo_db_location" VALUES(66598,NULL,'El Paso, TX 88514',26059,222,NULL,51,38514,0);
INSERT INTO "django_geo_db_location" VALUES(66599,NULL,'El Paso, TX 88515',26059,222,NULL,51,38515,0);
INSERT INTO "django_geo_db_location" VALUES(66600,NULL,'El Paso, TX 88516',26059,222,NULL,51,38516,0);
INSERT INTO "django_geo_db_location" VALUES(66601,NULL,'El Paso, TX 88517',26059,222,NULL,51,38517,0);
INSERT INTO "django_geo_db_location" VALUES(66602,NULL,'El Paso, TX 88518',26059,222,NULL,51,38518,0);
INSERT INTO "django_geo_db_location" VALUES(66603,NULL,'El Paso, TX 88519',26059,222,NULL,51,38519,0);
INSERT INTO "django_geo_db_location" VALUES(66604,NULL,'El Paso, TX 88520',26059,222,NULL,51,38520,0);
INSERT INTO "django_geo_db_location" VALUES(66605,NULL,'El Paso, TX 88521',26059,222,NULL,51,38521,0);
INSERT INTO "django_geo_db_location" VALUES(66606,NULL,'El Paso, TX 88523',26059,222,NULL,51,38522,0);
INSERT INTO "django_geo_db_location" VALUES(66607,NULL,'El Paso, TX 88524',26059,222,NULL,51,38523,0);
INSERT INTO "django_geo_db_location" VALUES(66608,NULL,'El Paso, TX 88525',26059,222,NULL,51,38524,0);
INSERT INTO "django_geo_db_location" VALUES(66609,NULL,'El Paso, TX 88526',26059,222,NULL,51,38525,0);
INSERT INTO "django_geo_db_location" VALUES(66610,NULL,'El Paso, TX 88527',26059,222,NULL,51,38526,0);
INSERT INTO "django_geo_db_location" VALUES(66611,NULL,'El Paso, TX 88528',26059,222,NULL,51,38527,0);
INSERT INTO "django_geo_db_location" VALUES(66612,NULL,'El Paso, TX 88529',26059,222,NULL,51,38528,0);
INSERT INTO "django_geo_db_location" VALUES(66613,NULL,'El Paso, TX 88530',26059,222,NULL,51,38529,0);
INSERT INTO "django_geo_db_location" VALUES(66614,NULL,'El Paso, TX 88531',26059,222,NULL,51,38530,0);
INSERT INTO "django_geo_db_location" VALUES(66615,NULL,'El Paso, TX 88532',26059,222,NULL,51,38531,0);
INSERT INTO "django_geo_db_location" VALUES(66616,NULL,'El Paso, TX 88533',26059,222,NULL,51,38532,0);
INSERT INTO "django_geo_db_location" VALUES(66617,NULL,'El Paso, TX 88534',26059,222,NULL,51,38533,0);
INSERT INTO "django_geo_db_location" VALUES(66618,NULL,'El Paso, TX 88535',26059,222,NULL,51,38534,0);
INSERT INTO "django_geo_db_location" VALUES(66619,NULL,'El Paso, TX 88536',26059,222,NULL,51,38535,0);
INSERT INTO "django_geo_db_location" VALUES(66620,NULL,'El Paso, TX 88538',26059,222,NULL,51,38536,0);
INSERT INTO "django_geo_db_location" VALUES(66621,NULL,'El Paso, TX 88539',26059,222,NULL,51,38537,0);
INSERT INTO "django_geo_db_location" VALUES(66622,NULL,'El Paso, TX 88540',26059,222,NULL,51,38538,0);
INSERT INTO "django_geo_db_location" VALUES(66623,NULL,'El Paso, TX 88541',26059,222,NULL,51,38539,0);
INSERT INTO "django_geo_db_location" VALUES(66624,NULL,'El Paso, TX 88542',26059,222,NULL,51,38540,0);
INSERT INTO "django_geo_db_location" VALUES(66625,NULL,'El Paso, TX 88543',26059,222,NULL,51,38541,0);
INSERT INTO "django_geo_db_location" VALUES(66626,NULL,'El Paso, TX 88544',26059,222,NULL,51,38542,0);
INSERT INTO "django_geo_db_location" VALUES(66627,NULL,'El Paso, TX 88545',26059,222,NULL,51,38543,0);
INSERT INTO "django_geo_db_location" VALUES(66628,NULL,'El Paso, TX 88546',26059,222,NULL,51,38544,0);
INSERT INTO "django_geo_db_location" VALUES(66629,NULL,'El Paso, TX 88547',26059,222,NULL,51,38545,0);
INSERT INTO "django_geo_db_location" VALUES(66630,NULL,'El Paso, TX 88548',26059,222,NULL,51,38546,0);
INSERT INTO "django_geo_db_location" VALUES(66631,NULL,'El Paso, TX 88549',26059,222,NULL,51,38547,0);
INSERT INTO "django_geo_db_location" VALUES(66632,NULL,'El Paso, TX 88550',26059,222,NULL,51,38548,0);
INSERT INTO "django_geo_db_location" VALUES(66633,NULL,'El Paso, TX 88553',26059,222,NULL,51,38549,0);
INSERT INTO "django_geo_db_location" VALUES(66634,NULL,'El Paso, TX 88554',26059,222,NULL,51,38550,0);
INSERT INTO "django_geo_db_location" VALUES(66635,NULL,'El Paso, TX 88555',26059,222,NULL,51,38551,0);
INSERT INTO "django_geo_db_location" VALUES(66636,NULL,'El Paso, TX 88556',26059,222,NULL,51,38552,0);
INSERT INTO "django_geo_db_location" VALUES(66637,NULL,'El Paso, TX 88557',26059,222,NULL,51,38553,0);
INSERT INTO "django_geo_db_location" VALUES(66638,NULL,'El Paso, TX 88558',26059,222,NULL,51,38554,0);
INSERT INTO "django_geo_db_location" VALUES(66639,NULL,'El Paso, TX 88559',26059,222,NULL,51,38555,0);
INSERT INTO "django_geo_db_location" VALUES(66640,NULL,'El Paso, TX 88560',26059,222,NULL,51,38556,0);
INSERT INTO "django_geo_db_location" VALUES(66641,NULL,'El Paso, TX 88561',26059,222,NULL,51,38557,0);
INSERT INTO "django_geo_db_location" VALUES(66642,NULL,'El Paso, TX 88562',26059,222,NULL,51,38558,0);
INSERT INTO "django_geo_db_location" VALUES(66643,NULL,'El Paso, TX 88563',26059,222,NULL,51,38559,0);
INSERT INTO "django_geo_db_location" VALUES(66644,NULL,'El Paso, TX 88565',26059,222,NULL,51,38560,0);
INSERT INTO "django_geo_db_location" VALUES(66645,NULL,'El Paso, TX 88566',26059,222,NULL,51,38561,0);
INSERT INTO "django_geo_db_location" VALUES(66646,NULL,'El Paso, TX 88567',26059,222,NULL,51,38562,0);
INSERT INTO "django_geo_db_location" VALUES(66647,NULL,'El Paso, TX 88568',26059,222,NULL,51,38563,0);
INSERT INTO "django_geo_db_location" VALUES(66648,NULL,'El Paso, TX 88569',26059,222,NULL,51,38564,0);
INSERT INTO "django_geo_db_location" VALUES(66649,NULL,'El Paso, TX 88570',26059,222,NULL,51,38565,0);
INSERT INTO "django_geo_db_location" VALUES(66650,NULL,'El Paso, TX 88571',26059,222,NULL,51,38566,0);
INSERT INTO "django_geo_db_location" VALUES(66651,NULL,'El Paso, TX 88572',26059,222,NULL,51,38567,0);
INSERT INTO "django_geo_db_location" VALUES(66652,NULL,'El Paso, TX 88573',26059,222,NULL,51,38568,0);
INSERT INTO "django_geo_db_location" VALUES(66653,NULL,'El Paso, TX 88574',26059,222,NULL,51,38569,0);
INSERT INTO "django_geo_db_location" VALUES(66654,NULL,'El Paso, TX 88575',26059,222,NULL,51,38570,0);
INSERT INTO "django_geo_db_location" VALUES(66655,NULL,'El Paso, TX 88576',26059,222,NULL,51,38571,0);
INSERT INTO "django_geo_db_location" VALUES(66656,NULL,'El Paso, TX 88577',26059,222,NULL,51,38572,0);
INSERT INTO "django_geo_db_location" VALUES(66657,NULL,'El Paso, TX 88578',26059,222,NULL,51,38573,0);
INSERT INTO "django_geo_db_location" VALUES(66658,NULL,'El Paso, TX 88579',26059,222,NULL,51,38574,0);
INSERT INTO "django_geo_db_location" VALUES(66659,NULL,'El Paso, TX 88580',26059,222,NULL,51,38575,0);
INSERT INTO "django_geo_db_location" VALUES(66660,NULL,'El Paso, TX 88581',26059,222,NULL,51,38576,0);
INSERT INTO "django_geo_db_location" VALUES(66661,NULL,'El Paso, TX 88582',26059,222,NULL,51,38577,0);
INSERT INTO "django_geo_db_location" VALUES(66662,NULL,'El Paso, TX 88583',26059,222,NULL,51,38578,0);
INSERT INTO "django_geo_db_location" VALUES(66663,NULL,'El Paso, TX 88584',26059,222,NULL,51,38579,0);
INSERT INTO "django_geo_db_location" VALUES(66664,NULL,'El Paso, TX 88585',26059,222,NULL,51,38580,0);
INSERT INTO "django_geo_db_location" VALUES(66665,NULL,'El Paso, TX 88586',26059,222,NULL,51,38581,0);
INSERT INTO "django_geo_db_location" VALUES(66666,NULL,'El Paso, TX 88587',26059,222,NULL,51,38582,0);
INSERT INTO "django_geo_db_location" VALUES(66667,NULL,'El Paso, TX 88588',26059,222,NULL,51,38583,0);
INSERT INTO "django_geo_db_location" VALUES(66668,NULL,'El Paso, TX 88589',26059,222,NULL,51,38584,0);
INSERT INTO "django_geo_db_location" VALUES(66669,NULL,'El Paso, TX 88590',26059,222,NULL,51,38585,0);
INSERT INTO "django_geo_db_location" VALUES(66670,NULL,'El Paso, TX 88595',26059,222,NULL,51,38586,0);
INSERT INTO "django_geo_db_location" VALUES(66671,NULL,'Roswell, NM 88603',27715,222,NULL,31,38587,0);
INSERT INTO "django_geo_db_location" VALUES(66672,NULL,'The Lakes, NV',27792,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66673,NULL,'The Lakes, NV 88901',27792,222,NULL,28,38588,0);
INSERT INTO "django_geo_db_location" VALUES(66674,NULL,'The Lakes, NV 88905',27792,222,NULL,28,38589,0);
INSERT INTO "django_geo_db_location" VALUES(66675,NULL,'Alamo, NV',27793,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66676,NULL,'Alamo, NV 89001',27793,222,NULL,28,38590,0);
INSERT INTO "django_geo_db_location" VALUES(66677,NULL,'Beatty, NV',27794,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66678,NULL,'Beatty, NV 89003',27794,222,NULL,28,38591,0);
INSERT INTO "django_geo_db_location" VALUES(66679,NULL,'Blue Diamond, NV',27795,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66680,NULL,'Blue Diamond, NV 89004',27795,222,NULL,28,38592,0);
INSERT INTO "django_geo_db_location" VALUES(66681,NULL,'Boulder City, NV',27796,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66682,NULL,'Boulder City, NV 89005',27796,222,NULL,28,38593,0);
INSERT INTO "django_geo_db_location" VALUES(66683,NULL,'Boulder City, NV 89006',27796,222,NULL,28,38594,0);
INSERT INTO "django_geo_db_location" VALUES(66684,NULL,'Bunkerville, NV',27797,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66685,NULL,'Bunkerville, NV 89007',27797,222,NULL,28,38595,0);
INSERT INTO "django_geo_db_location" VALUES(66686,NULL,'Caliente, NV',27798,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66687,NULL,'Caliente, NV 89008',27798,222,NULL,28,38596,0);
INSERT INTO "django_geo_db_location" VALUES(66688,NULL,'Henderson, NV',27799,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66689,NULL,'Henderson, NV 89009',27799,222,NULL,28,38597,0);
INSERT INTO "django_geo_db_location" VALUES(66690,NULL,'Dyer, NV',27800,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66691,NULL,'Dyer, NV 89010',27800,222,NULL,28,38598,0);
INSERT INTO "django_geo_db_location" VALUES(66692,NULL,'Henderson, NV 89011',27799,222,NULL,28,38599,0);
INSERT INTO "django_geo_db_location" VALUES(66693,NULL,'Henderson, NV 89012',27799,222,NULL,28,38600,0);
INSERT INTO "django_geo_db_location" VALUES(66694,NULL,'Goldfield, NV',27801,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66695,NULL,'Goldfield, NV 89013',27801,222,NULL,28,38601,0);
INSERT INTO "django_geo_db_location" VALUES(66696,NULL,'Henderson, NV 89014',27799,222,NULL,28,38602,0);
INSERT INTO "django_geo_db_location" VALUES(66697,NULL,'Henderson, NV 89015',27799,222,NULL,28,38603,0);
INSERT INTO "django_geo_db_location" VALUES(66698,NULL,'Henderson, NV 89016',27799,222,NULL,28,38604,0);
INSERT INTO "django_geo_db_location" VALUES(66699,NULL,'Hiko, NV',27802,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66700,NULL,'Hiko, NV 89017',27802,222,NULL,28,38605,0);
INSERT INTO "django_geo_db_location" VALUES(66701,NULL,'Indian Springs, NV',27803,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66702,NULL,'Indian Springs, NV 89018',27803,222,NULL,28,38606,0);
INSERT INTO "django_geo_db_location" VALUES(66703,NULL,'Jean, NV',27804,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66704,NULL,'Jean, NV 89019',27804,222,NULL,28,38607,0);
INSERT INTO "django_geo_db_location" VALUES(66705,NULL,'Amargosa Valley, NV',27805,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66706,NULL,'Amargosa Valley, NV 89020',27805,222,NULL,28,38608,0);
INSERT INTO "django_geo_db_location" VALUES(66707,NULL,'Logandale, NV',27806,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66708,NULL,'Logandale, NV 89021',27806,222,NULL,28,38609,0);
INSERT INTO "django_geo_db_location" VALUES(66709,NULL,'Manhattan, NV',27807,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66710,NULL,'Manhattan, NV 89022',27807,222,NULL,28,38610,0);
INSERT INTO "django_geo_db_location" VALUES(66711,NULL,'Mercury, NV',27808,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66712,NULL,'Mercury, NV 89023',27808,222,NULL,28,38611,0);
INSERT INTO "django_geo_db_location" VALUES(66713,NULL,'Mesquite, AZ',27809,222,NULL,3,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66714,NULL,'Mesquite, AZ 89024',27809,222,NULL,3,38612,0);
INSERT INTO "django_geo_db_location" VALUES(66715,NULL,'Moapa, NV',27810,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66716,NULL,'Moapa, NV 89025',27810,222,NULL,28,38613,0);
INSERT INTO "django_geo_db_location" VALUES(66717,NULL,'Jean, NV 89026',27804,222,NULL,28,38614,0);
INSERT INTO "django_geo_db_location" VALUES(66718,NULL,'Mesquite, NV',27811,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66719,NULL,'Mesquite, NV 89027',27811,222,NULL,28,38615,0);
INSERT INTO "django_geo_db_location" VALUES(66720,NULL,'Laughlin, NV',27812,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66721,NULL,'Laughlin, NV 89028',27812,222,NULL,28,38616,0);
INSERT INTO "django_geo_db_location" VALUES(66722,NULL,'Laughlin, NV 89029',27812,222,NULL,28,38617,0);
INSERT INTO "django_geo_db_location" VALUES(66723,NULL,'North Las Vegas, NV',27813,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66724,NULL,'North Las Vegas, NV 89030',27813,222,NULL,28,38618,0);
INSERT INTO "django_geo_db_location" VALUES(66725,NULL,'North Las Vegas, NV 89031',27813,222,NULL,28,38619,0);
INSERT INTO "django_geo_db_location" VALUES(66726,NULL,'North Las Vegas, NV 89032',27813,222,NULL,28,38620,0);
INSERT INTO "django_geo_db_location" VALUES(66727,NULL,'North Las Vegas, NV 89033',27813,222,NULL,28,38621,0);
INSERT INTO "django_geo_db_location" VALUES(66728,NULL,'North Las Vegas, NV 89036',27813,222,NULL,28,38622,0);
INSERT INTO "django_geo_db_location" VALUES(66729,NULL,'Cal Nev Ari, NV',27814,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66730,NULL,'Cal Nev Ari, NV 89039',27814,222,NULL,28,38623,0);
INSERT INTO "django_geo_db_location" VALUES(66731,NULL,'Overton, NV',27815,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66732,NULL,'Overton, NV 89040',27815,222,NULL,28,38624,0);
INSERT INTO "django_geo_db_location" VALUES(66733,NULL,'Pahrump, NV',27816,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66734,NULL,'Pahrump, NV 89041',27816,222,NULL,28,38625,0);
INSERT INTO "django_geo_db_location" VALUES(66735,NULL,'Panaca, NV',27817,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66736,NULL,'Panaca, NV 89042',27817,222,NULL,28,38626,0);
INSERT INTO "django_geo_db_location" VALUES(66737,NULL,'Pioche, NV',27818,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66738,NULL,'Pioche, NV 89043',27818,222,NULL,28,38627,0);
INSERT INTO "django_geo_db_location" VALUES(66739,NULL,'Round Mountain, NV',27819,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66740,NULL,'Round Mountain, NV 89045',27819,222,NULL,28,38628,0);
INSERT INTO "django_geo_db_location" VALUES(66741,NULL,'Searchlight, NV',27820,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66742,NULL,'Searchlight, NV 89046',27820,222,NULL,28,38629,0);
INSERT INTO "django_geo_db_location" VALUES(66743,NULL,'Silverpeak, NV',27821,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66744,NULL,'Silverpeak, NV 89047',27821,222,NULL,28,38630,0);
INSERT INTO "django_geo_db_location" VALUES(66745,NULL,'Pahrump, NV 89048',27816,222,NULL,28,38631,0);
INSERT INTO "django_geo_db_location" VALUES(66746,NULL,'Tonopah, NV',27822,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66747,NULL,'Tonopah, NV 89049',27822,222,NULL,28,38632,0);
INSERT INTO "django_geo_db_location" VALUES(66748,NULL,'Henderson, NV 89052',27799,222,NULL,28,38633,0);
INSERT INTO "django_geo_db_location" VALUES(66749,NULL,'Henderson, NV 89053',27799,222,NULL,28,38634,0);
INSERT INTO "django_geo_db_location" VALUES(66750,NULL,'Pahrump, NV 89060',27816,222,NULL,28,38635,0);
INSERT INTO "django_geo_db_location" VALUES(66751,NULL,'Pahrump, NV 89061',27816,222,NULL,28,38636,0);
INSERT INTO "django_geo_db_location" VALUES(66752,NULL,'Indian Springs, NV 89070',27803,222,NULL,28,38637,0);
INSERT INTO "django_geo_db_location" VALUES(66753,NULL,'Henderson, NV 89074',27799,222,NULL,28,38638,0);
INSERT INTO "django_geo_db_location" VALUES(66754,NULL,'Indian Springs, NV 89081',27803,222,NULL,28,38639,0);
INSERT INTO "django_geo_db_location" VALUES(66755,NULL,'North Las Vegas, NV 89084',27813,222,NULL,28,38640,0);
INSERT INTO "django_geo_db_location" VALUES(66756,NULL,'North Las Vegas, NV 89086',27813,222,NULL,28,38641,0);
INSERT INTO "django_geo_db_location" VALUES(66757,NULL,'Las Vegas, NV',27823,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66758,NULL,'Las Vegas, NV 89101',27823,222,NULL,28,38642,0);
INSERT INTO "django_geo_db_location" VALUES(66759,NULL,'Las Vegas, NV 89102',27823,222,NULL,28,38643,0);
INSERT INTO "django_geo_db_location" VALUES(66760,NULL,'Las Vegas, NV 89103',27823,222,NULL,28,38644,0);
INSERT INTO "django_geo_db_location" VALUES(66761,NULL,'Las Vegas, NV 89104',27823,222,NULL,28,38645,0);
INSERT INTO "django_geo_db_location" VALUES(66762,NULL,'Las Vegas, NV 89106',27823,222,NULL,28,38646,0);
INSERT INTO "django_geo_db_location" VALUES(66763,NULL,'Las Vegas, NV 89107',27823,222,NULL,28,38647,0);
INSERT INTO "django_geo_db_location" VALUES(66764,NULL,'Las Vegas, NV 89108',27823,222,NULL,28,38648,0);
INSERT INTO "django_geo_db_location" VALUES(66765,NULL,'Las Vegas, NV 89109',27823,222,NULL,28,38649,0);
INSERT INTO "django_geo_db_location" VALUES(66766,NULL,'Las Vegas, NV 89110',27823,222,NULL,28,38650,0);
INSERT INTO "django_geo_db_location" VALUES(66767,NULL,'Las Vegas, NV 89111',27823,222,NULL,28,38651,0);
INSERT INTO "django_geo_db_location" VALUES(66768,NULL,'Las Vegas, NV 89112',27823,222,NULL,28,38652,0);
INSERT INTO "django_geo_db_location" VALUES(66769,NULL,'Las Vegas, NV 89113',27823,222,NULL,28,38653,0);
INSERT INTO "django_geo_db_location" VALUES(66770,NULL,'Las Vegas, NV 89114',27823,222,NULL,28,38654,0);
INSERT INTO "django_geo_db_location" VALUES(66771,NULL,'Las Vegas, NV 89115',27823,222,NULL,28,38655,0);
INSERT INTO "django_geo_db_location" VALUES(66772,NULL,'Las Vegas, NV 89116',27823,222,NULL,28,38656,0);
INSERT INTO "django_geo_db_location" VALUES(66773,NULL,'Las Vegas, NV 89117',27823,222,NULL,28,38657,0);
INSERT INTO "django_geo_db_location" VALUES(66774,NULL,'Las Vegas, NV 89118',27823,222,NULL,28,38658,0);
INSERT INTO "django_geo_db_location" VALUES(66775,NULL,'Las Vegas, NV 89119',27823,222,NULL,28,38659,0);
INSERT INTO "django_geo_db_location" VALUES(66776,NULL,'Las Vegas, NV 89120',27823,222,NULL,28,38660,0);
INSERT INTO "django_geo_db_location" VALUES(66777,NULL,'Las Vegas, NV 89121',27823,222,NULL,28,38661,0);
INSERT INTO "django_geo_db_location" VALUES(66778,NULL,'Las Vegas, NV 89122',27823,222,NULL,28,38662,0);
INSERT INTO "django_geo_db_location" VALUES(66779,NULL,'Las Vegas, NV 89123',27823,222,NULL,28,38663,0);
INSERT INTO "django_geo_db_location" VALUES(66780,NULL,'Las Vegas, NV 89124',27823,222,NULL,28,38664,0);
INSERT INTO "django_geo_db_location" VALUES(66781,NULL,'Las Vegas, NV 89125',27823,222,NULL,28,38665,0);
INSERT INTO "django_geo_db_location" VALUES(66782,NULL,'Las Vegas, NV 89126',27823,222,NULL,28,38666,0);
INSERT INTO "django_geo_db_location" VALUES(66783,NULL,'Las Vegas, NV 89127',27823,222,NULL,28,38667,0);
INSERT INTO "django_geo_db_location" VALUES(66784,NULL,'Las Vegas, NV 89128',27823,222,NULL,28,38668,0);
INSERT INTO "django_geo_db_location" VALUES(66785,NULL,'Las Vegas, NV 89129',27823,222,NULL,28,38669,0);
INSERT INTO "django_geo_db_location" VALUES(66786,NULL,'Las Vegas, NV 89130',27823,222,NULL,28,38670,0);
INSERT INTO "django_geo_db_location" VALUES(66787,NULL,'Las Vegas, NV 89131',27823,222,NULL,28,38671,0);
INSERT INTO "django_geo_db_location" VALUES(66788,NULL,'Las Vegas, NV 89132',27823,222,NULL,28,38672,0);
INSERT INTO "django_geo_db_location" VALUES(66789,NULL,'Las Vegas, NV 89133',27823,222,NULL,28,38673,0);
INSERT INTO "django_geo_db_location" VALUES(66790,NULL,'Las Vegas, NV 89134',27823,222,NULL,28,38674,0);
INSERT INTO "django_geo_db_location" VALUES(66791,NULL,'Las Vegas, NV 89135',27823,222,NULL,28,38675,0);
INSERT INTO "django_geo_db_location" VALUES(66792,NULL,'Summerlin South, NV',27824,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66793,NULL,'Summerlin South, NV 89136',27824,222,NULL,28,38676,0);
INSERT INTO "django_geo_db_location" VALUES(66794,NULL,'Las Vegas, NV 89137',27823,222,NULL,28,38677,0);
INSERT INTO "django_geo_db_location" VALUES(66795,NULL,'Las Vegas, NV 89138',27823,222,NULL,28,38678,0);
INSERT INTO "django_geo_db_location" VALUES(66796,NULL,'Las Vegas, NV 89139',27823,222,NULL,28,38679,0);
INSERT INTO "django_geo_db_location" VALUES(66797,NULL,'Las Vegas, NV 89141',27823,222,NULL,28,38680,0);
INSERT INTO "django_geo_db_location" VALUES(66798,NULL,'Las Vegas, NV 89142',27823,222,NULL,28,38681,0);
INSERT INTO "django_geo_db_location" VALUES(66799,NULL,'Las Vegas, NV 89143',27823,222,NULL,28,38682,0);
INSERT INTO "django_geo_db_location" VALUES(66800,NULL,'Las Vegas, NV 89144',27823,222,NULL,28,38683,0);
INSERT INTO "django_geo_db_location" VALUES(66801,NULL,'Las Vegas, NV 89145',27823,222,NULL,28,38684,0);
INSERT INTO "django_geo_db_location" VALUES(66802,NULL,'Las Vegas, NV 89146',27823,222,NULL,28,38685,0);
INSERT INTO "django_geo_db_location" VALUES(66803,NULL,'Las Vegas, NV 89147',27823,222,NULL,28,38686,0);
INSERT INTO "django_geo_db_location" VALUES(66804,NULL,'Las Vegas, NV 89148',27823,222,NULL,28,38687,0);
INSERT INTO "django_geo_db_location" VALUES(66805,NULL,'Las Vegas, NV 89149',27823,222,NULL,28,38688,0);
INSERT INTO "django_geo_db_location" VALUES(66806,NULL,'Las Vegas, NV 89150',27823,222,NULL,28,38689,0);
INSERT INTO "django_geo_db_location" VALUES(66807,NULL,'Las Vegas, NV 89151',27823,222,NULL,28,38690,0);
INSERT INTO "django_geo_db_location" VALUES(66808,NULL,'Las Vegas, NV 89152',27823,222,NULL,28,38691,0);
INSERT INTO "django_geo_db_location" VALUES(66809,NULL,'Las Vegas, NV 89153',27823,222,NULL,28,38692,0);
INSERT INTO "django_geo_db_location" VALUES(66810,NULL,'Las Vegas, NV 89154',27823,222,NULL,28,38693,0);
INSERT INTO "django_geo_db_location" VALUES(66811,NULL,'Las Vegas, NV 89155',27823,222,NULL,28,38694,0);
INSERT INTO "django_geo_db_location" VALUES(66812,NULL,'Las Vegas, NV 89156',27823,222,NULL,28,38695,0);
INSERT INTO "django_geo_db_location" VALUES(66813,NULL,'Las Vegas, NV 89158',27823,222,NULL,28,38696,0);
INSERT INTO "django_geo_db_location" VALUES(66814,NULL,'Las Vegas, NV 89159',27823,222,NULL,28,38697,0);
INSERT INTO "django_geo_db_location" VALUES(66815,NULL,'Las Vegas, NV 89160',27823,222,NULL,28,38698,0);
INSERT INTO "django_geo_db_location" VALUES(66816,NULL,'The Lakes, NV 89163',27792,222,NULL,28,38699,0);
INSERT INTO "django_geo_db_location" VALUES(66817,NULL,'Las Vegas, NV 89164',27823,222,NULL,28,38700,0);
INSERT INTO "django_geo_db_location" VALUES(66818,NULL,'Las Vegas, NV 89170',27823,222,NULL,28,38701,0);
INSERT INTO "django_geo_db_location" VALUES(66819,NULL,'Las Vegas, NV 89173',27823,222,NULL,28,38702,0);
INSERT INTO "django_geo_db_location" VALUES(66820,NULL,'Las Vegas, NV 89177',27823,222,NULL,28,38703,0);
INSERT INTO "django_geo_db_location" VALUES(66821,NULL,'Las Vegas, NV 89180',27823,222,NULL,28,38704,0);
INSERT INTO "django_geo_db_location" VALUES(66822,NULL,'Las Vegas, NV 89185',27823,222,NULL,28,38705,0);
INSERT INTO "django_geo_db_location" VALUES(66823,NULL,'Nellis AFB, NV',27825,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66824,NULL,'Nellis AFB, NV 89191',27825,222,NULL,28,38706,0);
INSERT INTO "django_geo_db_location" VALUES(66825,NULL,'Las Vegas, NV 89193',27823,222,NULL,28,38707,0);
INSERT INTO "django_geo_db_location" VALUES(66826,NULL,'Las Vegas, NV 89195',27823,222,NULL,28,38708,0);
INSERT INTO "django_geo_db_location" VALUES(66827,NULL,'Las Vegas, NV 89199',27823,222,NULL,28,38709,0);
INSERT INTO "django_geo_db_location" VALUES(66828,NULL,'Ely, NV',27826,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66829,NULL,'Ely, NV 89301',27826,222,NULL,28,38710,0);
INSERT INTO "django_geo_db_location" VALUES(66830,NULL,'Austin, NV',27827,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66831,NULL,'Austin, NV 89310',27827,222,NULL,28,38711,0);
INSERT INTO "django_geo_db_location" VALUES(66832,NULL,'Baker, NV',27828,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66833,NULL,'Baker, NV 89311',27828,222,NULL,28,38712,0);
INSERT INTO "django_geo_db_location" VALUES(66834,NULL,'Duckwater, NV',27829,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66835,NULL,'Duckwater, NV 89314',27829,222,NULL,28,38713,0);
INSERT INTO "django_geo_db_location" VALUES(66836,NULL,'Ely, NV 89315',27826,222,NULL,28,38714,0);
INSERT INTO "django_geo_db_location" VALUES(66837,NULL,'Eureka, NV',27830,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66838,NULL,'Eureka, NV 89316',27830,222,NULL,28,38715,0);
INSERT INTO "django_geo_db_location" VALUES(66839,NULL,'Lund, NV',27831,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66840,NULL,'Lund, NV 89317',27831,222,NULL,28,38716,0);
INSERT INTO "django_geo_db_location" VALUES(66841,NULL,'McGill, NV',27832,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66842,NULL,'McGill, NV 89318',27832,222,NULL,28,38717,0);
INSERT INTO "django_geo_db_location" VALUES(66843,NULL,'Ruth, NV',27833,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66844,NULL,'Ruth, NV 89319',27833,222,NULL,28,38718,0);
INSERT INTO "django_geo_db_location" VALUES(66845,NULL,'Crystal Bay, NV',27834,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66846,NULL,'Crystal Bay, NV 89402',27834,222,NULL,28,38719,0);
INSERT INTO "django_geo_db_location" VALUES(66847,NULL,'Dayton, NV',27835,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66848,NULL,'Dayton, NV 89403',27835,222,NULL,28,38720,0);
INSERT INTO "django_geo_db_location" VALUES(66849,NULL,'Denio, NV',27836,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66850,NULL,'Denio, NV 89404',27836,222,NULL,28,38721,0);
INSERT INTO "django_geo_db_location" VALUES(66851,NULL,'Empire, NV',27837,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66852,NULL,'Empire, NV 89405',27837,222,NULL,28,38722,0);
INSERT INTO "django_geo_db_location" VALUES(66853,NULL,'Fallon, NV',27838,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66854,NULL,'Fallon, NV 89406',27838,222,NULL,28,38723,0);
INSERT INTO "django_geo_db_location" VALUES(66855,NULL,'Fallon, NV 89407',27838,222,NULL,28,38724,0);
INSERT INTO "django_geo_db_location" VALUES(66856,NULL,'Fernley, NV',27839,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66857,NULL,'Fernley, NV 89408',27839,222,NULL,28,38725,0);
INSERT INTO "django_geo_db_location" VALUES(66858,NULL,'Gabbs, NV',27840,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66859,NULL,'Gabbs, NV 89409',27840,222,NULL,28,38726,0);
INSERT INTO "django_geo_db_location" VALUES(66860,NULL,'Gardnerville, NV',27841,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66861,NULL,'Gardnerville, NV 89410',27841,222,NULL,28,38727,0);
INSERT INTO "django_geo_db_location" VALUES(66862,NULL,'Genoa, NV',27842,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66863,NULL,'Genoa, NV 89411',27842,222,NULL,28,38728,0);
INSERT INTO "django_geo_db_location" VALUES(66864,NULL,'Gerlach, NV',27843,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66865,NULL,'Gerlach, NV 89412',27843,222,NULL,28,38729,0);
INSERT INTO "django_geo_db_location" VALUES(66866,NULL,'Glenbrook, NV',27844,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66867,NULL,'Glenbrook, NV 89413',27844,222,NULL,28,38730,0);
INSERT INTO "django_geo_db_location" VALUES(66868,NULL,'Golconda, NV',27845,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66869,NULL,'Golconda, NV 89414',27845,222,NULL,28,38731,0);
INSERT INTO "django_geo_db_location" VALUES(66870,NULL,'Hawthorne, NV',27846,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66871,NULL,'Hawthorne, NV 89415',27846,222,NULL,28,38732,0);
INSERT INTO "django_geo_db_location" VALUES(66872,NULL,'Imlay, NV',27847,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66873,NULL,'Imlay, NV 89418',27847,222,NULL,28,38733,0);
INSERT INTO "django_geo_db_location" VALUES(66874,NULL,'Lovelock, NV',27848,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66875,NULL,'Lovelock, NV 89419',27848,222,NULL,28,38734,0);
INSERT INTO "django_geo_db_location" VALUES(66876,NULL,'Luning, NV',27849,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66877,NULL,'Luning, NV 89420',27849,222,NULL,28,38735,0);
INSERT INTO "django_geo_db_location" VALUES(66878,NULL,'McDermitt, NV',27850,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66879,NULL,'McDermitt, NV 89421',27850,222,NULL,28,38736,0);
INSERT INTO "django_geo_db_location" VALUES(66880,NULL,'Mina, NV',27851,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66881,NULL,'Mina, NV 89422',27851,222,NULL,28,38737,0);
INSERT INTO "django_geo_db_location" VALUES(66882,NULL,'Minden, NV',27852,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66883,NULL,'Minden, NV 89423',27852,222,NULL,28,38738,0);
INSERT INTO "django_geo_db_location" VALUES(66884,NULL,'Nixon, NV',27853,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66885,NULL,'Nixon, NV 89424',27853,222,NULL,28,38739,0);
INSERT INTO "django_geo_db_location" VALUES(66886,NULL,'Orovada, NV',27854,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66887,NULL,'Orovada, NV 89425',27854,222,NULL,28,38740,0);
INSERT INTO "django_geo_db_location" VALUES(66888,NULL,'Paradise Valley, NV',27855,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66889,NULL,'Paradise Valley, NV 89426',27855,222,NULL,28,38741,0);
INSERT INTO "django_geo_db_location" VALUES(66890,NULL,'Schurz, NV',27856,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66891,NULL,'Schurz, NV 89427',27856,222,NULL,28,38742,0);
INSERT INTO "django_geo_db_location" VALUES(66892,NULL,'Silver City, NV',27857,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66893,NULL,'Silver City, NV 89428',27857,222,NULL,28,38743,0);
INSERT INTO "django_geo_db_location" VALUES(66894,NULL,'Silver Springs, NV',27858,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66895,NULL,'Silver Springs, NV 89429',27858,222,NULL,28,38744,0);
INSERT INTO "django_geo_db_location" VALUES(66896,NULL,'Smith, NV',27859,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66897,NULL,'Smith, NV 89430',27859,222,NULL,28,38745,0);
INSERT INTO "django_geo_db_location" VALUES(66898,NULL,'Sparks, NV',27860,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66899,NULL,'Sparks, NV 89431',27860,222,NULL,28,38746,0);
INSERT INTO "django_geo_db_location" VALUES(66900,NULL,'Sparks, NV 89432',27860,222,NULL,28,38747,0);
INSERT INTO "django_geo_db_location" VALUES(66901,NULL,'Sun Valley, NV',27861,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66902,NULL,'Sun Valley, NV 89433',27861,222,NULL,28,38748,0);
INSERT INTO "django_geo_db_location" VALUES(66903,NULL,'Sparks, NV 89434',27860,222,NULL,28,38749,0);
INSERT INTO "django_geo_db_location" VALUES(66904,NULL,'Sparks, NV 89435',27860,222,NULL,28,38750,0);
INSERT INTO "django_geo_db_location" VALUES(66905,NULL,'Sparks, NV 89436',27860,222,NULL,28,38751,0);
INSERT INTO "django_geo_db_location" VALUES(66906,NULL,'Valmy, NV',27862,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66907,NULL,'Valmy, NV 89438',27862,222,NULL,28,38752,0);
INSERT INTO "django_geo_db_location" VALUES(66908,NULL,'Verdi, CA',27863,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66909,NULL,'Verdi, CA 89439',27863,222,NULL,6,38753,0);
INSERT INTO "django_geo_db_location" VALUES(66910,NULL,'Virginia City, NV',27864,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66911,NULL,'Virginia City, NV 89440',27864,222,NULL,28,38754,0);
INSERT INTO "django_geo_db_location" VALUES(66912,NULL,'Wadsworth, NV',27865,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66913,NULL,'Wadsworth, NV 89442',27865,222,NULL,28,38755,0);
INSERT INTO "django_geo_db_location" VALUES(66914,NULL,'Wellington, NV',27866,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66915,NULL,'Wellington, NV 89444',27866,222,NULL,28,38756,0);
INSERT INTO "django_geo_db_location" VALUES(66916,NULL,'Winnemucca, NV',27867,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66917,NULL,'Winnemucca, NV 89445',27867,222,NULL,28,38757,0);
INSERT INTO "django_geo_db_location" VALUES(66918,NULL,'Winnemucca, NV 89446',27867,222,NULL,28,38758,0);
INSERT INTO "django_geo_db_location" VALUES(66919,NULL,'Yerington, NV',27868,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66920,NULL,'Yerington, NV 89447',27868,222,NULL,28,38759,0);
INSERT INTO "django_geo_db_location" VALUES(66921,NULL,'Zephyr Cove, NV',27869,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66922,NULL,'Zephyr Cove, NV 89448',27869,222,NULL,28,38760,0);
INSERT INTO "django_geo_db_location" VALUES(66923,NULL,'Stateline, NV',27870,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66924,NULL,'Stateline, NV 89449',27870,222,NULL,28,38761,0);
INSERT INTO "django_geo_db_location" VALUES(66925,NULL,'Incline Village, NV',27871,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66926,NULL,'Incline Village, NV 89450',27871,222,NULL,28,38762,0);
INSERT INTO "django_geo_db_location" VALUES(66927,NULL,'Incline Village, NV 89451',27871,222,NULL,28,38763,0);
INSERT INTO "django_geo_db_location" VALUES(66928,NULL,'Incline Village, NV 89452',27871,222,NULL,28,38764,0);
INSERT INTO "django_geo_db_location" VALUES(66929,NULL,'Gardnerville Ranchos, NV',27872,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66930,NULL,'Gardnerville Ranchos, NV 89460',27872,222,NULL,28,38765,0);
INSERT INTO "django_geo_db_location" VALUES(66931,NULL,'Fallon, NV 89496',27838,222,NULL,28,38766,0);
INSERT INTO "django_geo_db_location" VALUES(66932,NULL,'Reno, NV',27873,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66933,NULL,'Reno, NV 89501',27873,222,NULL,28,38767,0);
INSERT INTO "django_geo_db_location" VALUES(66934,NULL,'Reno, NV 89502',27873,222,NULL,28,38768,0);
INSERT INTO "django_geo_db_location" VALUES(66935,NULL,'Reno, NV 89503',27873,222,NULL,28,38769,0);
INSERT INTO "django_geo_db_location" VALUES(66936,NULL,'Reno, NV 89504',27873,222,NULL,28,38770,0);
INSERT INTO "django_geo_db_location" VALUES(66937,NULL,'Reno, NV 89505',27873,222,NULL,28,38771,0);
INSERT INTO "django_geo_db_location" VALUES(66938,NULL,'Reno, NV 89506',27873,222,NULL,28,38772,0);
INSERT INTO "django_geo_db_location" VALUES(66939,NULL,'Reno, NV 89507',27873,222,NULL,28,38773,0);
INSERT INTO "django_geo_db_location" VALUES(66940,NULL,'Reno, NV 89509',27873,222,NULL,28,38774,0);
INSERT INTO "django_geo_db_location" VALUES(66941,NULL,'Reno, NV 89510',27873,222,NULL,28,38775,0);
INSERT INTO "django_geo_db_location" VALUES(66942,NULL,'Reno, NV 89511',27873,222,NULL,28,38776,0);
INSERT INTO "django_geo_db_location" VALUES(66943,NULL,'Reno, NV 89512',27873,222,NULL,28,38777,0);
INSERT INTO "django_geo_db_location" VALUES(66944,NULL,'Reno, NV 89513',27873,222,NULL,28,38778,0);
INSERT INTO "django_geo_db_location" VALUES(66945,NULL,'Reno, NV 89515',27873,222,NULL,28,38779,0);
INSERT INTO "django_geo_db_location" VALUES(66946,NULL,'Reno, NV 89520',27873,222,NULL,28,38780,0);
INSERT INTO "django_geo_db_location" VALUES(66947,NULL,'Reno, NV 89521',27873,222,NULL,28,38781,0);
INSERT INTO "django_geo_db_location" VALUES(66948,NULL,'Reno, NV 89523',27873,222,NULL,28,38782,0);
INSERT INTO "django_geo_db_location" VALUES(66949,NULL,'Reno, NV 89533',27873,222,NULL,28,38783,0);
INSERT INTO "django_geo_db_location" VALUES(66950,NULL,'Reno, NV 89557',27873,222,NULL,28,38784,0);
INSERT INTO "django_geo_db_location" VALUES(66951,NULL,'Reno, NV 89564',27873,222,NULL,28,38785,0);
INSERT INTO "django_geo_db_location" VALUES(66952,NULL,'Reno, NV 89570',27873,222,NULL,28,38786,0);
INSERT INTO "django_geo_db_location" VALUES(66953,NULL,'Reno, NV 89595',27873,222,NULL,28,38787,0);
INSERT INTO "django_geo_db_location" VALUES(66954,NULL,'Reno, NV 89599',27873,222,NULL,28,38788,0);
INSERT INTO "django_geo_db_location" VALUES(66955,NULL,'Carson City, NV',27874,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66956,NULL,'Carson City, NV 89701',27874,222,NULL,28,38789,0);
INSERT INTO "django_geo_db_location" VALUES(66957,NULL,'Carson City, NV 89702',27874,222,NULL,28,38790,0);
INSERT INTO "django_geo_db_location" VALUES(66958,NULL,'Carson City, NV 89703',27874,222,NULL,28,38791,0);
INSERT INTO "django_geo_db_location" VALUES(66959,NULL,'Washoe Valley, NV',27875,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66960,NULL,'Washoe Valley, NV 89704',27875,222,NULL,28,38792,0);
INSERT INTO "django_geo_db_location" VALUES(66961,NULL,'Carson City, NV 89705',27874,222,NULL,28,38793,0);
INSERT INTO "django_geo_db_location" VALUES(66962,NULL,'Carson City, NV 89706',27874,222,NULL,28,38794,0);
INSERT INTO "django_geo_db_location" VALUES(66963,NULL,'Carson City, NV 89710',27874,222,NULL,28,38795,0);
INSERT INTO "django_geo_db_location" VALUES(66964,NULL,'Carson City, NV 89711',27874,222,NULL,28,38796,0);
INSERT INTO "django_geo_db_location" VALUES(66965,NULL,'Carson City, NV 89712',27874,222,NULL,28,38797,0);
INSERT INTO "django_geo_db_location" VALUES(66966,NULL,'Carson City, NV 89713',27874,222,NULL,28,38798,0);
INSERT INTO "django_geo_db_location" VALUES(66967,NULL,'Carson City, NV 89714',27874,222,NULL,28,38799,0);
INSERT INTO "django_geo_db_location" VALUES(66968,NULL,'Carson City, NV 89721',27874,222,NULL,28,38800,0);
INSERT INTO "django_geo_db_location" VALUES(66969,NULL,'Kingsbury, NV',27876,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66970,NULL,'Kingsbury, NV 89779',27876,222,NULL,28,38801,0);
INSERT INTO "django_geo_db_location" VALUES(66971,NULL,'Elko, NV',27877,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66972,NULL,'Elko, NV 89801',27877,222,NULL,28,38802,0);
INSERT INTO "django_geo_db_location" VALUES(66973,NULL,'Elko, NV 89802',27877,222,NULL,28,38803,0);
INSERT INTO "django_geo_db_location" VALUES(66974,NULL,'Elko, NV 89803',27877,222,NULL,28,38804,0);
INSERT INTO "django_geo_db_location" VALUES(66975,NULL,'Spring Creek, NV',27878,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66976,NULL,'Spring Creek, NV 89815',27878,222,NULL,28,38805,0);
INSERT INTO "django_geo_db_location" VALUES(66977,NULL,'Battle Mountain, NV',27879,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66978,NULL,'Battle Mountain, NV 89820',27879,222,NULL,28,38806,0);
INSERT INTO "django_geo_db_location" VALUES(66979,NULL,'Crescent Valley, NV',27880,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66980,NULL,'Crescent Valley, NV 89821',27880,222,NULL,28,38807,0);
INSERT INTO "django_geo_db_location" VALUES(66981,NULL,'Carlin, NV',27881,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66982,NULL,'Carlin, NV 89822',27881,222,NULL,28,38808,0);
INSERT INTO "django_geo_db_location" VALUES(66983,NULL,'Deeth, NV',27882,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66984,NULL,'Deeth, NV 89823',27882,222,NULL,28,38809,0);
INSERT INTO "django_geo_db_location" VALUES(66985,NULL,'Halleck, NV',27883,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66986,NULL,'Halleck, NV 89824',27883,222,NULL,28,38810,0);
INSERT INTO "django_geo_db_location" VALUES(66987,NULL,'Jackpot, NV',27884,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66988,NULL,'Jackpot, NV 89825',27884,222,NULL,28,38811,0);
INSERT INTO "django_geo_db_location" VALUES(66989,NULL,'Jarbidge, NV',27885,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66990,NULL,'Jarbidge, NV 89826',27885,222,NULL,28,38812,0);
INSERT INTO "django_geo_db_location" VALUES(66991,NULL,'Lamoille, NV',27886,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66992,NULL,'Lamoille, NV 89828',27886,222,NULL,28,38813,0);
INSERT INTO "django_geo_db_location" VALUES(66993,NULL,'Montello, NV',27887,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66994,NULL,'Montello, NV 89830',27887,222,NULL,28,38814,0);
INSERT INTO "django_geo_db_location" VALUES(66995,NULL,'Mountain City, NV',27888,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66996,NULL,'Mountain City, NV 89831',27888,222,NULL,28,38815,0);
INSERT INTO "django_geo_db_location" VALUES(66997,NULL,'Owyhee, NV',27889,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(66998,NULL,'Owyhee, NV 89832',27889,222,NULL,28,38816,0);
INSERT INTO "django_geo_db_location" VALUES(66999,NULL,'Ruby Valley, NV',27890,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67000,NULL,'Ruby Valley, NV 89833',27890,222,NULL,28,38817,0);
INSERT INTO "django_geo_db_location" VALUES(67001,NULL,'Tuscarora, NV',27891,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67002,NULL,'Tuscarora, NV 89834',27891,222,NULL,28,38818,0);
INSERT INTO "django_geo_db_location" VALUES(67003,NULL,'Wells, NV',27892,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67004,NULL,'Wells, NV 89835',27892,222,NULL,28,38819,0);
INSERT INTO "django_geo_db_location" VALUES(67005,NULL,'West Wendover, NV',27893,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67006,NULL,'West Wendover, NV 89883',27893,222,NULL,28,38820,0);
INSERT INTO "django_geo_db_location" VALUES(67007,NULL,'Gerlach-Empire, NV',27894,222,NULL,28,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67008,NULL,'Gerlach-Empire, NV 89912',27894,222,NULL,28,38821,0);
INSERT INTO "django_geo_db_location" VALUES(67009,NULL,'Los Angeles, CA',27895,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67010,NULL,'Los Angeles, CA 90001',27895,222,NULL,6,38822,0);
INSERT INTO "django_geo_db_location" VALUES(67011,NULL,'Los Angeles, CA 90002',27895,222,NULL,6,38823,0);
INSERT INTO "django_geo_db_location" VALUES(67012,NULL,'Los Angeles, CA 90003',27895,222,NULL,6,38824,0);
INSERT INTO "django_geo_db_location" VALUES(67013,NULL,'Los Angeles, CA 90004',27895,222,NULL,6,38825,0);
INSERT INTO "django_geo_db_location" VALUES(67014,NULL,'Los Angeles, CA 90005',27895,222,NULL,6,38826,0);
INSERT INTO "django_geo_db_location" VALUES(67015,NULL,'Los Angeles, CA 90006',27895,222,NULL,6,38827,0);
INSERT INTO "django_geo_db_location" VALUES(67016,NULL,'Los Angeles, CA 90007',27895,222,NULL,6,38828,0);
INSERT INTO "django_geo_db_location" VALUES(67017,NULL,'Los Angeles, CA 90008',27895,222,NULL,6,38829,0);
INSERT INTO "django_geo_db_location" VALUES(67018,NULL,'Los Angeles, CA 90009',27895,222,NULL,6,38830,0);
INSERT INTO "django_geo_db_location" VALUES(67019,NULL,'Los Angeles, CA 90010',27895,222,NULL,6,38831,0);
INSERT INTO "django_geo_db_location" VALUES(67020,NULL,'Los Angeles, CA 90011',27895,222,NULL,6,38832,0);
INSERT INTO "django_geo_db_location" VALUES(67021,NULL,'Los Angeles, CA 90012',27895,222,NULL,6,38833,0);
INSERT INTO "django_geo_db_location" VALUES(67022,NULL,'Los Angeles, CA 90013',27895,222,NULL,6,38834,0);
INSERT INTO "django_geo_db_location" VALUES(67023,NULL,'Los Angeles, CA 90014',27895,222,NULL,6,38835,0);
INSERT INTO "django_geo_db_location" VALUES(67024,NULL,'Los Angeles, CA 90015',27895,222,NULL,6,38836,0);
INSERT INTO "django_geo_db_location" VALUES(67025,NULL,'Los Angeles, CA 90016',27895,222,NULL,6,38837,0);
INSERT INTO "django_geo_db_location" VALUES(67026,NULL,'Los Angeles, CA 90017',27895,222,NULL,6,38838,0);
INSERT INTO "django_geo_db_location" VALUES(67027,NULL,'Los Angeles, CA 90018',27895,222,NULL,6,38839,0);
INSERT INTO "django_geo_db_location" VALUES(67028,NULL,'Los Angeles, CA 90019',27895,222,NULL,6,38840,0);
INSERT INTO "django_geo_db_location" VALUES(67029,NULL,'Los Angeles, CA 90020',27895,222,NULL,6,38841,0);
INSERT INTO "django_geo_db_location" VALUES(67030,NULL,'Los Angeles, CA 90021',27895,222,NULL,6,38842,0);
INSERT INTO "django_geo_db_location" VALUES(67031,NULL,'Los Angeles, CA 90022',27895,222,NULL,6,38843,0);
INSERT INTO "django_geo_db_location" VALUES(67032,NULL,'Los Angeles, CA 90023',27895,222,NULL,6,38844,0);
INSERT INTO "django_geo_db_location" VALUES(67033,NULL,'Los Angeles, CA 90024',27895,222,NULL,6,38845,0);
INSERT INTO "django_geo_db_location" VALUES(67034,NULL,'Los Angeles, CA 90025',27895,222,NULL,6,38846,0);
INSERT INTO "django_geo_db_location" VALUES(67035,NULL,'Los Angeles, CA 90026',27895,222,NULL,6,38847,0);
INSERT INTO "django_geo_db_location" VALUES(67036,NULL,'Los Angeles, CA 90027',27895,222,NULL,6,38848,0);
INSERT INTO "django_geo_db_location" VALUES(67037,NULL,'Los Angeles, CA 90028',27895,222,NULL,6,38849,0);
INSERT INTO "django_geo_db_location" VALUES(67038,NULL,'Los Angeles, CA 90029',27895,222,NULL,6,38850,0);
INSERT INTO "django_geo_db_location" VALUES(67039,NULL,'Los Angeles, CA 90030',27895,222,NULL,6,38851,0);
INSERT INTO "django_geo_db_location" VALUES(67040,NULL,'Los Angeles, CA 90031',27895,222,NULL,6,38852,0);
INSERT INTO "django_geo_db_location" VALUES(67041,NULL,'Los Angeles, CA 90032',27895,222,NULL,6,38853,0);
INSERT INTO "django_geo_db_location" VALUES(67042,NULL,'Los Angeles, CA 90033',27895,222,NULL,6,38854,0);
INSERT INTO "django_geo_db_location" VALUES(67043,NULL,'Los Angeles, CA 90034',27895,222,NULL,6,38855,0);
INSERT INTO "django_geo_db_location" VALUES(67044,NULL,'Los Angeles, CA 90035',27895,222,NULL,6,38856,0);
INSERT INTO "django_geo_db_location" VALUES(67045,NULL,'Los Angeles, CA 90036',27895,222,NULL,6,38857,0);
INSERT INTO "django_geo_db_location" VALUES(67046,NULL,'Los Angeles, CA 90037',27895,222,NULL,6,38858,0);
INSERT INTO "django_geo_db_location" VALUES(67047,NULL,'Los Angeles, CA 90038',27895,222,NULL,6,38859,0);
INSERT INTO "django_geo_db_location" VALUES(67048,NULL,'Los Angeles, CA 90039',27895,222,NULL,6,38860,0);
INSERT INTO "django_geo_db_location" VALUES(67049,NULL,'Los Angeles, CA 90040',27895,222,NULL,6,38861,0);
INSERT INTO "django_geo_db_location" VALUES(67050,NULL,'Los Angeles, CA 90041',27895,222,NULL,6,38862,0);
INSERT INTO "django_geo_db_location" VALUES(67051,NULL,'Los Angeles, CA 90042',27895,222,NULL,6,38863,0);
INSERT INTO "django_geo_db_location" VALUES(67052,NULL,'Los Angeles, CA 90043',27895,222,NULL,6,38864,0);
INSERT INTO "django_geo_db_location" VALUES(67053,NULL,'Los Angeles, CA 90044',27895,222,NULL,6,38865,0);
INSERT INTO "django_geo_db_location" VALUES(67054,NULL,'Los Angeles, CA 90045',27895,222,NULL,6,38866,0);
INSERT INTO "django_geo_db_location" VALUES(67055,NULL,'Los Angeles, CA 90046',27895,222,NULL,6,38867,0);
INSERT INTO "django_geo_db_location" VALUES(67056,NULL,'Los Angeles, CA 90047',27895,222,NULL,6,38868,0);
INSERT INTO "django_geo_db_location" VALUES(67057,NULL,'Los Angeles, CA 90048',27895,222,NULL,6,38869,0);
INSERT INTO "django_geo_db_location" VALUES(67058,NULL,'Los Angeles, CA 90049',27895,222,NULL,6,38870,0);
INSERT INTO "django_geo_db_location" VALUES(67059,NULL,'Los Angeles, CA 90050',27895,222,NULL,6,38871,0);
INSERT INTO "django_geo_db_location" VALUES(67060,NULL,'Los Angeles, CA 90051',27895,222,NULL,6,38872,0);
INSERT INTO "django_geo_db_location" VALUES(67061,NULL,'Los Angeles, CA 90052',27895,222,NULL,6,38873,0);
INSERT INTO "django_geo_db_location" VALUES(67062,NULL,'Los Angeles, CA 90053',27895,222,NULL,6,38874,0);
INSERT INTO "django_geo_db_location" VALUES(67063,NULL,'Los Angeles, CA 90054',27895,222,NULL,6,38875,0);
INSERT INTO "django_geo_db_location" VALUES(67064,NULL,'Los Angeles, CA 90055',27895,222,NULL,6,38876,0);
INSERT INTO "django_geo_db_location" VALUES(67065,NULL,'Los Angeles, CA 90056',27895,222,NULL,6,38877,0);
INSERT INTO "django_geo_db_location" VALUES(67066,NULL,'Los Angeles, CA 90057',27895,222,NULL,6,38878,0);
INSERT INTO "django_geo_db_location" VALUES(67067,NULL,'Los Angeles, CA 90058',27895,222,NULL,6,38879,0);
INSERT INTO "django_geo_db_location" VALUES(67068,NULL,'Los Angeles, CA 90059',27895,222,NULL,6,38880,0);
INSERT INTO "django_geo_db_location" VALUES(67069,NULL,'Los Angeles, CA 90060',27895,222,NULL,6,38881,0);
INSERT INTO "django_geo_db_location" VALUES(67070,NULL,'Los Angeles, CA 90061',27895,222,NULL,6,38882,0);
INSERT INTO "django_geo_db_location" VALUES(67071,NULL,'Los Angeles, CA 90062',27895,222,NULL,6,38883,0);
INSERT INTO "django_geo_db_location" VALUES(67072,NULL,'Los Angeles, CA 90063',27895,222,NULL,6,38884,0);
INSERT INTO "django_geo_db_location" VALUES(67073,NULL,'Los Angeles, CA 90064',27895,222,NULL,6,38885,0);
INSERT INTO "django_geo_db_location" VALUES(67074,NULL,'Los Angeles, CA 90065',27895,222,NULL,6,38886,0);
INSERT INTO "django_geo_db_location" VALUES(67075,NULL,'Los Angeles, CA 90066',27895,222,NULL,6,38887,0);
INSERT INTO "django_geo_db_location" VALUES(67076,NULL,'Los Angeles, CA 90067',27895,222,NULL,6,38888,0);
INSERT INTO "django_geo_db_location" VALUES(67077,NULL,'Los Angeles, CA 90068',27895,222,NULL,6,38889,0);
INSERT INTO "django_geo_db_location" VALUES(67078,NULL,'West Hollywood, CA',27896,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67079,NULL,'West Hollywood, CA 90069',27896,222,NULL,6,38890,0);
INSERT INTO "django_geo_db_location" VALUES(67080,NULL,'Los Angeles, CA 90070',27895,222,NULL,6,38891,0);
INSERT INTO "django_geo_db_location" VALUES(67081,NULL,'Los Angeles, CA 90071',27895,222,NULL,6,38892,0);
INSERT INTO "django_geo_db_location" VALUES(67082,NULL,'Los Angeles, CA 90072',27895,222,NULL,6,38893,0);
INSERT INTO "django_geo_db_location" VALUES(67083,NULL,'Los Angeles, CA 90073',27895,222,NULL,6,38894,0);
INSERT INTO "django_geo_db_location" VALUES(67084,NULL,'Los Angeles, CA 90074',27895,222,NULL,6,38895,0);
INSERT INTO "django_geo_db_location" VALUES(67085,NULL,'Los Angeles, CA 90075',27895,222,NULL,6,38896,0);
INSERT INTO "django_geo_db_location" VALUES(67086,NULL,'Los Angeles, CA 90076',27895,222,NULL,6,38897,0);
INSERT INTO "django_geo_db_location" VALUES(67087,NULL,'Los Angeles, CA 90077',27895,222,NULL,6,38898,0);
INSERT INTO "django_geo_db_location" VALUES(67088,NULL,'Los Angeles, CA 90078',27895,222,NULL,6,38899,0);
INSERT INTO "django_geo_db_location" VALUES(67089,NULL,'Los Angeles, CA 90079',27895,222,NULL,6,38900,0);
INSERT INTO "django_geo_db_location" VALUES(67090,NULL,'Los Angeles, CA 90080',27895,222,NULL,6,38901,0);
INSERT INTO "django_geo_db_location" VALUES(67091,NULL,'Los Angeles, CA 90081',27895,222,NULL,6,38902,0);
INSERT INTO "django_geo_db_location" VALUES(67092,NULL,'Los Angeles, CA 90082',27895,222,NULL,6,38903,0);
INSERT INTO "django_geo_db_location" VALUES(67093,NULL,'Los Angeles, CA 90083',27895,222,NULL,6,38904,0);
INSERT INTO "django_geo_db_location" VALUES(67094,NULL,'Los Angeles, CA 90084',27895,222,NULL,6,38905,0);
INSERT INTO "django_geo_db_location" VALUES(67095,NULL,'Los Angeles, CA 90086',27895,222,NULL,6,38906,0);
INSERT INTO "django_geo_db_location" VALUES(67096,NULL,'Los Angeles, CA 90087',27895,222,NULL,6,38907,0);
INSERT INTO "django_geo_db_location" VALUES(67097,NULL,'Los Angeles, CA 90088',27895,222,NULL,6,38908,0);
INSERT INTO "django_geo_db_location" VALUES(67098,NULL,'Los Angeles, CA 90089',27895,222,NULL,6,38909,0);
INSERT INTO "django_geo_db_location" VALUES(67099,NULL,'Los Angeles, CA 90091',27895,222,NULL,6,38910,0);
INSERT INTO "django_geo_db_location" VALUES(67100,NULL,'Los Angeles, CA 90093',27895,222,NULL,6,38911,0);
INSERT INTO "django_geo_db_location" VALUES(67101,NULL,'Los Angeles, CA 90094',27895,222,NULL,6,38912,0);
INSERT INTO "django_geo_db_location" VALUES(67102,NULL,'Los Angeles, CA 90095',27895,222,NULL,6,38913,0);
INSERT INTO "django_geo_db_location" VALUES(67103,NULL,'Los Angeles, CA 90096',27895,222,NULL,6,38914,0);
INSERT INTO "django_geo_db_location" VALUES(67104,NULL,'Los Angeles, CA 90097',27895,222,NULL,6,38915,0);
INSERT INTO "django_geo_db_location" VALUES(67105,NULL,'Los Angeles, CA 90099',27895,222,NULL,6,38916,0);
INSERT INTO "django_geo_db_location" VALUES(67106,NULL,'Los Angeles, CA 90101',27895,222,NULL,6,38917,0);
INSERT INTO "django_geo_db_location" VALUES(67107,NULL,'Los Angeles, CA 90102',27895,222,NULL,6,38918,0);
INSERT INTO "django_geo_db_location" VALUES(67108,NULL,'Los Angeles, CA 90103',27895,222,NULL,6,38919,0);
INSERT INTO "django_geo_db_location" VALUES(67109,NULL,'Los Angeles, CA 90174',27895,222,NULL,6,38920,0);
INSERT INTO "django_geo_db_location" VALUES(67110,NULL,'Los Angeles, CA 90185',27895,222,NULL,6,38921,0);
INSERT INTO "django_geo_db_location" VALUES(67111,NULL,'Bell, CA',27897,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67112,NULL,'Bell, CA 90201',27897,222,NULL,6,38922,0);
INSERT INTO "django_geo_db_location" VALUES(67113,NULL,'Bell Gardens, CA',27898,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67114,NULL,'Bell Gardens, CA 90202',27898,222,NULL,6,38923,0);
INSERT INTO "django_geo_db_location" VALUES(67115,NULL,'Inglewood, CA',27899,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67116,NULL,'Inglewood, CA 90204',27899,222,NULL,6,38924,0);
INSERT INTO "django_geo_db_location" VALUES(67117,NULL,'Beverly Hills, CA',27900,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67118,NULL,'Beverly Hills, CA 90209',27900,222,NULL,6,38925,0);
INSERT INTO "django_geo_db_location" VALUES(67119,NULL,'Beverly Hills, CA 90210',27900,222,NULL,6,38926,0);
INSERT INTO "django_geo_db_location" VALUES(67120,NULL,'Beverly Hills, CA 90211',27900,222,NULL,6,38927,0);
INSERT INTO "django_geo_db_location" VALUES(67121,NULL,'Beverly Hills, CA 90212',27900,222,NULL,6,38928,0);
INSERT INTO "django_geo_db_location" VALUES(67122,NULL,'Beverly Hills, CA 90213',27900,222,NULL,6,38929,0);
INSERT INTO "django_geo_db_location" VALUES(67123,NULL,'Compton, CA',27901,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67124,NULL,'Compton, CA 90220',27901,222,NULL,6,38930,0);
INSERT INTO "django_geo_db_location" VALUES(67125,NULL,'Compton, CA 90221',27901,222,NULL,6,38931,0);
INSERT INTO "django_geo_db_location" VALUES(67126,NULL,'Compton, CA 90222',27901,222,NULL,6,38932,0);
INSERT INTO "django_geo_db_location" VALUES(67127,NULL,'Compton, CA 90223',27901,222,NULL,6,38933,0);
INSERT INTO "django_geo_db_location" VALUES(67128,NULL,'Compton, CA 90224',27901,222,NULL,6,38934,0);
INSERT INTO "django_geo_db_location" VALUES(67129,NULL,'Culver City, CA',27902,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67130,NULL,'Culver City, CA 90230',27902,222,NULL,6,38935,0);
INSERT INTO "django_geo_db_location" VALUES(67131,NULL,'Culver City, CA 90231',27902,222,NULL,6,38936,0);
INSERT INTO "django_geo_db_location" VALUES(67132,NULL,'Culver City, CA 90232',27902,222,NULL,6,38937,0);
INSERT INTO "django_geo_db_location" VALUES(67133,NULL,'Culver City, CA 90233',27902,222,NULL,6,38938,0);
INSERT INTO "django_geo_db_location" VALUES(67134,NULL,'Downey, CA',27903,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67135,NULL,'Downey, CA 90239',27903,222,NULL,6,38939,0);
INSERT INTO "django_geo_db_location" VALUES(67136,NULL,'Downey, CA 90240',27903,222,NULL,6,38940,0);
INSERT INTO "django_geo_db_location" VALUES(67137,NULL,'Downey, CA 90241',27903,222,NULL,6,38941,0);
INSERT INTO "django_geo_db_location" VALUES(67138,NULL,'Downey, CA 90242',27903,222,NULL,6,38942,0);
INSERT INTO "django_geo_db_location" VALUES(67139,NULL,'El Segundo, CA',27904,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67140,NULL,'El Segundo, CA 90245',27904,222,NULL,6,38943,0);
INSERT INTO "django_geo_db_location" VALUES(67141,NULL,'Gardena, CA',27905,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67142,NULL,'Gardena, CA 90247',27905,222,NULL,6,38944,0);
INSERT INTO "django_geo_db_location" VALUES(67143,NULL,'Gardena, CA 90248',27905,222,NULL,6,38945,0);
INSERT INTO "django_geo_db_location" VALUES(67144,NULL,'Gardena, CA 90249',27905,222,NULL,6,38946,0);
INSERT INTO "django_geo_db_location" VALUES(67145,NULL,'Hawthorne, CA',27906,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67146,NULL,'Hawthorne, CA 90250',27906,222,NULL,6,38947,0);
INSERT INTO "django_geo_db_location" VALUES(67147,NULL,'Hawthorne, CA 90251',27906,222,NULL,6,38948,0);
INSERT INTO "django_geo_db_location" VALUES(67148,NULL,'Hermosa Beach, CA',27907,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67149,NULL,'Hermosa Beach, CA 90254',27907,222,NULL,6,38949,0);
INSERT INTO "django_geo_db_location" VALUES(67150,NULL,'Huntington Park, CA',27908,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67151,NULL,'Huntington Park, CA 90255',27908,222,NULL,6,38950,0);
INSERT INTO "django_geo_db_location" VALUES(67152,NULL,'Lawndale, CA',27909,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67153,NULL,'Lawndale, CA 90260',27909,222,NULL,6,38951,0);
INSERT INTO "django_geo_db_location" VALUES(67154,NULL,'Lawndale, CA 90261',27909,222,NULL,6,38952,0);
INSERT INTO "django_geo_db_location" VALUES(67155,NULL,'Lynwood, CA',27910,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67156,NULL,'Lynwood, CA 90262',27910,222,NULL,6,38953,0);
INSERT INTO "django_geo_db_location" VALUES(67157,NULL,'Malibu, CA',27911,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67158,NULL,'Malibu, CA 90263',27911,222,NULL,6,38954,0);
INSERT INTO "django_geo_db_location" VALUES(67159,NULL,'Malibu, CA 90264',27911,222,NULL,6,38955,0);
INSERT INTO "django_geo_db_location" VALUES(67160,NULL,'Malibu, CA 90265',27911,222,NULL,6,38956,0);
INSERT INTO "django_geo_db_location" VALUES(67161,NULL,'Manhattan Beach, CA',27912,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67162,NULL,'Manhattan Beach, CA 90266',27912,222,NULL,6,38957,0);
INSERT INTO "django_geo_db_location" VALUES(67163,NULL,'Manhattan Beach, CA 90267',27912,222,NULL,6,38958,0);
INSERT INTO "django_geo_db_location" VALUES(67164,NULL,'Maywood, CA',27913,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67165,NULL,'Maywood, CA 90270',27913,222,NULL,6,38959,0);
INSERT INTO "django_geo_db_location" VALUES(67166,NULL,'Pacific Palisades, CA',27914,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67167,NULL,'Pacific Palisades, CA 90272',27914,222,NULL,6,38960,0);
INSERT INTO "django_geo_db_location" VALUES(67168,NULL,'Palos Verdes Peninsula, CA',27915,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67169,NULL,'Palos Verdes Peninsula, CA 90274',27915,222,NULL,6,38961,0);
INSERT INTO "django_geo_db_location" VALUES(67170,NULL,'Rancho Palos Verdes, CA',27916,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67171,NULL,'Rancho Palos Verdes, CA 90275',27916,222,NULL,6,38962,0);
INSERT INTO "django_geo_db_location" VALUES(67172,NULL,'Redondo Beach, CA',27917,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67173,NULL,'Redondo Beach, CA 90276',27917,222,NULL,6,38963,0);
INSERT INTO "django_geo_db_location" VALUES(67174,NULL,'Redondo Beach, CA 90277',27917,222,NULL,6,38964,0);
INSERT INTO "django_geo_db_location" VALUES(67175,NULL,'Redondo Beach, CA 90278',27917,222,NULL,6,38965,0);
INSERT INTO "django_geo_db_location" VALUES(67176,NULL,'South Gate, CA',27918,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67177,NULL,'South Gate, CA 90280',27918,222,NULL,6,38966,0);
INSERT INTO "django_geo_db_location" VALUES(67178,NULL,'Topanga, CA',27919,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67179,NULL,'Topanga, CA 90290',27919,222,NULL,6,38967,0);
INSERT INTO "django_geo_db_location" VALUES(67180,NULL,'Venice, CA',27920,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67181,NULL,'Venice, CA 90291',27920,222,NULL,6,38968,0);
INSERT INTO "django_geo_db_location" VALUES(67182,NULL,'Marina Del Rey, CA',27921,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67183,NULL,'Marina Del Rey, CA 90292',27921,222,NULL,6,38969,0);
INSERT INTO "django_geo_db_location" VALUES(67184,NULL,'Playa Del Rey, CA',27922,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67185,NULL,'Playa Del Rey, CA 90293',27922,222,NULL,6,38970,0);
INSERT INTO "django_geo_db_location" VALUES(67186,NULL,'Venice, CA 90294',27920,222,NULL,6,38971,0);
INSERT INTO "django_geo_db_location" VALUES(67187,NULL,'Marina Del Rey, CA 90295',27921,222,NULL,6,38972,0);
INSERT INTO "django_geo_db_location" VALUES(67188,NULL,'Playa Del Rey, CA 90296',27922,222,NULL,6,38973,0);
INSERT INTO "django_geo_db_location" VALUES(67189,NULL,'Inglewood, CA 90301',27899,222,NULL,6,38974,0);
INSERT INTO "django_geo_db_location" VALUES(67190,NULL,'Inglewood, CA 90302',27899,222,NULL,6,38975,0);
INSERT INTO "django_geo_db_location" VALUES(67191,NULL,'Inglewood, CA 90303',27899,222,NULL,6,38976,0);
INSERT INTO "django_geo_db_location" VALUES(67192,NULL,'Inglewood, CA 90304',27899,222,NULL,6,38977,0);
INSERT INTO "django_geo_db_location" VALUES(67193,NULL,'Inglewood, CA 90305',27899,222,NULL,6,38978,0);
INSERT INTO "django_geo_db_location" VALUES(67194,NULL,'Inglewood, CA 90306',27899,222,NULL,6,38979,0);
INSERT INTO "django_geo_db_location" VALUES(67195,NULL,'Inglewood, CA 90307',27899,222,NULL,6,38980,0);
INSERT INTO "django_geo_db_location" VALUES(67196,NULL,'Inglewood, CA 90308',27899,222,NULL,6,38981,0);
INSERT INTO "django_geo_db_location" VALUES(67197,NULL,'Inglewood, CA 90309',27899,222,NULL,6,38982,0);
INSERT INTO "django_geo_db_location" VALUES(67198,NULL,'Inglewood, CA 90310',27899,222,NULL,6,38983,0);
INSERT INTO "django_geo_db_location" VALUES(67199,NULL,'Inglewood, CA 90311',27899,222,NULL,6,38984,0);
INSERT INTO "django_geo_db_location" VALUES(67200,NULL,'Inglewood, CA 90312',27899,222,NULL,6,38985,0);
INSERT INTO "django_geo_db_location" VALUES(67201,NULL,'Inglewood, CA 90313',27899,222,NULL,6,38986,0);
INSERT INTO "django_geo_db_location" VALUES(67202,NULL,'Inglewood, CA 90397',27899,222,NULL,6,38987,0);
INSERT INTO "django_geo_db_location" VALUES(67203,NULL,'Inglewood, CA 90398',27899,222,NULL,6,38988,0);
INSERT INTO "django_geo_db_location" VALUES(67204,NULL,'Santa Monica, CA',27923,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67205,NULL,'Santa Monica, CA 90401',27923,222,NULL,6,38989,0);
INSERT INTO "django_geo_db_location" VALUES(67206,NULL,'Santa Monica, CA 90402',27923,222,NULL,6,38990,0);
INSERT INTO "django_geo_db_location" VALUES(67207,NULL,'Santa Monica, CA 90403',27923,222,NULL,6,38991,0);
INSERT INTO "django_geo_db_location" VALUES(67208,NULL,'Santa Monica, CA 90404',27923,222,NULL,6,38992,0);
INSERT INTO "django_geo_db_location" VALUES(67209,NULL,'Santa Monica, CA 90405',27923,222,NULL,6,38993,0);
INSERT INTO "django_geo_db_location" VALUES(67210,NULL,'Santa Monica, CA 90406',27923,222,NULL,6,38994,0);
INSERT INTO "django_geo_db_location" VALUES(67211,NULL,'Santa Monica, CA 90407',27923,222,NULL,6,38995,0);
INSERT INTO "django_geo_db_location" VALUES(67212,NULL,'Santa Monica, CA 90408',27923,222,NULL,6,38996,0);
INSERT INTO "django_geo_db_location" VALUES(67213,NULL,'Santa Monica, CA 90409',27923,222,NULL,6,38997,0);
INSERT INTO "django_geo_db_location" VALUES(67214,NULL,'Santa Monica, CA 90410',27923,222,NULL,6,38998,0);
INSERT INTO "django_geo_db_location" VALUES(67215,NULL,'Santa Monica, CA 90411',27923,222,NULL,6,38999,0);
INSERT INTO "django_geo_db_location" VALUES(67216,NULL,'Santa Monica, CA 90421',27923,222,NULL,6,39000,0);
INSERT INTO "django_geo_db_location" VALUES(67217,NULL,'Torrance, CA',27924,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67218,NULL,'Torrance, CA 90501',27924,222,NULL,6,39001,0);
INSERT INTO "django_geo_db_location" VALUES(67219,NULL,'Torrance, CA 90502',27924,222,NULL,6,39002,0);
INSERT INTO "django_geo_db_location" VALUES(67220,NULL,'Torrance, CA 90503',27924,222,NULL,6,39003,0);
INSERT INTO "django_geo_db_location" VALUES(67221,NULL,'Torrance, CA 90504',27924,222,NULL,6,39004,0);
INSERT INTO "django_geo_db_location" VALUES(67222,NULL,'Torrance, CA 90505',27924,222,NULL,6,39005,0);
INSERT INTO "django_geo_db_location" VALUES(67223,NULL,'Torrance, CA 90506',27924,222,NULL,6,39006,0);
INSERT INTO "django_geo_db_location" VALUES(67224,NULL,'Torrance, CA 90507',27924,222,NULL,6,39007,0);
INSERT INTO "django_geo_db_location" VALUES(67225,NULL,'Torrance, CA 90508',27924,222,NULL,6,39008,0);
INSERT INTO "django_geo_db_location" VALUES(67226,NULL,'Torrance, CA 90509',27924,222,NULL,6,39009,0);
INSERT INTO "django_geo_db_location" VALUES(67227,NULL,'Torrance, CA 90510',27924,222,NULL,6,39010,0);
INSERT INTO "django_geo_db_location" VALUES(67228,NULL,'Whittier, CA',27925,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67229,NULL,'Whittier, CA 90601',27925,222,NULL,6,39011,0);
INSERT INTO "django_geo_db_location" VALUES(67230,NULL,'Whittier, CA 90602',27925,222,NULL,6,39012,0);
INSERT INTO "django_geo_db_location" VALUES(67231,NULL,'Whittier, CA 90603',27925,222,NULL,6,39013,0);
INSERT INTO "django_geo_db_location" VALUES(67232,NULL,'Whittier, CA 90604',27925,222,NULL,6,39014,0);
INSERT INTO "django_geo_db_location" VALUES(67233,NULL,'Whittier, CA 90605',27925,222,NULL,6,39015,0);
INSERT INTO "django_geo_db_location" VALUES(67234,NULL,'Whittier, CA 90606',27925,222,NULL,6,39016,0);
INSERT INTO "django_geo_db_location" VALUES(67235,NULL,'Whittier, CA 90607',27925,222,NULL,6,39017,0);
INSERT INTO "django_geo_db_location" VALUES(67236,NULL,'Whittier, CA 90608',27925,222,NULL,6,39018,0);
INSERT INTO "django_geo_db_location" VALUES(67237,NULL,'Whittier, CA 90609',27925,222,NULL,6,39019,0);
INSERT INTO "django_geo_db_location" VALUES(67238,NULL,'Whittier, CA 90610',27925,222,NULL,6,39020,0);
INSERT INTO "django_geo_db_location" VALUES(67239,NULL,'Whittier, CA 90612',27925,222,NULL,6,39021,0);
INSERT INTO "django_geo_db_location" VALUES(67240,NULL,'Buena Park, CA',27926,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67241,NULL,'Buena Park, CA 90620',27926,222,NULL,6,39022,0);
INSERT INTO "django_geo_db_location" VALUES(67242,NULL,'Buena Park, CA 90621',27926,222,NULL,6,39023,0);
INSERT INTO "django_geo_db_location" VALUES(67243,NULL,'Buena Park, CA 90622',27926,222,NULL,6,39024,0);
INSERT INTO "django_geo_db_location" VALUES(67244,NULL,'La Palma, CA',27927,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67245,NULL,'La Palma, CA 90623',27927,222,NULL,6,39025,0);
INSERT INTO "django_geo_db_location" VALUES(67246,NULL,'Buena Park, CA 90624',27926,222,NULL,6,39026,0);
INSERT INTO "django_geo_db_location" VALUES(67247,NULL,'Cypress, CA',27928,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67248,NULL,'Cypress, CA 90630',27928,222,NULL,6,39027,0);
INSERT INTO "django_geo_db_location" VALUES(67249,NULL,'La Habra, CA',27929,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67250,NULL,'La Habra, CA 90631',27929,222,NULL,6,39028,0);
INSERT INTO "django_geo_db_location" VALUES(67251,NULL,'La Habra, CA 90632',27929,222,NULL,6,39029,0);
INSERT INTO "django_geo_db_location" VALUES(67252,NULL,'La Habra, CA 90633',27929,222,NULL,6,39030,0);
INSERT INTO "django_geo_db_location" VALUES(67253,NULL,'La Mirada, CA',27930,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67254,NULL,'La Mirada, CA 90637',27930,222,NULL,6,39031,0);
INSERT INTO "django_geo_db_location" VALUES(67255,NULL,'La Mirada, CA 90638',27930,222,NULL,6,39032,0);
INSERT INTO "django_geo_db_location" VALUES(67256,NULL,'La Mirada, CA 90639',27930,222,NULL,6,39033,0);
INSERT INTO "django_geo_db_location" VALUES(67257,NULL,'Montebello, CA',27931,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67258,NULL,'Montebello, CA 90640',27931,222,NULL,6,39034,0);
INSERT INTO "django_geo_db_location" VALUES(67259,NULL,'Norwalk, CA',27932,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67260,NULL,'Norwalk, CA 90650',27932,222,NULL,6,39035,0);
INSERT INTO "django_geo_db_location" VALUES(67261,NULL,'Norwalk, CA 90651',27932,222,NULL,6,39036,0);
INSERT INTO "django_geo_db_location" VALUES(67262,NULL,'Norwalk, CA 90652',27932,222,NULL,6,39037,0);
INSERT INTO "django_geo_db_location" VALUES(67263,NULL,'Norwalk, CA 90659',27932,222,NULL,6,39038,0);
INSERT INTO "django_geo_db_location" VALUES(67264,NULL,'Pico Rivera, CA',27933,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67265,NULL,'Pico Rivera, CA 90660',27933,222,NULL,6,39039,0);
INSERT INTO "django_geo_db_location" VALUES(67266,NULL,'Pico Rivera, CA 90661',27933,222,NULL,6,39040,0);
INSERT INTO "django_geo_db_location" VALUES(67267,NULL,'Pico Rivera, CA 90662',27933,222,NULL,6,39041,0);
INSERT INTO "django_geo_db_location" VALUES(67268,NULL,'Pico Rivera, CA 90665',27933,222,NULL,6,39042,0);
INSERT INTO "django_geo_db_location" VALUES(67269,NULL,'Santa Fe Springs, CA',27934,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67270,NULL,'Santa Fe Springs, CA 90670',27934,222,NULL,6,39043,0);
INSERT INTO "django_geo_db_location" VALUES(67271,NULL,'Santa Fe Springs, CA 90671',27934,222,NULL,6,39044,0);
INSERT INTO "django_geo_db_location" VALUES(67272,NULL,'Stanton, CA',27935,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67273,NULL,'Stanton, CA 90680',27935,222,NULL,6,39045,0);
INSERT INTO "django_geo_db_location" VALUES(67274,NULL,'Artesia, CA',27936,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67275,NULL,'Artesia, CA 90701',27936,222,NULL,6,39046,0);
INSERT INTO "django_geo_db_location" VALUES(67276,NULL,'Artesia, CA 90702',27936,222,NULL,6,39047,0);
INSERT INTO "django_geo_db_location" VALUES(67277,NULL,'Cerritos, CA',27937,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67278,NULL,'Cerritos, CA 90703',27937,222,NULL,6,39048,0);
INSERT INTO "django_geo_db_location" VALUES(67279,NULL,'Avalon, CA',27938,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67280,NULL,'Avalon, CA 90704',27938,222,NULL,6,39049,0);
INSERT INTO "django_geo_db_location" VALUES(67281,NULL,'Bellflower, CA',27939,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67282,NULL,'Bellflower, CA 90706',27939,222,NULL,6,39050,0);
INSERT INTO "django_geo_db_location" VALUES(67283,NULL,'Bellflower, CA 90707',27939,222,NULL,6,39051,0);
INSERT INTO "django_geo_db_location" VALUES(67284,NULL,'Harbor City, CA',27940,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67285,NULL,'Harbor City, CA 90710',27940,222,NULL,6,39052,0);
INSERT INTO "django_geo_db_location" VALUES(67286,NULL,'Lakewood, CA',27941,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67287,NULL,'Lakewood, CA 90711',27941,222,NULL,6,39053,0);
INSERT INTO "django_geo_db_location" VALUES(67288,NULL,'Lakewood, CA 90712',27941,222,NULL,6,39054,0);
INSERT INTO "django_geo_db_location" VALUES(67289,NULL,'Lakewood, CA 90713',27941,222,NULL,6,39055,0);
INSERT INTO "django_geo_db_location" VALUES(67290,NULL,'Lakewood, CA 90714',27941,222,NULL,6,39056,0);
INSERT INTO "django_geo_db_location" VALUES(67291,NULL,'Lakewood, CA 90715',27941,222,NULL,6,39057,0);
INSERT INTO "django_geo_db_location" VALUES(67292,NULL,'Hawaiian Gardens, CA',27942,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67293,NULL,'Hawaiian Gardens, CA 90716',27942,222,NULL,6,39058,0);
INSERT INTO "django_geo_db_location" VALUES(67294,NULL,'Lomita, CA',27943,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67295,NULL,'Lomita, CA 90717',27943,222,NULL,6,39059,0);
INSERT INTO "django_geo_db_location" VALUES(67296,NULL,'Los Alamitos, CA',27944,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67297,NULL,'Los Alamitos, CA 90720',27944,222,NULL,6,39060,0);
INSERT INTO "django_geo_db_location" VALUES(67298,NULL,'Los Alamitos, CA 90721',27944,222,NULL,6,39061,0);
INSERT INTO "django_geo_db_location" VALUES(67299,NULL,'Paramount, CA',27945,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67300,NULL,'Paramount, CA 90723',27945,222,NULL,6,39062,0);
INSERT INTO "django_geo_db_location" VALUES(67301,NULL,'San Pedro, CA',27946,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67302,NULL,'San Pedro, CA 90731',27946,222,NULL,6,39063,0);
INSERT INTO "django_geo_db_location" VALUES(67303,NULL,'San Pedro, CA 90732',27946,222,NULL,6,39064,0);
INSERT INTO "django_geo_db_location" VALUES(67304,NULL,'San Pedro, CA 90733',27946,222,NULL,6,39065,0);
INSERT INTO "django_geo_db_location" VALUES(67305,NULL,'San Pedro, CA 90734',27946,222,NULL,6,39066,0);
INSERT INTO "django_geo_db_location" VALUES(67306,NULL,'Seal Beach, CA',27947,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67307,NULL,'Seal Beach, CA 90740',27947,222,NULL,6,39067,0);
INSERT INTO "django_geo_db_location" VALUES(67308,NULL,'Sunset Beach, CA',27948,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67309,NULL,'Sunset Beach, CA 90742',27948,222,NULL,6,39068,0);
INSERT INTO "django_geo_db_location" VALUES(67310,NULL,'Surfside, CA',27949,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67311,NULL,'Surfside, CA 90743',27949,222,NULL,6,39069,0);
INSERT INTO "django_geo_db_location" VALUES(67312,NULL,'Wilmington, CA',27950,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67313,NULL,'Wilmington, CA 90744',27950,222,NULL,6,39070,0);
INSERT INTO "django_geo_db_location" VALUES(67314,NULL,'Carson, CA',27951,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67315,NULL,'Carson, CA 90745',27951,222,NULL,6,39071,0);
INSERT INTO "django_geo_db_location" VALUES(67316,NULL,'Carson, CA 90746',27951,222,NULL,6,39072,0);
INSERT INTO "django_geo_db_location" VALUES(67317,NULL,'Carson, CA 90747',27951,222,NULL,6,39073,0);
INSERT INTO "django_geo_db_location" VALUES(67318,NULL,'Wilmington, CA 90748',27950,222,NULL,6,39074,0);
INSERT INTO "django_geo_db_location" VALUES(67319,NULL,'Carson, CA 90749',27951,222,NULL,6,39075,0);
INSERT INTO "django_geo_db_location" VALUES(67320,NULL,'Long Beach, CA',27952,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67321,NULL,'Long Beach, CA 90755',27952,222,NULL,6,39076,0);
INSERT INTO "django_geo_db_location" VALUES(67322,NULL,'Los Angeles, CA 90774',27895,222,NULL,6,39077,0);
INSERT INTO "django_geo_db_location" VALUES(67323,NULL,'Long Beach, CA 90801',27952,222,NULL,6,39078,0);
INSERT INTO "django_geo_db_location" VALUES(67324,NULL,'Long Beach, CA 90802',27952,222,NULL,6,39079,0);
INSERT INTO "django_geo_db_location" VALUES(67325,NULL,'Long Beach, CA 90803',27952,222,NULL,6,39080,0);
INSERT INTO "django_geo_db_location" VALUES(67326,NULL,'Long Beach, CA 90804',27952,222,NULL,6,39081,0);
INSERT INTO "django_geo_db_location" VALUES(67327,NULL,'Long Beach, CA 90805',27952,222,NULL,6,39082,0);
INSERT INTO "django_geo_db_location" VALUES(67328,NULL,'Long Beach, CA 90806',27952,222,NULL,6,39083,0);
INSERT INTO "django_geo_db_location" VALUES(67329,NULL,'Long Beach, CA 90807',27952,222,NULL,6,39084,0);
INSERT INTO "django_geo_db_location" VALUES(67330,NULL,'Long Beach, CA 90808',27952,222,NULL,6,39085,0);
INSERT INTO "django_geo_db_location" VALUES(67331,NULL,'Long Beach, CA 90809',27952,222,NULL,6,39086,0);
INSERT INTO "django_geo_db_location" VALUES(67332,NULL,'Long Beach, CA 90810',27952,222,NULL,6,39087,0);
INSERT INTO "django_geo_db_location" VALUES(67333,NULL,'Long Beach, CA 90813',27952,222,NULL,6,39088,0);
INSERT INTO "django_geo_db_location" VALUES(67334,NULL,'Long Beach, CA 90814',27952,222,NULL,6,39089,0);
INSERT INTO "django_geo_db_location" VALUES(67335,NULL,'Long Beach, CA 90815',27952,222,NULL,6,39090,0);
INSERT INTO "django_geo_db_location" VALUES(67336,NULL,'Long Beach, CA 90822',27952,222,NULL,6,39091,0);
INSERT INTO "django_geo_db_location" VALUES(67337,NULL,'Long Beach, CA 90831',27952,222,NULL,6,39092,0);
INSERT INTO "django_geo_db_location" VALUES(67338,NULL,'Long Beach, CA 90832',27952,222,NULL,6,39093,0);
INSERT INTO "django_geo_db_location" VALUES(67339,NULL,'Long Beach, CA 90833',27952,222,NULL,6,39094,0);
INSERT INTO "django_geo_db_location" VALUES(67340,NULL,'Long Beach, CA 90834',27952,222,NULL,6,39095,0);
INSERT INTO "django_geo_db_location" VALUES(67341,NULL,'Long Beach, CA 90835',27952,222,NULL,6,39096,0);
INSERT INTO "django_geo_db_location" VALUES(67342,NULL,'Long Beach, CA 90840',27952,222,NULL,6,39097,0);
INSERT INTO "django_geo_db_location" VALUES(67343,NULL,'Long Beach, CA 90842',27952,222,NULL,6,39098,0);
INSERT INTO "django_geo_db_location" VALUES(67344,NULL,'Long Beach, CA 90844',27952,222,NULL,6,39099,0);
INSERT INTO "django_geo_db_location" VALUES(67345,NULL,'Long Beach, CA 90845',27952,222,NULL,6,39100,0);
INSERT INTO "django_geo_db_location" VALUES(67346,NULL,'Long Beach, CA 90846',27952,222,NULL,6,39101,0);
INSERT INTO "django_geo_db_location" VALUES(67347,NULL,'Long Beach, CA 90847',27952,222,NULL,6,39102,0);
INSERT INTO "django_geo_db_location" VALUES(67348,NULL,'Long Beach, CA 90848',27952,222,NULL,6,39103,0);
INSERT INTO "django_geo_db_location" VALUES(67349,NULL,'Long Beach, CA 90853',27952,222,NULL,6,39104,0);
INSERT INTO "django_geo_db_location" VALUES(67350,NULL,'Rancho Palos Verdes, CA 90879',27916,222,NULL,6,39105,0);
INSERT INTO "django_geo_db_location" VALUES(67351,NULL,'Long Beach, CA 90888',27952,222,NULL,6,39106,0);
INSERT INTO "django_geo_db_location" VALUES(67352,NULL,'Altadena, CA',27953,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67353,NULL,'Altadena, CA 91001',27953,222,NULL,6,39107,0);
INSERT INTO "django_geo_db_location" VALUES(67354,NULL,'Altadena, CA 91003',27953,222,NULL,6,39108,0);
INSERT INTO "django_geo_db_location" VALUES(67355,NULL,'Arcadia, CA',27954,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67356,NULL,'Arcadia, CA 91006',27954,222,NULL,6,39109,0);
INSERT INTO "django_geo_db_location" VALUES(67357,NULL,'Arcadia, CA 91007',27954,222,NULL,6,39110,0);
INSERT INTO "django_geo_db_location" VALUES(67358,NULL,'Duarte, CA',27955,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67359,NULL,'Duarte, CA 91009',27955,222,NULL,6,39111,0);
INSERT INTO "django_geo_db_location" VALUES(67360,NULL,'Duarte, CA 91010',27955,222,NULL,6,39112,0);
INSERT INTO "django_geo_db_location" VALUES(67361,NULL,'La Canada Flintridge, CA',27956,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67362,NULL,'La Canada Flintridge, CA 91011',27956,222,NULL,6,39113,0);
INSERT INTO "django_geo_db_location" VALUES(67363,NULL,'La Canada Flintridge, CA 91012',27956,222,NULL,6,39114,0);
INSERT INTO "django_geo_db_location" VALUES(67364,NULL,'Monrovia, CA',27957,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67365,NULL,'Monrovia, CA 91016',27957,222,NULL,6,39115,0);
INSERT INTO "django_geo_db_location" VALUES(67366,NULL,'Monrovia, CA 91017',27957,222,NULL,6,39116,0);
INSERT INTO "django_geo_db_location" VALUES(67367,NULL,'Montrose, CA',27958,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67368,NULL,'Montrose, CA 91020',27958,222,NULL,6,39117,0);
INSERT INTO "django_geo_db_location" VALUES(67369,NULL,'Montrose, CA 91021',27958,222,NULL,6,39118,0);
INSERT INTO "django_geo_db_location" VALUES(67370,NULL,'Mount Wilson, CA',27959,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67371,NULL,'Mount Wilson, CA 91023',27959,222,NULL,6,39119,0);
INSERT INTO "django_geo_db_location" VALUES(67372,NULL,'Sierra Madre, CA',27960,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67373,NULL,'Sierra Madre, CA 91024',27960,222,NULL,6,39120,0);
INSERT INTO "django_geo_db_location" VALUES(67374,NULL,'Sierra Madre, CA 91025',27960,222,NULL,6,39121,0);
INSERT INTO "django_geo_db_location" VALUES(67375,NULL,'South Pasadena, CA',27961,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67376,NULL,'South Pasadena, CA 91030',27961,222,NULL,6,39122,0);
INSERT INTO "django_geo_db_location" VALUES(67377,NULL,'South Pasadena, CA 91031',27961,222,NULL,6,39123,0);
INSERT INTO "django_geo_db_location" VALUES(67378,NULL,'Sunland, CA',27962,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67379,NULL,'Sunland, CA 91040',27962,222,NULL,6,39124,0);
INSERT INTO "django_geo_db_location" VALUES(67380,NULL,'Sunland, CA 91041',27962,222,NULL,6,39125,0);
INSERT INTO "django_geo_db_location" VALUES(67381,NULL,'Tujunga, CA',27963,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67382,NULL,'Tujunga, CA 91042',27963,222,NULL,6,39126,0);
INSERT INTO "django_geo_db_location" VALUES(67383,NULL,'Tujunga, CA 91043',27963,222,NULL,6,39127,0);
INSERT INTO "django_geo_db_location" VALUES(67384,NULL,'Verdugo City, CA',27964,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67385,NULL,'Verdugo City, CA 91046',27964,222,NULL,6,39128,0);
INSERT INTO "django_geo_db_location" VALUES(67386,NULL,'Pasadena, CA',27965,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67387,NULL,'Pasadena, CA 91050',27965,222,NULL,6,39129,0);
INSERT INTO "django_geo_db_location" VALUES(67388,NULL,'Pasadena, CA 91051',27965,222,NULL,6,39130,0);
INSERT INTO "django_geo_db_location" VALUES(67389,NULL,'Arcadia, CA 91066',27954,222,NULL,6,39131,0);
INSERT INTO "django_geo_db_location" VALUES(67390,NULL,'Arcadia, CA 91077',27954,222,NULL,6,39132,0);
INSERT INTO "django_geo_db_location" VALUES(67391,NULL,'Pasadena, CA 91101',27965,222,NULL,6,39133,0);
INSERT INTO "django_geo_db_location" VALUES(67392,NULL,'Pasadena, CA 91102',27965,222,NULL,6,39134,0);
INSERT INTO "django_geo_db_location" VALUES(67393,NULL,'Pasadena, CA 91103',27965,222,NULL,6,39135,0);
INSERT INTO "django_geo_db_location" VALUES(67394,NULL,'Pasadena, CA 91104',27965,222,NULL,6,39136,0);
INSERT INTO "django_geo_db_location" VALUES(67395,NULL,'Pasadena, CA 91105',27965,222,NULL,6,39137,0);
INSERT INTO "django_geo_db_location" VALUES(67396,NULL,'Pasadena, CA 91106',27965,222,NULL,6,39138,0);
INSERT INTO "django_geo_db_location" VALUES(67397,NULL,'Pasadena, CA 91107',27965,222,NULL,6,39139,0);
INSERT INTO "django_geo_db_location" VALUES(67398,NULL,'San Marino, CA',27966,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67399,NULL,'San Marino, CA 91108',27966,222,NULL,6,39140,0);
INSERT INTO "django_geo_db_location" VALUES(67400,NULL,'Pasadena, CA 91109',27965,222,NULL,6,39141,0);
INSERT INTO "django_geo_db_location" VALUES(67401,NULL,'Pasadena, CA 91110',27965,222,NULL,6,39142,0);
INSERT INTO "django_geo_db_location" VALUES(67402,NULL,'Pasadena, CA 91114',27965,222,NULL,6,39143,0);
INSERT INTO "django_geo_db_location" VALUES(67403,NULL,'Pasadena, CA 91115',27965,222,NULL,6,39144,0);
INSERT INTO "django_geo_db_location" VALUES(67404,NULL,'Pasadena, CA 91116',27965,222,NULL,6,39145,0);
INSERT INTO "django_geo_db_location" VALUES(67405,NULL,'Pasadena, CA 91117',27965,222,NULL,6,39146,0);
INSERT INTO "django_geo_db_location" VALUES(67406,NULL,'San Marino, CA 91118',27966,222,NULL,6,39147,0);
INSERT INTO "django_geo_db_location" VALUES(67407,NULL,'Pasadena, CA 91121',27965,222,NULL,6,39148,0);
INSERT INTO "django_geo_db_location" VALUES(67408,NULL,'Pasadena, CA 91123',27965,222,NULL,6,39149,0);
INSERT INTO "django_geo_db_location" VALUES(67409,NULL,'Pasadena, CA 91124',27965,222,NULL,6,39150,0);
INSERT INTO "django_geo_db_location" VALUES(67410,NULL,'Pasadena, CA 91125',27965,222,NULL,6,39151,0);
INSERT INTO "django_geo_db_location" VALUES(67411,NULL,'Pasadena, CA 91126',27965,222,NULL,6,39152,0);
INSERT INTO "django_geo_db_location" VALUES(67412,NULL,'Pasadena, CA 91129',27965,222,NULL,6,39153,0);
INSERT INTO "django_geo_db_location" VALUES(67413,NULL,'Pasadena, CA 91131',27965,222,NULL,6,39154,0);
INSERT INTO "django_geo_db_location" VALUES(67414,NULL,'Pasadena, CA 91175',27965,222,NULL,6,39155,0);
INSERT INTO "django_geo_db_location" VALUES(67415,NULL,'Pasadena, CA 91182',27965,222,NULL,6,39156,0);
INSERT INTO "django_geo_db_location" VALUES(67416,NULL,'Pasadena, CA 91184',27965,222,NULL,6,39157,0);
INSERT INTO "django_geo_db_location" VALUES(67417,NULL,'Pasadena, CA 91185',27965,222,NULL,6,39158,0);
INSERT INTO "django_geo_db_location" VALUES(67418,NULL,'Pasadena, CA 91186',27965,222,NULL,6,39159,0);
INSERT INTO "django_geo_db_location" VALUES(67419,NULL,'Pasadena, CA 91187',27965,222,NULL,6,39160,0);
INSERT INTO "django_geo_db_location" VALUES(67420,NULL,'Pasadena, CA 91188',27965,222,NULL,6,39161,0);
INSERT INTO "django_geo_db_location" VALUES(67421,NULL,'Pasadena, CA 91189',27965,222,NULL,6,39162,0);
INSERT INTO "django_geo_db_location" VALUES(67422,NULL,'Pasadena, CA 91191',27965,222,NULL,6,39163,0);
INSERT INTO "django_geo_db_location" VALUES(67423,NULL,'Glendale, CA',27967,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67424,NULL,'Glendale, CA 91201',27967,222,NULL,6,39164,0);
INSERT INTO "django_geo_db_location" VALUES(67425,NULL,'Glendale, CA 91202',27967,222,NULL,6,39165,0);
INSERT INTO "django_geo_db_location" VALUES(67426,NULL,'Glendale, CA 91203',27967,222,NULL,6,39166,0);
INSERT INTO "django_geo_db_location" VALUES(67427,NULL,'Glendale, CA 91204',27967,222,NULL,6,39167,0);
INSERT INTO "django_geo_db_location" VALUES(67428,NULL,'Glendale, CA 91205',27967,222,NULL,6,39168,0);
INSERT INTO "django_geo_db_location" VALUES(67429,NULL,'Glendale, CA 91206',27967,222,NULL,6,39169,0);
INSERT INTO "django_geo_db_location" VALUES(67430,NULL,'Glendale, CA 91207',27967,222,NULL,6,39170,0);
INSERT INTO "django_geo_db_location" VALUES(67431,NULL,'Glendale, CA 91208',27967,222,NULL,6,39171,0);
INSERT INTO "django_geo_db_location" VALUES(67432,NULL,'Glendale, CA 91209',27967,222,NULL,6,39172,0);
INSERT INTO "django_geo_db_location" VALUES(67433,NULL,'Glendale, CA 91210',27967,222,NULL,6,39173,0);
INSERT INTO "django_geo_db_location" VALUES(67434,NULL,'La Crescenta, CA',27968,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67435,NULL,'La Crescenta, CA 91214',27968,222,NULL,6,39174,0);
INSERT INTO "django_geo_db_location" VALUES(67436,NULL,'Glendale, CA 91221',27967,222,NULL,6,39175,0);
INSERT INTO "django_geo_db_location" VALUES(67437,NULL,'Glendale, CA 91222',27967,222,NULL,6,39176,0);
INSERT INTO "django_geo_db_location" VALUES(67438,NULL,'La Crescenta, CA 91224',27968,222,NULL,6,39177,0);
INSERT INTO "django_geo_db_location" VALUES(67439,NULL,'Glendale, CA 91225',27967,222,NULL,6,39178,0);
INSERT INTO "django_geo_db_location" VALUES(67440,NULL,'Glendale, CA 91226',27967,222,NULL,6,39179,0);
INSERT INTO "django_geo_db_location" VALUES(67441,NULL,'Agoura Hills, CA',27969,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67442,NULL,'Agoura Hills, CA 91301',27969,222,NULL,6,39180,0);
INSERT INTO "django_geo_db_location" VALUES(67443,NULL,'Calabasas, CA',27970,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67444,NULL,'Calabasas, CA 91302',27970,222,NULL,6,39181,0);
INSERT INTO "django_geo_db_location" VALUES(67445,NULL,'Canoga Park, CA',27971,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67446,NULL,'Canoga Park, CA 91303',27971,222,NULL,6,39182,0);
INSERT INTO "django_geo_db_location" VALUES(67447,NULL,'Canoga Park, CA 91304',27971,222,NULL,6,39183,0);
INSERT INTO "django_geo_db_location" VALUES(67448,NULL,'Canoga Park, CA 91305',27971,222,NULL,6,39184,0);
INSERT INTO "django_geo_db_location" VALUES(67449,NULL,'Winnetka, CA',27972,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67450,NULL,'Winnetka, CA 91306',27972,222,NULL,6,39185,0);
INSERT INTO "django_geo_db_location" VALUES(67451,NULL,'West Hills, CA',27973,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67452,NULL,'West Hills, CA 91307',27973,222,NULL,6,39186,0);
INSERT INTO "django_geo_db_location" VALUES(67453,NULL,'West Hills, CA 91308',27973,222,NULL,6,39187,0);
INSERT INTO "django_geo_db_location" VALUES(67454,NULL,'Canoga Park, CA 91309',27971,222,NULL,6,39188,0);
INSERT INTO "django_geo_db_location" VALUES(67455,NULL,'Castaic, CA',27974,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67456,NULL,'Castaic, CA 91310',27974,222,NULL,6,39189,0);
INSERT INTO "django_geo_db_location" VALUES(67457,NULL,'Chatsworth, CA',27975,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67458,NULL,'Chatsworth, CA 91311',27975,222,NULL,6,39190,0);
INSERT INTO "django_geo_db_location" VALUES(67459,NULL,'Chatsworth, CA 91312',27975,222,NULL,6,39191,0);
INSERT INTO "django_geo_db_location" VALUES(67460,NULL,'Chatsworth, CA 91313',27975,222,NULL,6,39192,0);
INSERT INTO "django_geo_db_location" VALUES(67461,NULL,'Encino, CA',27976,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67462,NULL,'Encino, CA 91316',27976,222,NULL,6,39193,0);
INSERT INTO "django_geo_db_location" VALUES(67463,NULL,'Newbury Park, CA',27977,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67464,NULL,'Newbury Park, CA 91319',27977,222,NULL,6,39194,0);
INSERT INTO "django_geo_db_location" VALUES(67465,NULL,'Newbury Park, CA 91320',27977,222,NULL,6,39195,0);
INSERT INTO "django_geo_db_location" VALUES(67466,NULL,'Newhall, CA',27978,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67467,NULL,'Newhall, CA 91321',27978,222,NULL,6,39196,0);
INSERT INTO "django_geo_db_location" VALUES(67468,NULL,'Newhall, CA 91322',27978,222,NULL,6,39197,0);
INSERT INTO "django_geo_db_location" VALUES(67469,NULL,'Northridge, CA',27979,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67470,NULL,'Northridge, CA 91324',27979,222,NULL,6,39198,0);
INSERT INTO "django_geo_db_location" VALUES(67471,NULL,'Northridge, CA 91325',27979,222,NULL,6,39199,0);
INSERT INTO "django_geo_db_location" VALUES(67472,NULL,'Northridge, CA 91326',27979,222,NULL,6,39200,0);
INSERT INTO "django_geo_db_location" VALUES(67473,NULL,'Northridge, CA 91327',27979,222,NULL,6,39201,0);
INSERT INTO "django_geo_db_location" VALUES(67474,NULL,'Northridge, CA 91328',27979,222,NULL,6,39202,0);
INSERT INTO "django_geo_db_location" VALUES(67475,NULL,'Northridge, CA 91329',27979,222,NULL,6,39203,0);
INSERT INTO "django_geo_db_location" VALUES(67476,NULL,'Northridge, CA 91330',27979,222,NULL,6,39204,0);
INSERT INTO "django_geo_db_location" VALUES(67477,NULL,'Pacoima, CA',27980,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67478,NULL,'Pacoima, CA 91331',27980,222,NULL,6,39205,0);
INSERT INTO "django_geo_db_location" VALUES(67479,NULL,'Pacoima, CA 91333',27980,222,NULL,6,39206,0);
INSERT INTO "django_geo_db_location" VALUES(67480,NULL,'Pacoima, CA 91334',27980,222,NULL,6,39207,0);
INSERT INTO "django_geo_db_location" VALUES(67481,NULL,'Reseda, CA',27981,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67482,NULL,'Reseda, CA 91335',27981,222,NULL,6,39208,0);
INSERT INTO "django_geo_db_location" VALUES(67483,NULL,'Reseda, CA 91337',27981,222,NULL,6,39209,0);
INSERT INTO "django_geo_db_location" VALUES(67484,NULL,'San Fernando, CA',27982,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67485,NULL,'San Fernando, CA 91340',27982,222,NULL,6,39210,0);
INSERT INTO "django_geo_db_location" VALUES(67486,NULL,'San Fernando, CA 91341',27982,222,NULL,6,39211,0);
INSERT INTO "django_geo_db_location" VALUES(67487,NULL,'Sylmar, CA',27983,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67488,NULL,'Sylmar, CA 91342',27983,222,NULL,6,39212,0);
INSERT INTO "django_geo_db_location" VALUES(67489,NULL,'North Hills, CA',27984,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67490,NULL,'North Hills, CA 91343',27984,222,NULL,6,39213,0);
INSERT INTO "django_geo_db_location" VALUES(67491,NULL,'Granada Hills, CA',27985,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67492,NULL,'Granada Hills, CA 91344',27985,222,NULL,6,39214,0);
INSERT INTO "django_geo_db_location" VALUES(67493,NULL,'Mission Hills, CA',27986,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67494,NULL,'Mission Hills, CA 91345',27986,222,NULL,6,39215,0);
INSERT INTO "django_geo_db_location" VALUES(67495,NULL,'Mission Hills, CA 91346',27986,222,NULL,6,39216,0);
INSERT INTO "django_geo_db_location" VALUES(67496,NULL,'Santa Clarita, CA',27987,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67497,NULL,'Santa Clarita, CA 91350',27987,222,NULL,6,39217,0);
INSERT INTO "django_geo_db_location" VALUES(67498,NULL,'Canyon Country, CA',27988,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67499,NULL,'Canyon Country, CA 91351',27988,222,NULL,6,39218,0);
INSERT INTO "django_geo_db_location" VALUES(67500,NULL,'Sun Valley, CA',27989,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67501,NULL,'Sun Valley, CA 91352',27989,222,NULL,6,39219,0);
INSERT INTO "django_geo_db_location" VALUES(67502,NULL,'Sun Valley, CA 91353',27989,222,NULL,6,39220,0);
INSERT INTO "django_geo_db_location" VALUES(67503,NULL,'Valencia, CA',27990,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67504,NULL,'Valencia, CA 91354',27990,222,NULL,6,39221,0);
INSERT INTO "django_geo_db_location" VALUES(67505,NULL,'Valencia, CA 91355',27990,222,NULL,6,39222,0);
INSERT INTO "django_geo_db_location" VALUES(67506,NULL,'Tarzana, CA',27991,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67507,NULL,'Tarzana, CA 91356',27991,222,NULL,6,39223,0);
INSERT INTO "django_geo_db_location" VALUES(67508,NULL,'Tarzana, CA 91357',27991,222,NULL,6,39224,0);
INSERT INTO "django_geo_db_location" VALUES(67509,NULL,'Thousand Oaks, CA',27992,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67510,NULL,'Thousand Oaks, CA 91358',27992,222,NULL,6,39225,0);
INSERT INTO "django_geo_db_location" VALUES(67511,NULL,'Westlake Village, CA',27993,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67512,NULL,'Westlake Village, CA 91359',27993,222,NULL,6,39226,0);
INSERT INTO "django_geo_db_location" VALUES(67513,NULL,'Thousand Oaks, CA 91360',27992,222,NULL,6,39227,0);
INSERT INTO "django_geo_db_location" VALUES(67514,NULL,'Westlake Village, CA 91361',27993,222,NULL,6,39228,0);
INSERT INTO "django_geo_db_location" VALUES(67515,NULL,'Thousand Oaks, CA 91362',27992,222,NULL,6,39229,0);
INSERT INTO "django_geo_db_location" VALUES(67516,NULL,'Westlake Village, CA 91363',27993,222,NULL,6,39230,0);
INSERT INTO "django_geo_db_location" VALUES(67517,NULL,'Woodland Hills, CA',27994,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67518,NULL,'Woodland Hills, CA 91364',27994,222,NULL,6,39231,0);
INSERT INTO "django_geo_db_location" VALUES(67519,NULL,'Woodland Hills, CA 91365',27994,222,NULL,6,39232,0);
INSERT INTO "django_geo_db_location" VALUES(67520,NULL,'Woodland Hills, CA 91367',27994,222,NULL,6,39233,0);
INSERT INTO "django_geo_db_location" VALUES(67521,NULL,'Woodland Hills, CA 91371',27994,222,NULL,6,39234,0);
INSERT INTO "django_geo_db_location" VALUES(67522,NULL,'Calabasas, CA 91372',27970,222,NULL,6,39235,0);
INSERT INTO "django_geo_db_location" VALUES(67523,NULL,'Agoura Hills, CA 91376',27969,222,NULL,6,39236,0);
INSERT INTO "django_geo_db_location" VALUES(67524,NULL,'Oak Park, CA',27995,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67525,NULL,'Oak Park, CA 91377',27995,222,NULL,6,39237,0);
INSERT INTO "django_geo_db_location" VALUES(67526,NULL,'Santa Clarita, CA 91380',27987,222,NULL,6,39238,0);
INSERT INTO "django_geo_db_location" VALUES(67527,NULL,'Stevenson Ranch, CA',27996,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67528,NULL,'Stevenson Ranch, CA 91381',27996,222,NULL,6,39239,0);
INSERT INTO "django_geo_db_location" VALUES(67529,NULL,'Santa Clarita, CA 91382',27987,222,NULL,6,39240,0);
INSERT INTO "django_geo_db_location" VALUES(67530,NULL,'Santa Clarita, CA 91383',27987,222,NULL,6,39241,0);
INSERT INTO "django_geo_db_location" VALUES(67531,NULL,'Castaic, CA 91384',27974,222,NULL,6,39242,0);
INSERT INTO "django_geo_db_location" VALUES(67532,NULL,'Valencia, CA 91385',27990,222,NULL,6,39243,0);
INSERT INTO "django_geo_db_location" VALUES(67533,NULL,'Canyon Country, CA 91386',27988,222,NULL,6,39244,0);
INSERT INTO "django_geo_db_location" VALUES(67534,NULL,'Santa Clarita, CA 91387',27987,222,NULL,6,39245,0);
INSERT INTO "django_geo_db_location" VALUES(67535,NULL,'Van Nuys, CA',27997,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67536,NULL,'Van Nuys, CA 91388',27997,222,NULL,6,39246,0);
INSERT INTO "django_geo_db_location" VALUES(67537,NULL,'Santa Clarita, CA 91390',27987,222,NULL,6,39247,0);
INSERT INTO "django_geo_db_location" VALUES(67538,NULL,'Sylmar, CA 91392',27983,222,NULL,6,39248,0);
INSERT INTO "django_geo_db_location" VALUES(67539,NULL,'North Hills, CA 91393',27984,222,NULL,6,39249,0);
INSERT INTO "django_geo_db_location" VALUES(67540,NULL,'Granada Hills, CA 91394',27985,222,NULL,6,39250,0);
INSERT INTO "django_geo_db_location" VALUES(67541,NULL,'Mission Hills, CA 91395',27986,222,NULL,6,39251,0);
INSERT INTO "django_geo_db_location" VALUES(67542,NULL,'Winnetka, CA 91396',27972,222,NULL,6,39252,0);
INSERT INTO "django_geo_db_location" VALUES(67543,NULL,'Woodland Hills, CA 91399',27994,222,NULL,6,39253,0);
INSERT INTO "django_geo_db_location" VALUES(67544,NULL,'Van Nuys, CA 91401',27997,222,NULL,6,39254,0);
INSERT INTO "django_geo_db_location" VALUES(67545,NULL,'Panorama City, CA',27998,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67546,NULL,'Panorama City, CA 91402',27998,222,NULL,6,39255,0);
INSERT INTO "django_geo_db_location" VALUES(67547,NULL,'Sherman Oaks, CA',27999,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67548,NULL,'Sherman Oaks, CA 91403',27999,222,NULL,6,39256,0);
INSERT INTO "django_geo_db_location" VALUES(67549,NULL,'Van Nuys, CA 91404',27997,222,NULL,6,39257,0);
INSERT INTO "django_geo_db_location" VALUES(67550,NULL,'Van Nuys, CA 91405',27997,222,NULL,6,39258,0);
INSERT INTO "django_geo_db_location" VALUES(67551,NULL,'Van Nuys, CA 91406',27997,222,NULL,6,39259,0);
INSERT INTO "django_geo_db_location" VALUES(67552,NULL,'Van Nuys, CA 91407',27997,222,NULL,6,39260,0);
INSERT INTO "django_geo_db_location" VALUES(67553,NULL,'Van Nuys, CA 91408',27997,222,NULL,6,39261,0);
INSERT INTO "django_geo_db_location" VALUES(67554,NULL,'Van Nuys, CA 91409',27997,222,NULL,6,39262,0);
INSERT INTO "django_geo_db_location" VALUES(67555,NULL,'Van Nuys, CA 91410',27997,222,NULL,6,39263,0);
INSERT INTO "django_geo_db_location" VALUES(67556,NULL,'Van Nuys, CA 91411',27997,222,NULL,6,39264,0);
INSERT INTO "django_geo_db_location" VALUES(67557,NULL,'Panorama City, CA 91412',27998,222,NULL,6,39265,0);
INSERT INTO "django_geo_db_location" VALUES(67558,NULL,'Sherman Oaks, CA 91413',27999,222,NULL,6,39266,0);
INSERT INTO "django_geo_db_location" VALUES(67559,NULL,'Encino, CA 91416',27976,222,NULL,6,39267,0);
INSERT INTO "django_geo_db_location" VALUES(67560,NULL,'Sherman Oaks, CA 91423',27999,222,NULL,6,39268,0);
INSERT INTO "django_geo_db_location" VALUES(67561,NULL,'Encino, CA 91426',27976,222,NULL,6,39269,0);
INSERT INTO "django_geo_db_location" VALUES(67562,NULL,'Encino, CA 91436',27976,222,NULL,6,39270,0);
INSERT INTO "django_geo_db_location" VALUES(67563,NULL,'Van Nuys, CA 91470',27997,222,NULL,6,39271,0);
INSERT INTO "django_geo_db_location" VALUES(67564,NULL,'Van Nuys, CA 91482',27997,222,NULL,6,39272,0);
INSERT INTO "django_geo_db_location" VALUES(67565,NULL,'Sherman Oaks, CA 91495',27999,222,NULL,6,39273,0);
INSERT INTO "django_geo_db_location" VALUES(67566,NULL,'Van Nuys, CA 91496',27997,222,NULL,6,39274,0);
INSERT INTO "django_geo_db_location" VALUES(67567,NULL,'Van Nuys, CA 91497',27997,222,NULL,6,39275,0);
INSERT INTO "django_geo_db_location" VALUES(67568,NULL,'Van Nuys, CA 91499',27997,222,NULL,6,39276,0);
INSERT INTO "django_geo_db_location" VALUES(67569,NULL,'Burbank, CA',28000,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67570,NULL,'Burbank, CA 91501',28000,222,NULL,6,39277,0);
INSERT INTO "django_geo_db_location" VALUES(67571,NULL,'Burbank, CA 91502',28000,222,NULL,6,39278,0);
INSERT INTO "django_geo_db_location" VALUES(67572,NULL,'Burbank, CA 91503',28000,222,NULL,6,39279,0);
INSERT INTO "django_geo_db_location" VALUES(67573,NULL,'Burbank, CA 91504',28000,222,NULL,6,39280,0);
INSERT INTO "django_geo_db_location" VALUES(67574,NULL,'Burbank, CA 91505',28000,222,NULL,6,39281,0);
INSERT INTO "django_geo_db_location" VALUES(67575,NULL,'Burbank, CA 91506',28000,222,NULL,6,39282,0);
INSERT INTO "django_geo_db_location" VALUES(67576,NULL,'Burbank, CA 91507',28000,222,NULL,6,39283,0);
INSERT INTO "django_geo_db_location" VALUES(67577,NULL,'Burbank, CA 91508',28000,222,NULL,6,39284,0);
INSERT INTO "django_geo_db_location" VALUES(67578,NULL,'Burbank, CA 91510',28000,222,NULL,6,39285,0);
INSERT INTO "django_geo_db_location" VALUES(67579,NULL,'Burbank, CA 91521',28000,222,NULL,6,39286,0);
INSERT INTO "django_geo_db_location" VALUES(67580,NULL,'Burbank, CA 91522',28000,222,NULL,6,39287,0);
INSERT INTO "django_geo_db_location" VALUES(67581,NULL,'Burbank, CA 91523',28000,222,NULL,6,39288,0);
INSERT INTO "django_geo_db_location" VALUES(67582,NULL,'Burbank, CA 91526',28000,222,NULL,6,39289,0);
INSERT INTO "django_geo_db_location" VALUES(67583,NULL,'North Hollywood, CA',28001,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67584,NULL,'North Hollywood, CA 91601',28001,222,NULL,6,39290,0);
INSERT INTO "django_geo_db_location" VALUES(67585,NULL,'North Hollywood, CA 91602',28001,222,NULL,6,39291,0);
INSERT INTO "django_geo_db_location" VALUES(67586,NULL,'North Hollywood, CA 91603',28001,222,NULL,6,39292,0);
INSERT INTO "django_geo_db_location" VALUES(67587,NULL,'Studio City, CA',28002,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67588,NULL,'Studio City, CA 91604',28002,222,NULL,6,39293,0);
INSERT INTO "django_geo_db_location" VALUES(67589,NULL,'North Hollywood, CA 91605',28001,222,NULL,6,39294,0);
INSERT INTO "django_geo_db_location" VALUES(67590,NULL,'North Hollywood, CA 91606',28001,222,NULL,6,39295,0);
INSERT INTO "django_geo_db_location" VALUES(67591,NULL,'Valley Village, CA',28003,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67592,NULL,'Valley Village, CA 91607',28003,222,NULL,6,39296,0);
INSERT INTO "django_geo_db_location" VALUES(67593,NULL,'Universal City, CA',28004,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67594,NULL,'Universal City, CA 91608',28004,222,NULL,6,39297,0);
INSERT INTO "django_geo_db_location" VALUES(67595,NULL,'North Hollywood, CA 91609',28001,222,NULL,6,39298,0);
INSERT INTO "django_geo_db_location" VALUES(67596,NULL,'Toluca Lake, CA',28005,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67597,NULL,'Toluca Lake, CA 91610',28005,222,NULL,6,39299,0);
INSERT INTO "django_geo_db_location" VALUES(67598,NULL,'North Hollywood, CA 91611',28001,222,NULL,6,39300,0);
INSERT INTO "django_geo_db_location" VALUES(67599,NULL,'North Hollywood, CA 91612',28001,222,NULL,6,39301,0);
INSERT INTO "django_geo_db_location" VALUES(67600,NULL,'Studio City, CA 91614',28002,222,NULL,6,39302,0);
INSERT INTO "django_geo_db_location" VALUES(67601,NULL,'North Hollywood, CA 91615',28001,222,NULL,6,39303,0);
INSERT INTO "django_geo_db_location" VALUES(67602,NULL,'North Hollywood, CA 91616',28001,222,NULL,6,39304,0);
INSERT INTO "django_geo_db_location" VALUES(67603,NULL,'Valley Village, CA 91617',28003,222,NULL,6,39305,0);
INSERT INTO "django_geo_db_location" VALUES(67604,NULL,'North Hollywood, CA 91618',28001,222,NULL,6,39306,0);
INSERT INTO "django_geo_db_location" VALUES(67605,NULL,'Los Angeles, CA 91671',27895,222,NULL,6,39307,0);
INSERT INTO "django_geo_db_location" VALUES(67606,NULL,'Alta Loma, CA',28006,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67607,NULL,'Alta Loma, CA 91701',28006,222,NULL,6,39308,0);
INSERT INTO "django_geo_db_location" VALUES(67608,NULL,'Azusa, CA',28007,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67609,NULL,'Azusa, CA 91702',28007,222,NULL,6,39309,0);
INSERT INTO "django_geo_db_location" VALUES(67610,NULL,'Baldwin Park, CA',28008,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67611,NULL,'Baldwin Park, CA 91706',28008,222,NULL,6,39310,0);
INSERT INTO "django_geo_db_location" VALUES(67612,NULL,'Chino, CA',28009,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67613,NULL,'Chino, CA 91708',28009,222,NULL,6,39311,0);
INSERT INTO "django_geo_db_location" VALUES(67614,NULL,'Chino Hills, CA',28010,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67615,NULL,'Chino Hills, CA 91709',28010,222,NULL,6,39312,0);
INSERT INTO "django_geo_db_location" VALUES(67616,NULL,'Chino, CA 91710',28009,222,NULL,6,39313,0);
INSERT INTO "django_geo_db_location" VALUES(67617,NULL,'Claremont, CA',28011,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67618,NULL,'Claremont, CA 91711',28011,222,NULL,6,39314,0);
INSERT INTO "django_geo_db_location" VALUES(67619,NULL,'City Of Industry, CA',28012,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67620,NULL,'City Of Industry, CA 91714',28012,222,NULL,6,39315,0);
INSERT INTO "django_geo_db_location" VALUES(67621,NULL,'City Of Industry, CA 91715',28012,222,NULL,6,39316,0);
INSERT INTO "django_geo_db_location" VALUES(67622,NULL,'City Of Industry, CA 91716',28012,222,NULL,6,39317,0);
INSERT INTO "django_geo_db_location" VALUES(67623,NULL,'Corona, CA',28013,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67624,NULL,'Corona, CA 91718',28013,222,NULL,6,39318,0);
INSERT INTO "django_geo_db_location" VALUES(67625,NULL,'Corona, CA 91719',28013,222,NULL,6,39319,0);
INSERT INTO "django_geo_db_location" VALUES(67626,NULL,'Corona, CA 91720',28013,222,NULL,6,39320,0);
INSERT INTO "django_geo_db_location" VALUES(67627,NULL,'Covina, CA',28014,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67628,NULL,'Covina, CA 91722',28014,222,NULL,6,39321,0);
INSERT INTO "django_geo_db_location" VALUES(67629,NULL,'Covina, CA 91723',28014,222,NULL,6,39322,0);
INSERT INTO "django_geo_db_location" VALUES(67630,NULL,'Covina, CA 91724',28014,222,NULL,6,39323,0);
INSERT INTO "django_geo_db_location" VALUES(67631,NULL,'Rancho Cucamonga, CA',28015,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67632,NULL,'Rancho Cucamonga, CA 91729',28015,222,NULL,6,39324,0);
INSERT INTO "django_geo_db_location" VALUES(67633,NULL,'Rancho Cucamonga, CA 91730',28015,222,NULL,6,39325,0);
INSERT INTO "django_geo_db_location" VALUES(67634,NULL,'El Monte, CA',28016,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67635,NULL,'El Monte, CA 91731',28016,222,NULL,6,39326,0);
INSERT INTO "django_geo_db_location" VALUES(67636,NULL,'El Monte, CA 91732',28016,222,NULL,6,39327,0);
INSERT INTO "django_geo_db_location" VALUES(67637,NULL,'South El Monte, CA',28017,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67638,NULL,'South El Monte, CA 91733',28017,222,NULL,6,39328,0);
INSERT INTO "django_geo_db_location" VALUES(67639,NULL,'El Monte, CA 91734',28016,222,NULL,6,39329,0);
INSERT INTO "django_geo_db_location" VALUES(67640,NULL,'El Monte, CA 91735',28016,222,NULL,6,39330,0);
INSERT INTO "django_geo_db_location" VALUES(67641,NULL,'Alta Loma, CA 91737',28006,222,NULL,6,39331,0);
INSERT INTO "django_geo_db_location" VALUES(67642,NULL,'Rancho Cucamonga, CA 91739',28015,222,NULL,6,39332,0);
INSERT INTO "django_geo_db_location" VALUES(67643,NULL,'Glendora, CA',28018,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67644,NULL,'Glendora, CA 91740',28018,222,NULL,6,39333,0);
INSERT INTO "django_geo_db_location" VALUES(67645,NULL,'Glendora, CA 91741',28018,222,NULL,6,39334,0);
INSERT INTO "django_geo_db_location" VALUES(67646,NULL,'Guasti, CA',28019,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67647,NULL,'Guasti, CA 91743',28019,222,NULL,6,39335,0);
INSERT INTO "django_geo_db_location" VALUES(67648,NULL,'La Puente, CA',28020,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67649,NULL,'La Puente, CA 91744',28020,222,NULL,6,39336,0);
INSERT INTO "django_geo_db_location" VALUES(67650,NULL,'Hacienda Heights, CA',28021,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67651,NULL,'Hacienda Heights, CA 91745',28021,222,NULL,6,39337,0);
INSERT INTO "django_geo_db_location" VALUES(67652,NULL,'La Puente, CA 91746',28020,222,NULL,6,39338,0);
INSERT INTO "django_geo_db_location" VALUES(67653,NULL,'La Puente, CA 91747',28020,222,NULL,6,39339,0);
INSERT INTO "django_geo_db_location" VALUES(67654,NULL,'Rowland Heights, CA',28022,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67655,NULL,'Rowland Heights, CA 91748',28022,222,NULL,6,39340,0);
INSERT INTO "django_geo_db_location" VALUES(67656,NULL,'La Puente, CA 91749',28020,222,NULL,6,39341,0);
INSERT INTO "django_geo_db_location" VALUES(67657,NULL,'La Verne, CA',28023,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67658,NULL,'La Verne, CA 91750',28023,222,NULL,6,39342,0);
INSERT INTO "django_geo_db_location" VALUES(67659,NULL,'Mira Loma, CA',28024,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67660,NULL,'Mira Loma, CA 91752',28024,222,NULL,6,39343,0);
INSERT INTO "django_geo_db_location" VALUES(67661,NULL,'Monterey Park, CA',28025,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67662,NULL,'Monterey Park, CA 91754',28025,222,NULL,6,39344,0);
INSERT INTO "django_geo_db_location" VALUES(67663,NULL,'Monterey Park, CA 91755',28025,222,NULL,6,39345,0);
INSERT INTO "django_geo_db_location" VALUES(67664,NULL,'Monterey Park, CA 91756',28025,222,NULL,6,39346,0);
INSERT INTO "django_geo_db_location" VALUES(67665,NULL,'Ontario, CA',28026,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67666,NULL,'Ontario, CA 91758',28026,222,NULL,6,39347,0);
INSERT INTO "django_geo_db_location" VALUES(67667,NULL,'Mt Baldy, CA',28027,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67668,NULL,'Mt Baldy, CA 91759',28027,222,NULL,6,39348,0);
INSERT INTO "django_geo_db_location" VALUES(67669,NULL,'Norco, CA',28028,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67670,NULL,'Norco, CA 91760',28028,222,NULL,6,39349,0);
INSERT INTO "django_geo_db_location" VALUES(67671,NULL,'Ontario, CA 91761',28026,222,NULL,6,39350,0);
INSERT INTO "django_geo_db_location" VALUES(67672,NULL,'Ontario, CA 91762',28026,222,NULL,6,39351,0);
INSERT INTO "django_geo_db_location" VALUES(67673,NULL,'Montclair, CA',28029,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67674,NULL,'Montclair, CA 91763',28029,222,NULL,6,39352,0);
INSERT INTO "django_geo_db_location" VALUES(67675,NULL,'Ontario, CA 91764',28026,222,NULL,6,39353,0);
INSERT INTO "django_geo_db_location" VALUES(67676,NULL,'Diamond Bar, CA',28030,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67677,NULL,'Diamond Bar, CA 91765',28030,222,NULL,6,39354,0);
INSERT INTO "django_geo_db_location" VALUES(67678,NULL,'Pomona, CA',28031,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67679,NULL,'Pomona, CA 91766',28031,222,NULL,6,39355,0);
INSERT INTO "django_geo_db_location" VALUES(67680,NULL,'Pomona, CA 91767',28031,222,NULL,6,39356,0);
INSERT INTO "django_geo_db_location" VALUES(67681,NULL,'Pomona, CA 91768',28031,222,NULL,6,39357,0);
INSERT INTO "django_geo_db_location" VALUES(67682,NULL,'Pomona, CA 91769',28031,222,NULL,6,39358,0);
INSERT INTO "django_geo_db_location" VALUES(67683,NULL,'Rosemead, CA',28032,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67684,NULL,'Rosemead, CA 91770',28032,222,NULL,6,39359,0);
INSERT INTO "django_geo_db_location" VALUES(67685,NULL,'Rosemead, CA 91771',28032,222,NULL,6,39360,0);
INSERT INTO "django_geo_db_location" VALUES(67686,NULL,'Rosemead, CA 91772',28032,222,NULL,6,39361,0);
INSERT INTO "django_geo_db_location" VALUES(67687,NULL,'San Dimas, CA',28033,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67688,NULL,'San Dimas, CA 91773',28033,222,NULL,6,39362,0);
INSERT INTO "django_geo_db_location" VALUES(67689,NULL,'San Gabriel, CA',28034,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67690,NULL,'San Gabriel, CA 91775',28034,222,NULL,6,39363,0);
INSERT INTO "django_geo_db_location" VALUES(67691,NULL,'San Gabriel, CA 91776',28034,222,NULL,6,39364,0);
INSERT INTO "django_geo_db_location" VALUES(67692,NULL,'San Gabriel, CA 91778',28034,222,NULL,6,39365,0);
INSERT INTO "django_geo_db_location" VALUES(67693,NULL,'Temple City, CA',28035,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67694,NULL,'Temple City, CA 91780',28035,222,NULL,6,39366,0);
INSERT INTO "django_geo_db_location" VALUES(67695,NULL,'Upland, CA',28036,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67696,NULL,'Upland, CA 91784',28036,222,NULL,6,39367,0);
INSERT INTO "django_geo_db_location" VALUES(67697,NULL,'Upland, CA 91785',28036,222,NULL,6,39368,0);
INSERT INTO "django_geo_db_location" VALUES(67698,NULL,'Upland, CA 91786',28036,222,NULL,6,39369,0);
INSERT INTO "django_geo_db_location" VALUES(67699,NULL,'Walnut, CA',28037,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67700,NULL,'Walnut, CA 91788',28037,222,NULL,6,39370,0);
INSERT INTO "django_geo_db_location" VALUES(67701,NULL,'Walnut, CA 91789',28037,222,NULL,6,39371,0);
INSERT INTO "django_geo_db_location" VALUES(67702,NULL,'West Covina, CA',28038,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67703,NULL,'West Covina, CA 91790',28038,222,NULL,6,39372,0);
INSERT INTO "django_geo_db_location" VALUES(67704,NULL,'West Covina, CA 91791',28038,222,NULL,6,39373,0);
INSERT INTO "django_geo_db_location" VALUES(67705,NULL,'West Covina, CA 91792',28038,222,NULL,6,39374,0);
INSERT INTO "django_geo_db_location" VALUES(67706,NULL,'West Covina, CA 91793',28038,222,NULL,6,39375,0);
INSERT INTO "django_geo_db_location" VALUES(67707,NULL,'Walnut, CA 91795',28037,222,NULL,6,39376,0);
INSERT INTO "django_geo_db_location" VALUES(67708,NULL,'Pomona, CA 91797',28031,222,NULL,6,39377,0);
INSERT INTO "django_geo_db_location" VALUES(67709,NULL,'Ontario, CA 91798',28026,222,NULL,6,39378,0);
INSERT INTO "django_geo_db_location" VALUES(67710,NULL,'Pomona, CA 91799',28031,222,NULL,6,39379,0);
INSERT INTO "django_geo_db_location" VALUES(67711,NULL,'Alhambra, CA',28039,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67712,NULL,'Alhambra, CA 91801',28039,222,NULL,6,39380,0);
INSERT INTO "django_geo_db_location" VALUES(67713,NULL,'Alhambra, CA 91802',28039,222,NULL,6,39381,0);
INSERT INTO "django_geo_db_location" VALUES(67714,NULL,'Alhambra, CA 91803',28039,222,NULL,6,39382,0);
INSERT INTO "django_geo_db_location" VALUES(67715,NULL,'Alhambra, CA 91804',28039,222,NULL,6,39383,0);
INSERT INTO "django_geo_db_location" VALUES(67716,NULL,'Alhambra, CA 91841',28039,222,NULL,6,39384,0);
INSERT INTO "django_geo_db_location" VALUES(67717,NULL,'Alhambra, CA 91896',28039,222,NULL,6,39385,0);
INSERT INTO "django_geo_db_location" VALUES(67718,NULL,'Alhambra, CA 91899',28039,222,NULL,6,39386,0);
INSERT INTO "django_geo_db_location" VALUES(67719,NULL,'Alpine, CA',28040,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67720,NULL,'Alpine, CA 91901',28040,222,NULL,6,39387,0);
INSERT INTO "django_geo_db_location" VALUES(67721,NULL,'Bonita, CA',28041,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67722,NULL,'Bonita, CA 91902',28041,222,NULL,6,39388,0);
INSERT INTO "django_geo_db_location" VALUES(67723,NULL,'Alpine, CA 91903',28040,222,NULL,6,39389,0);
INSERT INTO "django_geo_db_location" VALUES(67724,NULL,'Boulevard, CA',28042,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67725,NULL,'Boulevard, CA 91905',28042,222,NULL,6,39390,0);
INSERT INTO "django_geo_db_location" VALUES(67726,NULL,'Campo, CA',28043,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67727,NULL,'Campo, CA 91906',28043,222,NULL,6,39391,0);
INSERT INTO "django_geo_db_location" VALUES(67728,NULL,'Bonita, CA 91908',28041,222,NULL,6,39392,0);
INSERT INTO "django_geo_db_location" VALUES(67729,NULL,'Chula Vista, CA',28044,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67730,NULL,'Chula Vista, CA 91909',28044,222,NULL,6,39393,0);
INSERT INTO "django_geo_db_location" VALUES(67731,NULL,'Chula Vista, CA 91910',28044,222,NULL,6,39394,0);
INSERT INTO "django_geo_db_location" VALUES(67732,NULL,'Chula Vista, CA 91911',28044,222,NULL,6,39395,0);
INSERT INTO "django_geo_db_location" VALUES(67733,NULL,'Chula Vista, CA 91912',28044,222,NULL,6,39396,0);
INSERT INTO "django_geo_db_location" VALUES(67734,NULL,'Chula Vista, CA 91913',28044,222,NULL,6,39397,0);
INSERT INTO "django_geo_db_location" VALUES(67735,NULL,'Chula Vista, CA 91914',28044,222,NULL,6,39398,0);
INSERT INTO "django_geo_db_location" VALUES(67736,NULL,'Chula Vista, CA 91915',28044,222,NULL,6,39399,0);
INSERT INTO "django_geo_db_location" VALUES(67737,NULL,'Descanso, CA',28045,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67738,NULL,'Descanso, CA 91916',28045,222,NULL,6,39400,0);
INSERT INTO "django_geo_db_location" VALUES(67739,NULL,'Dulzura, CA',28046,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67740,NULL,'Dulzura, CA 91917',28046,222,NULL,6,39401,0);
INSERT INTO "django_geo_db_location" VALUES(67741,NULL,'Chula Vista, CA 91921',28044,222,NULL,6,39402,0);
INSERT INTO "django_geo_db_location" VALUES(67742,NULL,'La Presa, CA',28047,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67743,NULL,'La Presa, CA 91927',28047,222,NULL,6,39403,0);
INSERT INTO "django_geo_db_location" VALUES(67744,NULL,'Guatay, CA',28048,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67745,NULL,'Guatay, CA 91931',28048,222,NULL,6,39404,0);
INSERT INTO "django_geo_db_location" VALUES(67746,NULL,'Imperial Beach, CA',28049,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67747,NULL,'Imperial Beach, CA 91932',28049,222,NULL,6,39405,0);
INSERT INTO "django_geo_db_location" VALUES(67748,NULL,'Imperial Beach, CA 91933',28049,222,NULL,6,39406,0);
INSERT INTO "django_geo_db_location" VALUES(67749,NULL,'Jacumba, CA',28050,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67750,NULL,'Jacumba, CA 91934',28050,222,NULL,6,39407,0);
INSERT INTO "django_geo_db_location" VALUES(67751,NULL,'Jamul, CA',28051,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67752,NULL,'Jamul, CA 91935',28051,222,NULL,6,39408,0);
INSERT INTO "django_geo_db_location" VALUES(67753,NULL,'La Mesa, CA',28052,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67754,NULL,'La Mesa, CA 91941',28052,222,NULL,6,39409,0);
INSERT INTO "django_geo_db_location" VALUES(67755,NULL,'La Mesa, CA 91942',28052,222,NULL,6,39410,0);
INSERT INTO "django_geo_db_location" VALUES(67756,NULL,'La Mesa, CA 91943',28052,222,NULL,6,39411,0);
INSERT INTO "django_geo_db_location" VALUES(67757,NULL,'La Mesa, CA 91944',28052,222,NULL,6,39412,0);
INSERT INTO "django_geo_db_location" VALUES(67758,NULL,'Lemon Grove, CA',28053,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67759,NULL,'Lemon Grove, CA 91945',28053,222,NULL,6,39413,0);
INSERT INTO "django_geo_db_location" VALUES(67760,NULL,'Lemon Grove, CA 91946',28053,222,NULL,6,39414,0);
INSERT INTO "django_geo_db_location" VALUES(67761,NULL,'Lincoln Acres, CA',28054,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67762,NULL,'Lincoln Acres, CA 91947',28054,222,NULL,6,39415,0);
INSERT INTO "django_geo_db_location" VALUES(67763,NULL,'Mount Laguna, CA',28055,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67764,NULL,'Mount Laguna, CA 91948',28055,222,NULL,6,39416,0);
INSERT INTO "django_geo_db_location" VALUES(67765,NULL,'National City, CA',28056,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67766,NULL,'National City, CA 91950',28056,222,NULL,6,39417,0);
INSERT INTO "django_geo_db_location" VALUES(67767,NULL,'National City, CA 91951',28056,222,NULL,6,39418,0);
INSERT INTO "django_geo_db_location" VALUES(67768,NULL,'Pine Valley, CA',28057,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67769,NULL,'Pine Valley, CA 91962',28057,222,NULL,6,39419,0);
INSERT INTO "django_geo_db_location" VALUES(67770,NULL,'Potrero, CA',28058,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67771,NULL,'Potrero, CA 91963',28058,222,NULL,6,39420,0);
INSERT INTO "django_geo_db_location" VALUES(67772,NULL,'Spring Valley, CA',28059,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67773,NULL,'Spring Valley, CA 91976',28059,222,NULL,6,39421,0);
INSERT INTO "django_geo_db_location" VALUES(67774,NULL,'Spring Valley, CA 91977',28059,222,NULL,6,39422,0);
INSERT INTO "django_geo_db_location" VALUES(67775,NULL,'Spring Valley, CA 91978',28059,222,NULL,6,39423,0);
INSERT INTO "django_geo_db_location" VALUES(67776,NULL,'Spring Valley, CA 91979',28059,222,NULL,6,39424,0);
INSERT INTO "django_geo_db_location" VALUES(67777,NULL,'Tecate, CA',28060,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67778,NULL,'Tecate, CA 91980',28060,222,NULL,6,39425,0);
INSERT INTO "django_geo_db_location" VALUES(67779,NULL,'Tecate, CA 91987',28060,222,NULL,6,39426,0);
INSERT INTO "django_geo_db_location" VALUES(67780,NULL,'Potrero, CA 91990',28058,222,NULL,6,39427,0);
INSERT INTO "django_geo_db_location" VALUES(67781,NULL,'Carlsbad, CA',28061,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67782,NULL,'Carlsbad, CA 92002',28061,222,NULL,6,39428,0);
INSERT INTO "django_geo_db_location" VALUES(67783,NULL,'Bonsall, CA',28062,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67784,NULL,'Bonsall, CA 92003',28062,222,NULL,6,39429,0);
INSERT INTO "django_geo_db_location" VALUES(67785,NULL,'Borrego Springs, CA',28063,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67786,NULL,'Borrego Springs, CA 92004',28063,222,NULL,6,39430,0);
INSERT INTO "django_geo_db_location" VALUES(67787,NULL,'Cardiff By The Sea, CA',28064,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67788,NULL,'Cardiff By The Sea, CA 92007',28064,222,NULL,6,39431,0);
INSERT INTO "django_geo_db_location" VALUES(67789,NULL,'Carlsbad, CA 92008',28061,222,NULL,6,39432,0);
INSERT INTO "django_geo_db_location" VALUES(67790,NULL,'Carlsbad, CA 92009',28061,222,NULL,6,39433,0);
INSERT INTO "django_geo_db_location" VALUES(67791,NULL,'Carlsbad, CA 92013',28061,222,NULL,6,39434,0);
INSERT INTO "django_geo_db_location" VALUES(67792,NULL,'Del Mar, CA',28065,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67793,NULL,'Del Mar, CA 92014',28065,222,NULL,6,39435,0);
INSERT INTO "django_geo_db_location" VALUES(67794,NULL,'Carlsbad, CA 92018',28061,222,NULL,6,39436,0);
INSERT INTO "django_geo_db_location" VALUES(67795,NULL,'El Cajon, CA',28066,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67796,NULL,'El Cajon, CA 92019',28066,222,NULL,6,39437,0);
INSERT INTO "django_geo_db_location" VALUES(67797,NULL,'El Cajon, CA 92020',28066,222,NULL,6,39438,0);
INSERT INTO "django_geo_db_location" VALUES(67798,NULL,'El Cajon, CA 92021',28066,222,NULL,6,39439,0);
INSERT INTO "django_geo_db_location" VALUES(67799,NULL,'El Cajon, CA 92022',28066,222,NULL,6,39440,0);
INSERT INTO "django_geo_db_location" VALUES(67800,NULL,'Encinitas, CA',28067,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67801,NULL,'Encinitas, CA 92023',28067,222,NULL,6,39441,0);
INSERT INTO "django_geo_db_location" VALUES(67802,NULL,'Encinitas, CA 92024',28067,222,NULL,6,39442,0);
INSERT INTO "django_geo_db_location" VALUES(67803,NULL,'Escondido, CA',28068,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67804,NULL,'Escondido, CA 92025',28068,222,NULL,6,39443,0);
INSERT INTO "django_geo_db_location" VALUES(67805,NULL,'Escondido, CA 92026',28068,222,NULL,6,39444,0);
INSERT INTO "django_geo_db_location" VALUES(67806,NULL,'Escondido, CA 92027',28068,222,NULL,6,39445,0);
INSERT INTO "django_geo_db_location" VALUES(67807,NULL,'Fallbrook, CA',28069,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67808,NULL,'Fallbrook, CA 92028',28069,222,NULL,6,39446,0);
INSERT INTO "django_geo_db_location" VALUES(67809,NULL,'Escondido, CA 92029',28068,222,NULL,6,39447,0);
INSERT INTO "django_geo_db_location" VALUES(67810,NULL,'Escondido, CA 92030',28068,222,NULL,6,39448,0);
INSERT INTO "django_geo_db_location" VALUES(67811,NULL,'Adelanto, CA',28070,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67812,NULL,'Adelanto, CA 92031',28070,222,NULL,6,39449,0);
INSERT INTO "django_geo_db_location" VALUES(67813,NULL,'Escondido, CA 92033',28068,222,NULL,6,39450,0);
INSERT INTO "django_geo_db_location" VALUES(67814,NULL,'Julian, CA',28071,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67815,NULL,'Julian, CA 92036',28071,222,NULL,6,39451,0);
INSERT INTO "django_geo_db_location" VALUES(67816,NULL,'La Jolla, CA',28072,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67817,NULL,'La Jolla, CA 92037',28072,222,NULL,6,39452,0);
INSERT INTO "django_geo_db_location" VALUES(67818,NULL,'La Jolla, CA 92038',28072,222,NULL,6,39453,0);
INSERT INTO "django_geo_db_location" VALUES(67819,NULL,'La Jolla, CA 92039',28072,222,NULL,6,39454,0);
INSERT INTO "django_geo_db_location" VALUES(67820,NULL,'Lakeside, CA',28073,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67821,NULL,'Lakeside, CA 92040',28073,222,NULL,6,39455,0);
INSERT INTO "django_geo_db_location" VALUES(67822,NULL,'Escondido, CA 92046',28068,222,NULL,6,39456,0);
INSERT INTO "django_geo_db_location" VALUES(67823,NULL,'Oceanside, CA',28074,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67824,NULL,'Oceanside, CA 92049',28074,222,NULL,6,39457,0);
INSERT INTO "django_geo_db_location" VALUES(67825,NULL,'Oceanside, CA 92051',28074,222,NULL,6,39458,0);
INSERT INTO "django_geo_db_location" VALUES(67826,NULL,'Oceanside, CA 92052',28074,222,NULL,6,39459,0);
INSERT INTO "django_geo_db_location" VALUES(67827,NULL,'Oceanside, CA 92054',28074,222,NULL,6,39460,0);
INSERT INTO "django_geo_db_location" VALUES(67828,NULL,'Camp Pendleton, CA',28075,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67829,NULL,'Camp Pendleton, CA 92055',28075,222,NULL,6,39461,0);
INSERT INTO "django_geo_db_location" VALUES(67830,NULL,'Oceanside, CA 92056',28074,222,NULL,6,39462,0);
INSERT INTO "django_geo_db_location" VALUES(67831,NULL,'Oceanside, CA 92057',28074,222,NULL,6,39463,0);
INSERT INTO "django_geo_db_location" VALUES(67832,NULL,'Oceanside, CA 92058',28074,222,NULL,6,39464,0);
INSERT INTO "django_geo_db_location" VALUES(67833,NULL,'Pala, CA',28076,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67834,NULL,'Pala, CA 92059',28076,222,NULL,6,39465,0);
INSERT INTO "django_geo_db_location" VALUES(67835,NULL,'Palomar Mountain, CA',28077,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67836,NULL,'Palomar Mountain, CA 92060',28077,222,NULL,6,39466,0);
INSERT INTO "django_geo_db_location" VALUES(67837,NULL,'Pauma Valley, CA',28078,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67838,NULL,'Pauma Valley, CA 92061',28078,222,NULL,6,39467,0);
INSERT INTO "django_geo_db_location" VALUES(67839,NULL,'Poway, CA',28079,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67840,NULL,'Poway, CA 92064',28079,222,NULL,6,39468,0);
INSERT INTO "django_geo_db_location" VALUES(67841,NULL,'Ramona, CA',28080,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67842,NULL,'Ramona, CA 92065',28080,222,NULL,6,39469,0);
INSERT INTO "django_geo_db_location" VALUES(67843,NULL,'Ranchita, CA',28081,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67844,NULL,'Ranchita, CA 92066',28081,222,NULL,6,39470,0);
INSERT INTO "django_geo_db_location" VALUES(67845,NULL,'Rancho Santa Fe, CA',28082,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67846,NULL,'Rancho Santa Fe, CA 92067',28082,222,NULL,6,39471,0);
INSERT INTO "django_geo_db_location" VALUES(67847,NULL,'San Luis Rey, CA',28083,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67848,NULL,'San Luis Rey, CA 92068',28083,222,NULL,6,39472,0);
INSERT INTO "django_geo_db_location" VALUES(67849,NULL,'San Marcos, CA',28084,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67850,NULL,'San Marcos, CA 92069',28084,222,NULL,6,39473,0);
INSERT INTO "django_geo_db_location" VALUES(67851,NULL,'Santa Ysabel, CA',28085,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67852,NULL,'Santa Ysabel, CA 92070',28085,222,NULL,6,39474,0);
INSERT INTO "django_geo_db_location" VALUES(67853,NULL,'Santee, CA',28086,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67854,NULL,'Santee, CA 92071',28086,222,NULL,6,39475,0);
INSERT INTO "django_geo_db_location" VALUES(67855,NULL,'Santee, CA 92072',28086,222,NULL,6,39476,0);
INSERT INTO "django_geo_db_location" VALUES(67856,NULL,'Poway, CA 92074',28079,222,NULL,6,39477,0);
INSERT INTO "django_geo_db_location" VALUES(67857,NULL,'Solana Beach, CA',28087,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67858,NULL,'Solana Beach, CA 92075',28087,222,NULL,6,39478,0);
INSERT INTO "django_geo_db_location" VALUES(67859,NULL,'San Marcos, CA 92078',28084,222,NULL,6,39479,0);
INSERT INTO "django_geo_db_location" VALUES(67860,NULL,'San Marcos, CA 92079',28084,222,NULL,6,39480,0);
INSERT INTO "django_geo_db_location" VALUES(67861,NULL,'Valley Center, CA',28088,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67862,NULL,'Valley Center, CA 92082',28088,222,NULL,6,39481,0);
INSERT INTO "django_geo_db_location" VALUES(67863,NULL,'Vista, CA',28089,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67864,NULL,'Vista, CA 92083',28089,222,NULL,6,39482,0);
INSERT INTO "django_geo_db_location" VALUES(67865,NULL,'Vista, CA 92084',28089,222,NULL,6,39483,0);
INSERT INTO "django_geo_db_location" VALUES(67866,NULL,'Vista, CA 92085',28089,222,NULL,6,39484,0);
INSERT INTO "django_geo_db_location" VALUES(67867,NULL,'Warner Springs, CA',28090,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67868,NULL,'Warner Springs, CA 92086',28090,222,NULL,6,39485,0);
INSERT INTO "django_geo_db_location" VALUES(67869,NULL,'Fallbrook, CA 92088',28069,222,NULL,6,39486,0);
INSERT INTO "django_geo_db_location" VALUES(67870,NULL,'El Cajon, CA 92090',28066,222,NULL,6,39487,0);
INSERT INTO "django_geo_db_location" VALUES(67871,NULL,'Rancho Santa Fe, CA 92091',28082,222,NULL,6,39488,0);
INSERT INTO "django_geo_db_location" VALUES(67872,NULL,'La Jolla, CA 92092',28072,222,NULL,6,39489,0);
INSERT INTO "django_geo_db_location" VALUES(67873,NULL,'La Jolla, CA 92093',28072,222,NULL,6,39490,0);
INSERT INTO "django_geo_db_location" VALUES(67874,NULL,'San Marcos, CA 92096',28084,222,NULL,6,39491,0);
INSERT INTO "django_geo_db_location" VALUES(67875,NULL,'San Diego, CA',28091,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67876,NULL,'San Diego, CA 92101',28091,222,NULL,6,39492,0);
INSERT INTO "django_geo_db_location" VALUES(67877,NULL,'San Diego, CA 92102',28091,222,NULL,6,39493,0);
INSERT INTO "django_geo_db_location" VALUES(67878,NULL,'San Diego, CA 92103',28091,222,NULL,6,39494,0);
INSERT INTO "django_geo_db_location" VALUES(67879,NULL,'San Diego, CA 92104',28091,222,NULL,6,39495,0);
INSERT INTO "django_geo_db_location" VALUES(67880,NULL,'San Diego, CA 92105',28091,222,NULL,6,39496,0);
INSERT INTO "django_geo_db_location" VALUES(67881,NULL,'San Diego, CA 92106',28091,222,NULL,6,39497,0);
INSERT INTO "django_geo_db_location" VALUES(67882,NULL,'San Diego, CA 92107',28091,222,NULL,6,39498,0);
INSERT INTO "django_geo_db_location" VALUES(67883,NULL,'San Diego, CA 92108',28091,222,NULL,6,39499,0);
INSERT INTO "django_geo_db_location" VALUES(67884,NULL,'San Diego, CA 92109',28091,222,NULL,6,39500,0);
INSERT INTO "django_geo_db_location" VALUES(67885,NULL,'San Diego, CA 92110',28091,222,NULL,6,39501,0);
INSERT INTO "django_geo_db_location" VALUES(67886,NULL,'San Diego, CA 92111',28091,222,NULL,6,39502,0);
INSERT INTO "django_geo_db_location" VALUES(67887,NULL,'San Diego, CA 92112',28091,222,NULL,6,39503,0);
INSERT INTO "django_geo_db_location" VALUES(67888,NULL,'San Diego, CA 92113',28091,222,NULL,6,39504,0);
INSERT INTO "django_geo_db_location" VALUES(67889,NULL,'San Diego, CA 92114',28091,222,NULL,6,39505,0);
INSERT INTO "django_geo_db_location" VALUES(67890,NULL,'San Diego, CA 92115',28091,222,NULL,6,39506,0);
INSERT INTO "django_geo_db_location" VALUES(67891,NULL,'San Diego, CA 92116',28091,222,NULL,6,39507,0);
INSERT INTO "django_geo_db_location" VALUES(67892,NULL,'San Diego, CA 92117',28091,222,NULL,6,39508,0);
INSERT INTO "django_geo_db_location" VALUES(67893,NULL,'Coronado, CA',28092,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67894,NULL,'Coronado, CA 92118',28092,222,NULL,6,39509,0);
INSERT INTO "django_geo_db_location" VALUES(67895,NULL,'San Diego, CA 92119',28091,222,NULL,6,39510,0);
INSERT INTO "django_geo_db_location" VALUES(67896,NULL,'San Diego, CA 92120',28091,222,NULL,6,39511,0);
INSERT INTO "django_geo_db_location" VALUES(67897,NULL,'San Diego, CA 92121',28091,222,NULL,6,39512,0);
INSERT INTO "django_geo_db_location" VALUES(67898,NULL,'San Diego, CA 92122',28091,222,NULL,6,39513,0);
INSERT INTO "django_geo_db_location" VALUES(67899,NULL,'San Diego, CA 92123',28091,222,NULL,6,39514,0);
INSERT INTO "django_geo_db_location" VALUES(67900,NULL,'San Diego, CA 92124',28091,222,NULL,6,39515,0);
INSERT INTO "django_geo_db_location" VALUES(67901,NULL,'San Diego, CA 92126',28091,222,NULL,6,39516,0);
INSERT INTO "django_geo_db_location" VALUES(67902,NULL,'San Diego, CA 92127',28091,222,NULL,6,39517,0);
INSERT INTO "django_geo_db_location" VALUES(67903,NULL,'San Diego, CA 92128',28091,222,NULL,6,39518,0);
INSERT INTO "django_geo_db_location" VALUES(67904,NULL,'San Diego, CA 92129',28091,222,NULL,6,39519,0);
INSERT INTO "django_geo_db_location" VALUES(67905,NULL,'San Diego, CA 92130',28091,222,NULL,6,39520,0);
INSERT INTO "django_geo_db_location" VALUES(67906,NULL,'San Diego, CA 92131',28091,222,NULL,6,39521,0);
INSERT INTO "django_geo_db_location" VALUES(67907,NULL,'San Diego, CA 92132',28091,222,NULL,6,39522,0);
INSERT INTO "django_geo_db_location" VALUES(67908,NULL,'San Diego, CA 92133',28091,222,NULL,6,39523,0);
INSERT INTO "django_geo_db_location" VALUES(67909,NULL,'San Diego, CA 92134',28091,222,NULL,6,39524,0);
INSERT INTO "django_geo_db_location" VALUES(67910,NULL,'San Diego, CA 92135',28091,222,NULL,6,39525,0);
INSERT INTO "django_geo_db_location" VALUES(67911,NULL,'San Diego, CA 92136',28091,222,NULL,6,39526,0);
INSERT INTO "django_geo_db_location" VALUES(67912,NULL,'San Diego, CA 92137',28091,222,NULL,6,39527,0);
INSERT INTO "django_geo_db_location" VALUES(67913,NULL,'San Diego, CA 92138',28091,222,NULL,6,39528,0);
INSERT INTO "django_geo_db_location" VALUES(67914,NULL,'San Diego, CA 92139',28091,222,NULL,6,39529,0);
INSERT INTO "django_geo_db_location" VALUES(67915,NULL,'San Diego, CA 92140',28091,222,NULL,6,39530,0);
INSERT INTO "django_geo_db_location" VALUES(67916,NULL,'San Diego, CA 92142',28091,222,NULL,6,39531,0);
INSERT INTO "django_geo_db_location" VALUES(67917,NULL,'San Ysidro, CA',28093,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67918,NULL,'San Ysidro, CA 92143',28093,222,NULL,6,39532,0);
INSERT INTO "django_geo_db_location" VALUES(67919,NULL,'San Diego, CA 92145',28091,222,NULL,6,39533,0);
INSERT INTO "django_geo_db_location" VALUES(67920,NULL,'San Diego, CA 92147',28091,222,NULL,6,39534,0);
INSERT INTO "django_geo_db_location" VALUES(67921,NULL,'San Diego, CA 92149',28091,222,NULL,6,39535,0);
INSERT INTO "django_geo_db_location" VALUES(67922,NULL,'San Diego, CA 92150',28091,222,NULL,6,39536,0);
INSERT INTO "django_geo_db_location" VALUES(67923,NULL,'San Diego, CA 92152',28091,222,NULL,6,39537,0);
INSERT INTO "django_geo_db_location" VALUES(67924,NULL,'San Diego, CA 92153',28091,222,NULL,6,39538,0);
INSERT INTO "django_geo_db_location" VALUES(67925,NULL,'San Diego, CA 92154',28091,222,NULL,6,39539,0);
INSERT INTO "django_geo_db_location" VALUES(67926,NULL,'San Diego, CA 92155',28091,222,NULL,6,39540,0);
INSERT INTO "django_geo_db_location" VALUES(67927,NULL,'San Diego, CA 92158',28091,222,NULL,6,39541,0);
INSERT INTO "django_geo_db_location" VALUES(67928,NULL,'San Diego, CA 92159',28091,222,NULL,6,39542,0);
INSERT INTO "django_geo_db_location" VALUES(67929,NULL,'San Diego, CA 92160',28091,222,NULL,6,39543,0);
INSERT INTO "django_geo_db_location" VALUES(67930,NULL,'San Diego, CA 92161',28091,222,NULL,6,39544,0);
INSERT INTO "django_geo_db_location" VALUES(67931,NULL,'San Diego, CA 92162',28091,222,NULL,6,39545,0);
INSERT INTO "django_geo_db_location" VALUES(67932,NULL,'San Diego, CA 92163',28091,222,NULL,6,39546,0);
INSERT INTO "django_geo_db_location" VALUES(67933,NULL,'San Diego, CA 92164',28091,222,NULL,6,39547,0);
INSERT INTO "django_geo_db_location" VALUES(67934,NULL,'San Diego, CA 92165',28091,222,NULL,6,39548,0);
INSERT INTO "django_geo_db_location" VALUES(67935,NULL,'San Diego, CA 92166',28091,222,NULL,6,39549,0);
INSERT INTO "django_geo_db_location" VALUES(67936,NULL,'San Diego, CA 92167',28091,222,NULL,6,39550,0);
INSERT INTO "django_geo_db_location" VALUES(67937,NULL,'San Diego, CA 92168',28091,222,NULL,6,39551,0);
INSERT INTO "django_geo_db_location" VALUES(67938,NULL,'San Diego, CA 92169',28091,222,NULL,6,39552,0);
INSERT INTO "django_geo_db_location" VALUES(67939,NULL,'San Diego, CA 92170',28091,222,NULL,6,39553,0);
INSERT INTO "django_geo_db_location" VALUES(67940,NULL,'San Diego, CA 92171',28091,222,NULL,6,39554,0);
INSERT INTO "django_geo_db_location" VALUES(67941,NULL,'San Diego, CA 92172',28091,222,NULL,6,39555,0);
INSERT INTO "django_geo_db_location" VALUES(67942,NULL,'San Ysidro, CA 92173',28093,222,NULL,6,39556,0);
INSERT INTO "django_geo_db_location" VALUES(67943,NULL,'San Diego, CA 92174',28091,222,NULL,6,39557,0);
INSERT INTO "django_geo_db_location" VALUES(67944,NULL,'San Diego, CA 92175',28091,222,NULL,6,39558,0);
INSERT INTO "django_geo_db_location" VALUES(67945,NULL,'San Diego, CA 92176',28091,222,NULL,6,39559,0);
INSERT INTO "django_geo_db_location" VALUES(67946,NULL,'San Diego, CA 92177',28091,222,NULL,6,39560,0);
INSERT INTO "django_geo_db_location" VALUES(67947,NULL,'Coronado, CA 92178',28092,222,NULL,6,39561,0);
INSERT INTO "django_geo_db_location" VALUES(67948,NULL,'San Diego, CA 92179',28091,222,NULL,6,39562,0);
INSERT INTO "django_geo_db_location" VALUES(67949,NULL,'San Diego, CA 92182',28091,222,NULL,6,39563,0);
INSERT INTO "django_geo_db_location" VALUES(67950,NULL,'San Diego, CA 92184',28091,222,NULL,6,39564,0);
INSERT INTO "django_geo_db_location" VALUES(67951,NULL,'San Diego, CA 92186',28091,222,NULL,6,39565,0);
INSERT INTO "django_geo_db_location" VALUES(67952,NULL,'San Diego, CA 92187',28091,222,NULL,6,39566,0);
INSERT INTO "django_geo_db_location" VALUES(67953,NULL,'San Diego, CA 92190',28091,222,NULL,6,39567,0);
INSERT INTO "django_geo_db_location" VALUES(67954,NULL,'San Diego, CA 92191',28091,222,NULL,6,39568,0);
INSERT INTO "django_geo_db_location" VALUES(67955,NULL,'San Diego, CA 92192',28091,222,NULL,6,39569,0);
INSERT INTO "django_geo_db_location" VALUES(67956,NULL,'San Diego, CA 92193',28091,222,NULL,6,39570,0);
INSERT INTO "django_geo_db_location" VALUES(67957,NULL,'San Diego, CA 92194',28091,222,NULL,6,39571,0);
INSERT INTO "django_geo_db_location" VALUES(67958,NULL,'San Diego, CA 92195',28091,222,NULL,6,39572,0);
INSERT INTO "django_geo_db_location" VALUES(67959,NULL,'San Diego, CA 92196',28091,222,NULL,6,39573,0);
INSERT INTO "django_geo_db_location" VALUES(67960,NULL,'San Diego, CA 92197',28091,222,NULL,6,39574,0);
INSERT INTO "django_geo_db_location" VALUES(67961,NULL,'San Diego, CA 92198',28091,222,NULL,6,39575,0);
INSERT INTO "django_geo_db_location" VALUES(67962,NULL,'San Diego, CA 92199',28091,222,NULL,6,39576,0);
INSERT INTO "django_geo_db_location" VALUES(67963,NULL,'Indio, CA',28094,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67964,NULL,'Indio, CA 92201',28094,222,NULL,6,39577,0);
INSERT INTO "django_geo_db_location" VALUES(67965,NULL,'Indio, CA 92202',28094,222,NULL,6,39578,0);
INSERT INTO "django_geo_db_location" VALUES(67966,NULL,'Indio, CA 92203',28094,222,NULL,6,39579,0);
INSERT INTO "django_geo_db_location" VALUES(67967,NULL,'Indian Wells, CA',28095,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67968,NULL,'Indian Wells, CA 92210',28095,222,NULL,6,39580,0);
INSERT INTO "django_geo_db_location" VALUES(67969,NULL,'Palm Desert, CA',28096,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67970,NULL,'Palm Desert, CA 92211',28096,222,NULL,6,39581,0);
INSERT INTO "django_geo_db_location" VALUES(67971,NULL,'Banning, CA',28097,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67972,NULL,'Banning, CA 92220',28097,222,NULL,6,39582,0);
INSERT INTO "django_geo_db_location" VALUES(67973,NULL,'Bard, CA',28098,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67974,NULL,'Bard, CA 92222',28098,222,NULL,6,39583,0);
INSERT INTO "django_geo_db_location" VALUES(67975,NULL,'Beaumont, CA',28099,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67976,NULL,'Beaumont, CA 92223',28099,222,NULL,6,39584,0);
INSERT INTO "django_geo_db_location" VALUES(67977,NULL,'Blythe, CA',28100,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67978,NULL,'Blythe, CA 92225',28100,222,NULL,6,39585,0);
INSERT INTO "django_geo_db_location" VALUES(67979,NULL,'Blythe, CA 92226',28100,222,NULL,6,39586,0);
INSERT INTO "django_geo_db_location" VALUES(67980,NULL,'Brawley, CA',28101,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67981,NULL,'Brawley, CA 92227',28101,222,NULL,6,39587,0);
INSERT INTO "django_geo_db_location" VALUES(67982,NULL,'Cabazon, CA',28102,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67983,NULL,'Cabazon, CA 92230',28102,222,NULL,6,39588,0);
INSERT INTO "django_geo_db_location" VALUES(67984,NULL,'Calexico, CA',28103,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67985,NULL,'Calexico, CA 92231',28103,222,NULL,6,39589,0);
INSERT INTO "django_geo_db_location" VALUES(67986,NULL,'Calexico, CA 92232',28103,222,NULL,6,39590,0);
INSERT INTO "django_geo_db_location" VALUES(67987,NULL,'Calipatria, CA',28104,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67988,NULL,'Calipatria, CA 92233',28104,222,NULL,6,39591,0);
INSERT INTO "django_geo_db_location" VALUES(67989,NULL,'Cathedral City, CA',28105,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67990,NULL,'Cathedral City, CA 92234',28105,222,NULL,6,39592,0);
INSERT INTO "django_geo_db_location" VALUES(67991,NULL,'Cathedral City, CA 92235',28105,222,NULL,6,39593,0);
INSERT INTO "django_geo_db_location" VALUES(67992,NULL,'Coachella, CA',28106,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67993,NULL,'Coachella, CA 92236',28106,222,NULL,6,39594,0);
INSERT INTO "django_geo_db_location" VALUES(67994,NULL,'Desert Center, CA',28107,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67995,NULL,'Desert Center, CA 92239',28107,222,NULL,6,39595,0);
INSERT INTO "django_geo_db_location" VALUES(67996,NULL,'Desert Hot Springs, CA',28108,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(67997,NULL,'Desert Hot Springs, CA 92240',28108,222,NULL,6,39596,0);
INSERT INTO "django_geo_db_location" VALUES(67998,NULL,'Desert Hot Springs, CA 92241',28108,222,NULL,6,39597,0);
INSERT INTO "django_geo_db_location" VALUES(67999,NULL,'Earp, CA',28109,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68000,NULL,'Earp, CA 92242',28109,222,NULL,6,39598,0);
INSERT INTO "django_geo_db_location" VALUES(68001,NULL,'El Centro, CA',28110,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68002,NULL,'El Centro, CA 92243',28110,222,NULL,6,39599,0);
INSERT INTO "django_geo_db_location" VALUES(68003,NULL,'El Centro, CA 92244',28110,222,NULL,6,39600,0);
INSERT INTO "django_geo_db_location" VALUES(68004,NULL,'Heber, CA',28111,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68005,NULL,'Heber, CA 92249',28111,222,NULL,6,39601,0);
INSERT INTO "django_geo_db_location" VALUES(68006,NULL,'Holtville, CA',28112,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68007,NULL,'Holtville, CA 92250',28112,222,NULL,6,39602,0);
INSERT INTO "django_geo_db_location" VALUES(68008,NULL,'Imperial, CA',28113,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68009,NULL,'Imperial, CA 92251',28113,222,NULL,6,39603,0);
INSERT INTO "django_geo_db_location" VALUES(68010,NULL,'Joshua Tree, CA',28114,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68011,NULL,'Joshua Tree, CA 92252',28114,222,NULL,6,39604,0);
INSERT INTO "django_geo_db_location" VALUES(68012,NULL,'La Quinta, CA',28115,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68013,NULL,'La Quinta, CA 92253',28115,222,NULL,6,39605,0);
INSERT INTO "django_geo_db_location" VALUES(68014,NULL,'Mecca, CA',28116,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68015,NULL,'Mecca, CA 92254',28116,222,NULL,6,39606,0);
INSERT INTO "django_geo_db_location" VALUES(68016,NULL,'Palm Desert, CA 92255',28096,222,NULL,6,39607,0);
INSERT INTO "django_geo_db_location" VALUES(68017,NULL,'Morongo Valley, CA',28117,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68018,NULL,'Morongo Valley, CA 92256',28117,222,NULL,6,39608,0);
INSERT INTO "django_geo_db_location" VALUES(68019,NULL,'Niland, CA',28118,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68020,NULL,'Niland, CA 92257',28118,222,NULL,6,39609,0);
INSERT INTO "django_geo_db_location" VALUES(68021,NULL,'North Palm Springs, CA',28119,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68022,NULL,'North Palm Springs, CA 92258',28119,222,NULL,6,39610,0);
INSERT INTO "django_geo_db_location" VALUES(68023,NULL,'Ocotillo, CA',28120,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68024,NULL,'Ocotillo, CA 92259',28120,222,NULL,6,39611,0);
INSERT INTO "django_geo_db_location" VALUES(68025,NULL,'Palm Desert, CA 92260',28096,222,NULL,6,39612,0);
INSERT INTO "django_geo_db_location" VALUES(68026,NULL,'Palm Desert, CA 92261',28096,222,NULL,6,39613,0);
INSERT INTO "django_geo_db_location" VALUES(68027,NULL,'Palm Springs, CA',28121,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68028,NULL,'Palm Springs, CA 92262',28121,222,NULL,6,39614,0);
INSERT INTO "django_geo_db_location" VALUES(68029,NULL,'Palm Springs, CA 92263',28121,222,NULL,6,39615,0);
INSERT INTO "django_geo_db_location" VALUES(68030,NULL,'Palm Springs, CA 92264',28121,222,NULL,6,39616,0);
INSERT INTO "django_geo_db_location" VALUES(68031,NULL,'Palo Verde, CA',28122,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68032,NULL,'Palo Verde, CA 92266',28122,222,NULL,6,39617,0);
INSERT INTO "django_geo_db_location" VALUES(68033,NULL,'Parker Dam, CA',28123,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68034,NULL,'Parker Dam, CA 92267',28123,222,NULL,6,39618,0);
INSERT INTO "django_geo_db_location" VALUES(68035,NULL,'Pioneertown, CA',28124,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68036,NULL,'Pioneertown, CA 92268',28124,222,NULL,6,39619,0);
INSERT INTO "django_geo_db_location" VALUES(68037,NULL,'Rancho Mirage, CA',28125,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68038,NULL,'Rancho Mirage, CA 92270',28125,222,NULL,6,39620,0);
INSERT INTO "django_geo_db_location" VALUES(68039,NULL,'Rancho Mirage, CA 92271',28125,222,NULL,6,39621,0);
INSERT INTO "django_geo_db_location" VALUES(68040,NULL,'Seeley, CA',28126,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68041,NULL,'Seeley, CA 92273',28126,222,NULL,6,39622,0);
INSERT INTO "django_geo_db_location" VALUES(68042,NULL,'Thermal, CA',28127,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68043,NULL,'Thermal, CA 92274',28127,222,NULL,6,39623,0);
INSERT INTO "django_geo_db_location" VALUES(68044,NULL,'Salton City, CA',28128,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68045,NULL,'Salton City, CA 92275',28128,222,NULL,6,39624,0);
INSERT INTO "django_geo_db_location" VALUES(68046,NULL,'Thousand Palms, CA',28129,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68047,NULL,'Thousand Palms, CA 92276',28129,222,NULL,6,39625,0);
INSERT INTO "django_geo_db_location" VALUES(68048,NULL,'Twentynine Palms, CA',28130,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68049,NULL,'Twentynine Palms, CA 92277',28130,222,NULL,6,39626,0);
INSERT INTO "django_geo_db_location" VALUES(68050,NULL,'Twentynine Palms, CA 92278',28130,222,NULL,6,39627,0);
INSERT INTO "django_geo_db_location" VALUES(68051,NULL,'Vidal, CA',28131,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68052,NULL,'Vidal, CA 92280',28131,222,NULL,6,39628,0);
INSERT INTO "django_geo_db_location" VALUES(68053,NULL,'Westmorland, CA',28132,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68054,NULL,'Westmorland, CA 92281',28132,222,NULL,6,39629,0);
INSERT INTO "django_geo_db_location" VALUES(68055,NULL,'White Water, CA',28133,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68056,NULL,'White Water, CA 92282',28133,222,NULL,6,39630,0);
INSERT INTO "django_geo_db_location" VALUES(68057,NULL,'Winterhaven, CA',28134,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68058,NULL,'Winterhaven, CA 92283',28134,222,NULL,6,39631,0);
INSERT INTO "django_geo_db_location" VALUES(68059,NULL,'Yucca Valley, CA',28135,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68060,NULL,'Yucca Valley, CA 92284',28135,222,NULL,6,39632,0);
INSERT INTO "django_geo_db_location" VALUES(68061,NULL,'Landers, CA',28136,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68062,NULL,'Landers, CA 92285',28136,222,NULL,6,39633,0);
INSERT INTO "django_geo_db_location" VALUES(68063,NULL,'Yucca Valley, CA 92286',28135,222,NULL,6,39634,0);
INSERT INTO "django_geo_db_location" VALUES(68064,NULL,'Palm Springs, CA 92292',28121,222,NULL,6,39635,0);
INSERT INTO "django_geo_db_location" VALUES(68065,NULL,'Adelanto, CA 92301',28070,222,NULL,6,39636,0);
INSERT INTO "django_geo_db_location" VALUES(68066,NULL,'Amboy, CA',28137,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68067,NULL,'Amboy, CA 92304',28137,222,NULL,6,39637,0);
INSERT INTO "django_geo_db_location" VALUES(68068,NULL,'Angelus Oaks, CA',28138,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68069,NULL,'Angelus Oaks, CA 92305',28138,222,NULL,6,39638,0);
INSERT INTO "django_geo_db_location" VALUES(68070,NULL,'Apple Valley, CA',28139,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68071,NULL,'Apple Valley, CA 92307',28139,222,NULL,6,39639,0);
INSERT INTO "django_geo_db_location" VALUES(68072,NULL,'Apple Valley, CA 92308',28139,222,NULL,6,39640,0);
INSERT INTO "django_geo_db_location" VALUES(68073,NULL,'Baker, CA',28140,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68074,NULL,'Baker, CA 92309',28140,222,NULL,6,39641,0);
INSERT INTO "django_geo_db_location" VALUES(68075,NULL,'Fort Irwin, CA',28141,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68076,NULL,'Fort Irwin, CA 92310',28141,222,NULL,6,39642,0);
INSERT INTO "django_geo_db_location" VALUES(68077,NULL,'Barstow, CA',28142,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68078,NULL,'Barstow, CA 92311',28142,222,NULL,6,39643,0);
INSERT INTO "django_geo_db_location" VALUES(68079,NULL,'Barstow, CA 92312',28142,222,NULL,6,39644,0);
INSERT INTO "django_geo_db_location" VALUES(68080,NULL,'Grand Terrace, CA',28143,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68081,NULL,'Grand Terrace, CA 92313',28143,222,NULL,6,39645,0);
INSERT INTO "django_geo_db_location" VALUES(68082,NULL,'Big Bear City, CA',28144,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68083,NULL,'Big Bear City, CA 92314',28144,222,NULL,6,39646,0);
INSERT INTO "django_geo_db_location" VALUES(68084,NULL,'Big Bear Lake, CA',28145,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68085,NULL,'Big Bear Lake, CA 92315',28145,222,NULL,6,39647,0);
INSERT INTO "django_geo_db_location" VALUES(68086,NULL,'Bloomington, CA',28146,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68087,NULL,'Bloomington, CA 92316',28146,222,NULL,6,39648,0);
INSERT INTO "django_geo_db_location" VALUES(68088,NULL,'Blue Jay, CA',28147,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68089,NULL,'Blue Jay, CA 92317',28147,222,NULL,6,39649,0);
INSERT INTO "django_geo_db_location" VALUES(68090,NULL,'Bryn Mawr, CA',28148,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68091,NULL,'Bryn Mawr, CA 92318',28148,222,NULL,6,39650,0);
INSERT INTO "django_geo_db_location" VALUES(68092,NULL,'Calimesa, CA',28149,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68093,NULL,'Calimesa, CA 92320',28149,222,NULL,6,39651,0);
INSERT INTO "django_geo_db_location" VALUES(68094,NULL,'Cedar Glen, CA',28150,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68095,NULL,'Cedar Glen, CA 92321',28150,222,NULL,6,39652,0);
INSERT INTO "django_geo_db_location" VALUES(68096,NULL,'Cedarpines Park, CA',28151,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68097,NULL,'Cedarpines Park, CA 92322',28151,222,NULL,6,39653,0);
INSERT INTO "django_geo_db_location" VALUES(68098,NULL,'Cima, CA',28152,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68099,NULL,'Cima, CA 92323',28152,222,NULL,6,39654,0);
INSERT INTO "django_geo_db_location" VALUES(68100,NULL,'Colton, CA',28153,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68101,NULL,'Colton, CA 92324',28153,222,NULL,6,39655,0);
INSERT INTO "django_geo_db_location" VALUES(68102,NULL,'Crestline, CA',28154,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68103,NULL,'Crestline, CA 92325',28154,222,NULL,6,39656,0);
INSERT INTO "django_geo_db_location" VALUES(68104,NULL,'Crest Park, CA',28155,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68105,NULL,'Crest Park, CA 92326',28155,222,NULL,6,39657,0);
INSERT INTO "django_geo_db_location" VALUES(68106,NULL,'Daggett, CA',28156,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68107,NULL,'Daggett, CA 92327',28156,222,NULL,6,39658,0);
INSERT INTO "django_geo_db_location" VALUES(68108,NULL,'Death Valley, CA',28157,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68109,NULL,'Death Valley, CA 92328',28157,222,NULL,6,39659,0);
INSERT INTO "django_geo_db_location" VALUES(68110,NULL,'Phelan, CA',28158,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68111,NULL,'Phelan, CA 92329',28158,222,NULL,6,39660,0);
INSERT INTO "django_geo_db_location" VALUES(68112,NULL,'Essex, CA',28159,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68113,NULL,'Essex, CA 92332',28159,222,NULL,6,39661,0);
INSERT INTO "django_geo_db_location" VALUES(68114,NULL,'Fawnskin, CA',28160,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68115,NULL,'Fawnskin, CA 92333',28160,222,NULL,6,39662,0);
INSERT INTO "django_geo_db_location" VALUES(68116,NULL,'Fontana, CA',28161,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68117,NULL,'Fontana, CA 92334',28161,222,NULL,6,39663,0);
INSERT INTO "django_geo_db_location" VALUES(68118,NULL,'Fontana, CA 92335',28161,222,NULL,6,39664,0);
INSERT INTO "django_geo_db_location" VALUES(68119,NULL,'Fontana, CA 92336',28161,222,NULL,6,39665,0);
INSERT INTO "django_geo_db_location" VALUES(68120,NULL,'Fontana, CA 92337',28161,222,NULL,6,39666,0);
INSERT INTO "django_geo_db_location" VALUES(68121,NULL,'Ludlow, CA',28162,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68122,NULL,'Ludlow, CA 92338',28162,222,NULL,6,39667,0);
INSERT INTO "django_geo_db_location" VALUES(68123,NULL,'Forest Falls, CA',28163,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68124,NULL,'Forest Falls, CA 92339',28163,222,NULL,6,39668,0);
INSERT INTO "django_geo_db_location" VALUES(68125,NULL,'Hesperia, CA',28164,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68126,NULL,'Hesperia, CA 92340',28164,222,NULL,6,39669,0);
INSERT INTO "django_geo_db_location" VALUES(68127,NULL,'Green Valley Lake, CA',28165,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68128,NULL,'Green Valley Lake, CA 92341',28165,222,NULL,6,39670,0);
INSERT INTO "django_geo_db_location" VALUES(68129,NULL,'Helendale, CA',28166,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68130,NULL,'Helendale, CA 92342',28166,222,NULL,6,39671,0);
INSERT INTO "django_geo_db_location" VALUES(68131,NULL,'Hesperia, CA 92345',28164,222,NULL,6,39672,0);
INSERT INTO "django_geo_db_location" VALUES(68132,NULL,'Highland, CA',28167,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68133,NULL,'Highland, CA 92346',28167,222,NULL,6,39673,0);
INSERT INTO "django_geo_db_location" VALUES(68134,NULL,'Hinkley, CA',28168,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68135,NULL,'Hinkley, CA 92347',28168,222,NULL,6,39674,0);
INSERT INTO "django_geo_db_location" VALUES(68136,NULL,'Loma Linda, CA',28169,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68137,NULL,'Loma Linda, CA 92350',28169,222,NULL,6,39675,0);
INSERT INTO "django_geo_db_location" VALUES(68138,NULL,'Lake Arrowhead, CA',28170,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68139,NULL,'Lake Arrowhead, CA 92352',28170,222,NULL,6,39676,0);
INSERT INTO "django_geo_db_location" VALUES(68140,NULL,'Loma Linda, CA 92354',28169,222,NULL,6,39677,0);
INSERT INTO "django_geo_db_location" VALUES(68141,NULL,'Lucerne Valley, CA',28171,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68142,NULL,'Lucerne Valley, CA 92356',28171,222,NULL,6,39678,0);
INSERT INTO "django_geo_db_location" VALUES(68143,NULL,'Loma Linda, CA 92357',28169,222,NULL,6,39679,0);
INSERT INTO "django_geo_db_location" VALUES(68144,NULL,'Lytle Creek, CA',28172,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68145,NULL,'Lytle Creek, CA 92358',28172,222,NULL,6,39680,0);
INSERT INTO "django_geo_db_location" VALUES(68146,NULL,'Mentone, CA',28173,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68147,NULL,'Mentone, CA 92359',28173,222,NULL,6,39681,0);
INSERT INTO "django_geo_db_location" VALUES(68148,NULL,'Needles, CA',28174,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68149,NULL,'Needles, CA 92363',28174,222,NULL,6,39682,0);
INSERT INTO "django_geo_db_location" VALUES(68150,NULL,'Nipton, CA',28175,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68151,NULL,'Nipton, CA 92364',28175,222,NULL,6,39683,0);
INSERT INTO "django_geo_db_location" VALUES(68152,NULL,'Newberry Springs, CA',28176,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68153,NULL,'Newberry Springs, CA 92365',28176,222,NULL,6,39684,0);
INSERT INTO "django_geo_db_location" VALUES(68154,NULL,'Mountain Pass, CA',28177,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68155,NULL,'Mountain Pass, CA 92366',28177,222,NULL,6,39685,0);
INSERT INTO "django_geo_db_location" VALUES(68156,NULL,'Oro Grande, CA',28178,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68157,NULL,'Oro Grande, CA 92368',28178,222,NULL,6,39686,0);
INSERT INTO "django_geo_db_location" VALUES(68158,NULL,'Patton, CA',28179,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68159,NULL,'Patton, CA 92369',28179,222,NULL,6,39687,0);
INSERT INTO "django_geo_db_location" VALUES(68160,NULL,'Phelan, CA 92371',28158,222,NULL,6,39688,0);
INSERT INTO "django_geo_db_location" VALUES(68161,NULL,'Pinon Hills, CA',28180,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68162,NULL,'Pinon Hills, CA 92372',28180,222,NULL,6,39689,0);
INSERT INTO "django_geo_db_location" VALUES(68163,NULL,'Redlands, CA',28181,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68164,NULL,'Redlands, CA 92373',28181,222,NULL,6,39690,0);
INSERT INTO "django_geo_db_location" VALUES(68165,NULL,'Redlands, CA 92374',28181,222,NULL,6,39691,0);
INSERT INTO "django_geo_db_location" VALUES(68166,NULL,'Redlands, CA 92375',28181,222,NULL,6,39692,0);
INSERT INTO "django_geo_db_location" VALUES(68167,NULL,'Rialto, CA',28182,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68168,NULL,'Rialto, CA 92376',28182,222,NULL,6,39693,0);
INSERT INTO "django_geo_db_location" VALUES(68169,NULL,'Rialto, CA 92377',28182,222,NULL,6,39694,0);
INSERT INTO "django_geo_db_location" VALUES(68170,NULL,'Rimforest, CA',28183,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68171,NULL,'Rimforest, CA 92378',28183,222,NULL,6,39695,0);
INSERT INTO "django_geo_db_location" VALUES(68172,NULL,'Running Springs, CA',28184,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68173,NULL,'Running Springs, CA 92382',28184,222,NULL,6,39696,0);
INSERT INTO "django_geo_db_location" VALUES(68174,NULL,'Shoshone, CA',28185,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68175,NULL,'Shoshone, CA 92384',28185,222,NULL,6,39697,0);
INSERT INTO "django_geo_db_location" VALUES(68176,NULL,'Skyforest, CA',28186,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68177,NULL,'Skyforest, CA 92385',28186,222,NULL,6,39698,0);
INSERT INTO "django_geo_db_location" VALUES(68178,NULL,'Sugarloaf, CA',28187,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68179,NULL,'Sugarloaf, CA 92386',28187,222,NULL,6,39699,0);
INSERT INTO "django_geo_db_location" VALUES(68180,NULL,'Tecopa, CA',28188,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68181,NULL,'Tecopa, CA 92389',28188,222,NULL,6,39700,0);
INSERT INTO "django_geo_db_location" VALUES(68182,NULL,'Twin Peaks, CA',28189,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68183,NULL,'Twin Peaks, CA 92391',28189,222,NULL,6,39701,0);
INSERT INTO "django_geo_db_location" VALUES(68184,NULL,'Victorville, CA',28190,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68185,NULL,'Victorville, CA 92392',28190,222,NULL,6,39702,0);
INSERT INTO "django_geo_db_location" VALUES(68186,NULL,'Victorville, CA 92393',28190,222,NULL,6,39703,0);
INSERT INTO "django_geo_db_location" VALUES(68187,NULL,'Victorville, CA 92394',28190,222,NULL,6,39704,0);
INSERT INTO "django_geo_db_location" VALUES(68188,NULL,'Winchester, CA',28191,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68189,NULL,'Winchester, CA 92396',28191,222,NULL,6,39705,0);
INSERT INTO "django_geo_db_location" VALUES(68190,NULL,'Wrightwood, CA',28192,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68191,NULL,'Wrightwood, CA 92397',28192,222,NULL,6,39706,0);
INSERT INTO "django_geo_db_location" VALUES(68192,NULL,'Yermo, CA',28193,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68193,NULL,'Yermo, CA 92398',28193,222,NULL,6,39707,0);
INSERT INTO "django_geo_db_location" VALUES(68194,NULL,'Yucaipa, CA',28194,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68195,NULL,'Yucaipa, CA 92399',28194,222,NULL,6,39708,0);
INSERT INTO "django_geo_db_location" VALUES(68196,NULL,'San Bernardino, CA',28195,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68197,NULL,'San Bernardino, CA 92401',28195,222,NULL,6,39709,0);
INSERT INTO "django_geo_db_location" VALUES(68198,NULL,'San Bernardino, CA 92402',28195,222,NULL,6,39710,0);
INSERT INTO "django_geo_db_location" VALUES(68199,NULL,'San Bernardino, CA 92403',28195,222,NULL,6,39711,0);
INSERT INTO "django_geo_db_location" VALUES(68200,NULL,'San Bernardino, CA 92404',28195,222,NULL,6,39712,0);
INSERT INTO "django_geo_db_location" VALUES(68201,NULL,'San Bernardino, CA 92405',28195,222,NULL,6,39713,0);
INSERT INTO "django_geo_db_location" VALUES(68202,NULL,'San Bernardino, CA 92406',28195,222,NULL,6,39714,0);
INSERT INTO "django_geo_db_location" VALUES(68203,NULL,'San Bernardino, CA 92407',28195,222,NULL,6,39715,0);
INSERT INTO "django_geo_db_location" VALUES(68204,NULL,'San Bernardino, CA 92408',28195,222,NULL,6,39716,0);
INSERT INTO "django_geo_db_location" VALUES(68205,NULL,'San Bernardino, CA 92410',28195,222,NULL,6,39717,0);
INSERT INTO "django_geo_db_location" VALUES(68206,NULL,'San Bernardino, CA 92411',28195,222,NULL,6,39718,0);
INSERT INTO "django_geo_db_location" VALUES(68207,NULL,'San Bernardino, CA 92412',28195,222,NULL,6,39719,0);
INSERT INTO "django_geo_db_location" VALUES(68208,NULL,'San Bernardino, CA 92413',28195,222,NULL,6,39720,0);
INSERT INTO "django_geo_db_location" VALUES(68209,NULL,'San Bernardino, CA 92414',28195,222,NULL,6,39721,0);
INSERT INTO "django_geo_db_location" VALUES(68210,NULL,'San Bernardino, CA 92415',28195,222,NULL,6,39722,0);
INSERT INTO "django_geo_db_location" VALUES(68211,NULL,'San Bernardino, CA 92416',28195,222,NULL,6,39723,0);
INSERT INTO "django_geo_db_location" VALUES(68212,NULL,'San Bernardino, CA 92418',28195,222,NULL,6,39724,0);
INSERT INTO "django_geo_db_location" VALUES(68213,NULL,'San Bernardino, CA 92420',28195,222,NULL,6,39725,0);
INSERT INTO "django_geo_db_location" VALUES(68214,NULL,'San Bernardino, CA 92423',28195,222,NULL,6,39726,0);
INSERT INTO "django_geo_db_location" VALUES(68215,NULL,'San Bernardino, CA 92424',28195,222,NULL,6,39727,0);
INSERT INTO "django_geo_db_location" VALUES(68216,NULL,'San Bernardino, CA 92427',28195,222,NULL,6,39728,0);
INSERT INTO "django_geo_db_location" VALUES(68217,NULL,'Riverside, CA',28196,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68218,NULL,'Riverside, CA 92501',28196,222,NULL,6,39729,0);
INSERT INTO "django_geo_db_location" VALUES(68219,NULL,'Riverside, CA 92502',28196,222,NULL,6,39730,0);
INSERT INTO "django_geo_db_location" VALUES(68220,NULL,'Riverside, CA 92503',28196,222,NULL,6,39731,0);
INSERT INTO "django_geo_db_location" VALUES(68221,NULL,'Riverside, CA 92504',28196,222,NULL,6,39732,0);
INSERT INTO "django_geo_db_location" VALUES(68222,NULL,'Riverside, CA 92505',28196,222,NULL,6,39733,0);
INSERT INTO "django_geo_db_location" VALUES(68223,NULL,'Riverside, CA 92506',28196,222,NULL,6,39734,0);
INSERT INTO "django_geo_db_location" VALUES(68224,NULL,'Riverside, CA 92507',28196,222,NULL,6,39735,0);
INSERT INTO "django_geo_db_location" VALUES(68225,NULL,'Riverside, CA 92508',28196,222,NULL,6,39736,0);
INSERT INTO "django_geo_db_location" VALUES(68226,NULL,'Riverside, CA 92509',28196,222,NULL,6,39737,0);
INSERT INTO "django_geo_db_location" VALUES(68227,NULL,'Riverside, CA 92513',28196,222,NULL,6,39738,0);
INSERT INTO "django_geo_db_location" VALUES(68228,NULL,'Riverside, CA 92514',28196,222,NULL,6,39739,0);
INSERT INTO "django_geo_db_location" VALUES(68229,NULL,'Riverside, CA 92515',28196,222,NULL,6,39740,0);
INSERT INTO "django_geo_db_location" VALUES(68230,NULL,'Riverside, CA 92516',28196,222,NULL,6,39741,0);
INSERT INTO "django_geo_db_location" VALUES(68231,NULL,'Riverside, CA 92517',28196,222,NULL,6,39742,0);
INSERT INTO "django_geo_db_location" VALUES(68232,NULL,'March Air Force Base, CA',28197,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68233,NULL,'March Air Force Base, CA 92518',28197,222,NULL,6,39743,0);
INSERT INTO "django_geo_db_location" VALUES(68234,NULL,'Riverside, CA 92519',28196,222,NULL,6,39744,0);
INSERT INTO "django_geo_db_location" VALUES(68235,NULL,'Riverside, CA 92521',28196,222,NULL,6,39745,0);
INSERT INTO "django_geo_db_location" VALUES(68236,NULL,'Riverside, CA 92522',28196,222,NULL,6,39746,0);
INSERT INTO "django_geo_db_location" VALUES(68237,NULL,'Lake Elsinore, CA',28198,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68238,NULL,'Lake Elsinore, CA 92530',28198,222,NULL,6,39747,0);
INSERT INTO "django_geo_db_location" VALUES(68239,NULL,'Lake Elsinore, CA 92531',28198,222,NULL,6,39748,0);
INSERT INTO "django_geo_db_location" VALUES(68240,NULL,'Lake Elsinore, CA 92532',28198,222,NULL,6,39749,0);
INSERT INTO "django_geo_db_location" VALUES(68241,NULL,'Aguanga, CA',28199,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68242,NULL,'Aguanga, CA 92536',28199,222,NULL,6,39750,0);
INSERT INTO "django_geo_db_location" VALUES(68243,NULL,'Anza, CA',28200,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68244,NULL,'Anza, CA 92539',28200,222,NULL,6,39751,0);
INSERT INTO "django_geo_db_location" VALUES(68245,NULL,'Hemet, CA',28201,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68246,NULL,'Hemet, CA 92543',28201,222,NULL,6,39752,0);
INSERT INTO "django_geo_db_location" VALUES(68247,NULL,'Hemet, CA 92544',28201,222,NULL,6,39753,0);
INSERT INTO "django_geo_db_location" VALUES(68248,NULL,'Hemet, CA 92545',28201,222,NULL,6,39754,0);
INSERT INTO "django_geo_db_location" VALUES(68249,NULL,'Hemet, CA 92546',28201,222,NULL,6,39755,0);
INSERT INTO "django_geo_db_location" VALUES(68250,NULL,'Homeland, CA',28202,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68251,NULL,'Homeland, CA 92548',28202,222,NULL,6,39756,0);
INSERT INTO "django_geo_db_location" VALUES(68252,NULL,'Idyllwild, CA',28203,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68253,NULL,'Idyllwild, CA 92549',28203,222,NULL,6,39757,0);
INSERT INTO "django_geo_db_location" VALUES(68254,NULL,'Moreno Valley, CA',28204,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68255,NULL,'Moreno Valley, CA 92551',28204,222,NULL,6,39758,0);
INSERT INTO "django_geo_db_location" VALUES(68256,NULL,'Moreno Valley, CA 92552',28204,222,NULL,6,39759,0);
INSERT INTO "django_geo_db_location" VALUES(68257,NULL,'Moreno Valley, CA 92553',28204,222,NULL,6,39760,0);
INSERT INTO "django_geo_db_location" VALUES(68258,NULL,'Moreno Valley, CA 92554',28204,222,NULL,6,39761,0);
INSERT INTO "django_geo_db_location" VALUES(68259,NULL,'Moreno Valley, CA 92555',28204,222,NULL,6,39762,0);
INSERT INTO "django_geo_db_location" VALUES(68260,NULL,'Moreno Valley, CA 92556',28204,222,NULL,6,39763,0);
INSERT INTO "django_geo_db_location" VALUES(68261,NULL,'Moreno Valley, CA 92557',28204,222,NULL,6,39764,0);
INSERT INTO "django_geo_db_location" VALUES(68262,NULL,'Mountain Center, CA',28205,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68263,NULL,'Mountain Center, CA 92561',28205,222,NULL,6,39765,0);
INSERT INTO "django_geo_db_location" VALUES(68264,NULL,'Murrieta, CA',28206,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68265,NULL,'Murrieta, CA 92562',28206,222,NULL,6,39766,0);
INSERT INTO "django_geo_db_location" VALUES(68266,NULL,'Murrieta, CA 92563',28206,222,NULL,6,39767,0);
INSERT INTO "django_geo_db_location" VALUES(68267,NULL,'Murrieta, CA 92564',28206,222,NULL,6,39768,0);
INSERT INTO "django_geo_db_location" VALUES(68268,NULL,'Nuevo, CA',28207,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68269,NULL,'Nuevo, CA 92567',28207,222,NULL,6,39769,0);
INSERT INTO "django_geo_db_location" VALUES(68270,NULL,'Perris, CA',28208,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68271,NULL,'Perris, CA 92570',28208,222,NULL,6,39770,0);
INSERT INTO "django_geo_db_location" VALUES(68272,NULL,'Perris, CA 92571',28208,222,NULL,6,39771,0);
INSERT INTO "django_geo_db_location" VALUES(68273,NULL,'Perris, CA 92572',28208,222,NULL,6,39772,0);
INSERT INTO "django_geo_db_location" VALUES(68274,NULL,'San Jacinto, CA',28209,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68275,NULL,'San Jacinto, CA 92581',28209,222,NULL,6,39773,0);
INSERT INTO "django_geo_db_location" VALUES(68276,NULL,'San Jacinto, CA 92582',28209,222,NULL,6,39774,0);
INSERT INTO "django_geo_db_location" VALUES(68277,NULL,'San Jacinto, CA 92583',28209,222,NULL,6,39775,0);
INSERT INTO "django_geo_db_location" VALUES(68278,NULL,'Menifee, CA',28210,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68279,NULL,'Menifee, CA 92584',28210,222,NULL,6,39776,0);
INSERT INTO "django_geo_db_location" VALUES(68280,NULL,'Sun City, CA',28211,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68281,NULL,'Sun City, CA 92585',28211,222,NULL,6,39777,0);
INSERT INTO "django_geo_db_location" VALUES(68282,NULL,'Sun City, CA 92586',28211,222,NULL,6,39778,0);
INSERT INTO "django_geo_db_location" VALUES(68283,NULL,'Sun City, CA 92587',28211,222,NULL,6,39779,0);
INSERT INTO "django_geo_db_location" VALUES(68284,NULL,'Temecula, CA',28212,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68285,NULL,'Temecula, CA 92589',28212,222,NULL,6,39780,0);
INSERT INTO "django_geo_db_location" VALUES(68286,NULL,'Temecula, CA 92590',28212,222,NULL,6,39781,0);
INSERT INTO "django_geo_db_location" VALUES(68287,NULL,'Temecula, CA 92591',28212,222,NULL,6,39782,0);
INSERT INTO "django_geo_db_location" VALUES(68288,NULL,'Temecula, CA 92592',28212,222,NULL,6,39783,0);
INSERT INTO "django_geo_db_location" VALUES(68289,NULL,'Temecula, CA 92593',28212,222,NULL,6,39784,0);
INSERT INTO "django_geo_db_location" VALUES(68290,NULL,'Wildomar, CA',28213,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68291,NULL,'Wildomar, CA 92595',28213,222,NULL,6,39785,0);
INSERT INTO "django_geo_db_location" VALUES(68292,NULL,'Winchester, CA 92596',28191,222,NULL,6,39786,0);
INSERT INTO "django_geo_db_location" VALUES(68293,NULL,'Perris, CA 92599',28208,222,NULL,6,39787,0);
INSERT INTO "django_geo_db_location" VALUES(68294,NULL,'Irvine, CA',28214,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68295,NULL,'Irvine, CA 92602',28214,222,NULL,6,39788,0);
INSERT INTO "django_geo_db_location" VALUES(68296,NULL,'Irvine, CA 92603',28214,222,NULL,6,39789,0);
INSERT INTO "django_geo_db_location" VALUES(68297,NULL,'Irvine, CA 92604',28214,222,NULL,6,39790,0);
INSERT INTO "django_geo_db_location" VALUES(68298,NULL,'Huntington Beach, CA',28215,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68299,NULL,'Huntington Beach, CA 92605',28215,222,NULL,6,39791,0);
INSERT INTO "django_geo_db_location" VALUES(68300,NULL,'Irvine, CA 92606',28214,222,NULL,6,39792,0);
INSERT INTO "django_geo_db_location" VALUES(68301,NULL,'Laguna Niguel, CA',28216,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68302,NULL,'Laguna Niguel, CA 92607',28216,222,NULL,6,39793,0);
INSERT INTO "django_geo_db_location" VALUES(68303,NULL,'Foothill Ranch, CA',28217,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68304,NULL,'Foothill Ranch, CA 92610',28217,222,NULL,6,39794,0);
INSERT INTO "django_geo_db_location" VALUES(68305,NULL,'Irvine, CA 92612',28214,222,NULL,6,39795,0);
INSERT INTO "django_geo_db_location" VALUES(68306,NULL,'Irvine, CA 92614',28214,222,NULL,6,39796,0);
INSERT INTO "django_geo_db_location" VALUES(68307,NULL,'Huntington Beach, CA 92615',28215,222,NULL,6,39797,0);
INSERT INTO "django_geo_db_location" VALUES(68308,NULL,'Irvine, CA 92616',28214,222,NULL,6,39798,0);
INSERT INTO "django_geo_db_location" VALUES(68309,NULL,'Irvine, CA 92618',28214,222,NULL,6,39799,0);
INSERT INTO "django_geo_db_location" VALUES(68310,NULL,'Irvine, CA 92619',28214,222,NULL,6,39800,0);
INSERT INTO "django_geo_db_location" VALUES(68311,NULL,'Irvine, CA 92620',28214,222,NULL,6,39801,0);
INSERT INTO "django_geo_db_location" VALUES(68312,NULL,'Irvine, CA 92623',28214,222,NULL,6,39802,0);
INSERT INTO "django_geo_db_location" VALUES(68313,NULL,'Capistrano Beach, CA',28218,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68314,NULL,'Capistrano Beach, CA 92624',28218,222,NULL,6,39803,0);
INSERT INTO "django_geo_db_location" VALUES(68315,NULL,'Corona Del Mar, CA',28219,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68316,NULL,'Corona Del Mar, CA 92625',28219,222,NULL,6,39804,0);
INSERT INTO "django_geo_db_location" VALUES(68317,NULL,'Costa Mesa, CA',28220,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68318,NULL,'Costa Mesa, CA 92626',28220,222,NULL,6,39805,0);
INSERT INTO "django_geo_db_location" VALUES(68319,NULL,'Costa Mesa, CA 92627',28220,222,NULL,6,39806,0);
INSERT INTO "django_geo_db_location" VALUES(68320,NULL,'Costa Mesa, CA 92628',28220,222,NULL,6,39807,0);
INSERT INTO "django_geo_db_location" VALUES(68321,NULL,'Dana Point, CA',28221,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68322,NULL,'Dana Point, CA 92629',28221,222,NULL,6,39808,0);
INSERT INTO "django_geo_db_location" VALUES(68323,NULL,'Lake Forest, CA',28222,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68324,NULL,'Lake Forest, CA 92630',28222,222,NULL,6,39809,0);
INSERT INTO "django_geo_db_location" VALUES(68325,NULL,'Laguna Hills, CA',28223,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68326,NULL,'Laguna Hills, CA 92635',28223,222,NULL,6,39810,0);
INSERT INTO "django_geo_db_location" VALUES(68327,NULL,'Huntington Beach, CA 92646',28215,222,NULL,6,39811,0);
INSERT INTO "django_geo_db_location" VALUES(68328,NULL,'Huntington Beach, CA 92647',28215,222,NULL,6,39812,0);
INSERT INTO "django_geo_db_location" VALUES(68329,NULL,'Huntington Beach, CA 92648',28215,222,NULL,6,39813,0);
INSERT INTO "django_geo_db_location" VALUES(68330,NULL,'Huntington Beach, CA 92649',28215,222,NULL,6,39814,0);
INSERT INTO "django_geo_db_location" VALUES(68331,NULL,'East Irvine, CA',28224,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68332,NULL,'East Irvine, CA 92650',28224,222,NULL,6,39815,0);
INSERT INTO "django_geo_db_location" VALUES(68333,NULL,'Laguna Beach, CA',28225,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68334,NULL,'Laguna Beach, CA 92651',28225,222,NULL,6,39816,0);
INSERT INTO "django_geo_db_location" VALUES(68335,NULL,'Laguna Beach, CA 92652',28225,222,NULL,6,39817,0);
INSERT INTO "django_geo_db_location" VALUES(68336,NULL,'Laguna Hills, CA 92653',28223,222,NULL,6,39818,0);
INSERT INTO "django_geo_db_location" VALUES(68337,NULL,'Laguna Hills, CA 92654',28223,222,NULL,6,39819,0);
INSERT INTO "django_geo_db_location" VALUES(68338,NULL,'Midway City, CA',28226,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68339,NULL,'Midway City, CA 92655',28226,222,NULL,6,39820,0);
INSERT INTO "django_geo_db_location" VALUES(68340,NULL,'Aliso Viejo, CA',28227,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68341,NULL,'Aliso Viejo, CA 92656',28227,222,NULL,6,39821,0);
INSERT INTO "django_geo_db_location" VALUES(68342,NULL,'Newport Coast, CA',28228,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68343,NULL,'Newport Coast, CA 92657',28228,222,NULL,6,39822,0);
INSERT INTO "django_geo_db_location" VALUES(68344,NULL,'Newport Beach, CA',28229,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68345,NULL,'Newport Beach, CA 92658',28229,222,NULL,6,39823,0);
INSERT INTO "django_geo_db_location" VALUES(68346,NULL,'Newport Beach, CA 92659',28229,222,NULL,6,39824,0);
INSERT INTO "django_geo_db_location" VALUES(68347,NULL,'Newport Beach, CA 92660',28229,222,NULL,6,39825,0);
INSERT INTO "django_geo_db_location" VALUES(68348,NULL,'Newport Beach, CA 92661',28229,222,NULL,6,39826,0);
INSERT INTO "django_geo_db_location" VALUES(68349,NULL,'Newport Beach, CA 92662',28229,222,NULL,6,39827,0);
INSERT INTO "django_geo_db_location" VALUES(68350,NULL,'Newport Beach, CA 92663',28229,222,NULL,6,39828,0);
INSERT INTO "django_geo_db_location" VALUES(68351,NULL,'Placentia, CA',28230,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68352,NULL,'Placentia, CA 92670',28230,222,NULL,6,39829,0);
INSERT INTO "django_geo_db_location" VALUES(68353,NULL,'San Clemente, CA',28231,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68354,NULL,'San Clemente, CA 92672',28231,222,NULL,6,39830,0);
INSERT INTO "django_geo_db_location" VALUES(68355,NULL,'San Clemente, CA 92673',28231,222,NULL,6,39831,0);
INSERT INTO "django_geo_db_location" VALUES(68356,NULL,'San Clemente, CA 92674',28231,222,NULL,6,39832,0);
INSERT INTO "django_geo_db_location" VALUES(68357,NULL,'San Juan Capistrano, CA',28232,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68358,NULL,'San Juan Capistrano, CA 92675',28232,222,NULL,6,39833,0);
INSERT INTO "django_geo_db_location" VALUES(68359,NULL,'Silverado, CA',28233,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68360,NULL,'Silverado, CA 92676',28233,222,NULL,6,39834,0);
INSERT INTO "django_geo_db_location" VALUES(68361,NULL,'Laguna Niguel, CA 92677',28216,222,NULL,6,39835,0);
INSERT INTO "django_geo_db_location" VALUES(68362,NULL,'Trabuco Canyon, CA',28234,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68363,NULL,'Trabuco Canyon, CA 92678',28234,222,NULL,6,39836,0);
INSERT INTO "django_geo_db_location" VALUES(68364,NULL,'Trabuco Canyon, CA 92679',28234,222,NULL,6,39837,0);
INSERT INTO "django_geo_db_location" VALUES(68365,NULL,'Garden Grove, CA',28235,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68366,NULL,'Garden Grove, CA 92680',28235,222,NULL,6,39838,0);
INSERT INTO "django_geo_db_location" VALUES(68367,NULL,'Westminster, CA',28236,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68368,NULL,'Westminster, CA 92683',28236,222,NULL,6,39839,0);
INSERT INTO "django_geo_db_location" VALUES(68369,NULL,'Westminster, CA 92684',28236,222,NULL,6,39840,0);
INSERT INTO "django_geo_db_location" VALUES(68370,NULL,'Westminster, CA 92685',28236,222,NULL,6,39841,0);
INSERT INTO "django_geo_db_location" VALUES(68371,NULL,'Rancho Santa Margarita, CA',28237,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68372,NULL,'Rancho Santa Margarita, CA 92688',28237,222,NULL,6,39842,0);
INSERT INTO "django_geo_db_location" VALUES(68373,NULL,'Mission Viejo, CA',28238,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68374,NULL,'Mission Viejo, CA 92690',28238,222,NULL,6,39843,0);
INSERT INTO "django_geo_db_location" VALUES(68375,NULL,'Mission Viejo, CA 92691',28238,222,NULL,6,39844,0);
INSERT INTO "django_geo_db_location" VALUES(68376,NULL,'Mission Viejo, CA 92692',28238,222,NULL,6,39845,0);
INSERT INTO "django_geo_db_location" VALUES(68377,NULL,'San Juan Capistrano, CA 92693',28232,222,NULL,6,39846,0);
INSERT INTO "django_geo_db_location" VALUES(68378,NULL,'Ladera Ranch, CA',28239,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68379,NULL,'Ladera Ranch, CA 92694',28239,222,NULL,6,39847,0);
INSERT INTO "django_geo_db_location" VALUES(68380,NULL,'Irvine, CA 92697',28214,222,NULL,6,39848,0);
INSERT INTO "django_geo_db_location" VALUES(68381,NULL,'Aliso Viejo, CA 92698',28227,222,NULL,6,39849,0);
INSERT INTO "django_geo_db_location" VALUES(68382,NULL,'Santa Ana, CA',28240,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68383,NULL,'Santa Ana, CA 92701',28240,222,NULL,6,39850,0);
INSERT INTO "django_geo_db_location" VALUES(68384,NULL,'Santa Ana, CA 92702',28240,222,NULL,6,39851,0);
INSERT INTO "django_geo_db_location" VALUES(68385,NULL,'Santa Ana, CA 92703',28240,222,NULL,6,39852,0);
INSERT INTO "django_geo_db_location" VALUES(68386,NULL,'Santa Ana, CA 92704',28240,222,NULL,6,39853,0);
INSERT INTO "django_geo_db_location" VALUES(68387,NULL,'Santa Ana, CA 92705',28240,222,NULL,6,39854,0);
INSERT INTO "django_geo_db_location" VALUES(68388,NULL,'Santa Ana, CA 92706',28240,222,NULL,6,39855,0);
INSERT INTO "django_geo_db_location" VALUES(68389,NULL,'Santa Ana, CA 92707',28240,222,NULL,6,39856,0);
INSERT INTO "django_geo_db_location" VALUES(68390,NULL,'Fountain Valley, CA',28241,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68391,NULL,'Fountain Valley, CA 92708',28241,222,NULL,6,39857,0);
INSERT INTO "django_geo_db_location" VALUES(68392,NULL,'Irvine, CA 92709',28214,222,NULL,6,39858,0);
INSERT INTO "django_geo_db_location" VALUES(68393,NULL,'Irvine, CA 92710',28214,222,NULL,6,39859,0);
INSERT INTO "django_geo_db_location" VALUES(68394,NULL,'Santa Ana, CA 92711',28240,222,NULL,6,39860,0);
INSERT INTO "django_geo_db_location" VALUES(68395,NULL,'Santa Ana, CA 92712',28240,222,NULL,6,39861,0);
INSERT INTO "django_geo_db_location" VALUES(68396,NULL,'Fountain Valley, CA 92728',28241,222,NULL,6,39862,0);
INSERT INTO "django_geo_db_location" VALUES(68397,NULL,'Santa Ana, CA 92735',28240,222,NULL,6,39863,0);
INSERT INTO "django_geo_db_location" VALUES(68398,NULL,'Tustin, CA',28242,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68399,NULL,'Tustin, CA 92780',28242,222,NULL,6,39864,0);
INSERT INTO "django_geo_db_location" VALUES(68400,NULL,'Tustin, CA 92781',28242,222,NULL,6,39865,0);
INSERT INTO "django_geo_db_location" VALUES(68401,NULL,'Tustin, CA 92782',28242,222,NULL,6,39866,0);
INSERT INTO "django_geo_db_location" VALUES(68402,NULL,'Santa Ana, CA 92799',28240,222,NULL,6,39867,0);
INSERT INTO "django_geo_db_location" VALUES(68403,NULL,'Anaheim, CA',28243,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68404,NULL,'Anaheim, CA 92801',28243,222,NULL,6,39868,0);
INSERT INTO "django_geo_db_location" VALUES(68405,NULL,'Anaheim, CA 92802',28243,222,NULL,6,39869,0);
INSERT INTO "django_geo_db_location" VALUES(68406,NULL,'Anaheim, CA 92803',28243,222,NULL,6,39870,0);
INSERT INTO "django_geo_db_location" VALUES(68407,NULL,'Anaheim, CA 92804',28243,222,NULL,6,39871,0);
INSERT INTO "django_geo_db_location" VALUES(68408,NULL,'Anaheim, CA 92805',28243,222,NULL,6,39872,0);
INSERT INTO "django_geo_db_location" VALUES(68409,NULL,'Anaheim, CA 92806',28243,222,NULL,6,39873,0);
INSERT INTO "django_geo_db_location" VALUES(68410,NULL,'Anaheim, CA 92807',28243,222,NULL,6,39874,0);
INSERT INTO "django_geo_db_location" VALUES(68411,NULL,'Anaheim, CA 92808',28243,222,NULL,6,39875,0);
INSERT INTO "django_geo_db_location" VALUES(68412,NULL,'Atwood, CA',28244,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68413,NULL,'Atwood, CA 92811',28244,222,NULL,6,39876,0);
INSERT INTO "django_geo_db_location" VALUES(68414,NULL,'Anaheim, CA 92812',28243,222,NULL,6,39877,0);
INSERT INTO "django_geo_db_location" VALUES(68415,NULL,'Anaheim, CA 92814',28243,222,NULL,6,39878,0);
INSERT INTO "django_geo_db_location" VALUES(68416,NULL,'Anaheim, CA 92815',28243,222,NULL,6,39879,0);
INSERT INTO "django_geo_db_location" VALUES(68417,NULL,'Anaheim, CA 92816',28243,222,NULL,6,39880,0);
INSERT INTO "django_geo_db_location" VALUES(68418,NULL,'Anaheim, CA 92817',28243,222,NULL,6,39881,0);
INSERT INTO "django_geo_db_location" VALUES(68419,NULL,'Brea, CA',28245,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68420,NULL,'Brea, CA 92821',28245,222,NULL,6,39882,0);
INSERT INTO "django_geo_db_location" VALUES(68421,NULL,'Brea, CA 92822',28245,222,NULL,6,39883,0);
INSERT INTO "django_geo_db_location" VALUES(68422,NULL,'Brea, CA 92823',28245,222,NULL,6,39884,0);
INSERT INTO "django_geo_db_location" VALUES(68423,NULL,'Anaheim, CA 92825',28243,222,NULL,6,39885,0);
INSERT INTO "django_geo_db_location" VALUES(68424,NULL,'Fullerton, CA',28246,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68425,NULL,'Fullerton, CA 92831',28246,222,NULL,6,39886,0);
INSERT INTO "django_geo_db_location" VALUES(68426,NULL,'Fullerton, CA 92832',28246,222,NULL,6,39887,0);
INSERT INTO "django_geo_db_location" VALUES(68427,NULL,'Fullerton, CA 92833',28246,222,NULL,6,39888,0);
INSERT INTO "django_geo_db_location" VALUES(68428,NULL,'Fullerton, CA 92834',28246,222,NULL,6,39889,0);
INSERT INTO "django_geo_db_location" VALUES(68429,NULL,'Fullerton, CA 92835',28246,222,NULL,6,39890,0);
INSERT INTO "django_geo_db_location" VALUES(68430,NULL,'Fullerton, CA 92836',28246,222,NULL,6,39891,0);
INSERT INTO "django_geo_db_location" VALUES(68431,NULL,'Fullerton, CA 92837',28246,222,NULL,6,39892,0);
INSERT INTO "django_geo_db_location" VALUES(68432,NULL,'Fullerton, CA 92838',28246,222,NULL,6,39893,0);
INSERT INTO "django_geo_db_location" VALUES(68433,NULL,'Garden Grove, CA 92840',28235,222,NULL,6,39894,0);
INSERT INTO "django_geo_db_location" VALUES(68434,NULL,'Garden Grove, CA 92841',28235,222,NULL,6,39895,0);
INSERT INTO "django_geo_db_location" VALUES(68435,NULL,'Garden Grove, CA 92842',28235,222,NULL,6,39896,0);
INSERT INTO "django_geo_db_location" VALUES(68436,NULL,'Garden Grove, CA 92843',28235,222,NULL,6,39897,0);
INSERT INTO "django_geo_db_location" VALUES(68437,NULL,'Garden Grove, CA 92844',28235,222,NULL,6,39898,0);
INSERT INTO "django_geo_db_location" VALUES(68438,NULL,'Garden Grove, CA 92845',28235,222,NULL,6,39899,0);
INSERT INTO "django_geo_db_location" VALUES(68439,NULL,'Garden Grove, CA 92846',28235,222,NULL,6,39900,0);
INSERT INTO "django_geo_db_location" VALUES(68440,NULL,'Anaheim, CA 92850',28243,222,NULL,6,39901,0);
INSERT INTO "django_geo_db_location" VALUES(68441,NULL,'Orange, CA',28247,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68442,NULL,'Orange, CA 92856',28247,222,NULL,6,39902,0);
INSERT INTO "django_geo_db_location" VALUES(68443,NULL,'Orange, CA 92857',28247,222,NULL,6,39903,0);
INSERT INTO "django_geo_db_location" VALUES(68444,NULL,'Orange, CA 92859',28247,222,NULL,6,39904,0);
INSERT INTO "django_geo_db_location" VALUES(68445,NULL,'Norco, CA 92860',28028,222,NULL,6,39905,0);
INSERT INTO "django_geo_db_location" VALUES(68446,NULL,'Villa Park, CA',28248,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68447,NULL,'Villa Park, CA 92861',28248,222,NULL,6,39906,0);
INSERT INTO "django_geo_db_location" VALUES(68448,NULL,'Orange, CA 92862',28247,222,NULL,6,39907,0);
INSERT INTO "django_geo_db_location" VALUES(68449,NULL,'Orange, CA 92863',28247,222,NULL,6,39908,0);
INSERT INTO "django_geo_db_location" VALUES(68450,NULL,'Orange, CA 92864',28247,222,NULL,6,39909,0);
INSERT INTO "django_geo_db_location" VALUES(68451,NULL,'Orange, CA 92865',28247,222,NULL,6,39910,0);
INSERT INTO "django_geo_db_location" VALUES(68452,NULL,'Orange, CA 92866',28247,222,NULL,6,39911,0);
INSERT INTO "django_geo_db_location" VALUES(68453,NULL,'Orange, CA 92867',28247,222,NULL,6,39912,0);
INSERT INTO "django_geo_db_location" VALUES(68454,NULL,'Orange, CA 92868',28247,222,NULL,6,39913,0);
INSERT INTO "django_geo_db_location" VALUES(68455,NULL,'Orange, CA 92869',28247,222,NULL,6,39914,0);
INSERT INTO "django_geo_db_location" VALUES(68456,NULL,'Placentia, CA 92870',28230,222,NULL,6,39915,0);
INSERT INTO "django_geo_db_location" VALUES(68457,NULL,'Placentia, CA 92871',28230,222,NULL,6,39916,0);
INSERT INTO "django_geo_db_location" VALUES(68458,NULL,'Corona, CA 92877',28013,222,NULL,6,39917,0);
INSERT INTO "django_geo_db_location" VALUES(68459,NULL,'Corona, CA 92878',28013,222,NULL,6,39918,0);
INSERT INTO "django_geo_db_location" VALUES(68460,NULL,'Corona, CA 92879',28013,222,NULL,6,39919,0);
INSERT INTO "django_geo_db_location" VALUES(68461,NULL,'Corona, CA 92880',28013,222,NULL,6,39920,0);
INSERT INTO "django_geo_db_location" VALUES(68462,NULL,'Corona, CA 92881',28013,222,NULL,6,39921,0);
INSERT INTO "django_geo_db_location" VALUES(68463,NULL,'Corona, CA 92882',28013,222,NULL,6,39922,0);
INSERT INTO "django_geo_db_location" VALUES(68464,NULL,'Corona, CA 92883',28013,222,NULL,6,39923,0);
INSERT INTO "django_geo_db_location" VALUES(68465,NULL,'Yorba Linda, CA',28249,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68466,NULL,'Yorba Linda, CA 92885',28249,222,NULL,6,39924,0);
INSERT INTO "django_geo_db_location" VALUES(68467,NULL,'Yorba Linda, CA 92886',28249,222,NULL,6,39925,0);
INSERT INTO "django_geo_db_location" VALUES(68468,NULL,'Yorba Linda, CA 92887',28249,222,NULL,6,39926,0);
INSERT INTO "django_geo_db_location" VALUES(68469,NULL,'Anaheim, CA 92899',28243,222,NULL,6,39927,0);
INSERT INTO "django_geo_db_location" VALUES(68470,NULL,'Ventura, CA',28250,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68471,NULL,'Ventura, CA 93001',28250,222,NULL,6,39928,0);
INSERT INTO "django_geo_db_location" VALUES(68472,NULL,'Ventura, CA 93002',28250,222,NULL,6,39929,0);
INSERT INTO "django_geo_db_location" VALUES(68473,NULL,'Ventura, CA 93003',28250,222,NULL,6,39930,0);
INSERT INTO "django_geo_db_location" VALUES(68474,NULL,'Ventura, CA 93004',28250,222,NULL,6,39931,0);
INSERT INTO "django_geo_db_location" VALUES(68475,NULL,'Ventura, CA 93005',28250,222,NULL,6,39932,0);
INSERT INTO "django_geo_db_location" VALUES(68476,NULL,'Ventura, CA 93006',28250,222,NULL,6,39933,0);
INSERT INTO "django_geo_db_location" VALUES(68477,NULL,'Ventura, CA 93007',28250,222,NULL,6,39934,0);
INSERT INTO "django_geo_db_location" VALUES(68478,NULL,'Ventura, CA 93009',28250,222,NULL,6,39935,0);
INSERT INTO "django_geo_db_location" VALUES(68479,NULL,'Camarillo, CA',28251,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68480,NULL,'Camarillo, CA 93010',28251,222,NULL,6,39936,0);
INSERT INTO "django_geo_db_location" VALUES(68481,NULL,'Camarillo, CA 93011',28251,222,NULL,6,39937,0);
INSERT INTO "django_geo_db_location" VALUES(68482,NULL,'Camarillo, CA 93012',28251,222,NULL,6,39938,0);
INSERT INTO "django_geo_db_location" VALUES(68483,NULL,'Carpinteria, CA',28252,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68484,NULL,'Carpinteria, CA 93013',28252,222,NULL,6,39939,0);
INSERT INTO "django_geo_db_location" VALUES(68485,NULL,'Carpinteria, CA 93014',28252,222,NULL,6,39940,0);
INSERT INTO "django_geo_db_location" VALUES(68486,NULL,'Fillmore, CA',28253,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68487,NULL,'Fillmore, CA 93015',28253,222,NULL,6,39941,0);
INSERT INTO "django_geo_db_location" VALUES(68488,NULL,'Fillmore, CA 93016',28253,222,NULL,6,39942,0);
INSERT INTO "django_geo_db_location" VALUES(68489,NULL,'Moorpark, CA',28254,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68490,NULL,'Moorpark, CA 93020',28254,222,NULL,6,39943,0);
INSERT INTO "django_geo_db_location" VALUES(68491,NULL,'Moorpark, CA 93021',28254,222,NULL,6,39944,0);
INSERT INTO "django_geo_db_location" VALUES(68492,NULL,'Oak View, CA',28255,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68493,NULL,'Oak View, CA 93022',28255,222,NULL,6,39945,0);
INSERT INTO "django_geo_db_location" VALUES(68494,NULL,'Ojai, CA',28256,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68495,NULL,'Ojai, CA 93023',28256,222,NULL,6,39946,0);
INSERT INTO "django_geo_db_location" VALUES(68496,NULL,'Ojai, CA 93024',28256,222,NULL,6,39947,0);
INSERT INTO "django_geo_db_location" VALUES(68497,NULL,'Oxnard, CA',28257,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68498,NULL,'Oxnard, CA 93030',28257,222,NULL,6,39948,0);
INSERT INTO "django_geo_db_location" VALUES(68499,NULL,'Oxnard, CA 93031',28257,222,NULL,6,39949,0);
INSERT INTO "django_geo_db_location" VALUES(68500,NULL,'Oxnard, CA 93032',28257,222,NULL,6,39950,0);
INSERT INTO "django_geo_db_location" VALUES(68501,NULL,'Oxnard, CA 93033',28257,222,NULL,6,39951,0);
INSERT INTO "django_geo_db_location" VALUES(68502,NULL,'Oxnard, CA 93034',28257,222,NULL,6,39952,0);
INSERT INTO "django_geo_db_location" VALUES(68503,NULL,'Oxnard, CA 93035',28257,222,NULL,6,39953,0);
INSERT INTO "django_geo_db_location" VALUES(68504,NULL,'Oxnard, CA 93036',28257,222,NULL,6,39954,0);
INSERT INTO "django_geo_db_location" VALUES(68505,NULL,'Piru, CA',28258,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68506,NULL,'Piru, CA 93040',28258,222,NULL,6,39955,0);
INSERT INTO "django_geo_db_location" VALUES(68507,NULL,'Port Hueneme, CA',28259,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68508,NULL,'Port Hueneme, CA 93041',28259,222,NULL,6,39956,0);
INSERT INTO "django_geo_db_location" VALUES(68509,NULL,'Point Mugu Nawc, CA',28260,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68510,NULL,'Point Mugu Nawc, CA 93042',28260,222,NULL,6,39957,0);
INSERT INTO "django_geo_db_location" VALUES(68511,NULL,'Port Hueneme Cbc Base, CA',28261,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68512,NULL,'Port Hueneme Cbc Base, CA 93043',28261,222,NULL,6,39958,0);
INSERT INTO "django_geo_db_location" VALUES(68513,NULL,'Port Hueneme, CA 93044',28259,222,NULL,6,39959,0);
INSERT INTO "django_geo_db_location" VALUES(68514,NULL,'Santa Paula, CA',28262,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68515,NULL,'Santa Paula, CA 93060',28262,222,NULL,6,39960,0);
INSERT INTO "django_geo_db_location" VALUES(68516,NULL,'Santa Paula, CA 93061',28262,222,NULL,6,39961,0);
INSERT INTO "django_geo_db_location" VALUES(68517,NULL,'Simi Valley, CA',28263,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68518,NULL,'Simi Valley, CA 93062',28263,222,NULL,6,39962,0);
INSERT INTO "django_geo_db_location" VALUES(68519,NULL,'Simi Valley, CA 93063',28263,222,NULL,6,39963,0);
INSERT INTO "django_geo_db_location" VALUES(68520,NULL,'Brandeis, CA',28264,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68521,NULL,'Brandeis, CA 93064',28264,222,NULL,6,39964,0);
INSERT INTO "django_geo_db_location" VALUES(68522,NULL,'Simi Valley, CA 93065',28263,222,NULL,6,39965,0);
INSERT INTO "django_geo_db_location" VALUES(68523,NULL,'Somis, CA',28265,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68524,NULL,'Somis, CA 93066',28265,222,NULL,6,39966,0);
INSERT INTO "django_geo_db_location" VALUES(68525,NULL,'Summerland, CA',28266,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68526,NULL,'Summerland, CA 93067',28266,222,NULL,6,39967,0);
INSERT INTO "django_geo_db_location" VALUES(68527,NULL,'Simi Valley, CA 93093',28263,222,NULL,6,39968,0);
INSERT INTO "django_geo_db_location" VALUES(68528,NULL,'Simi Valley, CA 93094',28263,222,NULL,6,39969,0);
INSERT INTO "django_geo_db_location" VALUES(68529,NULL,'Simi Valley, CA 93099',28263,222,NULL,6,39970,0);
INSERT INTO "django_geo_db_location" VALUES(68530,NULL,'Santa Barbara, CA',28267,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68531,NULL,'Santa Barbara, CA 93101',28267,222,NULL,6,39971,0);
INSERT INTO "django_geo_db_location" VALUES(68532,NULL,'Santa Barbara, CA 93102',28267,222,NULL,6,39972,0);
INSERT INTO "django_geo_db_location" VALUES(68533,NULL,'Santa Barbara, CA 93103',28267,222,NULL,6,39973,0);
INSERT INTO "django_geo_db_location" VALUES(68534,NULL,'Santa Barbara, CA 93105',28267,222,NULL,6,39974,0);
INSERT INTO "django_geo_db_location" VALUES(68535,NULL,'Santa Barbara, CA 93106',28267,222,NULL,6,39975,0);
INSERT INTO "django_geo_db_location" VALUES(68536,NULL,'Santa Barbara, CA 93107',28267,222,NULL,6,39976,0);
INSERT INTO "django_geo_db_location" VALUES(68537,NULL,'Santa Barbara, CA 93108',28267,222,NULL,6,39977,0);
INSERT INTO "django_geo_db_location" VALUES(68538,NULL,'Santa Barbara, CA 93109',28267,222,NULL,6,39978,0);
INSERT INTO "django_geo_db_location" VALUES(68539,NULL,'Santa Barbara, CA 93110',28267,222,NULL,6,39979,0);
INSERT INTO "django_geo_db_location" VALUES(68540,NULL,'Santa Barbara, CA 93111',28267,222,NULL,6,39980,0);
INSERT INTO "django_geo_db_location" VALUES(68541,NULL,'Goleta, CA',28268,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68542,NULL,'Goleta, CA 93116',28268,222,NULL,6,39981,0);
INSERT INTO "django_geo_db_location" VALUES(68543,NULL,'Goleta, CA 93117',28268,222,NULL,6,39982,0);
INSERT INTO "django_geo_db_location" VALUES(68544,NULL,'Goleta, CA 93118',28268,222,NULL,6,39983,0);
INSERT INTO "django_geo_db_location" VALUES(68545,NULL,'Santa Barbara, CA 93120',28267,222,NULL,6,39984,0);
INSERT INTO "django_geo_db_location" VALUES(68546,NULL,'Santa Barbara, CA 93121',28267,222,NULL,6,39985,0);
INSERT INTO "django_geo_db_location" VALUES(68547,NULL,'Santa Barbara, CA 93130',28267,222,NULL,6,39986,0);
INSERT INTO "django_geo_db_location" VALUES(68548,NULL,'Santa Barbara, CA 93140',28267,222,NULL,6,39987,0);
INSERT INTO "django_geo_db_location" VALUES(68549,NULL,'Santa Barbara, CA 93150',28267,222,NULL,6,39988,0);
INSERT INTO "django_geo_db_location" VALUES(68550,NULL,'Santa Barbara, CA 93160',28267,222,NULL,6,39989,0);
INSERT INTO "django_geo_db_location" VALUES(68551,NULL,'Santa Barbara, CA 93190',28267,222,NULL,6,39990,0);
INSERT INTO "django_geo_db_location" VALUES(68552,NULL,'Goleta, CA 93199',28268,222,NULL,6,39991,0);
INSERT INTO "django_geo_db_location" VALUES(68553,NULL,'Alpaugh, CA',28269,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68554,NULL,'Alpaugh, CA 93201',28269,222,NULL,6,39992,0);
INSERT INTO "django_geo_db_location" VALUES(68555,NULL,'Armona, CA',28270,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68556,NULL,'Armona, CA 93202',28270,222,NULL,6,39993,0);
INSERT INTO "django_geo_db_location" VALUES(68557,NULL,'Arvin, CA',28271,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68558,NULL,'Arvin, CA 93203',28271,222,NULL,6,39994,0);
INSERT INTO "django_geo_db_location" VALUES(68559,NULL,'Avenal, CA',28272,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68560,NULL,'Avenal, CA 93204',28272,222,NULL,6,39995,0);
INSERT INTO "django_geo_db_location" VALUES(68561,NULL,'Bodfish, CA',28273,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68562,NULL,'Bodfish, CA 93205',28273,222,NULL,6,39996,0);
INSERT INTO "django_geo_db_location" VALUES(68563,NULL,'Buttonwillow, CA',28274,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68564,NULL,'Buttonwillow, CA 93206',28274,222,NULL,6,39997,0);
INSERT INTO "django_geo_db_location" VALUES(68565,NULL,'California Hot Springs, CA',28275,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68566,NULL,'California Hot Springs, CA 93207',28275,222,NULL,6,39998,0);
INSERT INTO "django_geo_db_location" VALUES(68567,NULL,'Camp Nelson, CA',28276,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68568,NULL,'Camp Nelson, CA 93208',28276,222,NULL,6,39999,0);
INSERT INTO "django_geo_db_location" VALUES(68569,NULL,'Coalinga, CA',28277,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68570,NULL,'Coalinga, CA 93210',28277,222,NULL,6,40000,0);
INSERT INTO "django_geo_db_location" VALUES(68571,NULL,'Corcoran, CA',28278,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68572,NULL,'Corcoran, CA 93212',28278,222,NULL,6,40001,0);
INSERT INTO "django_geo_db_location" VALUES(68573,NULL,'Delano, CA',28279,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68574,NULL,'Delano, CA 93215',28279,222,NULL,6,40002,0);
INSERT INTO "django_geo_db_location" VALUES(68575,NULL,'Delano, CA 93216',28279,222,NULL,6,40003,0);
INSERT INTO "django_geo_db_location" VALUES(68576,NULL,'Earlimart, CA',28280,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68577,NULL,'Earlimart, CA 93217',28280,222,NULL,6,40004,0);
INSERT INTO "django_geo_db_location" VALUES(68578,NULL,'Ducor, CA',28281,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68579,NULL,'Ducor, CA 93218',28281,222,NULL,6,40005,0);
INSERT INTO "django_geo_db_location" VALUES(68580,NULL,'Earlimart, CA 93219',28280,222,NULL,6,40006,0);
INSERT INTO "django_geo_db_location" VALUES(68581,NULL,'Edison, CA',28282,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68582,NULL,'Edison, CA 93220',28282,222,NULL,6,40007,0);
INSERT INTO "django_geo_db_location" VALUES(68583,NULL,'Exeter, CA',28283,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68584,NULL,'Exeter, CA 93221',28283,222,NULL,6,40008,0);
INSERT INTO "django_geo_db_location" VALUES(68585,NULL,'Frazier Park, CA',28284,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68586,NULL,'Frazier Park, CA 93222',28284,222,NULL,6,40009,0);
INSERT INTO "django_geo_db_location" VALUES(68587,NULL,'Farmersville, CA',28285,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68588,NULL,'Farmersville, CA 93223',28285,222,NULL,6,40010,0);
INSERT INTO "django_geo_db_location" VALUES(68589,NULL,'Fellows, CA',28286,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68590,NULL,'Fellows, CA 93224',28286,222,NULL,6,40011,0);
INSERT INTO "django_geo_db_location" VALUES(68591,NULL,'Frazier Park, CA 93225',28284,222,NULL,6,40012,0);
INSERT INTO "django_geo_db_location" VALUES(68592,NULL,'Glennville, CA',28287,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68593,NULL,'Glennville, CA 93226',28287,222,NULL,6,40013,0);
INSERT INTO "django_geo_db_location" VALUES(68594,NULL,'Goshen, CA',28288,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68595,NULL,'Goshen, CA 93227',28288,222,NULL,6,40014,0);
INSERT INTO "django_geo_db_location" VALUES(68596,NULL,'Hanford, CA',28289,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68597,NULL,'Hanford, CA 93230',28289,222,NULL,6,40015,0);
INSERT INTO "django_geo_db_location" VALUES(68598,NULL,'Hanford, CA 93231',28289,222,NULL,6,40016,0);
INSERT INTO "django_geo_db_location" VALUES(68599,NULL,'Hanford, CA 93232',28289,222,NULL,6,40017,0);
INSERT INTO "django_geo_db_location" VALUES(68600,NULL,'Huron, CA',28290,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68601,NULL,'Huron, CA 93234',28290,222,NULL,6,40018,0);
INSERT INTO "django_geo_db_location" VALUES(68602,NULL,'Ivanhoe, CA',28291,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68603,NULL,'Ivanhoe, CA 93235',28291,222,NULL,6,40019,0);
INSERT INTO "django_geo_db_location" VALUES(68604,NULL,'Kaweah, CA',28292,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68605,NULL,'Kaweah, CA 93237',28292,222,NULL,6,40020,0);
INSERT INTO "django_geo_db_location" VALUES(68606,NULL,'Kernville, CA',28293,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68607,NULL,'Kernville, CA 93238',28293,222,NULL,6,40021,0);
INSERT INTO "django_geo_db_location" VALUES(68608,NULL,'Kettleman City, CA',28294,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68609,NULL,'Kettleman City, CA 93239',28294,222,NULL,6,40022,0);
INSERT INTO "django_geo_db_location" VALUES(68610,NULL,'Lake Isabella, CA',28295,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68611,NULL,'Lake Isabella, CA 93240',28295,222,NULL,6,40023,0);
INSERT INTO "django_geo_db_location" VALUES(68612,NULL,'Lamont, CA',28296,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68613,NULL,'Lamont, CA 93241',28296,222,NULL,6,40024,0);
INSERT INTO "django_geo_db_location" VALUES(68614,NULL,'Laton, CA',28297,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68615,NULL,'Laton, CA 93242',28297,222,NULL,6,40025,0);
INSERT INTO "django_geo_db_location" VALUES(68616,NULL,'Lebec, CA',28298,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68617,NULL,'Lebec, CA 93243',28298,222,NULL,6,40026,0);
INSERT INTO "django_geo_db_location" VALUES(68618,NULL,'Lemon Cove, CA',28299,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68619,NULL,'Lemon Cove, CA 93244',28299,222,NULL,6,40027,0);
INSERT INTO "django_geo_db_location" VALUES(68620,NULL,'Lemoore, CA',28300,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68621,NULL,'Lemoore, CA 93245',28300,222,NULL,6,40028,0);
INSERT INTO "django_geo_db_location" VALUES(68622,NULL,'Lemoore, CA 93246',28300,222,NULL,6,40029,0);
INSERT INTO "django_geo_db_location" VALUES(68623,NULL,'Lindsay, CA',28301,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68624,NULL,'Lindsay, CA 93247',28301,222,NULL,6,40030,0);
INSERT INTO "django_geo_db_location" VALUES(68625,NULL,'Lost Hills, CA',28302,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68626,NULL,'Lost Hills, CA 93249',28302,222,NULL,6,40031,0);
INSERT INTO "django_geo_db_location" VALUES(68627,NULL,'McFarland, CA',28303,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68628,NULL,'McFarland, CA 93250',28303,222,NULL,6,40032,0);
INSERT INTO "django_geo_db_location" VALUES(68629,NULL,'McKittrick, CA',28304,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68630,NULL,'McKittrick, CA 93251',28304,222,NULL,6,40033,0);
INSERT INTO "django_geo_db_location" VALUES(68631,NULL,'Maricopa, CA',28305,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68632,NULL,'Maricopa, CA 93252',28305,222,NULL,6,40034,0);
INSERT INTO "django_geo_db_location" VALUES(68633,NULL,'New Cuyama, CA',28306,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68634,NULL,'New Cuyama, CA 93254',28306,222,NULL,6,40035,0);
INSERT INTO "django_geo_db_location" VALUES(68635,NULL,'Onyx, CA',28307,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68636,NULL,'Onyx, CA 93255',28307,222,NULL,6,40036,0);
INSERT INTO "django_geo_db_location" VALUES(68637,NULL,'Pixley, CA',28308,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68638,NULL,'Pixley, CA 93256',28308,222,NULL,6,40037,0);
INSERT INTO "django_geo_db_location" VALUES(68639,NULL,'Porterville, CA',28309,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68640,NULL,'Porterville, CA 93257',28309,222,NULL,6,40038,0);
INSERT INTO "django_geo_db_location" VALUES(68641,NULL,'Porterville, CA 93258',28309,222,NULL,6,40039,0);
INSERT INTO "django_geo_db_location" VALUES(68642,NULL,'Posey, CA',28310,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68643,NULL,'Posey, CA 93260',28310,222,NULL,6,40040,0);
INSERT INTO "django_geo_db_location" VALUES(68644,NULL,'Richgrove, CA',28311,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68645,NULL,'Richgrove, CA 93261',28311,222,NULL,6,40041,0);
INSERT INTO "django_geo_db_location" VALUES(68646,NULL,'Sequoia National Park, CA',28312,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68647,NULL,'Sequoia National Park, CA 93262',28312,222,NULL,6,40042,0);
INSERT INTO "django_geo_db_location" VALUES(68648,NULL,'Shafter, CA',28313,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68649,NULL,'Shafter, CA 93263',28313,222,NULL,6,40043,0);
INSERT INTO "django_geo_db_location" VALUES(68650,NULL,'Springville, CA',28314,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68651,NULL,'Springville, CA 93265',28314,222,NULL,6,40044,0);
INSERT INTO "django_geo_db_location" VALUES(68652,NULL,'Stratford, CA',28315,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68653,NULL,'Stratford, CA 93266',28315,222,NULL,6,40045,0);
INSERT INTO "django_geo_db_location" VALUES(68654,NULL,'Strathmore, CA',28316,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68655,NULL,'Strathmore, CA 93267',28316,222,NULL,6,40046,0);
INSERT INTO "django_geo_db_location" VALUES(68656,NULL,'Taft, CA',28317,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68657,NULL,'Taft, CA 93268',28317,222,NULL,6,40047,0);
INSERT INTO "django_geo_db_location" VALUES(68658,NULL,'Terra Bella, CA',28318,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68659,NULL,'Terra Bella, CA 93270',28318,222,NULL,6,40048,0);
INSERT INTO "django_geo_db_location" VALUES(68660,NULL,'Three Rivers, CA',28319,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68661,NULL,'Three Rivers, CA 93271',28319,222,NULL,6,40049,0);
INSERT INTO "django_geo_db_location" VALUES(68662,NULL,'Tipton, CA',28320,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68663,NULL,'Tipton, CA 93272',28320,222,NULL,6,40050,0);
INSERT INTO "django_geo_db_location" VALUES(68664,NULL,'Tulare, CA',28321,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68665,NULL,'Tulare, CA 93274',28321,222,NULL,6,40051,0);
INSERT INTO "django_geo_db_location" VALUES(68666,NULL,'Tulare, CA 93275',28321,222,NULL,6,40052,0);
INSERT INTO "django_geo_db_location" VALUES(68667,NULL,'Tupman, CA',28322,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68668,NULL,'Tupman, CA 93276',28322,222,NULL,6,40053,0);
INSERT INTO "django_geo_db_location" VALUES(68669,NULL,'Visalia, CA',28323,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68670,NULL,'Visalia, CA 93277',28323,222,NULL,6,40054,0);
INSERT INTO "django_geo_db_location" VALUES(68671,NULL,'Visalia, CA 93278',28323,222,NULL,6,40055,0);
INSERT INTO "django_geo_db_location" VALUES(68672,NULL,'Visalia, CA 93279',28323,222,NULL,6,40056,0);
INSERT INTO "django_geo_db_location" VALUES(68673,NULL,'Wasco, CA',28324,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68674,NULL,'Wasco, CA 93280',28324,222,NULL,6,40057,0);
INSERT INTO "django_geo_db_location" VALUES(68675,NULL,'Waukena, CA',28325,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68676,NULL,'Waukena, CA 93282',28325,222,NULL,6,40058,0);
INSERT INTO "django_geo_db_location" VALUES(68677,NULL,'Weldon, CA',28326,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68678,NULL,'Weldon, CA 93283',28326,222,NULL,6,40059,0);
INSERT INTO "django_geo_db_location" VALUES(68679,NULL,'Wofford Heights, CA',28327,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68680,NULL,'Wofford Heights, CA 93285',28327,222,NULL,6,40060,0);
INSERT INTO "django_geo_db_location" VALUES(68681,NULL,'Woodlake, CA',28328,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68682,NULL,'Woodlake, CA 93286',28328,222,NULL,6,40061,0);
INSERT INTO "django_geo_db_location" VALUES(68683,NULL,'Woody, CA',28329,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68684,NULL,'Woody, CA 93287',28329,222,NULL,6,40062,0);
INSERT INTO "django_geo_db_location" VALUES(68685,NULL,'Visalia, CA 93291',28323,222,NULL,6,40063,0);
INSERT INTO "django_geo_db_location" VALUES(68686,NULL,'Visalia, CA 93292',28323,222,NULL,6,40064,0);
INSERT INTO "django_geo_db_location" VALUES(68687,NULL,'Bakersfield, CA',28330,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68688,NULL,'Bakersfield, CA 93301',28330,222,NULL,6,40065,0);
INSERT INTO "django_geo_db_location" VALUES(68689,NULL,'Bakersfield, CA 93302',28330,222,NULL,6,40066,0);
INSERT INTO "django_geo_db_location" VALUES(68690,NULL,'Bakersfield, CA 93303',28330,222,NULL,6,40067,0);
INSERT INTO "django_geo_db_location" VALUES(68691,NULL,'Bakersfield, CA 93304',28330,222,NULL,6,40068,0);
INSERT INTO "django_geo_db_location" VALUES(68692,NULL,'Bakersfield, CA 93305',28330,222,NULL,6,40069,0);
INSERT INTO "django_geo_db_location" VALUES(68693,NULL,'Bakersfield, CA 93306',28330,222,NULL,6,40070,0);
INSERT INTO "django_geo_db_location" VALUES(68694,NULL,'Bakersfield, CA 93307',28330,222,NULL,6,40071,0);
INSERT INTO "django_geo_db_location" VALUES(68695,NULL,'Bakersfield, CA 93308',28330,222,NULL,6,40072,0);
INSERT INTO "django_geo_db_location" VALUES(68696,NULL,'Bakersfield, CA 93309',28330,222,NULL,6,40073,0);
INSERT INTO "django_geo_db_location" VALUES(68697,NULL,'Bakersfield, CA 93311',28330,222,NULL,6,40074,0);
INSERT INTO "django_geo_db_location" VALUES(68698,NULL,'Bakersfield, CA 93312',28330,222,NULL,6,40075,0);
INSERT INTO "django_geo_db_location" VALUES(68699,NULL,'Bakersfield, CA 93313',28330,222,NULL,6,40076,0);
INSERT INTO "django_geo_db_location" VALUES(68700,NULL,'Lake of the Woods, CA',28331,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68701,NULL,'Lake of the Woods, CA 93325',28331,222,NULL,6,40077,0);
INSERT INTO "django_geo_db_location" VALUES(68702,NULL,'Bakersfield, CA 93380',28330,222,NULL,6,40078,0);
INSERT INTO "django_geo_db_location" VALUES(68703,NULL,'Bakersfield, CA 93381',28330,222,NULL,6,40079,0);
INSERT INTO "django_geo_db_location" VALUES(68704,NULL,'Bakersfield, CA 93382',28330,222,NULL,6,40080,0);
INSERT INTO "django_geo_db_location" VALUES(68705,NULL,'Bakersfield, CA 93383',28330,222,NULL,6,40081,0);
INSERT INTO "django_geo_db_location" VALUES(68706,NULL,'Bakersfield, CA 93384',28330,222,NULL,6,40082,0);
INSERT INTO "django_geo_db_location" VALUES(68707,NULL,'Bakersfield, CA 93385',28330,222,NULL,6,40083,0);
INSERT INTO "django_geo_db_location" VALUES(68708,NULL,'Bakersfield, CA 93386',28330,222,NULL,6,40084,0);
INSERT INTO "django_geo_db_location" VALUES(68709,NULL,'Bakersfield, CA 93387',28330,222,NULL,6,40085,0);
INSERT INTO "django_geo_db_location" VALUES(68710,NULL,'Bakersfield, CA 93388',28330,222,NULL,6,40086,0);
INSERT INTO "django_geo_db_location" VALUES(68711,NULL,'Bakersfield, CA 93389',28330,222,NULL,6,40087,0);
INSERT INTO "django_geo_db_location" VALUES(68712,NULL,'Bakersfield, CA 93390',28330,222,NULL,6,40088,0);
INSERT INTO "django_geo_db_location" VALUES(68713,NULL,'San Luis Obispo, CA',28332,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68714,NULL,'San Luis Obispo, CA 93401',28332,222,NULL,6,40089,0);
INSERT INTO "django_geo_db_location" VALUES(68715,NULL,'Los Osos, CA',28333,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68716,NULL,'Los Osos, CA 93402',28333,222,NULL,6,40090,0);
INSERT INTO "django_geo_db_location" VALUES(68717,NULL,'San Luis Obispo, CA 93403',28332,222,NULL,6,40091,0);
INSERT INTO "django_geo_db_location" VALUES(68718,NULL,'San Luis Obispo, CA 93405',28332,222,NULL,6,40092,0);
INSERT INTO "django_geo_db_location" VALUES(68719,NULL,'San Luis Obispo, CA 93406',28332,222,NULL,6,40093,0);
INSERT INTO "django_geo_db_location" VALUES(68720,NULL,'San Luis Obispo, CA 93407',28332,222,NULL,6,40094,0);
INSERT INTO "django_geo_db_location" VALUES(68721,NULL,'San Luis Obispo, CA 93408',28332,222,NULL,6,40095,0);
INSERT INTO "django_geo_db_location" VALUES(68722,NULL,'San Luis Obispo, CA 93409',28332,222,NULL,6,40096,0);
INSERT INTO "django_geo_db_location" VALUES(68723,NULL,'San Luis Obispo, CA 93410',28332,222,NULL,6,40097,0);
INSERT INTO "django_geo_db_location" VALUES(68724,NULL,'Los Osos, CA 93412',28333,222,NULL,6,40098,0);
INSERT INTO "django_geo_db_location" VALUES(68725,NULL,'Arroyo Grande, CA',28334,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68726,NULL,'Arroyo Grande, CA 93420',28334,222,NULL,6,40099,0);
INSERT INTO "django_geo_db_location" VALUES(68727,NULL,'Arroyo Grande, CA 93421',28334,222,NULL,6,40100,0);
INSERT INTO "django_geo_db_location" VALUES(68728,NULL,'Atascadero, CA',28335,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68729,NULL,'Atascadero, CA 93422',28335,222,NULL,6,40101,0);
INSERT INTO "django_geo_db_location" VALUES(68730,NULL,'Atascadero, CA 93423',28335,222,NULL,6,40102,0);
INSERT INTO "django_geo_db_location" VALUES(68731,NULL,'Avila Beach, CA',28336,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68732,NULL,'Avila Beach, CA 93424',28336,222,NULL,6,40103,0);
INSERT INTO "django_geo_db_location" VALUES(68733,NULL,'Bradley, CA',28337,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68734,NULL,'Bradley, CA 93426',28337,222,NULL,6,40104,0);
INSERT INTO "django_geo_db_location" VALUES(68735,NULL,'Buellton, CA',28338,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68736,NULL,'Buellton, CA 93427',28338,222,NULL,6,40105,0);
INSERT INTO "django_geo_db_location" VALUES(68737,NULL,'Cambria, CA',28339,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68738,NULL,'Cambria, CA 93428',28339,222,NULL,6,40106,0);
INSERT INTO "django_geo_db_location" VALUES(68739,NULL,'Casmalia, CA',28340,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68740,NULL,'Casmalia, CA 93429',28340,222,NULL,6,40107,0);
INSERT INTO "django_geo_db_location" VALUES(68741,NULL,'Cayucos, CA',28341,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68742,NULL,'Cayucos, CA 93430',28341,222,NULL,6,40108,0);
INSERT INTO "django_geo_db_location" VALUES(68743,NULL,'Creston, CA',28342,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68744,NULL,'Creston, CA 93432',28342,222,NULL,6,40109,0);
INSERT INTO "django_geo_db_location" VALUES(68745,NULL,'Grover Beach, CA',28343,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68746,NULL,'Grover Beach, CA 93433',28343,222,NULL,6,40110,0);
INSERT INTO "django_geo_db_location" VALUES(68747,NULL,'Guadalupe, CA',28344,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68748,NULL,'Guadalupe, CA 93434',28344,222,NULL,6,40111,0);
INSERT INTO "django_geo_db_location" VALUES(68749,NULL,'Harmony, CA',28345,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68750,NULL,'Harmony, CA 93435',28345,222,NULL,6,40112,0);
INSERT INTO "django_geo_db_location" VALUES(68751,NULL,'Lompoc, CA',28346,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68752,NULL,'Lompoc, CA 93436',28346,222,NULL,6,40113,0);
INSERT INTO "django_geo_db_location" VALUES(68753,NULL,'Lompoc, CA 93437',28346,222,NULL,6,40114,0);
INSERT INTO "django_geo_db_location" VALUES(68754,NULL,'Lompoc, CA 93438',28346,222,NULL,6,40115,0);
INSERT INTO "django_geo_db_location" VALUES(68755,NULL,'Los Alamos, CA',28347,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68756,NULL,'Los Alamos, CA 93440',28347,222,NULL,6,40116,0);
INSERT INTO "django_geo_db_location" VALUES(68757,NULL,'Los Olivos, CA',28348,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68758,NULL,'Los Olivos, CA 93441',28348,222,NULL,6,40117,0);
INSERT INTO "django_geo_db_location" VALUES(68759,NULL,'Morro Bay, CA',28349,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68760,NULL,'Morro Bay, CA 93442',28349,222,NULL,6,40118,0);
INSERT INTO "django_geo_db_location" VALUES(68761,NULL,'Morro Bay, CA 93443',28349,222,NULL,6,40119,0);
INSERT INTO "django_geo_db_location" VALUES(68762,NULL,'Nipomo, CA',28350,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68763,NULL,'Nipomo, CA 93444',28350,222,NULL,6,40120,0);
INSERT INTO "django_geo_db_location" VALUES(68764,NULL,'Oceano, CA',28351,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68765,NULL,'Oceano, CA 93445',28351,222,NULL,6,40121,0);
INSERT INTO "django_geo_db_location" VALUES(68766,NULL,'Paso Robles, CA',28352,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68767,NULL,'Paso Robles, CA 93446',28352,222,NULL,6,40122,0);
INSERT INTO "django_geo_db_location" VALUES(68768,NULL,'Paso Robles, CA 93447',28352,222,NULL,6,40123,0);
INSERT INTO "django_geo_db_location" VALUES(68769,NULL,'Pismo Beach, CA',28353,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68770,NULL,'Pismo Beach, CA 93448',28353,222,NULL,6,40124,0);
INSERT INTO "django_geo_db_location" VALUES(68771,NULL,'Pismo Beach, CA 93449',28353,222,NULL,6,40125,0);
INSERT INTO "django_geo_db_location" VALUES(68772,NULL,'San Ardo, CA',28354,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68773,NULL,'San Ardo, CA 93450',28354,222,NULL,6,40126,0);
INSERT INTO "django_geo_db_location" VALUES(68774,NULL,'San Miguel, CA',28355,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68775,NULL,'San Miguel, CA 93451',28355,222,NULL,6,40127,0);
INSERT INTO "django_geo_db_location" VALUES(68776,NULL,'San Simeon, CA',28356,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68777,NULL,'San Simeon, CA 93452',28356,222,NULL,6,40128,0);
INSERT INTO "django_geo_db_location" VALUES(68778,NULL,'Santa Margarita, CA',28357,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68779,NULL,'Santa Margarita, CA 93453',28357,222,NULL,6,40129,0);
INSERT INTO "django_geo_db_location" VALUES(68780,NULL,'Santa Maria, CA',28358,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68781,NULL,'Santa Maria, CA 93454',28358,222,NULL,6,40130,0);
INSERT INTO "django_geo_db_location" VALUES(68782,NULL,'Santa Maria, CA 93455',28358,222,NULL,6,40131,0);
INSERT INTO "django_geo_db_location" VALUES(68783,NULL,'Santa Maria, CA 93456',28358,222,NULL,6,40132,0);
INSERT INTO "django_geo_db_location" VALUES(68784,NULL,'Santa Maria, CA 93457',28358,222,NULL,6,40133,0);
INSERT INTO "django_geo_db_location" VALUES(68785,NULL,'Santa Maria, CA 93458',28358,222,NULL,6,40134,0);
INSERT INTO "django_geo_db_location" VALUES(68786,NULL,'Santa Ynez, CA',28359,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68787,NULL,'Santa Ynez, CA 93460',28359,222,NULL,6,40135,0);
INSERT INTO "django_geo_db_location" VALUES(68788,NULL,'Shandon, CA',28360,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68789,NULL,'Shandon, CA 93461',28360,222,NULL,6,40136,0);
INSERT INTO "django_geo_db_location" VALUES(68790,NULL,'Solvang, CA',28361,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68791,NULL,'Solvang, CA 93463',28361,222,NULL,6,40137,0);
INSERT INTO "django_geo_db_location" VALUES(68792,NULL,'Solvang, CA 93464',28361,222,NULL,6,40138,0);
INSERT INTO "django_geo_db_location" VALUES(68793,NULL,'Templeton, CA',28362,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68794,NULL,'Templeton, CA 93465',28362,222,NULL,6,40139,0);
INSERT INTO "django_geo_db_location" VALUES(68795,NULL,'Grover Beach, CA 93483',28343,222,NULL,6,40140,0);
INSERT INTO "django_geo_db_location" VALUES(68796,NULL,'Morro Bay, CA 93492',28349,222,NULL,6,40141,0);
INSERT INTO "django_geo_db_location" VALUES(68797,NULL,'Mojave, CA',28363,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68798,NULL,'Mojave, CA 93501',28363,222,NULL,6,40142,0);
INSERT INTO "django_geo_db_location" VALUES(68799,NULL,'Mojave, CA 93502',28363,222,NULL,6,40143,0);
INSERT INTO "django_geo_db_location" VALUES(68800,NULL,'California City, CA',28364,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68801,NULL,'California City, CA 93504',28364,222,NULL,6,40144,0);
INSERT INTO "django_geo_db_location" VALUES(68802,NULL,'California City, CA 93505',28364,222,NULL,6,40145,0);
INSERT INTO "django_geo_db_location" VALUES(68803,NULL,'Acton, CA',28365,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68804,NULL,'Acton, CA 93510',28365,222,NULL,6,40146,0);
INSERT INTO "django_geo_db_location" VALUES(68805,NULL,'Benton, CA',28366,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68806,NULL,'Benton, CA 93512',28366,222,NULL,6,40147,0);
INSERT INTO "django_geo_db_location" VALUES(68807,NULL,'Big Pine, CA',28367,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68808,NULL,'Big Pine, CA 93513',28367,222,NULL,6,40148,0);
INSERT INTO "django_geo_db_location" VALUES(68809,NULL,'Bishop, CA',28368,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68810,NULL,'Bishop, CA 93514',28368,222,NULL,6,40149,0);
INSERT INTO "django_geo_db_location" VALUES(68811,NULL,'Bishop, CA 93515',28368,222,NULL,6,40150,0);
INSERT INTO "django_geo_db_location" VALUES(68812,NULL,'Boron, CA',28369,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68813,NULL,'Boron, CA 93516',28369,222,NULL,6,40151,0);
INSERT INTO "django_geo_db_location" VALUES(68814,NULL,'Bridgeport, CA',28370,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68815,NULL,'Bridgeport, CA 93517',28370,222,NULL,6,40152,0);
INSERT INTO "django_geo_db_location" VALUES(68816,NULL,'Caliente, CA',28371,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68817,NULL,'Caliente, CA 93518',28371,222,NULL,6,40153,0);
INSERT INTO "django_geo_db_location" VALUES(68818,NULL,'Cantil, CA',28372,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68819,NULL,'Cantil, CA 93519',28372,222,NULL,6,40154,0);
INSERT INTO "django_geo_db_location" VALUES(68820,NULL,'Darwin, CA',28373,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68821,NULL,'Darwin, CA 93522',28373,222,NULL,6,40155,0);
INSERT INTO "django_geo_db_location" VALUES(68822,NULL,'Edwards, CA',28374,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68823,NULL,'Edwards, CA 93523',28374,222,NULL,6,40156,0);
INSERT INTO "django_geo_db_location" VALUES(68824,NULL,'Edwards, CA 93524',28374,222,NULL,6,40157,0);
INSERT INTO "django_geo_db_location" VALUES(68825,NULL,'Independence, CA',28375,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68826,NULL,'Independence, CA 93526',28375,222,NULL,6,40158,0);
INSERT INTO "django_geo_db_location" VALUES(68827,NULL,'Inyokern, CA',28376,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68828,NULL,'Inyokern, CA 93527',28376,222,NULL,6,40159,0);
INSERT INTO "django_geo_db_location" VALUES(68829,NULL,'Johannesburg, CA',28377,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68830,NULL,'Johannesburg, CA 93528',28377,222,NULL,6,40160,0);
INSERT INTO "django_geo_db_location" VALUES(68831,NULL,'June Lake, CA',28378,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68832,NULL,'June Lake, CA 93529',28378,222,NULL,6,40161,0);
INSERT INTO "django_geo_db_location" VALUES(68833,NULL,'Keeler, CA',28379,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68834,NULL,'Keeler, CA 93530',28379,222,NULL,6,40162,0);
INSERT INTO "django_geo_db_location" VALUES(68835,NULL,'Keene, CA',28380,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68836,NULL,'Keene, CA 93531',28380,222,NULL,6,40163,0);
INSERT INTO "django_geo_db_location" VALUES(68837,NULL,'Lake Hughes, CA',28381,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68838,NULL,'Lake Hughes, CA 93532',28381,222,NULL,6,40164,0);
INSERT INTO "django_geo_db_location" VALUES(68839,NULL,'Lancaster, CA',28382,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68840,NULL,'Lancaster, CA 93534',28382,222,NULL,6,40165,0);
INSERT INTO "django_geo_db_location" VALUES(68841,NULL,'Lancaster, CA 93535',28382,222,NULL,6,40166,0);
INSERT INTO "django_geo_db_location" VALUES(68842,NULL,'Lancaster, CA 93536',28382,222,NULL,6,40167,0);
INSERT INTO "django_geo_db_location" VALUES(68843,NULL,'Lancaster, CA 93539',28382,222,NULL,6,40168,0);
INSERT INTO "django_geo_db_location" VALUES(68844,NULL,'Lake Isabella, CA 93540',28295,222,NULL,6,40169,0);
INSERT INTO "django_geo_db_location" VALUES(68845,NULL,'Lee Vining, CA',28383,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68846,NULL,'Lee Vining, CA 93541',28383,222,NULL,6,40170,0);
INSERT INTO "django_geo_db_location" VALUES(68847,NULL,'Little Lake, CA',28384,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68848,NULL,'Little Lake, CA 93542',28384,222,NULL,6,40171,0);
INSERT INTO "django_geo_db_location" VALUES(68849,NULL,'Littlerock, CA',28385,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68850,NULL,'Littlerock, CA 93543',28385,222,NULL,6,40172,0);
INSERT INTO "django_geo_db_location" VALUES(68851,NULL,'Llano, CA',28386,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68852,NULL,'Llano, CA 93544',28386,222,NULL,6,40173,0);
INSERT INTO "django_geo_db_location" VALUES(68853,NULL,'Lone Pine, CA',28387,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68854,NULL,'Lone Pine, CA 93545',28387,222,NULL,6,40174,0);
INSERT INTO "django_geo_db_location" VALUES(68855,NULL,'Mammoth Lakes, CA',28388,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68856,NULL,'Mammoth Lakes, CA 93546',28388,222,NULL,6,40175,0);
INSERT INTO "django_geo_db_location" VALUES(68857,NULL,'Olancha, CA',28389,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68858,NULL,'Olancha, CA 93549',28389,222,NULL,6,40176,0);
INSERT INTO "django_geo_db_location" VALUES(68859,NULL,'Palmdale, CA',28390,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68860,NULL,'Palmdale, CA 93550',28390,222,NULL,6,40177,0);
INSERT INTO "django_geo_db_location" VALUES(68861,NULL,'Palmdale, CA 93551',28390,222,NULL,6,40178,0);
INSERT INTO "django_geo_db_location" VALUES(68862,NULL,'Palmdale, CA 93552',28390,222,NULL,6,40179,0);
INSERT INTO "django_geo_db_location" VALUES(68863,NULL,'Pearblossom, CA',28391,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68864,NULL,'Pearblossom, CA 93553',28391,222,NULL,6,40180,0);
INSERT INTO "django_geo_db_location" VALUES(68865,NULL,'Randsburg, CA',28392,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68866,NULL,'Randsburg, CA 93554',28392,222,NULL,6,40181,0);
INSERT INTO "django_geo_db_location" VALUES(68867,NULL,'Ridgecrest, CA',28393,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68868,NULL,'Ridgecrest, CA 93555',28393,222,NULL,6,40182,0);
INSERT INTO "django_geo_db_location" VALUES(68869,NULL,'Ridgecrest, CA 93556',28393,222,NULL,6,40183,0);
INSERT INTO "django_geo_db_location" VALUES(68870,NULL,'Red Mountain, CA',28394,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68871,NULL,'Red Mountain, CA 93558',28394,222,NULL,6,40184,0);
INSERT INTO "django_geo_db_location" VALUES(68872,NULL,'Rosamond, CA',28395,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68873,NULL,'Rosamond, CA 93560',28395,222,NULL,6,40185,0);
INSERT INTO "django_geo_db_location" VALUES(68874,NULL,'Tehachapi, CA',28396,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68875,NULL,'Tehachapi, CA 93561',28396,222,NULL,6,40186,0);
INSERT INTO "django_geo_db_location" VALUES(68876,NULL,'Trona, CA',28397,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68877,NULL,'Trona, CA 93562',28397,222,NULL,6,40187,0);
INSERT INTO "django_geo_db_location" VALUES(68878,NULL,'Valyermo, CA',28398,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68879,NULL,'Valyermo, CA 93563',28398,222,NULL,6,40188,0);
INSERT INTO "django_geo_db_location" VALUES(68880,NULL,'Rosamond, CA 93564',28395,222,NULL,6,40189,0);
INSERT INTO "django_geo_db_location" VALUES(68881,NULL,'Tehachapi, CA 93581',28396,222,NULL,6,40190,0);
INSERT INTO "django_geo_db_location" VALUES(68882,NULL,'Lancaster, CA 93584',28382,222,NULL,6,40191,0);
INSERT INTO "django_geo_db_location" VALUES(68883,NULL,'Lancaster, CA 93586',28382,222,NULL,6,40192,0);
INSERT INTO "django_geo_db_location" VALUES(68884,NULL,'Palmdale, CA 93590',28390,222,NULL,6,40193,0);
INSERT INTO "django_geo_db_location" VALUES(68885,NULL,'Palmdale, CA 93591',28390,222,NULL,6,40194,0);
INSERT INTO "django_geo_db_location" VALUES(68886,NULL,'Trona, CA 93592',28397,222,NULL,6,40195,0);
INSERT INTO "django_geo_db_location" VALUES(68887,NULL,'Boron, CA 93596',28369,222,NULL,6,40196,0);
INSERT INTO "django_geo_db_location" VALUES(68888,NULL,'Palmdale, CA 93599',28390,222,NULL,6,40197,0);
INSERT INTO "django_geo_db_location" VALUES(68889,NULL,'Ahwahnee, CA',28399,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68890,NULL,'Ahwahnee, CA 93601',28399,222,NULL,6,40198,0);
INSERT INTO "django_geo_db_location" VALUES(68891,NULL,'Auberry, CA',28400,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68892,NULL,'Auberry, CA 93602',28400,222,NULL,6,40199,0);
INSERT INTO "django_geo_db_location" VALUES(68893,NULL,'Badger, CA',28401,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68894,NULL,'Badger, CA 93603',28401,222,NULL,6,40200,0);
INSERT INTO "django_geo_db_location" VALUES(68895,NULL,'Bass Lake, CA',28402,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68896,NULL,'Bass Lake, CA 93604',28402,222,NULL,6,40201,0);
INSERT INTO "django_geo_db_location" VALUES(68897,NULL,'Big Creek, CA',28403,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68898,NULL,'Big Creek, CA 93605',28403,222,NULL,6,40202,0);
INSERT INTO "django_geo_db_location" VALUES(68899,NULL,'Biola, CA',28404,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68900,NULL,'Biola, CA 93606',28404,222,NULL,6,40203,0);
INSERT INTO "django_geo_db_location" VALUES(68901,NULL,'Burrel, CA',28405,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68902,NULL,'Burrel, CA 93607',28405,222,NULL,6,40204,0);
INSERT INTO "django_geo_db_location" VALUES(68903,NULL,'Cantua Creek, CA',28406,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68904,NULL,'Cantua Creek, CA 93608',28406,222,NULL,6,40205,0);
INSERT INTO "django_geo_db_location" VALUES(68905,NULL,'Caruthers, CA',28407,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68906,NULL,'Caruthers, CA 93609',28407,222,NULL,6,40206,0);
INSERT INTO "django_geo_db_location" VALUES(68907,NULL,'Chowchilla, CA',28408,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68908,NULL,'Chowchilla, CA 93610',28408,222,NULL,6,40207,0);
INSERT INTO "django_geo_db_location" VALUES(68909,NULL,'Clovis, CA',28409,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68910,NULL,'Clovis, CA 93611',28409,222,NULL,6,40208,0);
INSERT INTO "django_geo_db_location" VALUES(68911,NULL,'Clovis, CA 93612',28409,222,NULL,6,40209,0);
INSERT INTO "django_geo_db_location" VALUES(68912,NULL,'Clovis, CA 93613',28409,222,NULL,6,40210,0);
INSERT INTO "django_geo_db_location" VALUES(68913,NULL,'Coarsegold, CA',28410,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68914,NULL,'Coarsegold, CA 93614',28410,222,NULL,6,40211,0);
INSERT INTO "django_geo_db_location" VALUES(68915,NULL,'Cutler, CA',28411,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68916,NULL,'Cutler, CA 93615',28411,222,NULL,6,40212,0);
INSERT INTO "django_geo_db_location" VALUES(68917,NULL,'Del Rey, CA',28412,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68918,NULL,'Del Rey, CA 93616',28412,222,NULL,6,40213,0);
INSERT INTO "django_geo_db_location" VALUES(68919,NULL,'Dinuba, CA',28413,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68920,NULL,'Dinuba, CA 93618',28413,222,NULL,6,40214,0);
INSERT INTO "django_geo_db_location" VALUES(68921,NULL,'Dos Palos, CA',28414,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68922,NULL,'Dos Palos, CA 93620',28414,222,NULL,6,40215,0);
INSERT INTO "django_geo_db_location" VALUES(68923,NULL,'Dunlap, CA',28415,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68924,NULL,'Dunlap, CA 93621',28415,222,NULL,6,40216,0);
INSERT INTO "django_geo_db_location" VALUES(68925,NULL,'Firebaugh, CA',28416,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68926,NULL,'Firebaugh, CA 93622',28416,222,NULL,6,40217,0);
INSERT INTO "django_geo_db_location" VALUES(68927,NULL,'Fish Camp, CA',28417,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68928,NULL,'Fish Camp, CA 93623',28417,222,NULL,6,40218,0);
INSERT INTO "django_geo_db_location" VALUES(68929,NULL,'Five Points, CA',28418,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68930,NULL,'Five Points, CA 93624',28418,222,NULL,6,40219,0);
INSERT INTO "django_geo_db_location" VALUES(68931,NULL,'Fowler, CA',28419,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68932,NULL,'Fowler, CA 93625',28419,222,NULL,6,40220,0);
INSERT INTO "django_geo_db_location" VALUES(68933,NULL,'Friant, CA',28420,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68934,NULL,'Friant, CA 93626',28420,222,NULL,6,40221,0);
INSERT INTO "django_geo_db_location" VALUES(68935,NULL,'Helm, CA',28421,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68936,NULL,'Helm, CA 93627',28421,222,NULL,6,40222,0);
INSERT INTO "django_geo_db_location" VALUES(68937,NULL,'Hume, CA',28422,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68938,NULL,'Hume, CA 93628',28422,222,NULL,6,40223,0);
INSERT INTO "django_geo_db_location" VALUES(68939,NULL,'Kerman, CA',28423,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68940,NULL,'Kerman, CA 93630',28423,222,NULL,6,40224,0);
INSERT INTO "django_geo_db_location" VALUES(68941,NULL,'Kingsburg, CA',28424,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68942,NULL,'Kingsburg, CA 93631',28424,222,NULL,6,40225,0);
INSERT INTO "django_geo_db_location" VALUES(68943,NULL,'Kings Canyon National Pk, CA',28425,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68944,NULL,'Kings Canyon National Pk, CA 93633',28425,222,NULL,6,40226,0);
INSERT INTO "django_geo_db_location" VALUES(68945,NULL,'Lakeshore, CA',28426,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68946,NULL,'Lakeshore, CA 93634',28426,222,NULL,6,40227,0);
INSERT INTO "django_geo_db_location" VALUES(68947,NULL,'Los Banos, CA',28427,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68948,NULL,'Los Banos, CA 93635',28427,222,NULL,6,40228,0);
INSERT INTO "django_geo_db_location" VALUES(68949,NULL,'Madera, CA',28428,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68950,NULL,'Madera, CA 93637',28428,222,NULL,6,40229,0);
INSERT INTO "django_geo_db_location" VALUES(68951,NULL,'Madera, CA 93638',28428,222,NULL,6,40230,0);
INSERT INTO "django_geo_db_location" VALUES(68952,NULL,'Madera, CA 93639',28428,222,NULL,6,40231,0);
INSERT INTO "django_geo_db_location" VALUES(68953,NULL,'Mendota, CA',28429,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68954,NULL,'Mendota, CA 93640',28429,222,NULL,6,40232,0);
INSERT INTO "django_geo_db_location" VALUES(68955,NULL,'Miramonte, CA',28430,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68956,NULL,'Miramonte, CA 93641',28430,222,NULL,6,40233,0);
INSERT INTO "django_geo_db_location" VALUES(68957,NULL,'Mono Hot Springs, CA',28431,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68958,NULL,'Mono Hot Springs, CA 93642',28431,222,NULL,6,40234,0);
INSERT INTO "django_geo_db_location" VALUES(68959,NULL,'North Fork, CA',28432,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68960,NULL,'North Fork, CA 93643',28432,222,NULL,6,40235,0);
INSERT INTO "django_geo_db_location" VALUES(68961,NULL,'Oakhurst, CA',28433,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68962,NULL,'Oakhurst, CA 93644',28433,222,NULL,6,40236,0);
INSERT INTO "django_geo_db_location" VALUES(68963,NULL,'O Neals, CA',28434,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68964,NULL,'O Neals, CA 93645',28434,222,NULL,6,40237,0);
INSERT INTO "django_geo_db_location" VALUES(68965,NULL,'Orange Cove, CA',28435,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68966,NULL,'Orange Cove, CA 93646',28435,222,NULL,6,40238,0);
INSERT INTO "django_geo_db_location" VALUES(68967,NULL,'Orosi, CA',28436,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68968,NULL,'Orosi, CA 93647',28436,222,NULL,6,40239,0);
INSERT INTO "django_geo_db_location" VALUES(68969,NULL,'Parlier, CA',28437,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68970,NULL,'Parlier, CA 93648',28437,222,NULL,6,40240,0);
INSERT INTO "django_geo_db_location" VALUES(68971,NULL,'Piedra, CA',28438,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68972,NULL,'Piedra, CA 93649',28438,222,NULL,6,40241,0);
INSERT INTO "django_geo_db_location" VALUES(68973,NULL,'Fresno, CA',28439,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68974,NULL,'Fresno, CA 93650',28439,222,NULL,6,40242,0);
INSERT INTO "django_geo_db_location" VALUES(68975,NULL,'Prather, CA',28440,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68976,NULL,'Prather, CA 93651',28440,222,NULL,6,40243,0);
INSERT INTO "django_geo_db_location" VALUES(68977,NULL,'Raisin, CA',28441,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68978,NULL,'Raisin, CA 93652',28441,222,NULL,6,40244,0);
INSERT INTO "django_geo_db_location" VALUES(68979,NULL,'Raymond, CA',28442,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68980,NULL,'Raymond, CA 93653',28442,222,NULL,6,40245,0);
INSERT INTO "django_geo_db_location" VALUES(68981,NULL,'Reedley, CA',28443,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68982,NULL,'Reedley, CA 93654',28443,222,NULL,6,40246,0);
INSERT INTO "django_geo_db_location" VALUES(68983,NULL,'Riverdale, CA',28444,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68984,NULL,'Riverdale, CA 93656',28444,222,NULL,6,40247,0);
INSERT INTO "django_geo_db_location" VALUES(68985,NULL,'Sanger, CA',28445,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68986,NULL,'Sanger, CA 93657',28445,222,NULL,6,40248,0);
INSERT INTO "django_geo_db_location" VALUES(68987,NULL,'San Joaquin, CA',28446,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68988,NULL,'San Joaquin, CA 93660',28446,222,NULL,6,40249,0);
INSERT INTO "django_geo_db_location" VALUES(68989,NULL,'Santa Rita Park, CA',28447,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68990,NULL,'Santa Rita Park, CA 93661',28447,222,NULL,6,40250,0);
INSERT INTO "django_geo_db_location" VALUES(68991,NULL,'Selma, CA',28448,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68992,NULL,'Selma, CA 93662',28448,222,NULL,6,40251,0);
INSERT INTO "django_geo_db_location" VALUES(68993,NULL,'Shaver Lake, CA',28449,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68994,NULL,'Shaver Lake, CA 93664',28449,222,NULL,6,40252,0);
INSERT INTO "django_geo_db_location" VALUES(68995,NULL,'South Dos Palos, CA',28450,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68996,NULL,'South Dos Palos, CA 93665',28450,222,NULL,6,40253,0);
INSERT INTO "django_geo_db_location" VALUES(68997,NULL,'Sultana, CA',28451,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(68998,NULL,'Sultana, CA 93666',28451,222,NULL,6,40254,0);
INSERT INTO "django_geo_db_location" VALUES(68999,NULL,'Tollhouse, CA',28452,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69000,NULL,'Tollhouse, CA 93667',28452,222,NULL,6,40255,0);
INSERT INTO "django_geo_db_location" VALUES(69001,NULL,'Tranquillity, CA',28453,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69002,NULL,'Tranquillity, CA 93668',28453,222,NULL,6,40256,0);
INSERT INTO "django_geo_db_location" VALUES(69003,NULL,'Wishon, CA',28454,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69004,NULL,'Wishon, CA 93669',28454,222,NULL,6,40257,0);
INSERT INTO "django_geo_db_location" VALUES(69005,NULL,'Yettem, CA',28455,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69006,NULL,'Yettem, CA 93670',28455,222,NULL,6,40258,0);
INSERT INTO "django_geo_db_location" VALUES(69007,NULL,'Traver, CA',28456,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69008,NULL,'Traver, CA 93673',28456,222,NULL,6,40259,0);
INSERT INTO "django_geo_db_location" VALUES(69009,NULL,'Squaw Valley, CA',28457,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69010,NULL,'Squaw Valley, CA 93675',28457,222,NULL,6,40260,0);
INSERT INTO "django_geo_db_location" VALUES(69011,NULL,'Tranquillity, CA 93688',28453,222,NULL,6,40261,0);
INSERT INTO "django_geo_db_location" VALUES(69012,NULL,'Fresno, CA 93701',28439,222,NULL,6,40262,0);
INSERT INTO "django_geo_db_location" VALUES(69013,NULL,'Fresno, CA 93702',28439,222,NULL,6,40263,0);
INSERT INTO "django_geo_db_location" VALUES(69014,NULL,'Fresno, CA 93703',28439,222,NULL,6,40264,0);
INSERT INTO "django_geo_db_location" VALUES(69015,NULL,'Fresno, CA 93704',28439,222,NULL,6,40265,0);
INSERT INTO "django_geo_db_location" VALUES(69016,NULL,'Fresno, CA 93705',28439,222,NULL,6,40266,0);
INSERT INTO "django_geo_db_location" VALUES(69017,NULL,'Fresno, CA 93706',28439,222,NULL,6,40267,0);
INSERT INTO "django_geo_db_location" VALUES(69018,NULL,'Fresno, CA 93707',28439,222,NULL,6,40268,0);
INSERT INTO "django_geo_db_location" VALUES(69019,NULL,'Fresno, CA 93708',28439,222,NULL,6,40269,0);
INSERT INTO "django_geo_db_location" VALUES(69020,NULL,'Fresno, CA 93709',28439,222,NULL,6,40270,0);
INSERT INTO "django_geo_db_location" VALUES(69021,NULL,'Fresno, CA 93710',28439,222,NULL,6,40271,0);
INSERT INTO "django_geo_db_location" VALUES(69022,NULL,'Fresno, CA 93711',28439,222,NULL,6,40272,0);
INSERT INTO "django_geo_db_location" VALUES(69023,NULL,'Fresno, CA 93712',28439,222,NULL,6,40273,0);
INSERT INTO "django_geo_db_location" VALUES(69024,NULL,'Fresno, CA 93714',28439,222,NULL,6,40274,0);
INSERT INTO "django_geo_db_location" VALUES(69025,NULL,'Fresno, CA 93715',28439,222,NULL,6,40275,0);
INSERT INTO "django_geo_db_location" VALUES(69026,NULL,'Fresno, CA 93716',28439,222,NULL,6,40276,0);
INSERT INTO "django_geo_db_location" VALUES(69027,NULL,'Fresno, CA 93717',28439,222,NULL,6,40277,0);
INSERT INTO "django_geo_db_location" VALUES(69028,NULL,'Fresno, CA 93718',28439,222,NULL,6,40278,0);
INSERT INTO "django_geo_db_location" VALUES(69029,NULL,'Fresno, CA 93720',28439,222,NULL,6,40279,0);
INSERT INTO "django_geo_db_location" VALUES(69030,NULL,'Fresno, CA 93721',28439,222,NULL,6,40280,0);
INSERT INTO "django_geo_db_location" VALUES(69031,NULL,'Fresno, CA 93722',28439,222,NULL,6,40281,0);
INSERT INTO "django_geo_db_location" VALUES(69032,NULL,'Fresno, CA 93724',28439,222,NULL,6,40282,0);
INSERT INTO "django_geo_db_location" VALUES(69033,NULL,'Fresno, CA 93725',28439,222,NULL,6,40283,0);
INSERT INTO "django_geo_db_location" VALUES(69034,NULL,'Fresno, CA 93726',28439,222,NULL,6,40284,0);
INSERT INTO "django_geo_db_location" VALUES(69035,NULL,'Fresno, CA 93727',28439,222,NULL,6,40285,0);
INSERT INTO "django_geo_db_location" VALUES(69036,NULL,'Fresno, CA 93728',28439,222,NULL,6,40286,0);
INSERT INTO "django_geo_db_location" VALUES(69037,NULL,'Fresno, CA 93729',28439,222,NULL,6,40287,0);
INSERT INTO "django_geo_db_location" VALUES(69038,NULL,'Fresno, CA 93740',28439,222,NULL,6,40288,0);
INSERT INTO "django_geo_db_location" VALUES(69039,NULL,'Fresno, CA 93741',28439,222,NULL,6,40289,0);
INSERT INTO "django_geo_db_location" VALUES(69040,NULL,'Fresno, CA 93744',28439,222,NULL,6,40290,0);
INSERT INTO "django_geo_db_location" VALUES(69041,NULL,'Fresno, CA 93745',28439,222,NULL,6,40291,0);
INSERT INTO "django_geo_db_location" VALUES(69042,NULL,'Fresno, CA 93747',28439,222,NULL,6,40292,0);
INSERT INTO "django_geo_db_location" VALUES(69043,NULL,'Fresno, CA 93750',28439,222,NULL,6,40293,0);
INSERT INTO "django_geo_db_location" VALUES(69044,NULL,'Fresno, CA 93755',28439,222,NULL,6,40294,0);
INSERT INTO "django_geo_db_location" VALUES(69045,NULL,'Fresno, CA 93759',28439,222,NULL,6,40295,0);
INSERT INTO "django_geo_db_location" VALUES(69046,NULL,'Fresno, CA 93760',28439,222,NULL,6,40296,0);
INSERT INTO "django_geo_db_location" VALUES(69047,NULL,'Fresno, CA 93761',28439,222,NULL,6,40297,0);
INSERT INTO "django_geo_db_location" VALUES(69048,NULL,'Fresno, CA 93762',28439,222,NULL,6,40298,0);
INSERT INTO "django_geo_db_location" VALUES(69049,NULL,'Fresno, CA 93764',28439,222,NULL,6,40299,0);
INSERT INTO "django_geo_db_location" VALUES(69050,NULL,'Fresno, CA 93765',28439,222,NULL,6,40300,0);
INSERT INTO "django_geo_db_location" VALUES(69051,NULL,'Fresno, CA 93771',28439,222,NULL,6,40301,0);
INSERT INTO "django_geo_db_location" VALUES(69052,NULL,'Fresno, CA 93772',28439,222,NULL,6,40302,0);
INSERT INTO "django_geo_db_location" VALUES(69053,NULL,'Fresno, CA 93773',28439,222,NULL,6,40303,0);
INSERT INTO "django_geo_db_location" VALUES(69054,NULL,'Fresno, CA 93774',28439,222,NULL,6,40304,0);
INSERT INTO "django_geo_db_location" VALUES(69055,NULL,'Fresno, CA 93775',28439,222,NULL,6,40305,0);
INSERT INTO "django_geo_db_location" VALUES(69056,NULL,'Fresno, CA 93776',28439,222,NULL,6,40306,0);
INSERT INTO "django_geo_db_location" VALUES(69057,NULL,'Fresno, CA 93777',28439,222,NULL,6,40307,0);
INSERT INTO "django_geo_db_location" VALUES(69058,NULL,'Fresno, CA 93778',28439,222,NULL,6,40308,0);
INSERT INTO "django_geo_db_location" VALUES(69059,NULL,'Fresno, CA 93779',28439,222,NULL,6,40309,0);
INSERT INTO "django_geo_db_location" VALUES(69060,NULL,'Fresno, CA 93780',28439,222,NULL,6,40310,0);
INSERT INTO "django_geo_db_location" VALUES(69061,NULL,'Fresno, CA 93782',28439,222,NULL,6,40311,0);
INSERT INTO "django_geo_db_location" VALUES(69062,NULL,'Fresno, CA 93784',28439,222,NULL,6,40312,0);
INSERT INTO "django_geo_db_location" VALUES(69063,NULL,'Fresno, CA 93786',28439,222,NULL,6,40313,0);
INSERT INTO "django_geo_db_location" VALUES(69064,NULL,'Fresno, CA 93790',28439,222,NULL,6,40314,0);
INSERT INTO "django_geo_db_location" VALUES(69065,NULL,'Fresno, CA 93791',28439,222,NULL,6,40315,0);
INSERT INTO "django_geo_db_location" VALUES(69066,NULL,'Fresno, CA 93792',28439,222,NULL,6,40316,0);
INSERT INTO "django_geo_db_location" VALUES(69067,NULL,'Fresno, CA 93793',28439,222,NULL,6,40317,0);
INSERT INTO "django_geo_db_location" VALUES(69068,NULL,'Fresno, CA 93794',28439,222,NULL,6,40318,0);
INSERT INTO "django_geo_db_location" VALUES(69069,NULL,'Wofford Heights, CA 93825',28327,222,NULL,6,40319,0);
INSERT INTO "django_geo_db_location" VALUES(69070,NULL,'Fresno, CA 93844',28439,222,NULL,6,40320,0);
INSERT INTO "django_geo_db_location" VALUES(69071,NULL,'Fresno, CA 93888',28439,222,NULL,6,40321,0);
INSERT INTO "django_geo_db_location" VALUES(69072,NULL,'Salinas, CA',28458,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69073,NULL,'Salinas, CA 93901',28458,222,NULL,6,40322,0);
INSERT INTO "django_geo_db_location" VALUES(69074,NULL,'Salinas, CA 93902',28458,222,NULL,6,40323,0);
INSERT INTO "django_geo_db_location" VALUES(69075,NULL,'Salinas, CA 93905',28458,222,NULL,6,40324,0);
INSERT INTO "django_geo_db_location" VALUES(69076,NULL,'Salinas, CA 93906',28458,222,NULL,6,40325,0);
INSERT INTO "django_geo_db_location" VALUES(69077,NULL,'Salinas, CA 93907',28458,222,NULL,6,40326,0);
INSERT INTO "django_geo_db_location" VALUES(69078,NULL,'Salinas, CA 93908',28458,222,NULL,6,40327,0);
INSERT INTO "django_geo_db_location" VALUES(69079,NULL,'Salinas, CA 93912',28458,222,NULL,6,40328,0);
INSERT INTO "django_geo_db_location" VALUES(69080,NULL,'Salinas, CA 93915',28458,222,NULL,6,40329,0);
INSERT INTO "django_geo_db_location" VALUES(69081,NULL,'Big Sur, CA',28459,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69082,NULL,'Big Sur, CA 93920',28459,222,NULL,6,40330,0);
INSERT INTO "django_geo_db_location" VALUES(69083,NULL,'Carmel, CA',28460,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69084,NULL,'Carmel, CA 93921',28460,222,NULL,6,40331,0);
INSERT INTO "django_geo_db_location" VALUES(69085,NULL,'Carmel, CA 93922',28460,222,NULL,6,40332,0);
INSERT INTO "django_geo_db_location" VALUES(69086,NULL,'Carmel, CA 93923',28460,222,NULL,6,40333,0);
INSERT INTO "django_geo_db_location" VALUES(69087,NULL,'Carmel Valley, CA',28461,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69088,NULL,'Carmel Valley, CA 93924',28461,222,NULL,6,40334,0);
INSERT INTO "django_geo_db_location" VALUES(69089,NULL,'Chualar, CA',28462,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69090,NULL,'Chualar, CA 93925',28462,222,NULL,6,40335,0);
INSERT INTO "django_geo_db_location" VALUES(69091,NULL,'Gonzales, CA',28463,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69092,NULL,'Gonzales, CA 93926',28463,222,NULL,6,40336,0);
INSERT INTO "django_geo_db_location" VALUES(69093,NULL,'Greenfield, CA',28464,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69094,NULL,'Greenfield, CA 93927',28464,222,NULL,6,40337,0);
INSERT INTO "django_geo_db_location" VALUES(69095,NULL,'Jolon, CA',28465,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69096,NULL,'Jolon, CA 93928',28465,222,NULL,6,40338,0);
INSERT INTO "django_geo_db_location" VALUES(69097,NULL,'King City, CA',28466,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69098,NULL,'King City, CA 93930',28466,222,NULL,6,40339,0);
INSERT INTO "django_geo_db_location" VALUES(69099,NULL,'Lockwood, CA',28467,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69100,NULL,'Lockwood, CA 93932',28467,222,NULL,6,40340,0);
INSERT INTO "django_geo_db_location" VALUES(69101,NULL,'Marina, CA',28468,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69102,NULL,'Marina, CA 93933',28468,222,NULL,6,40341,0);
INSERT INTO "django_geo_db_location" VALUES(69103,NULL,'Monterey, CA',28469,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69104,NULL,'Monterey, CA 93940',28469,222,NULL,6,40342,0);
INSERT INTO "django_geo_db_location" VALUES(69105,NULL,'Monterey, CA 93942',28469,222,NULL,6,40343,0);
INSERT INTO "django_geo_db_location" VALUES(69106,NULL,'Monterey, CA 93943',28469,222,NULL,6,40344,0);
INSERT INTO "django_geo_db_location" VALUES(69107,NULL,'Monterey, CA 93944',28469,222,NULL,6,40345,0);
INSERT INTO "django_geo_db_location" VALUES(69108,NULL,'Pacific Grove, CA',28470,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69109,NULL,'Pacific Grove, CA 93950',28470,222,NULL,6,40346,0);
INSERT INTO "django_geo_db_location" VALUES(69110,NULL,'Pebble Beach, CA',28471,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69111,NULL,'Pebble Beach, CA 93953',28471,222,NULL,6,40347,0);
INSERT INTO "django_geo_db_location" VALUES(69112,NULL,'San Lucas, CA',28472,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69113,NULL,'San Lucas, CA 93954',28472,222,NULL,6,40348,0);
INSERT INTO "django_geo_db_location" VALUES(69114,NULL,'Seaside, CA',28473,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69115,NULL,'Seaside, CA 93955',28473,222,NULL,6,40349,0);
INSERT INTO "django_geo_db_location" VALUES(69116,NULL,'Soledad, CA',28474,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69117,NULL,'Soledad, CA 93960',28474,222,NULL,6,40350,0);
INSERT INTO "django_geo_db_location" VALUES(69118,NULL,'Spreckels, CA',28475,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69119,NULL,'Spreckels, CA 93962',28475,222,NULL,6,40351,0);
INSERT INTO "django_geo_db_location" VALUES(69120,NULL,'Belmont, CA',28476,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69121,NULL,'Belmont, CA 94002',28476,222,NULL,6,40352,0);
INSERT INTO "django_geo_db_location" VALUES(69122,NULL,'Belmont, CA 94003',28476,222,NULL,6,40353,0);
INSERT INTO "django_geo_db_location" VALUES(69123,NULL,'Brisbane, CA',28477,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69124,NULL,'Brisbane, CA 94005',28477,222,NULL,6,40354,0);
INSERT INTO "django_geo_db_location" VALUES(69125,NULL,'Burlingame, CA',28478,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69126,NULL,'Burlingame, CA 94010',28478,222,NULL,6,40355,0);
INSERT INTO "django_geo_db_location" VALUES(69127,NULL,'Burlingame, CA 94011',28478,222,NULL,6,40356,0);
INSERT INTO "django_geo_db_location" VALUES(69128,NULL,'Burlingame, CA 94012',28478,222,NULL,6,40357,0);
INSERT INTO "django_geo_db_location" VALUES(69129,NULL,'Daly City, CA',28479,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69130,NULL,'Daly City, CA 94014',28479,222,NULL,6,40358,0);
INSERT INTO "django_geo_db_location" VALUES(69131,NULL,'Daly City, CA 94015',28479,222,NULL,6,40359,0);
INSERT INTO "django_geo_db_location" VALUES(69132,NULL,'Daly City, CA 94016',28479,222,NULL,6,40360,0);
INSERT INTO "django_geo_db_location" VALUES(69133,NULL,'Daly City, CA 94017',28479,222,NULL,6,40361,0);
INSERT INTO "django_geo_db_location" VALUES(69134,NULL,'El Granada, CA',28480,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69135,NULL,'El Granada, CA 94018',28480,222,NULL,6,40362,0);
INSERT INTO "django_geo_db_location" VALUES(69136,NULL,'Half Moon Bay, CA',28481,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69137,NULL,'Half Moon Bay, CA 94019',28481,222,NULL,6,40363,0);
INSERT INTO "django_geo_db_location" VALUES(69138,NULL,'La Honda, CA',28482,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69139,NULL,'La Honda, CA 94020',28482,222,NULL,6,40364,0);
INSERT INTO "django_geo_db_location" VALUES(69140,NULL,'Loma Mar, CA',28483,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69141,NULL,'Loma Mar, CA 94021',28483,222,NULL,6,40365,0);
INSERT INTO "django_geo_db_location" VALUES(69142,NULL,'Los Altos, CA',28484,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69143,NULL,'Los Altos, CA 94022',28484,222,NULL,6,40366,0);
INSERT INTO "django_geo_db_location" VALUES(69144,NULL,'Los Altos, CA 94023',28484,222,NULL,6,40367,0);
INSERT INTO "django_geo_db_location" VALUES(69145,NULL,'Los Altos, CA 94024',28484,222,NULL,6,40368,0);
INSERT INTO "django_geo_db_location" VALUES(69146,NULL,'Menlo Park, CA',28485,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69147,NULL,'Menlo Park, CA 94025',28485,222,NULL,6,40369,0);
INSERT INTO "django_geo_db_location" VALUES(69148,NULL,'Menlo Park, CA 94026',28485,222,NULL,6,40370,0);
INSERT INTO "django_geo_db_location" VALUES(69149,NULL,'Atherton, CA',28486,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69150,NULL,'Atherton, CA 94027',28486,222,NULL,6,40371,0);
INSERT INTO "django_geo_db_location" VALUES(69151,NULL,'Portola Valley, CA',28487,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69152,NULL,'Portola Valley, CA 94028',28487,222,NULL,6,40372,0);
INSERT INTO "django_geo_db_location" VALUES(69153,NULL,'Menlo Park, CA 94029',28485,222,NULL,6,40373,0);
INSERT INTO "django_geo_db_location" VALUES(69154,NULL,'Millbrae, CA',28488,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69155,NULL,'Millbrae, CA 94030',28488,222,NULL,6,40374,0);
INSERT INTO "django_geo_db_location" VALUES(69156,NULL,'Millbrae, CA 94031',28488,222,NULL,6,40375,0);
INSERT INTO "django_geo_db_location" VALUES(69157,NULL,'Mountain View, CA',28489,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69158,NULL,'Mountain View, CA 94035',28489,222,NULL,6,40376,0);
INSERT INTO "django_geo_db_location" VALUES(69159,NULL,'Montara, CA',28490,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69160,NULL,'Montara, CA 94037',28490,222,NULL,6,40377,0);
INSERT INTO "django_geo_db_location" VALUES(69161,NULL,'Moss Beach, CA',28491,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69162,NULL,'Moss Beach, CA 94038',28491,222,NULL,6,40378,0);
INSERT INTO "django_geo_db_location" VALUES(69163,NULL,'Mountain View, CA 94039',28489,222,NULL,6,40379,0);
INSERT INTO "django_geo_db_location" VALUES(69164,NULL,'Mountain View, CA 94040',28489,222,NULL,6,40380,0);
INSERT INTO "django_geo_db_location" VALUES(69165,NULL,'Mountain View, CA 94041',28489,222,NULL,6,40381,0);
INSERT INTO "django_geo_db_location" VALUES(69166,NULL,'Mountain View, CA 94042',28489,222,NULL,6,40382,0);
INSERT INTO "django_geo_db_location" VALUES(69167,NULL,'Mountain View, CA 94043',28489,222,NULL,6,40383,0);
INSERT INTO "django_geo_db_location" VALUES(69168,NULL,'Pacifica, CA',28492,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69169,NULL,'Pacifica, CA 94044',28492,222,NULL,6,40384,0);
INSERT INTO "django_geo_db_location" VALUES(69170,NULL,'Pacifica, CA 94045',28492,222,NULL,6,40385,0);
INSERT INTO "django_geo_db_location" VALUES(69171,NULL,'Redwood City, CA',28493,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69172,NULL,'Redwood City, CA 94059',28493,222,NULL,6,40386,0);
INSERT INTO "django_geo_db_location" VALUES(69173,NULL,'Pescadero, CA',28494,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69174,NULL,'Pescadero, CA 94060',28494,222,NULL,6,40387,0);
INSERT INTO "django_geo_db_location" VALUES(69175,NULL,'Redwood City, CA 94061',28493,222,NULL,6,40388,0);
INSERT INTO "django_geo_db_location" VALUES(69176,NULL,'Redwood City, CA 94062',28493,222,NULL,6,40389,0);
INSERT INTO "django_geo_db_location" VALUES(69177,NULL,'Redwood City, CA 94063',28493,222,NULL,6,40390,0);
INSERT INTO "django_geo_db_location" VALUES(69178,NULL,'Redwood City, CA 94064',28493,222,NULL,6,40391,0);
INSERT INTO "django_geo_db_location" VALUES(69179,NULL,'Redwood City, CA 94065',28493,222,NULL,6,40392,0);
INSERT INTO "django_geo_db_location" VALUES(69180,NULL,'San Bruno, CA',28495,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69181,NULL,'San Bruno, CA 94066',28495,222,NULL,6,40393,0);
INSERT INTO "django_geo_db_location" VALUES(69182,NULL,'San Bruno, CA 94067',28495,222,NULL,6,40394,0);
INSERT INTO "django_geo_db_location" VALUES(69183,NULL,'San Carlos, CA',28496,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69184,NULL,'San Carlos, CA 94070',28496,222,NULL,6,40395,0);
INSERT INTO "django_geo_db_location" VALUES(69185,NULL,'San Carlos, CA 94071',28496,222,NULL,6,40396,0);
INSERT INTO "django_geo_db_location" VALUES(69186,NULL,'San Gregorio, CA',28497,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69187,NULL,'San Gregorio, CA 94074',28497,222,NULL,6,40397,0);
INSERT INTO "django_geo_db_location" VALUES(69188,NULL,'South San Francisco, CA',28498,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69189,NULL,'South San Francisco, CA 94080',28498,222,NULL,6,40398,0);
INSERT INTO "django_geo_db_location" VALUES(69190,NULL,'South San Francisco, CA 94083',28498,222,NULL,6,40399,0);
INSERT INTO "django_geo_db_location" VALUES(69191,NULL,'Sunnyvale, CA',28499,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69192,NULL,'Sunnyvale, CA 94085',28499,222,NULL,6,40400,0);
INSERT INTO "django_geo_db_location" VALUES(69193,NULL,'Sunnyvale, CA 94086',28499,222,NULL,6,40401,0);
INSERT INTO "django_geo_db_location" VALUES(69194,NULL,'Sunnyvale, CA 94087',28499,222,NULL,6,40402,0);
INSERT INTO "django_geo_db_location" VALUES(69195,NULL,'Sunnyvale, CA 94088',28499,222,NULL,6,40403,0);
INSERT INTO "django_geo_db_location" VALUES(69196,NULL,'Sunnyvale, CA 94089',28499,222,NULL,6,40404,0);
INSERT INTO "django_geo_db_location" VALUES(69197,NULL,'Sunnyvale, CA 94090',28499,222,NULL,6,40405,0);
INSERT INTO "django_geo_db_location" VALUES(69198,NULL,'San Bruno, CA 94096',28495,222,NULL,6,40406,0);
INSERT INTO "django_geo_db_location" VALUES(69199,NULL,'San Bruno, CA 94098',28495,222,NULL,6,40407,0);
INSERT INTO "django_geo_db_location" VALUES(69200,NULL,'South San Francisco, CA 94099',28498,222,NULL,6,40408,0);
INSERT INTO "django_geo_db_location" VALUES(69201,NULL,'San Francisco, CA',28500,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69202,NULL,'San Francisco, CA 94101',28500,222,NULL,6,40409,0);
INSERT INTO "django_geo_db_location" VALUES(69203,NULL,'San Francisco, CA 94102',28500,222,NULL,6,40410,0);
INSERT INTO "django_geo_db_location" VALUES(69204,NULL,'San Francisco, CA 94103',28500,222,NULL,6,40411,0);
INSERT INTO "django_geo_db_location" VALUES(69205,NULL,'San Francisco, CA 94104',28500,222,NULL,6,40412,0);
INSERT INTO "django_geo_db_location" VALUES(69206,NULL,'San Francisco, CA 94105',28500,222,NULL,6,40413,0);
INSERT INTO "django_geo_db_location" VALUES(69207,NULL,'San Francisco, CA 94106',28500,222,NULL,6,40414,0);
INSERT INTO "django_geo_db_location" VALUES(69208,NULL,'San Francisco, CA 94107',28500,222,NULL,6,40415,0);
INSERT INTO "django_geo_db_location" VALUES(69209,NULL,'San Francisco, CA 94108',28500,222,NULL,6,40416,0);
INSERT INTO "django_geo_db_location" VALUES(69210,NULL,'San Francisco, CA 94109',28500,222,NULL,6,40417,0);
INSERT INTO "django_geo_db_location" VALUES(69211,NULL,'San Francisco, CA 94110',28500,222,NULL,6,40418,0);
INSERT INTO "django_geo_db_location" VALUES(69212,NULL,'San Francisco, CA 94111',28500,222,NULL,6,40419,0);
INSERT INTO "django_geo_db_location" VALUES(69213,NULL,'San Francisco, CA 94112',28500,222,NULL,6,40420,0);
INSERT INTO "django_geo_db_location" VALUES(69214,NULL,'San Francisco, CA 94114',28500,222,NULL,6,40421,0);
INSERT INTO "django_geo_db_location" VALUES(69215,NULL,'San Francisco, CA 94115',28500,222,NULL,6,40422,0);
INSERT INTO "django_geo_db_location" VALUES(69216,NULL,'San Francisco, CA 94116',28500,222,NULL,6,40423,0);
INSERT INTO "django_geo_db_location" VALUES(69217,NULL,'San Francisco, CA 94117',28500,222,NULL,6,40424,0);
INSERT INTO "django_geo_db_location" VALUES(69218,NULL,'San Francisco, CA 94118',28500,222,NULL,6,40425,0);
INSERT INTO "django_geo_db_location" VALUES(69219,NULL,'San Francisco, CA 94119',28500,222,NULL,6,40426,0);
INSERT INTO "django_geo_db_location" VALUES(69220,NULL,'San Francisco, CA 94120',28500,222,NULL,6,40427,0);
INSERT INTO "django_geo_db_location" VALUES(69221,NULL,'San Francisco, CA 94121',28500,222,NULL,6,40428,0);
INSERT INTO "django_geo_db_location" VALUES(69222,NULL,'San Francisco, CA 94122',28500,222,NULL,6,40429,0);
INSERT INTO "django_geo_db_location" VALUES(69223,NULL,'San Francisco, CA 94123',28500,222,NULL,6,40430,0);
INSERT INTO "django_geo_db_location" VALUES(69224,NULL,'San Francisco, CA 94124',28500,222,NULL,6,40431,0);
INSERT INTO "django_geo_db_location" VALUES(69225,NULL,'San Francisco, CA 94125',28500,222,NULL,6,40432,0);
INSERT INTO "django_geo_db_location" VALUES(69226,NULL,'San Francisco, CA 94126',28500,222,NULL,6,40433,0);
INSERT INTO "django_geo_db_location" VALUES(69227,NULL,'San Francisco, CA 94127',28500,222,NULL,6,40434,0);
INSERT INTO "django_geo_db_location" VALUES(69228,NULL,'San Francisco, CA 94128',28500,222,NULL,6,40435,0);
INSERT INTO "django_geo_db_location" VALUES(69229,NULL,'San Francisco, CA 94129',28500,222,NULL,6,40436,0);
INSERT INTO "django_geo_db_location" VALUES(69230,NULL,'San Francisco, CA 94130',28500,222,NULL,6,40437,0);
INSERT INTO "django_geo_db_location" VALUES(69231,NULL,'San Francisco, CA 94131',28500,222,NULL,6,40438,0);
INSERT INTO "django_geo_db_location" VALUES(69232,NULL,'San Francisco, CA 94132',28500,222,NULL,6,40439,0);
INSERT INTO "django_geo_db_location" VALUES(69233,NULL,'San Francisco, CA 94133',28500,222,NULL,6,40440,0);
INSERT INTO "django_geo_db_location" VALUES(69234,NULL,'San Francisco, CA 94134',28500,222,NULL,6,40441,0);
INSERT INTO "django_geo_db_location" VALUES(69235,NULL,'San Francisco, CA 94135',28500,222,NULL,6,40442,0);
INSERT INTO "django_geo_db_location" VALUES(69236,NULL,'San Francisco, CA 94136',28500,222,NULL,6,40443,0);
INSERT INTO "django_geo_db_location" VALUES(69237,NULL,'San Francisco, CA 94137',28500,222,NULL,6,40444,0);
INSERT INTO "django_geo_db_location" VALUES(69238,NULL,'San Francisco, CA 94138',28500,222,NULL,6,40445,0);
INSERT INTO "django_geo_db_location" VALUES(69239,NULL,'San Francisco, CA 94139',28500,222,NULL,6,40446,0);
INSERT INTO "django_geo_db_location" VALUES(69240,NULL,'San Francisco, CA 94140',28500,222,NULL,6,40447,0);
INSERT INTO "django_geo_db_location" VALUES(69241,NULL,'San Francisco, CA 94141',28500,222,NULL,6,40448,0);
INSERT INTO "django_geo_db_location" VALUES(69242,NULL,'San Francisco, CA 94142',28500,222,NULL,6,40449,0);
INSERT INTO "django_geo_db_location" VALUES(69243,NULL,'San Francisco, CA 94143',28500,222,NULL,6,40450,0);
INSERT INTO "django_geo_db_location" VALUES(69244,NULL,'San Francisco, CA 94144',28500,222,NULL,6,40451,0);
INSERT INTO "django_geo_db_location" VALUES(69245,NULL,'San Francisco, CA 94145',28500,222,NULL,6,40452,0);
INSERT INTO "django_geo_db_location" VALUES(69246,NULL,'San Francisco, CA 94146',28500,222,NULL,6,40453,0);
INSERT INTO "django_geo_db_location" VALUES(69247,NULL,'San Francisco, CA 94147',28500,222,NULL,6,40454,0);
INSERT INTO "django_geo_db_location" VALUES(69248,NULL,'San Francisco, CA 94150',28500,222,NULL,6,40455,0);
INSERT INTO "django_geo_db_location" VALUES(69249,NULL,'San Francisco, CA 94151',28500,222,NULL,6,40456,0);
INSERT INTO "django_geo_db_location" VALUES(69250,NULL,'San Francisco, CA 94152',28500,222,NULL,6,40457,0);
INSERT INTO "django_geo_db_location" VALUES(69251,NULL,'San Francisco, CA 94153',28500,222,NULL,6,40458,0);
INSERT INTO "django_geo_db_location" VALUES(69252,NULL,'San Francisco, CA 94154',28500,222,NULL,6,40459,0);
INSERT INTO "django_geo_db_location" VALUES(69253,NULL,'San Francisco, CA 94155',28500,222,NULL,6,40460,0);
INSERT INTO "django_geo_db_location" VALUES(69254,NULL,'San Francisco, CA 94156',28500,222,NULL,6,40461,0);
INSERT INTO "django_geo_db_location" VALUES(69255,NULL,'San Francisco, CA 94157',28500,222,NULL,6,40462,0);
INSERT INTO "django_geo_db_location" VALUES(69256,NULL,'San Francisco, CA 94159',28500,222,NULL,6,40463,0);
INSERT INTO "django_geo_db_location" VALUES(69257,NULL,'San Francisco, CA 94160',28500,222,NULL,6,40464,0);
INSERT INTO "django_geo_db_location" VALUES(69258,NULL,'San Francisco, CA 94161',28500,222,NULL,6,40465,0);
INSERT INTO "django_geo_db_location" VALUES(69259,NULL,'San Francisco, CA 94162',28500,222,NULL,6,40466,0);
INSERT INTO "django_geo_db_location" VALUES(69260,NULL,'San Francisco, CA 94163',28500,222,NULL,6,40467,0);
INSERT INTO "django_geo_db_location" VALUES(69261,NULL,'San Francisco, CA 94164',28500,222,NULL,6,40468,0);
INSERT INTO "django_geo_db_location" VALUES(69262,NULL,'San Francisco, CA 94165',28500,222,NULL,6,40469,0);
INSERT INTO "django_geo_db_location" VALUES(69263,NULL,'San Francisco, CA 94166',28500,222,NULL,6,40470,0);
INSERT INTO "django_geo_db_location" VALUES(69264,NULL,'San Francisco, CA 94167',28500,222,NULL,6,40471,0);
INSERT INTO "django_geo_db_location" VALUES(69265,NULL,'San Francisco, CA 94168',28500,222,NULL,6,40472,0);
INSERT INTO "django_geo_db_location" VALUES(69266,NULL,'San Francisco, CA 94169',28500,222,NULL,6,40473,0);
INSERT INTO "django_geo_db_location" VALUES(69267,NULL,'San Francisco, CA 94170',28500,222,NULL,6,40474,0);
INSERT INTO "django_geo_db_location" VALUES(69268,NULL,'San Francisco, CA 94171',28500,222,NULL,6,40475,0);
INSERT INTO "django_geo_db_location" VALUES(69269,NULL,'San Francisco, CA 94172',28500,222,NULL,6,40476,0);
INSERT INTO "django_geo_db_location" VALUES(69270,NULL,'San Francisco, CA 94175',28500,222,NULL,6,40477,0);
INSERT INTO "django_geo_db_location" VALUES(69271,NULL,'San Francisco, CA 94177',28500,222,NULL,6,40478,0);
INSERT INTO "django_geo_db_location" VALUES(69272,NULL,'San Francisco, CA 94188',28500,222,NULL,6,40479,0);
INSERT INTO "django_geo_db_location" VALUES(69273,NULL,'Sacramento, CA',28501,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69274,NULL,'Sacramento, CA 94203',28501,222,NULL,6,40480,0);
INSERT INTO "django_geo_db_location" VALUES(69275,NULL,'Sacramento, CA 94204',28501,222,NULL,6,40481,0);
INSERT INTO "django_geo_db_location" VALUES(69276,NULL,'Sacramento, CA 94205',28501,222,NULL,6,40482,0);
INSERT INTO "django_geo_db_location" VALUES(69277,NULL,'Sacramento, CA 94206',28501,222,NULL,6,40483,0);
INSERT INTO "django_geo_db_location" VALUES(69278,NULL,'Sacramento, CA 94207',28501,222,NULL,6,40484,0);
INSERT INTO "django_geo_db_location" VALUES(69279,NULL,'Sacramento, CA 94208',28501,222,NULL,6,40485,0);
INSERT INTO "django_geo_db_location" VALUES(69280,NULL,'Sacramento, CA 94209',28501,222,NULL,6,40486,0);
INSERT INTO "django_geo_db_location" VALUES(69281,NULL,'Sacramento, CA 94211',28501,222,NULL,6,40487,0);
INSERT INTO "django_geo_db_location" VALUES(69282,NULL,'Sacramento, CA 94229',28501,222,NULL,6,40488,0);
INSERT INTO "django_geo_db_location" VALUES(69283,NULL,'Sacramento, CA 94230',28501,222,NULL,6,40489,0);
INSERT INTO "django_geo_db_location" VALUES(69284,NULL,'Sacramento, CA 94232',28501,222,NULL,6,40490,0);
INSERT INTO "django_geo_db_location" VALUES(69285,NULL,'Sacramento, CA 94234',28501,222,NULL,6,40491,0);
INSERT INTO "django_geo_db_location" VALUES(69286,NULL,'Sacramento, CA 94235',28501,222,NULL,6,40492,0);
INSERT INTO "django_geo_db_location" VALUES(69287,NULL,'Sacramento, CA 94236',28501,222,NULL,6,40493,0);
INSERT INTO "django_geo_db_location" VALUES(69288,NULL,'Sacramento, CA 94237',28501,222,NULL,6,40494,0);
INSERT INTO "django_geo_db_location" VALUES(69289,NULL,'Sacramento, CA 94239',28501,222,NULL,6,40495,0);
INSERT INTO "django_geo_db_location" VALUES(69290,NULL,'Sacramento, CA 94240',28501,222,NULL,6,40496,0);
INSERT INTO "django_geo_db_location" VALUES(69291,NULL,'Sacramento, CA 94243',28501,222,NULL,6,40497,0);
INSERT INTO "django_geo_db_location" VALUES(69292,NULL,'Sacramento, CA 94244',28501,222,NULL,6,40498,0);
INSERT INTO "django_geo_db_location" VALUES(69293,NULL,'Sacramento, CA 94245',28501,222,NULL,6,40499,0);
INSERT INTO "django_geo_db_location" VALUES(69294,NULL,'Sacramento, CA 94246',28501,222,NULL,6,40500,0);
INSERT INTO "django_geo_db_location" VALUES(69295,NULL,'Sacramento, CA 94247',28501,222,NULL,6,40501,0);
INSERT INTO "django_geo_db_location" VALUES(69296,NULL,'Sacramento, CA 94248',28501,222,NULL,6,40502,0);
INSERT INTO "django_geo_db_location" VALUES(69297,NULL,'Sacramento, CA 94249',28501,222,NULL,6,40503,0);
INSERT INTO "django_geo_db_location" VALUES(69298,NULL,'Sacramento, CA 94250',28501,222,NULL,6,40504,0);
INSERT INTO "django_geo_db_location" VALUES(69299,NULL,'Sacramento, CA 94252',28501,222,NULL,6,40505,0);
INSERT INTO "django_geo_db_location" VALUES(69300,NULL,'Sacramento, CA 94253',28501,222,NULL,6,40506,0);
INSERT INTO "django_geo_db_location" VALUES(69301,NULL,'Sacramento, CA 94254',28501,222,NULL,6,40507,0);
INSERT INTO "django_geo_db_location" VALUES(69302,NULL,'Sacramento, CA 94256',28501,222,NULL,6,40508,0);
INSERT INTO "django_geo_db_location" VALUES(69303,NULL,'Sacramento, CA 94257',28501,222,NULL,6,40509,0);
INSERT INTO "django_geo_db_location" VALUES(69304,NULL,'Sacramento, CA 94258',28501,222,NULL,6,40510,0);
INSERT INTO "django_geo_db_location" VALUES(69305,NULL,'Sacramento, CA 94259',28501,222,NULL,6,40511,0);
INSERT INTO "django_geo_db_location" VALUES(69306,NULL,'Sacramento, CA 94261',28501,222,NULL,6,40512,0);
INSERT INTO "django_geo_db_location" VALUES(69307,NULL,'Sacramento, CA 94262',28501,222,NULL,6,40513,0);
INSERT INTO "django_geo_db_location" VALUES(69308,NULL,'Sacramento, CA 94263',28501,222,NULL,6,40514,0);
INSERT INTO "django_geo_db_location" VALUES(69309,NULL,'Sacramento, CA 94267',28501,222,NULL,6,40515,0);
INSERT INTO "django_geo_db_location" VALUES(69310,NULL,'Sacramento, CA 94268',28501,222,NULL,6,40516,0);
INSERT INTO "django_geo_db_location" VALUES(69311,NULL,'Sacramento, CA 94269',28501,222,NULL,6,40517,0);
INSERT INTO "django_geo_db_location" VALUES(69312,NULL,'Sacramento, CA 94271',28501,222,NULL,6,40518,0);
INSERT INTO "django_geo_db_location" VALUES(69313,NULL,'Sacramento, CA 94273',28501,222,NULL,6,40519,0);
INSERT INTO "django_geo_db_location" VALUES(69314,NULL,'Sacramento, CA 94274',28501,222,NULL,6,40520,0);
INSERT INTO "django_geo_db_location" VALUES(69315,NULL,'Sacramento, CA 94277',28501,222,NULL,6,40521,0);
INSERT INTO "django_geo_db_location" VALUES(69316,NULL,'Sacramento, CA 94278',28501,222,NULL,6,40522,0);
INSERT INTO "django_geo_db_location" VALUES(69317,NULL,'Sacramento, CA 94279',28501,222,NULL,6,40523,0);
INSERT INTO "django_geo_db_location" VALUES(69318,NULL,'Sacramento, CA 94280',28501,222,NULL,6,40524,0);
INSERT INTO "django_geo_db_location" VALUES(69319,NULL,'Sacramento, CA 94282',28501,222,NULL,6,40525,0);
INSERT INTO "django_geo_db_location" VALUES(69320,NULL,'Sacramento, CA 94283',28501,222,NULL,6,40526,0);
INSERT INTO "django_geo_db_location" VALUES(69321,NULL,'Sacramento, CA 94284',28501,222,NULL,6,40527,0);
INSERT INTO "django_geo_db_location" VALUES(69322,NULL,'Sacramento, CA 94285',28501,222,NULL,6,40528,0);
INSERT INTO "django_geo_db_location" VALUES(69323,NULL,'Sacramento, CA 94286',28501,222,NULL,6,40529,0);
INSERT INTO "django_geo_db_location" VALUES(69324,NULL,'Sacramento, CA 94287',28501,222,NULL,6,40530,0);
INSERT INTO "django_geo_db_location" VALUES(69325,NULL,'Sacramento, CA 94288',28501,222,NULL,6,40531,0);
INSERT INTO "django_geo_db_location" VALUES(69326,NULL,'Sacramento, CA 94289',28501,222,NULL,6,40532,0);
INSERT INTO "django_geo_db_location" VALUES(69327,NULL,'Sacramento, CA 94290',28501,222,NULL,6,40533,0);
INSERT INTO "django_geo_db_location" VALUES(69328,NULL,'Sacramento, CA 94291',28501,222,NULL,6,40534,0);
INSERT INTO "django_geo_db_location" VALUES(69329,NULL,'Sacramento, CA 94293',28501,222,NULL,6,40535,0);
INSERT INTO "django_geo_db_location" VALUES(69330,NULL,'Sacramento, CA 94294',28501,222,NULL,6,40536,0);
INSERT INTO "django_geo_db_location" VALUES(69331,NULL,'Sacramento, CA 94295',28501,222,NULL,6,40537,0);
INSERT INTO "django_geo_db_location" VALUES(69332,NULL,'Sacramento, CA 94296',28501,222,NULL,6,40538,0);
INSERT INTO "django_geo_db_location" VALUES(69333,NULL,'Sacramento, CA 94297',28501,222,NULL,6,40539,0);
INSERT INTO "django_geo_db_location" VALUES(69334,NULL,'Sacramento, CA 94298',28501,222,NULL,6,40540,0);
INSERT INTO "django_geo_db_location" VALUES(69335,NULL,'Sacramento, CA 94299',28501,222,NULL,6,40541,0);
INSERT INTO "django_geo_db_location" VALUES(69336,NULL,'Palo Alto, CA',28502,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69337,NULL,'Palo Alto, CA 94301',28502,222,NULL,6,40542,0);
INSERT INTO "django_geo_db_location" VALUES(69338,NULL,'Palo Alto, CA 94302',28502,222,NULL,6,40543,0);
INSERT INTO "django_geo_db_location" VALUES(69339,NULL,'Palo Alto, CA 94303',28502,222,NULL,6,40544,0);
INSERT INTO "django_geo_db_location" VALUES(69340,NULL,'Palo Alto, CA 94304',28502,222,NULL,6,40545,0);
INSERT INTO "django_geo_db_location" VALUES(69341,NULL,'Stanford, CA',28503,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69342,NULL,'Stanford, CA 94305',28503,222,NULL,6,40546,0);
INSERT INTO "django_geo_db_location" VALUES(69343,NULL,'Palo Alto, CA 94306',28502,222,NULL,6,40547,0);
INSERT INTO "django_geo_db_location" VALUES(69344,NULL,'Palo Alto, CA 94307',28502,222,NULL,6,40548,0);
INSERT INTO "django_geo_db_location" VALUES(69345,NULL,'Palo Alto, CA 94308',28502,222,NULL,6,40549,0);
INSERT INTO "django_geo_db_location" VALUES(69346,NULL,'Palo Alto, CA 94309',28502,222,NULL,6,40550,0);
INSERT INTO "django_geo_db_location" VALUES(69347,NULL,'Palo Alto, CA 94310',28502,222,NULL,6,40551,0);
INSERT INTO "django_geo_db_location" VALUES(69348,NULL,'San Mateo, CA',28504,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69349,NULL,'San Mateo, CA 94401',28504,222,NULL,6,40552,0);
INSERT INTO "django_geo_db_location" VALUES(69350,NULL,'San Mateo, CA 94402',28504,222,NULL,6,40553,0);
INSERT INTO "django_geo_db_location" VALUES(69351,NULL,'San Mateo, CA 94403',28504,222,NULL,6,40554,0);
INSERT INTO "django_geo_db_location" VALUES(69352,NULL,'San Mateo, CA 94404',28504,222,NULL,6,40555,0);
INSERT INTO "django_geo_db_location" VALUES(69353,NULL,'San Mateo, CA 94405',28504,222,NULL,6,40556,0);
INSERT INTO "django_geo_db_location" VALUES(69354,NULL,'San Mateo, CA 94406',28504,222,NULL,6,40557,0);
INSERT INTO "django_geo_db_location" VALUES(69355,NULL,'San Mateo, CA 94407',28504,222,NULL,6,40558,0);
INSERT INTO "django_geo_db_location" VALUES(69356,NULL,'San Mateo, CA 94408',28504,222,NULL,6,40559,0);
INSERT INTO "django_geo_db_location" VALUES(69357,NULL,'San Mateo, CA 94409',28504,222,NULL,6,40560,0);
INSERT INTO "django_geo_db_location" VALUES(69358,NULL,'Foster City, CA',28505,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69359,NULL,'Foster City, CA 94420',28505,222,NULL,6,40561,0);
INSERT INTO "django_geo_db_location" VALUES(69360,NULL,'San Mateo, CA 94497',28504,222,NULL,6,40562,0);
INSERT INTO "django_geo_db_location" VALUES(69361,NULL,'Alameda, CA',28506,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69362,NULL,'Alameda, CA 94501',28506,222,NULL,6,40563,0);
INSERT INTO "django_geo_db_location" VALUES(69363,NULL,'Alameda, CA 94502',28506,222,NULL,6,40564,0);
INSERT INTO "django_geo_db_location" VALUES(69364,NULL,'American Canyon, CA',28507,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69365,NULL,'American Canyon, CA 94503',28507,222,NULL,6,40565,0);
INSERT INTO "django_geo_db_location" VALUES(69366,NULL,'Danville, CA',28508,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69367,NULL,'Danville, CA 94506',28508,222,NULL,6,40566,0);
INSERT INTO "django_geo_db_location" VALUES(69368,NULL,'Alamo, CA',28509,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69369,NULL,'Alamo, CA 94507',28509,222,NULL,6,40567,0);
INSERT INTO "django_geo_db_location" VALUES(69370,NULL,'Angwin, CA',28510,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69371,NULL,'Angwin, CA 94508',28510,222,NULL,6,40568,0);
INSERT INTO "django_geo_db_location" VALUES(69372,NULL,'Antioch, CA',28511,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69373,NULL,'Antioch, CA 94509',28511,222,NULL,6,40569,0);
INSERT INTO "django_geo_db_location" VALUES(69374,NULL,'Benicia, CA',28512,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69375,NULL,'Benicia, CA 94510',28512,222,NULL,6,40570,0);
INSERT INTO "django_geo_db_location" VALUES(69376,NULL,'Bethel Island, CA',28513,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69377,NULL,'Bethel Island, CA 94511',28513,222,NULL,6,40571,0);
INSERT INTO "django_geo_db_location" VALUES(69378,NULL,'Birds Landing, CA',28514,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69379,NULL,'Birds Landing, CA 94512',28514,222,NULL,6,40572,0);
INSERT INTO "django_geo_db_location" VALUES(69380,NULL,'Brentwood, CA',28515,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69381,NULL,'Brentwood, CA 94513',28515,222,NULL,6,40573,0);
INSERT INTO "django_geo_db_location" VALUES(69382,NULL,'Byron, CA',28516,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69383,NULL,'Byron, CA 94514',28516,222,NULL,6,40574,0);
INSERT INTO "django_geo_db_location" VALUES(69384,NULL,'Calistoga, CA',28517,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69385,NULL,'Calistoga, CA 94515',28517,222,NULL,6,40575,0);
INSERT INTO "django_geo_db_location" VALUES(69386,NULL,'Canyon, CA',28518,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69387,NULL,'Canyon, CA 94516',28518,222,NULL,6,40576,0);
INSERT INTO "django_geo_db_location" VALUES(69388,NULL,'Clayton, CA',28519,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69389,NULL,'Clayton, CA 94517',28519,222,NULL,6,40577,0);
INSERT INTO "django_geo_db_location" VALUES(69390,NULL,'Concord, CA',28520,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69391,NULL,'Concord, CA 94518',28520,222,NULL,6,40578,0);
INSERT INTO "django_geo_db_location" VALUES(69392,NULL,'Concord, CA 94519',28520,222,NULL,6,40579,0);
INSERT INTO "django_geo_db_location" VALUES(69393,NULL,'Concord, CA 94520',28520,222,NULL,6,40580,0);
INSERT INTO "django_geo_db_location" VALUES(69394,NULL,'Concord, CA 94521',28520,222,NULL,6,40581,0);
INSERT INTO "django_geo_db_location" VALUES(69395,NULL,'Concord, CA 94522',28520,222,NULL,6,40582,0);
INSERT INTO "django_geo_db_location" VALUES(69396,NULL,'Pleasant Hill, CA',28521,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69397,NULL,'Pleasant Hill, CA 94523',28521,222,NULL,6,40583,0);
INSERT INTO "django_geo_db_location" VALUES(69398,NULL,'Concord, CA 94524',28520,222,NULL,6,40584,0);
INSERT INTO "django_geo_db_location" VALUES(69399,NULL,'Crockett, CA',28522,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69400,NULL,'Crockett, CA 94525',28522,222,NULL,6,40585,0);
INSERT INTO "django_geo_db_location" VALUES(69401,NULL,'Danville, CA 94526',28508,222,NULL,6,40586,0);
INSERT INTO "django_geo_db_location" VALUES(69402,NULL,'Concord, CA 94527',28520,222,NULL,6,40587,0);
INSERT INTO "django_geo_db_location" VALUES(69403,NULL,'Diablo, CA',28523,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69404,NULL,'Diablo, CA 94528',28523,222,NULL,6,40588,0);
INSERT INTO "django_geo_db_location" VALUES(69405,NULL,'Concord, CA 94529',28520,222,NULL,6,40589,0);
INSERT INTO "django_geo_db_location" VALUES(69406,NULL,'El Cerrito, CA',28524,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69407,NULL,'El Cerrito, CA 94530',28524,222,NULL,6,40590,0);
INSERT INTO "django_geo_db_location" VALUES(69408,NULL,'Antioch, CA 94531',28511,222,NULL,6,40591,0);
INSERT INTO "django_geo_db_location" VALUES(69409,NULL,'Fairfield, CA',28525,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69410,NULL,'Fairfield, CA 94533',28525,222,NULL,6,40592,0);
INSERT INTO "django_geo_db_location" VALUES(69411,NULL,'Fairfield, CA 94534',28525,222,NULL,6,40593,0);
INSERT INTO "django_geo_db_location" VALUES(69412,NULL,'Travis AFB, CA',28526,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69413,NULL,'Travis AFB, CA 94535',28526,222,NULL,6,40594,0);
INSERT INTO "django_geo_db_location" VALUES(69414,NULL,'Fremont, CA',28527,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69415,NULL,'Fremont, CA 94536',28527,222,NULL,6,40595,0);
INSERT INTO "django_geo_db_location" VALUES(69416,NULL,'Fremont, CA 94537',28527,222,NULL,6,40596,0);
INSERT INTO "django_geo_db_location" VALUES(69417,NULL,'Fremont, CA 94538',28527,222,NULL,6,40597,0);
INSERT INTO "django_geo_db_location" VALUES(69418,NULL,'Fremont, CA 94539',28527,222,NULL,6,40598,0);
INSERT INTO "django_geo_db_location" VALUES(69419,NULL,'Hayward, CA',28528,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69420,NULL,'Hayward, CA 94540',28528,222,NULL,6,40599,0);
INSERT INTO "django_geo_db_location" VALUES(69421,NULL,'Hayward, CA 94541',28528,222,NULL,6,40600,0);
INSERT INTO "django_geo_db_location" VALUES(69422,NULL,'Hayward, CA 94542',28528,222,NULL,6,40601,0);
INSERT INTO "django_geo_db_location" VALUES(69423,NULL,'Hayward, CA 94543',28528,222,NULL,6,40602,0);
INSERT INTO "django_geo_db_location" VALUES(69424,NULL,'Hayward, CA 94544',28528,222,NULL,6,40603,0);
INSERT INTO "django_geo_db_location" VALUES(69425,NULL,'Hayward, CA 94545',28528,222,NULL,6,40604,0);
INSERT INTO "django_geo_db_location" VALUES(69426,NULL,'Castro Valley, CA',28529,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69427,NULL,'Castro Valley, CA 94546',28529,222,NULL,6,40605,0);
INSERT INTO "django_geo_db_location" VALUES(69428,NULL,'Hercules, CA',28530,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69429,NULL,'Hercules, CA 94547',28530,222,NULL,6,40606,0);
INSERT INTO "django_geo_db_location" VALUES(69430,NULL,'Knightsen, CA',28531,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69431,NULL,'Knightsen, CA 94548',28531,222,NULL,6,40607,0);
INSERT INTO "django_geo_db_location" VALUES(69432,NULL,'Lafayette, CA',28532,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69433,NULL,'Lafayette, CA 94549',28532,222,NULL,6,40608,0);
INSERT INTO "django_geo_db_location" VALUES(69434,NULL,'Livermore, CA',28533,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69435,NULL,'Livermore, CA 94550',28533,222,NULL,6,40609,0);
INSERT INTO "django_geo_db_location" VALUES(69436,NULL,'Livermore, CA 94551',28533,222,NULL,6,40610,0);
INSERT INTO "django_geo_db_location" VALUES(69437,NULL,'Castro Valley, CA 94552',28529,222,NULL,6,40611,0);
INSERT INTO "django_geo_db_location" VALUES(69438,NULL,'Martinez, CA',28534,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69439,NULL,'Martinez, CA 94553',28534,222,NULL,6,40612,0);
INSERT INTO "django_geo_db_location" VALUES(69440,NULL,'Fremont, CA 94555',28527,222,NULL,6,40613,0);
INSERT INTO "django_geo_db_location" VALUES(69441,NULL,'Moraga, CA',28535,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69442,NULL,'Moraga, CA 94556',28535,222,NULL,6,40614,0);
INSERT INTO "django_geo_db_location" VALUES(69443,NULL,'Hayward, CA 94557',28528,222,NULL,6,40615,0);
INSERT INTO "django_geo_db_location" VALUES(69444,NULL,'Napa, CA',28536,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69445,NULL,'Napa, CA 94558',28536,222,NULL,6,40616,0);
INSERT INTO "django_geo_db_location" VALUES(69446,NULL,'Napa, CA 94559',28536,222,NULL,6,40617,0);
INSERT INTO "django_geo_db_location" VALUES(69447,NULL,'Newark, CA',28537,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69448,NULL,'Newark, CA 94560',28537,222,NULL,6,40618,0);
INSERT INTO "django_geo_db_location" VALUES(69449,NULL,'Oakley, CA',28538,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69450,NULL,'Oakley, CA 94561',28538,222,NULL,6,40619,0);
INSERT INTO "django_geo_db_location" VALUES(69451,NULL,'Oakville, CA',28539,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69452,NULL,'Oakville, CA 94562',28539,222,NULL,6,40620,0);
INSERT INTO "django_geo_db_location" VALUES(69453,NULL,'Orinda, CA',28540,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69454,NULL,'Orinda, CA 94563',28540,222,NULL,6,40621,0);
INSERT INTO "django_geo_db_location" VALUES(69455,NULL,'Pinole, CA',28541,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69456,NULL,'Pinole, CA 94564',28541,222,NULL,6,40622,0);
INSERT INTO "django_geo_db_location" VALUES(69457,NULL,'Pittsburg, CA',28542,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69458,NULL,'Pittsburg, CA 94565',28542,222,NULL,6,40623,0);
INSERT INTO "django_geo_db_location" VALUES(69459,NULL,'Pleasanton, CA',28543,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69460,NULL,'Pleasanton, CA 94566',28543,222,NULL,6,40624,0);
INSERT INTO "django_geo_db_location" VALUES(69461,NULL,'Pope Valley, CA',28544,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69462,NULL,'Pope Valley, CA 94567',28544,222,NULL,6,40625,0);
INSERT INTO "django_geo_db_location" VALUES(69463,NULL,'Dublin, CA',28545,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69464,NULL,'Dublin, CA 94568',28545,222,NULL,6,40626,0);
INSERT INTO "django_geo_db_location" VALUES(69465,NULL,'Port Costa, CA',28546,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69466,NULL,'Port Costa, CA 94569',28546,222,NULL,6,40627,0);
INSERT INTO "django_geo_db_location" VALUES(69467,NULL,'Moraga, CA 94570',28535,222,NULL,6,40628,0);
INSERT INTO "django_geo_db_location" VALUES(69468,NULL,'Rio Vista, CA',28547,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69469,NULL,'Rio Vista, CA 94571',28547,222,NULL,6,40629,0);
INSERT INTO "django_geo_db_location" VALUES(69470,NULL,'Rodeo, CA',28548,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69471,NULL,'Rodeo, CA 94572',28548,222,NULL,6,40630,0);
INSERT INTO "django_geo_db_location" VALUES(69472,NULL,'Rutherford, CA',28549,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69473,NULL,'Rutherford, CA 94573',28549,222,NULL,6,40631,0);
INSERT INTO "django_geo_db_location" VALUES(69474,NULL,'Saint Helena, CA',28550,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69475,NULL,'Saint Helena, CA 94574',28550,222,NULL,6,40632,0);
INSERT INTO "django_geo_db_location" VALUES(69476,NULL,'Moraga, CA 94575',28535,222,NULL,6,40633,0);
INSERT INTO "django_geo_db_location" VALUES(69477,NULL,'Deer Park, CA',28551,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69478,NULL,'Deer Park, CA 94576',28551,222,NULL,6,40634,0);
INSERT INTO "django_geo_db_location" VALUES(69479,NULL,'San Leandro, CA',28552,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69480,NULL,'San Leandro, CA 94577',28552,222,NULL,6,40635,0);
INSERT INTO "django_geo_db_location" VALUES(69481,NULL,'San Leandro, CA 94578',28552,222,NULL,6,40636,0);
INSERT INTO "django_geo_db_location" VALUES(69482,NULL,'San Leandro, CA 94579',28552,222,NULL,6,40637,0);
INSERT INTO "django_geo_db_location" VALUES(69483,NULL,'San Lorenzo, CA',28553,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69484,NULL,'San Lorenzo, CA 94580',28553,222,NULL,6,40638,0);
INSERT INTO "django_geo_db_location" VALUES(69485,NULL,'Napa, CA 94581',28536,222,NULL,6,40639,0);
INSERT INTO "django_geo_db_location" VALUES(69486,NULL,'San Ramon, CA',28554,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69487,NULL,'San Ramon, CA 94583',28554,222,NULL,6,40640,0);
INSERT INTO "django_geo_db_location" VALUES(69488,NULL,'Suisun City, CA',28555,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69489,NULL,'Suisun City, CA 94585',28555,222,NULL,6,40641,0);
INSERT INTO "django_geo_db_location" VALUES(69490,NULL,'Sunol, CA',28556,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69491,NULL,'Sunol, CA 94586',28556,222,NULL,6,40642,0);
INSERT INTO "django_geo_db_location" VALUES(69492,NULL,'Union City, CA',28557,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69493,NULL,'Union City, CA 94587',28557,222,NULL,6,40643,0);
INSERT INTO "django_geo_db_location" VALUES(69494,NULL,'Pleasanton, CA 94588',28543,222,NULL,6,40644,0);
INSERT INTO "django_geo_db_location" VALUES(69495,NULL,'Vallejo, CA',28558,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69496,NULL,'Vallejo, CA 94589',28558,222,NULL,6,40645,0);
INSERT INTO "django_geo_db_location" VALUES(69497,NULL,'Vallejo, CA 94590',28558,222,NULL,6,40646,0);
INSERT INTO "django_geo_db_location" VALUES(69498,NULL,'Vallejo, CA 94591',28558,222,NULL,6,40647,0);
INSERT INTO "django_geo_db_location" VALUES(69499,NULL,'Vallejo, CA 94592',28558,222,NULL,6,40648,0);
INSERT INTO "django_geo_db_location" VALUES(69500,NULL,'Walnut Creek, CA',28559,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69501,NULL,'Walnut Creek, CA 94595',28559,222,NULL,6,40649,0);
INSERT INTO "django_geo_db_location" VALUES(69502,NULL,'Walnut Creek, CA 94596',28559,222,NULL,6,40650,0);
INSERT INTO "django_geo_db_location" VALUES(69503,NULL,'Walnut Creek, CA 94597',28559,222,NULL,6,40651,0);
INSERT INTO "django_geo_db_location" VALUES(69504,NULL,'Walnut Creek, CA 94598',28559,222,NULL,6,40652,0);
INSERT INTO "django_geo_db_location" VALUES(69505,NULL,'Yountville, CA',28560,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69506,NULL,'Yountville, CA 94599',28560,222,NULL,6,40653,0);
INSERT INTO "django_geo_db_location" VALUES(69507,NULL,'Oakland, CA',28561,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69508,NULL,'Oakland, CA 94601',28561,222,NULL,6,40654,0);
INSERT INTO "django_geo_db_location" VALUES(69509,NULL,'Oakland, CA 94602',28561,222,NULL,6,40655,0);
INSERT INTO "django_geo_db_location" VALUES(69510,NULL,'Oakland, CA 94603',28561,222,NULL,6,40656,0);
INSERT INTO "django_geo_db_location" VALUES(69511,NULL,'Oakland, CA 94604',28561,222,NULL,6,40657,0);
INSERT INTO "django_geo_db_location" VALUES(69512,NULL,'Oakland, CA 94605',28561,222,NULL,6,40658,0);
INSERT INTO "django_geo_db_location" VALUES(69513,NULL,'Oakland, CA 94606',28561,222,NULL,6,40659,0);
INSERT INTO "django_geo_db_location" VALUES(69514,NULL,'Oakland, CA 94607',28561,222,NULL,6,40660,0);
INSERT INTO "django_geo_db_location" VALUES(69515,NULL,'Emeryville, CA',28562,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69516,NULL,'Emeryville, CA 94608',28562,222,NULL,6,40661,0);
INSERT INTO "django_geo_db_location" VALUES(69517,NULL,'Oakland, CA 94609',28561,222,NULL,6,40662,0);
INSERT INTO "django_geo_db_location" VALUES(69518,NULL,'Oakland, CA 94610',28561,222,NULL,6,40663,0);
INSERT INTO "django_geo_db_location" VALUES(69519,NULL,'Oakland, CA 94611',28561,222,NULL,6,40664,0);
INSERT INTO "django_geo_db_location" VALUES(69520,NULL,'Oakland, CA 94612',28561,222,NULL,6,40665,0);
INSERT INTO "django_geo_db_location" VALUES(69521,NULL,'Oakland, CA 94613',28561,222,NULL,6,40666,0);
INSERT INTO "django_geo_db_location" VALUES(69522,NULL,'Oakland, CA 94614',28561,222,NULL,6,40667,0);
INSERT INTO "django_geo_db_location" VALUES(69523,NULL,'Oakland, CA 94615',28561,222,NULL,6,40668,0);
INSERT INTO "django_geo_db_location" VALUES(69524,NULL,'Oakland, CA 94617',28561,222,NULL,6,40669,0);
INSERT INTO "django_geo_db_location" VALUES(69525,NULL,'Oakland, CA 94618',28561,222,NULL,6,40670,0);
INSERT INTO "django_geo_db_location" VALUES(69526,NULL,'Oakland, CA 94619',28561,222,NULL,6,40671,0);
INSERT INTO "django_geo_db_location" VALUES(69527,NULL,'Piedmont, CA',28563,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69528,NULL,'Piedmont, CA 94620',28563,222,NULL,6,40672,0);
INSERT INTO "django_geo_db_location" VALUES(69529,NULL,'Oakland, CA 94621',28561,222,NULL,6,40673,0);
INSERT INTO "django_geo_db_location" VALUES(69530,NULL,'Oakland, CA 94623',28561,222,NULL,6,40674,0);
INSERT INTO "django_geo_db_location" VALUES(69531,NULL,'Oakland, CA 94624',28561,222,NULL,6,40675,0);
INSERT INTO "django_geo_db_location" VALUES(69532,NULL,'Oakland, CA 94625',28561,222,NULL,6,40676,0);
INSERT INTO "django_geo_db_location" VALUES(69533,NULL,'Oakland, CA 94626',28561,222,NULL,6,40677,0);
INSERT INTO "django_geo_db_location" VALUES(69534,NULL,'Oakland, CA 94627',28561,222,NULL,6,40678,0);
INSERT INTO "django_geo_db_location" VALUES(69535,NULL,'Oakland, CA 94643',28561,222,NULL,6,40679,0);
INSERT INTO "django_geo_db_location" VALUES(69536,NULL,'Oakland, CA 94649',28561,222,NULL,6,40680,0);
INSERT INTO "django_geo_db_location" VALUES(69537,NULL,'Oakland, CA 94659',28561,222,NULL,6,40681,0);
INSERT INTO "django_geo_db_location" VALUES(69538,NULL,'Oakland, CA 94660',28561,222,NULL,6,40682,0);
INSERT INTO "django_geo_db_location" VALUES(69539,NULL,'Oakland, CA 94661',28561,222,NULL,6,40683,0);
INSERT INTO "django_geo_db_location" VALUES(69540,NULL,'Emeryville, CA 94662',28562,222,NULL,6,40684,0);
INSERT INTO "django_geo_db_location" VALUES(69541,NULL,'Oakland, CA 94666',28561,222,NULL,6,40685,0);
INSERT INTO "django_geo_db_location" VALUES(69542,NULL,'Berkeley, CA',28564,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69543,NULL,'Berkeley, CA 94701',28564,222,NULL,6,40686,0);
INSERT INTO "django_geo_db_location" VALUES(69544,NULL,'Berkeley, CA 94702',28564,222,NULL,6,40687,0);
INSERT INTO "django_geo_db_location" VALUES(69545,NULL,'Berkeley, CA 94703',28564,222,NULL,6,40688,0);
INSERT INTO "django_geo_db_location" VALUES(69546,NULL,'Berkeley, CA 94704',28564,222,NULL,6,40689,0);
INSERT INTO "django_geo_db_location" VALUES(69547,NULL,'Berkeley, CA 94705',28564,222,NULL,6,40690,0);
INSERT INTO "django_geo_db_location" VALUES(69548,NULL,'Albany, CA',28565,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69549,NULL,'Albany, CA 94706',28565,222,NULL,6,40691,0);
INSERT INTO "django_geo_db_location" VALUES(69550,NULL,'Berkeley, CA 94707',28564,222,NULL,6,40692,0);
INSERT INTO "django_geo_db_location" VALUES(69551,NULL,'Berkeley, CA 94708',28564,222,NULL,6,40693,0);
INSERT INTO "django_geo_db_location" VALUES(69552,NULL,'Berkeley, CA 94709',28564,222,NULL,6,40694,0);
INSERT INTO "django_geo_db_location" VALUES(69553,NULL,'Berkeley, CA 94710',28564,222,NULL,6,40695,0);
INSERT INTO "django_geo_db_location" VALUES(69554,NULL,'Berkeley, CA 94712',28564,222,NULL,6,40696,0);
INSERT INTO "django_geo_db_location" VALUES(69555,NULL,'Berkeley, CA 94720',28564,222,NULL,6,40697,0);
INSERT INTO "django_geo_db_location" VALUES(69556,NULL,'Richmond, CA',28566,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69557,NULL,'Richmond, CA 94801',28566,222,NULL,6,40698,0);
INSERT INTO "django_geo_db_location" VALUES(69558,NULL,'Richmond, CA 94802',28566,222,NULL,6,40699,0);
INSERT INTO "django_geo_db_location" VALUES(69559,NULL,'El Sobrante, CA',28567,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69560,NULL,'El Sobrante, CA 94803',28567,222,NULL,6,40700,0);
INSERT INTO "django_geo_db_location" VALUES(69561,NULL,'Richmond, CA 94804',28566,222,NULL,6,40701,0);
INSERT INTO "django_geo_db_location" VALUES(69562,NULL,'Richmond, CA 94805',28566,222,NULL,6,40702,0);
INSERT INTO "django_geo_db_location" VALUES(69563,NULL,'San Pablo, CA',28568,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69564,NULL,'San Pablo, CA 94806',28568,222,NULL,6,40703,0);
INSERT INTO "django_geo_db_location" VALUES(69565,NULL,'Richmond, CA 94807',28566,222,NULL,6,40704,0);
INSERT INTO "django_geo_db_location" VALUES(69566,NULL,'Richmond, CA 94808',28566,222,NULL,6,40705,0);
INSERT INTO "django_geo_db_location" VALUES(69567,NULL,'El Sobrante, CA 94820',28567,222,NULL,6,40706,0);
INSERT INTO "django_geo_db_location" VALUES(69568,NULL,'Richmond, CA 94850',28566,222,NULL,6,40707,0);
INSERT INTO "django_geo_db_location" VALUES(69569,NULL,'San Rafael, CA',28569,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69570,NULL,'San Rafael, CA 94901',28569,222,NULL,6,40708,0);
INSERT INTO "django_geo_db_location" VALUES(69571,NULL,'San Rafael, CA 94903',28569,222,NULL,6,40709,0);
INSERT INTO "django_geo_db_location" VALUES(69572,NULL,'Greenbrae, CA',28570,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69573,NULL,'Greenbrae, CA 94904',28570,222,NULL,6,40710,0);
INSERT INTO "django_geo_db_location" VALUES(69574,NULL,'San Rafael, CA 94912',28569,222,NULL,6,40711,0);
INSERT INTO "django_geo_db_location" VALUES(69575,NULL,'San Rafael, CA 94913',28569,222,NULL,6,40712,0);
INSERT INTO "django_geo_db_location" VALUES(69576,NULL,'Kentfield, CA',28571,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69577,NULL,'Kentfield, CA 94914',28571,222,NULL,6,40713,0);
INSERT INTO "django_geo_db_location" VALUES(69578,NULL,'San Rafael, CA 94915',28569,222,NULL,6,40714,0);
INSERT INTO "django_geo_db_location" VALUES(69579,NULL,'Belvedere Tiburon, CA',28572,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69580,NULL,'Belvedere Tiburon, CA 94920',28572,222,NULL,6,40715,0);
INSERT INTO "django_geo_db_location" VALUES(69581,NULL,'Bodega, CA',28573,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69582,NULL,'Bodega, CA 94922',28573,222,NULL,6,40716,0);
INSERT INTO "django_geo_db_location" VALUES(69583,NULL,'Bodega Bay, CA',28574,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69584,NULL,'Bodega Bay, CA 94923',28574,222,NULL,6,40717,0);
INSERT INTO "django_geo_db_location" VALUES(69585,NULL,'Bolinas, CA',28575,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69586,NULL,'Bolinas, CA 94924',28575,222,NULL,6,40718,0);
INSERT INTO "django_geo_db_location" VALUES(69587,NULL,'Corte Madera, CA',28576,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69588,NULL,'Corte Madera, CA 94925',28576,222,NULL,6,40719,0);
INSERT INTO "django_geo_db_location" VALUES(69589,NULL,'Cotati, CA',28577,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69590,NULL,'Cotati, CA 94926',28577,222,NULL,6,40720,0);
INSERT INTO "django_geo_db_location" VALUES(69591,NULL,'Rohnert Park, CA',28578,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69592,NULL,'Rohnert Park, CA 94927',28578,222,NULL,6,40721,0);
INSERT INTO "django_geo_db_location" VALUES(69593,NULL,'Rohnert Park, CA 94928',28578,222,NULL,6,40722,0);
INSERT INTO "django_geo_db_location" VALUES(69594,NULL,'Dillon Beach, CA',28579,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69595,NULL,'Dillon Beach, CA 94929',28579,222,NULL,6,40723,0);
INSERT INTO "django_geo_db_location" VALUES(69596,NULL,'Fairfax, CA',28580,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69597,NULL,'Fairfax, CA 94930',28580,222,NULL,6,40724,0);
INSERT INTO "django_geo_db_location" VALUES(69598,NULL,'Cotati, CA 94931',28577,222,NULL,6,40725,0);
INSERT INTO "django_geo_db_location" VALUES(69599,NULL,'Forest Knolls, CA',28581,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69600,NULL,'Forest Knolls, CA 94933',28581,222,NULL,6,40726,0);
INSERT INTO "django_geo_db_location" VALUES(69601,NULL,'Inverness, CA',28582,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69602,NULL,'Inverness, CA 94937',28582,222,NULL,6,40727,0);
INSERT INTO "django_geo_db_location" VALUES(69603,NULL,'Lagunitas, CA',28583,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69604,NULL,'Lagunitas, CA 94938',28583,222,NULL,6,40728,0);
INSERT INTO "django_geo_db_location" VALUES(69605,NULL,'Larkspur, CA',28584,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69606,NULL,'Larkspur, CA 94939',28584,222,NULL,6,40729,0);
INSERT INTO "django_geo_db_location" VALUES(69607,NULL,'Marshall, CA',28585,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69608,NULL,'Marshall, CA 94940',28585,222,NULL,6,40730,0);
INSERT INTO "django_geo_db_location" VALUES(69609,NULL,'Mill Valley, CA',28586,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69610,NULL,'Mill Valley, CA 94941',28586,222,NULL,6,40731,0);
INSERT INTO "django_geo_db_location" VALUES(69611,NULL,'Mill Valley, CA 94942',28586,222,NULL,6,40732,0);
INSERT INTO "django_geo_db_location" VALUES(69612,NULL,'Novato, CA',28587,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69613,NULL,'Novato, CA 94945',28587,222,NULL,6,40733,0);
INSERT INTO "django_geo_db_location" VALUES(69614,NULL,'Nicasio, CA',28588,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69615,NULL,'Nicasio, CA 94946',28588,222,NULL,6,40734,0);
INSERT INTO "django_geo_db_location" VALUES(69616,NULL,'Novato, CA 94947',28587,222,NULL,6,40735,0);
INSERT INTO "django_geo_db_location" VALUES(69617,NULL,'Novato, CA 94948',28587,222,NULL,6,40736,0);
INSERT INTO "django_geo_db_location" VALUES(69618,NULL,'Novato, CA 94949',28587,222,NULL,6,40737,0);
INSERT INTO "django_geo_db_location" VALUES(69619,NULL,'Olema, CA',28589,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69620,NULL,'Olema, CA 94950',28589,222,NULL,6,40738,0);
INSERT INTO "django_geo_db_location" VALUES(69621,NULL,'Penngrove, CA',28590,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69622,NULL,'Penngrove, CA 94951',28590,222,NULL,6,40739,0);
INSERT INTO "django_geo_db_location" VALUES(69623,NULL,'Petaluma, CA',28591,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69624,NULL,'Petaluma, CA 94952',28591,222,NULL,6,40740,0);
INSERT INTO "django_geo_db_location" VALUES(69625,NULL,'Petaluma, CA 94953',28591,222,NULL,6,40741,0);
INSERT INTO "django_geo_db_location" VALUES(69626,NULL,'Petaluma, CA 94954',28591,222,NULL,6,40742,0);
INSERT INTO "django_geo_db_location" VALUES(69627,NULL,'Petaluma, CA 94955',28591,222,NULL,6,40743,0);
INSERT INTO "django_geo_db_location" VALUES(69628,NULL,'Point Reyes Station, CA',28592,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69629,NULL,'Point Reyes Station, CA 94956',28592,222,NULL,6,40744,0);
INSERT INTO "django_geo_db_location" VALUES(69630,NULL,'Ross, CA',28593,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69631,NULL,'Ross, CA 94957',28593,222,NULL,6,40745,0);
INSERT INTO "django_geo_db_location" VALUES(69632,NULL,'San Anselmo, CA',28594,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69633,NULL,'San Anselmo, CA 94960',28594,222,NULL,6,40746,0);
INSERT INTO "django_geo_db_location" VALUES(69634,NULL,'San Geronimo, CA',28595,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69635,NULL,'San Geronimo, CA 94963',28595,222,NULL,6,40747,0);
INSERT INTO "django_geo_db_location" VALUES(69636,NULL,'San Quentin, CA',28596,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69637,NULL,'San Quentin, CA 94964',28596,222,NULL,6,40748,0);
INSERT INTO "django_geo_db_location" VALUES(69638,NULL,'Sausalito, CA',28597,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69639,NULL,'Sausalito, CA 94965',28597,222,NULL,6,40749,0);
INSERT INTO "django_geo_db_location" VALUES(69640,NULL,'Sausalito, CA 94966',28597,222,NULL,6,40750,0);
INSERT INTO "django_geo_db_location" VALUES(69641,NULL,'Stinson Beach, CA',28598,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69642,NULL,'Stinson Beach, CA 94970',28598,222,NULL,6,40751,0);
INSERT INTO "django_geo_db_location" VALUES(69643,NULL,'Tomales, CA',28599,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69644,NULL,'Tomales, CA 94971',28599,222,NULL,6,40752,0);
INSERT INTO "django_geo_db_location" VALUES(69645,NULL,'Valley Ford, CA',28600,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69646,NULL,'Valley Ford, CA 94972',28600,222,NULL,6,40753,0);
INSERT INTO "django_geo_db_location" VALUES(69647,NULL,'Woodacre, CA',28601,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69648,NULL,'Woodacre, CA 94973',28601,222,NULL,6,40754,0);
INSERT INTO "django_geo_db_location" VALUES(69649,NULL,'San Quentin, CA 94974',28596,222,NULL,6,40755,0);
INSERT INTO "django_geo_db_location" VALUES(69650,NULL,'Petaluma, CA 94975',28591,222,NULL,6,40756,0);
INSERT INTO "django_geo_db_location" VALUES(69651,NULL,'Corte Madera, CA 94976',28576,222,NULL,6,40757,0);
INSERT INTO "django_geo_db_location" VALUES(69652,NULL,'Larkspur, CA 94977',28584,222,NULL,6,40758,0);
INSERT INTO "django_geo_db_location" VALUES(69653,NULL,'Fairfax, CA 94978',28580,222,NULL,6,40759,0);
INSERT INTO "django_geo_db_location" VALUES(69654,NULL,'San Anselmo, CA 94979',28594,222,NULL,6,40760,0);
INSERT INTO "django_geo_db_location" VALUES(69655,NULL,'San Rafael, CA 94991',28569,222,NULL,6,40761,0);
INSERT INTO "django_geo_db_location" VALUES(69656,NULL,'Novato, CA 94998',28587,222,NULL,6,40762,0);
INSERT INTO "django_geo_db_location" VALUES(69657,NULL,'Petaluma, CA 94999',28591,222,NULL,6,40763,0);
INSERT INTO "django_geo_db_location" VALUES(69658,NULL,'Aptos, CA',28602,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69659,NULL,'Aptos, CA 95001',28602,222,NULL,6,40764,0);
INSERT INTO "django_geo_db_location" VALUES(69660,NULL,'Alviso, CA',28603,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69661,NULL,'Alviso, CA 95002',28603,222,NULL,6,40765,0);
INSERT INTO "django_geo_db_location" VALUES(69662,NULL,'Aptos, CA 95003',28602,222,NULL,6,40766,0);
INSERT INTO "django_geo_db_location" VALUES(69663,NULL,'Aromas, CA',28604,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69664,NULL,'Aromas, CA 95004',28604,222,NULL,6,40767,0);
INSERT INTO "django_geo_db_location" VALUES(69665,NULL,'Ben Lomond, CA',28605,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69666,NULL,'Ben Lomond, CA 95005',28605,222,NULL,6,40768,0);
INSERT INTO "django_geo_db_location" VALUES(69667,NULL,'Boulder Creek, CA',28606,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69668,NULL,'Boulder Creek, CA 95006',28606,222,NULL,6,40769,0);
INSERT INTO "django_geo_db_location" VALUES(69669,NULL,'Brookdale, CA',28607,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69670,NULL,'Brookdale, CA 95007',28607,222,NULL,6,40770,0);
INSERT INTO "django_geo_db_location" VALUES(69671,NULL,'Campbell, CA',28608,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69672,NULL,'Campbell, CA 95008',28608,222,NULL,6,40771,0);
INSERT INTO "django_geo_db_location" VALUES(69673,NULL,'Campbell, CA 95009',28608,222,NULL,6,40772,0);
INSERT INTO "django_geo_db_location" VALUES(69674,NULL,'Capitola, CA',28609,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69675,NULL,'Capitola, CA 95010',28609,222,NULL,6,40773,0);
INSERT INTO "django_geo_db_location" VALUES(69676,NULL,'Campbell, CA 95011',28608,222,NULL,6,40774,0);
INSERT INTO "django_geo_db_location" VALUES(69677,NULL,'Castroville, CA',28610,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69678,NULL,'Castroville, CA 95012',28610,222,NULL,6,40775,0);
INSERT INTO "django_geo_db_location" VALUES(69679,NULL,'Coyote, CA',28611,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69680,NULL,'Coyote, CA 95013',28611,222,NULL,6,40776,0);
INSERT INTO "django_geo_db_location" VALUES(69681,NULL,'Cupertino, CA',28612,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69682,NULL,'Cupertino, CA 95014',28612,222,NULL,6,40777,0);
INSERT INTO "django_geo_db_location" VALUES(69683,NULL,'Cupertino, CA 95015',28612,222,NULL,6,40778,0);
INSERT INTO "django_geo_db_location" VALUES(69684,NULL,'Davenport, CA',28613,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69685,NULL,'Davenport, CA 95017',28613,222,NULL,6,40779,0);
INSERT INTO "django_geo_db_location" VALUES(69686,NULL,'Felton, CA',28614,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69687,NULL,'Felton, CA 95018',28614,222,NULL,6,40780,0);
INSERT INTO "django_geo_db_location" VALUES(69688,NULL,'Freedom, CA',28615,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69689,NULL,'Freedom, CA 95019',28615,222,NULL,6,40781,0);
INSERT INTO "django_geo_db_location" VALUES(69690,NULL,'Gilroy, CA',28616,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69691,NULL,'Gilroy, CA 95020',28616,222,NULL,6,40782,0);
INSERT INTO "django_geo_db_location" VALUES(69692,NULL,'Gilroy, CA 95021',28616,222,NULL,6,40783,0);
INSERT INTO "django_geo_db_location" VALUES(69693,NULL,'Palo Alto, CA 95022',28502,222,NULL,6,40784,0);
INSERT INTO "django_geo_db_location" VALUES(69694,NULL,'Hollister, CA',28617,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69695,NULL,'Hollister, CA 95023',28617,222,NULL,6,40785,0);
INSERT INTO "django_geo_db_location" VALUES(69696,NULL,'Hollister, CA 95024',28617,222,NULL,6,40786,0);
INSERT INTO "django_geo_db_location" VALUES(69697,NULL,'Holy City, CA',28618,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69698,NULL,'Holy City, CA 95026',28618,222,NULL,6,40787,0);
INSERT INTO "django_geo_db_location" VALUES(69699,NULL,'Los Gatos, CA',28619,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69700,NULL,'Los Gatos, CA 95030',28619,222,NULL,6,40788,0);
INSERT INTO "django_geo_db_location" VALUES(69701,NULL,'Los Gatos, CA 95031',28619,222,NULL,6,40789,0);
INSERT INTO "django_geo_db_location" VALUES(69702,NULL,'Los Gatos, CA 95032',28619,222,NULL,6,40790,0);
INSERT INTO "django_geo_db_location" VALUES(69703,NULL,'Los Gatos, CA 95033',28619,222,NULL,6,40791,0);
INSERT INTO "django_geo_db_location" VALUES(69704,NULL,'Milpitas, CA',28620,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69705,NULL,'Milpitas, CA 95035',28620,222,NULL,6,40792,0);
INSERT INTO "django_geo_db_location" VALUES(69706,NULL,'Milpitas, CA 95036',28620,222,NULL,6,40793,0);
INSERT INTO "django_geo_db_location" VALUES(69707,NULL,'Morgan Hill, CA',28621,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69708,NULL,'Morgan Hill, CA 95037',28621,222,NULL,6,40794,0);
INSERT INTO "django_geo_db_location" VALUES(69709,NULL,'Morgan Hill, CA 95038',28621,222,NULL,6,40795,0);
INSERT INTO "django_geo_db_location" VALUES(69710,NULL,'Moss Landing, CA',28622,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69711,NULL,'Moss Landing, CA 95039',28622,222,NULL,6,40796,0);
INSERT INTO "django_geo_db_location" VALUES(69712,NULL,'Mount Hermon, CA',28623,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69713,NULL,'Mount Hermon, CA 95041',28623,222,NULL,6,40797,0);
INSERT INTO "django_geo_db_location" VALUES(69714,NULL,'New Almaden, CA',28624,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69715,NULL,'New Almaden, CA 95042',28624,222,NULL,6,40798,0);
INSERT INTO "django_geo_db_location" VALUES(69716,NULL,'Paicines, CA',28625,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69717,NULL,'Paicines, CA 95043',28625,222,NULL,6,40799,0);
INSERT INTO "django_geo_db_location" VALUES(69718,NULL,'Redwood Estates, CA',28626,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69719,NULL,'Redwood Estates, CA 95044',28626,222,NULL,6,40800,0);
INSERT INTO "django_geo_db_location" VALUES(69720,NULL,'San Juan Bautista, CA',28627,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69721,NULL,'San Juan Bautista, CA 95045',28627,222,NULL,6,40801,0);
INSERT INTO "django_geo_db_location" VALUES(69722,NULL,'San Martin, CA',28628,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69723,NULL,'San Martin, CA 95046',28628,222,NULL,6,40802,0);
INSERT INTO "django_geo_db_location" VALUES(69724,NULL,'Santa Clara, CA',28629,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69725,NULL,'Santa Clara, CA 95050',28629,222,NULL,6,40803,0);
INSERT INTO "django_geo_db_location" VALUES(69726,NULL,'Santa Clara, CA 95051',28629,222,NULL,6,40804,0);
INSERT INTO "django_geo_db_location" VALUES(69727,NULL,'Santa Clara, CA 95052',28629,222,NULL,6,40805,0);
INSERT INTO "django_geo_db_location" VALUES(69728,NULL,'Santa Clara, CA 95053',28629,222,NULL,6,40806,0);
INSERT INTO "django_geo_db_location" VALUES(69729,NULL,'Santa Clara, CA 95054',28629,222,NULL,6,40807,0);
INSERT INTO "django_geo_db_location" VALUES(69730,NULL,'Santa Clara, CA 95055',28629,222,NULL,6,40808,0);
INSERT INTO "django_geo_db_location" VALUES(69731,NULL,'Santa Clara, CA 95056',28629,222,NULL,6,40809,0);
INSERT INTO "django_geo_db_location" VALUES(69732,NULL,'Santa Cruz, CA',28630,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69733,NULL,'Santa Cruz, CA 95060',28630,222,NULL,6,40810,0);
INSERT INTO "django_geo_db_location" VALUES(69734,NULL,'Santa Cruz, CA 95061',28630,222,NULL,6,40811,0);
INSERT INTO "django_geo_db_location" VALUES(69735,NULL,'Santa Cruz, CA 95062',28630,222,NULL,6,40812,0);
INSERT INTO "django_geo_db_location" VALUES(69736,NULL,'Santa Cruz, CA 95063',28630,222,NULL,6,40813,0);
INSERT INTO "django_geo_db_location" VALUES(69737,NULL,'Santa Cruz, CA 95064',28630,222,NULL,6,40814,0);
INSERT INTO "django_geo_db_location" VALUES(69738,NULL,'Santa Cruz, CA 95065',28630,222,NULL,6,40815,0);
INSERT INTO "django_geo_db_location" VALUES(69739,NULL,'Scotts Valley, CA',28631,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69740,NULL,'Scotts Valley, CA 95066',28631,222,NULL,6,40816,0);
INSERT INTO "django_geo_db_location" VALUES(69741,NULL,'Scotts Valley, CA 95067',28631,222,NULL,6,40817,0);
INSERT INTO "django_geo_db_location" VALUES(69742,NULL,'Saratoga, CA',28632,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69743,NULL,'Saratoga, CA 95070',28632,222,NULL,6,40818,0);
INSERT INTO "django_geo_db_location" VALUES(69744,NULL,'Saratoga, CA 95071',28632,222,NULL,6,40819,0);
INSERT INTO "django_geo_db_location" VALUES(69745,NULL,'Soquel, CA',28633,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69746,NULL,'Soquel, CA 95073',28633,222,NULL,6,40820,0);
INSERT INTO "django_geo_db_location" VALUES(69747,NULL,'Tres Pinos, CA',28634,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69748,NULL,'Tres Pinos, CA 95075',28634,222,NULL,6,40821,0);
INSERT INTO "django_geo_db_location" VALUES(69749,NULL,'Watsonville, CA',28635,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69750,NULL,'Watsonville, CA 95076',28635,222,NULL,6,40822,0);
INSERT INTO "django_geo_db_location" VALUES(69751,NULL,'Watsonville, CA 95077',28635,222,NULL,6,40823,0);
INSERT INTO "django_geo_db_location" VALUES(69752,NULL,'San Jose, CA',28636,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69753,NULL,'San Jose, CA 95101',28636,222,NULL,6,40824,0);
INSERT INTO "django_geo_db_location" VALUES(69754,NULL,'San Jose, CA 95102',28636,222,NULL,6,40825,0);
INSERT INTO "django_geo_db_location" VALUES(69755,NULL,'San Jose, CA 95103',28636,222,NULL,6,40826,0);
INSERT INTO "django_geo_db_location" VALUES(69756,NULL,'San Jose, CA 95106',28636,222,NULL,6,40827,0);
INSERT INTO "django_geo_db_location" VALUES(69757,NULL,'San Jose, CA 95108',28636,222,NULL,6,40828,0);
INSERT INTO "django_geo_db_location" VALUES(69758,NULL,'San Jose, CA 95109',28636,222,NULL,6,40829,0);
INSERT INTO "django_geo_db_location" VALUES(69759,NULL,'San Jose, CA 95110',28636,222,NULL,6,40830,0);
INSERT INTO "django_geo_db_location" VALUES(69760,NULL,'San Jose, CA 95111',28636,222,NULL,6,40831,0);
INSERT INTO "django_geo_db_location" VALUES(69761,NULL,'San Jose, CA 95112',28636,222,NULL,6,40832,0);
INSERT INTO "django_geo_db_location" VALUES(69762,NULL,'San Jose, CA 95113',28636,222,NULL,6,40833,0);
INSERT INTO "django_geo_db_location" VALUES(69763,NULL,'San Jose, CA 95114',28636,222,NULL,6,40834,0);
INSERT INTO "django_geo_db_location" VALUES(69764,NULL,'San Jose, CA 95115',28636,222,NULL,6,40835,0);
INSERT INTO "django_geo_db_location" VALUES(69765,NULL,'San Jose, CA 95116',28636,222,NULL,6,40836,0);
INSERT INTO "django_geo_db_location" VALUES(69766,NULL,'San Jose, CA 95117',28636,222,NULL,6,40837,0);
INSERT INTO "django_geo_db_location" VALUES(69767,NULL,'San Jose, CA 95118',28636,222,NULL,6,40838,0);
INSERT INTO "django_geo_db_location" VALUES(69768,NULL,'San Jose, CA 95119',28636,222,NULL,6,40839,0);
INSERT INTO "django_geo_db_location" VALUES(69769,NULL,'San Jose, CA 95120',28636,222,NULL,6,40840,0);
INSERT INTO "django_geo_db_location" VALUES(69770,NULL,'San Jose, CA 95121',28636,222,NULL,6,40841,0);
INSERT INTO "django_geo_db_location" VALUES(69771,NULL,'San Jose, CA 95122',28636,222,NULL,6,40842,0);
INSERT INTO "django_geo_db_location" VALUES(69772,NULL,'San Jose, CA 95123',28636,222,NULL,6,40843,0);
INSERT INTO "django_geo_db_location" VALUES(69773,NULL,'San Jose, CA 95124',28636,222,NULL,6,40844,0);
INSERT INTO "django_geo_db_location" VALUES(69774,NULL,'San Jose, CA 95125',28636,222,NULL,6,40845,0);
INSERT INTO "django_geo_db_location" VALUES(69775,NULL,'San Jose, CA 95126',28636,222,NULL,6,40846,0);
INSERT INTO "django_geo_db_location" VALUES(69776,NULL,'San Jose, CA 95127',28636,222,NULL,6,40847,0);
INSERT INTO "django_geo_db_location" VALUES(69777,NULL,'San Jose, CA 95128',28636,222,NULL,6,40848,0);
INSERT INTO "django_geo_db_location" VALUES(69778,NULL,'San Jose, CA 95129',28636,222,NULL,6,40849,0);
INSERT INTO "django_geo_db_location" VALUES(69779,NULL,'San Jose, CA 95130',28636,222,NULL,6,40850,0);
INSERT INTO "django_geo_db_location" VALUES(69780,NULL,'San Jose, CA 95131',28636,222,NULL,6,40851,0);
INSERT INTO "django_geo_db_location" VALUES(69781,NULL,'San Jose, CA 95132',28636,222,NULL,6,40852,0);
INSERT INTO "django_geo_db_location" VALUES(69782,NULL,'San Jose, CA 95133',28636,222,NULL,6,40853,0);
INSERT INTO "django_geo_db_location" VALUES(69783,NULL,'San Jose, CA 95134',28636,222,NULL,6,40854,0);
INSERT INTO "django_geo_db_location" VALUES(69784,NULL,'San Jose, CA 95135',28636,222,NULL,6,40855,0);
INSERT INTO "django_geo_db_location" VALUES(69785,NULL,'San Jose, CA 95136',28636,222,NULL,6,40856,0);
INSERT INTO "django_geo_db_location" VALUES(69786,NULL,'San Jose, CA 95137',28636,222,NULL,6,40857,0);
INSERT INTO "django_geo_db_location" VALUES(69787,NULL,'San Jose, CA 95138',28636,222,NULL,6,40858,0);
INSERT INTO "django_geo_db_location" VALUES(69788,NULL,'San Jose, CA 95139',28636,222,NULL,6,40859,0);
INSERT INTO "django_geo_db_location" VALUES(69789,NULL,'Mount Hamilton, CA',28637,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69790,NULL,'Mount Hamilton, CA 95140',28637,222,NULL,6,40860,0);
INSERT INTO "django_geo_db_location" VALUES(69791,NULL,'San Jose, CA 95141',28636,222,NULL,6,40861,0);
INSERT INTO "django_geo_db_location" VALUES(69792,NULL,'San Jose, CA 95142',28636,222,NULL,6,40862,0);
INSERT INTO "django_geo_db_location" VALUES(69793,NULL,'San Jose, CA 95148',28636,222,NULL,6,40863,0);
INSERT INTO "django_geo_db_location" VALUES(69794,NULL,'San Jose, CA 95150',28636,222,NULL,6,40864,0);
INSERT INTO "django_geo_db_location" VALUES(69795,NULL,'San Jose, CA 95151',28636,222,NULL,6,40865,0);
INSERT INTO "django_geo_db_location" VALUES(69796,NULL,'San Jose, CA 95152',28636,222,NULL,6,40866,0);
INSERT INTO "django_geo_db_location" VALUES(69797,NULL,'San Jose, CA 95153',28636,222,NULL,6,40867,0);
INSERT INTO "django_geo_db_location" VALUES(69798,NULL,'San Jose, CA 95154',28636,222,NULL,6,40868,0);
INSERT INTO "django_geo_db_location" VALUES(69799,NULL,'San Jose, CA 95155',28636,222,NULL,6,40869,0);
INSERT INTO "django_geo_db_location" VALUES(69800,NULL,'San Jose, CA 95156',28636,222,NULL,6,40870,0);
INSERT INTO "django_geo_db_location" VALUES(69801,NULL,'San Jose, CA 95157',28636,222,NULL,6,40871,0);
INSERT INTO "django_geo_db_location" VALUES(69802,NULL,'San Jose, CA 95158',28636,222,NULL,6,40872,0);
INSERT INTO "django_geo_db_location" VALUES(69803,NULL,'San Jose, CA 95159',28636,222,NULL,6,40873,0);
INSERT INTO "django_geo_db_location" VALUES(69804,NULL,'San Jose, CA 95160',28636,222,NULL,6,40874,0);
INSERT INTO "django_geo_db_location" VALUES(69805,NULL,'San Jose, CA 95161',28636,222,NULL,6,40875,0);
INSERT INTO "django_geo_db_location" VALUES(69806,NULL,'San Jose, CA 95164',28636,222,NULL,6,40876,0);
INSERT INTO "django_geo_db_location" VALUES(69807,NULL,'San Jose, CA 95170',28636,222,NULL,6,40877,0);
INSERT INTO "django_geo_db_location" VALUES(69808,NULL,'San Jose, CA 95171',28636,222,NULL,6,40878,0);
INSERT INTO "django_geo_db_location" VALUES(69809,NULL,'San Jose, CA 95172',28636,222,NULL,6,40879,0);
INSERT INTO "django_geo_db_location" VALUES(69810,NULL,'San Jose, CA 95173',28636,222,NULL,6,40880,0);
INSERT INTO "django_geo_db_location" VALUES(69811,NULL,'San Jose, CA 95190',28636,222,NULL,6,40881,0);
INSERT INTO "django_geo_db_location" VALUES(69812,NULL,'San Jose, CA 95191',28636,222,NULL,6,40882,0);
INSERT INTO "django_geo_db_location" VALUES(69813,NULL,'San Jose, CA 95192',28636,222,NULL,6,40883,0);
INSERT INTO "django_geo_db_location" VALUES(69814,NULL,'San Jose, CA 95193',28636,222,NULL,6,40884,0);
INSERT INTO "django_geo_db_location" VALUES(69815,NULL,'San Jose, CA 95194',28636,222,NULL,6,40885,0);
INSERT INTO "django_geo_db_location" VALUES(69816,NULL,'San Jose, CA 95196',28636,222,NULL,6,40886,0);
INSERT INTO "django_geo_db_location" VALUES(69817,NULL,'Stockton, CA',28638,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69818,NULL,'Stockton, CA 95201',28638,222,NULL,6,40887,0);
INSERT INTO "django_geo_db_location" VALUES(69819,NULL,'Stockton, CA 95202',28638,222,NULL,6,40888,0);
INSERT INTO "django_geo_db_location" VALUES(69820,NULL,'Stockton, CA 95203',28638,222,NULL,6,40889,0);
INSERT INTO "django_geo_db_location" VALUES(69821,NULL,'Stockton, CA 95204',28638,222,NULL,6,40890,0);
INSERT INTO "django_geo_db_location" VALUES(69822,NULL,'Stockton, CA 95205',28638,222,NULL,6,40891,0);
INSERT INTO "django_geo_db_location" VALUES(69823,NULL,'Stockton, CA 95206',28638,222,NULL,6,40892,0);
INSERT INTO "django_geo_db_location" VALUES(69824,NULL,'Stockton, CA 95207',28638,222,NULL,6,40893,0);
INSERT INTO "django_geo_db_location" VALUES(69825,NULL,'Stockton, CA 95208',28638,222,NULL,6,40894,0);
INSERT INTO "django_geo_db_location" VALUES(69826,NULL,'Stockton, CA 95209',28638,222,NULL,6,40895,0);
INSERT INTO "django_geo_db_location" VALUES(69827,NULL,'Stockton, CA 95210',28638,222,NULL,6,40896,0);
INSERT INTO "django_geo_db_location" VALUES(69828,NULL,'Stockton, CA 95211',28638,222,NULL,6,40897,0);
INSERT INTO "django_geo_db_location" VALUES(69829,NULL,'Stockton, CA 95212',28638,222,NULL,6,40898,0);
INSERT INTO "django_geo_db_location" VALUES(69830,NULL,'Stockton, CA 95213',28638,222,NULL,6,40899,0);
INSERT INTO "django_geo_db_location" VALUES(69831,NULL,'Stockton, CA 95215',28638,222,NULL,6,40900,0);
INSERT INTO "django_geo_db_location" VALUES(69832,NULL,'Stockton, CA 95219',28638,222,NULL,6,40901,0);
INSERT INTO "django_geo_db_location" VALUES(69833,NULL,'Acampo, CA',28639,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69834,NULL,'Acampo, CA 95220',28639,222,NULL,6,40902,0);
INSERT INTO "django_geo_db_location" VALUES(69835,NULL,'Altaville, CA',28640,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69836,NULL,'Altaville, CA 95221',28640,222,NULL,6,40903,0);
INSERT INTO "django_geo_db_location" VALUES(69837,NULL,'Angels Camp, CA',28641,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69838,NULL,'Angels Camp, CA 95222',28641,222,NULL,6,40904,0);
INSERT INTO "django_geo_db_location" VALUES(69839,NULL,'Arnold, CA',28642,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69840,NULL,'Arnold, CA 95223',28642,222,NULL,6,40905,0);
INSERT INTO "django_geo_db_location" VALUES(69841,NULL,'Avery, CA',28643,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69842,NULL,'Avery, CA 95224',28643,222,NULL,6,40906,0);
INSERT INTO "django_geo_db_location" VALUES(69843,NULL,'Burson, CA',28644,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69844,NULL,'Burson, CA 95225',28644,222,NULL,6,40907,0);
INSERT INTO "django_geo_db_location" VALUES(69845,NULL,'Campo Seco, CA',28645,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69846,NULL,'Campo Seco, CA 95226',28645,222,NULL,6,40908,0);
INSERT INTO "django_geo_db_location" VALUES(69847,NULL,'Clements, CA',28646,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69848,NULL,'Clements, CA 95227',28646,222,NULL,6,40909,0);
INSERT INTO "django_geo_db_location" VALUES(69849,NULL,'Copperopolis, CA',28647,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69850,NULL,'Copperopolis, CA 95228',28647,222,NULL,6,40910,0);
INSERT INTO "django_geo_db_location" VALUES(69851,NULL,'Douglas Flat, CA',28648,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69852,NULL,'Douglas Flat, CA 95229',28648,222,NULL,6,40911,0);
INSERT INTO "django_geo_db_location" VALUES(69853,NULL,'Farmington, CA',28649,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69854,NULL,'Farmington, CA 95230',28649,222,NULL,6,40912,0);
INSERT INTO "django_geo_db_location" VALUES(69855,NULL,'French Camp, CA',28650,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69856,NULL,'French Camp, CA 95231',28650,222,NULL,6,40913,0);
INSERT INTO "django_geo_db_location" VALUES(69857,NULL,'Glencoe, CA',28651,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69858,NULL,'Glencoe, CA 95232',28651,222,NULL,6,40914,0);
INSERT INTO "django_geo_db_location" VALUES(69859,NULL,'Hathaway Pines, CA',28652,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69860,NULL,'Hathaway Pines, CA 95233',28652,222,NULL,6,40915,0);
INSERT INTO "django_geo_db_location" VALUES(69861,NULL,'Holt, CA',28653,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69862,NULL,'Holt, CA 95234',28653,222,NULL,6,40916,0);
INSERT INTO "django_geo_db_location" VALUES(69863,NULL,'Linden, CA',28654,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69864,NULL,'Linden, CA 95236',28654,222,NULL,6,40917,0);
INSERT INTO "django_geo_db_location" VALUES(69865,NULL,'Lockeford, CA',28655,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69866,NULL,'Lockeford, CA 95237',28655,222,NULL,6,40918,0);
INSERT INTO "django_geo_db_location" VALUES(69867,NULL,'Lodi, CA',28656,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69868,NULL,'Lodi, CA 95240',28656,222,NULL,6,40919,0);
INSERT INTO "django_geo_db_location" VALUES(69869,NULL,'Lodi, CA 95241',28656,222,NULL,6,40920,0);
INSERT INTO "django_geo_db_location" VALUES(69870,NULL,'Lodi, CA 95242',28656,222,NULL,6,40921,0);
INSERT INTO "django_geo_db_location" VALUES(69871,NULL,'Mokelumne Hill, CA',28657,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69872,NULL,'Mokelumne Hill, CA 95245',28657,222,NULL,6,40922,0);
INSERT INTO "django_geo_db_location" VALUES(69873,NULL,'Mountain Ranch, CA',28658,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69874,NULL,'Mountain Ranch, CA 95246',28658,222,NULL,6,40923,0);
INSERT INTO "django_geo_db_location" VALUES(69875,NULL,'Murphys, CA',28659,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69876,NULL,'Murphys, CA 95247',28659,222,NULL,6,40924,0);
INSERT INTO "django_geo_db_location" VALUES(69877,NULL,'Rail Road Flat, CA',28660,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69878,NULL,'Rail Road Flat, CA 95248',28660,222,NULL,6,40925,0);
INSERT INTO "django_geo_db_location" VALUES(69879,NULL,'San Andreas, CA',28661,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69880,NULL,'San Andreas, CA 95249',28661,222,NULL,6,40926,0);
INSERT INTO "django_geo_db_location" VALUES(69881,NULL,'Sheep Ranch, CA',28662,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69882,NULL,'Sheep Ranch, CA 95250',28662,222,NULL,6,40927,0);
INSERT INTO "django_geo_db_location" VALUES(69883,NULL,'Vallecito, CA',28663,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69884,NULL,'Vallecito, CA 95251',28663,222,NULL,6,40928,0);
INSERT INTO "django_geo_db_location" VALUES(69885,NULL,'Valley Springs, CA',28664,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69886,NULL,'Valley Springs, CA 95252',28664,222,NULL,6,40929,0);
INSERT INTO "django_geo_db_location" VALUES(69887,NULL,'Victor, CA',28665,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69888,NULL,'Victor, CA 95253',28665,222,NULL,6,40930,0);
INSERT INTO "django_geo_db_location" VALUES(69889,NULL,'Wallace, CA',28666,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69890,NULL,'Wallace, CA 95254',28666,222,NULL,6,40931,0);
INSERT INTO "django_geo_db_location" VALUES(69891,NULL,'West Point, CA',28667,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69892,NULL,'West Point, CA 95255',28667,222,NULL,6,40932,0);
INSERT INTO "django_geo_db_location" VALUES(69893,NULL,'Wilseyville, CA',28668,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69894,NULL,'Wilseyville, CA 95257',28668,222,NULL,6,40933,0);
INSERT INTO "django_geo_db_location" VALUES(69895,NULL,'Woodbridge, CA',28669,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69896,NULL,'Woodbridge, CA 95258',28669,222,NULL,6,40934,0);
INSERT INTO "django_geo_db_location" VALUES(69897,NULL,'Stockton, CA 95267',28638,222,NULL,6,40935,0);
INSERT INTO "django_geo_db_location" VALUES(69898,NULL,'Stockton, CA 95269',28638,222,NULL,6,40936,0);
INSERT INTO "django_geo_db_location" VALUES(69899,NULL,'Stockton, CA 95290',28638,222,NULL,6,40937,0);
INSERT INTO "django_geo_db_location" VALUES(69900,NULL,'Lyoth, CA',28670,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69901,NULL,'Lyoth, CA 95296',28670,222,NULL,6,40938,0);
INSERT INTO "django_geo_db_location" VALUES(69902,NULL,'Stockton, CA 95297',28638,222,NULL,6,40939,0);
INSERT INTO "django_geo_db_location" VALUES(69903,NULL,'Stockton, CA 95298',28638,222,NULL,6,40940,0);
INSERT INTO "django_geo_db_location" VALUES(69904,NULL,'Atwater, CA',28671,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69905,NULL,'Atwater, CA 95301',28671,222,NULL,6,40941,0);
INSERT INTO "django_geo_db_location" VALUES(69906,NULL,'Ballico, CA',28672,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69907,NULL,'Ballico, CA 95303',28672,222,NULL,6,40942,0);
INSERT INTO "django_geo_db_location" VALUES(69908,NULL,'Banta, CA',28673,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69909,NULL,'Banta, CA 95304',28673,222,NULL,6,40943,0);
INSERT INTO "django_geo_db_location" VALUES(69910,NULL,'Big Oak Flat, CA',28674,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69911,NULL,'Big Oak Flat, CA 95305',28674,222,NULL,6,40944,0);
INSERT INTO "django_geo_db_location" VALUES(69912,NULL,'Catheys Valley, CA',28675,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69913,NULL,'Catheys Valley, CA 95306',28675,222,NULL,6,40945,0);
INSERT INTO "django_geo_db_location" VALUES(69914,NULL,'Ceres, CA',28676,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69915,NULL,'Ceres, CA 95307',28676,222,NULL,6,40946,0);
INSERT INTO "django_geo_db_location" VALUES(69916,NULL,'Chinese Camp, CA',28677,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69917,NULL,'Chinese Camp, CA 95309',28677,222,NULL,6,40947,0);
INSERT INTO "django_geo_db_location" VALUES(69918,NULL,'Columbia, CA',28678,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69919,NULL,'Columbia, CA 95310',28678,222,NULL,6,40948,0);
INSERT INTO "django_geo_db_location" VALUES(69920,NULL,'Coulterville, CA',28679,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69921,NULL,'Coulterville, CA 95311',28679,222,NULL,6,40949,0);
INSERT INTO "django_geo_db_location" VALUES(69922,NULL,'Cressey, CA',28680,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69923,NULL,'Cressey, CA 95312',28680,222,NULL,6,40950,0);
INSERT INTO "django_geo_db_location" VALUES(69924,NULL,'Crows Landing, CA',28681,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69925,NULL,'Crows Landing, CA 95313',28681,222,NULL,6,40951,0);
INSERT INTO "django_geo_db_location" VALUES(69926,NULL,'Dardanelle, CA',28682,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69927,NULL,'Dardanelle, CA 95314',28682,222,NULL,6,40952,0);
INSERT INTO "django_geo_db_location" VALUES(69928,NULL,'Delhi, CA',28683,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69929,NULL,'Delhi, CA 95315',28683,222,NULL,6,40953,0);
INSERT INTO "django_geo_db_location" VALUES(69930,NULL,'Denair, CA',28684,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69931,NULL,'Denair, CA 95316',28684,222,NULL,6,40954,0);
INSERT INTO "django_geo_db_location" VALUES(69932,NULL,'El Nido, CA',28685,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69933,NULL,'El Nido, CA 95317',28685,222,NULL,6,40955,0);
INSERT INTO "django_geo_db_location" VALUES(69934,NULL,'El Portal, CA',28686,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69935,NULL,'El Portal, CA 95318',28686,222,NULL,6,40956,0);
INSERT INTO "django_geo_db_location" VALUES(69936,NULL,'Empire, CA',28687,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69937,NULL,'Empire, CA 95319',28687,222,NULL,6,40957,0);
INSERT INTO "django_geo_db_location" VALUES(69938,NULL,'Escalon, CA',28688,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69939,NULL,'Escalon, CA 95320',28688,222,NULL,6,40958,0);
INSERT INTO "django_geo_db_location" VALUES(69940,NULL,'Groveland, CA',28689,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69941,NULL,'Groveland, CA 95321',28689,222,NULL,6,40959,0);
INSERT INTO "django_geo_db_location" VALUES(69942,NULL,'Gustine, CA',28690,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69943,NULL,'Gustine, CA 95322',28690,222,NULL,6,40960,0);
INSERT INTO "django_geo_db_location" VALUES(69944,NULL,'Hickman, CA',28691,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69945,NULL,'Hickman, CA 95323',28691,222,NULL,6,40961,0);
INSERT INTO "django_geo_db_location" VALUES(69946,NULL,'Hilmar, CA',28692,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69947,NULL,'Hilmar, CA 95324',28692,222,NULL,6,40962,0);
INSERT INTO "django_geo_db_location" VALUES(69948,NULL,'Hornitos, CA',28693,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69949,NULL,'Hornitos, CA 95325',28693,222,NULL,6,40963,0);
INSERT INTO "django_geo_db_location" VALUES(69950,NULL,'Hughson, CA',28694,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69951,NULL,'Hughson, CA 95326',28694,222,NULL,6,40964,0);
INSERT INTO "django_geo_db_location" VALUES(69952,NULL,'Jamestown, CA',28695,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69953,NULL,'Jamestown, CA 95327',28695,222,NULL,6,40965,0);
INSERT INTO "django_geo_db_location" VALUES(69954,NULL,'Keyes, CA',28696,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69955,NULL,'Keyes, CA 95328',28696,222,NULL,6,40966,0);
INSERT INTO "django_geo_db_location" VALUES(69956,NULL,'La Grange, CA',28697,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69957,NULL,'La Grange, CA 95329',28697,222,NULL,6,40967,0);
INSERT INTO "django_geo_db_location" VALUES(69958,NULL,'Lathrop, CA',28698,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69959,NULL,'Lathrop, CA 95330',28698,222,NULL,6,40968,0);
INSERT INTO "django_geo_db_location" VALUES(69960,NULL,'Le Grand, CA',28699,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69961,NULL,'Le Grand, CA 95333',28699,222,NULL,6,40969,0);
INSERT INTO "django_geo_db_location" VALUES(69962,NULL,'Livingston, CA',28700,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69963,NULL,'Livingston, CA 95334',28700,222,NULL,6,40970,0);
INSERT INTO "django_geo_db_location" VALUES(69964,NULL,'Long Barn, CA',28701,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69965,NULL,'Long Barn, CA 95335',28701,222,NULL,6,40971,0);
INSERT INTO "django_geo_db_location" VALUES(69966,NULL,'Manteca, CA',28702,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69967,NULL,'Manteca, CA 95336',28702,222,NULL,6,40972,0);
INSERT INTO "django_geo_db_location" VALUES(69968,NULL,'Manteca, CA 95337',28702,222,NULL,6,40973,0);
INSERT INTO "django_geo_db_location" VALUES(69969,NULL,'Mariposa, CA',28703,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69970,NULL,'Mariposa, CA 95338',28703,222,NULL,6,40974,0);
INSERT INTO "django_geo_db_location" VALUES(69971,NULL,'Merced, CA',28704,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69972,NULL,'Merced, CA 95340',28704,222,NULL,6,40975,0);
INSERT INTO "django_geo_db_location" VALUES(69973,NULL,'Merced, CA 95341',28704,222,NULL,6,40976,0);
INSERT INTO "django_geo_db_location" VALUES(69974,NULL,'Atwater, CA 95342',28671,222,NULL,6,40977,0);
INSERT INTO "django_geo_db_location" VALUES(69975,NULL,'Merced, CA 95343',28704,222,NULL,6,40978,0);
INSERT INTO "django_geo_db_location" VALUES(69976,NULL,'Merced, CA 95344',28704,222,NULL,6,40979,0);
INSERT INTO "django_geo_db_location" VALUES(69977,NULL,'Midpines, CA',28705,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69978,NULL,'Midpines, CA 95345',28705,222,NULL,6,40980,0);
INSERT INTO "django_geo_db_location" VALUES(69979,NULL,'Mi Wuk Village, CA',28706,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69980,NULL,'Mi Wuk Village, CA 95346',28706,222,NULL,6,40981,0);
INSERT INTO "django_geo_db_location" VALUES(69981,NULL,'Moccasin, CA',28707,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69982,NULL,'Moccasin, CA 95347',28707,222,NULL,6,40982,0);
INSERT INTO "django_geo_db_location" VALUES(69983,NULL,'Merced, CA 95348',28704,222,NULL,6,40983,0);
INSERT INTO "django_geo_db_location" VALUES(69984,NULL,'Modesto, CA',28708,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69985,NULL,'Modesto, CA 95350',28708,222,NULL,6,40984,0);
INSERT INTO "django_geo_db_location" VALUES(69986,NULL,'Modesto, CA 95351',28708,222,NULL,6,40985,0);
INSERT INTO "django_geo_db_location" VALUES(69987,NULL,'Modesto, CA 95352',28708,222,NULL,6,40986,0);
INSERT INTO "django_geo_db_location" VALUES(69988,NULL,'Modesto, CA 95353',28708,222,NULL,6,40987,0);
INSERT INTO "django_geo_db_location" VALUES(69989,NULL,'Modesto, CA 95354',28708,222,NULL,6,40988,0);
INSERT INTO "django_geo_db_location" VALUES(69990,NULL,'Modesto, CA 95355',28708,222,NULL,6,40989,0);
INSERT INTO "django_geo_db_location" VALUES(69991,NULL,'Modesto, CA 95356',28708,222,NULL,6,40990,0);
INSERT INTO "django_geo_db_location" VALUES(69992,NULL,'Modesto, CA 95357',28708,222,NULL,6,40991,0);
INSERT INTO "django_geo_db_location" VALUES(69993,NULL,'Modesto, CA 95358',28708,222,NULL,6,40992,0);
INSERT INTO "django_geo_db_location" VALUES(69994,NULL,'Newman, CA',28709,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69995,NULL,'Newman, CA 95360',28709,222,NULL,6,40993,0);
INSERT INTO "django_geo_db_location" VALUES(69996,NULL,'Oakdale, CA',28710,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69997,NULL,'Oakdale, CA 95361',28710,222,NULL,6,40994,0);
INSERT INTO "django_geo_db_location" VALUES(69998,NULL,'Patterson, CA',28711,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(69999,NULL,'Patterson, CA 95363',28711,222,NULL,6,40995,0);
INSERT INTO "django_geo_db_location" VALUES(70000,NULL,'Pinecrest, CA',28712,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70001,NULL,'Pinecrest, CA 95364',28712,222,NULL,6,40996,0);
INSERT INTO "django_geo_db_location" VALUES(70002,NULL,'Planada, CA',28713,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70003,NULL,'Planada, CA 95365',28713,222,NULL,6,40997,0);
INSERT INTO "django_geo_db_location" VALUES(70004,NULL,'Ripon, CA',28714,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70005,NULL,'Ripon, CA 95366',28714,222,NULL,6,40998,0);
INSERT INTO "django_geo_db_location" VALUES(70006,NULL,'Riverbank, CA',28715,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70007,NULL,'Riverbank, CA 95367',28715,222,NULL,6,40999,0);
INSERT INTO "django_geo_db_location" VALUES(70008,NULL,'Salida, CA',28716,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70009,NULL,'Salida, CA 95368',28716,222,NULL,6,41000,0);
INSERT INTO "django_geo_db_location" VALUES(70010,NULL,'Snelling, CA',28717,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70011,NULL,'Snelling, CA 95369',28717,222,NULL,6,41001,0);
INSERT INTO "django_geo_db_location" VALUES(70012,NULL,'Sonora, CA',28718,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70013,NULL,'Sonora, CA 95370',28718,222,NULL,6,41002,0);
INSERT INTO "django_geo_db_location" VALUES(70014,NULL,'Soulsbyville, CA',28719,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70015,NULL,'Soulsbyville, CA 95372',28719,222,NULL,6,41003,0);
INSERT INTO "django_geo_db_location" VALUES(70016,NULL,'Standard, CA',28720,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70017,NULL,'Standard, CA 95373',28720,222,NULL,6,41004,0);
INSERT INTO "django_geo_db_location" VALUES(70018,NULL,'Stevinson, CA',28721,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70019,NULL,'Stevinson, CA 95374',28721,222,NULL,6,41005,0);
INSERT INTO "django_geo_db_location" VALUES(70020,NULL,'Strawberry, CA',28722,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70021,NULL,'Strawberry, CA 95375',28722,222,NULL,6,41006,0);
INSERT INTO "django_geo_db_location" VALUES(70022,NULL,'Tracy, CA',28723,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70023,NULL,'Tracy, CA 95376',28723,222,NULL,6,41007,0);
INSERT INTO "django_geo_db_location" VALUES(70024,NULL,'Tracy, CA 95377',28723,222,NULL,6,41008,0);
INSERT INTO "django_geo_db_location" VALUES(70025,NULL,'Tracy, CA 95378',28723,222,NULL,6,41009,0);
INSERT INTO "django_geo_db_location" VALUES(70026,NULL,'Tuolumne, CA',28724,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70027,NULL,'Tuolumne, CA 95379',28724,222,NULL,6,41010,0);
INSERT INTO "django_geo_db_location" VALUES(70028,NULL,'Turlock, CA',28725,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70029,NULL,'Turlock, CA 95380',28725,222,NULL,6,41011,0);
INSERT INTO "django_geo_db_location" VALUES(70030,NULL,'Turlock, CA 95381',28725,222,NULL,6,41012,0);
INSERT INTO "django_geo_db_location" VALUES(70031,NULL,'Turlock, CA 95382',28725,222,NULL,6,41013,0);
INSERT INTO "django_geo_db_location" VALUES(70032,NULL,'Twain Harte, CA',28726,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70033,NULL,'Twain Harte, CA 95383',28726,222,NULL,6,41014,0);
INSERT INTO "django_geo_db_location" VALUES(70034,NULL,'Vernalis, CA',28727,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70035,NULL,'Vernalis, CA 95385',28727,222,NULL,6,41015,0);
INSERT INTO "django_geo_db_location" VALUES(70036,NULL,'Waterford, CA',28728,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70037,NULL,'Waterford, CA 95386',28728,222,NULL,6,41016,0);
INSERT INTO "django_geo_db_location" VALUES(70038,NULL,'Westley, CA',28729,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70039,NULL,'Westley, CA 95387',28729,222,NULL,6,41017,0);
INSERT INTO "django_geo_db_location" VALUES(70040,NULL,'Winton, CA',28730,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70041,NULL,'Winton, CA 95388',28730,222,NULL,6,41018,0);
INSERT INTO "django_geo_db_location" VALUES(70042,NULL,'Yosemite National Park, CA',28731,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70043,NULL,'Yosemite National Park, CA 95389',28731,222,NULL,6,41019,0);
INSERT INTO "django_geo_db_location" VALUES(70044,NULL,'Riverbank, CA 95390',28715,222,NULL,6,41020,0);
INSERT INTO "django_geo_db_location" VALUES(70045,NULL,'Modesto, CA 95397',28708,222,NULL,6,41021,0);
INSERT INTO "django_geo_db_location" VALUES(70046,NULL,'Santa Rosa, CA',28732,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70047,NULL,'Santa Rosa, CA 95401',28732,222,NULL,6,41022,0);
INSERT INTO "django_geo_db_location" VALUES(70048,NULL,'Santa Rosa, CA 95402',28732,222,NULL,6,41023,0);
INSERT INTO "django_geo_db_location" VALUES(70049,NULL,'Santa Rosa, CA 95403',28732,222,NULL,6,41024,0);
INSERT INTO "django_geo_db_location" VALUES(70050,NULL,'Santa Rosa, CA 95404',28732,222,NULL,6,41025,0);
INSERT INTO "django_geo_db_location" VALUES(70051,NULL,'Santa Rosa, CA 95405',28732,222,NULL,6,41026,0);
INSERT INTO "django_geo_db_location" VALUES(70052,NULL,'Santa Rosa, CA 95406',28732,222,NULL,6,41027,0);
INSERT INTO "django_geo_db_location" VALUES(70053,NULL,'Santa Rosa, CA 95407',28732,222,NULL,6,41028,0);
INSERT INTO "django_geo_db_location" VALUES(70054,NULL,'Santa Rosa, CA 95408',28732,222,NULL,6,41029,0);
INSERT INTO "django_geo_db_location" VALUES(70055,NULL,'Santa Rosa, CA 95409',28732,222,NULL,6,41030,0);
INSERT INTO "django_geo_db_location" VALUES(70056,NULL,'Albion, CA',28733,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70057,NULL,'Albion, CA 95410',28733,222,NULL,6,41031,0);
INSERT INTO "django_geo_db_location" VALUES(70058,NULL,'Annapolis, CA',28734,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70059,NULL,'Annapolis, CA 95412',28734,222,NULL,6,41032,0);
INSERT INTO "django_geo_db_location" VALUES(70060,NULL,'Boonville, CA',28735,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70061,NULL,'Boonville, CA 95415',28735,222,NULL,6,41033,0);
INSERT INTO "django_geo_db_location" VALUES(70062,NULL,'Boyes Hot Springs, CA',28736,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70063,NULL,'Boyes Hot Springs, CA 95416',28736,222,NULL,6,41034,0);
INSERT INTO "django_geo_db_location" VALUES(70064,NULL,'Branscomb, CA',28737,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70065,NULL,'Branscomb, CA 95417',28737,222,NULL,6,41035,0);
INSERT INTO "django_geo_db_location" VALUES(70066,NULL,'Calpella, CA',28738,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70067,NULL,'Calpella, CA 95418',28738,222,NULL,6,41036,0);
INSERT INTO "django_geo_db_location" VALUES(70068,NULL,'Camp Meeker, CA',28739,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70069,NULL,'Camp Meeker, CA 95419',28739,222,NULL,6,41037,0);
INSERT INTO "django_geo_db_location" VALUES(70070,NULL,'Caspar, CA',28740,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70071,NULL,'Caspar, CA 95420',28740,222,NULL,6,41038,0);
INSERT INTO "django_geo_db_location" VALUES(70072,NULL,'Cazadero, CA',28741,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70073,NULL,'Cazadero, CA 95421',28741,222,NULL,6,41039,0);
INSERT INTO "django_geo_db_location" VALUES(70074,NULL,'Clearlake, CA',28742,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70075,NULL,'Clearlake, CA 95422',28742,222,NULL,6,41040,0);
INSERT INTO "django_geo_db_location" VALUES(70076,NULL,'Clearlake Oaks, CA',28743,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70077,NULL,'Clearlake Oaks, CA 95423',28743,222,NULL,6,41041,0);
INSERT INTO "django_geo_db_location" VALUES(70078,NULL,'Clearlake Park, CA',28744,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70079,NULL,'Clearlake Park, CA 95424',28744,222,NULL,6,41042,0);
INSERT INTO "django_geo_db_location" VALUES(70080,NULL,'Cloverdale, CA',28745,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70081,NULL,'Cloverdale, CA 95425',28745,222,NULL,6,41043,0);
INSERT INTO "django_geo_db_location" VALUES(70082,NULL,'Cobb, CA',28746,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70083,NULL,'Cobb, CA 95426',28746,222,NULL,6,41044,0);
INSERT INTO "django_geo_db_location" VALUES(70084,NULL,'Comptche, CA',28747,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70085,NULL,'Comptche, CA 95427',28747,222,NULL,6,41045,0);
INSERT INTO "django_geo_db_location" VALUES(70086,NULL,'Covelo, CA',28748,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70087,NULL,'Covelo, CA 95428',28748,222,NULL,6,41046,0);
INSERT INTO "django_geo_db_location" VALUES(70088,NULL,'Dos Rios, CA',28749,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70089,NULL,'Dos Rios, CA 95429',28749,222,NULL,6,41047,0);
INSERT INTO "django_geo_db_location" VALUES(70090,NULL,'Duncans Mills, CA',28750,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70091,NULL,'Duncans Mills, CA 95430',28750,222,NULL,6,41048,0);
INSERT INTO "django_geo_db_location" VALUES(70092,NULL,'Eldridge, CA',28751,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70093,NULL,'Eldridge, CA 95431',28751,222,NULL,6,41049,0);
INSERT INTO "django_geo_db_location" VALUES(70094,NULL,'Elk, CA',28752,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70095,NULL,'Elk, CA 95432',28752,222,NULL,6,41050,0);
INSERT INTO "django_geo_db_location" VALUES(70096,NULL,'El Verano, CA',28753,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70097,NULL,'El Verano, CA 95433',28753,222,NULL,6,41051,0);
INSERT INTO "django_geo_db_location" VALUES(70098,NULL,'Finley, CA',28754,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70099,NULL,'Finley, CA 95435',28754,222,NULL,6,41052,0);
INSERT INTO "django_geo_db_location" VALUES(70100,NULL,'Forestville, CA',28755,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70101,NULL,'Forestville, CA 95436',28755,222,NULL,6,41053,0);
INSERT INTO "django_geo_db_location" VALUES(70102,NULL,'Fort Bragg, CA',28756,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70103,NULL,'Fort Bragg, CA 95437',28756,222,NULL,6,41054,0);
INSERT INTO "django_geo_db_location" VALUES(70104,NULL,'Fulton, CA',28757,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70105,NULL,'Fulton, CA 95439',28757,222,NULL,6,41055,0);
INSERT INTO "django_geo_db_location" VALUES(70106,NULL,'Geyserville, CA',28758,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70107,NULL,'Geyserville, CA 95441',28758,222,NULL,6,41056,0);
INSERT INTO "django_geo_db_location" VALUES(70108,NULL,'Glen Ellen, CA',28759,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70109,NULL,'Glen Ellen, CA 95442',28759,222,NULL,6,41057,0);
INSERT INTO "django_geo_db_location" VALUES(70110,NULL,'Glenhaven, CA',28760,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70111,NULL,'Glenhaven, CA 95443',28760,222,NULL,6,41058,0);
INSERT INTO "django_geo_db_location" VALUES(70112,NULL,'Graton, CA',28761,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70113,NULL,'Graton, CA 95444',28761,222,NULL,6,41059,0);
INSERT INTO "django_geo_db_location" VALUES(70114,NULL,'Gualala, CA',28762,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70115,NULL,'Gualala, CA 95445',28762,222,NULL,6,41060,0);
INSERT INTO "django_geo_db_location" VALUES(70116,NULL,'Guerneville, CA',28763,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70117,NULL,'Guerneville, CA 95446',28763,222,NULL,6,41061,0);
INSERT INTO "django_geo_db_location" VALUES(70118,NULL,'Healdsburg, CA',28764,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70119,NULL,'Healdsburg, CA 95448',28764,222,NULL,6,41062,0);
INSERT INTO "django_geo_db_location" VALUES(70120,NULL,'Hopland, CA',28765,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70121,NULL,'Hopland, CA 95449',28765,222,NULL,6,41063,0);
INSERT INTO "django_geo_db_location" VALUES(70122,NULL,'Jenner, CA',28766,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70123,NULL,'Jenner, CA 95450',28766,222,NULL,6,41064,0);
INSERT INTO "django_geo_db_location" VALUES(70124,NULL,'Kelseyville, CA',28767,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70125,NULL,'Kelseyville, CA 95451',28767,222,NULL,6,41065,0);
INSERT INTO "django_geo_db_location" VALUES(70126,NULL,'Kenwood, CA',28768,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70127,NULL,'Kenwood, CA 95452',28768,222,NULL,6,41066,0);
INSERT INTO "django_geo_db_location" VALUES(70128,NULL,'Lakeport, CA',28769,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70129,NULL,'Lakeport, CA 95453',28769,222,NULL,6,41067,0);
INSERT INTO "django_geo_db_location" VALUES(70130,NULL,'Laytonville, CA',28770,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70131,NULL,'Laytonville, CA 95454',28770,222,NULL,6,41068,0);
INSERT INTO "django_geo_db_location" VALUES(70132,NULL,'Littleriver, CA',28771,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70133,NULL,'Littleriver, CA 95456',28771,222,NULL,6,41069,0);
INSERT INTO "django_geo_db_location" VALUES(70134,NULL,'Lower Lake, CA',28772,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70135,NULL,'Lower Lake, CA 95457',28772,222,NULL,6,41070,0);
INSERT INTO "django_geo_db_location" VALUES(70136,NULL,'Lucerne, CA',28773,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70137,NULL,'Lucerne, CA 95458',28773,222,NULL,6,41071,0);
INSERT INTO "django_geo_db_location" VALUES(70138,NULL,'Manchester, CA',28774,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70139,NULL,'Manchester, CA 95459',28774,222,NULL,6,41072,0);
INSERT INTO "django_geo_db_location" VALUES(70140,NULL,'Mendocino, CA',28775,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70141,NULL,'Mendocino, CA 95460',28775,222,NULL,6,41073,0);
INSERT INTO "django_geo_db_location" VALUES(70142,NULL,'Middletown, CA',28776,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70143,NULL,'Middletown, CA 95461',28776,222,NULL,6,41074,0);
INSERT INTO "django_geo_db_location" VALUES(70144,NULL,'Monte Rio, CA',28777,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70145,NULL,'Monte Rio, CA 95462',28777,222,NULL,6,41075,0);
INSERT INTO "django_geo_db_location" VALUES(70146,NULL,'Navarro, CA',28778,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70147,NULL,'Navarro, CA 95463',28778,222,NULL,6,41076,0);
INSERT INTO "django_geo_db_location" VALUES(70148,NULL,'Nice, CA',28779,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70149,NULL,'Nice, CA 95464',28779,222,NULL,6,41077,0);
INSERT INTO "django_geo_db_location" VALUES(70150,NULL,'Occidental, CA',28780,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70151,NULL,'Occidental, CA 95465',28780,222,NULL,6,41078,0);
INSERT INTO "django_geo_db_location" VALUES(70152,NULL,'Philo, CA',28781,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70153,NULL,'Philo, CA 95466',28781,222,NULL,6,41079,0);
INSERT INTO "django_geo_db_location" VALUES(70154,NULL,'Point Arena, CA',28782,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70155,NULL,'Point Arena, CA 95468',28782,222,NULL,6,41080,0);
INSERT INTO "django_geo_db_location" VALUES(70156,NULL,'Potter Valley, CA',28783,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70157,NULL,'Potter Valley, CA 95469',28783,222,NULL,6,41081,0);
INSERT INTO "django_geo_db_location" VALUES(70158,NULL,'Redwood Valley, CA',28784,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70159,NULL,'Redwood Valley, CA 95470',28784,222,NULL,6,41082,0);
INSERT INTO "django_geo_db_location" VALUES(70160,NULL,'Rio Nido, CA',28785,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70161,NULL,'Rio Nido, CA 95471',28785,222,NULL,6,41083,0);
INSERT INTO "django_geo_db_location" VALUES(70162,NULL,'Sebastopol, CA',28786,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70163,NULL,'Sebastopol, CA 95472',28786,222,NULL,6,41084,0);
INSERT INTO "django_geo_db_location" VALUES(70164,NULL,'Sebastopol, CA 95473',28786,222,NULL,6,41085,0);
INSERT INTO "django_geo_db_location" VALUES(70165,NULL,'Sonoma, CA',28787,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70166,NULL,'Sonoma, CA 95476',28787,222,NULL,6,41086,0);
INSERT INTO "django_geo_db_location" VALUES(70167,NULL,'Stewarts Point, CA',28788,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70168,NULL,'Stewarts Point, CA 95480',28788,222,NULL,6,41087,0);
INSERT INTO "django_geo_db_location" VALUES(70169,NULL,'Talmage, CA',28789,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70170,NULL,'Talmage, CA 95481',28789,222,NULL,6,41088,0);
INSERT INTO "django_geo_db_location" VALUES(70171,NULL,'Ukiah, CA',28790,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70172,NULL,'Ukiah, CA 95482',28790,222,NULL,6,41089,0);
INSERT INTO "django_geo_db_location" VALUES(70173,NULL,'Upper Lake, CA',28791,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70174,NULL,'Upper Lake, CA 95485',28791,222,NULL,6,41090,0);
INSERT INTO "django_geo_db_location" VALUES(70175,NULL,'Villa Grande, CA',28792,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70176,NULL,'Villa Grande, CA 95486',28792,222,NULL,6,41091,0);
INSERT INTO "django_geo_db_location" VALUES(70177,NULL,'Vineburg, CA',28793,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70178,NULL,'Vineburg, CA 95487',28793,222,NULL,6,41092,0);
INSERT INTO "django_geo_db_location" VALUES(70179,NULL,'Westport, CA',28794,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70180,NULL,'Westport, CA 95488',28794,222,NULL,6,41093,0);
INSERT INTO "django_geo_db_location" VALUES(70181,NULL,'Willits, CA',28795,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70182,NULL,'Willits, CA 95490',28795,222,NULL,6,41094,0);
INSERT INTO "django_geo_db_location" VALUES(70183,NULL,'Windsor, CA',28796,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70184,NULL,'Windsor, CA 95492',28796,222,NULL,6,41095,0);
INSERT INTO "django_geo_db_location" VALUES(70185,NULL,'Witter Springs, CA',28797,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70186,NULL,'Witter Springs, CA 95493',28797,222,NULL,6,41096,0);
INSERT INTO "django_geo_db_location" VALUES(70187,NULL,'Yorkville, CA',28798,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70188,NULL,'Yorkville, CA 95494',28798,222,NULL,6,41097,0);
INSERT INTO "django_geo_db_location" VALUES(70189,NULL,'The Sea Ranch, CA',28799,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70190,NULL,'The Sea Ranch, CA 95497',28799,222,NULL,6,41098,0);
INSERT INTO "django_geo_db_location" VALUES(70191,NULL,'Eureka, CA',28800,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70192,NULL,'Eureka, CA 95501',28800,222,NULL,6,41099,0);
INSERT INTO "django_geo_db_location" VALUES(70193,NULL,'Eureka, CA 95502',28800,222,NULL,6,41100,0);
INSERT INTO "django_geo_db_location" VALUES(70194,NULL,'Eureka, CA 95503',28800,222,NULL,6,41101,0);
INSERT INTO "django_geo_db_location" VALUES(70195,NULL,'Alderpoint, CA',28801,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70196,NULL,'Alderpoint, CA 95511',28801,222,NULL,6,41102,0);
INSERT INTO "django_geo_db_location" VALUES(70197,NULL,'Blocksburg, CA',28802,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70198,NULL,'Blocksburg, CA 95514',28802,222,NULL,6,41103,0);
INSERT INTO "django_geo_db_location" VALUES(70199,NULL,'Diamond Springs, CA',28803,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70200,NULL,'Diamond Springs, CA 95517',28803,222,NULL,6,41104,0);
INSERT INTO "django_geo_db_location" VALUES(70201,NULL,'Arcata, CA',28804,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70202,NULL,'Arcata, CA 95518',28804,222,NULL,6,41105,0);
INSERT INTO "django_geo_db_location" VALUES(70203,NULL,'Mckinleyville, CA',28805,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70204,NULL,'Mckinleyville, CA 95519',28805,222,NULL,6,41106,0);
INSERT INTO "django_geo_db_location" VALUES(70205,NULL,'Arcata, CA 95521',28804,222,NULL,6,41107,0);
INSERT INTO "django_geo_db_location" VALUES(70206,NULL,'Arcata, CA 95522',28804,222,NULL,6,41108,0);
INSERT INTO "django_geo_db_location" VALUES(70207,NULL,'Bayside, CA',28806,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70208,NULL,'Bayside, CA 95524',28806,222,NULL,6,41109,0);
INSERT INTO "django_geo_db_location" VALUES(70209,NULL,'Blue Lake, CA',28807,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70210,NULL,'Blue Lake, CA 95525',28807,222,NULL,6,41110,0);
INSERT INTO "django_geo_db_location" VALUES(70211,NULL,'Bridgeville, CA',28808,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70212,NULL,'Bridgeville, CA 95526',28808,222,NULL,6,41111,0);
INSERT INTO "django_geo_db_location" VALUES(70213,NULL,'Burnt Ranch, CA',28809,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70214,NULL,'Burnt Ranch, CA 95527',28809,222,NULL,6,41112,0);
INSERT INTO "django_geo_db_location" VALUES(70215,NULL,'Carlotta, CA',28810,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70216,NULL,'Carlotta, CA 95528',28810,222,NULL,6,41113,0);
INSERT INTO "django_geo_db_location" VALUES(70217,NULL,'Crescent City, CA',28811,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70218,NULL,'Crescent City, CA 95531',28811,222,NULL,6,41114,0);
INSERT INTO "django_geo_db_location" VALUES(70219,NULL,'Crescent City, CA 95532',28811,222,NULL,6,41115,0);
INSERT INTO "django_geo_db_location" VALUES(70220,NULL,'Cutten, CA',28812,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70221,NULL,'Cutten, CA 95534',28812,222,NULL,6,41116,0);
INSERT INTO "django_geo_db_location" VALUES(70222,NULL,'Ferndale, CA',28813,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70223,NULL,'Ferndale, CA 95536',28813,222,NULL,6,41117,0);
INSERT INTO "django_geo_db_location" VALUES(70224,NULL,'Fields Landing, CA',28814,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70225,NULL,'Fields Landing, CA 95537',28814,222,NULL,6,41118,0);
INSERT INTO "django_geo_db_location" VALUES(70226,NULL,'Fort Dick, CA',28815,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70227,NULL,'Fort Dick, CA 95538',28815,222,NULL,6,41119,0);
INSERT INTO "django_geo_db_location" VALUES(70228,NULL,'Fortuna, CA',28816,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70229,NULL,'Fortuna, CA 95540',28816,222,NULL,6,41120,0);
INSERT INTO "django_geo_db_location" VALUES(70230,NULL,'Garberville, CA',28817,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70231,NULL,'Garberville, CA 95542',28817,222,NULL,6,41121,0);
INSERT INTO "django_geo_db_location" VALUES(70232,NULL,'Gasquet, CA',28818,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70233,NULL,'Gasquet, CA 95543',28818,222,NULL,6,41122,0);
INSERT INTO "django_geo_db_location" VALUES(70234,NULL,'Honeydew, CA',28819,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70235,NULL,'Honeydew, CA 95545',28819,222,NULL,6,41123,0);
INSERT INTO "django_geo_db_location" VALUES(70236,NULL,'Hoopa, CA',28820,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70237,NULL,'Hoopa, CA 95546',28820,222,NULL,6,41124,0);
INSERT INTO "django_geo_db_location" VALUES(70238,NULL,'Hydesville, CA',28821,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70239,NULL,'Hydesville, CA 95547',28821,222,NULL,6,41125,0);
INSERT INTO "django_geo_db_location" VALUES(70240,NULL,'Klamath, CA',28822,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70241,NULL,'Klamath, CA 95548',28822,222,NULL,6,41126,0);
INSERT INTO "django_geo_db_location" VALUES(70242,NULL,'Kneeland, CA',28823,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70243,NULL,'Kneeland, CA 95549',28823,222,NULL,6,41127,0);
INSERT INTO "django_geo_db_location" VALUES(70244,NULL,'Korbel, CA',28824,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70245,NULL,'Korbel, CA 95550',28824,222,NULL,6,41128,0);
INSERT INTO "django_geo_db_location" VALUES(70246,NULL,'Loleta, CA',28825,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70247,NULL,'Loleta, CA 95551',28825,222,NULL,6,41129,0);
INSERT INTO "django_geo_db_location" VALUES(70248,NULL,'Mad River, CA',28826,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70249,NULL,'Mad River, CA 95552',28826,222,NULL,6,41130,0);
INSERT INTO "django_geo_db_location" VALUES(70250,NULL,'Miranda, CA',28827,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70251,NULL,'Miranda, CA 95553',28827,222,NULL,6,41131,0);
INSERT INTO "django_geo_db_location" VALUES(70252,NULL,'Myers Flat, CA',28828,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70253,NULL,'Myers Flat, CA 95554',28828,222,NULL,6,41132,0);
INSERT INTO "django_geo_db_location" VALUES(70254,NULL,'Orick, CA',28829,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70255,NULL,'Orick, CA 95555',28829,222,NULL,6,41133,0);
INSERT INTO "django_geo_db_location" VALUES(70256,NULL,'Orleans, CA',28830,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70257,NULL,'Orleans, CA 95556',28830,222,NULL,6,41134,0);
INSERT INTO "django_geo_db_location" VALUES(70258,NULL,'Petrolia, CA',28831,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70259,NULL,'Petrolia, CA 95558',28831,222,NULL,6,41135,0);
INSERT INTO "django_geo_db_location" VALUES(70260,NULL,'Phillipsville, CA',28832,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70261,NULL,'Phillipsville, CA 95559',28832,222,NULL,6,41136,0);
INSERT INTO "django_geo_db_location" VALUES(70262,NULL,'Redway, CA',28833,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70263,NULL,'Redway, CA 95560',28833,222,NULL,6,41137,0);
INSERT INTO "django_geo_db_location" VALUES(70264,NULL,'Rio Dell, CA',28834,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70265,NULL,'Rio Dell, CA 95562',28834,222,NULL,6,41138,0);
INSERT INTO "django_geo_db_location" VALUES(70266,NULL,'Salyer, CA',28835,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70267,NULL,'Salyer, CA 95563',28835,222,NULL,6,41139,0);
INSERT INTO "django_geo_db_location" VALUES(70268,NULL,'Samoa, CA',28836,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70269,NULL,'Samoa, CA 95564',28836,222,NULL,6,41140,0);
INSERT INTO "django_geo_db_location" VALUES(70270,NULL,'Scotia, CA',28837,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70271,NULL,'Scotia, CA 95565',28837,222,NULL,6,41141,0);
INSERT INTO "django_geo_db_location" VALUES(70272,NULL,'Smith River, CA',28838,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70273,NULL,'Smith River, CA 95567',28838,222,NULL,6,41142,0);
INSERT INTO "django_geo_db_location" VALUES(70274,NULL,'Somes Bar, CA',28839,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70275,NULL,'Somes Bar, CA 95568',28839,222,NULL,6,41143,0);
INSERT INTO "django_geo_db_location" VALUES(70276,NULL,'Redcrest, CA',28840,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70277,NULL,'Redcrest, CA 95569',28840,222,NULL,6,41144,0);
INSERT INTO "django_geo_db_location" VALUES(70278,NULL,'Trinidad, CA',28841,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70279,NULL,'Trinidad, CA 95570',28841,222,NULL,6,41145,0);
INSERT INTO "django_geo_db_location" VALUES(70280,NULL,'Weott, CA',28842,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70281,NULL,'Weott, CA 95571',28842,222,NULL,6,41146,0);
INSERT INTO "django_geo_db_location" VALUES(70282,NULL,'Willow Creek, CA',28843,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70283,NULL,'Willow Creek, CA 95573',28843,222,NULL,6,41147,0);
INSERT INTO "django_geo_db_location" VALUES(70284,NULL,'Leggett, CA',28844,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70285,NULL,'Leggett, CA 95585',28844,222,NULL,6,41148,0);
INSERT INTO "django_geo_db_location" VALUES(70286,NULL,'Piercy, CA',28845,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70287,NULL,'Piercy, CA 95587',28845,222,NULL,6,41149,0);
INSERT INTO "django_geo_db_location" VALUES(70288,NULL,'Whitethorn, CA',28846,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70289,NULL,'Whitethorn, CA 95589',28846,222,NULL,6,41150,0);
INSERT INTO "django_geo_db_location" VALUES(70290,NULL,'Vallejo, CA 95592',28558,222,NULL,6,41151,0);
INSERT INTO "django_geo_db_location" VALUES(70291,NULL,'Zenia, CA',28847,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70292,NULL,'Zenia, CA 95595',28847,222,NULL,6,41152,0);
INSERT INTO "django_geo_db_location" VALUES(70293,NULL,'Amador City, CA',28848,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70294,NULL,'Amador City, CA 95601',28848,222,NULL,6,41153,0);
INSERT INTO "django_geo_db_location" VALUES(70295,NULL,'Auburn, CA',28849,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70296,NULL,'Auburn, CA 95602',28849,222,NULL,6,41154,0);
INSERT INTO "django_geo_db_location" VALUES(70297,NULL,'Auburn, CA 95603',28849,222,NULL,6,41155,0);
INSERT INTO "django_geo_db_location" VALUES(70298,NULL,'Auburn, CA 95604',28849,222,NULL,6,41156,0);
INSERT INTO "django_geo_db_location" VALUES(70299,NULL,'West Sacramento, CA',28850,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70300,NULL,'West Sacramento, CA 95605',28850,222,NULL,6,41157,0);
INSERT INTO "django_geo_db_location" VALUES(70301,NULL,'Brooks, CA',28851,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70302,NULL,'Brooks, CA 95606',28851,222,NULL,6,41158,0);
INSERT INTO "django_geo_db_location" VALUES(70303,NULL,'Capay, CA',28852,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70304,NULL,'Capay, CA 95607',28852,222,NULL,6,41159,0);
INSERT INTO "django_geo_db_location" VALUES(70305,NULL,'Carmichael, CA',28853,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70306,NULL,'Carmichael, CA 95608',28853,222,NULL,6,41160,0);
INSERT INTO "django_geo_db_location" VALUES(70307,NULL,'Carmichael, CA 95609',28853,222,NULL,6,41161,0);
INSERT INTO "django_geo_db_location" VALUES(70308,NULL,'Citrus Heights, CA',28854,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70309,NULL,'Citrus Heights, CA 95610',28854,222,NULL,6,41162,0);
INSERT INTO "django_geo_db_location" VALUES(70310,NULL,'Citrus Heights, CA 95611',28854,222,NULL,6,41163,0);
INSERT INTO "django_geo_db_location" VALUES(70311,NULL,'Clarksburg, CA',28855,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70312,NULL,'Clarksburg, CA 95612',28855,222,NULL,6,41164,0);
INSERT INTO "django_geo_db_location" VALUES(70313,NULL,'Coloma, CA',28856,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70314,NULL,'Coloma, CA 95613',28856,222,NULL,6,41165,0);
INSERT INTO "django_geo_db_location" VALUES(70315,NULL,'Cool, CA',28857,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70316,NULL,'Cool, CA 95614',28857,222,NULL,6,41166,0);
INSERT INTO "django_geo_db_location" VALUES(70317,NULL,'Courtland, CA',28858,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70318,NULL,'Courtland, CA 95615',28858,222,NULL,6,41167,0);
INSERT INTO "django_geo_db_location" VALUES(70319,NULL,'Davis, CA',28859,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70320,NULL,'Davis, CA 95616',28859,222,NULL,6,41168,0);
INSERT INTO "django_geo_db_location" VALUES(70321,NULL,'Davis, CA 95617',28859,222,NULL,6,41169,0);
INSERT INTO "django_geo_db_location" VALUES(70322,NULL,'El Macero, CA',28860,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70323,NULL,'El Macero, CA 95618',28860,222,NULL,6,41170,0);
INSERT INTO "django_geo_db_location" VALUES(70324,NULL,'Diamond Springs, CA 95619',28803,222,NULL,6,41171,0);
INSERT INTO "django_geo_db_location" VALUES(70325,NULL,'Dixon, CA',28861,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70326,NULL,'Dixon, CA 95620',28861,222,NULL,6,41172,0);
INSERT INTO "django_geo_db_location" VALUES(70327,NULL,'Citrus Heights, CA 95621',28854,222,NULL,6,41173,0);
INSERT INTO "django_geo_db_location" VALUES(70328,NULL,'El Dorado, CA',28862,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70329,NULL,'El Dorado, CA 95623',28862,222,NULL,6,41174,0);
INSERT INTO "django_geo_db_location" VALUES(70330,NULL,'Elk Grove, CA',28863,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70331,NULL,'Elk Grove, CA 95624',28863,222,NULL,6,41175,0);
INSERT INTO "django_geo_db_location" VALUES(70332,NULL,'Elmira, CA',28864,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70333,NULL,'Elmira, CA 95625',28864,222,NULL,6,41176,0);
INSERT INTO "django_geo_db_location" VALUES(70334,NULL,'Elverta, CA',28865,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70335,NULL,'Elverta, CA 95626',28865,222,NULL,6,41177,0);
INSERT INTO "django_geo_db_location" VALUES(70336,NULL,'Esparto, CA',28866,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70337,NULL,'Esparto, CA 95627',28866,222,NULL,6,41178,0);
INSERT INTO "django_geo_db_location" VALUES(70338,NULL,'Fair Oaks, CA',28867,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70339,NULL,'Fair Oaks, CA 95628',28867,222,NULL,6,41179,0);
INSERT INTO "django_geo_db_location" VALUES(70340,NULL,'Fiddletown, CA',28868,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70341,NULL,'Fiddletown, CA 95629',28868,222,NULL,6,41180,0);
INSERT INTO "django_geo_db_location" VALUES(70342,NULL,'Folsom, CA',28869,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70343,NULL,'Folsom, CA 95630',28869,222,NULL,6,41181,0);
INSERT INTO "django_geo_db_location" VALUES(70344,NULL,'Foresthill, CA',28870,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70345,NULL,'Foresthill, CA 95631',28870,222,NULL,6,41182,0);
INSERT INTO "django_geo_db_location" VALUES(70346,NULL,'Galt, CA',28871,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70347,NULL,'Galt, CA 95632',28871,222,NULL,6,41183,0);
INSERT INTO "django_geo_db_location" VALUES(70348,NULL,'Garden Valley, CA',28872,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70349,NULL,'Garden Valley, CA 95633',28872,222,NULL,6,41184,0);
INSERT INTO "django_geo_db_location" VALUES(70350,NULL,'Georgetown, CA',28873,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70351,NULL,'Georgetown, CA 95634',28873,222,NULL,6,41185,0);
INSERT INTO "django_geo_db_location" VALUES(70352,NULL,'Greenwood, CA',28874,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70353,NULL,'Greenwood, CA 95635',28874,222,NULL,6,41186,0);
INSERT INTO "django_geo_db_location" VALUES(70354,NULL,'Grizzly Flats, CA',28875,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70355,NULL,'Grizzly Flats, CA 95636',28875,222,NULL,6,41187,0);
INSERT INTO "django_geo_db_location" VALUES(70356,NULL,'Guinda, CA',28876,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70357,NULL,'Guinda, CA 95637',28876,222,NULL,6,41188,0);
INSERT INTO "django_geo_db_location" VALUES(70358,NULL,'Herald, CA',28877,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70359,NULL,'Herald, CA 95638',28877,222,NULL,6,41189,0);
INSERT INTO "django_geo_db_location" VALUES(70360,NULL,'Hood, CA',28878,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70361,NULL,'Hood, CA 95639',28878,222,NULL,6,41190,0);
INSERT INTO "django_geo_db_location" VALUES(70362,NULL,'Ione, CA',28879,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70363,NULL,'Ione, CA 95640',28879,222,NULL,6,41191,0);
INSERT INTO "django_geo_db_location" VALUES(70364,NULL,'Isleton, CA',28880,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70365,NULL,'Isleton, CA 95641',28880,222,NULL,6,41192,0);
INSERT INTO "django_geo_db_location" VALUES(70366,NULL,'Jackson, CA',28881,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70367,NULL,'Jackson, CA 95642',28881,222,NULL,6,41193,0);
INSERT INTO "django_geo_db_location" VALUES(70368,NULL,'Kit Carson, CA',28882,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70369,NULL,'Kit Carson, CA 95644',28882,222,NULL,6,41194,0);
INSERT INTO "django_geo_db_location" VALUES(70370,NULL,'Knights Landing, CA',28883,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70371,NULL,'Knights Landing, CA 95645',28883,222,NULL,6,41195,0);
INSERT INTO "django_geo_db_location" VALUES(70372,NULL,'Kirkwood, CA',28884,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70373,NULL,'Kirkwood, CA 95646',28884,222,NULL,6,41196,0);
INSERT INTO "django_geo_db_location" VALUES(70374,NULL,'Lincoln, CA',28885,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70375,NULL,'Lincoln, CA 95648',28885,222,NULL,6,41197,0);
INSERT INTO "django_geo_db_location" VALUES(70376,NULL,'Loomis, CA',28886,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70377,NULL,'Loomis, CA 95650',28886,222,NULL,6,41198,0);
INSERT INTO "django_geo_db_location" VALUES(70378,NULL,'Lotus, CA',28887,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70379,NULL,'Lotus, CA 95651',28887,222,NULL,6,41199,0);
INSERT INTO "django_geo_db_location" VALUES(70380,NULL,'Mcclellan AFB, CA',28888,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70381,NULL,'Mcclellan AFB, CA 95652',28888,222,NULL,6,41200,0);
INSERT INTO "django_geo_db_location" VALUES(70382,NULL,'Madison, CA',28889,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70383,NULL,'Madison, CA 95653',28889,222,NULL,6,41201,0);
INSERT INTO "django_geo_db_location" VALUES(70384,NULL,'Martell, CA',28890,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70385,NULL,'Martell, CA 95654',28890,222,NULL,6,41202,0);
INSERT INTO "django_geo_db_location" VALUES(70386,NULL,'Mather, CA',28891,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70387,NULL,'Mather, CA 95655',28891,222,NULL,6,41203,0);
INSERT INTO "django_geo_db_location" VALUES(70388,NULL,'Mount Aukum, CA',28892,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70389,NULL,'Mount Aukum, CA 95656',28892,222,NULL,6,41204,0);
INSERT INTO "django_geo_db_location" VALUES(70390,NULL,'Newcastle, CA',28893,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70391,NULL,'Newcastle, CA 95658',28893,222,NULL,6,41205,0);
INSERT INTO "django_geo_db_location" VALUES(70392,NULL,'Nicolaus, CA',28894,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70393,NULL,'Nicolaus, CA 95659',28894,222,NULL,6,41206,0);
INSERT INTO "django_geo_db_location" VALUES(70394,NULL,'North Highlands, CA',28895,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70395,NULL,'North Highlands, CA 95660',28895,222,NULL,6,41207,0);
INSERT INTO "django_geo_db_location" VALUES(70396,NULL,'Roseville, CA',28896,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70397,NULL,'Roseville, CA 95661',28896,222,NULL,6,41208,0);
INSERT INTO "django_geo_db_location" VALUES(70398,NULL,'Orangevale, CA',28897,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70399,NULL,'Orangevale, CA 95662',28897,222,NULL,6,41209,0);
INSERT INTO "django_geo_db_location" VALUES(70400,NULL,'Penryn, CA',28898,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70401,NULL,'Penryn, CA 95663',28898,222,NULL,6,41210,0);
INSERT INTO "django_geo_db_location" VALUES(70402,NULL,'Pilot Hill, CA',28899,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70403,NULL,'Pilot Hill, CA 95664',28899,222,NULL,6,41211,0);
INSERT INTO "django_geo_db_location" VALUES(70404,NULL,'Pine Grove, CA',28900,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70405,NULL,'Pine Grove, CA 95665',28900,222,NULL,6,41212,0);
INSERT INTO "django_geo_db_location" VALUES(70406,NULL,'Pioneer, CA',28901,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70407,NULL,'Pioneer, CA 95666',28901,222,NULL,6,41213,0);
INSERT INTO "django_geo_db_location" VALUES(70408,NULL,'Placerville, CA',28902,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70409,NULL,'Placerville, CA 95667',28902,222,NULL,6,41214,0);
INSERT INTO "django_geo_db_location" VALUES(70410,NULL,'Pleasant Grove, CA',28903,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70411,NULL,'Pleasant Grove, CA 95668',28903,222,NULL,6,41215,0);
INSERT INTO "django_geo_db_location" VALUES(70412,NULL,'Plymouth, CA',28904,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70413,NULL,'Plymouth, CA 95669',28904,222,NULL,6,41216,0);
INSERT INTO "django_geo_db_location" VALUES(70414,NULL,'Rancho Cordova, CA',28905,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70415,NULL,'Rancho Cordova, CA 95670',28905,222,NULL,6,41217,0);
INSERT INTO "django_geo_db_location" VALUES(70416,NULL,'Represa, CA',28906,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70417,NULL,'Represa, CA 95671',28906,222,NULL,6,41218,0);
INSERT INTO "django_geo_db_location" VALUES(70418,NULL,'Rescue, CA',28907,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70419,NULL,'Rescue, CA 95672',28907,222,NULL,6,41219,0);
INSERT INTO "django_geo_db_location" VALUES(70420,NULL,'Rio Linda, CA',28908,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70421,NULL,'Rio Linda, CA 95673',28908,222,NULL,6,41220,0);
INSERT INTO "django_geo_db_location" VALUES(70422,NULL,'Rio Oso, CA',28909,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70423,NULL,'Rio Oso, CA 95674',28909,222,NULL,6,41221,0);
INSERT INTO "django_geo_db_location" VALUES(70424,NULL,'River Pines, CA',28910,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70425,NULL,'River Pines, CA 95675',28910,222,NULL,6,41222,0);
INSERT INTO "django_geo_db_location" VALUES(70426,NULL,'Robbins, CA',28911,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70427,NULL,'Robbins, CA 95676',28911,222,NULL,6,41223,0);
INSERT INTO "django_geo_db_location" VALUES(70428,NULL,'Rocklin, CA',28912,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70429,NULL,'Rocklin, CA 95677',28912,222,NULL,6,41224,0);
INSERT INTO "django_geo_db_location" VALUES(70430,NULL,'Roseville, CA 95678',28896,222,NULL,6,41225,0);
INSERT INTO "django_geo_db_location" VALUES(70431,NULL,'Rumsey, CA',28913,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70432,NULL,'Rumsey, CA 95679',28913,222,NULL,6,41226,0);
INSERT INTO "django_geo_db_location" VALUES(70433,NULL,'Ryde, CA',28914,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70434,NULL,'Ryde, CA 95680',28914,222,NULL,6,41227,0);
INSERT INTO "django_geo_db_location" VALUES(70435,NULL,'Sheridan, CA',28915,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70436,NULL,'Sheridan, CA 95681',28915,222,NULL,6,41228,0);
INSERT INTO "django_geo_db_location" VALUES(70437,NULL,'Shingle Springs, CA',28916,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70438,NULL,'Shingle Springs, CA 95682',28916,222,NULL,6,41229,0);
INSERT INTO "django_geo_db_location" VALUES(70439,NULL,'Sloughhouse, CA',28917,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70440,NULL,'Sloughhouse, CA 95683',28917,222,NULL,6,41230,0);
INSERT INTO "django_geo_db_location" VALUES(70441,NULL,'Somerset, CA',28918,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70442,NULL,'Somerset, CA 95684',28918,222,NULL,6,41231,0);
INSERT INTO "django_geo_db_location" VALUES(70443,NULL,'Sutter Creek, CA',28919,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70444,NULL,'Sutter Creek, CA 95685',28919,222,NULL,6,41232,0);
INSERT INTO "django_geo_db_location" VALUES(70445,NULL,'Thornton, CA',28920,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70446,NULL,'Thornton, CA 95686',28920,222,NULL,6,41233,0);
INSERT INTO "django_geo_db_location" VALUES(70447,NULL,'Vacaville, CA',28921,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70448,NULL,'Vacaville, CA 95687',28921,222,NULL,6,41234,0);
INSERT INTO "django_geo_db_location" VALUES(70449,NULL,'Vacaville, CA 95688',28921,222,NULL,6,41235,0);
INSERT INTO "django_geo_db_location" VALUES(70450,NULL,'Volcano, CA',28922,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70451,NULL,'Volcano, CA 95689',28922,222,NULL,6,41236,0);
INSERT INTO "django_geo_db_location" VALUES(70452,NULL,'Walnut Grove, CA',28923,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70453,NULL,'Walnut Grove, CA 95690',28923,222,NULL,6,41237,0);
INSERT INTO "django_geo_db_location" VALUES(70454,NULL,'West Sacramento, CA 95691',28850,222,NULL,6,41238,0);
INSERT INTO "django_geo_db_location" VALUES(70455,NULL,'Wheatland, CA',28924,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70456,NULL,'Wheatland, CA 95692',28924,222,NULL,6,41239,0);
INSERT INTO "django_geo_db_location" VALUES(70457,NULL,'Wilton, CA',28925,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70458,NULL,'Wilton, CA 95693',28925,222,NULL,6,41240,0);
INSERT INTO "django_geo_db_location" VALUES(70459,NULL,'Winters, CA',28926,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70460,NULL,'Winters, CA 95694',28926,222,NULL,6,41241,0);
INSERT INTO "django_geo_db_location" VALUES(70461,NULL,'Woodland, CA',28927,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70462,NULL,'Woodland, CA 95695',28927,222,NULL,6,41242,0);
INSERT INTO "django_geo_db_location" VALUES(70463,NULL,'Vacaville, CA 95696',28921,222,NULL,6,41243,0);
INSERT INTO "django_geo_db_location" VALUES(70464,NULL,'Yolo, CA',28928,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70465,NULL,'Yolo, CA 95697',28928,222,NULL,6,41244,0);
INSERT INTO "django_geo_db_location" VALUES(70466,NULL,'Zamora, CA',28929,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70467,NULL,'Zamora, CA 95698',28929,222,NULL,6,41245,0);
INSERT INTO "django_geo_db_location" VALUES(70468,NULL,'Drytown, CA',28930,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70469,NULL,'Drytown, CA 95699',28930,222,NULL,6,41246,0);
INSERT INTO "django_geo_db_location" VALUES(70470,NULL,'Alta, CA',28931,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70471,NULL,'Alta, CA 95701',28931,222,NULL,6,41247,0);
INSERT INTO "django_geo_db_location" VALUES(70472,NULL,'Applegate, CA',28932,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70473,NULL,'Applegate, CA 95703',28932,222,NULL,6,41248,0);
INSERT INTO "django_geo_db_location" VALUES(70474,NULL,'Camino, CA',28933,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70475,NULL,'Camino, CA 95709',28933,222,NULL,6,41249,0);
INSERT INTO "django_geo_db_location" VALUES(70476,NULL,'Chicago Park, CA',28934,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70477,NULL,'Chicago Park, CA 95712',28934,222,NULL,6,41250,0);
INSERT INTO "django_geo_db_location" VALUES(70478,NULL,'Colfax, CA',28935,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70479,NULL,'Colfax, CA 95713',28935,222,NULL,6,41251,0);
INSERT INTO "django_geo_db_location" VALUES(70480,NULL,'Dutch Flat, CA',28936,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70481,NULL,'Dutch Flat, CA 95714',28936,222,NULL,6,41252,0);
INSERT INTO "django_geo_db_location" VALUES(70482,NULL,'Emigrant Gap, CA',28937,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70483,NULL,'Emigrant Gap, CA 95715',28937,222,NULL,6,41253,0);
INSERT INTO "django_geo_db_location" VALUES(70484,NULL,'Gold Run, CA',28938,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70485,NULL,'Gold Run, CA 95717',28938,222,NULL,6,41254,0);
INSERT INTO "django_geo_db_location" VALUES(70486,NULL,'Kyburz, CA',28939,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70487,NULL,'Kyburz, CA 95720',28939,222,NULL,6,41255,0);
INSERT INTO "django_geo_db_location" VALUES(70488,NULL,'Echo Lake, CA',28940,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70489,NULL,'Echo Lake, CA 95721',28940,222,NULL,6,41256,0);
INSERT INTO "django_geo_db_location" VALUES(70490,NULL,'Meadow Vista, CA',28941,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70491,NULL,'Meadow Vista, CA 95722',28941,222,NULL,6,41257,0);
INSERT INTO "django_geo_db_location" VALUES(70492,NULL,'Norden, CA',28942,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70493,NULL,'Norden, CA 95724',28942,222,NULL,6,41258,0);
INSERT INTO "django_geo_db_location" VALUES(70494,NULL,'Pollock Pines, CA',28943,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70495,NULL,'Pollock Pines, CA 95726',28943,222,NULL,6,41259,0);
INSERT INTO "django_geo_db_location" VALUES(70496,NULL,'Soda Springs, CA',28944,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70497,NULL,'Soda Springs, CA 95728',28944,222,NULL,6,41260,0);
INSERT INTO "django_geo_db_location" VALUES(70498,NULL,'Twin Bridges, CA',28945,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70499,NULL,'Twin Bridges, CA 95735',28945,222,NULL,6,41261,0);
INSERT INTO "django_geo_db_location" VALUES(70500,NULL,'Weimar, CA',28946,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70501,NULL,'Weimar, CA 95736',28946,222,NULL,6,41262,0);
INSERT INTO "django_geo_db_location" VALUES(70502,NULL,'Rancho Cordova, CA 95741',28905,222,NULL,6,41263,0);
INSERT INTO "django_geo_db_location" VALUES(70503,NULL,'Rancho Cordova, CA 95742',28905,222,NULL,6,41264,0);
INSERT INTO "django_geo_db_location" VALUES(70504,NULL,'Rancho Cordova, CA 95743',28905,222,NULL,6,41265,0);
INSERT INTO "django_geo_db_location" VALUES(70505,NULL,'Granite Bay, CA',28947,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70506,NULL,'Granite Bay, CA 95746',28947,222,NULL,6,41266,0);
INSERT INTO "django_geo_db_location" VALUES(70507,NULL,'Roseville, CA 95747',28896,222,NULL,6,41267,0);
INSERT INTO "django_geo_db_location" VALUES(70508,NULL,'San Andreas, CA 95749',28661,222,NULL,6,41268,0);
INSERT INTO "django_geo_db_location" VALUES(70509,NULL,'Elk Grove, CA 95758',28863,222,NULL,6,41269,0);
INSERT INTO "django_geo_db_location" VALUES(70510,NULL,'Elk Grove, CA 95759',28863,222,NULL,6,41270,0);
INSERT INTO "django_geo_db_location" VALUES(70511,NULL,'El Dorado Hills, CA',28948,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70512,NULL,'El Dorado Hills, CA 95762',28948,222,NULL,6,41271,0);
INSERT INTO "django_geo_db_location" VALUES(70513,NULL,'Folsom, CA 95763',28869,222,NULL,6,41272,0);
INSERT INTO "django_geo_db_location" VALUES(70514,NULL,'Rocklin, CA 95765',28912,222,NULL,6,41273,0);
INSERT INTO "django_geo_db_location" VALUES(70515,NULL,'Spring Garden, CA',28949,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70516,NULL,'Spring Garden, CA 95771',28949,222,NULL,6,41274,0);
INSERT INTO "django_geo_db_location" VALUES(70517,NULL,'Woodland, CA 95776',28927,222,NULL,6,41275,0);
INSERT INTO "django_geo_db_location" VALUES(70518,NULL,'West Sacramento, CA 95798',28850,222,NULL,6,41276,0);
INSERT INTO "django_geo_db_location" VALUES(70519,NULL,'West Sacramento, CA 95799',28850,222,NULL,6,41277,0);
INSERT INTO "django_geo_db_location" VALUES(70520,NULL,'Sacramento, CA 95812',28501,222,NULL,6,41278,0);
INSERT INTO "django_geo_db_location" VALUES(70521,NULL,'Sacramento, CA 95813',28501,222,NULL,6,41279,0);
INSERT INTO "django_geo_db_location" VALUES(70522,NULL,'Sacramento, CA 95814',28501,222,NULL,6,41280,0);
INSERT INTO "django_geo_db_location" VALUES(70523,NULL,'Sacramento, CA 95815',28501,222,NULL,6,41281,0);
INSERT INTO "django_geo_db_location" VALUES(70524,NULL,'Sacramento, CA 95816',28501,222,NULL,6,41282,0);
INSERT INTO "django_geo_db_location" VALUES(70525,NULL,'Sacramento, CA 95817',28501,222,NULL,6,41283,0);
INSERT INTO "django_geo_db_location" VALUES(70526,NULL,'Sacramento, CA 95818',28501,222,NULL,6,41284,0);
INSERT INTO "django_geo_db_location" VALUES(70527,NULL,'Sacramento, CA 95819',28501,222,NULL,6,41285,0);
INSERT INTO "django_geo_db_location" VALUES(70528,NULL,'Sacramento, CA 95820',28501,222,NULL,6,41286,0);
INSERT INTO "django_geo_db_location" VALUES(70529,NULL,'Sacramento, CA 95821',28501,222,NULL,6,41287,0);
INSERT INTO "django_geo_db_location" VALUES(70530,NULL,'Sacramento, CA 95822',28501,222,NULL,6,41288,0);
INSERT INTO "django_geo_db_location" VALUES(70531,NULL,'Sacramento, CA 95823',28501,222,NULL,6,41289,0);
INSERT INTO "django_geo_db_location" VALUES(70532,NULL,'Sacramento, CA 95824',28501,222,NULL,6,41290,0);
INSERT INTO "django_geo_db_location" VALUES(70533,NULL,'Sacramento, CA 95825',28501,222,NULL,6,41291,0);
INSERT INTO "django_geo_db_location" VALUES(70534,NULL,'Sacramento, CA 95826',28501,222,NULL,6,41292,0);
INSERT INTO "django_geo_db_location" VALUES(70535,NULL,'Sacramento, CA 95827',28501,222,NULL,6,41293,0);
INSERT INTO "django_geo_db_location" VALUES(70536,NULL,'Sacramento, CA 95828',28501,222,NULL,6,41294,0);
INSERT INTO "django_geo_db_location" VALUES(70537,NULL,'Sacramento, CA 95829',28501,222,NULL,6,41295,0);
INSERT INTO "django_geo_db_location" VALUES(70538,NULL,'Sacramento, CA 95830',28501,222,NULL,6,41296,0);
INSERT INTO "django_geo_db_location" VALUES(70539,NULL,'Sacramento, CA 95831',28501,222,NULL,6,41297,0);
INSERT INTO "django_geo_db_location" VALUES(70540,NULL,'Sacramento, CA 95832',28501,222,NULL,6,41298,0);
INSERT INTO "django_geo_db_location" VALUES(70541,NULL,'Sacramento, CA 95833',28501,222,NULL,6,41299,0);
INSERT INTO "django_geo_db_location" VALUES(70542,NULL,'Sacramento, CA 95834',28501,222,NULL,6,41300,0);
INSERT INTO "django_geo_db_location" VALUES(70543,NULL,'Sacramento, CA 95835',28501,222,NULL,6,41301,0);
INSERT INTO "django_geo_db_location" VALUES(70544,NULL,'Sacramento, CA 95836',28501,222,NULL,6,41302,0);
INSERT INTO "django_geo_db_location" VALUES(70545,NULL,'Sacramento, CA 95837',28501,222,NULL,6,41303,0);
INSERT INTO "django_geo_db_location" VALUES(70546,NULL,'Sacramento, CA 95838',28501,222,NULL,6,41304,0);
INSERT INTO "django_geo_db_location" VALUES(70547,NULL,'Sacramento, CA 95840',28501,222,NULL,6,41305,0);
INSERT INTO "django_geo_db_location" VALUES(70548,NULL,'Sacramento, CA 95841',28501,222,NULL,6,41306,0);
INSERT INTO "django_geo_db_location" VALUES(70549,NULL,'Sacramento, CA 95842',28501,222,NULL,6,41307,0);
INSERT INTO "django_geo_db_location" VALUES(70550,NULL,'Antelope, CA',28950,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70551,NULL,'Antelope, CA 95843',28950,222,NULL,6,41308,0);
INSERT INTO "django_geo_db_location" VALUES(70552,NULL,'Sacramento, CA 95851',28501,222,NULL,6,41309,0);
INSERT INTO "django_geo_db_location" VALUES(70553,NULL,'Sacramento, CA 95852',28501,222,NULL,6,41310,0);
INSERT INTO "django_geo_db_location" VALUES(70554,NULL,'Sacramento, CA 95853',28501,222,NULL,6,41311,0);
INSERT INTO "django_geo_db_location" VALUES(70555,NULL,'Sacramento, CA 95857',28501,222,NULL,6,41312,0);
INSERT INTO "django_geo_db_location" VALUES(70556,NULL,'Sacramento, CA 95860',28501,222,NULL,6,41313,0);
INSERT INTO "django_geo_db_location" VALUES(70557,NULL,'Sacramento, CA 95864',28501,222,NULL,6,41314,0);
INSERT INTO "django_geo_db_location" VALUES(70558,NULL,'Sacramento, CA 95865',28501,222,NULL,6,41315,0);
INSERT INTO "django_geo_db_location" VALUES(70559,NULL,'Sacramento, CA 95866',28501,222,NULL,6,41316,0);
INSERT INTO "django_geo_db_location" VALUES(70560,NULL,'Sacramento, CA 95867',28501,222,NULL,6,41317,0);
INSERT INTO "django_geo_db_location" VALUES(70561,NULL,'Sacramento, CA 95873',28501,222,NULL,6,41318,0);
INSERT INTO "django_geo_db_location" VALUES(70562,NULL,'Sacramento, CA 95887',28501,222,NULL,6,41319,0);
INSERT INTO "django_geo_db_location" VALUES(70563,NULL,'Sacramento, CA 95894',28501,222,NULL,6,41320,0);
INSERT INTO "django_geo_db_location" VALUES(70564,NULL,'Sacramento, CA 95899',28501,222,NULL,6,41321,0);
INSERT INTO "django_geo_db_location" VALUES(70565,NULL,'Marysville, CA',28951,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70566,NULL,'Marysville, CA 95901',28951,222,NULL,6,41322,0);
INSERT INTO "django_geo_db_location" VALUES(70567,NULL,'Beale AFB, CA',28952,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70568,NULL,'Beale AFB, CA 95903',28952,222,NULL,6,41323,0);
INSERT INTO "django_geo_db_location" VALUES(70569,NULL,'Alleghany, CA',28953,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70570,NULL,'Alleghany, CA 95910',28953,222,NULL,6,41324,0);
INSERT INTO "django_geo_db_location" VALUES(70571,NULL,'Arbuckle, CA',28954,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70572,NULL,'Arbuckle, CA 95912',28954,222,NULL,6,41325,0);
INSERT INTO "django_geo_db_location" VALUES(70573,NULL,'Artois, CA',28955,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70574,NULL,'Artois, CA 95913',28955,222,NULL,6,41326,0);
INSERT INTO "django_geo_db_location" VALUES(70575,NULL,'Bangor, CA',28956,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70576,NULL,'Bangor, CA 95914',28956,222,NULL,6,41327,0);
INSERT INTO "django_geo_db_location" VALUES(70577,NULL,'Belden, CA',28957,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70578,NULL,'Belden, CA 95915',28957,222,NULL,6,41328,0);
INSERT INTO "django_geo_db_location" VALUES(70579,NULL,'Berry Creek, CA',28958,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70580,NULL,'Berry Creek, CA 95916',28958,222,NULL,6,41329,0);
INSERT INTO "django_geo_db_location" VALUES(70581,NULL,'Biggs, CA',28959,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70582,NULL,'Biggs, CA 95917',28959,222,NULL,6,41330,0);
INSERT INTO "django_geo_db_location" VALUES(70583,NULL,'Browns Valley, CA',28960,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70584,NULL,'Browns Valley, CA 95918',28960,222,NULL,6,41331,0);
INSERT INTO "django_geo_db_location" VALUES(70585,NULL,'Brownsville, CA',28961,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70586,NULL,'Brownsville, CA 95919',28961,222,NULL,6,41332,0);
INSERT INTO "django_geo_db_location" VALUES(70587,NULL,'Butte City, CA',28962,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70588,NULL,'Butte City, CA 95920',28962,222,NULL,6,41333,0);
INSERT INTO "django_geo_db_location" VALUES(70589,NULL,'Camptonville, CA',28963,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70590,NULL,'Camptonville, CA 95922',28963,222,NULL,6,41334,0);
INSERT INTO "django_geo_db_location" VALUES(70591,NULL,'Canyondam, CA',28964,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70592,NULL,'Canyondam, CA 95923',28964,222,NULL,6,41335,0);
INSERT INTO "django_geo_db_location" VALUES(70593,NULL,'Cedar Ridge, CA',28965,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70594,NULL,'Cedar Ridge, CA 95924',28965,222,NULL,6,41336,0);
INSERT INTO "django_geo_db_location" VALUES(70595,NULL,'Challenge, CA',28966,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70596,NULL,'Challenge, CA 95925',28966,222,NULL,6,41337,0);
INSERT INTO "django_geo_db_location" VALUES(70597,NULL,'Chico, CA',28967,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70598,NULL,'Chico, CA 95926',28967,222,NULL,6,41338,0);
INSERT INTO "django_geo_db_location" VALUES(70599,NULL,'Chico, CA 95927',28967,222,NULL,6,41339,0);
INSERT INTO "django_geo_db_location" VALUES(70600,NULL,'Chico, CA 95928',28967,222,NULL,6,41340,0);
INSERT INTO "django_geo_db_location" VALUES(70601,NULL,'Chico, CA 95929',28967,222,NULL,6,41341,0);
INSERT INTO "django_geo_db_location" VALUES(70602,NULL,'Clipper Mills, CA',28968,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70603,NULL,'Clipper Mills, CA 95930',28968,222,NULL,6,41342,0);
INSERT INTO "django_geo_db_location" VALUES(70604,NULL,'College City, CA',28969,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70605,NULL,'College City, CA 95931',28969,222,NULL,6,41343,0);
INSERT INTO "django_geo_db_location" VALUES(70606,NULL,'Colusa, CA',28970,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70607,NULL,'Colusa, CA 95932',28970,222,NULL,6,41344,0);
INSERT INTO "django_geo_db_location" VALUES(70608,NULL,'Crescent Mills, CA',28971,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70609,NULL,'Crescent Mills, CA 95934',28971,222,NULL,6,41345,0);
INSERT INTO "django_geo_db_location" VALUES(70610,NULL,'Dobbins, CA',28972,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70611,NULL,'Dobbins, CA 95935',28972,222,NULL,6,41346,0);
INSERT INTO "django_geo_db_location" VALUES(70612,NULL,'Downieville, CA',28973,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70613,NULL,'Downieville, CA 95936',28973,222,NULL,6,41347,0);
INSERT INTO "django_geo_db_location" VALUES(70614,NULL,'Dunnigan, CA',28974,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70615,NULL,'Dunnigan, CA 95937',28974,222,NULL,6,41348,0);
INSERT INTO "django_geo_db_location" VALUES(70616,NULL,'Durham, CA',28975,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70617,NULL,'Durham, CA 95938',28975,222,NULL,6,41349,0);
INSERT INTO "django_geo_db_location" VALUES(70618,NULL,'Elk Creek, CA',28976,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70619,NULL,'Elk Creek, CA 95939',28976,222,NULL,6,41350,0);
INSERT INTO "django_geo_db_location" VALUES(70620,NULL,'Feather Falls, CA',28977,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70621,NULL,'Feather Falls, CA 95940',28977,222,NULL,6,41351,0);
INSERT INTO "django_geo_db_location" VALUES(70622,NULL,'Forbestown, CA',28978,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70623,NULL,'Forbestown, CA 95941',28978,222,NULL,6,41352,0);
INSERT INTO "django_geo_db_location" VALUES(70624,NULL,'Forest Ranch, CA',28979,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70625,NULL,'Forest Ranch, CA 95942',28979,222,NULL,6,41353,0);
INSERT INTO "django_geo_db_location" VALUES(70626,NULL,'Glenn, CA',28980,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70627,NULL,'Glenn, CA 95943',28980,222,NULL,6,41354,0);
INSERT INTO "django_geo_db_location" VALUES(70628,NULL,'Goodyears Bar, CA',28981,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70629,NULL,'Goodyears Bar, CA 95944',28981,222,NULL,6,41355,0);
INSERT INTO "django_geo_db_location" VALUES(70630,NULL,'Grass Valley, CA',28982,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70631,NULL,'Grass Valley, CA 95945',28982,222,NULL,6,41356,0);
INSERT INTO "django_geo_db_location" VALUES(70632,NULL,'Penn Valley, CA',28983,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70633,NULL,'Penn Valley, CA 95946',28983,222,NULL,6,41357,0);
INSERT INTO "django_geo_db_location" VALUES(70634,NULL,'Greenville, CA',28984,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70635,NULL,'Greenville, CA 95947',28984,222,NULL,6,41358,0);
INSERT INTO "django_geo_db_location" VALUES(70636,NULL,'Gridley, CA',28985,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70637,NULL,'Gridley, CA 95948',28985,222,NULL,6,41359,0);
INSERT INTO "django_geo_db_location" VALUES(70638,NULL,'Grass Valley, CA 95949',28982,222,NULL,6,41360,0);
INSERT INTO "django_geo_db_location" VALUES(70639,NULL,'Grimes, CA',28986,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70640,NULL,'Grimes, CA 95950',28986,222,NULL,6,41361,0);
INSERT INTO "django_geo_db_location" VALUES(70641,NULL,'Hamilton City, CA',28987,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70642,NULL,'Hamilton City, CA 95951',28987,222,NULL,6,41362,0);
INSERT INTO "django_geo_db_location" VALUES(70643,NULL,'Live Oak, CA',28988,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70644,NULL,'Live Oak, CA 95953',28988,222,NULL,6,41363,0);
INSERT INTO "django_geo_db_location" VALUES(70645,NULL,'Magalia, CA',28989,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70646,NULL,'Magalia, CA 95954',28989,222,NULL,6,41364,0);
INSERT INTO "django_geo_db_location" VALUES(70647,NULL,'Maxwell, CA',28990,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70648,NULL,'Maxwell, CA 95955',28990,222,NULL,6,41365,0);
INSERT INTO "django_geo_db_location" VALUES(70649,NULL,'Meadow Valley, CA',28991,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70650,NULL,'Meadow Valley, CA 95956',28991,222,NULL,6,41366,0);
INSERT INTO "django_geo_db_location" VALUES(70651,NULL,'Meridian, CA',28992,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70652,NULL,'Meridian, CA 95957',28992,222,NULL,6,41367,0);
INSERT INTO "django_geo_db_location" VALUES(70653,NULL,'Nelson, CA',28993,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70654,NULL,'Nelson, CA 95958',28993,222,NULL,6,41368,0);
INSERT INTO "django_geo_db_location" VALUES(70655,NULL,'Nevada City, CA',28994,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70656,NULL,'Nevada City, CA 95959',28994,222,NULL,6,41369,0);
INSERT INTO "django_geo_db_location" VALUES(70657,NULL,'North San Juan, CA',28995,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70658,NULL,'North San Juan, CA 95960',28995,222,NULL,6,41370,0);
INSERT INTO "django_geo_db_location" VALUES(70659,NULL,'Olivehurst, CA',28996,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70660,NULL,'Olivehurst, CA 95961',28996,222,NULL,6,41371,0);
INSERT INTO "django_geo_db_location" VALUES(70661,NULL,'Oregon House, CA',28997,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70662,NULL,'Oregon House, CA 95962',28997,222,NULL,6,41372,0);
INSERT INTO "django_geo_db_location" VALUES(70663,NULL,'Orland, CA',28998,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70664,NULL,'Orland, CA 95963',28998,222,NULL,6,41373,0);
INSERT INTO "django_geo_db_location" VALUES(70665,NULL,'Oroville, CA',28999,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70666,NULL,'Oroville, CA 95965',28999,222,NULL,6,41374,0);
INSERT INTO "django_geo_db_location" VALUES(70667,NULL,'Oroville, CA 95966',28999,222,NULL,6,41375,0);
INSERT INTO "django_geo_db_location" VALUES(70668,NULL,'Paradise, CA',29000,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70669,NULL,'Paradise, CA 95967',29000,222,NULL,6,41376,0);
INSERT INTO "django_geo_db_location" VALUES(70670,NULL,'Palermo, CA',29001,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70671,NULL,'Palermo, CA 95968',29001,222,NULL,6,41377,0);
INSERT INTO "django_geo_db_location" VALUES(70672,NULL,'Paradise, CA 95969',29000,222,NULL,6,41378,0);
INSERT INTO "django_geo_db_location" VALUES(70673,NULL,'Princeton, CA',29002,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70674,NULL,'Princeton, CA 95970',29002,222,NULL,6,41379,0);
INSERT INTO "django_geo_db_location" VALUES(70675,NULL,'Quincy, CA',29003,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70676,NULL,'Quincy, CA 95971',29003,222,NULL,6,41380,0);
INSERT INTO "django_geo_db_location" VALUES(70677,NULL,'Rackerby, CA',29004,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70678,NULL,'Rackerby, CA 95972',29004,222,NULL,6,41381,0);
INSERT INTO "django_geo_db_location" VALUES(70679,NULL,'Chico, CA 95973',28967,222,NULL,6,41382,0);
INSERT INTO "django_geo_db_location" VALUES(70680,NULL,'Richvale, CA',29005,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70681,NULL,'Richvale, CA 95974',29005,222,NULL,6,41383,0);
INSERT INTO "django_geo_db_location" VALUES(70682,NULL,'Rough And Ready, CA',29006,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70683,NULL,'Rough And Ready, CA 95975',29006,222,NULL,6,41384,0);
INSERT INTO "django_geo_db_location" VALUES(70684,NULL,'Chico, CA 95976',28967,222,NULL,6,41385,0);
INSERT INTO "django_geo_db_location" VALUES(70685,NULL,'Smartville, CA',29007,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70686,NULL,'Smartville, CA 95977',29007,222,NULL,6,41386,0);
INSERT INTO "django_geo_db_location" VALUES(70687,NULL,'Stirling City, CA',29008,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70688,NULL,'Stirling City, CA 95978',29008,222,NULL,6,41387,0);
INSERT INTO "django_geo_db_location" VALUES(70689,NULL,'Stonyford, CA',29009,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70690,NULL,'Stonyford, CA 95979',29009,222,NULL,6,41388,0);
INSERT INTO "django_geo_db_location" VALUES(70691,NULL,'Storrie, CA',29010,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70692,NULL,'Storrie, CA 95980',29010,222,NULL,6,41389,0);
INSERT INTO "django_geo_db_location" VALUES(70693,NULL,'Strawberry Valley, CA',29011,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70694,NULL,'Strawberry Valley, CA 95981',29011,222,NULL,6,41390,0);
INSERT INTO "django_geo_db_location" VALUES(70695,NULL,'Sutter, CA',29012,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70696,NULL,'Sutter, CA 95982',29012,222,NULL,6,41391,0);
INSERT INTO "django_geo_db_location" VALUES(70697,NULL,'Taylorsville, CA',29013,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70698,NULL,'Taylorsville, CA 95983',29013,222,NULL,6,41392,0);
INSERT INTO "django_geo_db_location" VALUES(70699,NULL,'Twain, CA',29014,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70700,NULL,'Twain, CA 95984',29014,222,NULL,6,41393,0);
INSERT INTO "django_geo_db_location" VALUES(70701,NULL,'Washington, CA',29015,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70702,NULL,'Washington, CA 95986',29015,222,NULL,6,41394,0);
INSERT INTO "django_geo_db_location" VALUES(70703,NULL,'Williams, CA',29016,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70704,NULL,'Williams, CA 95987',29016,222,NULL,6,41395,0);
INSERT INTO "django_geo_db_location" VALUES(70705,NULL,'Willows, CA',29017,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70706,NULL,'Willows, CA 95988',29017,222,NULL,6,41396,0);
INSERT INTO "django_geo_db_location" VALUES(70707,NULL,'Yuba City, CA',29018,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70708,NULL,'Yuba City, CA 95991',29018,222,NULL,6,41397,0);
INSERT INTO "django_geo_db_location" VALUES(70709,NULL,'Yuba City, CA 95992',29018,222,NULL,6,41398,0);
INSERT INTO "django_geo_db_location" VALUES(70710,NULL,'Yuba City, CA 95993',29018,222,NULL,6,41399,0);
INSERT INTO "django_geo_db_location" VALUES(70711,NULL,'Redding, CA',29019,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70712,NULL,'Redding, CA 96001',29019,222,NULL,6,41400,0);
INSERT INTO "django_geo_db_location" VALUES(70713,NULL,'Redding, CA 96002',29019,222,NULL,6,41401,0);
INSERT INTO "django_geo_db_location" VALUES(70714,NULL,'Redding, CA 96003',29019,222,NULL,6,41402,0);
INSERT INTO "django_geo_db_location" VALUES(70715,NULL,'Adin, CA',29020,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70716,NULL,'Adin, CA 96006',29020,222,NULL,6,41403,0);
INSERT INTO "django_geo_db_location" VALUES(70717,NULL,'Anderson, CA',29021,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70718,NULL,'Anderson, CA 96007',29021,222,NULL,6,41404,0);
INSERT INTO "django_geo_db_location" VALUES(70719,NULL,'Bella Vista, CA',29022,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70720,NULL,'Bella Vista, CA 96008',29022,222,NULL,6,41405,0);
INSERT INTO "django_geo_db_location" VALUES(70721,NULL,'Bieber, CA',29023,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70722,NULL,'Bieber, CA 96009',29023,222,NULL,6,41406,0);
INSERT INTO "django_geo_db_location" VALUES(70723,NULL,'Big Bar, CA',29024,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70724,NULL,'Big Bar, CA 96010',29024,222,NULL,6,41407,0);
INSERT INTO "django_geo_db_location" VALUES(70725,NULL,'Big Bend, CA',29025,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70726,NULL,'Big Bend, CA 96011',29025,222,NULL,6,41408,0);
INSERT INTO "django_geo_db_location" VALUES(70727,NULL,'Burney, CA',29026,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70728,NULL,'Burney, CA 96013',29026,222,NULL,6,41409,0);
INSERT INTO "django_geo_db_location" VALUES(70729,NULL,'Callahan, CA',29027,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70730,NULL,'Callahan, CA 96014',29027,222,NULL,6,41410,0);
INSERT INTO "django_geo_db_location" VALUES(70731,NULL,'Canby, CA',29028,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70732,NULL,'Canby, CA 96015',29028,222,NULL,6,41411,0);
INSERT INTO "django_geo_db_location" VALUES(70733,NULL,'Cassel, CA',29029,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70734,NULL,'Cassel, CA 96016',29029,222,NULL,6,41412,0);
INSERT INTO "django_geo_db_location" VALUES(70735,NULL,'Castella, CA',29030,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70736,NULL,'Castella, CA 96017',29030,222,NULL,6,41413,0);
INSERT INTO "django_geo_db_location" VALUES(70737,NULL,'Shasta Lake, CA',29031,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70738,NULL,'Shasta Lake, CA 96019',29031,222,NULL,6,41414,0);
INSERT INTO "django_geo_db_location" VALUES(70739,NULL,'Chester, CA',29032,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70740,NULL,'Chester, CA 96020',29032,222,NULL,6,41415,0);
INSERT INTO "django_geo_db_location" VALUES(70741,NULL,'Corning, CA',29033,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70742,NULL,'Corning, CA 96021',29033,222,NULL,6,41416,0);
INSERT INTO "django_geo_db_location" VALUES(70743,NULL,'Cottonwood, CA',29034,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70744,NULL,'Cottonwood, CA 96022',29034,222,NULL,6,41417,0);
INSERT INTO "django_geo_db_location" VALUES(70745,NULL,'Dorris, CA',29035,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70746,NULL,'Dorris, CA 96023',29035,222,NULL,6,41418,0);
INSERT INTO "django_geo_db_location" VALUES(70747,NULL,'Douglas City, CA',29036,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70748,NULL,'Douglas City, CA 96024',29036,222,NULL,6,41419,0);
INSERT INTO "django_geo_db_location" VALUES(70749,NULL,'Dunsmuir, CA',29037,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70750,NULL,'Dunsmuir, CA 96025',29037,222,NULL,6,41420,0);
INSERT INTO "django_geo_db_location" VALUES(70751,NULL,'Etna, CA',29038,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70752,NULL,'Etna, CA 96027',29038,222,NULL,6,41421,0);
INSERT INTO "django_geo_db_location" VALUES(70753,NULL,'Fall River Mills, CA',29039,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70754,NULL,'Fall River Mills, CA 96028',29039,222,NULL,6,41422,0);
INSERT INTO "django_geo_db_location" VALUES(70755,NULL,'Flournoy, CA',29040,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70756,NULL,'Flournoy, CA 96029',29040,222,NULL,6,41423,0);
INSERT INTO "django_geo_db_location" VALUES(70757,NULL,'Forks Of Salmon, CA',29041,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70758,NULL,'Forks Of Salmon, CA 96031',29041,222,NULL,6,41424,0);
INSERT INTO "django_geo_db_location" VALUES(70759,NULL,'Fort Jones, CA',29042,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70760,NULL,'Fort Jones, CA 96032',29042,222,NULL,6,41425,0);
INSERT INTO "django_geo_db_location" VALUES(70761,NULL,'French Gulch, CA',29043,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70762,NULL,'French Gulch, CA 96033',29043,222,NULL,6,41426,0);
INSERT INTO "django_geo_db_location" VALUES(70763,NULL,'Gazelle, CA',29044,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70764,NULL,'Gazelle, CA 96034',29044,222,NULL,6,41427,0);
INSERT INTO "django_geo_db_location" VALUES(70765,NULL,'Gerber, CA',29045,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70766,NULL,'Gerber, CA 96035',29045,222,NULL,6,41428,0);
INSERT INTO "django_geo_db_location" VALUES(70767,NULL,'Greenview, CA',29046,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70768,NULL,'Greenview, CA 96037',29046,222,NULL,6,41429,0);
INSERT INTO "django_geo_db_location" VALUES(70769,NULL,'Grenada, CA',29047,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70770,NULL,'Grenada, CA 96038',29047,222,NULL,6,41430,0);
INSERT INTO "django_geo_db_location" VALUES(70771,NULL,'Happy Camp, CA',29048,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70772,NULL,'Happy Camp, CA 96039',29048,222,NULL,6,41431,0);
INSERT INTO "django_geo_db_location" VALUES(70773,NULL,'Hat Creek, CA',29049,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70774,NULL,'Hat Creek, CA 96040',29049,222,NULL,6,41432,0);
INSERT INTO "django_geo_db_location" VALUES(70775,NULL,'Hayfork, CA',29050,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70776,NULL,'Hayfork, CA 96041',29050,222,NULL,6,41433,0);
INSERT INTO "django_geo_db_location" VALUES(70777,NULL,'Hornbrook, CA',29051,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70778,NULL,'Hornbrook, CA 96044',29051,222,NULL,6,41434,0);
INSERT INTO "django_geo_db_location" VALUES(70779,NULL,'Hyampom, CA',29052,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70780,NULL,'Hyampom, CA 96046',29052,222,NULL,6,41435,0);
INSERT INTO "django_geo_db_location" VALUES(70781,NULL,'Igo, CA',29053,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70782,NULL,'Igo, CA 96047',29053,222,NULL,6,41436,0);
INSERT INTO "django_geo_db_location" VALUES(70783,NULL,'Junction City, CA',29054,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70784,NULL,'Junction City, CA 96048',29054,222,NULL,6,41437,0);
INSERT INTO "django_geo_db_location" VALUES(70785,NULL,'Redding, CA 96049',29019,222,NULL,6,41438,0);
INSERT INTO "django_geo_db_location" VALUES(70786,NULL,'Klamath River, CA',29055,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70787,NULL,'Klamath River, CA 96050',29055,222,NULL,6,41439,0);
INSERT INTO "django_geo_db_location" VALUES(70788,NULL,'Lakehead, CA',29056,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70789,NULL,'Lakehead, CA 96051',29056,222,NULL,6,41440,0);
INSERT INTO "django_geo_db_location" VALUES(70790,NULL,'Lewiston, CA',29057,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70791,NULL,'Lewiston, CA 96052',29057,222,NULL,6,41441,0);
INSERT INTO "django_geo_db_location" VALUES(70792,NULL,'Mcarthur, CA',29058,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70793,NULL,'Mcarthur, CA 96053',29058,222,NULL,6,41442,0);
INSERT INTO "django_geo_db_location" VALUES(70794,NULL,'Lookout, CA',29059,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70795,NULL,'Lookout, CA 96054',29059,222,NULL,6,41443,0);
INSERT INTO "django_geo_db_location" VALUES(70796,NULL,'Los Molinos, CA',29060,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70797,NULL,'Los Molinos, CA 96055',29060,222,NULL,6,41444,0);
INSERT INTO "django_geo_db_location" VALUES(70798,NULL,'Mcarthur, CA 96056',29058,222,NULL,6,41445,0);
INSERT INTO "django_geo_db_location" VALUES(70799,NULL,'Mccloud, CA',29061,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70800,NULL,'Mccloud, CA 96057',29061,222,NULL,6,41446,0);
INSERT INTO "django_geo_db_location" VALUES(70801,NULL,'Macdoel, CA',29062,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70802,NULL,'Macdoel, CA 96058',29062,222,NULL,6,41447,0);
INSERT INTO "django_geo_db_location" VALUES(70803,NULL,'Manton, CA',29063,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70804,NULL,'Manton, CA 96059',29063,222,NULL,6,41448,0);
INSERT INTO "django_geo_db_location" VALUES(70805,NULL,'Mill Creek, CA',29064,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70806,NULL,'Mill Creek, CA 96061',29064,222,NULL,6,41449,0);
INSERT INTO "django_geo_db_location" VALUES(70807,NULL,'Millville, CA',29065,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70808,NULL,'Millville, CA 96062',29065,222,NULL,6,41450,0);
INSERT INTO "django_geo_db_location" VALUES(70809,NULL,'Mineral, CA',29066,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70810,NULL,'Mineral, CA 96063',29066,222,NULL,6,41451,0);
INSERT INTO "django_geo_db_location" VALUES(70811,NULL,'Montague, CA',29067,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70812,NULL,'Montague, CA 96064',29067,222,NULL,6,41452,0);
INSERT INTO "django_geo_db_location" VALUES(70813,NULL,'Montgomery Creek, CA',29068,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70814,NULL,'Montgomery Creek, CA 96065',29068,222,NULL,6,41453,0);
INSERT INTO "django_geo_db_location" VALUES(70815,NULL,'Mount Shasta, CA',29069,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70816,NULL,'Mount Shasta, CA 96067',29069,222,NULL,6,41454,0);
INSERT INTO "django_geo_db_location" VALUES(70817,NULL,'Nubieber, CA',29070,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70818,NULL,'Nubieber, CA 96068',29070,222,NULL,6,41455,0);
INSERT INTO "django_geo_db_location" VALUES(70819,NULL,'Oak Run, CA',29071,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70820,NULL,'Oak Run, CA 96069',29071,222,NULL,6,41456,0);
INSERT INTO "django_geo_db_location" VALUES(70821,NULL,'Obrien, CA',29072,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70822,NULL,'Obrien, CA 96070',29072,222,NULL,6,41457,0);
INSERT INTO "django_geo_db_location" VALUES(70823,NULL,'Old Station, CA',29073,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70824,NULL,'Old Station, CA 96071',29073,222,NULL,6,41458,0);
INSERT INTO "django_geo_db_location" VALUES(70825,NULL,'Palo Cedro, CA',29074,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70826,NULL,'Palo Cedro, CA 96073',29074,222,NULL,6,41459,0);
INSERT INTO "django_geo_db_location" VALUES(70827,NULL,'Paskenta, CA',29075,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70828,NULL,'Paskenta, CA 96074',29075,222,NULL,6,41460,0);
INSERT INTO "django_geo_db_location" VALUES(70829,NULL,'Paynes Creek, CA',29076,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70830,NULL,'Paynes Creek, CA 96075',29076,222,NULL,6,41461,0);
INSERT INTO "django_geo_db_location" VALUES(70831,NULL,'Platina, CA',29077,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70832,NULL,'Platina, CA 96076',29077,222,NULL,6,41462,0);
INSERT INTO "django_geo_db_location" VALUES(70833,NULL,'Proberta, CA',29078,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70834,NULL,'Proberta, CA 96078',29078,222,NULL,6,41463,0);
INSERT INTO "django_geo_db_location" VALUES(70835,NULL,'Shasta Lake, CA 96079',29031,222,NULL,6,41464,0);
INSERT INTO "django_geo_db_location" VALUES(70836,NULL,'Red Bluff, CA',29079,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70837,NULL,'Red Bluff, CA 96080',29079,222,NULL,6,41465,0);
INSERT INTO "django_geo_db_location" VALUES(70838,NULL,'Round Mountain, CA',29080,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70839,NULL,'Round Mountain, CA 96084',29080,222,NULL,6,41466,0);
INSERT INTO "django_geo_db_location" VALUES(70840,NULL,'Scott Bar, CA',29081,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70841,NULL,'Scott Bar, CA 96085',29081,222,NULL,6,41467,0);
INSERT INTO "django_geo_db_location" VALUES(70842,NULL,'Seiad Valley, CA',29082,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70843,NULL,'Seiad Valley, CA 96086',29082,222,NULL,6,41468,0);
INSERT INTO "django_geo_db_location" VALUES(70844,NULL,'Shasta, CA',29083,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70845,NULL,'Shasta, CA 96087',29083,222,NULL,6,41469,0);
INSERT INTO "django_geo_db_location" VALUES(70846,NULL,'Shingletown, CA',29084,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70847,NULL,'Shingletown, CA 96088',29084,222,NULL,6,41470,0);
INSERT INTO "django_geo_db_location" VALUES(70848,NULL,'Shasta Lake, CA 96089',29031,222,NULL,6,41471,0);
INSERT INTO "django_geo_db_location" VALUES(70849,NULL,'Tehama, CA',29085,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70850,NULL,'Tehama, CA 96090',29085,222,NULL,6,41472,0);
INSERT INTO "django_geo_db_location" VALUES(70851,NULL,'Trinity Center, CA',29086,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70852,NULL,'Trinity Center, CA 96091',29086,222,NULL,6,41473,0);
INSERT INTO "django_geo_db_location" VALUES(70853,NULL,'Vina, CA',29087,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70854,NULL,'Vina, CA 96092',29087,222,NULL,6,41474,0);
INSERT INTO "django_geo_db_location" VALUES(70855,NULL,'Weaverville, CA',29088,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70856,NULL,'Weaverville, CA 96093',29088,222,NULL,6,41475,0);
INSERT INTO "django_geo_db_location" VALUES(70857,NULL,'Weed, CA',29089,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70858,NULL,'Weed, CA 96094',29089,222,NULL,6,41476,0);
INSERT INTO "django_geo_db_location" VALUES(70859,NULL,'Whiskeytown, CA',29090,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70860,NULL,'Whiskeytown, CA 96095',29090,222,NULL,6,41477,0);
INSERT INTO "django_geo_db_location" VALUES(70861,NULL,'Whitmore, CA',29091,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70862,NULL,'Whitmore, CA 96096',29091,222,NULL,6,41478,0);
INSERT INTO "django_geo_db_location" VALUES(70863,NULL,'Yreka, CA',29092,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70864,NULL,'Yreka, CA 96097',29092,222,NULL,6,41479,0);
INSERT INTO "django_geo_db_location" VALUES(70865,NULL,'Redding, CA 96099',29019,222,NULL,6,41480,0);
INSERT INTO "django_geo_db_location" VALUES(70866,NULL,'Alturas, CA',29093,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70867,NULL,'Alturas, CA 96101',29093,222,NULL,6,41481,0);
INSERT INTO "django_geo_db_location" VALUES(70868,NULL,'Blairsden-Graeagle, CA',29094,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70869,NULL,'Blairsden-Graeagle, CA 96103',29094,222,NULL,6,41482,0);
INSERT INTO "django_geo_db_location" VALUES(70870,NULL,'Cedarville, CA',29095,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70871,NULL,'Cedarville, CA 96104',29095,222,NULL,6,41483,0);
INSERT INTO "django_geo_db_location" VALUES(70872,NULL,'Chilcoot, CA',29096,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70873,NULL,'Chilcoot, CA 96105',29096,222,NULL,6,41484,0);
INSERT INTO "django_geo_db_location" VALUES(70874,NULL,'Clio, CA',29097,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70875,NULL,'Clio, CA 96106',29097,222,NULL,6,41485,0);
INSERT INTO "django_geo_db_location" VALUES(70876,NULL,'Coleville, CA',29098,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70877,NULL,'Coleville, CA 96107',29098,222,NULL,6,41486,0);
INSERT INTO "django_geo_db_location" VALUES(70878,NULL,'Davis Creek, CA',29099,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70879,NULL,'Davis Creek, CA 96108',29099,222,NULL,6,41487,0);
INSERT INTO "django_geo_db_location" VALUES(70880,NULL,'Doyle, CA',29100,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70881,NULL,'Doyle, CA 96109',29100,222,NULL,6,41488,0);
INSERT INTO "django_geo_db_location" VALUES(70882,NULL,'Eagleville, CA',29101,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70883,NULL,'Eagleville, CA 96110',29101,222,NULL,6,41489,0);
INSERT INTO "django_geo_db_location" VALUES(70884,NULL,'Floriston, CA',29102,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70885,NULL,'Floriston, CA 96111',29102,222,NULL,6,41490,0);
INSERT INTO "django_geo_db_location" VALUES(70886,NULL,'Fort Bidwell, CA',29103,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70887,NULL,'Fort Bidwell, CA 96112',29103,222,NULL,6,41491,0);
INSERT INTO "django_geo_db_location" VALUES(70888,NULL,'Herlong, CA',29104,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70889,NULL,'Herlong, CA 96113',29104,222,NULL,6,41492,0);
INSERT INTO "django_geo_db_location" VALUES(70890,NULL,'Janesville, CA',29105,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70891,NULL,'Janesville, CA 96114',29105,222,NULL,6,41493,0);
INSERT INTO "django_geo_db_location" VALUES(70892,NULL,'Lake City, CA',29106,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70893,NULL,'Lake City, CA 96115',29106,222,NULL,6,41494,0);
INSERT INTO "django_geo_db_location" VALUES(70894,NULL,'Likely, CA',29107,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70895,NULL,'Likely, CA 96116',29107,222,NULL,6,41495,0);
INSERT INTO "django_geo_db_location" VALUES(70896,NULL,'Litchfield, CA',29108,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70897,NULL,'Litchfield, CA 96117',29108,222,NULL,6,41496,0);
INSERT INTO "django_geo_db_location" VALUES(70898,NULL,'Loyalton, CA',29109,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70899,NULL,'Loyalton, CA 96118',29109,222,NULL,6,41497,0);
INSERT INTO "django_geo_db_location" VALUES(70900,NULL,'Madeline, CA',29110,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70901,NULL,'Madeline, CA 96119',29110,222,NULL,6,41498,0);
INSERT INTO "django_geo_db_location" VALUES(70902,NULL,'Markleeville, CA',29111,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70903,NULL,'Markleeville, CA 96120',29111,222,NULL,6,41499,0);
INSERT INTO "django_geo_db_location" VALUES(70904,NULL,'Milford, CA',29112,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70905,NULL,'Milford, CA 96121',29112,222,NULL,6,41500,0);
INSERT INTO "django_geo_db_location" VALUES(70906,NULL,'Portola, CA',29113,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70907,NULL,'Portola, CA 96122',29113,222,NULL,6,41501,0);
INSERT INTO "django_geo_db_location" VALUES(70908,NULL,'Ravendale, CA',29114,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70909,NULL,'Ravendale, CA 96123',29114,222,NULL,6,41502,0);
INSERT INTO "django_geo_db_location" VALUES(70910,NULL,'Calpine, CA',29115,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70911,NULL,'Calpine, CA 96124',29115,222,NULL,6,41503,0);
INSERT INTO "django_geo_db_location" VALUES(70912,NULL,'Sierra City, CA',29116,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70913,NULL,'Sierra City, CA 96125',29116,222,NULL,6,41504,0);
INSERT INTO "django_geo_db_location" VALUES(70914,NULL,'Sierraville, CA',29117,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70915,NULL,'Sierraville, CA 96126',29117,222,NULL,6,41505,0);
INSERT INTO "django_geo_db_location" VALUES(70916,NULL,'Susanville, CA',29118,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70917,NULL,'Susanville, CA 96127',29118,222,NULL,6,41506,0);
INSERT INTO "django_geo_db_location" VALUES(70918,NULL,'Standish, CA',29119,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70919,NULL,'Standish, CA 96128',29119,222,NULL,6,41507,0);
INSERT INTO "django_geo_db_location" VALUES(70920,NULL,'Beckwourth, CA',29120,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70921,NULL,'Beckwourth, CA 96129',29120,222,NULL,6,41508,0);
INSERT INTO "django_geo_db_location" VALUES(70922,NULL,'Susanville, CA 96130',29118,222,NULL,6,41509,0);
INSERT INTO "django_geo_db_location" VALUES(70923,NULL,'Termo, CA',29121,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70924,NULL,'Termo, CA 96132',29121,222,NULL,6,41510,0);
INSERT INTO "django_geo_db_location" VALUES(70925,NULL,'Topaz, CA',29122,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70926,NULL,'Topaz, CA 96133',29122,222,NULL,6,41511,0);
INSERT INTO "django_geo_db_location" VALUES(70927,NULL,'Tulelake, CA',29123,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70928,NULL,'Tulelake, CA 96134',29123,222,NULL,6,41512,0);
INSERT INTO "django_geo_db_location" VALUES(70929,NULL,'Vinton, CA',29124,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70930,NULL,'Vinton, CA 96135',29124,222,NULL,6,41513,0);
INSERT INTO "django_geo_db_location" VALUES(70931,NULL,'Wendel, CA',29125,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70932,NULL,'Wendel, CA 96136',29125,222,NULL,6,41514,0);
INSERT INTO "django_geo_db_location" VALUES(70933,NULL,'Westwood, CA',29126,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70934,NULL,'Westwood, CA 96137',29126,222,NULL,6,41515,0);
INSERT INTO "django_geo_db_location" VALUES(70935,NULL,'Carnelian Bay, CA',29127,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70936,NULL,'Carnelian Bay, CA 96140',29127,222,NULL,6,41516,0);
INSERT INTO "django_geo_db_location" VALUES(70937,NULL,'Homewood, CA',29128,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70938,NULL,'Homewood, CA 96141',29128,222,NULL,6,41517,0);
INSERT INTO "django_geo_db_location" VALUES(70939,NULL,'Tahoma, CA',29129,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70940,NULL,'Tahoma, CA 96142',29129,222,NULL,6,41518,0);
INSERT INTO "django_geo_db_location" VALUES(70941,NULL,'Kings Beach, CA',29130,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70942,NULL,'Kings Beach, CA 96143',29130,222,NULL,6,41519,0);
INSERT INTO "django_geo_db_location" VALUES(70943,NULL,'Tahoe City, CA',29131,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70944,NULL,'Tahoe City, CA 96145',29131,222,NULL,6,41520,0);
INSERT INTO "django_geo_db_location" VALUES(70945,NULL,'Olympic Valley, CA',29132,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70946,NULL,'Olympic Valley, CA 96146',29132,222,NULL,6,41521,0);
INSERT INTO "django_geo_db_location" VALUES(70947,NULL,'Tahoe Vista, CA',29133,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70948,NULL,'Tahoe Vista, CA 96148',29133,222,NULL,6,41522,0);
INSERT INTO "django_geo_db_location" VALUES(70949,NULL,'South Lake Tahoe, CA',29134,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70950,NULL,'South Lake Tahoe, CA 96150',29134,222,NULL,6,41523,0);
INSERT INTO "django_geo_db_location" VALUES(70951,NULL,'South Lake Tahoe, CA 96151',29134,222,NULL,6,41524,0);
INSERT INTO "django_geo_db_location" VALUES(70952,NULL,'South Lake Tahoe, CA 96152',29134,222,NULL,6,41525,0);
INSERT INTO "django_geo_db_location" VALUES(70953,NULL,'South Lake Tahoe, CA 96154',29134,222,NULL,6,41526,0);
INSERT INTO "django_geo_db_location" VALUES(70954,NULL,'South Lake Tahoe, CA 96155',29134,222,NULL,6,41527,0);
INSERT INTO "django_geo_db_location" VALUES(70955,NULL,'South Lake Tahoe, CA 96156',29134,222,NULL,6,41528,0);
INSERT INTO "django_geo_db_location" VALUES(70956,NULL,'South Lake Tahoe, CA 96157',29134,222,NULL,6,41529,0);
INSERT INTO "django_geo_db_location" VALUES(70957,NULL,'South Lake Tahoe, CA 96158',29134,222,NULL,6,41530,0);
INSERT INTO "django_geo_db_location" VALUES(70958,NULL,'Truckee, CA',29135,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70959,NULL,'Truckee, CA 96160',29135,222,NULL,6,41531,0);
INSERT INTO "django_geo_db_location" VALUES(70960,NULL,'Truckee, CA 96161',29135,222,NULL,6,41532,0);
INSERT INTO "django_geo_db_location" VALUES(70961,NULL,'Truckee, CA 96162',29135,222,NULL,6,41533,0);
INSERT INTO "django_geo_db_location" VALUES(70962,NULL,'Truckee, CA 96163',29135,222,NULL,6,41534,0);
INSERT INTO "django_geo_db_location" VALUES(70963,NULL,'Cottonwood, CA 96222',29034,222,NULL,6,41535,0);
INSERT INTO "django_geo_db_location" VALUES(70964,NULL,'Kawela Bay, HI',29136,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70965,NULL,'Kawela Bay, HI 96371',29136,222,NULL,15,41536,0);
INSERT INTO "django_geo_db_location" VALUES(70966,NULL,'Hawaiian Ocean View, HI',29137,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70967,NULL,'Hawaiian Ocean View, HI 96373',29137,222,NULL,15,41537,0);
INSERT INTO "django_geo_db_location" VALUES(70968,NULL,'Volcano, HI',29138,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70969,NULL,'Volcano, HI 96385',29138,222,NULL,15,41538,0);
INSERT INTO "django_geo_db_location" VALUES(70970,NULL,'Kaneohe, HI',29139,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70971,NULL,'Kaneohe, HI 96477',29139,222,NULL,15,41539,0);
INSERT INTO "django_geo_db_location" VALUES(70972,NULL,'Aiea, HI',29140,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70973,NULL,'Aiea, HI 96701',29140,222,NULL,15,41540,0);
INSERT INTO "django_geo_db_location" VALUES(70974,NULL,'Anahola, HI',29141,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70975,NULL,'Anahola, HI 96703',29141,222,NULL,15,41541,0);
INSERT INTO "django_geo_db_location" VALUES(70976,NULL,'Captain Cook, HI',29142,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70977,NULL,'Captain Cook, HI 96704',29142,222,NULL,15,41542,0);
INSERT INTO "django_geo_db_location" VALUES(70978,NULL,'Eleele, HI',29143,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70979,NULL,'Eleele, HI 96705',29143,222,NULL,15,41543,0);
INSERT INTO "django_geo_db_location" VALUES(70980,NULL,'Ewa Beach, HI',29144,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70981,NULL,'Ewa Beach, HI 96706',29144,222,NULL,15,41544,0);
INSERT INTO "django_geo_db_location" VALUES(70982,NULL,'Kapolei, HI',29145,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70983,NULL,'Kapolei, HI 96707',29145,222,NULL,15,41545,0);
INSERT INTO "django_geo_db_location" VALUES(70984,NULL,'Haiku, HI',29146,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70985,NULL,'Haiku, HI 96708',29146,222,NULL,15,41546,0);
INSERT INTO "django_geo_db_location" VALUES(70986,NULL,'Kapolei, HI 96709',29145,222,NULL,15,41547,0);
INSERT INTO "django_geo_db_location" VALUES(70987,NULL,'Hakalau, HI',29147,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70988,NULL,'Hakalau, HI 96710',29147,222,NULL,15,41548,0);
INSERT INTO "django_geo_db_location" VALUES(70989,NULL,'Haleiwa, HI',29148,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70990,NULL,'Haleiwa, HI 96712',29148,222,NULL,15,41549,0);
INSERT INTO "django_geo_db_location" VALUES(70991,NULL,'Hana, HI',29149,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70992,NULL,'Hana, HI 96713',29149,222,NULL,15,41550,0);
INSERT INTO "django_geo_db_location" VALUES(70993,NULL,'Hanalei, HI',29150,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70994,NULL,'Hanalei, HI 96714',29150,222,NULL,15,41551,0);
INSERT INTO "django_geo_db_location" VALUES(70995,NULL,'Hanamaulu, HI',29151,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70996,NULL,'Hanamaulu, HI 96715',29151,222,NULL,15,41552,0);
INSERT INTO "django_geo_db_location" VALUES(70997,NULL,'Hanapepe, HI',29152,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(70998,NULL,'Hanapepe, HI 96716',29152,222,NULL,15,41553,0);
INSERT INTO "django_geo_db_location" VALUES(70999,NULL,'Hauula, HI',29153,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71000,NULL,'Hauula, HI 96717',29153,222,NULL,15,41554,0);
INSERT INTO "django_geo_db_location" VALUES(71001,NULL,'Hawaii National Park, HI',29154,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71002,NULL,'Hawaii National Park, HI 96718',29154,222,NULL,15,41555,0);
INSERT INTO "django_geo_db_location" VALUES(71003,NULL,'Hawi, HI',29155,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71004,NULL,'Hawi, HI 96719',29155,222,NULL,15,41556,0);
INSERT INTO "django_geo_db_location" VALUES(71005,NULL,'Hilo, HI',29156,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71006,NULL,'Hilo, HI 96720',29156,222,NULL,15,41557,0);
INSERT INTO "django_geo_db_location" VALUES(71007,NULL,'Hilo, HI 96721',29156,222,NULL,15,41558,0);
INSERT INTO "django_geo_db_location" VALUES(71008,NULL,'Princeville, HI',29157,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71009,NULL,'Princeville, HI 96722',29157,222,NULL,15,41559,0);
INSERT INTO "django_geo_db_location" VALUES(71010,NULL,'Holualoa, HI',29158,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71011,NULL,'Holualoa, HI 96725',29158,222,NULL,15,41560,0);
INSERT INTO "django_geo_db_location" VALUES(71012,NULL,'Honaunau, HI',29159,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71013,NULL,'Honaunau, HI 96726',29159,222,NULL,15,41561,0);
INSERT INTO "django_geo_db_location" VALUES(71014,NULL,'Honokaa, HI',29160,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71015,NULL,'Honokaa, HI 96727',29160,222,NULL,15,41562,0);
INSERT INTO "django_geo_db_location" VALUES(71016,NULL,'Honomu, HI',29161,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71017,NULL,'Honomu, HI 96728',29161,222,NULL,15,41563,0);
INSERT INTO "django_geo_db_location" VALUES(71018,NULL,'Hoolehua, HI',29162,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71019,NULL,'Hoolehua, HI 96729',29162,222,NULL,15,41564,0);
INSERT INTO "django_geo_db_location" VALUES(71020,NULL,'Kaaawa, HI',29163,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71021,NULL,'Kaaawa, HI 96730',29163,222,NULL,15,41565,0);
INSERT INTO "django_geo_db_location" VALUES(71022,NULL,'Kahuku, HI',29164,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71023,NULL,'Kahuku, HI 96731',29164,222,NULL,15,41566,0);
INSERT INTO "django_geo_db_location" VALUES(71024,NULL,'Kahului, HI',29165,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71025,NULL,'Kahului, HI 96732',29165,222,NULL,15,41567,0);
INSERT INTO "django_geo_db_location" VALUES(71026,NULL,'Kahului, HI 96733',29165,222,NULL,15,41568,0);
INSERT INTO "django_geo_db_location" VALUES(71027,NULL,'Kailua, HI',29166,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71028,NULL,'Kailua, HI 96734',29166,222,NULL,15,41569,0);
INSERT INTO "django_geo_db_location" VALUES(71029,NULL,'Ocean View, HI',29167,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71030,NULL,'Ocean View, HI 96737',29167,222,NULL,15,41570,0);
INSERT INTO "django_geo_db_location" VALUES(71031,NULL,'Waikoloa, HI',29168,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71032,NULL,'Waikoloa, HI 96738',29168,222,NULL,15,41571,0);
INSERT INTO "django_geo_db_location" VALUES(71033,NULL,'Keauhou, HI',29169,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71034,NULL,'Keauhou, HI 96739',29169,222,NULL,15,41572,0);
INSERT INTO "django_geo_db_location" VALUES(71035,NULL,'Kailua Kona, HI',29170,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71036,NULL,'Kailua Kona, HI 96740',29170,222,NULL,15,41573,0);
INSERT INTO "django_geo_db_location" VALUES(71037,NULL,'Kalaheo, HI',29171,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71038,NULL,'Kalaheo, HI 96741',29171,222,NULL,15,41574,0);
INSERT INTO "django_geo_db_location" VALUES(71039,NULL,'Kalaupapa, HI',29172,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71040,NULL,'Kalaupapa, HI 96742',29172,222,NULL,15,41575,0);
INSERT INTO "django_geo_db_location" VALUES(71041,NULL,'Kamuela, HI',29173,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71042,NULL,'Kamuela, HI 96743',29173,222,NULL,15,41576,0);
INSERT INTO "django_geo_db_location" VALUES(71043,NULL,'Kaneohe, HI 96744',29139,222,NULL,15,41577,0);
INSERT INTO "django_geo_db_location" VALUES(71044,NULL,'Kailua Kona, HI 96745',29170,222,NULL,15,41578,0);
INSERT INTO "django_geo_db_location" VALUES(71045,NULL,'Kapaa, HI',29174,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71046,NULL,'Kapaa, HI 96746',29174,222,NULL,15,41579,0);
INSERT INTO "django_geo_db_location" VALUES(71047,NULL,'Kaumakani, HI',29175,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71048,NULL,'Kaumakani, HI 96747',29175,222,NULL,15,41580,0);
INSERT INTO "django_geo_db_location" VALUES(71049,NULL,'Kaunakakai, HI',29176,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71050,NULL,'Kaunakakai, HI 96748',29176,222,NULL,15,41581,0);
INSERT INTO "django_geo_db_location" VALUES(71051,NULL,'Keaau, HI',29177,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71052,NULL,'Keaau, HI 96749',29177,222,NULL,15,41582,0);
INSERT INTO "django_geo_db_location" VALUES(71053,NULL,'Kealakekua, HI',29178,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71054,NULL,'Kealakekua, HI 96750',29178,222,NULL,15,41583,0);
INSERT INTO "django_geo_db_location" VALUES(71055,NULL,'Kealia, HI',29179,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71056,NULL,'Kealia, HI 96751',29179,222,NULL,15,41584,0);
INSERT INTO "django_geo_db_location" VALUES(71057,NULL,'Kekaha, HI',29180,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71058,NULL,'Kekaha, HI 96752',29180,222,NULL,15,41585,0);
INSERT INTO "django_geo_db_location" VALUES(71059,NULL,'Kihei, HI',29181,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71060,NULL,'Kihei, HI 96753',29181,222,NULL,15,41586,0);
INSERT INTO "django_geo_db_location" VALUES(71061,NULL,'Kilauea, HI',29182,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71062,NULL,'Kilauea, HI 96754',29182,222,NULL,15,41587,0);
INSERT INTO "django_geo_db_location" VALUES(71063,NULL,'Kapaau, HI',29183,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71064,NULL,'Kapaau, HI 96755',29183,222,NULL,15,41588,0);
INSERT INTO "django_geo_db_location" VALUES(71065,NULL,'Koloa, HI',29184,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71066,NULL,'Koloa, HI 96756',29184,222,NULL,15,41589,0);
INSERT INTO "django_geo_db_location" VALUES(71067,NULL,'Kualapuu, HI',29185,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71068,NULL,'Kualapuu, HI 96757',29185,222,NULL,15,41590,0);
INSERT INTO "django_geo_db_location" VALUES(71069,NULL,'Kunia, HI',29186,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71070,NULL,'Kunia, HI 96759',29186,222,NULL,15,41591,0);
INSERT INTO "django_geo_db_location" VALUES(71071,NULL,'Kurtistown, HI',29187,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71072,NULL,'Kurtistown, HI 96760',29187,222,NULL,15,41592,0);
INSERT INTO "django_geo_db_location" VALUES(71073,NULL,'Lahaina, HI',29188,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71074,NULL,'Lahaina, HI 96761',29188,222,NULL,15,41593,0);
INSERT INTO "django_geo_db_location" VALUES(71075,NULL,'Laie, HI',29189,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71076,NULL,'Laie, HI 96762',29189,222,NULL,15,41594,0);
INSERT INTO "django_geo_db_location" VALUES(71077,NULL,'Lanai City, HI',29190,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71078,NULL,'Lanai City, HI 96763',29190,222,NULL,15,41595,0);
INSERT INTO "django_geo_db_location" VALUES(71079,NULL,'Laupahoehoe, HI',29191,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71080,NULL,'Laupahoehoe, HI 96764',29191,222,NULL,15,41596,0);
INSERT INTO "django_geo_db_location" VALUES(71081,NULL,'Lawai, HI',29192,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71082,NULL,'Lawai, HI 96765',29192,222,NULL,15,41597,0);
INSERT INTO "django_geo_db_location" VALUES(71083,NULL,'Lihue, HI',29193,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71084,NULL,'Lihue, HI 96766',29193,222,NULL,15,41598,0);
INSERT INTO "django_geo_db_location" VALUES(71085,NULL,'Lahaina, HI 96767',29188,222,NULL,15,41599,0);
INSERT INTO "django_geo_db_location" VALUES(71086,NULL,'Makawao, HI',29194,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71087,NULL,'Makawao, HI 96768',29194,222,NULL,15,41600,0);
INSERT INTO "django_geo_db_location" VALUES(71088,NULL,'Makaweli, HI',29195,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71089,NULL,'Makaweli, HI 96769',29195,222,NULL,15,41601,0);
INSERT INTO "django_geo_db_location" VALUES(71090,NULL,'Maunaloa, HI',29196,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71091,NULL,'Maunaloa, HI 96770',29196,222,NULL,15,41602,0);
INSERT INTO "django_geo_db_location" VALUES(71092,NULL,'Mountain View, HI',29197,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71093,NULL,'Mountain View, HI 96771',29197,222,NULL,15,41603,0);
INSERT INTO "django_geo_db_location" VALUES(71094,NULL,'Naalehu, HI',29198,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71095,NULL,'Naalehu, HI 96772',29198,222,NULL,15,41604,0);
INSERT INTO "django_geo_db_location" VALUES(71096,NULL,'Ninole, HI',29199,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71097,NULL,'Ninole, HI 96773',29199,222,NULL,15,41605,0);
INSERT INTO "django_geo_db_location" VALUES(71098,NULL,'Ookala, HI',29200,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71099,NULL,'Ookala, HI 96774',29200,222,NULL,15,41606,0);
INSERT INTO "django_geo_db_location" VALUES(71100,NULL,'Paauhau, HI',29201,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71101,NULL,'Paauhau, HI 96775',29201,222,NULL,15,41607,0);
INSERT INTO "django_geo_db_location" VALUES(71102,NULL,'Paauilo, HI',29202,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71103,NULL,'Paauilo, HI 96776',29202,222,NULL,15,41608,0);
INSERT INTO "django_geo_db_location" VALUES(71104,NULL,'Pahala, HI',29203,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71105,NULL,'Pahala, HI 96777',29203,222,NULL,15,41609,0);
INSERT INTO "django_geo_db_location" VALUES(71106,NULL,'Pahoa, HI',29204,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71107,NULL,'Pahoa, HI 96778',29204,222,NULL,15,41610,0);
INSERT INTO "django_geo_db_location" VALUES(71108,NULL,'Paia, HI',29205,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71109,NULL,'Paia, HI 96779',29205,222,NULL,15,41611,0);
INSERT INTO "django_geo_db_location" VALUES(71110,NULL,'Papaaloa, HI',29206,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71111,NULL,'Papaaloa, HI 96780',29206,222,NULL,15,41612,0);
INSERT INTO "django_geo_db_location" VALUES(71112,NULL,'Papaikou, HI',29207,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71113,NULL,'Papaikou, HI 96781',29207,222,NULL,15,41613,0);
INSERT INTO "django_geo_db_location" VALUES(71114,NULL,'Pearl City, HI',29208,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71115,NULL,'Pearl City, HI 96782',29208,222,NULL,15,41614,0);
INSERT INTO "django_geo_db_location" VALUES(71116,NULL,'Pepeekeo, HI',29209,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71117,NULL,'Pepeekeo, HI 96783',29209,222,NULL,15,41615,0);
INSERT INTO "django_geo_db_location" VALUES(71118,NULL,'Puunene, HI',29210,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71119,NULL,'Puunene, HI 96784',29210,222,NULL,15,41616,0);
INSERT INTO "django_geo_db_location" VALUES(71120,NULL,'Volcano, HI 96785',29138,222,NULL,15,41617,0);
INSERT INTO "django_geo_db_location" VALUES(71121,NULL,'Wahiawa, HI',29211,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71122,NULL,'Wahiawa, HI 96786',29211,222,NULL,15,41618,0);
INSERT INTO "django_geo_db_location" VALUES(71123,NULL,'Pukalani, HI',29212,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71124,NULL,'Pukalani, HI 96788',29212,222,NULL,15,41619,0);
INSERT INTO "django_geo_db_location" VALUES(71125,NULL,'Mililani, HI',29213,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71126,NULL,'Mililani, HI 96789',29213,222,NULL,15,41620,0);
INSERT INTO "django_geo_db_location" VALUES(71127,NULL,'Kula, HI',29214,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71128,NULL,'Kula, HI 96790',29214,222,NULL,15,41621,0);
INSERT INTO "django_geo_db_location" VALUES(71129,NULL,'Waialua, HI',29215,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71130,NULL,'Waialua, HI 96791',29215,222,NULL,15,41622,0);
INSERT INTO "django_geo_db_location" VALUES(71131,NULL,'Waianae, HI',29216,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71132,NULL,'Waianae, HI 96792',29216,222,NULL,15,41623,0);
INSERT INTO "django_geo_db_location" VALUES(71133,NULL,'Wailuku, HI',29217,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71134,NULL,'Wailuku, HI 96793',29217,222,NULL,15,41624,0);
INSERT INTO "django_geo_db_location" VALUES(71135,NULL,'Waimanalo, HI',29218,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71136,NULL,'Waimanalo, HI 96795',29218,222,NULL,15,41625,0);
INSERT INTO "django_geo_db_location" VALUES(71137,NULL,'Waimea, HI',29219,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71138,NULL,'Waimea, HI 96796',29219,222,NULL,15,41626,0);
INSERT INTO "django_geo_db_location" VALUES(71139,NULL,'Waipahu, HI',29220,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71140,NULL,'Waipahu, HI 96797',29220,222,NULL,15,41627,0);
INSERT INTO "django_geo_db_location" VALUES(71141,NULL,'Pago Pago, AS',29221,222,NULL,5,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71142,NULL,'Pago Pago, AS 96799',29221,222,NULL,5,41628,0);
INSERT INTO "django_geo_db_location" VALUES(71143,NULL,'Honolulu, HI',29222,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71144,NULL,'Honolulu, HI 96801',29222,222,NULL,15,41629,0);
INSERT INTO "django_geo_db_location" VALUES(71145,NULL,'Honolulu, HI 96802',29222,222,NULL,15,41630,0);
INSERT INTO "django_geo_db_location" VALUES(71146,NULL,'Honolulu, HI 96803',29222,222,NULL,15,41631,0);
INSERT INTO "django_geo_db_location" VALUES(71147,NULL,'Honolulu, HI 96804',29222,222,NULL,15,41632,0);
INSERT INTO "django_geo_db_location" VALUES(71148,NULL,'Honolulu, HI 96805',29222,222,NULL,15,41633,0);
INSERT INTO "django_geo_db_location" VALUES(71149,NULL,'Honolulu, HI 96806',29222,222,NULL,15,41634,0);
INSERT INTO "django_geo_db_location" VALUES(71150,NULL,'Honolulu, HI 96807',29222,222,NULL,15,41635,0);
INSERT INTO "django_geo_db_location" VALUES(71151,NULL,'Honolulu, HI 96808',29222,222,NULL,15,41636,0);
INSERT INTO "django_geo_db_location" VALUES(71152,NULL,'Honolulu, HI 96809',29222,222,NULL,15,41637,0);
INSERT INTO "django_geo_db_location" VALUES(71153,NULL,'Honolulu, HI 96810',29222,222,NULL,15,41638,0);
INSERT INTO "django_geo_db_location" VALUES(71154,NULL,'Honolulu, HI 96811',29222,222,NULL,15,41639,0);
INSERT INTO "django_geo_db_location" VALUES(71155,NULL,'Honolulu, HI 96812',29222,222,NULL,15,41640,0);
INSERT INTO "django_geo_db_location" VALUES(71156,NULL,'Honolulu, HI 96813',29222,222,NULL,15,41641,0);
INSERT INTO "django_geo_db_location" VALUES(71157,NULL,'Honolulu, HI 96814',29222,222,NULL,15,41642,0);
INSERT INTO "django_geo_db_location" VALUES(71158,NULL,'Honolulu, HI 96815',29222,222,NULL,15,41643,0);
INSERT INTO "django_geo_db_location" VALUES(71159,NULL,'Honolulu, HI 96816',29222,222,NULL,15,41644,0);
INSERT INTO "django_geo_db_location" VALUES(71160,NULL,'Honolulu, HI 96817',29222,222,NULL,15,41645,0);
INSERT INTO "django_geo_db_location" VALUES(71161,NULL,'Honolulu, HI 96818',29222,222,NULL,15,41646,0);
INSERT INTO "django_geo_db_location" VALUES(71162,NULL,'Honolulu, HI 96819',29222,222,NULL,15,41647,0);
INSERT INTO "django_geo_db_location" VALUES(71163,NULL,'Honolulu, HI 96820',29222,222,NULL,15,41648,0);
INSERT INTO "django_geo_db_location" VALUES(71164,NULL,'Honolulu, HI 96821',29222,222,NULL,15,41649,0);
INSERT INTO "django_geo_db_location" VALUES(71165,NULL,'Honolulu, HI 96822',29222,222,NULL,15,41650,0);
INSERT INTO "django_geo_db_location" VALUES(71166,NULL,'Honolulu, HI 96823',29222,222,NULL,15,41651,0);
INSERT INTO "django_geo_db_location" VALUES(71167,NULL,'Honolulu, HI 96824',29222,222,NULL,15,41652,0);
INSERT INTO "django_geo_db_location" VALUES(71168,NULL,'Honolulu, HI 96825',29222,222,NULL,15,41653,0);
INSERT INTO "django_geo_db_location" VALUES(71169,NULL,'Honolulu, HI 96826',29222,222,NULL,15,41654,0);
INSERT INTO "django_geo_db_location" VALUES(71170,NULL,'Honolulu, HI 96827',29222,222,NULL,15,41655,0);
INSERT INTO "django_geo_db_location" VALUES(71171,NULL,'Honolulu, HI 96828',29222,222,NULL,15,41656,0);
INSERT INTO "django_geo_db_location" VALUES(71172,NULL,'Honolulu, HI 96830',29222,222,NULL,15,41657,0);
INSERT INTO "django_geo_db_location" VALUES(71173,NULL,'Honolulu, HI 96835',29222,222,NULL,15,41658,0);
INSERT INTO "django_geo_db_location" VALUES(71174,NULL,'Honolulu, HI 96836',29222,222,NULL,15,41659,0);
INSERT INTO "django_geo_db_location" VALUES(71175,NULL,'Honolulu, HI 96837',29222,222,NULL,15,41660,0);
INSERT INTO "django_geo_db_location" VALUES(71176,NULL,'Honolulu, HI 96838',29222,222,NULL,15,41661,0);
INSERT INTO "django_geo_db_location" VALUES(71177,NULL,'Honolulu, HI 96839',29222,222,NULL,15,41662,0);
INSERT INTO "django_geo_db_location" VALUES(71178,NULL,'Honolulu, HI 96840',29222,222,NULL,15,41663,0);
INSERT INTO "django_geo_db_location" VALUES(71179,NULL,'Honolulu, HI 96841',29222,222,NULL,15,41664,0);
INSERT INTO "django_geo_db_location" VALUES(71180,NULL,'Honolulu, HI 96842',29222,222,NULL,15,41665,0);
INSERT INTO "django_geo_db_location" VALUES(71181,NULL,'Honolulu, HI 96843',29222,222,NULL,15,41666,0);
INSERT INTO "django_geo_db_location" VALUES(71182,NULL,'Honolulu, HI 96844',29222,222,NULL,15,41667,0);
INSERT INTO "django_geo_db_location" VALUES(71183,NULL,'Honolulu, HI 96845',29222,222,NULL,15,41668,0);
INSERT INTO "django_geo_db_location" VALUES(71184,NULL,'Honolulu, HI 96846',29222,222,NULL,15,41669,0);
INSERT INTO "django_geo_db_location" VALUES(71185,NULL,'Honolulu, HI 96847',29222,222,NULL,15,41670,0);
INSERT INTO "django_geo_db_location" VALUES(71186,NULL,'Honolulu, HI 96848',29222,222,NULL,15,41671,0);
INSERT INTO "django_geo_db_location" VALUES(71187,NULL,'Honolulu, HI 96849',29222,222,NULL,15,41672,0);
INSERT INTO "django_geo_db_location" VALUES(71188,NULL,'Honolulu, HI 96850',29222,222,NULL,15,41673,0);
INSERT INTO "django_geo_db_location" VALUES(71189,NULL,'Hickam AFB, HI',29223,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71190,NULL,'Hickam AFB, HI 96853',29223,222,NULL,15,41674,0);
INSERT INTO "django_geo_db_location" VALUES(71191,NULL,'Wheeler Army Airfield, HI',29224,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71192,NULL,'Wheeler Army Airfield, HI 96854',29224,222,NULL,15,41675,0);
INSERT INTO "django_geo_db_location" VALUES(71193,NULL,'Schofield Barracks, HI',29225,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71194,NULL,'Schofield Barracks, HI 96857',29225,222,NULL,15,41676,0);
INSERT INTO "django_geo_db_location" VALUES(71195,NULL,'Fort Shafter, HI',29226,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71196,NULL,'Fort Shafter, HI 96858',29226,222,NULL,15,41677,0);
INSERT INTO "django_geo_db_location" VALUES(71197,NULL,'Tripler Army Medical Ctr, HI',29227,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71198,NULL,'Tripler Army Medical Ctr, HI 96859',29227,222,NULL,15,41678,0);
INSERT INTO "django_geo_db_location" VALUES(71199,NULL,'Pearl Harbor, HI',29228,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71200,NULL,'Pearl Harbor, HI 96860',29228,222,NULL,15,41679,0);
INSERT INTO "django_geo_db_location" VALUES(71201,NULL,'Camp H M Smith, HI',29229,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71202,NULL,'Camp H M Smith, HI 96861',29229,222,NULL,15,41680,0);
INSERT INTO "django_geo_db_location" VALUES(71203,NULL,'Barbers Point N A S, HI',29230,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71204,NULL,'Barbers Point N A S, HI 96862',29230,222,NULL,15,41681,0);
INSERT INTO "django_geo_db_location" VALUES(71205,NULL,'M C B H Kaneohe Bay, HI',29231,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71206,NULL,'M C B H Kaneohe Bay, HI 96863',29231,222,NULL,15,41682,0);
INSERT INTO "django_geo_db_location" VALUES(71207,NULL,'Volcano, HI 96885',29138,222,NULL,15,41683,0);
INSERT INTO "django_geo_db_location" VALUES(71208,NULL,'Wake Island, HI',29232,222,NULL,15,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71209,NULL,'Wake Island, HI 96898',29232,222,NULL,15,41684,0);
INSERT INTO "django_geo_db_location" VALUES(71210,NULL,'Antelope, OR',29233,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71211,NULL,'Antelope, OR 97001',29233,222,NULL,37,41685,0);
INSERT INTO "django_geo_db_location" VALUES(71212,NULL,'Aurora, OR',29234,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71213,NULL,'Aurora, OR 97002',29234,222,NULL,37,41686,0);
INSERT INTO "django_geo_db_location" VALUES(71214,NULL,'Beavercreek, OR',29235,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71215,NULL,'Beavercreek, OR 97004',29235,222,NULL,37,41687,0);
INSERT INTO "django_geo_db_location" VALUES(71216,NULL,'Beaverton, OR',29236,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71217,NULL,'Beaverton, OR 97005',29236,222,NULL,37,41688,0);
INSERT INTO "django_geo_db_location" VALUES(71218,NULL,'Beaverton, OR 97006',29236,222,NULL,37,41689,0);
INSERT INTO "django_geo_db_location" VALUES(71219,NULL,'Beaverton, OR 97007',29236,222,NULL,37,41690,0);
INSERT INTO "django_geo_db_location" VALUES(71220,NULL,'Beaverton, OR 97008',29236,222,NULL,37,41691,0);
INSERT INTO "django_geo_db_location" VALUES(71221,NULL,'Boring, OR',29237,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71222,NULL,'Boring, OR 97009',29237,222,NULL,37,41692,0);
INSERT INTO "django_geo_db_location" VALUES(71223,NULL,'Bridal Veil, OR',29238,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71224,NULL,'Bridal Veil, OR 97010',29238,222,NULL,37,41693,0);
INSERT INTO "django_geo_db_location" VALUES(71225,NULL,'Brightwood, OR',29239,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71226,NULL,'Brightwood, OR 97011',29239,222,NULL,37,41694,0);
INSERT INTO "django_geo_db_location" VALUES(71227,NULL,'Canby, OR',29240,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71228,NULL,'Canby, OR 97013',29240,222,NULL,37,41695,0);
INSERT INTO "django_geo_db_location" VALUES(71229,NULL,'Cascade Locks, OR',29241,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71230,NULL,'Cascade Locks, OR 97014',29241,222,NULL,37,41696,0);
INSERT INTO "django_geo_db_location" VALUES(71231,NULL,'Clackamas, OR',29242,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71232,NULL,'Clackamas, OR 97015',29242,222,NULL,37,41697,0);
INSERT INTO "django_geo_db_location" VALUES(71233,NULL,'Clatskanie, OR',29243,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71234,NULL,'Clatskanie, OR 97016',29243,222,NULL,37,41698,0);
INSERT INTO "django_geo_db_location" VALUES(71235,NULL,'Colton, OR',29244,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71236,NULL,'Colton, OR 97017',29244,222,NULL,37,41699,0);
INSERT INTO "django_geo_db_location" VALUES(71237,NULL,'Columbia City, OR',29245,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71238,NULL,'Columbia City, OR 97018',29245,222,NULL,37,41700,0);
INSERT INTO "django_geo_db_location" VALUES(71239,NULL,'Corbett, OR',29246,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71240,NULL,'Corbett, OR 97019',29246,222,NULL,37,41701,0);
INSERT INTO "django_geo_db_location" VALUES(71241,NULL,'Donald, OR',29247,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71242,NULL,'Donald, OR 97020',29247,222,NULL,37,41702,0);
INSERT INTO "django_geo_db_location" VALUES(71243,NULL,'Dufur, OR',29248,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71244,NULL,'Dufur, OR 97021',29248,222,NULL,37,41703,0);
INSERT INTO "django_geo_db_location" VALUES(71245,NULL,'Eagle Creek, OR',29249,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71246,NULL,'Eagle Creek, OR 97022',29249,222,NULL,37,41704,0);
INSERT INTO "django_geo_db_location" VALUES(71247,NULL,'Estacada, OR',29250,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71248,NULL,'Estacada, OR 97023',29250,222,NULL,37,41705,0);
INSERT INTO "django_geo_db_location" VALUES(71249,NULL,'Fairview, OR',29251,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71250,NULL,'Fairview, OR 97024',29251,222,NULL,37,41706,0);
INSERT INTO "django_geo_db_location" VALUES(71251,NULL,'Gervais, OR',29252,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71252,NULL,'Gervais, OR 97026',29252,222,NULL,37,41707,0);
INSERT INTO "django_geo_db_location" VALUES(71253,NULL,'Gladstone, OR',29253,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71254,NULL,'Gladstone, OR 97027',29253,222,NULL,37,41708,0);
INSERT INTO "django_geo_db_location" VALUES(71255,NULL,'Government Camp, OR',29254,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71256,NULL,'Government Camp, OR 97028',29254,222,NULL,37,41709,0);
INSERT INTO "django_geo_db_location" VALUES(71257,NULL,'Grass Valley, OR',29255,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71258,NULL,'Grass Valley, OR 97029',29255,222,NULL,37,41710,0);
INSERT INTO "django_geo_db_location" VALUES(71259,NULL,'Gresham, OR',29256,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71260,NULL,'Gresham, OR 97030',29256,222,NULL,37,41711,0);
INSERT INTO "django_geo_db_location" VALUES(71261,NULL,'Hood River, OR',29257,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71262,NULL,'Hood River, OR 97031',29257,222,NULL,37,41712,0);
INSERT INTO "django_geo_db_location" VALUES(71263,NULL,'Hubbard, OR',29258,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71264,NULL,'Hubbard, OR 97032',29258,222,NULL,37,41713,0);
INSERT INTO "django_geo_db_location" VALUES(71265,NULL,'Kent, OR',29259,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71266,NULL,'Kent, OR 97033',29259,222,NULL,37,41714,0);
INSERT INTO "django_geo_db_location" VALUES(71267,NULL,'Lake Oswego, OR',29260,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71268,NULL,'Lake Oswego, OR 97034',29260,222,NULL,37,41715,0);
INSERT INTO "django_geo_db_location" VALUES(71269,NULL,'Lake Oswego, OR 97035',29260,222,NULL,37,41716,0);
INSERT INTO "django_geo_db_location" VALUES(71270,NULL,'Marylhurst, OR',29261,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71271,NULL,'Marylhurst, OR 97036',29261,222,NULL,37,41717,0);
INSERT INTO "django_geo_db_location" VALUES(71272,NULL,'Maupin, OR',29262,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71273,NULL,'Maupin, OR 97037',29262,222,NULL,37,41718,0);
INSERT INTO "django_geo_db_location" VALUES(71274,NULL,'Molalla, OR',29263,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71275,NULL,'Molalla, OR 97038',29263,222,NULL,37,41719,0);
INSERT INTO "django_geo_db_location" VALUES(71276,NULL,'Moro, OR',29264,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71277,NULL,'Moro, OR 97039',29264,222,NULL,37,41720,0);
INSERT INTO "django_geo_db_location" VALUES(71278,NULL,'Mosier, OR',29265,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71279,NULL,'Mosier, OR 97040',29265,222,NULL,37,41721,0);
INSERT INTO "django_geo_db_location" VALUES(71280,NULL,'Mount Hood Parkdale, OR',29266,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71281,NULL,'Mount Hood Parkdale, OR 97041',29266,222,NULL,37,41722,0);
INSERT INTO "django_geo_db_location" VALUES(71282,NULL,'Mulino, OR',29267,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71283,NULL,'Mulino, OR 97042',29267,222,NULL,37,41723,0);
INSERT INTO "django_geo_db_location" VALUES(71284,NULL,'Odell, OR',29268,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71285,NULL,'Odell, OR 97044',29268,222,NULL,37,41724,0);
INSERT INTO "django_geo_db_location" VALUES(71286,NULL,'Oregon City, OR',29269,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71287,NULL,'Oregon City, OR 97045',29269,222,NULL,37,41725,0);
INSERT INTO "django_geo_db_location" VALUES(71288,NULL,'Rainier, OR',29270,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71289,NULL,'Rainier, OR 97048',29270,222,NULL,37,41726,0);
INSERT INTO "django_geo_db_location" VALUES(71290,NULL,'Rhododendron, OR',29271,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71291,NULL,'Rhododendron, OR 97049',29271,222,NULL,37,41727,0);
INSERT INTO "django_geo_db_location" VALUES(71292,NULL,'Rufus, OR',29272,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71293,NULL,'Rufus, OR 97050',29272,222,NULL,37,41728,0);
INSERT INTO "django_geo_db_location" VALUES(71294,NULL,'Saint Helens, OR',29273,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71295,NULL,'Saint Helens, OR 97051',29273,222,NULL,37,41729,0);
INSERT INTO "django_geo_db_location" VALUES(71296,NULL,'Warren, OR',29274,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71297,NULL,'Warren, OR 97053',29274,222,NULL,37,41730,0);
INSERT INTO "django_geo_db_location" VALUES(71298,NULL,'Deer Island, OR',29275,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71299,NULL,'Deer Island, OR 97054',29275,222,NULL,37,41731,0);
INSERT INTO "django_geo_db_location" VALUES(71300,NULL,'Sandy, OR',29276,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71301,NULL,'Sandy, OR 97055',29276,222,NULL,37,41732,0);
INSERT INTO "django_geo_db_location" VALUES(71302,NULL,'Scappoose, OR',29277,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71303,NULL,'Scappoose, OR 97056',29277,222,NULL,37,41733,0);
INSERT INTO "django_geo_db_location" VALUES(71304,NULL,'Shaniko, OR',29278,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71305,NULL,'Shaniko, OR 97057',29278,222,NULL,37,41734,0);
INSERT INTO "django_geo_db_location" VALUES(71306,NULL,'The Dalles, OR',29279,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71307,NULL,'The Dalles, OR 97058',29279,222,NULL,37,41735,0);
INSERT INTO "django_geo_db_location" VALUES(71308,NULL,'Troutdale, OR',29280,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71309,NULL,'Troutdale, OR 97060',29280,222,NULL,37,41736,0);
INSERT INTO "django_geo_db_location" VALUES(71310,NULL,'Tualatin, OR',29281,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71311,NULL,'Tualatin, OR 97062',29281,222,NULL,37,41737,0);
INSERT INTO "django_geo_db_location" VALUES(71312,NULL,'Tygh Valley, OR',29282,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71313,NULL,'Tygh Valley, OR 97063',29282,222,NULL,37,41738,0);
INSERT INTO "django_geo_db_location" VALUES(71314,NULL,'Vernonia, OR',29283,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71315,NULL,'Vernonia, OR 97064',29283,222,NULL,37,41739,0);
INSERT INTO "django_geo_db_location" VALUES(71316,NULL,'Wasco, OR',29284,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71317,NULL,'Wasco, OR 97065',29284,222,NULL,37,41740,0);
INSERT INTO "django_geo_db_location" VALUES(71318,NULL,'Welches, OR',29285,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71319,NULL,'Welches, OR 97067',29285,222,NULL,37,41741,0);
INSERT INTO "django_geo_db_location" VALUES(71320,NULL,'West Linn, OR',29286,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71321,NULL,'West Linn, OR 97068',29286,222,NULL,37,41742,0);
INSERT INTO "django_geo_db_location" VALUES(71322,NULL,'Wilsonville, OR',29287,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71323,NULL,'Wilsonville, OR 97070',29287,222,NULL,37,41743,0);
INSERT INTO "django_geo_db_location" VALUES(71324,NULL,'Woodburn, OR',29288,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71325,NULL,'Woodburn, OR 97071',29288,222,NULL,37,41744,0);
INSERT INTO "django_geo_db_location" VALUES(71326,NULL,'Beaverton, OR 97075',29236,222,NULL,37,41745,0);
INSERT INTO "django_geo_db_location" VALUES(71327,NULL,'Beaverton, OR 97076',29236,222,NULL,37,41746,0);
INSERT INTO "django_geo_db_location" VALUES(71328,NULL,'Beaverton, OR 97077',29236,222,NULL,37,41747,0);
INSERT INTO "django_geo_db_location" VALUES(71329,NULL,'Beaverton, OR 97078',29236,222,NULL,37,41748,0);
INSERT INTO "django_geo_db_location" VALUES(71330,NULL,'Gresham, OR 97080',29256,222,NULL,37,41749,0);
INSERT INTO "django_geo_db_location" VALUES(71331,NULL,'Amity, OR',29289,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71332,NULL,'Amity, OR 97101',29289,222,NULL,37,41750,0);
INSERT INTO "django_geo_db_location" VALUES(71333,NULL,'Arch Cape, OR',29290,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71334,NULL,'Arch Cape, OR 97102',29290,222,NULL,37,41751,0);
INSERT INTO "django_geo_db_location" VALUES(71335,NULL,'Astoria, OR',29291,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71336,NULL,'Astoria, OR 97103',29291,222,NULL,37,41752,0);
INSERT INTO "django_geo_db_location" VALUES(71337,NULL,'Hillsboro, OR',29292,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71338,NULL,'Hillsboro, OR 97104',29292,222,NULL,37,41753,0);
INSERT INTO "django_geo_db_location" VALUES(71339,NULL,'Banks, OR',29293,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71340,NULL,'Banks, OR 97106',29293,222,NULL,37,41754,0);
INSERT INTO "django_geo_db_location" VALUES(71341,NULL,'Bay City, OR',29294,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71342,NULL,'Bay City, OR 97107',29294,222,NULL,37,41755,0);
INSERT INTO "django_geo_db_location" VALUES(71343,NULL,'Beaver, OR',29295,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71344,NULL,'Beaver, OR 97108',29295,222,NULL,37,41756,0);
INSERT INTO "django_geo_db_location" VALUES(71345,NULL,'Buxton, OR',29296,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71346,NULL,'Buxton, OR 97109',29296,222,NULL,37,41757,0);
INSERT INTO "django_geo_db_location" VALUES(71347,NULL,'Cannon Beach, OR',29297,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71348,NULL,'Cannon Beach, OR 97110',29297,222,NULL,37,41758,0);
INSERT INTO "django_geo_db_location" VALUES(71349,NULL,'Carlton, OR',29298,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71350,NULL,'Carlton, OR 97111',29298,222,NULL,37,41759,0);
INSERT INTO "django_geo_db_location" VALUES(71351,NULL,'Cloverdale, OR',29299,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71352,NULL,'Cloverdale, OR 97112',29299,222,NULL,37,41760,0);
INSERT INTO "django_geo_db_location" VALUES(71353,NULL,'Cornelius, OR',29300,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71354,NULL,'Cornelius, OR 97113',29300,222,NULL,37,41761,0);
INSERT INTO "django_geo_db_location" VALUES(71355,NULL,'Dayton, OR',29301,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71356,NULL,'Dayton, OR 97114',29301,222,NULL,37,41762,0);
INSERT INTO "django_geo_db_location" VALUES(71357,NULL,'Dundee, OR',29302,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71358,NULL,'Dundee, OR 97115',29302,222,NULL,37,41763,0);
INSERT INTO "django_geo_db_location" VALUES(71359,NULL,'Forest Grove, OR',29303,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71360,NULL,'Forest Grove, OR 97116',29303,222,NULL,37,41764,0);
INSERT INTO "django_geo_db_location" VALUES(71361,NULL,'Gales Creek, OR',29304,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71362,NULL,'Gales Creek, OR 97117',29304,222,NULL,37,41765,0);
INSERT INTO "django_geo_db_location" VALUES(71363,NULL,'Garibaldi, OR',29305,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71364,NULL,'Garibaldi, OR 97118',29305,222,NULL,37,41766,0);
INSERT INTO "django_geo_db_location" VALUES(71365,NULL,'Gaston, OR',29306,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71366,NULL,'Gaston, OR 97119',29306,222,NULL,37,41767,0);
INSERT INTO "django_geo_db_location" VALUES(71367,NULL,'Hammond, OR',29307,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71368,NULL,'Hammond, OR 97121',29307,222,NULL,37,41768,0);
INSERT INTO "django_geo_db_location" VALUES(71369,NULL,'Hebo, OR',29308,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71370,NULL,'Hebo, OR 97122',29308,222,NULL,37,41769,0);
INSERT INTO "django_geo_db_location" VALUES(71371,NULL,'Hillsboro, OR 97123',29292,222,NULL,37,41770,0);
INSERT INTO "django_geo_db_location" VALUES(71372,NULL,'Hillsboro, OR 97124',29292,222,NULL,37,41771,0);
INSERT INTO "django_geo_db_location" VALUES(71373,NULL,'Manning, OR',29309,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71374,NULL,'Manning, OR 97125',29309,222,NULL,37,41772,0);
INSERT INTO "django_geo_db_location" VALUES(71375,NULL,'Lafayette, OR',29310,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71376,NULL,'Lafayette, OR 97127',29310,222,NULL,37,41773,0);
INSERT INTO "django_geo_db_location" VALUES(71377,NULL,'Mcminnville, OR',29311,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71378,NULL,'Mcminnville, OR 97128',29311,222,NULL,37,41774,0);
INSERT INTO "django_geo_db_location" VALUES(71379,NULL,'Manzanita, OR',29312,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71380,NULL,'Manzanita, OR 97130',29312,222,NULL,37,41775,0);
INSERT INTO "django_geo_db_location" VALUES(71381,NULL,'Nehalem, OR',29313,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71382,NULL,'Nehalem, OR 97131',29313,222,NULL,37,41776,0);
INSERT INTO "django_geo_db_location" VALUES(71383,NULL,'Newberg, OR',29314,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71384,NULL,'Newberg, OR 97132',29314,222,NULL,37,41777,0);
INSERT INTO "django_geo_db_location" VALUES(71385,NULL,'North Plains, OR',29315,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71386,NULL,'North Plains, OR 97133',29315,222,NULL,37,41778,0);
INSERT INTO "django_geo_db_location" VALUES(71387,NULL,'Oceanside, OR',29316,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71388,NULL,'Oceanside, OR 97134',29316,222,NULL,37,41779,0);
INSERT INTO "django_geo_db_location" VALUES(71389,NULL,'Pacific City, OR',29317,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71390,NULL,'Pacific City, OR 97135',29317,222,NULL,37,41780,0);
INSERT INTO "django_geo_db_location" VALUES(71391,NULL,'Rockaway Beach, OR',29318,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71392,NULL,'Rockaway Beach, OR 97136',29318,222,NULL,37,41781,0);
INSERT INTO "django_geo_db_location" VALUES(71393,NULL,'Saint Paul, OR',29319,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71394,NULL,'Saint Paul, OR 97137',29319,222,NULL,37,41782,0);
INSERT INTO "django_geo_db_location" VALUES(71395,NULL,'Seaside, OR',29320,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71396,NULL,'Seaside, OR 97138',29320,222,NULL,37,41783,0);
INSERT INTO "django_geo_db_location" VALUES(71397,NULL,'Sherwood, OR',29321,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71398,NULL,'Sherwood, OR 97140',29321,222,NULL,37,41784,0);
INSERT INTO "django_geo_db_location" VALUES(71399,NULL,'Tillamook, OR',29322,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71400,NULL,'Tillamook, OR 97141',29322,222,NULL,37,41785,0);
INSERT INTO "django_geo_db_location" VALUES(71401,NULL,'Netarts, OR',29323,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71402,NULL,'Netarts, OR 97143',29323,222,NULL,37,41786,0);
INSERT INTO "django_geo_db_location" VALUES(71403,NULL,'Timber, OR',29324,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71404,NULL,'Timber, OR 97144',29324,222,NULL,37,41787,0);
INSERT INTO "django_geo_db_location" VALUES(71405,NULL,'Tolovana Park, OR',29325,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71406,NULL,'Tolovana Park, OR 97145',29325,222,NULL,37,41788,0);
INSERT INTO "django_geo_db_location" VALUES(71407,NULL,'Warrenton, OR',29326,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71408,NULL,'Warrenton, OR 97146',29326,222,NULL,37,41789,0);
INSERT INTO "django_geo_db_location" VALUES(71409,NULL,'Wheeler, OR',29327,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71410,NULL,'Wheeler, OR 97147',29327,222,NULL,37,41790,0);
INSERT INTO "django_geo_db_location" VALUES(71411,NULL,'Yamhill, OR',29328,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71412,NULL,'Yamhill, OR 97148',29328,222,NULL,37,41791,0);
INSERT INTO "django_geo_db_location" VALUES(71413,NULL,'Neskowin, OR',29329,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71414,NULL,'Neskowin, OR 97149',29329,222,NULL,37,41792,0);
INSERT INTO "django_geo_db_location" VALUES(71415,NULL,'Sherwood, OR 97180',29321,222,NULL,37,41793,0);
INSERT INTO "django_geo_db_location" VALUES(71416,NULL,'Portland, OR',29330,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71417,NULL,'Portland, OR 97201',29330,222,NULL,37,41794,0);
INSERT INTO "django_geo_db_location" VALUES(71418,NULL,'Portland, OR 97202',29330,222,NULL,37,41795,0);
INSERT INTO "django_geo_db_location" VALUES(71419,NULL,'Portland, OR 97203',29330,222,NULL,37,41796,0);
INSERT INTO "django_geo_db_location" VALUES(71420,NULL,'Portland, OR 97204',29330,222,NULL,37,41797,0);
INSERT INTO "django_geo_db_location" VALUES(71421,NULL,'Portland, OR 97205',29330,222,NULL,37,41798,0);
INSERT INTO "django_geo_db_location" VALUES(71422,NULL,'Portland, OR 97206',29330,222,NULL,37,41799,0);
INSERT INTO "django_geo_db_location" VALUES(71423,NULL,'Portland, OR 97207',29330,222,NULL,37,41800,0);
INSERT INTO "django_geo_db_location" VALUES(71424,NULL,'Portland, OR 97208',29330,222,NULL,37,41801,0);
INSERT INTO "django_geo_db_location" VALUES(71425,NULL,'Portland, OR 97209',29330,222,NULL,37,41802,0);
INSERT INTO "django_geo_db_location" VALUES(71426,NULL,'Portland, OR 97210',29330,222,NULL,37,41803,0);
INSERT INTO "django_geo_db_location" VALUES(71427,NULL,'Portland, OR 97211',29330,222,NULL,37,41804,0);
INSERT INTO "django_geo_db_location" VALUES(71428,NULL,'Portland, OR 97212',29330,222,NULL,37,41805,0);
INSERT INTO "django_geo_db_location" VALUES(71429,NULL,'Portland, OR 97213',29330,222,NULL,37,41806,0);
INSERT INTO "django_geo_db_location" VALUES(71430,NULL,'Portland, OR 97214',29330,222,NULL,37,41807,0);
INSERT INTO "django_geo_db_location" VALUES(71431,NULL,'Portland, OR 97215',29330,222,NULL,37,41808,0);
INSERT INTO "django_geo_db_location" VALUES(71432,NULL,'Portland, OR 97216',29330,222,NULL,37,41809,0);
INSERT INTO "django_geo_db_location" VALUES(71433,NULL,'Portland, OR 97217',29330,222,NULL,37,41810,0);
INSERT INTO "django_geo_db_location" VALUES(71434,NULL,'Portland, OR 97218',29330,222,NULL,37,41811,0);
INSERT INTO "django_geo_db_location" VALUES(71435,NULL,'Portland, OR 97219',29330,222,NULL,37,41812,0);
INSERT INTO "django_geo_db_location" VALUES(71436,NULL,'Portland, OR 97220',29330,222,NULL,37,41813,0);
INSERT INTO "django_geo_db_location" VALUES(71437,NULL,'Portland, OR 97221',29330,222,NULL,37,41814,0);
INSERT INTO "django_geo_db_location" VALUES(71438,NULL,'Portland, OR 97222',29330,222,NULL,37,41815,0);
INSERT INTO "django_geo_db_location" VALUES(71439,NULL,'Portland, OR 97223',29330,222,NULL,37,41816,0);
INSERT INTO "django_geo_db_location" VALUES(71440,NULL,'Portland, OR 97224',29330,222,NULL,37,41817,0);
INSERT INTO "django_geo_db_location" VALUES(71441,NULL,'Portland, OR 97225',29330,222,NULL,37,41818,0);
INSERT INTO "django_geo_db_location" VALUES(71442,NULL,'Raleigh Hills, OR',29331,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71443,NULL,'Raleigh Hills, OR 97226',29331,222,NULL,37,41819,0);
INSERT INTO "django_geo_db_location" VALUES(71444,NULL,'Portland, OR 97227',29330,222,NULL,37,41820,0);
INSERT INTO "django_geo_db_location" VALUES(71445,NULL,'Portland, OR 97228',29330,222,NULL,37,41821,0);
INSERT INTO "django_geo_db_location" VALUES(71446,NULL,'Portland, OR 97229',29330,222,NULL,37,41822,0);
INSERT INTO "django_geo_db_location" VALUES(71447,NULL,'Portland, OR 97230',29330,222,NULL,37,41823,0);
INSERT INTO "django_geo_db_location" VALUES(71448,NULL,'Portland, OR 97231',29330,222,NULL,37,41824,0);
INSERT INTO "django_geo_db_location" VALUES(71449,NULL,'Portland, OR 97232',29330,222,NULL,37,41825,0);
INSERT INTO "django_geo_db_location" VALUES(71450,NULL,'Portland, OR 97233',29330,222,NULL,37,41826,0);
INSERT INTO "django_geo_db_location" VALUES(71451,NULL,'Portland, OR 97236',29330,222,NULL,37,41827,0);
INSERT INTO "django_geo_db_location" VALUES(71452,NULL,'Portland, OR 97238',29330,222,NULL,37,41828,0);
INSERT INTO "django_geo_db_location" VALUES(71453,NULL,'Portland, OR 97239',29330,222,NULL,37,41829,0);
INSERT INTO "django_geo_db_location" VALUES(71454,NULL,'Portland, OR 97240',29330,222,NULL,37,41830,0);
INSERT INTO "django_geo_db_location" VALUES(71455,NULL,'Portland, OR 97242',29330,222,NULL,37,41831,0);
INSERT INTO "django_geo_db_location" VALUES(71456,NULL,'Portland, OR 97251',29330,222,NULL,37,41832,0);
INSERT INTO "django_geo_db_location" VALUES(71457,NULL,'Portland, OR 97253',29330,222,NULL,37,41833,0);
INSERT INTO "django_geo_db_location" VALUES(71458,NULL,'Portland, OR 97254',29330,222,NULL,37,41834,0);
INSERT INTO "django_geo_db_location" VALUES(71459,NULL,'Portland, OR 97255',29330,222,NULL,37,41835,0);
INSERT INTO "django_geo_db_location" VALUES(71460,NULL,'Portland, OR 97256',29330,222,NULL,37,41836,0);
INSERT INTO "django_geo_db_location" VALUES(71461,NULL,'Grants Pass, OR',29332,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71462,NULL,'Grants Pass, OR 97257',29332,222,NULL,37,41837,0);
INSERT INTO "django_geo_db_location" VALUES(71463,NULL,'Portland, OR 97258',29330,222,NULL,37,41838,0);
INSERT INTO "django_geo_db_location" VALUES(71464,NULL,'Portland, OR 97259',29330,222,NULL,37,41839,0);
INSERT INTO "django_geo_db_location" VALUES(71465,NULL,'Chiloquin, OR',29333,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71466,NULL,'Chiloquin, OR 97264',29333,222,NULL,37,41840,0);
INSERT INTO "django_geo_db_location" VALUES(71467,NULL,'Portland, OR 97266',29330,222,NULL,37,41841,0);
INSERT INTO "django_geo_db_location" VALUES(71468,NULL,'Portland, OR 97267',29330,222,NULL,37,41842,0);
INSERT INTO "django_geo_db_location" VALUES(71469,NULL,'Portland, OR 97268',29330,222,NULL,37,41843,0);
INSERT INTO "django_geo_db_location" VALUES(71470,NULL,'Portland, OR 97269',29330,222,NULL,37,41844,0);
INSERT INTO "django_geo_db_location" VALUES(71471,NULL,'Portland, OR 97271',29330,222,NULL,37,41845,0);
INSERT INTO "django_geo_db_location" VALUES(71472,NULL,'Portland, OR 97272',29330,222,NULL,37,41846,0);
INSERT INTO "django_geo_db_location" VALUES(71473,NULL,'Portland, OR 97280',29330,222,NULL,37,41847,0);
INSERT INTO "django_geo_db_location" VALUES(71474,NULL,'Portland, OR 97281',29330,222,NULL,37,41848,0);
INSERT INTO "django_geo_db_location" VALUES(71475,NULL,'Portland, OR 97282',29330,222,NULL,37,41849,0);
INSERT INTO "django_geo_db_location" VALUES(71476,NULL,'Portland, OR 97283',29330,222,NULL,37,41850,0);
INSERT INTO "django_geo_db_location" VALUES(71477,NULL,'Portland, OR 97286',29330,222,NULL,37,41851,0);
INSERT INTO "django_geo_db_location" VALUES(71478,NULL,'Portland, OR 97290',29330,222,NULL,37,41852,0);
INSERT INTO "django_geo_db_location" VALUES(71479,NULL,'Portland, OR 97291',29330,222,NULL,37,41853,0);
INSERT INTO "django_geo_db_location" VALUES(71480,NULL,'Portland, OR 97292',29330,222,NULL,37,41854,0);
INSERT INTO "django_geo_db_location" VALUES(71481,NULL,'Portland, OR 97293',29330,222,NULL,37,41855,0);
INSERT INTO "django_geo_db_location" VALUES(71482,NULL,'Portland, OR 97294',29330,222,NULL,37,41856,0);
INSERT INTO "django_geo_db_location" VALUES(71483,NULL,'Portland, OR 97296',29330,222,NULL,37,41857,0);
INSERT INTO "django_geo_db_location" VALUES(71484,NULL,'Portland, OR 97298',29330,222,NULL,37,41858,0);
INSERT INTO "django_geo_db_location" VALUES(71485,NULL,'Portland, OR 97299',29330,222,NULL,37,41859,0);
INSERT INTO "django_geo_db_location" VALUES(71486,NULL,'Salem, OR',29334,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71487,NULL,'Salem, OR 97301',29334,222,NULL,37,41860,0);
INSERT INTO "django_geo_db_location" VALUES(71488,NULL,'Salem, OR 97302',29334,222,NULL,37,41861,0);
INSERT INTO "django_geo_db_location" VALUES(71489,NULL,'Salem, OR 97303',29334,222,NULL,37,41862,0);
INSERT INTO "django_geo_db_location" VALUES(71490,NULL,'Salem, OR 97304',29334,222,NULL,37,41863,0);
INSERT INTO "django_geo_db_location" VALUES(71491,NULL,'Salem, OR 97305',29334,222,NULL,37,41864,0);
INSERT INTO "django_geo_db_location" VALUES(71492,NULL,'Salem, OR 97306',29334,222,NULL,37,41865,0);
INSERT INTO "django_geo_db_location" VALUES(71493,NULL,'Keizer, OR',29335,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71494,NULL,'Keizer, OR 97307',29335,222,NULL,37,41866,0);
INSERT INTO "django_geo_db_location" VALUES(71495,NULL,'Salem, OR 97308',29334,222,NULL,37,41867,0);
INSERT INTO "django_geo_db_location" VALUES(71496,NULL,'Salem, OR 97309',29334,222,NULL,37,41868,0);
INSERT INTO "django_geo_db_location" VALUES(71497,NULL,'Salem, OR 97310',29334,222,NULL,37,41869,0);
INSERT INTO "django_geo_db_location" VALUES(71498,NULL,'Salem, OR 97311',29334,222,NULL,37,41870,0);
INSERT INTO "django_geo_db_location" VALUES(71499,NULL,'Salem, OR 97312',29334,222,NULL,37,41871,0);
INSERT INTO "django_geo_db_location" VALUES(71500,NULL,'Salem, OR 97313',29334,222,NULL,37,41872,0);
INSERT INTO "django_geo_db_location" VALUES(71501,NULL,'Salem, OR 97314',29334,222,NULL,37,41873,0);
INSERT INTO "django_geo_db_location" VALUES(71502,NULL,'Albany, OR',29336,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71503,NULL,'Albany, OR 97321',29336,222,NULL,37,41874,0);
INSERT INTO "django_geo_db_location" VALUES(71504,NULL,'Albany, OR 97322',29336,222,NULL,37,41875,0);
INSERT INTO "django_geo_db_location" VALUES(71505,NULL,'Alsea, OR',29337,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71506,NULL,'Alsea, OR 97324',29337,222,NULL,37,41876,0);
INSERT INTO "django_geo_db_location" VALUES(71507,NULL,'Aumsville, OR',29338,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71508,NULL,'Aumsville, OR 97325',29338,222,NULL,37,41877,0);
INSERT INTO "django_geo_db_location" VALUES(71509,NULL,'Blodgett, OR',29339,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71510,NULL,'Blodgett, OR 97326',29339,222,NULL,37,41878,0);
INSERT INTO "django_geo_db_location" VALUES(71511,NULL,'Brownsville, OR',29340,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71512,NULL,'Brownsville, OR 97327',29340,222,NULL,37,41879,0);
INSERT INTO "django_geo_db_location" VALUES(71513,NULL,'Cascadia, OR',29341,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71514,NULL,'Cascadia, OR 97329',29341,222,NULL,37,41880,0);
INSERT INTO "django_geo_db_location" VALUES(71515,NULL,'Corvallis, OR',29342,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71516,NULL,'Corvallis, OR 97330',29342,222,NULL,37,41881,0);
INSERT INTO "django_geo_db_location" VALUES(71517,NULL,'Corvallis, OR 97331',29342,222,NULL,37,41882,0);
INSERT INTO "django_geo_db_location" VALUES(71518,NULL,'Corvallis, OR 97333',29342,222,NULL,37,41883,0);
INSERT INTO "django_geo_db_location" VALUES(71519,NULL,'Crabtree, OR',29343,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71520,NULL,'Crabtree, OR 97335',29343,222,NULL,37,41884,0);
INSERT INTO "django_geo_db_location" VALUES(71521,NULL,'Crawfordsville, OR',29344,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71522,NULL,'Crawfordsville, OR 97336',29344,222,NULL,37,41885,0);
INSERT INTO "django_geo_db_location" VALUES(71523,NULL,'Dallas, OR',29345,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71524,NULL,'Dallas, OR 97338',29345,222,NULL,37,41886,0);
INSERT INTO "django_geo_db_location" VALUES(71525,NULL,'Corvallis, OR 97339',29342,222,NULL,37,41887,0);
INSERT INTO "django_geo_db_location" VALUES(71526,NULL,'Depoe Bay, OR',29346,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71527,NULL,'Depoe Bay, OR 97341',29346,222,NULL,37,41888,0);
INSERT INTO "django_geo_db_location" VALUES(71528,NULL,'Detroit, OR',29347,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71529,NULL,'Detroit, OR 97342',29347,222,NULL,37,41889,0);
INSERT INTO "django_geo_db_location" VALUES(71530,NULL,'Eddyville, OR',29348,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71531,NULL,'Eddyville, OR 97343',29348,222,NULL,37,41890,0);
INSERT INTO "django_geo_db_location" VALUES(71532,NULL,'Falls City, OR',29349,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71533,NULL,'Falls City, OR 97344',29349,222,NULL,37,41891,0);
INSERT INTO "django_geo_db_location" VALUES(71534,NULL,'Foster, OR',29350,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71535,NULL,'Foster, OR 97345',29350,222,NULL,37,41892,0);
INSERT INTO "django_geo_db_location" VALUES(71536,NULL,'Gates, OR',29351,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71537,NULL,'Gates, OR 97346',29351,222,NULL,37,41893,0);
INSERT INTO "django_geo_db_location" VALUES(71538,NULL,'Grand Ronde, OR',29352,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71539,NULL,'Grand Ronde, OR 97347',29352,222,NULL,37,41894,0);
INSERT INTO "django_geo_db_location" VALUES(71540,NULL,'Halsey, OR',29353,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71541,NULL,'Halsey, OR 97348',29353,222,NULL,37,41895,0);
INSERT INTO "django_geo_db_location" VALUES(71542,NULL,'Idanha, OR',29354,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71543,NULL,'Idanha, OR 97350',29354,222,NULL,37,41896,0);
INSERT INTO "django_geo_db_location" VALUES(71544,NULL,'Independence, OR',29355,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71545,NULL,'Independence, OR 97351',29355,222,NULL,37,41897,0);
INSERT INTO "django_geo_db_location" VALUES(71546,NULL,'Jefferson, OR',29356,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71547,NULL,'Jefferson, OR 97352',29356,222,NULL,37,41898,0);
INSERT INTO "django_geo_db_location" VALUES(71548,NULL,'Lebanon, OR',29357,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71549,NULL,'Lebanon, OR 97355',29357,222,NULL,37,41899,0);
INSERT INTO "django_geo_db_location" VALUES(71550,NULL,'Logsden, OR',29358,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71551,NULL,'Logsden, OR 97357',29358,222,NULL,37,41900,0);
INSERT INTO "django_geo_db_location" VALUES(71552,NULL,'Lyons, OR',29359,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71553,NULL,'Lyons, OR 97358',29359,222,NULL,37,41901,0);
INSERT INTO "django_geo_db_location" VALUES(71554,NULL,'Marion, OR',29360,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71555,NULL,'Marion, OR 97359',29360,222,NULL,37,41902,0);
INSERT INTO "django_geo_db_location" VALUES(71556,NULL,'Mill City, OR',29361,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71557,NULL,'Mill City, OR 97360',29361,222,NULL,37,41903,0);
INSERT INTO "django_geo_db_location" VALUES(71558,NULL,'Monmouth, OR',29362,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71559,NULL,'Monmouth, OR 97361',29362,222,NULL,37,41904,0);
INSERT INTO "django_geo_db_location" VALUES(71560,NULL,'Mount Angel, OR',29363,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71561,NULL,'Mount Angel, OR 97362',29363,222,NULL,37,41905,0);
INSERT INTO "django_geo_db_location" VALUES(71562,NULL,'Neotsu, OR',29364,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71563,NULL,'Neotsu, OR 97364',29364,222,NULL,37,41906,0);
INSERT INTO "django_geo_db_location" VALUES(71564,NULL,'Newport, OR',29365,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71565,NULL,'Newport, OR 97365',29365,222,NULL,37,41907,0);
INSERT INTO "django_geo_db_location" VALUES(71566,NULL,'South Beach, OR',29366,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71567,NULL,'South Beach, OR 97366',29366,222,NULL,37,41908,0);
INSERT INTO "django_geo_db_location" VALUES(71568,NULL,'Lincoln City, OR',29367,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71569,NULL,'Lincoln City, OR 97367',29367,222,NULL,37,41909,0);
INSERT INTO "django_geo_db_location" VALUES(71570,NULL,'Otis, OR',29368,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71571,NULL,'Otis, OR 97368',29368,222,NULL,37,41910,0);
INSERT INTO "django_geo_db_location" VALUES(71572,NULL,'Otter Rock, OR',29369,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71573,NULL,'Otter Rock, OR 97369',29369,222,NULL,37,41911,0);
INSERT INTO "django_geo_db_location" VALUES(71574,NULL,'Philomath, OR',29370,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71575,NULL,'Philomath, OR 97370',29370,222,NULL,37,41912,0);
INSERT INTO "django_geo_db_location" VALUES(71576,NULL,'Rickreall, OR',29371,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71577,NULL,'Rickreall, OR 97371',29371,222,NULL,37,41913,0);
INSERT INTO "django_geo_db_location" VALUES(71578,NULL,'Rose Lodge, OR',29372,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71579,NULL,'Rose Lodge, OR 97372',29372,222,NULL,37,41914,0);
INSERT INTO "django_geo_db_location" VALUES(71580,NULL,'Saint Benedict, OR',29373,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71581,NULL,'Saint Benedict, OR 97373',29373,222,NULL,37,41915,0);
INSERT INTO "django_geo_db_location" VALUES(71582,NULL,'Scio, OR',29374,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71583,NULL,'Scio, OR 97374',29374,222,NULL,37,41916,0);
INSERT INTO "django_geo_db_location" VALUES(71584,NULL,'Scotts Mills, OR',29375,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71585,NULL,'Scotts Mills, OR 97375',29375,222,NULL,37,41917,0);
INSERT INTO "django_geo_db_location" VALUES(71586,NULL,'Seal Rock, OR',29376,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71587,NULL,'Seal Rock, OR 97376',29376,222,NULL,37,41918,0);
INSERT INTO "django_geo_db_location" VALUES(71588,NULL,'Shedd, OR',29377,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71589,NULL,'Shedd, OR 97377',29377,222,NULL,37,41919,0);
INSERT INTO "django_geo_db_location" VALUES(71590,NULL,'Sheridan, OR',29378,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71591,NULL,'Sheridan, OR 97378',29378,222,NULL,37,41920,0);
INSERT INTO "django_geo_db_location" VALUES(71592,NULL,'Siletz, OR',29379,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71593,NULL,'Siletz, OR 97380',29379,222,NULL,37,41921,0);
INSERT INTO "django_geo_db_location" VALUES(71594,NULL,'Silverton, OR',29380,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71595,NULL,'Silverton, OR 97381',29380,222,NULL,37,41922,0);
INSERT INTO "django_geo_db_location" VALUES(71596,NULL,'Stayton, OR',29381,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71597,NULL,'Stayton, OR 97383',29381,222,NULL,37,41923,0);
INSERT INTO "django_geo_db_location" VALUES(71598,NULL,'Mehama, OR',29382,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71599,NULL,'Mehama, OR 97384',29382,222,NULL,37,41924,0);
INSERT INTO "django_geo_db_location" VALUES(71600,NULL,'Sublimity, OR',29383,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71601,NULL,'Sublimity, OR 97385',29383,222,NULL,37,41925,0);
INSERT INTO "django_geo_db_location" VALUES(71602,NULL,'Sweet Home, OR',29384,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71603,NULL,'Sweet Home, OR 97386',29384,222,NULL,37,41926,0);
INSERT INTO "django_geo_db_location" VALUES(71604,NULL,'Gleneden Beach, OR',29385,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71605,NULL,'Gleneden Beach, OR 97388',29385,222,NULL,37,41927,0);
INSERT INTO "django_geo_db_location" VALUES(71606,NULL,'Tangent, OR',29386,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71607,NULL,'Tangent, OR 97389',29386,222,NULL,37,41928,0);
INSERT INTO "django_geo_db_location" VALUES(71608,NULL,'Tidewater, OR',29387,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71609,NULL,'Tidewater, OR 97390',29387,222,NULL,37,41929,0);
INSERT INTO "django_geo_db_location" VALUES(71610,NULL,'Toledo, OR',29388,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71611,NULL,'Toledo, OR 97391',29388,222,NULL,37,41930,0);
INSERT INTO "django_geo_db_location" VALUES(71612,NULL,'Turner, OR',29389,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71613,NULL,'Turner, OR 97392',29389,222,NULL,37,41931,0);
INSERT INTO "django_geo_db_location" VALUES(71614,NULL,'Waldport, OR',29390,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71615,NULL,'Waldport, OR 97394',29390,222,NULL,37,41932,0);
INSERT INTO "django_geo_db_location" VALUES(71616,NULL,'Willamina, OR',29391,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71617,NULL,'Willamina, OR 97396',29391,222,NULL,37,41933,0);
INSERT INTO "django_geo_db_location" VALUES(71618,NULL,'Eugene, OR',29392,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71619,NULL,'Eugene, OR 97401',29392,222,NULL,37,41934,0);
INSERT INTO "django_geo_db_location" VALUES(71620,NULL,'Eugene, OR 97402',29392,222,NULL,37,41935,0);
INSERT INTO "django_geo_db_location" VALUES(71621,NULL,'Eugene, OR 97403',29392,222,NULL,37,41936,0);
INSERT INTO "django_geo_db_location" VALUES(71622,NULL,'Eugene, OR 97404',29392,222,NULL,37,41937,0);
INSERT INTO "django_geo_db_location" VALUES(71623,NULL,'Eugene, OR 97405',29392,222,NULL,37,41938,0);
INSERT INTO "django_geo_db_location" VALUES(71624,NULL,'Agness, OR',29393,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71625,NULL,'Agness, OR 97406',29393,222,NULL,37,41939,0);
INSERT INTO "django_geo_db_location" VALUES(71626,NULL,'Allegany, OR',29394,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71627,NULL,'Allegany, OR 97407',29394,222,NULL,37,41940,0);
INSERT INTO "django_geo_db_location" VALUES(71628,NULL,'Eugene, OR 97408',29392,222,NULL,37,41941,0);
INSERT INTO "django_geo_db_location" VALUES(71629,NULL,'Alvadore, OR',29395,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71630,NULL,'Alvadore, OR 97409',29395,222,NULL,37,41942,0);
INSERT INTO "django_geo_db_location" VALUES(71631,NULL,'Azalea, OR',29396,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71632,NULL,'Azalea, OR 97410',29396,222,NULL,37,41943,0);
INSERT INTO "django_geo_db_location" VALUES(71633,NULL,'Bandon, OR',29397,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71634,NULL,'Bandon, OR 97411',29397,222,NULL,37,41944,0);
INSERT INTO "django_geo_db_location" VALUES(71635,NULL,'Blachly, OR',29398,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71636,NULL,'Blachly, OR 97412',29398,222,NULL,37,41945,0);
INSERT INTO "django_geo_db_location" VALUES(71637,NULL,'Blue River, OR',29399,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71638,NULL,'Blue River, OR 97413',29399,222,NULL,37,41946,0);
INSERT INTO "django_geo_db_location" VALUES(71639,NULL,'Broadbent, OR',29400,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71640,NULL,'Broadbent, OR 97414',29400,222,NULL,37,41947,0);
INSERT INTO "django_geo_db_location" VALUES(71641,NULL,'Brookings, OR',29401,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71642,NULL,'Brookings, OR 97415',29401,222,NULL,37,41948,0);
INSERT INTO "django_geo_db_location" VALUES(71643,NULL,'Camas Valley, OR',29402,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71644,NULL,'Camas Valley, OR 97416',29402,222,NULL,37,41949,0);
INSERT INTO "django_geo_db_location" VALUES(71645,NULL,'Canyonville, OR',29403,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71646,NULL,'Canyonville, OR 97417',29403,222,NULL,37,41950,0);
INSERT INTO "django_geo_db_location" VALUES(71647,NULL,'Cheshire, OR',29404,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71648,NULL,'Cheshire, OR 97419',29404,222,NULL,37,41951,0);
INSERT INTO "django_geo_db_location" VALUES(71649,NULL,'Coos Bay, OR',29405,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71650,NULL,'Coos Bay, OR 97420',29405,222,NULL,37,41952,0);
INSERT INTO "django_geo_db_location" VALUES(71651,NULL,'Coquille, OR',29406,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71652,NULL,'Coquille, OR 97423',29406,222,NULL,37,41953,0);
INSERT INTO "django_geo_db_location" VALUES(71653,NULL,'Cottage Grove, OR',29407,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71654,NULL,'Cottage Grove, OR 97424',29407,222,NULL,37,41954,0);
INSERT INTO "django_geo_db_location" VALUES(71655,NULL,'Crescent Lake, OR',29408,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71656,NULL,'Crescent Lake, OR 97425',29408,222,NULL,37,41955,0);
INSERT INTO "django_geo_db_location" VALUES(71657,NULL,'Creswell, OR',29409,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71658,NULL,'Creswell, OR 97426',29409,222,NULL,37,41956,0);
INSERT INTO "django_geo_db_location" VALUES(71659,NULL,'Culp Creek, OR',29410,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71660,NULL,'Culp Creek, OR 97427',29410,222,NULL,37,41957,0);
INSERT INTO "django_geo_db_location" VALUES(71661,NULL,'Curtin, OR',29411,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71662,NULL,'Curtin, OR 97428',29411,222,NULL,37,41958,0);
INSERT INTO "django_geo_db_location" VALUES(71663,NULL,'Days Creek, OR',29412,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71664,NULL,'Days Creek, OR 97429',29412,222,NULL,37,41959,0);
INSERT INTO "django_geo_db_location" VALUES(71665,NULL,'Deadwood, OR',29413,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71666,NULL,'Deadwood, OR 97430',29413,222,NULL,37,41960,0);
INSERT INTO "django_geo_db_location" VALUES(71667,NULL,'Dexter, OR',29414,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71668,NULL,'Dexter, OR 97431',29414,222,NULL,37,41961,0);
INSERT INTO "django_geo_db_location" VALUES(71669,NULL,'Dillard, OR',29415,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71670,NULL,'Dillard, OR 97432',29415,222,NULL,37,41962,0);
INSERT INTO "django_geo_db_location" VALUES(71671,NULL,'Dorena, OR',29416,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71672,NULL,'Dorena, OR 97434',29416,222,NULL,37,41963,0);
INSERT INTO "django_geo_db_location" VALUES(71673,NULL,'Drain, OR',29417,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71674,NULL,'Drain, OR 97435',29417,222,NULL,37,41964,0);
INSERT INTO "django_geo_db_location" VALUES(71675,NULL,'Elkton, OR',29418,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71676,NULL,'Elkton, OR 97436',29418,222,NULL,37,41965,0);
INSERT INTO "django_geo_db_location" VALUES(71677,NULL,'Elmira, OR',29419,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71678,NULL,'Elmira, OR 97437',29419,222,NULL,37,41966,0);
INSERT INTO "django_geo_db_location" VALUES(71679,NULL,'Fall Creek, OR',29420,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71680,NULL,'Fall Creek, OR 97438',29420,222,NULL,37,41967,0);
INSERT INTO "django_geo_db_location" VALUES(71681,NULL,'Florence, OR',29421,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71682,NULL,'Florence, OR 97439',29421,222,NULL,37,41968,0);
INSERT INTO "django_geo_db_location" VALUES(71683,NULL,'Eugene, OR 97440',29392,222,NULL,37,41969,0);
INSERT INTO "django_geo_db_location" VALUES(71684,NULL,'Gardiner, OR',29422,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71685,NULL,'Gardiner, OR 97441',29422,222,NULL,37,41970,0);
INSERT INTO "django_geo_db_location" VALUES(71686,NULL,'Glendale, OR',29423,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71687,NULL,'Glendale, OR 97442',29423,222,NULL,37,41971,0);
INSERT INTO "django_geo_db_location" VALUES(71688,NULL,'Glide, OR',29424,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71689,NULL,'Glide, OR 97443',29424,222,NULL,37,41972,0);
INSERT INTO "django_geo_db_location" VALUES(71690,NULL,'Gold Beach, OR',29425,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71691,NULL,'Gold Beach, OR 97444',29425,222,NULL,37,41973,0);
INSERT INTO "django_geo_db_location" VALUES(71692,NULL,'Harrisburg, OR',29426,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71693,NULL,'Harrisburg, OR 97446',29426,222,NULL,37,41974,0);
INSERT INTO "django_geo_db_location" VALUES(71694,NULL,'Idleyld Park, OR',29427,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71695,NULL,'Idleyld Park, OR 97447',29427,222,NULL,37,41975,0);
INSERT INTO "django_geo_db_location" VALUES(71696,NULL,'Junction City, OR',29428,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71697,NULL,'Junction City, OR 97448',29428,222,NULL,37,41976,0);
INSERT INTO "django_geo_db_location" VALUES(71698,NULL,'Lakeside, OR',29429,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71699,NULL,'Lakeside, OR 97449',29429,222,NULL,37,41977,0);
INSERT INTO "django_geo_db_location" VALUES(71700,NULL,'Langlois, OR',29430,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71701,NULL,'Langlois, OR 97450',29430,222,NULL,37,41978,0);
INSERT INTO "django_geo_db_location" VALUES(71702,NULL,'Lorane, OR',29431,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71703,NULL,'Lorane, OR 97451',29431,222,NULL,37,41979,0);
INSERT INTO "django_geo_db_location" VALUES(71704,NULL,'Lowell, OR',29432,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71705,NULL,'Lowell, OR 97452',29432,222,NULL,37,41980,0);
INSERT INTO "django_geo_db_location" VALUES(71706,NULL,'Mapleton, OR',29433,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71707,NULL,'Mapleton, OR 97453',29433,222,NULL,37,41981,0);
INSERT INTO "django_geo_db_location" VALUES(71708,NULL,'Marcola, OR',29434,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71709,NULL,'Marcola, OR 97454',29434,222,NULL,37,41982,0);
INSERT INTO "django_geo_db_location" VALUES(71710,NULL,'Pleasant Hill, OR',29435,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71711,NULL,'Pleasant Hill, OR 97455',29435,222,NULL,37,41983,0);
INSERT INTO "django_geo_db_location" VALUES(71712,NULL,'Monroe, OR',29436,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71713,NULL,'Monroe, OR 97456',29436,222,NULL,37,41984,0);
INSERT INTO "django_geo_db_location" VALUES(71714,NULL,'Myrtle Creek, OR',29437,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71715,NULL,'Myrtle Creek, OR 97457',29437,222,NULL,37,41985,0);
INSERT INTO "django_geo_db_location" VALUES(71716,NULL,'Myrtle Point, OR',29438,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71717,NULL,'Myrtle Point, OR 97458',29438,222,NULL,37,41986,0);
INSERT INTO "django_geo_db_location" VALUES(71718,NULL,'North Bend, OR',29439,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71719,NULL,'North Bend, OR 97459',29439,222,NULL,37,41987,0);
INSERT INTO "django_geo_db_location" VALUES(71720,NULL,'Norway, OR',29440,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71721,NULL,'Norway, OR 97460',29440,222,NULL,37,41988,0);
INSERT INTO "django_geo_db_location" VALUES(71722,NULL,'Noti, OR',29441,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71723,NULL,'Noti, OR 97461',29441,222,NULL,37,41989,0);
INSERT INTO "django_geo_db_location" VALUES(71724,NULL,'Oakland, OR',29442,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71725,NULL,'Oakland, OR 97462',29442,222,NULL,37,41990,0);
INSERT INTO "django_geo_db_location" VALUES(71726,NULL,'Oakridge, OR',29443,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71727,NULL,'Oakridge, OR 97463',29443,222,NULL,37,41991,0);
INSERT INTO "django_geo_db_location" VALUES(71728,NULL,'Ophir, OR',29444,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71729,NULL,'Ophir, OR 97464',29444,222,NULL,37,41992,0);
INSERT INTO "django_geo_db_location" VALUES(71730,NULL,'Port Orford, OR',29445,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71731,NULL,'Port Orford, OR 97465',29445,222,NULL,37,41993,0);
INSERT INTO "django_geo_db_location" VALUES(71732,NULL,'Powers, OR',29446,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71733,NULL,'Powers, OR 97466',29446,222,NULL,37,41994,0);
INSERT INTO "django_geo_db_location" VALUES(71734,NULL,'Reedsport, OR',29447,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71735,NULL,'Reedsport, OR 97467',29447,222,NULL,37,41995,0);
INSERT INTO "django_geo_db_location" VALUES(71736,NULL,'Remote, OR',29448,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71737,NULL,'Remote, OR 97468',29448,222,NULL,37,41996,0);
INSERT INTO "django_geo_db_location" VALUES(71738,NULL,'Riddle, OR',29449,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71739,NULL,'Riddle, OR 97469',29449,222,NULL,37,41997,0);
INSERT INTO "django_geo_db_location" VALUES(71740,NULL,'Roseburg, OR',29450,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71741,NULL,'Roseburg, OR 97470',29450,222,NULL,37,41998,0);
INSERT INTO "django_geo_db_location" VALUES(71742,NULL,'Saginaw, OR',29451,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71743,NULL,'Saginaw, OR 97472',29451,222,NULL,37,41999,0);
INSERT INTO "django_geo_db_location" VALUES(71744,NULL,'Scottsburg, OR',29452,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71745,NULL,'Scottsburg, OR 97473',29452,222,NULL,37,42000,0);
INSERT INTO "django_geo_db_location" VALUES(71746,NULL,'Sixes, OR',29453,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71747,NULL,'Sixes, OR 97476',29453,222,NULL,37,42001,0);
INSERT INTO "django_geo_db_location" VALUES(71748,NULL,'Springfield, OR',29454,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71749,NULL,'Springfield, OR 97477',29454,222,NULL,37,42002,0);
INSERT INTO "django_geo_db_location" VALUES(71750,NULL,'Springfield, OR 97478',29454,222,NULL,37,42003,0);
INSERT INTO "django_geo_db_location" VALUES(71751,NULL,'Sutherlin, OR',29455,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71752,NULL,'Sutherlin, OR 97479',29455,222,NULL,37,42004,0);
INSERT INTO "django_geo_db_location" VALUES(71753,NULL,'Swisshome, OR',29456,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71754,NULL,'Swisshome, OR 97480',29456,222,NULL,37,42005,0);
INSERT INTO "django_geo_db_location" VALUES(71755,NULL,'Tenmile, OR',29457,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71756,NULL,'Tenmile, OR 97481',29457,222,NULL,37,42006,0);
INSERT INTO "django_geo_db_location" VALUES(71757,NULL,'Thurston, OR',29458,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71758,NULL,'Thurston, OR 97482',29458,222,NULL,37,42007,0);
INSERT INTO "django_geo_db_location" VALUES(71759,NULL,'Tiller, OR',29459,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71760,NULL,'Tiller, OR 97484',29459,222,NULL,37,42008,0);
INSERT INTO "django_geo_db_location" VALUES(71761,NULL,'Umpqua, OR',29460,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71762,NULL,'Umpqua, OR 97486',29460,222,NULL,37,42009,0);
INSERT INTO "django_geo_db_location" VALUES(71763,NULL,'Veneta, OR',29461,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71764,NULL,'Veneta, OR 97487',29461,222,NULL,37,42010,0);
INSERT INTO "django_geo_db_location" VALUES(71765,NULL,'Vida, OR',29462,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71766,NULL,'Vida, OR 97488',29462,222,NULL,37,42011,0);
INSERT INTO "django_geo_db_location" VALUES(71767,NULL,'Walterville, OR',29463,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71768,NULL,'Walterville, OR 97489',29463,222,NULL,37,42012,0);
INSERT INTO "django_geo_db_location" VALUES(71769,NULL,'Walton, OR',29464,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71770,NULL,'Walton, OR 97490',29464,222,NULL,37,42013,0);
INSERT INTO "django_geo_db_location" VALUES(71771,NULL,'Wedderburn, OR',29465,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71772,NULL,'Wedderburn, OR 97491',29465,222,NULL,37,42014,0);
INSERT INTO "django_geo_db_location" VALUES(71773,NULL,'Westfir, OR',29466,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71774,NULL,'Westfir, OR 97492',29466,222,NULL,37,42015,0);
INSERT INTO "django_geo_db_location" VALUES(71775,NULL,'Westlake, OR',29467,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71776,NULL,'Westlake, OR 97493',29467,222,NULL,37,42016,0);
INSERT INTO "django_geo_db_location" VALUES(71777,NULL,'Wilbur, OR',29468,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71778,NULL,'Wilbur, OR 97494',29468,222,NULL,37,42017,0);
INSERT INTO "django_geo_db_location" VALUES(71779,NULL,'Winchester, OR',29469,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71780,NULL,'Winchester, OR 97495',29469,222,NULL,37,42018,0);
INSERT INTO "django_geo_db_location" VALUES(71781,NULL,'Winston, OR',29470,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71782,NULL,'Winston, OR 97496',29470,222,NULL,37,42019,0);
INSERT INTO "django_geo_db_location" VALUES(71783,NULL,'Wolf Creek, OR',29471,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71784,NULL,'Wolf Creek, OR 97497',29471,222,NULL,37,42020,0);
INSERT INTO "django_geo_db_location" VALUES(71785,NULL,'Yachats, OR',29472,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71786,NULL,'Yachats, OR 97498',29472,222,NULL,37,42021,0);
INSERT INTO "django_geo_db_location" VALUES(71787,NULL,'Yoncalla, OR',29473,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71788,NULL,'Yoncalla, OR 97499',29473,222,NULL,37,42022,0);
INSERT INTO "django_geo_db_location" VALUES(71789,NULL,'Medford, OR',29474,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71790,NULL,'Medford, OR 97501',29474,222,NULL,37,42023,0);
INSERT INTO "django_geo_db_location" VALUES(71791,NULL,'Central Point, OR',29475,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71792,NULL,'Central Point, OR 97502',29475,222,NULL,37,42024,0);
INSERT INTO "django_geo_db_location" VALUES(71793,NULL,'White City, OR',29476,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71794,NULL,'White City, OR 97503',29476,222,NULL,37,42025,0);
INSERT INTO "django_geo_db_location" VALUES(71795,NULL,'Medford, OR 97504',29474,222,NULL,37,42026,0);
INSERT INTO "django_geo_db_location" VALUES(71796,NULL,'Ashland, OR',29477,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71797,NULL,'Ashland, OR 97520',29477,222,NULL,37,42027,0);
INSERT INTO "django_geo_db_location" VALUES(71798,NULL,'Butte Falls, OR',29478,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71799,NULL,'Butte Falls, OR 97522',29478,222,NULL,37,42028,0);
INSERT INTO "django_geo_db_location" VALUES(71800,NULL,'Cave Junction, OR',29479,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71801,NULL,'Cave Junction, OR 97523',29479,222,NULL,37,42029,0);
INSERT INTO "django_geo_db_location" VALUES(71802,NULL,'Eagle Point, OR',29480,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71803,NULL,'Eagle Point, OR 97524',29480,222,NULL,37,42030,0);
INSERT INTO "django_geo_db_location" VALUES(71804,NULL,'Gold Hill, OR',29481,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71805,NULL,'Gold Hill, OR 97525',29481,222,NULL,37,42031,0);
INSERT INTO "django_geo_db_location" VALUES(71806,NULL,'Grants Pass, OR 97526',29332,222,NULL,37,42032,0);
INSERT INTO "django_geo_db_location" VALUES(71807,NULL,'Grants Pass, OR 97527',29332,222,NULL,37,42033,0);
INSERT INTO "django_geo_db_location" VALUES(71808,NULL,'Grants Pass, OR 97528',29332,222,NULL,37,42034,0);
INSERT INTO "django_geo_db_location" VALUES(71809,NULL,'Jacksonville, OR',29482,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71810,NULL,'Jacksonville, OR 97530',29482,222,NULL,37,42035,0);
INSERT INTO "django_geo_db_location" VALUES(71811,NULL,'Kerby, OR',29483,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71812,NULL,'Kerby, OR 97531',29483,222,NULL,37,42036,0);
INSERT INTO "django_geo_db_location" VALUES(71813,NULL,'Merlin, OR',29484,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71814,NULL,'Merlin, OR 97532',29484,222,NULL,37,42037,0);
INSERT INTO "django_geo_db_location" VALUES(71815,NULL,'Murphy, OR',29485,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71816,NULL,'Murphy, OR 97533',29485,222,NULL,37,42038,0);
INSERT INTO "django_geo_db_location" VALUES(71817,NULL,'O Brien, OR',29486,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71818,NULL,'O Brien, OR 97534',29486,222,NULL,37,42039,0);
INSERT INTO "django_geo_db_location" VALUES(71819,NULL,'Phoenix, OR',29487,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71820,NULL,'Phoenix, OR 97535',29487,222,NULL,37,42040,0);
INSERT INTO "django_geo_db_location" VALUES(71821,NULL,'Prospect, OR',29488,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71822,NULL,'Prospect, OR 97536',29488,222,NULL,37,42041,0);
INSERT INTO "django_geo_db_location" VALUES(71823,NULL,'Rogue River, OR',29489,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71824,NULL,'Rogue River, OR 97537',29489,222,NULL,37,42042,0);
INSERT INTO "django_geo_db_location" VALUES(71825,NULL,'Selma, OR',29490,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71826,NULL,'Selma, OR 97538',29490,222,NULL,37,42043,0);
INSERT INTO "django_geo_db_location" VALUES(71827,NULL,'Shady Cove, OR',29491,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71828,NULL,'Shady Cove, OR 97539',29491,222,NULL,37,42044,0);
INSERT INTO "django_geo_db_location" VALUES(71829,NULL,'Talent, OR',29492,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71830,NULL,'Talent, OR 97540',29492,222,NULL,37,42045,0);
INSERT INTO "django_geo_db_location" VALUES(71831,NULL,'Trail, OR',29493,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71832,NULL,'Trail, OR 97541',29493,222,NULL,37,42046,0);
INSERT INTO "django_geo_db_location" VALUES(71833,NULL,'Wilderville, OR',29494,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71834,NULL,'Wilderville, OR 97543',29494,222,NULL,37,42047,0);
INSERT INTO "django_geo_db_location" VALUES(71835,NULL,'Williams, OR',29495,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71836,NULL,'Williams, OR 97544',29495,222,NULL,37,42048,0);
INSERT INTO "django_geo_db_location" VALUES(71837,NULL,'Lincoln City, OR 97567',29367,222,NULL,37,42049,0);
INSERT INTO "django_geo_db_location" VALUES(71838,NULL,'Lostine, OR',29496,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71839,NULL,'Lostine, OR 97587',29496,222,NULL,37,42050,0);
INSERT INTO "django_geo_db_location" VALUES(71840,NULL,'Klamath Falls, OR',29497,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71841,NULL,'Klamath Falls, OR 97601',29497,222,NULL,37,42051,0);
INSERT INTO "django_geo_db_location" VALUES(71842,NULL,'Klamath Falls, OR 97602',29497,222,NULL,37,42052,0);
INSERT INTO "django_geo_db_location" VALUES(71843,NULL,'Klamath Falls, OR 97603',29497,222,NULL,37,42053,0);
INSERT INTO "django_geo_db_location" VALUES(71844,NULL,'Crater Lake, OR',29498,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71845,NULL,'Crater Lake, OR 97604',29498,222,NULL,37,42054,0);
INSERT INTO "django_geo_db_location" VALUES(71846,NULL,'Adel, OR',29499,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71847,NULL,'Adel, OR 97620',29499,222,NULL,37,42055,0);
INSERT INTO "django_geo_db_location" VALUES(71848,NULL,'Beatty, OR',29500,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71849,NULL,'Beatty, OR 97621',29500,222,NULL,37,42056,0);
INSERT INTO "django_geo_db_location" VALUES(71850,NULL,'Bly, OR',29501,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71851,NULL,'Bly, OR 97622',29501,222,NULL,37,42057,0);
INSERT INTO "django_geo_db_location" VALUES(71852,NULL,'Bonanza, OR',29502,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71853,NULL,'Bonanza, OR 97623',29502,222,NULL,37,42058,0);
INSERT INTO "django_geo_db_location" VALUES(71854,NULL,'Chiloquin, OR 97624',29333,222,NULL,37,42059,0);
INSERT INTO "django_geo_db_location" VALUES(71855,NULL,'Dairy, OR',29503,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71856,NULL,'Dairy, OR 97625',29503,222,NULL,37,42060,0);
INSERT INTO "django_geo_db_location" VALUES(71857,NULL,'Fort Klamath, OR',29504,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71858,NULL,'Fort Klamath, OR 97626',29504,222,NULL,37,42061,0);
INSERT INTO "django_geo_db_location" VALUES(71859,NULL,'Keno, OR',29505,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71860,NULL,'Keno, OR 97627',29505,222,NULL,37,42062,0);
INSERT INTO "django_geo_db_location" VALUES(71861,NULL,'Lakeview, OR',29506,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71862,NULL,'Lakeview, OR 97630',29506,222,NULL,37,42063,0);
INSERT INTO "django_geo_db_location" VALUES(71863,NULL,'Monmouth, OR 97631',29362,222,NULL,37,42064,0);
INSERT INTO "django_geo_db_location" VALUES(71864,NULL,'Malin, OR',29507,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71865,NULL,'Malin, OR 97632',29507,222,NULL,37,42065,0);
INSERT INTO "django_geo_db_location" VALUES(71866,NULL,'Merrill, OR',29508,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71867,NULL,'Merrill, OR 97633',29508,222,NULL,37,42066,0);
INSERT INTO "django_geo_db_location" VALUES(71868,NULL,'Midland, OR',29509,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71869,NULL,'Midland, OR 97634',29509,222,NULL,37,42067,0);
INSERT INTO "django_geo_db_location" VALUES(71870,NULL,'New Pine Creek, CA',29510,222,NULL,6,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71871,NULL,'New Pine Creek, CA 97635',29510,222,NULL,6,42068,0);
INSERT INTO "django_geo_db_location" VALUES(71872,NULL,'Paisley, OR',29511,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71873,NULL,'Paisley, OR 97636',29511,222,NULL,37,42069,0);
INSERT INTO "django_geo_db_location" VALUES(71874,NULL,'Plush, OR',29512,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71875,NULL,'Plush, OR 97637',29512,222,NULL,37,42070,0);
INSERT INTO "django_geo_db_location" VALUES(71876,NULL,'Silver Lake, OR',29513,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71877,NULL,'Silver Lake, OR 97638',29513,222,NULL,37,42071,0);
INSERT INTO "django_geo_db_location" VALUES(71878,NULL,'Sprague River, OR',29514,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71879,NULL,'Sprague River, OR 97639',29514,222,NULL,37,42072,0);
INSERT INTO "django_geo_db_location" VALUES(71880,NULL,'Summer Lake, OR',29515,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71881,NULL,'Summer Lake, OR 97640',29515,222,NULL,37,42073,0);
INSERT INTO "django_geo_db_location" VALUES(71882,NULL,'Christmas Valley, OR',29516,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71883,NULL,'Christmas Valley, OR 97641',29516,222,NULL,37,42074,0);
INSERT INTO "django_geo_db_location" VALUES(71884,NULL,'Bend, OR',29517,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71885,NULL,'Bend, OR 97701',29517,222,NULL,37,42075,0);
INSERT INTO "django_geo_db_location" VALUES(71886,NULL,'Bend, OR 97702',29517,222,NULL,37,42076,0);
INSERT INTO "django_geo_db_location" VALUES(71887,NULL,'Bend, OR 97707',29517,222,NULL,37,42077,0);
INSERT INTO "django_geo_db_location" VALUES(71888,NULL,'Bend, OR 97708',29517,222,NULL,37,42078,0);
INSERT INTO "django_geo_db_location" VALUES(71889,NULL,'Bend, OR 97709',29517,222,NULL,37,42079,0);
INSERT INTO "django_geo_db_location" VALUES(71890,NULL,'Fields, OR',29518,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71891,NULL,'Fields, OR 97710',29518,222,NULL,37,42080,0);
INSERT INTO "django_geo_db_location" VALUES(71892,NULL,'Ashwood, OR',29519,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71893,NULL,'Ashwood, OR 97711',29519,222,NULL,37,42081,0);
INSERT INTO "django_geo_db_location" VALUES(71894,NULL,'Brothers, OR',29520,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71895,NULL,'Brothers, OR 97712',29520,222,NULL,37,42082,0);
INSERT INTO "django_geo_db_location" VALUES(71896,NULL,'Burns, OR',29521,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71897,NULL,'Burns, OR 97720',29521,222,NULL,37,42083,0);
INSERT INTO "django_geo_db_location" VALUES(71898,NULL,'Princeton, OR',29522,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71899,NULL,'Princeton, OR 97721',29522,222,NULL,37,42084,0);
INSERT INTO "django_geo_db_location" VALUES(71900,NULL,'Diamond, OR',29523,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71901,NULL,'Diamond, OR 97722',29523,222,NULL,37,42085,0);
INSERT INTO "django_geo_db_location" VALUES(71902,NULL,'Camp Sherman, OR',29524,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71903,NULL,'Camp Sherman, OR 97730',29524,222,NULL,37,42086,0);
INSERT INTO "django_geo_db_location" VALUES(71904,NULL,'Chemult, OR',29525,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71905,NULL,'Chemult, OR 97731',29525,222,NULL,37,42087,0);
INSERT INTO "django_geo_db_location" VALUES(71906,NULL,'Crane, OR',29526,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71907,NULL,'Crane, OR 97732',29526,222,NULL,37,42088,0);
INSERT INTO "django_geo_db_location" VALUES(71908,NULL,'Crescent, OR',29527,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71909,NULL,'Crescent, OR 97733',29527,222,NULL,37,42089,0);
INSERT INTO "django_geo_db_location" VALUES(71910,NULL,'Culver, OR',29528,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71911,NULL,'Culver, OR 97734',29528,222,NULL,37,42090,0);
INSERT INTO "django_geo_db_location" VALUES(71912,NULL,'Fort Rock, OR',29529,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71913,NULL,'Fort Rock, OR 97735',29529,222,NULL,37,42091,0);
INSERT INTO "django_geo_db_location" VALUES(71914,NULL,'Frenchglen, OR',29530,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71915,NULL,'Frenchglen, OR 97736',29530,222,NULL,37,42092,0);
INSERT INTO "django_geo_db_location" VALUES(71916,NULL,'Gilchrist, OR',29531,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71917,NULL,'Gilchrist, OR 97737',29531,222,NULL,37,42093,0);
INSERT INTO "django_geo_db_location" VALUES(71918,NULL,'Hines, OR',29532,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71919,NULL,'Hines, OR 97738',29532,222,NULL,37,42094,0);
INSERT INTO "django_geo_db_location" VALUES(71920,NULL,'La Pine, OR',29533,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71921,NULL,'La Pine, OR 97739',29533,222,NULL,37,42095,0);
INSERT INTO "django_geo_db_location" VALUES(71922,NULL,'Lawen, OR',29534,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71923,NULL,'Lawen, OR 97740',29534,222,NULL,37,42096,0);
INSERT INTO "django_geo_db_location" VALUES(71924,NULL,'Madras, OR',29535,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71925,NULL,'Madras, OR 97741',29535,222,NULL,37,42097,0);
INSERT INTO "django_geo_db_location" VALUES(71926,NULL,'Mitchell, OR',29536,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71927,NULL,'Mitchell, OR 97750',29536,222,NULL,37,42098,0);
INSERT INTO "django_geo_db_location" VALUES(71928,NULL,'Paulina, OR',29537,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71929,NULL,'Paulina, OR 97751',29537,222,NULL,37,42099,0);
INSERT INTO "django_geo_db_location" VALUES(71930,NULL,'Post, OR',29538,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71931,NULL,'Post, OR 97752',29538,222,NULL,37,42100,0);
INSERT INTO "django_geo_db_location" VALUES(71932,NULL,'Powell Butte, OR',29539,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71933,NULL,'Powell Butte, OR 97753',29539,222,NULL,37,42101,0);
INSERT INTO "django_geo_db_location" VALUES(71934,NULL,'Prineville, OR',29540,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71935,NULL,'Prineville, OR 97754',29540,222,NULL,37,42102,0);
INSERT INTO "django_geo_db_location" VALUES(71936,NULL,'Redmond, OR',29541,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71937,NULL,'Redmond, OR 97756',29541,222,NULL,37,42103,0);
INSERT INTO "django_geo_db_location" VALUES(71938,NULL,'Riley, OR',29542,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71939,NULL,'Riley, OR 97758',29542,222,NULL,37,42104,0);
INSERT INTO "django_geo_db_location" VALUES(71940,NULL,'Sisters, OR',29543,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71941,NULL,'Sisters, OR 97759',29543,222,NULL,37,42105,0);
INSERT INTO "django_geo_db_location" VALUES(71942,NULL,'Terrebonne, OR',29544,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71943,NULL,'Terrebonne, OR 97760',29544,222,NULL,37,42106,0);
INSERT INTO "django_geo_db_location" VALUES(71944,NULL,'Warm Springs, OR',29545,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71945,NULL,'Warm Springs, OR 97761',29545,222,NULL,37,42107,0);
INSERT INTO "django_geo_db_location" VALUES(71946,NULL,'Roseburg North, OR',29546,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71947,NULL,'Roseburg North, OR 97795',29546,222,NULL,37,42108,0);
INSERT INTO "django_geo_db_location" VALUES(71948,NULL,'Pendleton, OR',29547,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71949,NULL,'Pendleton, OR 97801',29547,222,NULL,37,42109,0);
INSERT INTO "django_geo_db_location" VALUES(71950,NULL,'Adams, OR',29548,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71951,NULL,'Adams, OR 97810',29548,222,NULL,37,42110,0);
INSERT INTO "django_geo_db_location" VALUES(71952,NULL,'Arlington, OR',29549,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71953,NULL,'Arlington, OR 97812',29549,222,NULL,37,42111,0);
INSERT INTO "django_geo_db_location" VALUES(71954,NULL,'Athena, OR',29550,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71955,NULL,'Athena, OR 97813',29550,222,NULL,37,42112,0);
INSERT INTO "django_geo_db_location" VALUES(71956,NULL,'Baker City, OR',29551,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71957,NULL,'Baker City, OR 97814',29551,222,NULL,37,42113,0);
INSERT INTO "django_geo_db_location" VALUES(71958,NULL,'Bates, OR',29552,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71959,NULL,'Bates, OR 97817',29552,222,NULL,37,42114,0);
INSERT INTO "django_geo_db_location" VALUES(71960,NULL,'Boardman, OR',29553,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71961,NULL,'Boardman, OR 97818',29553,222,NULL,37,42115,0);
INSERT INTO "django_geo_db_location" VALUES(71962,NULL,'Bridgeport, OR',29554,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71963,NULL,'Bridgeport, OR 97819',29554,222,NULL,37,42116,0);
INSERT INTO "django_geo_db_location" VALUES(71964,NULL,'Canyon City, OR',29555,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71965,NULL,'Canyon City, OR 97820',29555,222,NULL,37,42117,0);
INSERT INTO "django_geo_db_location" VALUES(71966,NULL,'Cayuse, OR',29556,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71967,NULL,'Cayuse, OR 97821',29556,222,NULL,37,42118,0);
INSERT INTO "django_geo_db_location" VALUES(71968,NULL,'Condon, OR',29557,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71969,NULL,'Condon, OR 97823',29557,222,NULL,37,42119,0);
INSERT INTO "django_geo_db_location" VALUES(71970,NULL,'Cove, OR',29558,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71971,NULL,'Cove, OR 97824',29558,222,NULL,37,42120,0);
INSERT INTO "django_geo_db_location" VALUES(71972,NULL,'Dayville, OR',29559,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71973,NULL,'Dayville, OR 97825',29559,222,NULL,37,42121,0);
INSERT INTO "django_geo_db_location" VALUES(71974,NULL,'Echo, OR',29560,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71975,NULL,'Echo, OR 97826',29560,222,NULL,37,42122,0);
INSERT INTO "django_geo_db_location" VALUES(71976,NULL,'Elgin, OR',29561,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71977,NULL,'Elgin, OR 97827',29561,222,NULL,37,42123,0);
INSERT INTO "django_geo_db_location" VALUES(71978,NULL,'Enterprise, OR',29562,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71979,NULL,'Enterprise, OR 97828',29562,222,NULL,37,42124,0);
INSERT INTO "django_geo_db_location" VALUES(71980,NULL,'Fossil, OR',29563,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71981,NULL,'Fossil, OR 97830',29563,222,NULL,37,42125,0);
INSERT INTO "django_geo_db_location" VALUES(71982,NULL,'Fox, OR',29564,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71983,NULL,'Fox, OR 97831',29564,222,NULL,37,42126,0);
INSERT INTO "django_geo_db_location" VALUES(71984,NULL,'Haines, OR',29565,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71985,NULL,'Haines, OR 97833',29565,222,NULL,37,42127,0);
INSERT INTO "django_geo_db_location" VALUES(71986,NULL,'Halfway, OR',29566,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71987,NULL,'Halfway, OR 97834',29566,222,NULL,37,42128,0);
INSERT INTO "django_geo_db_location" VALUES(71988,NULL,'Helix, OR',29567,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71989,NULL,'Helix, OR 97835',29567,222,NULL,37,42129,0);
INSERT INTO "django_geo_db_location" VALUES(71990,NULL,'Heppner, OR',29568,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71991,NULL,'Heppner, OR 97836',29568,222,NULL,37,42130,0);
INSERT INTO "django_geo_db_location" VALUES(71992,NULL,'Hereford, OR',29569,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71993,NULL,'Hereford, OR 97837',29569,222,NULL,37,42131,0);
INSERT INTO "django_geo_db_location" VALUES(71994,NULL,'Hermiston, OR',29570,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71995,NULL,'Hermiston, OR 97838',29570,222,NULL,37,42132,0);
INSERT INTO "django_geo_db_location" VALUES(71996,NULL,'Lexington, OR',29571,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71997,NULL,'Lexington, OR 97839',29571,222,NULL,37,42133,0);
INSERT INTO "django_geo_db_location" VALUES(71998,NULL,'Oxbow, OR',29572,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(71999,NULL,'Oxbow, OR 97840',29572,222,NULL,37,42134,0);
INSERT INTO "django_geo_db_location" VALUES(72000,NULL,'Imbler, OR',29573,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72001,NULL,'Imbler, OR 97841',29573,222,NULL,37,42135,0);
INSERT INTO "django_geo_db_location" VALUES(72002,NULL,'Imnaha, OR',29574,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72003,NULL,'Imnaha, OR 97842',29574,222,NULL,37,42136,0);
INSERT INTO "django_geo_db_location" VALUES(72004,NULL,'Ione, OR',29575,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72005,NULL,'Ione, OR 97843',29575,222,NULL,37,42137,0);
INSERT INTO "django_geo_db_location" VALUES(72006,NULL,'Irrigon, OR',29576,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72007,NULL,'Irrigon, OR 97844',29576,222,NULL,37,42138,0);
INSERT INTO "django_geo_db_location" VALUES(72008,NULL,'John Day, OR',29577,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72009,NULL,'John Day, OR 97845',29577,222,NULL,37,42139,0);
INSERT INTO "django_geo_db_location" VALUES(72010,NULL,'Joseph, OR',29578,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72011,NULL,'Joseph, OR 97846',29578,222,NULL,37,42140,0);
INSERT INTO "django_geo_db_location" VALUES(72012,NULL,'Kimberly, OR',29579,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72013,NULL,'Kimberly, OR 97848',29579,222,NULL,37,42141,0);
INSERT INTO "django_geo_db_location" VALUES(72014,NULL,'La Grande, OR',29580,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72015,NULL,'La Grande, OR 97850',29580,222,NULL,37,42142,0);
INSERT INTO "django_geo_db_location" VALUES(72016,NULL,'Long Creek, OR',29581,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72017,NULL,'Long Creek, OR 97856',29581,222,NULL,37,42143,0);
INSERT INTO "django_geo_db_location" VALUES(72018,NULL,'Lostine, OR 97857',29496,222,NULL,37,42144,0);
INSERT INTO "django_geo_db_location" VALUES(72019,NULL,'Meacham, OR',29582,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72020,NULL,'Meacham, OR 97859',29582,222,NULL,37,42145,0);
INSERT INTO "django_geo_db_location" VALUES(72021,NULL,'Mikkalo, OR',29583,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72022,NULL,'Mikkalo, OR 97861',29583,222,NULL,37,42146,0);
INSERT INTO "django_geo_db_location" VALUES(72023,NULL,'Milton Freewater, OR',29584,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72024,NULL,'Milton Freewater, OR 97862',29584,222,NULL,37,42147,0);
INSERT INTO "django_geo_db_location" VALUES(72025,NULL,'Monument, OR',29585,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72026,NULL,'Monument, OR 97864',29585,222,NULL,37,42148,0);
INSERT INTO "django_geo_db_location" VALUES(72027,NULL,'Mount Vernon, OR',29586,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72028,NULL,'Mount Vernon, OR 97865',29586,222,NULL,37,42149,0);
INSERT INTO "django_geo_db_location" VALUES(72029,NULL,'North Powder, OR',29587,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72030,NULL,'North Powder, OR 97867',29587,222,NULL,37,42150,0);
INSERT INTO "django_geo_db_location" VALUES(72031,NULL,'Pilot Rock, OR',29588,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72032,NULL,'Pilot Rock, OR 97868',29588,222,NULL,37,42151,0);
INSERT INTO "django_geo_db_location" VALUES(72033,NULL,'Prairie City, OR',29589,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72034,NULL,'Prairie City, OR 97869',29589,222,NULL,37,42152,0);
INSERT INTO "django_geo_db_location" VALUES(72035,NULL,'Richland, OR',29590,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72036,NULL,'Richland, OR 97870',29590,222,NULL,37,42153,0);
INSERT INTO "django_geo_db_location" VALUES(72037,NULL,'Ritter, OR',29591,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72038,NULL,'Ritter, OR 97872',29591,222,NULL,37,42154,0);
INSERT INTO "django_geo_db_location" VALUES(72039,NULL,'Seneca, OR',29592,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72040,NULL,'Seneca, OR 97873',29592,222,NULL,37,42155,0);
INSERT INTO "django_geo_db_location" VALUES(72041,NULL,'Spray, OR',29593,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72042,NULL,'Spray, OR 97874',29593,222,NULL,37,42156,0);
INSERT INTO "django_geo_db_location" VALUES(72043,NULL,'Stanfield, OR',29594,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72044,NULL,'Stanfield, OR 97875',29594,222,NULL,37,42157,0);
INSERT INTO "django_geo_db_location" VALUES(72045,NULL,'Summerville, OR',29595,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72046,NULL,'Summerville, OR 97876',29595,222,NULL,37,42158,0);
INSERT INTO "django_geo_db_location" VALUES(72047,NULL,'Sumpter, OR',29596,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72048,NULL,'Sumpter, OR 97877',29596,222,NULL,37,42159,0);
INSERT INTO "django_geo_db_location" VALUES(72049,NULL,'Ukiah, OR',29597,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72050,NULL,'Ukiah, OR 97880',29597,222,NULL,37,42160,0);
INSERT INTO "django_geo_db_location" VALUES(72051,NULL,'Umatilla, OR',29598,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72052,NULL,'Umatilla, OR 97882',29598,222,NULL,37,42161,0);
INSERT INTO "django_geo_db_location" VALUES(72053,NULL,'Union, OR',29599,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72054,NULL,'Union, OR 97883',29599,222,NULL,37,42162,0);
INSERT INTO "django_geo_db_location" VALUES(72055,NULL,'Unity, OR',29600,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72056,NULL,'Unity, OR 97884',29600,222,NULL,37,42163,0);
INSERT INTO "django_geo_db_location" VALUES(72057,NULL,'Wallowa, OR',29601,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72058,NULL,'Wallowa, OR 97885',29601,222,NULL,37,42164,0);
INSERT INTO "django_geo_db_location" VALUES(72059,NULL,'Weston, OR',29602,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72060,NULL,'Weston, OR 97886',29602,222,NULL,37,42165,0);
INSERT INTO "django_geo_db_location" VALUES(72061,NULL,'Adrian, OR',29603,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72062,NULL,'Adrian, OR 97901',29603,222,NULL,37,42166,0);
INSERT INTO "django_geo_db_location" VALUES(72063,NULL,'Arock, OR',29604,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72064,NULL,'Arock, OR 97902',29604,222,NULL,37,42167,0);
INSERT INTO "django_geo_db_location" VALUES(72065,NULL,'Brogan, OR',29605,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72066,NULL,'Brogan, OR 97903',29605,222,NULL,37,42168,0);
INSERT INTO "django_geo_db_location" VALUES(72067,NULL,'Drewsey, OR',29606,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72068,NULL,'Drewsey, OR 97904',29606,222,NULL,37,42169,0);
INSERT INTO "django_geo_db_location" VALUES(72069,NULL,'Durkee, OR',29607,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72070,NULL,'Durkee, OR 97905',29607,222,NULL,37,42170,0);
INSERT INTO "django_geo_db_location" VALUES(72071,NULL,'Harper, OR',29608,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72072,NULL,'Harper, OR 97906',29608,222,NULL,37,42171,0);
INSERT INTO "django_geo_db_location" VALUES(72073,NULL,'Huntington, OR',29609,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72074,NULL,'Huntington, OR 97907',29609,222,NULL,37,42172,0);
INSERT INTO "django_geo_db_location" VALUES(72075,NULL,'Ironside, OR',29610,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72076,NULL,'Ironside, OR 97908',29610,222,NULL,37,42173,0);
INSERT INTO "django_geo_db_location" VALUES(72077,NULL,'Jamieson, OR',29611,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72078,NULL,'Jamieson, OR 97909',29611,222,NULL,37,42174,0);
INSERT INTO "django_geo_db_location" VALUES(72079,NULL,'Jordan Valley, ID',29612,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72080,NULL,'Jordan Valley, ID 97910',29612,222,NULL,16,42175,0);
INSERT INTO "django_geo_db_location" VALUES(72081,NULL,'Juntura, OR',29613,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72082,NULL,'Juntura, OR 97911',29613,222,NULL,37,42176,0);
INSERT INTO "django_geo_db_location" VALUES(72083,NULL,'Nyssa, ID',29614,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72084,NULL,'Nyssa, ID 97913',29614,222,NULL,16,42177,0);
INSERT INTO "django_geo_db_location" VALUES(72085,NULL,'Ontario, OR',29615,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72086,NULL,'Ontario, OR 97914',29615,222,NULL,37,42178,0);
INSERT INTO "django_geo_db_location" VALUES(72087,NULL,'Riverside, OR',29616,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72088,NULL,'Riverside, OR 97917',29616,222,NULL,37,42179,0);
INSERT INTO "django_geo_db_location" VALUES(72089,NULL,'Vale, OR',29617,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72090,NULL,'Vale, OR 97918',29617,222,NULL,37,42180,0);
INSERT INTO "django_geo_db_location" VALUES(72091,NULL,'Westfall, OR',29618,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72092,NULL,'Westfall, OR 97920',29618,222,NULL,37,42181,0);
INSERT INTO "django_geo_db_location" VALUES(72093,NULL,'Auburn, WA',29619,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72094,NULL,'Auburn, WA 98001',29619,222,NULL,56,42182,0);
INSERT INTO "django_geo_db_location" VALUES(72095,NULL,'Auburn, WA 98002',29619,222,NULL,56,42183,0);
INSERT INTO "django_geo_db_location" VALUES(72096,NULL,'Federal Way, WA',29620,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72097,NULL,'Federal Way, WA 98003',29620,222,NULL,56,42184,0);
INSERT INTO "django_geo_db_location" VALUES(72098,NULL,'Bellevue, WA',29621,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72099,NULL,'Bellevue, WA 98004',29621,222,NULL,56,42185,0);
INSERT INTO "django_geo_db_location" VALUES(72100,NULL,'Bellevue, WA 98005',29621,222,NULL,56,42186,0);
INSERT INTO "django_geo_db_location" VALUES(72101,NULL,'Bellevue, WA 98006',29621,222,NULL,56,42187,0);
INSERT INTO "django_geo_db_location" VALUES(72102,NULL,'Bellevue, WA 98007',29621,222,NULL,56,42188,0);
INSERT INTO "django_geo_db_location" VALUES(72103,NULL,'Bellevue, WA 98008',29621,222,NULL,56,42189,0);
INSERT INTO "django_geo_db_location" VALUES(72104,NULL,'Bellevue, WA 98009',29621,222,NULL,56,42190,0);
INSERT INTO "django_geo_db_location" VALUES(72105,NULL,'Black Diamond, WA',29622,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72106,NULL,'Black Diamond, WA 98010',29622,222,NULL,56,42191,0);
INSERT INTO "django_geo_db_location" VALUES(72107,NULL,'Bothell, WA',29623,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72108,NULL,'Bothell, WA 98011',29623,222,NULL,56,42192,0);
INSERT INTO "django_geo_db_location" VALUES(72109,NULL,'Bothell, WA 98012',29623,222,NULL,56,42193,0);
INSERT INTO "django_geo_db_location" VALUES(72110,NULL,'Burton, WA',29624,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72111,NULL,'Burton, WA 98013',29624,222,NULL,56,42194,0);
INSERT INTO "django_geo_db_location" VALUES(72112,NULL,'Carnation, WA',29625,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72113,NULL,'Carnation, WA 98014',29625,222,NULL,56,42195,0);
INSERT INTO "django_geo_db_location" VALUES(72114,NULL,'Bellevue, WA 98015',29621,222,NULL,56,42196,0);
INSERT INTO "django_geo_db_location" VALUES(72115,NULL,'Duvall, WA',29626,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72116,NULL,'Duvall, WA 98019',29626,222,NULL,56,42197,0);
INSERT INTO "django_geo_db_location" VALUES(72117,NULL,'Edmonds, WA',29627,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72118,NULL,'Edmonds, WA 98020',29627,222,NULL,56,42198,0);
INSERT INTO "django_geo_db_location" VALUES(72119,NULL,'Bothell, WA 98021',29623,222,NULL,56,42199,0);
INSERT INTO "django_geo_db_location" VALUES(72120,NULL,'Enumclaw, WA',29628,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72121,NULL,'Enumclaw, WA 98022',29628,222,NULL,56,42200,0);
INSERT INTO "django_geo_db_location" VALUES(72122,NULL,'Federal Way, WA 98023',29620,222,NULL,56,42201,0);
INSERT INTO "django_geo_db_location" VALUES(72123,NULL,'Fall City, WA',29629,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72124,NULL,'Fall City, WA 98024',29629,222,NULL,56,42202,0);
INSERT INTO "django_geo_db_location" VALUES(72125,NULL,'Hobart, WA',29630,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72126,NULL,'Hobart, WA 98025',29630,222,NULL,56,42203,0);
INSERT INTO "django_geo_db_location" VALUES(72127,NULL,'Edmonds, WA 98026',29627,222,NULL,56,42204,0);
INSERT INTO "django_geo_db_location" VALUES(72128,NULL,'Issaquah, WA',29631,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72129,NULL,'Issaquah, WA 98027',29631,222,NULL,56,42205,0);
INSERT INTO "django_geo_db_location" VALUES(72130,NULL,'Kenmore, WA',29632,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72131,NULL,'Kenmore, WA 98028',29632,222,NULL,56,42206,0);
INSERT INTO "django_geo_db_location" VALUES(72132,NULL,'Issaquah, WA 98029',29631,222,NULL,56,42207,0);
INSERT INTO "django_geo_db_location" VALUES(72133,NULL,'Kent, WA',29633,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72134,NULL,'Kent, WA 98030',29633,222,NULL,56,42208,0);
INSERT INTO "django_geo_db_location" VALUES(72135,NULL,'Kent, WA 98031',29633,222,NULL,56,42209,0);
INSERT INTO "django_geo_db_location" VALUES(72136,NULL,'Kent, WA 98032',29633,222,NULL,56,42210,0);
INSERT INTO "django_geo_db_location" VALUES(72137,NULL,'Kirkland, WA',29634,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72138,NULL,'Kirkland, WA 98033',29634,222,NULL,56,42211,0);
INSERT INTO "django_geo_db_location" VALUES(72139,NULL,'Kirkland, WA 98034',29634,222,NULL,56,42212,0);
INSERT INTO "django_geo_db_location" VALUES(72140,NULL,'Kent, WA 98035',29633,222,NULL,56,42213,0);
INSERT INTO "django_geo_db_location" VALUES(72141,NULL,'Lynnwood, WA',29635,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72142,NULL,'Lynnwood, WA 98036',29635,222,NULL,56,42214,0);
INSERT INTO "django_geo_db_location" VALUES(72143,NULL,'Lynnwood, WA 98037',29635,222,NULL,56,42215,0);
INSERT INTO "django_geo_db_location" VALUES(72144,NULL,'Maple Valley, WA',29636,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72145,NULL,'Maple Valley, WA 98038',29636,222,NULL,56,42216,0);
INSERT INTO "django_geo_db_location" VALUES(72146,NULL,'Medina, WA',29637,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72147,NULL,'Medina, WA 98039',29637,222,NULL,56,42217,0);
INSERT INTO "django_geo_db_location" VALUES(72148,NULL,'Mercer Island, WA',29638,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72149,NULL,'Mercer Island, WA 98040',29638,222,NULL,56,42218,0);
INSERT INTO "django_geo_db_location" VALUES(72150,NULL,'Bothell, WA 98041',29623,222,NULL,56,42219,0);
INSERT INTO "django_geo_db_location" VALUES(72151,NULL,'Kent, WA 98042',29633,222,NULL,56,42220,0);
INSERT INTO "django_geo_db_location" VALUES(72152,NULL,'Mountlake Terrace, WA',29639,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72153,NULL,'Mountlake Terrace, WA 98043',29639,222,NULL,56,42221,0);
INSERT INTO "django_geo_db_location" VALUES(72154,NULL,'North Bend, WA',29640,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72155,NULL,'North Bend, WA 98045',29640,222,NULL,56,42222,0);
INSERT INTO "django_geo_db_location" VALUES(72156,NULL,'Lynnwood, WA 98046',29635,222,NULL,56,42223,0);
INSERT INTO "django_geo_db_location" VALUES(72157,NULL,'Pacific, WA',29641,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72158,NULL,'Pacific, WA 98047',29641,222,NULL,56,42224,0);
INSERT INTO "django_geo_db_location" VALUES(72159,NULL,'Preston, WA',29642,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72160,NULL,'Preston, WA 98050',29642,222,NULL,56,42225,0);
INSERT INTO "django_geo_db_location" VALUES(72161,NULL,'Ravensdale, WA',29643,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72162,NULL,'Ravensdale, WA 98051',29643,222,NULL,56,42226,0);
INSERT INTO "django_geo_db_location" VALUES(72163,NULL,'Redmond, WA',29644,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72164,NULL,'Redmond, WA 98052',29644,222,NULL,56,42227,0);
INSERT INTO "django_geo_db_location" VALUES(72165,NULL,'Redmond, WA 98053',29644,222,NULL,56,42228,0);
INSERT INTO "django_geo_db_location" VALUES(72166,NULL,'Redondo, WA',29645,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72167,NULL,'Redondo, WA 98054',29645,222,NULL,56,42229,0);
INSERT INTO "django_geo_db_location" VALUES(72168,NULL,'Renton, WA',29646,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72169,NULL,'Renton, WA 98055',29646,222,NULL,56,42230,0);
INSERT INTO "django_geo_db_location" VALUES(72170,NULL,'Renton, WA 98056',29646,222,NULL,56,42231,0);
INSERT INTO "django_geo_db_location" VALUES(72171,NULL,'Renton, WA 98057',29646,222,NULL,56,42232,0);
INSERT INTO "django_geo_db_location" VALUES(72172,NULL,'Renton, WA 98058',29646,222,NULL,56,42233,0);
INSERT INTO "django_geo_db_location" VALUES(72173,NULL,'Renton, WA 98059',29646,222,NULL,56,42234,0);
INSERT INTO "django_geo_db_location" VALUES(72174,NULL,'Seattle, WA',29647,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72175,NULL,'Seattle, WA 98060',29647,222,NULL,56,42235,0);
INSERT INTO "django_geo_db_location" VALUES(72176,NULL,'Rollingbay, WA',29648,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72177,NULL,'Rollingbay, WA 98061',29648,222,NULL,56,42236,0);
INSERT INTO "django_geo_db_location" VALUES(72178,NULL,'Seahurst, WA',29649,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72179,NULL,'Seahurst, WA 98062',29649,222,NULL,56,42237,0);
INSERT INTO "django_geo_db_location" VALUES(72180,NULL,'Federal Way, WA 98063',29620,222,NULL,56,42238,0);
INSERT INTO "django_geo_db_location" VALUES(72181,NULL,'Kent, WA 98064',29633,222,NULL,56,42239,0);
INSERT INTO "django_geo_db_location" VALUES(72182,NULL,'Snoqualmie, WA',29650,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72183,NULL,'Snoqualmie, WA 98065',29650,222,NULL,56,42240,0);
INSERT INTO "django_geo_db_location" VALUES(72184,NULL,'Bellevue, WA 98067',29621,222,NULL,56,42241,0);
INSERT INTO "django_geo_db_location" VALUES(72185,NULL,'Snoqualmie Pass, WA',29651,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72186,NULL,'Snoqualmie Pass, WA 98068',29651,222,NULL,56,42242,0);
INSERT INTO "django_geo_db_location" VALUES(72187,NULL,'Vashon, WA',29652,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72188,NULL,'Vashon, WA 98070',29652,222,NULL,56,42243,0);
INSERT INTO "django_geo_db_location" VALUES(72189,NULL,'Auburn, WA 98071',29619,222,NULL,56,42244,0);
INSERT INTO "django_geo_db_location" VALUES(72190,NULL,'Woodinville, WA',29653,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72191,NULL,'Woodinville, WA 98072',29653,222,NULL,56,42245,0);
INSERT INTO "django_geo_db_location" VALUES(72192,NULL,'Redmond, WA 98073',29644,222,NULL,56,42246,0);
INSERT INTO "django_geo_db_location" VALUES(72193,NULL,'Sammamish, WA',29654,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72194,NULL,'Sammamish, WA 98074',29654,222,NULL,56,42247,0);
INSERT INTO "django_geo_db_location" VALUES(72195,NULL,'Sammamish, WA 98075',29654,222,NULL,56,42248,0);
INSERT INTO "django_geo_db_location" VALUES(72196,NULL,'Bothell, WA 98082',29623,222,NULL,56,42249,0);
INSERT INTO "django_geo_db_location" VALUES(72197,NULL,'Kirkland, WA 98083',29634,222,NULL,56,42250,0);
INSERT INTO "django_geo_db_location" VALUES(72198,NULL,'Auburn, WA 98092',29619,222,NULL,56,42251,0);
INSERT INTO "django_geo_db_location" VALUES(72199,NULL,'Federal Way, WA 98093',29620,222,NULL,56,42252,0);
INSERT INTO "django_geo_db_location" VALUES(72200,NULL,'Seattle, WA 98101',29647,222,NULL,56,42253,0);
INSERT INTO "django_geo_db_location" VALUES(72201,NULL,'Seattle, WA 98102',29647,222,NULL,56,42254,0);
INSERT INTO "django_geo_db_location" VALUES(72202,NULL,'Seattle, WA 98103',29647,222,NULL,56,42255,0);
INSERT INTO "django_geo_db_location" VALUES(72203,NULL,'Seattle, WA 98104',29647,222,NULL,56,42256,0);
INSERT INTO "django_geo_db_location" VALUES(72204,NULL,'Seattle, WA 98105',29647,222,NULL,56,42257,0);
INSERT INTO "django_geo_db_location" VALUES(72205,NULL,'Seattle, WA 98106',29647,222,NULL,56,42258,0);
INSERT INTO "django_geo_db_location" VALUES(72206,NULL,'Seattle, WA 98107',29647,222,NULL,56,42259,0);
INSERT INTO "django_geo_db_location" VALUES(72207,NULL,'Seattle, WA 98108',29647,222,NULL,56,42260,0);
INSERT INTO "django_geo_db_location" VALUES(72208,NULL,'Seattle, WA 98109',29647,222,NULL,56,42261,0);
INSERT INTO "django_geo_db_location" VALUES(72209,NULL,'Bainbridge Island, WA',29655,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72210,NULL,'Bainbridge Island, WA 98110',29655,222,NULL,56,42262,0);
INSERT INTO "django_geo_db_location" VALUES(72211,NULL,'Seattle, WA 98111',29647,222,NULL,56,42263,0);
INSERT INTO "django_geo_db_location" VALUES(72212,NULL,'Seattle, WA 98112',29647,222,NULL,56,42264,0);
INSERT INTO "django_geo_db_location" VALUES(72213,NULL,'Shoreline, WA',29656,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72214,NULL,'Shoreline, WA 98113',29656,222,NULL,56,42265,0);
INSERT INTO "django_geo_db_location" VALUES(72215,NULL,'Seattle, WA 98114',29647,222,NULL,56,42266,0);
INSERT INTO "django_geo_db_location" VALUES(72216,NULL,'Seattle, WA 98115',29647,222,NULL,56,42267,0);
INSERT INTO "django_geo_db_location" VALUES(72217,NULL,'Seattle, WA 98116',29647,222,NULL,56,42268,0);
INSERT INTO "django_geo_db_location" VALUES(72218,NULL,'Seattle, WA 98117',29647,222,NULL,56,42269,0);
INSERT INTO "django_geo_db_location" VALUES(72219,NULL,'Seattle, WA 98118',29647,222,NULL,56,42270,0);
INSERT INTO "django_geo_db_location" VALUES(72220,NULL,'Seattle, WA 98119',29647,222,NULL,56,42271,0);
INSERT INTO "django_geo_db_location" VALUES(72221,NULL,'Seattle, WA 98121',29647,222,NULL,56,42272,0);
INSERT INTO "django_geo_db_location" VALUES(72222,NULL,'Seattle, WA 98122',29647,222,NULL,56,42273,0);
INSERT INTO "django_geo_db_location" VALUES(72223,NULL,'Seattle, WA 98124',29647,222,NULL,56,42274,0);
INSERT INTO "django_geo_db_location" VALUES(72224,NULL,'Seattle, WA 98125',29647,222,NULL,56,42275,0);
INSERT INTO "django_geo_db_location" VALUES(72225,NULL,'Seattle, WA 98126',29647,222,NULL,56,42276,0);
INSERT INTO "django_geo_db_location" VALUES(72226,NULL,'Seattle, WA 98129',29647,222,NULL,56,42277,0);
INSERT INTO "django_geo_db_location" VALUES(72227,NULL,'Seattle, WA 98130',29647,222,NULL,56,42278,0);
INSERT INTO "django_geo_db_location" VALUES(72228,NULL,'Seattle, WA 98131',29647,222,NULL,56,42279,0);
INSERT INTO "django_geo_db_location" VALUES(72229,NULL,'Seattle, WA 98132',29647,222,NULL,56,42280,0);
INSERT INTO "django_geo_db_location" VALUES(72230,NULL,'Seattle, WA 98133',29647,222,NULL,56,42281,0);
INSERT INTO "django_geo_db_location" VALUES(72231,NULL,'Seattle, WA 98134',29647,222,NULL,56,42282,0);
INSERT INTO "django_geo_db_location" VALUES(72232,NULL,'Seattle, WA 98136',29647,222,NULL,56,42283,0);
INSERT INTO "django_geo_db_location" VALUES(72233,NULL,'Seattle, WA 98138',29647,222,NULL,56,42284,0);
INSERT INTO "django_geo_db_location" VALUES(72234,NULL,'Seattle, WA 98140',29647,222,NULL,56,42285,0);
INSERT INTO "django_geo_db_location" VALUES(72235,NULL,'Seattle, WA 98144',29647,222,NULL,56,42286,0);
INSERT INTO "django_geo_db_location" VALUES(72236,NULL,'Seattle, WA 98145',29647,222,NULL,56,42287,0);
INSERT INTO "django_geo_db_location" VALUES(72237,NULL,'Seattle, WA 98146',29647,222,NULL,56,42288,0);
INSERT INTO "django_geo_db_location" VALUES(72238,NULL,'Seattle, WA 98148',29647,222,NULL,56,42289,0);
INSERT INTO "django_geo_db_location" VALUES(72239,NULL,'Seattle, WA 98150',29647,222,NULL,56,42290,0);
INSERT INTO "django_geo_db_location" VALUES(72240,NULL,'Seattle, WA 98151',29647,222,NULL,56,42291,0);
INSERT INTO "django_geo_db_location" VALUES(72241,NULL,'Seattle, WA 98154',29647,222,NULL,56,42292,0);
INSERT INTO "django_geo_db_location" VALUES(72242,NULL,'Seattle, WA 98155',29647,222,NULL,56,42293,0);
INSERT INTO "django_geo_db_location" VALUES(72243,NULL,'Seattle, WA 98158',29647,222,NULL,56,42294,0);
INSERT INTO "django_geo_db_location" VALUES(72244,NULL,'Seattle, WA 98160',29647,222,NULL,56,42295,0);
INSERT INTO "django_geo_db_location" VALUES(72245,NULL,'Seattle, WA 98161',29647,222,NULL,56,42296,0);
INSERT INTO "django_geo_db_location" VALUES(72246,NULL,'Seattle, WA 98164',29647,222,NULL,56,42297,0);
INSERT INTO "django_geo_db_location" VALUES(72247,NULL,'Seattle, WA 98166',29647,222,NULL,56,42298,0);
INSERT INTO "django_geo_db_location" VALUES(72248,NULL,'Seattle, WA 98168',29647,222,NULL,56,42299,0);
INSERT INTO "django_geo_db_location" VALUES(72249,NULL,'Seattle, WA 98171',29647,222,NULL,56,42300,0);
INSERT INTO "django_geo_db_location" VALUES(72250,NULL,'Seattle, WA 98174',29647,222,NULL,56,42301,0);
INSERT INTO "django_geo_db_location" VALUES(72251,NULL,'Seattle, WA 98177',29647,222,NULL,56,42302,0);
INSERT INTO "django_geo_db_location" VALUES(72252,NULL,'Seattle, WA 98178',29647,222,NULL,56,42303,0);
INSERT INTO "django_geo_db_location" VALUES(72253,NULL,'Seattle, WA 98181',29647,222,NULL,56,42304,0);
INSERT INTO "django_geo_db_location" VALUES(72254,NULL,'Seattle, WA 98184',29647,222,NULL,56,42305,0);
INSERT INTO "django_geo_db_location" VALUES(72255,NULL,'Seattle, WA 98185',29647,222,NULL,56,42306,0);
INSERT INTO "django_geo_db_location" VALUES(72256,NULL,'Seattle, WA 98188',29647,222,NULL,56,42307,0);
INSERT INTO "django_geo_db_location" VALUES(72257,NULL,'Seattle, WA 98190',29647,222,NULL,56,42308,0);
INSERT INTO "django_geo_db_location" VALUES(72258,NULL,'Seattle, WA 98191',29647,222,NULL,56,42309,0);
INSERT INTO "django_geo_db_location" VALUES(72259,NULL,'Seattle, WA 98195',29647,222,NULL,56,42310,0);
INSERT INTO "django_geo_db_location" VALUES(72260,NULL,'Seattle, WA 98198',29647,222,NULL,56,42311,0);
INSERT INTO "django_geo_db_location" VALUES(72261,NULL,'Seattle, WA 98199',29647,222,NULL,56,42312,0);
INSERT INTO "django_geo_db_location" VALUES(72262,NULL,'Everett, WA',29657,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72263,NULL,'Everett, WA 98201',29657,222,NULL,56,42313,0);
INSERT INTO "django_geo_db_location" VALUES(72264,NULL,'Everett, WA 98203',29657,222,NULL,56,42314,0);
INSERT INTO "django_geo_db_location" VALUES(72265,NULL,'Everett, WA 98204',29657,222,NULL,56,42315,0);
INSERT INTO "django_geo_db_location" VALUES(72266,NULL,'Everett, WA 98205',29657,222,NULL,56,42316,0);
INSERT INTO "django_geo_db_location" VALUES(72267,NULL,'Everett, WA 98206',29657,222,NULL,56,42317,0);
INSERT INTO "django_geo_db_location" VALUES(72268,NULL,'Everett, WA 98207',29657,222,NULL,56,42318,0);
INSERT INTO "django_geo_db_location" VALUES(72269,NULL,'Everett, WA 98208',29657,222,NULL,56,42319,0);
INSERT INTO "django_geo_db_location" VALUES(72270,NULL,'Acme, WA',29658,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72271,NULL,'Acme, WA 98220',29658,222,NULL,56,42320,0);
INSERT INTO "django_geo_db_location" VALUES(72272,NULL,'Anacortes, WA',29659,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72273,NULL,'Anacortes, WA 98221',29659,222,NULL,56,42321,0);
INSERT INTO "django_geo_db_location" VALUES(72274,NULL,'Blakely Island, WA',29660,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72275,NULL,'Blakely Island, WA 98222',29660,222,NULL,56,42322,0);
INSERT INTO "django_geo_db_location" VALUES(72276,NULL,'Arlington, WA',29661,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72277,NULL,'Arlington, WA 98223',29661,222,NULL,56,42323,0);
INSERT INTO "django_geo_db_location" VALUES(72278,NULL,'Baring, WA',29662,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72279,NULL,'Baring, WA 98224',29662,222,NULL,56,42324,0);
INSERT INTO "django_geo_db_location" VALUES(72280,NULL,'Bellingham, WA',29663,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72281,NULL,'Bellingham, WA 98225',29663,222,NULL,56,42325,0);
INSERT INTO "django_geo_db_location" VALUES(72282,NULL,'Bellingham, WA 98226',29663,222,NULL,56,42326,0);
INSERT INTO "django_geo_db_location" VALUES(72283,NULL,'Bellingham, WA 98227',29663,222,NULL,56,42327,0);
INSERT INTO "django_geo_db_location" VALUES(72284,NULL,'Bellingham, WA 98228',29663,222,NULL,56,42328,0);
INSERT INTO "django_geo_db_location" VALUES(72285,NULL,'Bellingham, WA 98229',29663,222,NULL,56,42329,0);
INSERT INTO "django_geo_db_location" VALUES(72286,NULL,'Blaine, WA',29664,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72287,NULL,'Blaine, WA 98230',29664,222,NULL,56,42330,0);
INSERT INTO "django_geo_db_location" VALUES(72288,NULL,'Blaine, WA 98231',29664,222,NULL,56,42331,0);
INSERT INTO "django_geo_db_location" VALUES(72289,NULL,'Bow, WA',29665,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72290,NULL,'Bow, WA 98232',29665,222,NULL,56,42332,0);
INSERT INTO "django_geo_db_location" VALUES(72291,NULL,'Burlington, WA',29666,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72292,NULL,'Burlington, WA 98233',29666,222,NULL,56,42333,0);
INSERT INTO "django_geo_db_location" VALUES(72293,NULL,'Clearlake, WA',29667,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72294,NULL,'Clearlake, WA 98235',29667,222,NULL,56,42334,0);
INSERT INTO "django_geo_db_location" VALUES(72295,NULL,'Clinton, WA',29668,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72296,NULL,'Clinton, WA 98236',29668,222,NULL,56,42335,0);
INSERT INTO "django_geo_db_location" VALUES(72297,NULL,'Concrete, WA',29669,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72298,NULL,'Concrete, WA 98237',29669,222,NULL,56,42336,0);
INSERT INTO "django_geo_db_location" VALUES(72299,NULL,'Conway, WA',29670,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72300,NULL,'Conway, WA 98238',29670,222,NULL,56,42337,0);
INSERT INTO "django_geo_db_location" VALUES(72301,NULL,'Coupeville, WA',29671,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72302,NULL,'Coupeville, WA 98239',29671,222,NULL,56,42338,0);
INSERT INTO "django_geo_db_location" VALUES(72303,NULL,'Custer, WA',29672,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72304,NULL,'Custer, WA 98240',29672,222,NULL,56,42339,0);
INSERT INTO "django_geo_db_location" VALUES(72305,NULL,'Darrington, WA',29673,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72306,NULL,'Darrington, WA 98241',29673,222,NULL,56,42340,0);
INSERT INTO "django_geo_db_location" VALUES(72307,NULL,'Deer Harbor, WA',29674,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72308,NULL,'Deer Harbor, WA 98243',29674,222,NULL,56,42341,0);
INSERT INTO "django_geo_db_location" VALUES(72309,NULL,'Deming, WA',29675,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72310,NULL,'Deming, WA 98244',29675,222,NULL,56,42342,0);
INSERT INTO "django_geo_db_location" VALUES(72311,NULL,'Eastsound, WA',29676,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72312,NULL,'Eastsound, WA 98245',29676,222,NULL,56,42343,0);
INSERT INTO "django_geo_db_location" VALUES(72313,NULL,'Bow, WA 98246',29665,222,NULL,56,42344,0);
INSERT INTO "django_geo_db_location" VALUES(72314,NULL,'Everson, WA',29677,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72315,NULL,'Everson, WA 98247',29677,222,NULL,56,42345,0);
INSERT INTO "django_geo_db_location" VALUES(72316,NULL,'Ferndale, WA',29678,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72317,NULL,'Ferndale, WA 98248',29678,222,NULL,56,42346,0);
INSERT INTO "django_geo_db_location" VALUES(72318,NULL,'Freeland, WA',29679,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72319,NULL,'Freeland, WA 98249',29679,222,NULL,56,42347,0);
INSERT INTO "django_geo_db_location" VALUES(72320,NULL,'Friday Harbor, WA',29680,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72321,NULL,'Friday Harbor, WA 98250',29680,222,NULL,56,42348,0);
INSERT INTO "django_geo_db_location" VALUES(72322,NULL,'Gold Bar, WA',29681,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72323,NULL,'Gold Bar, WA 98251',29681,222,NULL,56,42349,0);
INSERT INTO "django_geo_db_location" VALUES(72324,NULL,'Granite Falls, WA',29682,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72325,NULL,'Granite Falls, WA 98252',29682,222,NULL,56,42350,0);
INSERT INTO "django_geo_db_location" VALUES(72326,NULL,'Greenbank, WA',29683,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72327,NULL,'Greenbank, WA 98253',29683,222,NULL,56,42351,0);
INSERT INTO "django_geo_db_location" VALUES(72328,NULL,'Hamilton, WA',29684,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72329,NULL,'Hamilton, WA 98255',29684,222,NULL,56,42352,0);
INSERT INTO "django_geo_db_location" VALUES(72330,NULL,'Index, WA',29685,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72331,NULL,'Index, WA 98256',29685,222,NULL,56,42353,0);
INSERT INTO "django_geo_db_location" VALUES(72332,NULL,'La Conner, WA',29686,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72333,NULL,'La Conner, WA 98257',29686,222,NULL,56,42354,0);
INSERT INTO "django_geo_db_location" VALUES(72334,NULL,'Lake Stevens, WA',29687,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72335,NULL,'Lake Stevens, WA 98258',29687,222,NULL,56,42355,0);
INSERT INTO "django_geo_db_location" VALUES(72336,NULL,'North Lakewood, WA',29688,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72337,NULL,'North Lakewood, WA 98259',29688,222,NULL,56,42356,0);
INSERT INTO "django_geo_db_location" VALUES(72338,NULL,'Langley, WA',29689,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72339,NULL,'Langley, WA 98260',29689,222,NULL,56,42357,0);
INSERT INTO "django_geo_db_location" VALUES(72340,NULL,'Lopez Island, WA',29690,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72341,NULL,'Lopez Island, WA 98261',29690,222,NULL,56,42358,0);
INSERT INTO "django_geo_db_location" VALUES(72342,NULL,'Lummi Island, WA',29691,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72343,NULL,'Lummi Island, WA 98262',29691,222,NULL,56,42359,0);
INSERT INTO "django_geo_db_location" VALUES(72344,NULL,'Lyman, WA',29692,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72345,NULL,'Lyman, WA 98263',29692,222,NULL,56,42360,0);
INSERT INTO "django_geo_db_location" VALUES(72346,NULL,'Lynden, WA',29693,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72347,NULL,'Lynden, WA 98264',29693,222,NULL,56,42361,0);
INSERT INTO "django_geo_db_location" VALUES(72348,NULL,'Maple Falls, WA',29694,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72349,NULL,'Maple Falls, WA 98266',29694,222,NULL,56,42362,0);
INSERT INTO "django_geo_db_location" VALUES(72350,NULL,'Marblemount, WA',29695,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72351,NULL,'Marblemount, WA 98267',29695,222,NULL,56,42363,0);
INSERT INTO "django_geo_db_location" VALUES(72352,NULL,'Marysville, WA',29696,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72353,NULL,'Marysville, WA 98270',29696,222,NULL,56,42364,0);
INSERT INTO "django_geo_db_location" VALUES(72354,NULL,'Marysville, WA 98271',29696,222,NULL,56,42365,0);
INSERT INTO "django_geo_db_location" VALUES(72355,NULL,'Monroe, WA',29697,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72356,NULL,'Monroe, WA 98272',29697,222,NULL,56,42366,0);
INSERT INTO "django_geo_db_location" VALUES(72357,NULL,'Mount Vernon, WA',29698,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72358,NULL,'Mount Vernon, WA 98273',29698,222,NULL,56,42367,0);
INSERT INTO "django_geo_db_location" VALUES(72359,NULL,'Mount Vernon, WA 98274',29698,222,NULL,56,42368,0);
INSERT INTO "django_geo_db_location" VALUES(72360,NULL,'Mukilteo, WA',29699,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72361,NULL,'Mukilteo, WA 98275',29699,222,NULL,56,42369,0);
INSERT INTO "django_geo_db_location" VALUES(72362,NULL,'Nooksack, WA',29700,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72363,NULL,'Nooksack, WA 98276',29700,222,NULL,56,42370,0);
INSERT INTO "django_geo_db_location" VALUES(72364,NULL,'Oak Harbor, WA',29701,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72365,NULL,'Oak Harbor, WA 98277',29701,222,NULL,56,42371,0);
INSERT INTO "django_geo_db_location" VALUES(72366,NULL,'Oak Harbor, WA 98278',29701,222,NULL,56,42372,0);
INSERT INTO "django_geo_db_location" VALUES(72367,NULL,'Olga, WA',29702,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72368,NULL,'Olga, WA 98279',29702,222,NULL,56,42373,0);
INSERT INTO "django_geo_db_location" VALUES(72369,NULL,'Orcas, WA',29703,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72370,NULL,'Orcas, WA 98280',29703,222,NULL,56,42374,0);
INSERT INTO "django_geo_db_location" VALUES(72371,NULL,'Point Roberts, WA',29704,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72372,NULL,'Point Roberts, WA 98281',29704,222,NULL,56,42375,0);
INSERT INTO "django_geo_db_location" VALUES(72373,NULL,'Camano, WA',29705,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72374,NULL,'Camano, WA 98282',29705,222,NULL,56,42376,0);
INSERT INTO "django_geo_db_location" VALUES(72375,NULL,'Rockport, WA',29706,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72376,NULL,'Rockport, WA 98283',29706,222,NULL,56,42377,0);
INSERT INTO "django_geo_db_location" VALUES(72377,NULL,'Sedro Woolley, WA',29707,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72378,NULL,'Sedro Woolley, WA 98284',29707,222,NULL,56,42378,0);
INSERT INTO "django_geo_db_location" VALUES(72379,NULL,'Shaw Island, WA',29708,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72380,NULL,'Shaw Island, WA 98286',29708,222,NULL,56,42379,0);
INSERT INTO "django_geo_db_location" VALUES(72381,NULL,'Silvana, WA',29709,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72382,NULL,'Silvana, WA 98287',29709,222,NULL,56,42380,0);
INSERT INTO "django_geo_db_location" VALUES(72383,NULL,'Skykomish, WA',29710,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72384,NULL,'Skykomish, WA 98288',29710,222,NULL,56,42381,0);
INSERT INTO "django_geo_db_location" VALUES(72385,NULL,'Snohomish, WA',29711,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72386,NULL,'Snohomish, WA 98290',29711,222,NULL,56,42382,0);
INSERT INTO "django_geo_db_location" VALUES(72387,NULL,'Snohomish, WA 98291',29711,222,NULL,56,42383,0);
INSERT INTO "django_geo_db_location" VALUES(72388,NULL,'Stanwood, WA',29712,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72389,NULL,'Stanwood, WA 98292',29712,222,NULL,56,42384,0);
INSERT INTO "django_geo_db_location" VALUES(72390,NULL,'Startup, WA',29713,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72391,NULL,'Startup, WA 98293',29713,222,NULL,56,42385,0);
INSERT INTO "django_geo_db_location" VALUES(72392,NULL,'Sultan, WA',29714,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72393,NULL,'Sultan, WA 98294',29714,222,NULL,56,42386,0);
INSERT INTO "django_geo_db_location" VALUES(72394,NULL,'Sumas, WA',29715,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72395,NULL,'Sumas, WA 98295',29715,222,NULL,56,42387,0);
INSERT INTO "django_geo_db_location" VALUES(72396,NULL,'Snohomish, WA 98296',29711,222,NULL,56,42388,0);
INSERT INTO "django_geo_db_location" VALUES(72397,NULL,'Waldron, WA',29716,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72398,NULL,'Waldron, WA 98297',29716,222,NULL,56,42389,0);
INSERT INTO "django_geo_db_location" VALUES(72399,NULL,'Anderson Island, WA',29717,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72400,NULL,'Anderson Island, WA 98303',29717,222,NULL,56,42390,0);
INSERT INTO "django_geo_db_location" VALUES(72401,NULL,'Ashford, WA',29718,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72402,NULL,'Ashford, WA 98304',29718,222,NULL,56,42391,0);
INSERT INTO "django_geo_db_location" VALUES(72403,NULL,'Beaver, WA',29719,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72404,NULL,'Beaver, WA 98305',29719,222,NULL,56,42392,0);
INSERT INTO "django_geo_db_location" VALUES(72405,NULL,'Bremerton, WA',29720,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72406,NULL,'Bremerton, WA 98310',29720,222,NULL,56,42393,0);
INSERT INTO "django_geo_db_location" VALUES(72407,NULL,'Bremerton, WA 98311',29720,222,NULL,56,42394,0);
INSERT INTO "django_geo_db_location" VALUES(72408,NULL,'Bremerton, WA 98312',29720,222,NULL,56,42395,0);
INSERT INTO "django_geo_db_location" VALUES(72409,NULL,'Bremerton, WA 98314',29720,222,NULL,56,42396,0);
INSERT INTO "django_geo_db_location" VALUES(72410,NULL,'Silverdale, WA',29721,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72411,NULL,'Silverdale, WA 98315',29721,222,NULL,56,42397,0);
INSERT INTO "django_geo_db_location" VALUES(72412,NULL,'Duvall, WA 98319',29626,222,NULL,56,42398,0);
INSERT INTO "django_geo_db_location" VALUES(72413,NULL,'Brinnon, WA',29722,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72414,NULL,'Brinnon, WA 98320',29722,222,NULL,56,42399,0);
INSERT INTO "django_geo_db_location" VALUES(72415,NULL,'Buckley, WA',29723,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72416,NULL,'Buckley, WA 98321',29723,222,NULL,56,42400,0);
INSERT INTO "django_geo_db_location" VALUES(72417,NULL,'Burley, WA',29724,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72418,NULL,'Burley, WA 98322',29724,222,NULL,56,42401,0);
INSERT INTO "django_geo_db_location" VALUES(72419,NULL,'Carbonado, WA',29725,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72420,NULL,'Carbonado, WA 98323',29725,222,NULL,56,42402,0);
INSERT INTO "django_geo_db_location" VALUES(72421,NULL,'Carlsborg, WA',29726,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72422,NULL,'Carlsborg, WA 98324',29726,222,NULL,56,42403,0);
INSERT INTO "django_geo_db_location" VALUES(72423,NULL,'Chimacum, WA',29727,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72424,NULL,'Chimacum, WA 98325',29727,222,NULL,56,42404,0);
INSERT INTO "django_geo_db_location" VALUES(72425,NULL,'Clallam Bay, WA',29728,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72426,NULL,'Clallam Bay, WA 98326',29728,222,NULL,56,42405,0);
INSERT INTO "django_geo_db_location" VALUES(72427,NULL,'Dupont, WA',29729,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72428,NULL,'Dupont, WA 98327',29729,222,NULL,56,42406,0);
INSERT INTO "django_geo_db_location" VALUES(72429,NULL,'Eatonville, WA',29730,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72430,NULL,'Eatonville, WA 98328',29730,222,NULL,56,42407,0);
INSERT INTO "django_geo_db_location" VALUES(72431,NULL,'Gig Harbor, WA',29731,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72432,NULL,'Gig Harbor, WA 98329',29731,222,NULL,56,42408,0);
INSERT INTO "django_geo_db_location" VALUES(72433,NULL,'Elbe, WA',29732,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72434,NULL,'Elbe, WA 98330',29732,222,NULL,56,42409,0);
INSERT INTO "django_geo_db_location" VALUES(72435,NULL,'Forks, WA',29733,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72436,NULL,'Forks, WA 98331',29733,222,NULL,56,42410,0);
INSERT INTO "django_geo_db_location" VALUES(72437,NULL,'Gig Harbor, WA 98332',29731,222,NULL,56,42411,0);
INSERT INTO "django_geo_db_location" VALUES(72438,NULL,'Fox Island, WA',29734,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72439,NULL,'Fox Island, WA 98333',29734,222,NULL,56,42412,0);
INSERT INTO "django_geo_db_location" VALUES(72440,NULL,'Gig Harbor, WA 98335',29731,222,NULL,56,42413,0);
INSERT INTO "django_geo_db_location" VALUES(72441,NULL,'Glenoma, WA',29735,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72442,NULL,'Glenoma, WA 98336',29735,222,NULL,56,42414,0);
INSERT INTO "django_geo_db_location" VALUES(72443,NULL,'Bremerton, WA 98337',29720,222,NULL,56,42415,0);
INSERT INTO "django_geo_db_location" VALUES(72444,NULL,'Graham, WA',29736,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72445,NULL,'Graham, WA 98338',29736,222,NULL,56,42416,0);
INSERT INTO "django_geo_db_location" VALUES(72446,NULL,'Port Hadlock, WA',29737,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72447,NULL,'Port Hadlock, WA 98339',29737,222,NULL,56,42417,0);
INSERT INTO "django_geo_db_location" VALUES(72448,NULL,'Hansville, WA',29738,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72449,NULL,'Hansville, WA 98340',29738,222,NULL,56,42418,0);
INSERT INTO "django_geo_db_location" VALUES(72450,NULL,'Indianola, WA',29739,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72451,NULL,'Indianola, WA 98342',29739,222,NULL,56,42419,0);
INSERT INTO "django_geo_db_location" VALUES(72452,NULL,'Joyce, WA',29740,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72453,NULL,'Joyce, WA 98343',29740,222,NULL,56,42420,0);
INSERT INTO "django_geo_db_location" VALUES(72454,NULL,'Kapowsin, WA',29741,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72455,NULL,'Kapowsin, WA 98344',29741,222,NULL,56,42421,0);
INSERT INTO "django_geo_db_location" VALUES(72456,NULL,'Keyport, WA',29742,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72457,NULL,'Keyport, WA 98345',29742,222,NULL,56,42422,0);
INSERT INTO "django_geo_db_location" VALUES(72458,NULL,'Kingston, WA',29743,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72459,NULL,'Kingston, WA 98346',29743,222,NULL,56,42423,0);
INSERT INTO "django_geo_db_location" VALUES(72460,NULL,'La Grande, WA',29744,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72461,NULL,'La Grande, WA 98348',29744,222,NULL,56,42424,0);
INSERT INTO "django_geo_db_location" VALUES(72462,NULL,'Lakebay, WA',29745,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72463,NULL,'Lakebay, WA 98349',29745,222,NULL,56,42425,0);
INSERT INTO "django_geo_db_location" VALUES(72464,NULL,'La Push, WA',29746,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72465,NULL,'La Push, WA 98350',29746,222,NULL,56,42426,0);
INSERT INTO "django_geo_db_location" VALUES(72466,NULL,'Longbranch, WA',29747,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72467,NULL,'Longbranch, WA 98351',29747,222,NULL,56,42427,0);
INSERT INTO "django_geo_db_location" VALUES(72468,NULL,'Sumner, WA',29748,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72469,NULL,'Sumner, WA 98352',29748,222,NULL,56,42428,0);
INSERT INTO "django_geo_db_location" VALUES(72470,NULL,'Manchester, WA',29749,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72471,NULL,'Manchester, WA 98353',29749,222,NULL,56,42429,0);
INSERT INTO "django_geo_db_location" VALUES(72472,NULL,'Milton, WA',29750,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72473,NULL,'Milton, WA 98354',29750,222,NULL,56,42430,0);
INSERT INTO "django_geo_db_location" VALUES(72474,NULL,'Mineral, WA',29751,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72475,NULL,'Mineral, WA 98355',29751,222,NULL,56,42431,0);
INSERT INTO "django_geo_db_location" VALUES(72476,NULL,'Morton, WA',29752,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72477,NULL,'Morton, WA 98356',29752,222,NULL,56,42432,0);
INSERT INTO "django_geo_db_location" VALUES(72478,NULL,'Neah Bay, WA',29753,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72479,NULL,'Neah Bay, WA 98357',29753,222,NULL,56,42433,0);
INSERT INTO "django_geo_db_location" VALUES(72480,NULL,'Nordland, WA',29754,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72481,NULL,'Nordland, WA 98358',29754,222,NULL,56,42434,0);
INSERT INTO "django_geo_db_location" VALUES(72482,NULL,'Olalla, WA',29755,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72483,NULL,'Olalla, WA 98359',29755,222,NULL,56,42435,0);
INSERT INTO "django_geo_db_location" VALUES(72484,NULL,'Orting, WA',29756,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72485,NULL,'Orting, WA 98360',29756,222,NULL,56,42436,0);
INSERT INTO "django_geo_db_location" VALUES(72486,NULL,'Packwood, WA',29757,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72487,NULL,'Packwood, WA 98361',29757,222,NULL,56,42437,0);
INSERT INTO "django_geo_db_location" VALUES(72488,NULL,'Port Angeles, WA',29758,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72489,NULL,'Port Angeles, WA 98362',29758,222,NULL,56,42438,0);
INSERT INTO "django_geo_db_location" VALUES(72490,NULL,'Port Angeles, WA 98363',29758,222,NULL,56,42439,0);
INSERT INTO "django_geo_db_location" VALUES(72491,NULL,'Port Gamble, WA',29759,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72492,NULL,'Port Gamble, WA 98364',29759,222,NULL,56,42440,0);
INSERT INTO "django_geo_db_location" VALUES(72493,NULL,'Port Ludlow, WA',29760,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72494,NULL,'Port Ludlow, WA 98365',29760,222,NULL,56,42441,0);
INSERT INTO "django_geo_db_location" VALUES(72495,NULL,'Port Orchard, WA',29761,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72496,NULL,'Port Orchard, WA 98366',29761,222,NULL,56,42442,0);
INSERT INTO "django_geo_db_location" VALUES(72497,NULL,'Port Orchard, WA 98367',29761,222,NULL,56,42443,0);
INSERT INTO "django_geo_db_location" VALUES(72498,NULL,'Port Townsend, WA',29762,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72499,NULL,'Port Townsend, WA 98368',29762,222,NULL,56,42444,0);
INSERT INTO "django_geo_db_location" VALUES(72500,NULL,'Poulsbo, WA',29763,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72501,NULL,'Poulsbo, WA 98370',29763,222,NULL,56,42445,0);
INSERT INTO "django_geo_db_location" VALUES(72502,NULL,'Puyallup, WA',29764,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72503,NULL,'Puyallup, WA 98371',29764,222,NULL,56,42446,0);
INSERT INTO "django_geo_db_location" VALUES(72504,NULL,'Puyallup, WA 98372',29764,222,NULL,56,42447,0);
INSERT INTO "django_geo_db_location" VALUES(72505,NULL,'Puyallup, WA 98373',29764,222,NULL,56,42448,0);
INSERT INTO "django_geo_db_location" VALUES(72506,NULL,'Puyallup, WA 98374',29764,222,NULL,56,42449,0);
INSERT INTO "django_geo_db_location" VALUES(72507,NULL,'Puyallup, WA 98375',29764,222,NULL,56,42450,0);
INSERT INTO "django_geo_db_location" VALUES(72508,NULL,'Quilcene, WA',29765,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72509,NULL,'Quilcene, WA 98376',29765,222,NULL,56,42451,0);
INSERT INTO "django_geo_db_location" VALUES(72510,NULL,'Randle, WA',29766,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72511,NULL,'Randle, WA 98377',29766,222,NULL,56,42452,0);
INSERT INTO "django_geo_db_location" VALUES(72512,NULL,'Retsil, WA',29767,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72513,NULL,'Retsil, WA 98378',29767,222,NULL,56,42453,0);
INSERT INTO "django_geo_db_location" VALUES(72514,NULL,'Seabeck, WA',29768,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72515,NULL,'Seabeck, WA 98380',29768,222,NULL,56,42454,0);
INSERT INTO "django_geo_db_location" VALUES(72516,NULL,'Sekiu, WA',29769,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72517,NULL,'Sekiu, WA 98381',29769,222,NULL,56,42455,0);
INSERT INTO "django_geo_db_location" VALUES(72518,NULL,'Sequim, WA',29770,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72519,NULL,'Sequim, WA 98382',29770,222,NULL,56,42456,0);
INSERT INTO "django_geo_db_location" VALUES(72520,NULL,'Silverdale, WA 98383',29721,222,NULL,56,42457,0);
INSERT INTO "django_geo_db_location" VALUES(72521,NULL,'South Colby, WA',29771,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72522,NULL,'South Colby, WA 98384',29771,222,NULL,56,42458,0);
INSERT INTO "django_geo_db_location" VALUES(72523,NULL,'South Prairie, WA',29772,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72524,NULL,'South Prairie, WA 98385',29772,222,NULL,56,42459,0);
INSERT INTO "django_geo_db_location" VALUES(72525,NULL,'Southworth, WA',29773,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72526,NULL,'Southworth, WA 98386',29773,222,NULL,56,42460,0);
INSERT INTO "django_geo_db_location" VALUES(72527,NULL,'Spanaway, WA',29774,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72528,NULL,'Spanaway, WA 98387',29774,222,NULL,56,42461,0);
INSERT INTO "django_geo_db_location" VALUES(72529,NULL,'Steilacoom, WA',29775,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72530,NULL,'Steilacoom, WA 98388',29775,222,NULL,56,42462,0);
INSERT INTO "django_geo_db_location" VALUES(72531,NULL,'South Prairie, WA 98389',29772,222,NULL,56,42463,0);
INSERT INTO "django_geo_db_location" VALUES(72532,NULL,'Sumner, WA 98390',29748,222,NULL,56,42464,0);
INSERT INTO "django_geo_db_location" VALUES(72533,NULL,'Suquamish, WA',29776,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72534,NULL,'Suquamish, WA 98392',29776,222,NULL,56,42465,0);
INSERT INTO "django_geo_db_location" VALUES(72535,NULL,'Tracyton, WA',29777,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72536,NULL,'Tracyton, WA 98393',29777,222,NULL,56,42466,0);
INSERT INTO "django_geo_db_location" VALUES(72537,NULL,'Vaughn, WA',29778,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72538,NULL,'Vaughn, WA 98394',29778,222,NULL,56,42467,0);
INSERT INTO "django_geo_db_location" VALUES(72539,NULL,'Wauna, WA',29779,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72540,NULL,'Wauna, WA 98395',29779,222,NULL,56,42468,0);
INSERT INTO "django_geo_db_location" VALUES(72541,NULL,'Wilkeson, WA',29780,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72542,NULL,'Wilkeson, WA 98396',29780,222,NULL,56,42469,0);
INSERT INTO "django_geo_db_location" VALUES(72543,NULL,'Longmire, WA',29781,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72544,NULL,'Longmire, WA 98397',29781,222,NULL,56,42470,0);
INSERT INTO "django_geo_db_location" VALUES(72545,NULL,'Paradise Inn, WA',29782,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72546,NULL,'Paradise Inn, WA 98398',29782,222,NULL,56,42471,0);
INSERT INTO "django_geo_db_location" VALUES(72547,NULL,'Tacoma, WA',29783,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72548,NULL,'Tacoma, WA 98401',29783,222,NULL,56,42472,0);
INSERT INTO "django_geo_db_location" VALUES(72549,NULL,'Tacoma, WA 98402',29783,222,NULL,56,42473,0);
INSERT INTO "django_geo_db_location" VALUES(72550,NULL,'Tacoma, WA 98403',29783,222,NULL,56,42474,0);
INSERT INTO "django_geo_db_location" VALUES(72551,NULL,'Tacoma, WA 98404',29783,222,NULL,56,42475,0);
INSERT INTO "django_geo_db_location" VALUES(72552,NULL,'Tacoma, WA 98405',29783,222,NULL,56,42476,0);
INSERT INTO "django_geo_db_location" VALUES(72553,NULL,'Tacoma, WA 98406',29783,222,NULL,56,42477,0);
INSERT INTO "django_geo_db_location" VALUES(72554,NULL,'Tacoma, WA 98407',29783,222,NULL,56,42478,0);
INSERT INTO "django_geo_db_location" VALUES(72555,NULL,'Tacoma, WA 98408',29783,222,NULL,56,42479,0);
INSERT INTO "django_geo_db_location" VALUES(72556,NULL,'Tacoma, WA 98409',29783,222,NULL,56,42480,0);
INSERT INTO "django_geo_db_location" VALUES(72557,NULL,'Tacoma, WA 98411',29783,222,NULL,56,42481,0);
INSERT INTO "django_geo_db_location" VALUES(72558,NULL,'Tacoma, WA 98412',29783,222,NULL,56,42482,0);
INSERT INTO "django_geo_db_location" VALUES(72559,NULL,'Tacoma, WA 98413',29783,222,NULL,56,42483,0);
INSERT INTO "django_geo_db_location" VALUES(72560,NULL,'Tacoma, WA 98415',29783,222,NULL,56,42484,0);
INSERT INTO "django_geo_db_location" VALUES(72561,NULL,'Tacoma, WA 98416',29783,222,NULL,56,42485,0);
INSERT INTO "django_geo_db_location" VALUES(72562,NULL,'Tacoma, WA 98418',29783,222,NULL,56,42486,0);
INSERT INTO "django_geo_db_location" VALUES(72563,NULL,'Tacoma, WA 98421',29783,222,NULL,56,42487,0);
INSERT INTO "django_geo_db_location" VALUES(72564,NULL,'Tacoma, WA 98422',29783,222,NULL,56,42488,0);
INSERT INTO "django_geo_db_location" VALUES(72565,NULL,'Tacoma, WA 98424',29783,222,NULL,56,42489,0);
INSERT INTO "django_geo_db_location" VALUES(72566,NULL,'Camp Murray, WA',29784,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72567,NULL,'Camp Murray, WA 98430',29784,222,NULL,56,42490,0);
INSERT INTO "django_geo_db_location" VALUES(72568,NULL,'Tacoma, WA 98431',29783,222,NULL,56,42491,0);
INSERT INTO "django_geo_db_location" VALUES(72569,NULL,'Tacoma, WA 98433',29783,222,NULL,56,42492,0);
INSERT INTO "django_geo_db_location" VALUES(72570,NULL,'Tacoma, WA 98434',29783,222,NULL,56,42493,0);
INSERT INTO "django_geo_db_location" VALUES(72571,NULL,'Tacoma, WA 98438',29783,222,NULL,56,42494,0);
INSERT INTO "django_geo_db_location" VALUES(72572,NULL,'Lakewood, WA',29785,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72573,NULL,'Lakewood, WA 98439',29785,222,NULL,56,42495,0);
INSERT INTO "django_geo_db_location" VALUES(72574,NULL,'Tacoma, WA 98442',29783,222,NULL,56,42496,0);
INSERT INTO "django_geo_db_location" VALUES(72575,NULL,'Tacoma, WA 98443',29783,222,NULL,56,42497,0);
INSERT INTO "django_geo_db_location" VALUES(72576,NULL,'Tacoma, WA 98444',29783,222,NULL,56,42498,0);
INSERT INTO "django_geo_db_location" VALUES(72577,NULL,'Tacoma, WA 98445',29783,222,NULL,56,42499,0);
INSERT INTO "django_geo_db_location" VALUES(72578,NULL,'Tacoma, WA 98446',29783,222,NULL,56,42500,0);
INSERT INTO "django_geo_db_location" VALUES(72579,NULL,'Tacoma, WA 98447',29783,222,NULL,56,42501,0);
INSERT INTO "django_geo_db_location" VALUES(72580,NULL,'Parkland, WA',29786,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72581,NULL,'Parkland, WA 98448',29786,222,NULL,56,42502,0);
INSERT INTO "django_geo_db_location" VALUES(72582,NULL,'Tacoma, WA 98450',29783,222,NULL,56,42503,0);
INSERT INTO "django_geo_db_location" VALUES(72583,NULL,'Tacoma, WA 98455',29783,222,NULL,56,42504,0);
INSERT INTO "django_geo_db_location" VALUES(72584,NULL,'Tacoma, WA 98460',29783,222,NULL,56,42505,0);
INSERT INTO "django_geo_db_location" VALUES(72585,NULL,'Tacoma, WA 98464',29783,222,NULL,56,42506,0);
INSERT INTO "django_geo_db_location" VALUES(72586,NULL,'Tacoma, WA 98465',29783,222,NULL,56,42507,0);
INSERT INTO "django_geo_db_location" VALUES(72587,NULL,'Tacoma, WA 98466',29783,222,NULL,56,42508,0);
INSERT INTO "django_geo_db_location" VALUES(72588,NULL,'University Place, WA',29787,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72589,NULL,'University Place, WA 98467',29787,222,NULL,56,42509,0);
INSERT INTO "django_geo_db_location" VALUES(72590,NULL,'Oakville, WA',29788,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72591,NULL,'Oakville, WA 98468',29788,222,NULL,56,42510,0);
INSERT INTO "django_geo_db_location" VALUES(72592,NULL,'Tacoma, WA 98471',29783,222,NULL,56,42511,0);
INSERT INTO "django_geo_db_location" VALUES(72593,NULL,'Tacoma, WA 98477',29783,222,NULL,56,42512,0);
INSERT INTO "django_geo_db_location" VALUES(72594,NULL,'Tacoma, WA 98481',29783,222,NULL,56,42513,0);
INSERT INTO "django_geo_db_location" VALUES(72595,NULL,'South Prairie, WA 98485',29772,222,NULL,56,42514,0);
INSERT INTO "django_geo_db_location" VALUES(72596,NULL,'Lakewood, WA 98492',29785,222,NULL,56,42515,0);
INSERT INTO "django_geo_db_location" VALUES(72597,NULL,'Tacoma, WA 98493',29783,222,NULL,56,42516,0);
INSERT INTO "django_geo_db_location" VALUES(72598,NULL,'Tacoma, WA 98494',29783,222,NULL,56,42517,0);
INSERT INTO "django_geo_db_location" VALUES(72599,NULL,'Lakewood, WA 98497',29785,222,NULL,56,42518,0);
INSERT INTO "django_geo_db_location" VALUES(72600,NULL,'Lakewood, WA 98498',29785,222,NULL,56,42519,0);
INSERT INTO "django_geo_db_location" VALUES(72601,NULL,'Lakewood, WA 98499',29785,222,NULL,56,42520,0);
INSERT INTO "django_geo_db_location" VALUES(72602,NULL,'Tumwater, WA',29789,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72603,NULL,'Tumwater, WA 98500',29789,222,NULL,56,42521,0);
INSERT INTO "django_geo_db_location" VALUES(72604,NULL,'Olympia, WA',29790,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72605,NULL,'Olympia, WA 98501',29790,222,NULL,56,42522,0);
INSERT INTO "django_geo_db_location" VALUES(72606,NULL,'Olympia, WA 98502',29790,222,NULL,56,42523,0);
INSERT INTO "django_geo_db_location" VALUES(72607,NULL,'Lacey, WA',29791,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72608,NULL,'Lacey, WA 98503',29791,222,NULL,56,42524,0);
INSERT INTO "django_geo_db_location" VALUES(72609,NULL,'Olympia, WA 98504',29790,222,NULL,56,42525,0);
INSERT INTO "django_geo_db_location" VALUES(72610,NULL,'Olympia, WA 98505',29790,222,NULL,56,42526,0);
INSERT INTO "django_geo_db_location" VALUES(72611,NULL,'Olympia, WA 98506',29790,222,NULL,56,42527,0);
INSERT INTO "django_geo_db_location" VALUES(72612,NULL,'Olympia, WA 98507',29790,222,NULL,56,42528,0);
INSERT INTO "django_geo_db_location" VALUES(72613,NULL,'Olympia, WA 98508',29790,222,NULL,56,42529,0);
INSERT INTO "django_geo_db_location" VALUES(72614,NULL,'Lacey, WA 98509',29791,222,NULL,56,42530,0);
INSERT INTO "django_geo_db_location" VALUES(72615,NULL,'Olympia, WA 98512',29790,222,NULL,56,42531,0);
INSERT INTO "django_geo_db_location" VALUES(72616,NULL,'Olympia, WA 98513',29790,222,NULL,56,42532,0);
INSERT INTO "django_geo_db_location" VALUES(72617,NULL,'Olympia, WA 98516',29790,222,NULL,56,42533,0);
INSERT INTO "django_geo_db_location" VALUES(72618,NULL,'Aberdeen, WA',29792,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72619,NULL,'Aberdeen, WA 98520',29792,222,NULL,56,42534,0);
INSERT INTO "django_geo_db_location" VALUES(72620,NULL,'Adna, WA',29793,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72621,NULL,'Adna, WA 98522',29793,222,NULL,56,42535,0);
INSERT INTO "django_geo_db_location" VALUES(72622,NULL,'Allyn, WA',29794,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72623,NULL,'Allyn, WA 98524',29794,222,NULL,56,42536,0);
INSERT INTO "django_geo_db_location" VALUES(72624,NULL,'Amanda Park, WA',29795,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72625,NULL,'Amanda Park, WA 98526',29795,222,NULL,56,42537,0);
INSERT INTO "django_geo_db_location" VALUES(72626,NULL,'Bay Center, WA',29796,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72627,NULL,'Bay Center, WA 98527',29796,222,NULL,56,42538,0);
INSERT INTO "django_geo_db_location" VALUES(72628,NULL,'Belfair, WA',29797,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72629,NULL,'Belfair, WA 98528',29797,222,NULL,56,42539,0);
INSERT INTO "django_geo_db_location" VALUES(72630,NULL,'Bucoda, WA',29798,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72631,NULL,'Bucoda, WA 98530',29798,222,NULL,56,42540,0);
INSERT INTO "django_geo_db_location" VALUES(72632,NULL,'Centralia, WA',29799,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72633,NULL,'Centralia, WA 98531',29799,222,NULL,56,42541,0);
INSERT INTO "django_geo_db_location" VALUES(72634,NULL,'Chehalis, WA',29800,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72635,NULL,'Chehalis, WA 98532',29800,222,NULL,56,42542,0);
INSERT INTO "django_geo_db_location" VALUES(72636,NULL,'Cinebar, WA',29801,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72637,NULL,'Cinebar, WA 98533',29801,222,NULL,56,42543,0);
INSERT INTO "django_geo_db_location" VALUES(72638,NULL,'Copalis Beach, WA',29802,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72639,NULL,'Copalis Beach, WA 98535',29802,222,NULL,56,42544,0);
INSERT INTO "django_geo_db_location" VALUES(72640,NULL,'Copalis Crossing, WA',29803,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72641,NULL,'Copalis Crossing, WA 98536',29803,222,NULL,56,42545,0);
INSERT INTO "django_geo_db_location" VALUES(72642,NULL,'Cosmopolis, WA',29804,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72643,NULL,'Cosmopolis, WA 98537',29804,222,NULL,56,42546,0);
INSERT INTO "django_geo_db_location" VALUES(72644,NULL,'Curtis, WA',29805,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72645,NULL,'Curtis, WA 98538',29805,222,NULL,56,42547,0);
INSERT INTO "django_geo_db_location" VALUES(72646,NULL,'Doty, WA',29806,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72647,NULL,'Doty, WA 98539',29806,222,NULL,56,42548,0);
INSERT INTO "django_geo_db_location" VALUES(72648,NULL,'East Olympia, WA',29807,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72649,NULL,'East Olympia, WA 98540',29807,222,NULL,56,42549,0);
INSERT INTO "django_geo_db_location" VALUES(72650,NULL,'Elma, WA',29808,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72651,NULL,'Elma, WA 98541',29808,222,NULL,56,42550,0);
INSERT INTO "django_geo_db_location" VALUES(72652,NULL,'Ethel, WA',29809,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72653,NULL,'Ethel, WA 98542',29809,222,NULL,56,42551,0);
INSERT INTO "django_geo_db_location" VALUES(72654,NULL,'Galvin, WA',29810,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72655,NULL,'Galvin, WA 98544',29810,222,NULL,56,42552,0);
INSERT INTO "django_geo_db_location" VALUES(72656,NULL,'Grapeview, WA',29811,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72657,NULL,'Grapeview, WA 98546',29811,222,NULL,56,42553,0);
INSERT INTO "django_geo_db_location" VALUES(72658,NULL,'Grayland, WA',29812,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72659,NULL,'Grayland, WA 98547',29812,222,NULL,56,42554,0);
INSERT INTO "django_geo_db_location" VALUES(72660,NULL,'Hoodsport, WA',29813,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72661,NULL,'Hoodsport, WA 98548',29813,222,NULL,56,42555,0);
INSERT INTO "django_geo_db_location" VALUES(72662,NULL,'Hoquiam, WA',29814,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72663,NULL,'Hoquiam, WA 98550',29814,222,NULL,56,42556,0);
INSERT INTO "django_geo_db_location" VALUES(72664,NULL,'Humptulips, WA',29815,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72665,NULL,'Humptulips, WA 98552',29815,222,NULL,56,42557,0);
INSERT INTO "django_geo_db_location" VALUES(72666,NULL,'Lebam, WA',29816,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72667,NULL,'Lebam, WA 98554',29816,222,NULL,56,42558,0);
INSERT INTO "django_geo_db_location" VALUES(72668,NULL,'Lilliwaup, WA',29817,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72669,NULL,'Lilliwaup, WA 98555',29817,222,NULL,56,42559,0);
INSERT INTO "django_geo_db_location" VALUES(72670,NULL,'Littlerock, WA',29818,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72671,NULL,'Littlerock, WA 98556',29818,222,NULL,56,42560,0);
INSERT INTO "django_geo_db_location" VALUES(72672,NULL,'Mccleary, WA',29819,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72673,NULL,'Mccleary, WA 98557',29819,222,NULL,56,42561,0);
INSERT INTO "django_geo_db_location" VALUES(72674,NULL,'Mckenna, WA',29820,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72675,NULL,'Mckenna, WA 98558',29820,222,NULL,56,42562,0);
INSERT INTO "django_geo_db_location" VALUES(72676,NULL,'Malone, WA',29821,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72677,NULL,'Malone, WA 98559',29821,222,NULL,56,42563,0);
INSERT INTO "django_geo_db_location" VALUES(72678,NULL,'Matlock, WA',29822,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72679,NULL,'Matlock, WA 98560',29822,222,NULL,56,42564,0);
INSERT INTO "django_geo_db_location" VALUES(72680,NULL,'Menlo, WA',29823,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72681,NULL,'Menlo, WA 98561',29823,222,NULL,56,42565,0);
INSERT INTO "django_geo_db_location" VALUES(72682,NULL,'Moclips, WA',29824,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72683,NULL,'Moclips, WA 98562',29824,222,NULL,56,42566,0);
INSERT INTO "django_geo_db_location" VALUES(72684,NULL,'Montesano, WA',29825,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72685,NULL,'Montesano, WA 98563',29825,222,NULL,56,42567,0);
INSERT INTO "django_geo_db_location" VALUES(72686,NULL,'Mossyrock, WA',29826,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72687,NULL,'Mossyrock, WA 98564',29826,222,NULL,56,42568,0);
INSERT INTO "django_geo_db_location" VALUES(72688,NULL,'Napavine, WA',29827,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72689,NULL,'Napavine, WA 98565',29827,222,NULL,56,42569,0);
INSERT INTO "django_geo_db_location" VALUES(72690,NULL,'Neilton, WA',29828,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72691,NULL,'Neilton, WA 98566',29828,222,NULL,56,42570,0);
INSERT INTO "django_geo_db_location" VALUES(72692,NULL,'Oakville, WA 98568',29788,222,NULL,56,42571,0);
INSERT INTO "django_geo_db_location" VALUES(72693,NULL,'Ocean Shores, WA',29829,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72694,NULL,'Ocean Shores, WA 98569',29829,222,NULL,56,42572,0);
INSERT INTO "django_geo_db_location" VALUES(72695,NULL,'Onalaska, WA',29830,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72696,NULL,'Onalaska, WA 98570',29830,222,NULL,56,42573,0);
INSERT INTO "django_geo_db_location" VALUES(72697,NULL,'Pacific Beach, WA',29831,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72698,NULL,'Pacific Beach, WA 98571',29831,222,NULL,56,42574,0);
INSERT INTO "django_geo_db_location" VALUES(72699,NULL,'Pe Ell, WA',29832,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72700,NULL,'Pe Ell, WA 98572',29832,222,NULL,56,42575,0);
INSERT INTO "django_geo_db_location" VALUES(72701,NULL,'Quinault, WA',29833,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72702,NULL,'Quinault, WA 98575',29833,222,NULL,56,42576,0);
INSERT INTO "django_geo_db_location" VALUES(72703,NULL,'Rainier, WA',29834,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72704,NULL,'Rainier, WA 98576',29834,222,NULL,56,42577,0);
INSERT INTO "django_geo_db_location" VALUES(72705,NULL,'Raymond, WA',29835,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72706,NULL,'Raymond, WA 98577',29835,222,NULL,56,42578,0);
INSERT INTO "django_geo_db_location" VALUES(72707,NULL,'Rochester, WA',29836,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72708,NULL,'Rochester, WA 98579',29836,222,NULL,56,42579,0);
INSERT INTO "django_geo_db_location" VALUES(72709,NULL,'Roy, WA',29837,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72710,NULL,'Roy, WA 98580',29837,222,NULL,56,42580,0);
INSERT INTO "django_geo_db_location" VALUES(72711,NULL,'Ryderwood, WA',29838,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72712,NULL,'Ryderwood, WA 98581',29838,222,NULL,56,42581,0);
INSERT INTO "django_geo_db_location" VALUES(72713,NULL,'Salkum, WA',29839,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72714,NULL,'Salkum, WA 98582',29839,222,NULL,56,42582,0);
INSERT INTO "django_geo_db_location" VALUES(72715,NULL,'Satsop, WA',29840,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72716,NULL,'Satsop, WA 98583',29840,222,NULL,56,42583,0);
INSERT INTO "django_geo_db_location" VALUES(72717,NULL,'Shelton, WA',29841,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72718,NULL,'Shelton, WA 98584',29841,222,NULL,56,42584,0);
INSERT INTO "django_geo_db_location" VALUES(72719,NULL,'Silver Creek, WA',29842,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72720,NULL,'Silver Creek, WA 98585',29842,222,NULL,56,42585,0);
INSERT INTO "django_geo_db_location" VALUES(72721,NULL,'South Bend, WA',29843,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72722,NULL,'South Bend, WA 98586',29843,222,NULL,56,42586,0);
INSERT INTO "django_geo_db_location" VALUES(72723,NULL,'Taholah, WA',29844,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72724,NULL,'Taholah, WA 98587',29844,222,NULL,56,42587,0);
INSERT INTO "django_geo_db_location" VALUES(72725,NULL,'Tahuya, WA',29845,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72726,NULL,'Tahuya, WA 98588',29845,222,NULL,56,42588,0);
INSERT INTO "django_geo_db_location" VALUES(72727,NULL,'Tenino, WA',29846,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72728,NULL,'Tenino, WA 98589',29846,222,NULL,56,42589,0);
INSERT INTO "django_geo_db_location" VALUES(72729,NULL,'Tokeland, WA',29847,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72730,NULL,'Tokeland, WA 98590',29847,222,NULL,56,42590,0);
INSERT INTO "django_geo_db_location" VALUES(72731,NULL,'Toledo, WA',29848,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72732,NULL,'Toledo, WA 98591',29848,222,NULL,56,42591,0);
INSERT INTO "django_geo_db_location" VALUES(72733,NULL,'Union, WA',29849,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72734,NULL,'Union, WA 98592',29849,222,NULL,56,42592,0);
INSERT INTO "django_geo_db_location" VALUES(72735,NULL,'Vader, WA',29850,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72736,NULL,'Vader, WA 98593',29850,222,NULL,56,42593,0);
INSERT INTO "django_geo_db_location" VALUES(72737,NULL,'Westport, WA',29851,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72738,NULL,'Westport, WA 98595',29851,222,NULL,56,42594,0);
INSERT INTO "django_geo_db_location" VALUES(72739,NULL,'Winlock, WA',29852,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72740,NULL,'Winlock, WA 98596',29852,222,NULL,56,42595,0);
INSERT INTO "django_geo_db_location" VALUES(72741,NULL,'Yelm, WA',29853,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72742,NULL,'Yelm, WA 98597',29853,222,NULL,56,42596,0);
INSERT INTO "django_geo_db_location" VALUES(72743,NULL,'Olympia, WA 98599',29790,222,NULL,56,42597,0);
INSERT INTO "django_geo_db_location" VALUES(72744,NULL,'Amboy, WA',29854,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72745,NULL,'Amboy, WA 98601',29854,222,NULL,56,42598,0);
INSERT INTO "django_geo_db_location" VALUES(72746,NULL,'Appleton, WA',29855,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72747,NULL,'Appleton, WA 98602',29855,222,NULL,56,42599,0);
INSERT INTO "django_geo_db_location" VALUES(72748,NULL,'Ariel, WA',29856,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72749,NULL,'Ariel, WA 98603',29856,222,NULL,56,42600,0);
INSERT INTO "django_geo_db_location" VALUES(72750,NULL,'Battle Ground, WA',29857,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72751,NULL,'Battle Ground, WA 98604',29857,222,NULL,56,42601,0);
INSERT INTO "django_geo_db_location" VALUES(72752,NULL,'Bingen, WA',29858,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72753,NULL,'Bingen, WA 98605',29858,222,NULL,56,42602,0);
INSERT INTO "django_geo_db_location" VALUES(72754,NULL,'Brush Prairie, WA',29859,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72755,NULL,'Brush Prairie, WA 98606',29859,222,NULL,56,42603,0);
INSERT INTO "django_geo_db_location" VALUES(72756,NULL,'Camas, WA',29860,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72757,NULL,'Camas, WA 98607',29860,222,NULL,56,42604,0);
INSERT INTO "django_geo_db_location" VALUES(72758,NULL,'Carrolls, WA',29861,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72759,NULL,'Carrolls, WA 98609',29861,222,NULL,56,42605,0);
INSERT INTO "django_geo_db_location" VALUES(72760,NULL,'Carson, WA',29862,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72761,NULL,'Carson, WA 98610',29862,222,NULL,56,42606,0);
INSERT INTO "django_geo_db_location" VALUES(72762,NULL,'Castle Rock, WA',29863,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72763,NULL,'Castle Rock, WA 98611',29863,222,NULL,56,42607,0);
INSERT INTO "django_geo_db_location" VALUES(72764,NULL,'Cathlamet, WA',29864,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72765,NULL,'Cathlamet, WA 98612',29864,222,NULL,56,42608,0);
INSERT INTO "django_geo_db_location" VALUES(72766,NULL,'Centerville, WA',29865,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72767,NULL,'Centerville, WA 98613',29865,222,NULL,56,42609,0);
INSERT INTO "django_geo_db_location" VALUES(72768,NULL,'Chinook, WA',29866,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72769,NULL,'Chinook, WA 98614',29866,222,NULL,56,42610,0);
INSERT INTO "django_geo_db_location" VALUES(72770,NULL,'Cougar, WA',29867,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72771,NULL,'Cougar, WA 98616',29867,222,NULL,56,42611,0);
INSERT INTO "django_geo_db_location" VALUES(72772,NULL,'Dallesport, WA',29868,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72773,NULL,'Dallesport, WA 98617',29868,222,NULL,56,42612,0);
INSERT INTO "django_geo_db_location" VALUES(72774,NULL,'Glenwood, WA',29869,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72775,NULL,'Glenwood, WA 98619',29869,222,NULL,56,42613,0);
INSERT INTO "django_geo_db_location" VALUES(72776,NULL,'Goldendale, WA',29870,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72777,NULL,'Goldendale, WA 98620',29870,222,NULL,56,42614,0);
INSERT INTO "django_geo_db_location" VALUES(72778,NULL,'Grays River, WA',29871,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72779,NULL,'Grays River, WA 98621',29871,222,NULL,56,42615,0);
INSERT INTO "django_geo_db_location" VALUES(72780,NULL,'Heisson, WA',29872,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72781,NULL,'Heisson, WA 98622',29872,222,NULL,56,42616,0);
INSERT INTO "django_geo_db_location" VALUES(72782,NULL,'Husum, WA',29873,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72783,NULL,'Husum, WA 98623',29873,222,NULL,56,42617,0);
INSERT INTO "django_geo_db_location" VALUES(72784,NULL,'Ilwaco, WA',29874,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72785,NULL,'Ilwaco, WA 98624',29874,222,NULL,56,42618,0);
INSERT INTO "django_geo_db_location" VALUES(72786,NULL,'Kalama, WA',29875,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72787,NULL,'Kalama, WA 98625',29875,222,NULL,56,42619,0);
INSERT INTO "django_geo_db_location" VALUES(72788,NULL,'Kelso, WA',29876,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72789,NULL,'Kelso, WA 98626',29876,222,NULL,56,42620,0);
INSERT INTO "django_geo_db_location" VALUES(72790,NULL,'Klickitat, WA',29877,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72791,NULL,'Klickitat, WA 98628',29877,222,NULL,56,42621,0);
INSERT INTO "django_geo_db_location" VALUES(72792,NULL,'La Center, WA',29878,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72793,NULL,'La Center, WA 98629',29878,222,NULL,56,42622,0);
INSERT INTO "django_geo_db_location" VALUES(72794,NULL,'Long Beach, WA',29879,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72795,NULL,'Long Beach, WA 98631',29879,222,NULL,56,42623,0);
INSERT INTO "django_geo_db_location" VALUES(72796,NULL,'Longview, WA',29880,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72797,NULL,'Longview, WA 98632',29880,222,NULL,56,42624,0);
INSERT INTO "django_geo_db_location" VALUES(72798,NULL,'Lyle, WA',29881,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72799,NULL,'Lyle, WA 98635',29881,222,NULL,56,42625,0);
INSERT INTO "django_geo_db_location" VALUES(72800,NULL,'Nahcotta, WA',29882,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72801,NULL,'Nahcotta, WA 98637',29882,222,NULL,56,42626,0);
INSERT INTO "django_geo_db_location" VALUES(72802,NULL,'Naselle, WA',29883,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72803,NULL,'Naselle, WA 98638',29883,222,NULL,56,42627,0);
INSERT INTO "django_geo_db_location" VALUES(72804,NULL,'North Bonneville, WA',29884,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72805,NULL,'North Bonneville, WA 98639',29884,222,NULL,56,42628,0);
INSERT INTO "django_geo_db_location" VALUES(72806,NULL,'Ocean Park, WA',29885,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72807,NULL,'Ocean Park, WA 98640',29885,222,NULL,56,42629,0);
INSERT INTO "django_geo_db_location" VALUES(72808,NULL,'Oysterville, WA',29886,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72809,NULL,'Oysterville, WA 98641',29886,222,NULL,56,42630,0);
INSERT INTO "django_geo_db_location" VALUES(72810,NULL,'Ridgefield, WA',29887,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72811,NULL,'Ridgefield, WA 98642',29887,222,NULL,56,42631,0);
INSERT INTO "django_geo_db_location" VALUES(72812,NULL,'Rosburg, WA',29888,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72813,NULL,'Rosburg, WA 98643',29888,222,NULL,56,42632,0);
INSERT INTO "django_geo_db_location" VALUES(72814,NULL,'Seaview, WA',29889,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72815,NULL,'Seaview, WA 98644',29889,222,NULL,56,42633,0);
INSERT INTO "django_geo_db_location" VALUES(72816,NULL,'Silverlake, WA',29890,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72817,NULL,'Silverlake, WA 98645',29890,222,NULL,56,42634,0);
INSERT INTO "django_geo_db_location" VALUES(72818,NULL,'Skamokawa, WA',29891,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72819,NULL,'Skamokawa, WA 98647',29891,222,NULL,56,42635,0);
INSERT INTO "django_geo_db_location" VALUES(72820,NULL,'Stevenson, WA',29892,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72821,NULL,'Stevenson, WA 98648',29892,222,NULL,56,42636,0);
INSERT INTO "django_geo_db_location" VALUES(72822,NULL,'Toutle, WA',29893,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72823,NULL,'Toutle, WA 98649',29893,222,NULL,56,42637,0);
INSERT INTO "django_geo_db_location" VALUES(72824,NULL,'Trout Lake, WA',29894,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72825,NULL,'Trout Lake, WA 98650',29894,222,NULL,56,42638,0);
INSERT INTO "django_geo_db_location" VALUES(72826,NULL,'Underwood, WA',29895,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72827,NULL,'Underwood, WA 98651',29895,222,NULL,56,42639,0);
INSERT INTO "django_geo_db_location" VALUES(72828,NULL,'Lyle, WA 98653',29881,222,NULL,56,42640,0);
INSERT INTO "django_geo_db_location" VALUES(72829,NULL,'Hazel Dell North, WA',29896,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72830,NULL,'Hazel Dell North, WA 98655',29896,222,NULL,56,42641,0);
INSERT INTO "django_geo_db_location" VALUES(72831,NULL,'Vancouver, WA',29897,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72832,NULL,'Vancouver, WA 98660',29897,222,NULL,56,42642,0);
INSERT INTO "django_geo_db_location" VALUES(72833,NULL,'Vancouver, WA 98661',29897,222,NULL,56,42643,0);
INSERT INTO "django_geo_db_location" VALUES(72834,NULL,'Vancouver, WA 98662',29897,222,NULL,56,42644,0);
INSERT INTO "django_geo_db_location" VALUES(72835,NULL,'Vancouver, WA 98663',29897,222,NULL,56,42645,0);
INSERT INTO "django_geo_db_location" VALUES(72836,NULL,'Vancouver, WA 98664',29897,222,NULL,56,42646,0);
INSERT INTO "django_geo_db_location" VALUES(72837,NULL,'Vancouver, WA 98665',29897,222,NULL,56,42647,0);
INSERT INTO "django_geo_db_location" VALUES(72838,NULL,'Vancouver, WA 98666',29897,222,NULL,56,42648,0);
INSERT INTO "django_geo_db_location" VALUES(72839,NULL,'Vancouver, WA 98667',29897,222,NULL,56,42649,0);
INSERT INTO "django_geo_db_location" VALUES(72840,NULL,'Vancouver, WA 98668',29897,222,NULL,56,42650,0);
INSERT INTO "django_geo_db_location" VALUES(72841,NULL,'Wahkiacus, WA',29898,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72842,NULL,'Wahkiacus, WA 98670',29898,222,NULL,56,42651,0);
INSERT INTO "django_geo_db_location" VALUES(72843,NULL,'Washougal, WA',29899,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72844,NULL,'Washougal, WA 98671',29899,222,NULL,56,42652,0);
INSERT INTO "django_geo_db_location" VALUES(72845,NULL,'White Salmon, WA',29900,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72846,NULL,'White Salmon, WA 98672',29900,222,NULL,56,42653,0);
INSERT INTO "django_geo_db_location" VALUES(72847,NULL,'Wishram, WA',29901,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72848,NULL,'Wishram, WA 98673',29901,222,NULL,56,42654,0);
INSERT INTO "django_geo_db_location" VALUES(72849,NULL,'Woodland, WA',29902,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72850,NULL,'Woodland, WA 98674',29902,222,NULL,56,42655,0);
INSERT INTO "django_geo_db_location" VALUES(72851,NULL,'Yacolt, WA',29903,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72852,NULL,'Yacolt, WA 98675',29903,222,NULL,56,42656,0);
INSERT INTO "django_geo_db_location" VALUES(72853,NULL,'Vancouver, WA 98682',29897,222,NULL,56,42657,0);
INSERT INTO "django_geo_db_location" VALUES(72854,NULL,'Vancouver, WA 98683',29897,222,NULL,56,42658,0);
INSERT INTO "django_geo_db_location" VALUES(72855,NULL,'Vancouver, WA 98684',29897,222,NULL,56,42659,0);
INSERT INTO "django_geo_db_location" VALUES(72856,NULL,'Vancouver, WA 98685',29897,222,NULL,56,42660,0);
INSERT INTO "django_geo_db_location" VALUES(72857,NULL,'Vancouver, WA 98686',29897,222,NULL,56,42661,0);
INSERT INTO "django_geo_db_location" VALUES(72858,NULL,'Vancouver, WA 98687',29897,222,NULL,56,42662,0);
INSERT INTO "django_geo_db_location" VALUES(72859,NULL,'Waller, WA',29904,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72860,NULL,'Waller, WA 98731',29904,222,NULL,56,42663,0);
INSERT INTO "django_geo_db_location" VALUES(72861,NULL,'Wenatchee, WA',29905,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72862,NULL,'Wenatchee, WA 98801',29905,222,NULL,56,42664,0);
INSERT INTO "django_geo_db_location" VALUES(72863,NULL,'East Wenatchee, WA',29906,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72864,NULL,'East Wenatchee, WA 98802',29906,222,NULL,56,42665,0);
INSERT INTO "django_geo_db_location" VALUES(72865,NULL,'Wenatchee, WA 98807',29905,222,NULL,56,42666,0);
INSERT INTO "django_geo_db_location" VALUES(72866,NULL,'Ardenvoir, WA',29907,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72867,NULL,'Ardenvoir, WA 98811',29907,222,NULL,56,42667,0);
INSERT INTO "django_geo_db_location" VALUES(72868,NULL,'Brewster, WA',29908,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72869,NULL,'Brewster, WA 98812',29908,222,NULL,56,42668,0);
INSERT INTO "django_geo_db_location" VALUES(72870,NULL,'Bridgeport, WA',29909,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72871,NULL,'Bridgeport, WA 98813',29909,222,NULL,56,42669,0);
INSERT INTO "django_geo_db_location" VALUES(72872,NULL,'Carlton, WA',29910,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72873,NULL,'Carlton, WA 98814',29910,222,NULL,56,42670,0);
INSERT INTO "django_geo_db_location" VALUES(72874,NULL,'Cashmere, WA',29911,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72875,NULL,'Cashmere, WA 98815',29911,222,NULL,56,42671,0);
INSERT INTO "django_geo_db_location" VALUES(72876,NULL,'Chelan, WA',29912,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72877,NULL,'Chelan, WA 98816',29912,222,NULL,56,42672,0);
INSERT INTO "django_geo_db_location" VALUES(72878,NULL,'Chelan Falls, WA',29913,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72879,NULL,'Chelan Falls, WA 98817',29913,222,NULL,56,42673,0);
INSERT INTO "django_geo_db_location" VALUES(72880,NULL,'Conconully, WA',29914,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72881,NULL,'Conconully, WA 98819',29914,222,NULL,56,42674,0);
INSERT INTO "django_geo_db_location" VALUES(72882,NULL,'Dryden, WA',29915,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72883,NULL,'Dryden, WA 98821',29915,222,NULL,56,42675,0);
INSERT INTO "django_geo_db_location" VALUES(72884,NULL,'Entiat, WA',29916,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72885,NULL,'Entiat, WA 98822',29916,222,NULL,56,42676,0);
INSERT INTO "django_geo_db_location" VALUES(72886,NULL,'Ephrata, WA',29917,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72887,NULL,'Ephrata, WA 98823',29917,222,NULL,56,42677,0);
INSERT INTO "django_geo_db_location" VALUES(72888,NULL,'George, WA',29918,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72889,NULL,'George, WA 98824',29918,222,NULL,56,42678,0);
INSERT INTO "django_geo_db_location" VALUES(72890,NULL,'Leavenworth, WA',29919,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72891,NULL,'Leavenworth, WA 98826',29919,222,NULL,56,42679,0);
INSERT INTO "django_geo_db_location" VALUES(72892,NULL,'Loomis, WA',29920,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72893,NULL,'Loomis, WA 98827',29920,222,NULL,56,42680,0);
INSERT INTO "django_geo_db_location" VALUES(72894,NULL,'Malaga, WA',29921,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72895,NULL,'Malaga, WA 98828',29921,222,NULL,56,42681,0);
INSERT INTO "django_geo_db_location" VALUES(72896,NULL,'Malott, WA',29922,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72897,NULL,'Malott, WA 98829',29922,222,NULL,56,42682,0);
INSERT INTO "django_geo_db_location" VALUES(72898,NULL,'Mansfield, WA',29923,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72899,NULL,'Mansfield, WA 98830',29923,222,NULL,56,42683,0);
INSERT INTO "django_geo_db_location" VALUES(72900,NULL,'Manson, WA',29924,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72901,NULL,'Manson, WA 98831',29924,222,NULL,56,42684,0);
INSERT INTO "django_geo_db_location" VALUES(72902,NULL,'Marlin, WA',29925,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72903,NULL,'Marlin, WA 98832',29925,222,NULL,56,42685,0);
INSERT INTO "django_geo_db_location" VALUES(72904,NULL,'Mazama, WA',29926,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72905,NULL,'Mazama, WA 98833',29926,222,NULL,56,42686,0);
INSERT INTO "django_geo_db_location" VALUES(72906,NULL,'Methow, WA',29927,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72907,NULL,'Methow, WA 98834',29927,222,NULL,56,42687,0);
INSERT INTO "django_geo_db_location" VALUES(72908,NULL,'Monitor, WA',29928,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72909,NULL,'Monitor, WA 98836',29928,222,NULL,56,42688,0);
INSERT INTO "django_geo_db_location" VALUES(72910,NULL,'Moses Lake, WA',29929,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72911,NULL,'Moses Lake, WA 98837',29929,222,NULL,56,42689,0);
INSERT INTO "django_geo_db_location" VALUES(72912,NULL,'Okanogan, WA',29930,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72913,NULL,'Okanogan, WA 98840',29930,222,NULL,56,42690,0);
INSERT INTO "django_geo_db_location" VALUES(72914,NULL,'Omak, WA',29931,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72915,NULL,'Omak, WA 98841',29931,222,NULL,56,42691,0);
INSERT INTO "django_geo_db_location" VALUES(72916,NULL,'Orondo, WA',29932,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72917,NULL,'Orondo, WA 98843',29932,222,NULL,56,42692,0);
INSERT INTO "django_geo_db_location" VALUES(72918,NULL,'Oroville, WA',29933,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72919,NULL,'Oroville, WA 98844',29933,222,NULL,56,42693,0);
INSERT INTO "django_geo_db_location" VALUES(72920,NULL,'Palisades, WA',29934,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72921,NULL,'Palisades, WA 98845',29934,222,NULL,56,42694,0);
INSERT INTO "django_geo_db_location" VALUES(72922,NULL,'Pateros, WA',29935,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72923,NULL,'Pateros, WA 98846',29935,222,NULL,56,42695,0);
INSERT INTO "django_geo_db_location" VALUES(72924,NULL,'Peshastin, WA',29936,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72925,NULL,'Peshastin, WA 98847',29936,222,NULL,56,42696,0);
INSERT INTO "django_geo_db_location" VALUES(72926,NULL,'Quincy, WA',29937,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72927,NULL,'Quincy, WA 98848',29937,222,NULL,56,42697,0);
INSERT INTO "django_geo_db_location" VALUES(72928,NULL,'Riverside, WA',29938,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72929,NULL,'Riverside, WA 98849',29938,222,NULL,56,42698,0);
INSERT INTO "django_geo_db_location" VALUES(72930,NULL,'Rock Island, WA',29939,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72931,NULL,'Rock Island, WA 98850',29939,222,NULL,56,42699,0);
INSERT INTO "django_geo_db_location" VALUES(72932,NULL,'Soap Lake, WA',29940,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72933,NULL,'Soap Lake, WA 98851',29940,222,NULL,56,42700,0);
INSERT INTO "django_geo_db_location" VALUES(72934,NULL,'Stehekin, WA',29941,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72935,NULL,'Stehekin, WA 98852',29941,222,NULL,56,42701,0);
INSERT INTO "django_geo_db_location" VALUES(72936,NULL,'Stratford, WA',29942,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72937,NULL,'Stratford, WA 98853',29942,222,NULL,56,42702,0);
INSERT INTO "django_geo_db_location" VALUES(72938,NULL,'Tonasket, WA',29943,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72939,NULL,'Tonasket, WA 98855',29943,222,NULL,56,42703,0);
INSERT INTO "django_geo_db_location" VALUES(72940,NULL,'Twisp, WA',29944,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72941,NULL,'Twisp, WA 98856',29944,222,NULL,56,42704,0);
INSERT INTO "django_geo_db_location" VALUES(72942,NULL,'Warden, WA',29945,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72943,NULL,'Warden, WA 98857',29945,222,NULL,56,42705,0);
INSERT INTO "django_geo_db_location" VALUES(72944,NULL,'Waterville, WA',29946,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72945,NULL,'Waterville, WA 98858',29946,222,NULL,56,42706,0);
INSERT INTO "django_geo_db_location" VALUES(72946,NULL,'Wauconda, WA',29947,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72947,NULL,'Wauconda, WA 98859',29947,222,NULL,56,42707,0);
INSERT INTO "django_geo_db_location" VALUES(72948,NULL,'Wilson Creek, WA',29948,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72949,NULL,'Wilson Creek, WA 98860',29948,222,NULL,56,42708,0);
INSERT INTO "django_geo_db_location" VALUES(72950,NULL,'Winthrop, WA',29949,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72951,NULL,'Winthrop, WA 98862',29949,222,NULL,56,42709,0);
INSERT INTO "django_geo_db_location" VALUES(72952,NULL,'Yakima, WA',29950,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72953,NULL,'Yakima, WA 98901',29950,222,NULL,56,42710,0);
INSERT INTO "django_geo_db_location" VALUES(72954,NULL,'Yakima, WA 98902',29950,222,NULL,56,42711,0);
INSERT INTO "django_geo_db_location" VALUES(72955,NULL,'Yakima, WA 98903',29950,222,NULL,56,42712,0);
INSERT INTO "django_geo_db_location" VALUES(72956,NULL,'Yakima, WA 98904',29950,222,NULL,56,42713,0);
INSERT INTO "django_geo_db_location" VALUES(72957,NULL,'Yakima, WA 98907',29950,222,NULL,56,42714,0);
INSERT INTO "django_geo_db_location" VALUES(72958,NULL,'Yakima, WA 98908',29950,222,NULL,56,42715,0);
INSERT INTO "django_geo_db_location" VALUES(72959,NULL,'Yakima, WA 98909',29950,222,NULL,56,42716,0);
INSERT INTO "django_geo_db_location" VALUES(72960,NULL,'Brownstown, WA',29951,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72961,NULL,'Brownstown, WA 98920',29951,222,NULL,56,42717,0);
INSERT INTO "django_geo_db_location" VALUES(72962,NULL,'Buena, WA',29952,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72963,NULL,'Buena, WA 98921',29952,222,NULL,56,42718,0);
INSERT INTO "django_geo_db_location" VALUES(72964,NULL,'Cle Elum, WA',29953,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72965,NULL,'Cle Elum, WA 98922',29953,222,NULL,56,42719,0);
INSERT INTO "django_geo_db_location" VALUES(72966,NULL,'Cowiche, WA',29954,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72967,NULL,'Cowiche, WA 98923',29954,222,NULL,56,42720,0);
INSERT INTO "django_geo_db_location" VALUES(72968,NULL,'Easton, WA',29955,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72969,NULL,'Easton, WA 98925',29955,222,NULL,56,42721,0);
INSERT INTO "django_geo_db_location" VALUES(72970,NULL,'Ellensburg, WA',29956,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72971,NULL,'Ellensburg, WA 98926',29956,222,NULL,56,42722,0);
INSERT INTO "django_geo_db_location" VALUES(72972,NULL,'Goose Prairie, WA',29957,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72973,NULL,'Goose Prairie, WA 98929',29957,222,NULL,56,42723,0);
INSERT INTO "django_geo_db_location" VALUES(72974,NULL,'Grandview, WA',29958,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72975,NULL,'Grandview, WA 98930',29958,222,NULL,56,42724,0);
INSERT INTO "django_geo_db_location" VALUES(72976,NULL,'Granger, WA',29959,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72977,NULL,'Granger, WA 98932',29959,222,NULL,56,42725,0);
INSERT INTO "django_geo_db_location" VALUES(72978,NULL,'Harrah, WA',29960,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72979,NULL,'Harrah, WA 98933',29960,222,NULL,56,42726,0);
INSERT INTO "django_geo_db_location" VALUES(72980,NULL,'Kittitas, WA',29961,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72981,NULL,'Kittitas, WA 98934',29961,222,NULL,56,42727,0);
INSERT INTO "django_geo_db_location" VALUES(72982,NULL,'Mabton, WA',29962,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72983,NULL,'Mabton, WA 98935',29962,222,NULL,56,42728,0);
INSERT INTO "django_geo_db_location" VALUES(72984,NULL,'Moxee, WA',29963,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72985,NULL,'Moxee, WA 98936',29963,222,NULL,56,42729,0);
INSERT INTO "django_geo_db_location" VALUES(72986,NULL,'Naches, WA',29964,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72987,NULL,'Naches, WA 98937',29964,222,NULL,56,42730,0);
INSERT INTO "django_geo_db_location" VALUES(72988,NULL,'Outlook, WA',29965,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72989,NULL,'Outlook, WA 98938',29965,222,NULL,56,42731,0);
INSERT INTO "django_geo_db_location" VALUES(72990,NULL,'Parker, WA',29966,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72991,NULL,'Parker, WA 98939',29966,222,NULL,56,42732,0);
INSERT INTO "django_geo_db_location" VALUES(72992,NULL,'Ronald, WA',29967,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72993,NULL,'Ronald, WA 98940',29967,222,NULL,56,42733,0);
INSERT INTO "django_geo_db_location" VALUES(72994,NULL,'Roslyn, WA',29968,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72995,NULL,'Roslyn, WA 98941',29968,222,NULL,56,42734,0);
INSERT INTO "django_geo_db_location" VALUES(72996,NULL,'Selah, WA',29969,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72997,NULL,'Selah, WA 98942',29969,222,NULL,56,42735,0);
INSERT INTO "django_geo_db_location" VALUES(72998,NULL,'South Cle Elum, WA',29970,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(72999,NULL,'South Cle Elum, WA 98943',29970,222,NULL,56,42736,0);
INSERT INTO "django_geo_db_location" VALUES(73000,NULL,'Sunnyside, WA',29971,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73001,NULL,'Sunnyside, WA 98944',29971,222,NULL,56,42737,0);
INSERT INTO "django_geo_db_location" VALUES(73002,NULL,'Thorp, WA',29972,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73003,NULL,'Thorp, WA 98946',29972,222,NULL,56,42738,0);
INSERT INTO "django_geo_db_location" VALUES(73004,NULL,'Tieton, WA',29973,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73005,NULL,'Tieton, WA 98947',29973,222,NULL,56,42739,0);
INSERT INTO "django_geo_db_location" VALUES(73006,NULL,'Toppenish, WA',29974,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73007,NULL,'Toppenish, WA 98948',29974,222,NULL,56,42740,0);
INSERT INTO "django_geo_db_location" VALUES(73008,NULL,'Vantage, WA',29975,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73009,NULL,'Vantage, WA 98950',29975,222,NULL,56,42741,0);
INSERT INTO "django_geo_db_location" VALUES(73010,NULL,'Wapato, WA',29976,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73011,NULL,'Wapato, WA 98951',29976,222,NULL,56,42742,0);
INSERT INTO "django_geo_db_location" VALUES(73012,NULL,'White Swan, WA',29977,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73013,NULL,'White Swan, WA 98952',29977,222,NULL,56,42743,0);
INSERT INTO "django_geo_db_location" VALUES(73014,NULL,'Zillah, WA',29978,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73015,NULL,'Zillah, WA 98953',29978,222,NULL,56,42744,0);
INSERT INTO "django_geo_db_location" VALUES(73016,NULL,'Roslyn, WA 98991',29968,222,NULL,56,42745,0);
INSERT INTO "django_geo_db_location" VALUES(73017,NULL,'Airway Heights, WA',29979,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73018,NULL,'Airway Heights, WA 99001',29979,222,NULL,56,42746,0);
INSERT INTO "django_geo_db_location" VALUES(73019,NULL,'Chattaroy, WA',29980,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73020,NULL,'Chattaroy, WA 99003',29980,222,NULL,56,42747,0);
INSERT INTO "django_geo_db_location" VALUES(73021,NULL,'Cheney, WA',29981,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73022,NULL,'Cheney, WA 99004',29981,222,NULL,56,42748,0);
INSERT INTO "django_geo_db_location" VALUES(73023,NULL,'Colbert, WA',29982,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73024,NULL,'Colbert, WA 99005',29982,222,NULL,56,42749,0);
INSERT INTO "django_geo_db_location" VALUES(73025,NULL,'Deer Park, WA',29983,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73026,NULL,'Deer Park, WA 99006',29983,222,NULL,56,42750,0);
INSERT INTO "django_geo_db_location" VALUES(73027,NULL,'Edwall, WA',29984,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73028,NULL,'Edwall, WA 99008',29984,222,NULL,56,42751,0);
INSERT INTO "django_geo_db_location" VALUES(73029,NULL,'Elk, WA',29985,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73030,NULL,'Elk, WA 99009',29985,222,NULL,56,42752,0);
INSERT INTO "django_geo_db_location" VALUES(73031,NULL,'Fairchild Air Force Base, WA',29986,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73032,NULL,'Fairchild Air Force Base, WA 99011',29986,222,NULL,56,42753,0);
INSERT INTO "django_geo_db_location" VALUES(73033,NULL,'Fairfield, WA',29987,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73034,NULL,'Fairfield, WA 99012',29987,222,NULL,56,42754,0);
INSERT INTO "django_geo_db_location" VALUES(73035,NULL,'Ford, WA',29988,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73036,NULL,'Ford, WA 99013',29988,222,NULL,56,42755,0);
INSERT INTO "django_geo_db_location" VALUES(73037,NULL,'Four Lakes, WA',29989,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73038,NULL,'Four Lakes, WA 99014',29989,222,NULL,56,42756,0);
INSERT INTO "django_geo_db_location" VALUES(73039,NULL,'Freeman, WA',29990,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73040,NULL,'Freeman, WA 99015',29990,222,NULL,56,42757,0);
INSERT INTO "django_geo_db_location" VALUES(73041,NULL,'Greenacres, WA',29991,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73042,NULL,'Greenacres, WA 99016',29991,222,NULL,56,42758,0);
INSERT INTO "django_geo_db_location" VALUES(73043,NULL,'Lamont, WA',29992,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73044,NULL,'Lamont, WA 99017',29992,222,NULL,56,42759,0);
INSERT INTO "django_geo_db_location" VALUES(73045,NULL,'Latah, WA',29993,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73046,NULL,'Latah, WA 99018',29993,222,NULL,56,42760,0);
INSERT INTO "django_geo_db_location" VALUES(73047,NULL,'Liberty Lake, WA',29994,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73048,NULL,'Liberty Lake, WA 99019',29994,222,NULL,56,42761,0);
INSERT INTO "django_geo_db_location" VALUES(73049,NULL,'Marshall, WA',29995,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73050,NULL,'Marshall, WA 99020',29995,222,NULL,56,42762,0);
INSERT INTO "django_geo_db_location" VALUES(73051,NULL,'Mead, WA',29996,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73052,NULL,'Mead, WA 99021',29996,222,NULL,56,42763,0);
INSERT INTO "django_geo_db_location" VALUES(73053,NULL,'Medical Lake, WA',29997,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73054,NULL,'Medical Lake, WA 99022',29997,222,NULL,56,42764,0);
INSERT INTO "django_geo_db_location" VALUES(73055,NULL,'Mica, WA',29998,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73056,NULL,'Mica, WA 99023',29998,222,NULL,56,42765,0);
INSERT INTO "django_geo_db_location" VALUES(73057,NULL,'Newman Lake, WA',29999,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73058,NULL,'Newman Lake, WA 99025',29999,222,NULL,56,42766,0);
INSERT INTO "django_geo_db_location" VALUES(73059,NULL,'Nine Mile Falls, WA',30000,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73060,NULL,'Nine Mile Falls, WA 99026',30000,222,NULL,56,42767,0);
INSERT INTO "django_geo_db_location" VALUES(73061,NULL,'Otis Orchards, WA',30001,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73062,NULL,'Otis Orchards, WA 99027',30001,222,NULL,56,42768,0);
INSERT INTO "django_geo_db_location" VALUES(73063,NULL,'Reardan, WA',30002,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73064,NULL,'Reardan, WA 99029',30002,222,NULL,56,42769,0);
INSERT INTO "django_geo_db_location" VALUES(73065,NULL,'Rockford, WA',30003,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73066,NULL,'Rockford, WA 99030',30003,222,NULL,56,42770,0);
INSERT INTO "django_geo_db_location" VALUES(73067,NULL,'Spangle, WA',30004,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73068,NULL,'Spangle, WA 99031',30004,222,NULL,56,42771,0);
INSERT INTO "django_geo_db_location" VALUES(73069,NULL,'Sprague, WA',30005,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73070,NULL,'Sprague, WA 99032',30005,222,NULL,56,42772,0);
INSERT INTO "django_geo_db_location" VALUES(73071,NULL,'Tekoa, WA',30006,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73072,NULL,'Tekoa, WA 99033',30006,222,NULL,56,42773,0);
INSERT INTO "django_geo_db_location" VALUES(73073,NULL,'Tumtum, WA',30007,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73074,NULL,'Tumtum, WA 99034',30007,222,NULL,56,42774,0);
INSERT INTO "django_geo_db_location" VALUES(73075,NULL,'Valleyford, WA',30008,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73076,NULL,'Valleyford, WA 99036',30008,222,NULL,56,42775,0);
INSERT INTO "django_geo_db_location" VALUES(73077,NULL,'Veradale, WA',30009,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73078,NULL,'Veradale, WA 99037',30009,222,NULL,56,42776,0);
INSERT INTO "django_geo_db_location" VALUES(73079,NULL,'Waverly, WA',30010,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73080,NULL,'Waverly, WA 99039',30010,222,NULL,56,42777,0);
INSERT INTO "django_geo_db_location" VALUES(73081,NULL,'Wellpinit, WA',30011,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73082,NULL,'Wellpinit, WA 99040',30011,222,NULL,56,42778,0);
INSERT INTO "django_geo_db_location" VALUES(73083,NULL,'Deer Park, WA 99066',29983,222,NULL,56,42779,0);
INSERT INTO "django_geo_db_location" VALUES(73084,NULL,'Addy, WA',30012,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73085,NULL,'Addy, WA 99101',30012,222,NULL,56,42780,0);
INSERT INTO "django_geo_db_location" VALUES(73086,NULL,'Albion, WA',30013,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73087,NULL,'Albion, WA 99102',30013,222,NULL,56,42781,0);
INSERT INTO "django_geo_db_location" VALUES(73088,NULL,'Almira, WA',30014,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73089,NULL,'Almira, WA 99103',30014,222,NULL,56,42782,0);
INSERT INTO "django_geo_db_location" VALUES(73090,NULL,'Belmont, WA',30015,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73091,NULL,'Belmont, WA 99104',30015,222,NULL,56,42783,0);
INSERT INTO "django_geo_db_location" VALUES(73092,NULL,'Benge, WA',30016,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73093,NULL,'Benge, WA 99105',30016,222,NULL,56,42784,0);
INSERT INTO "django_geo_db_location" VALUES(73094,NULL,'Boyds, WA',30017,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73095,NULL,'Boyds, WA 99107',30017,222,NULL,56,42785,0);
INSERT INTO "django_geo_db_location" VALUES(73096,NULL,'Chewelah, WA',30018,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73097,NULL,'Chewelah, WA 99109',30018,222,NULL,56,42786,0);
INSERT INTO "django_geo_db_location" VALUES(73098,NULL,'Clayton, WA',30019,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73099,NULL,'Clayton, WA 99110',30019,222,NULL,56,42787,0);
INSERT INTO "django_geo_db_location" VALUES(73100,NULL,'Colfax, WA',30020,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73101,NULL,'Colfax, WA 99111',30020,222,NULL,56,42788,0);
INSERT INTO "django_geo_db_location" VALUES(73102,NULL,'Colton, WA',30021,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73103,NULL,'Colton, WA 99113',30021,222,NULL,56,42789,0);
INSERT INTO "django_geo_db_location" VALUES(73104,NULL,'Colville, WA',30022,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73105,NULL,'Colville, WA 99114',30022,222,NULL,56,42790,0);
INSERT INTO "django_geo_db_location" VALUES(73106,NULL,'Coulee City, WA',30023,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73107,NULL,'Coulee City, WA 99115',30023,222,NULL,56,42791,0);
INSERT INTO "django_geo_db_location" VALUES(73108,NULL,'Coulee Dam, WA',30024,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73109,NULL,'Coulee Dam, WA 99116',30024,222,NULL,56,42792,0);
INSERT INTO "django_geo_db_location" VALUES(73110,NULL,'Creston, WA',30025,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73111,NULL,'Creston, WA 99117',30025,222,NULL,56,42793,0);
INSERT INTO "django_geo_db_location" VALUES(73112,NULL,'Curlew, WA',30026,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73113,NULL,'Curlew, WA 99118',30026,222,NULL,56,42794,0);
INSERT INTO "django_geo_db_location" VALUES(73114,NULL,'Cusick, WA',30027,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73115,NULL,'Cusick, WA 99119',30027,222,NULL,56,42795,0);
INSERT INTO "django_geo_db_location" VALUES(73116,NULL,'Danville, WA',30028,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73117,NULL,'Danville, WA 99121',30028,222,NULL,56,42796,0);
INSERT INTO "django_geo_db_location" VALUES(73118,NULL,'Davenport, WA',30029,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73119,NULL,'Davenport, WA 99122',30029,222,NULL,56,42797,0);
INSERT INTO "django_geo_db_location" VALUES(73120,NULL,'Electric City, WA',30030,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73121,NULL,'Electric City, WA 99123',30030,222,NULL,56,42798,0);
INSERT INTO "django_geo_db_location" VALUES(73122,NULL,'Elmer City, WA',30031,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73123,NULL,'Elmer City, WA 99124',30031,222,NULL,56,42799,0);
INSERT INTO "django_geo_db_location" VALUES(73124,NULL,'Endicott, WA',30032,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73125,NULL,'Endicott, WA 99125',30032,222,NULL,56,42800,0);
INSERT INTO "django_geo_db_location" VALUES(73126,NULL,'Evans, WA',30033,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73127,NULL,'Evans, WA 99126',30033,222,NULL,56,42801,0);
INSERT INTO "django_geo_db_location" VALUES(73128,NULL,'Saint John, WA',30034,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73129,NULL,'Saint John, WA 99127',30034,222,NULL,56,42802,0);
INSERT INTO "django_geo_db_location" VALUES(73130,NULL,'Farmington, ID',30035,222,NULL,16,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73131,NULL,'Farmington, ID 99128',30035,222,NULL,16,42803,0);
INSERT INTO "django_geo_db_location" VALUES(73132,NULL,'Fruitland, WA',30036,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73133,NULL,'Fruitland, WA 99129',30036,222,NULL,56,42804,0);
INSERT INTO "django_geo_db_location" VALUES(73134,NULL,'Garfield, WA',30037,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73135,NULL,'Garfield, WA 99130',30037,222,NULL,56,42805,0);
INSERT INTO "django_geo_db_location" VALUES(73136,NULL,'Gifford, WA',30038,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73137,NULL,'Gifford, WA 99131',30038,222,NULL,56,42806,0);
INSERT INTO "django_geo_db_location" VALUES(73138,NULL,'Grand Coulee, WA',30039,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73139,NULL,'Grand Coulee, WA 99133',30039,222,NULL,56,42807,0);
INSERT INTO "django_geo_db_location" VALUES(73140,NULL,'Harrington, WA',30040,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73141,NULL,'Harrington, WA 99134',30040,222,NULL,56,42808,0);
INSERT INTO "django_geo_db_location" VALUES(73142,NULL,'Hartline, WA',30041,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73143,NULL,'Hartline, WA 99135',30041,222,NULL,56,42809,0);
INSERT INTO "django_geo_db_location" VALUES(73144,NULL,'Hay, WA',30042,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73145,NULL,'Hay, WA 99136',30042,222,NULL,56,42810,0);
INSERT INTO "django_geo_db_location" VALUES(73146,NULL,'Hunters, WA',30043,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73147,NULL,'Hunters, WA 99137',30043,222,NULL,56,42811,0);
INSERT INTO "django_geo_db_location" VALUES(73148,NULL,'Inchelium, WA',30044,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73149,NULL,'Inchelium, WA 99138',30044,222,NULL,56,42812,0);
INSERT INTO "django_geo_db_location" VALUES(73150,NULL,'Ione, WA',30045,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73151,NULL,'Ione, WA 99139',30045,222,NULL,56,42813,0);
INSERT INTO "django_geo_db_location" VALUES(73152,NULL,'Keller, WA',30046,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73153,NULL,'Keller, WA 99140',30046,222,NULL,56,42814,0);
INSERT INTO "django_geo_db_location" VALUES(73154,NULL,'Kettle Falls, WA',30047,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73155,NULL,'Kettle Falls, WA 99141',30047,222,NULL,56,42815,0);
INSERT INTO "django_geo_db_location" VALUES(73156,NULL,'Lacrosse, WA',30048,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73157,NULL,'Lacrosse, WA 99143',30048,222,NULL,56,42816,0);
INSERT INTO "django_geo_db_location" VALUES(73158,NULL,'Lamona, WA',30049,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73159,NULL,'Lamona, WA 99144',30049,222,NULL,56,42817,0);
INSERT INTO "django_geo_db_location" VALUES(73160,NULL,'Laurier, WA',30050,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73161,NULL,'Laurier, WA 99146',30050,222,NULL,56,42818,0);
INSERT INTO "django_geo_db_location" VALUES(73162,NULL,'Lincoln, WA',30051,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73163,NULL,'Lincoln, WA 99147',30051,222,NULL,56,42819,0);
INSERT INTO "django_geo_db_location" VALUES(73164,NULL,'Loon Lake, WA',30052,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73165,NULL,'Loon Lake, WA 99148',30052,222,NULL,56,42820,0);
INSERT INTO "django_geo_db_location" VALUES(73166,NULL,'Malden, WA',30053,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73167,NULL,'Malden, WA 99149',30053,222,NULL,56,42821,0);
INSERT INTO "django_geo_db_location" VALUES(73168,NULL,'Malo, WA',30054,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73169,NULL,'Malo, WA 99150',30054,222,NULL,56,42822,0);
INSERT INTO "django_geo_db_location" VALUES(73170,NULL,'Marcus, WA',30055,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73171,NULL,'Marcus, WA 99151',30055,222,NULL,56,42823,0);
INSERT INTO "django_geo_db_location" VALUES(73172,NULL,'Metaline, WA',30056,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73173,NULL,'Metaline, WA 99152',30056,222,NULL,56,42824,0);
INSERT INTO "django_geo_db_location" VALUES(73174,NULL,'Metaline Falls, WA',30057,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73175,NULL,'Metaline Falls, WA 99153',30057,222,NULL,56,42825,0);
INSERT INTO "django_geo_db_location" VALUES(73176,NULL,'Mohler, WA',30058,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73177,NULL,'Mohler, WA 99154',30058,222,NULL,56,42826,0);
INSERT INTO "django_geo_db_location" VALUES(73178,NULL,'Nespelem, WA',30059,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73179,NULL,'Nespelem, WA 99155',30059,222,NULL,56,42827,0);
INSERT INTO "django_geo_db_location" VALUES(73180,NULL,'Newport, WA',30060,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73181,NULL,'Newport, WA 99156',30060,222,NULL,56,42828,0);
INSERT INTO "django_geo_db_location" VALUES(73182,NULL,'Northport, WA',30061,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73183,NULL,'Northport, WA 99157',30061,222,NULL,56,42829,0);
INSERT INTO "django_geo_db_location" VALUES(73184,NULL,'Oakesdale, WA',30062,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73185,NULL,'Oakesdale, WA 99158',30062,222,NULL,56,42830,0);
INSERT INTO "django_geo_db_location" VALUES(73186,NULL,'Odessa, WA',30063,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73187,NULL,'Odessa, WA 99159',30063,222,NULL,56,42831,0);
INSERT INTO "django_geo_db_location" VALUES(73188,NULL,'Orient, WA',30064,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73189,NULL,'Orient, WA 99160',30064,222,NULL,56,42832,0);
INSERT INTO "django_geo_db_location" VALUES(73190,NULL,'Palouse, WA',30065,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73191,NULL,'Palouse, WA 99161',30065,222,NULL,56,42833,0);
INSERT INTO "django_geo_db_location" VALUES(73192,NULL,'Pullman, WA',30066,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73193,NULL,'Pullman, WA 99163',30066,222,NULL,56,42834,0);
INSERT INTO "django_geo_db_location" VALUES(73194,NULL,'Pullman, WA 99164',30066,222,NULL,56,42835,0);
INSERT INTO "django_geo_db_location" VALUES(73195,NULL,'Pullman, WA 99165',30066,222,NULL,56,42836,0);
INSERT INTO "django_geo_db_location" VALUES(73196,NULL,'Republic, WA',30067,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73197,NULL,'Republic, WA 99166',30067,222,NULL,56,42837,0);
INSERT INTO "django_geo_db_location" VALUES(73198,NULL,'Rice, WA',30068,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73199,NULL,'Rice, WA 99167',30068,222,NULL,56,42838,0);
INSERT INTO "django_geo_db_location" VALUES(73200,NULL,'Ritzville, WA',30069,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73201,NULL,'Ritzville, WA 99169',30069,222,NULL,56,42839,0);
INSERT INTO "django_geo_db_location" VALUES(73202,NULL,'Rosalia, WA',30070,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73203,NULL,'Rosalia, WA 99170',30070,222,NULL,56,42840,0);
INSERT INTO "django_geo_db_location" VALUES(73204,NULL,'Saint John, WA 99171',30034,222,NULL,56,42841,0);
INSERT INTO "django_geo_db_location" VALUES(73205,NULL,'Springdale, WA',30071,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73206,NULL,'Springdale, WA 99173',30071,222,NULL,56,42842,0);
INSERT INTO "django_geo_db_location" VALUES(73207,NULL,'Steptoe, WA',30072,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73208,NULL,'Steptoe, WA 99174',30072,222,NULL,56,42843,0);
INSERT INTO "django_geo_db_location" VALUES(73209,NULL,'Thornton, WA',30073,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73210,NULL,'Thornton, WA 99176',30073,222,NULL,56,42844,0);
INSERT INTO "django_geo_db_location" VALUES(73211,NULL,'Uniontown, WA',30074,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73212,NULL,'Uniontown, WA 99179',30074,222,NULL,56,42845,0);
INSERT INTO "django_geo_db_location" VALUES(73213,NULL,'Usk, WA',30075,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73214,NULL,'Usk, WA 99180',30075,222,NULL,56,42846,0);
INSERT INTO "django_geo_db_location" VALUES(73215,NULL,'Valley, WA',30076,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73216,NULL,'Valley, WA 99181',30076,222,NULL,56,42847,0);
INSERT INTO "django_geo_db_location" VALUES(73217,NULL,'Wilbur, WA',30077,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73218,NULL,'Wilbur, WA 99185',30077,222,NULL,56,42848,0);
INSERT INTO "django_geo_db_location" VALUES(73219,NULL,'Spokane, WA',30078,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73220,NULL,'Spokane, WA 99201',30078,222,NULL,56,42849,0);
INSERT INTO "django_geo_db_location" VALUES(73221,NULL,'Spokane, WA 99202',30078,222,NULL,56,42850,0);
INSERT INTO "django_geo_db_location" VALUES(73222,NULL,'Spokane, WA 99203',30078,222,NULL,56,42851,0);
INSERT INTO "django_geo_db_location" VALUES(73223,NULL,'Spokane, WA 99204',30078,222,NULL,56,42852,0);
INSERT INTO "django_geo_db_location" VALUES(73224,NULL,'Spokane, WA 99205',30078,222,NULL,56,42853,0);
INSERT INTO "django_geo_db_location" VALUES(73225,NULL,'Spokane, WA 99206',30078,222,NULL,56,42854,0);
INSERT INTO "django_geo_db_location" VALUES(73226,NULL,'Spokane, WA 99207',30078,222,NULL,56,42855,0);
INSERT INTO "django_geo_db_location" VALUES(73227,NULL,'Spokane, WA 99208',30078,222,NULL,56,42856,0);
INSERT INTO "django_geo_db_location" VALUES(73228,NULL,'Spokane, WA 99209',30078,222,NULL,56,42857,0);
INSERT INTO "django_geo_db_location" VALUES(73229,NULL,'Spokane, WA 99210',30078,222,NULL,56,42858,0);
INSERT INTO "django_geo_db_location" VALUES(73230,NULL,'Spokane, WA 99211',30078,222,NULL,56,42859,0);
INSERT INTO "django_geo_db_location" VALUES(73231,NULL,'Spokane, WA 99212',30078,222,NULL,56,42860,0);
INSERT INTO "django_geo_db_location" VALUES(73232,NULL,'Spokane, WA 99213',30078,222,NULL,56,42861,0);
INSERT INTO "django_geo_db_location" VALUES(73233,NULL,'Spokane, WA 99214',30078,222,NULL,56,42862,0);
INSERT INTO "django_geo_db_location" VALUES(73234,NULL,'Spokane, WA 99215',30078,222,NULL,56,42863,0);
INSERT INTO "django_geo_db_location" VALUES(73235,NULL,'Spokane, WA 99216',30078,222,NULL,56,42864,0);
INSERT INTO "django_geo_db_location" VALUES(73236,NULL,'Spokane, WA 99217',30078,222,NULL,56,42865,0);
INSERT INTO "django_geo_db_location" VALUES(73237,NULL,'Spokane, WA 99218',30078,222,NULL,56,42866,0);
INSERT INTO "django_geo_db_location" VALUES(73238,NULL,'Spokane, WA 99219',30078,222,NULL,56,42867,0);
INSERT INTO "django_geo_db_location" VALUES(73239,NULL,'Spokane, WA 99220',30078,222,NULL,56,42868,0);
INSERT INTO "django_geo_db_location" VALUES(73240,NULL,'Spokane, WA 99223',30078,222,NULL,56,42869,0);
INSERT INTO "django_geo_db_location" VALUES(73241,NULL,'Spokane, WA 99224',30078,222,NULL,56,42870,0);
INSERT INTO "django_geo_db_location" VALUES(73242,NULL,'Spokane, WA 99228',30078,222,NULL,56,42871,0);
INSERT INTO "django_geo_db_location" VALUES(73243,NULL,'Spokane, WA 99251',30078,222,NULL,56,42872,0);
INSERT INTO "django_geo_db_location" VALUES(73244,NULL,'Spokane, WA 99252',30078,222,NULL,56,42873,0);
INSERT INTO "django_geo_db_location" VALUES(73245,NULL,'Spokane, WA 99256',30078,222,NULL,56,42874,0);
INSERT INTO "django_geo_db_location" VALUES(73246,NULL,'Spokane, WA 99258',30078,222,NULL,56,42875,0);
INSERT INTO "django_geo_db_location" VALUES(73247,NULL,'Spokane, WA 99260',30078,222,NULL,56,42876,0);
INSERT INTO "django_geo_db_location" VALUES(73248,NULL,'Spokane, WA 99299',30078,222,NULL,56,42877,0);
INSERT INTO "django_geo_db_location" VALUES(73249,NULL,'Pasco, WA',30079,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73250,NULL,'Pasco, WA 99301',30079,222,NULL,56,42878,0);
INSERT INTO "django_geo_db_location" VALUES(73251,NULL,'Pasco, WA 99302',30079,222,NULL,56,42879,0);
INSERT INTO "django_geo_db_location" VALUES(73252,NULL,'Mattawa, WA',30080,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73253,NULL,'Mattawa, WA 99309',30080,222,NULL,56,42880,0);
INSERT INTO "django_geo_db_location" VALUES(73254,NULL,'Desert Aire, WA',30081,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73255,NULL,'Desert Aire, WA 99319',30081,222,NULL,56,42881,0);
INSERT INTO "django_geo_db_location" VALUES(73256,NULL,'Benton City, WA',30082,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73257,NULL,'Benton City, WA 99320',30082,222,NULL,56,42882,0);
INSERT INTO "django_geo_db_location" VALUES(73258,NULL,'Beverly, WA',30083,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73259,NULL,'Beverly, WA 99321',30083,222,NULL,56,42883,0);
INSERT INTO "django_geo_db_location" VALUES(73260,NULL,'Bickleton, WA',30084,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73261,NULL,'Bickleton, WA 99322',30084,222,NULL,56,42884,0);
INSERT INTO "django_geo_db_location" VALUES(73262,NULL,'Burbank, WA',30085,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73263,NULL,'Burbank, WA 99323',30085,222,NULL,56,42885,0);
INSERT INTO "django_geo_db_location" VALUES(73264,NULL,'College Place, WA',30086,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73265,NULL,'College Place, WA 99324',30086,222,NULL,56,42886,0);
INSERT INTO "django_geo_db_location" VALUES(73266,NULL,'Connell, WA',30087,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73267,NULL,'Connell, WA 99326',30087,222,NULL,56,42887,0);
INSERT INTO "django_geo_db_location" VALUES(73268,NULL,'Cunningham, WA',30088,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73269,NULL,'Cunningham, WA 99327',30088,222,NULL,56,42888,0);
INSERT INTO "django_geo_db_location" VALUES(73270,NULL,'Dayton, WA',30089,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73271,NULL,'Dayton, WA 99328',30089,222,NULL,56,42889,0);
INSERT INTO "django_geo_db_location" VALUES(73272,NULL,'Dixie, WA',30090,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73273,NULL,'Dixie, WA 99329',30090,222,NULL,56,42890,0);
INSERT INTO "django_geo_db_location" VALUES(73274,NULL,'Eltopia, WA',30091,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73275,NULL,'Eltopia, WA 99330',30091,222,NULL,56,42891,0);
INSERT INTO "django_geo_db_location" VALUES(73276,NULL,'Hatton, WA',30092,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73277,NULL,'Hatton, WA 99332',30092,222,NULL,56,42892,0);
INSERT INTO "django_geo_db_location" VALUES(73278,NULL,'Hooper, WA',30093,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73279,NULL,'Hooper, WA 99333',30093,222,NULL,56,42893,0);
INSERT INTO "django_geo_db_location" VALUES(73280,NULL,'Kahlotus, WA',30094,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73281,NULL,'Kahlotus, WA 99335',30094,222,NULL,56,42894,0);
INSERT INTO "django_geo_db_location" VALUES(73282,NULL,'Kennewick, WA',30095,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73283,NULL,'Kennewick, WA 99336',30095,222,NULL,56,42895,0);
INSERT INTO "django_geo_db_location" VALUES(73284,NULL,'Kennewick, WA 99337',30095,222,NULL,56,42896,0);
INSERT INTO "django_geo_db_location" VALUES(73285,NULL,'Kennewick, WA 99338',30095,222,NULL,56,42897,0);
INSERT INTO "django_geo_db_location" VALUES(73286,NULL,'Lind, WA',30096,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73287,NULL,'Lind, WA 99341',30096,222,NULL,56,42898,0);
INSERT INTO "django_geo_db_location" VALUES(73288,NULL,'Mesa, WA',30097,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73289,NULL,'Mesa, WA 99343',30097,222,NULL,56,42899,0);
INSERT INTO "django_geo_db_location" VALUES(73290,NULL,'Othello, WA',30098,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73291,NULL,'Othello, WA 99344',30098,222,NULL,56,42900,0);
INSERT INTO "django_geo_db_location" VALUES(73292,NULL,'Paterson, WA',30099,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73293,NULL,'Paterson, WA 99345',30099,222,NULL,56,42901,0);
INSERT INTO "django_geo_db_location" VALUES(73294,NULL,'Plymouth, WA',30100,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73295,NULL,'Plymouth, WA 99346',30100,222,NULL,56,42902,0);
INSERT INTO "django_geo_db_location" VALUES(73296,NULL,'Pomeroy, WA',30101,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73297,NULL,'Pomeroy, WA 99347',30101,222,NULL,56,42903,0);
INSERT INTO "django_geo_db_location" VALUES(73298,NULL,'Prescott, WA',30102,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73299,NULL,'Prescott, WA 99348',30102,222,NULL,56,42904,0);
INSERT INTO "django_geo_db_location" VALUES(73300,NULL,'Mattawa, WA 99349',30080,222,NULL,56,42905,0);
INSERT INTO "django_geo_db_location" VALUES(73301,NULL,'Prosser, WA',30103,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73302,NULL,'Prosser, WA 99350',30103,222,NULL,56,42906,0);
INSERT INTO "django_geo_db_location" VALUES(73303,NULL,'Richland, WA',30104,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73304,NULL,'Richland, WA 99352',30104,222,NULL,56,42907,0);
INSERT INTO "django_geo_db_location" VALUES(73305,NULL,'West Richland, WA',30105,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73306,NULL,'West Richland, WA 99353',30105,222,NULL,56,42908,0);
INSERT INTO "django_geo_db_location" VALUES(73307,NULL,'Roosevelt, WA',30106,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73308,NULL,'Roosevelt, WA 99356',30106,222,NULL,56,42909,0);
INSERT INTO "django_geo_db_location" VALUES(73309,NULL,'Royal City, WA',30107,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73310,NULL,'Royal City, WA 99357',30107,222,NULL,56,42910,0);
INSERT INTO "django_geo_db_location" VALUES(73311,NULL,'Starbuck, WA',30108,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73312,NULL,'Starbuck, WA 99359',30108,222,NULL,56,42911,0);
INSERT INTO "django_geo_db_location" VALUES(73313,NULL,'Touchet, WA',30109,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73314,NULL,'Touchet, WA 99360',30109,222,NULL,56,42912,0);
INSERT INTO "django_geo_db_location" VALUES(73315,NULL,'Waitsburg, WA',30110,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73316,NULL,'Waitsburg, WA 99361',30110,222,NULL,56,42913,0);
INSERT INTO "django_geo_db_location" VALUES(73317,NULL,'Walla Walla, OR',30111,222,NULL,37,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73318,NULL,'Walla Walla, OR 99362',30111,222,NULL,37,42914,0);
INSERT INTO "django_geo_db_location" VALUES(73319,NULL,'Wallula, WA',30112,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73320,NULL,'Wallula, WA 99363',30112,222,NULL,56,42915,0);
INSERT INTO "django_geo_db_location" VALUES(73321,NULL,'Washtucna, WA',30113,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73322,NULL,'Washtucna, WA 99371',30113,222,NULL,56,42916,0);
INSERT INTO "django_geo_db_location" VALUES(73323,NULL,'Anatone, WA',30114,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73324,NULL,'Anatone, WA 99401',30114,222,NULL,56,42917,0);
INSERT INTO "django_geo_db_location" VALUES(73325,NULL,'Asotin, WA',30115,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73326,NULL,'Asotin, WA 99402',30115,222,NULL,56,42918,0);
INSERT INTO "django_geo_db_location" VALUES(73327,NULL,'Clarkston, WA',30116,222,NULL,56,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73328,NULL,'Clarkston, WA 99403',30116,222,NULL,56,42919,0);
INSERT INTO "django_geo_db_location" VALUES(73329,NULL,'Anchorage, AK',30117,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73330,NULL,'Anchorage, AK 99501',30117,222,NULL,2,42920,0);
INSERT INTO "django_geo_db_location" VALUES(73331,NULL,'Anchorage, AK 99502',30117,222,NULL,2,42921,0);
INSERT INTO "django_geo_db_location" VALUES(73332,NULL,'Anchorage, AK 99503',30117,222,NULL,2,42922,0);
INSERT INTO "django_geo_db_location" VALUES(73333,NULL,'Anchorage, AK 99504',30117,222,NULL,2,42923,0);
INSERT INTO "django_geo_db_location" VALUES(73334,NULL,'Fort Richardson, AK',30118,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73335,NULL,'Fort Richardson, AK 99505',30118,222,NULL,2,42924,0);
INSERT INTO "django_geo_db_location" VALUES(73336,NULL,'Elmendorf AFB, AK',30119,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73337,NULL,'Elmendorf AFB, AK 99506',30119,222,NULL,2,42925,0);
INSERT INTO "django_geo_db_location" VALUES(73338,NULL,'Anchorage, AK 99507',30117,222,NULL,2,42926,0);
INSERT INTO "django_geo_db_location" VALUES(73339,NULL,'Anchorage, AK 99508',30117,222,NULL,2,42927,0);
INSERT INTO "django_geo_db_location" VALUES(73340,NULL,'Anchorage, AK 99509',30117,222,NULL,2,42928,0);
INSERT INTO "django_geo_db_location" VALUES(73341,NULL,'Anchorage, AK 99510',30117,222,NULL,2,42929,0);
INSERT INTO "django_geo_db_location" VALUES(73342,NULL,'Anchorage, AK 99511',30117,222,NULL,2,42930,0);
INSERT INTO "django_geo_db_location" VALUES(73343,NULL,'Anchorage, AK 99512',30117,222,NULL,2,42931,0);
INSERT INTO "django_geo_db_location" VALUES(73344,NULL,'Anchorage, AK 99513',30117,222,NULL,2,42932,0);
INSERT INTO "django_geo_db_location" VALUES(73345,NULL,'Anchorage, AK 99514',30117,222,NULL,2,42933,0);
INSERT INTO "django_geo_db_location" VALUES(73346,NULL,'Anchorage, AK 99515',30117,222,NULL,2,42934,0);
INSERT INTO "django_geo_db_location" VALUES(73347,NULL,'Anchorage, AK 99516',30117,222,NULL,2,42935,0);
INSERT INTO "django_geo_db_location" VALUES(73348,NULL,'Anchorage, AK 99517',30117,222,NULL,2,42936,0);
INSERT INTO "django_geo_db_location" VALUES(73349,NULL,'Anchorage, AK 99518',30117,222,NULL,2,42937,0);
INSERT INTO "django_geo_db_location" VALUES(73350,NULL,'Anchorage, AK 99519',30117,222,NULL,2,42938,0);
INSERT INTO "django_geo_db_location" VALUES(73351,NULL,'Anchorage, AK 99520',30117,222,NULL,2,42939,0);
INSERT INTO "django_geo_db_location" VALUES(73352,NULL,'Anchorage, AK 99521',30117,222,NULL,2,42940,0);
INSERT INTO "django_geo_db_location" VALUES(73353,NULL,'Anchorage, AK 99522',30117,222,NULL,2,42941,0);
INSERT INTO "django_geo_db_location" VALUES(73354,NULL,'Anchorage, AK 99523',30117,222,NULL,2,42942,0);
INSERT INTO "django_geo_db_location" VALUES(73355,NULL,'Anchorage, AK 99524',30117,222,NULL,2,42943,0);
INSERT INTO "django_geo_db_location" VALUES(73356,NULL,'Kennewick, WA 99536',30095,222,NULL,56,42944,0);
INSERT INTO "django_geo_db_location" VALUES(73357,NULL,'Indian, AK',30120,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73358,NULL,'Indian, AK 99540',30120,222,NULL,2,42945,0);
INSERT INTO "django_geo_db_location" VALUES(73359,NULL,'Adak, AK',30121,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73360,NULL,'Adak, AK 99546',30121,222,NULL,2,42946,0);
INSERT INTO "django_geo_db_location" VALUES(73361,NULL,'Atka, AK',30122,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73362,NULL,'Atka, AK 99547',30122,222,NULL,2,42947,0);
INSERT INTO "django_geo_db_location" VALUES(73363,NULL,'Chignik Lake, AK',30123,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73364,NULL,'Chignik Lake, AK 99548',30123,222,NULL,2,42948,0);
INSERT INTO "django_geo_db_location" VALUES(73365,NULL,'Port Heiden, AK',30124,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73366,NULL,'Port Heiden, AK 99549',30124,222,NULL,2,42949,0);
INSERT INTO "django_geo_db_location" VALUES(73367,NULL,'Port Lions, AK',30125,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73368,NULL,'Port Lions, AK 99550',30125,222,NULL,2,42950,0);
INSERT INTO "django_geo_db_location" VALUES(73369,NULL,'Akiachak, AK',30126,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73370,NULL,'Akiachak, AK 99551',30126,222,NULL,2,42951,0);
INSERT INTO "django_geo_db_location" VALUES(73371,NULL,'Akiak, AK',30127,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73372,NULL,'Akiak, AK 99552',30127,222,NULL,2,42952,0);
INSERT INTO "django_geo_db_location" VALUES(73373,NULL,'Akutan, AK',30128,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73374,NULL,'Akutan, AK 99553',30128,222,NULL,2,42953,0);
INSERT INTO "django_geo_db_location" VALUES(73375,NULL,'Alakanuk, AK',30129,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73376,NULL,'Alakanuk, AK 99554',30129,222,NULL,2,42954,0);
INSERT INTO "django_geo_db_location" VALUES(73377,NULL,'Aleknagik, AK',30130,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73378,NULL,'Aleknagik, AK 99555',30130,222,NULL,2,42955,0);
INSERT INTO "django_geo_db_location" VALUES(73379,NULL,'Anchor Point, AK',30131,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73380,NULL,'Anchor Point, AK 99556',30131,222,NULL,2,42956,0);
INSERT INTO "django_geo_db_location" VALUES(73381,NULL,'Aniak, AK',30132,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73382,NULL,'Aniak, AK 99557',30132,222,NULL,2,42957,0);
INSERT INTO "django_geo_db_location" VALUES(73383,NULL,'Anvik, AK',30133,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73384,NULL,'Anvik, AK 99558',30133,222,NULL,2,42958,0);
INSERT INTO "django_geo_db_location" VALUES(73385,NULL,'Bethel, AK',30134,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73386,NULL,'Bethel, AK 99559',30134,222,NULL,2,42959,0);
INSERT INTO "django_geo_db_location" VALUES(73387,NULL,'Chefornak, AK',30135,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73388,NULL,'Chefornak, AK 99561',30135,222,NULL,2,42960,0);
INSERT INTO "django_geo_db_location" VALUES(73389,NULL,'Chevak, AK',30136,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73390,NULL,'Chevak, AK 99563',30136,222,NULL,2,42961,0);
INSERT INTO "django_geo_db_location" VALUES(73391,NULL,'Chignik, AK',30137,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73392,NULL,'Chignik, AK 99564',30137,222,NULL,2,42962,0);
INSERT INTO "django_geo_db_location" VALUES(73393,NULL,'Chignik Lagoon, AK',30138,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73394,NULL,'Chignik Lagoon, AK 99565',30138,222,NULL,2,42963,0);
INSERT INTO "django_geo_db_location" VALUES(73395,NULL,'Chitina, AK',30139,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73396,NULL,'Chitina, AK 99566',30139,222,NULL,2,42964,0);
INSERT INTO "django_geo_db_location" VALUES(73397,NULL,'Chugiak, AK',30140,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73398,NULL,'Chugiak, AK 99567',30140,222,NULL,2,42965,0);
INSERT INTO "django_geo_db_location" VALUES(73399,NULL,'Clam Gulch, AK',30141,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73400,NULL,'Clam Gulch, AK 99568',30141,222,NULL,2,42966,0);
INSERT INTO "django_geo_db_location" VALUES(73401,NULL,'Clarks Point, AK',30142,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73402,NULL,'Clarks Point, AK 99569',30142,222,NULL,2,42967,0);
INSERT INTO "django_geo_db_location" VALUES(73403,NULL,'Cold Bay, AK',30143,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73404,NULL,'Cold Bay, AK 99571',30143,222,NULL,2,42968,0);
INSERT INTO "django_geo_db_location" VALUES(73405,NULL,'Cooper Landing, AK',30144,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73406,NULL,'Cooper Landing, AK 99572',30144,222,NULL,2,42969,0);
INSERT INTO "django_geo_db_location" VALUES(73407,NULL,'Copper Center, AK',30145,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73408,NULL,'Copper Center, AK 99573',30145,222,NULL,2,42970,0);
INSERT INTO "django_geo_db_location" VALUES(73409,NULL,'Cordova, AK',30146,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73410,NULL,'Cordova, AK 99574',30146,222,NULL,2,42971,0);
INSERT INTO "django_geo_db_location" VALUES(73411,NULL,'Crooked Creek, AK',30147,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73412,NULL,'Crooked Creek, AK 99575',30147,222,NULL,2,42972,0);
INSERT INTO "django_geo_db_location" VALUES(73413,NULL,'Dillingham, AK',30148,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73414,NULL,'Dillingham, AK 99576',30148,222,NULL,2,42973,0);
INSERT INTO "django_geo_db_location" VALUES(73415,NULL,'Eagle River, AK',30149,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73416,NULL,'Eagle River, AK 99577',30149,222,NULL,2,42974,0);
INSERT INTO "django_geo_db_location" VALUES(73417,NULL,'Eek, AK',30150,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73418,NULL,'Eek, AK 99578',30150,222,NULL,2,42975,0);
INSERT INTO "django_geo_db_location" VALUES(73419,NULL,'Egegik, AK',30151,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73420,NULL,'Egegik, AK 99579',30151,222,NULL,2,42976,0);
INSERT INTO "django_geo_db_location" VALUES(73421,NULL,'Ekwok, AK',30152,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73422,NULL,'Ekwok, AK 99580',30152,222,NULL,2,42977,0);
INSERT INTO "django_geo_db_location" VALUES(73423,NULL,'Emmonak, AK',30153,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73424,NULL,'Emmonak, AK 99581',30153,222,NULL,2,42978,0);
INSERT INTO "django_geo_db_location" VALUES(73425,NULL,'False Pass, AK',30154,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73426,NULL,'False Pass, AK 99583',30154,222,NULL,2,42979,0);
INSERT INTO "django_geo_db_location" VALUES(73427,NULL,'Flat, AK',30155,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73428,NULL,'Flat, AK 99584',30155,222,NULL,2,42980,0);
INSERT INTO "django_geo_db_location" VALUES(73429,NULL,'Marshall, AK',30156,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73430,NULL,'Marshall, AK 99585',30156,222,NULL,2,42981,0);
INSERT INTO "django_geo_db_location" VALUES(73431,NULL,'Gakona, AK',30157,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73432,NULL,'Gakona, AK 99586',30157,222,NULL,2,42982,0);
INSERT INTO "django_geo_db_location" VALUES(73433,NULL,'Girdwood, AK',30158,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73434,NULL,'Girdwood, AK 99587',30158,222,NULL,2,42983,0);
INSERT INTO "django_geo_db_location" VALUES(73435,NULL,'Glennallen, AK',30159,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73436,NULL,'Glennallen, AK 99588',30159,222,NULL,2,42984,0);
INSERT INTO "django_geo_db_location" VALUES(73437,NULL,'Goodnews Bay, AK',30160,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73438,NULL,'Goodnews Bay, AK 99589',30160,222,NULL,2,42985,0);
INSERT INTO "django_geo_db_location" VALUES(73439,NULL,'Grayling, AK',30161,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73440,NULL,'Grayling, AK 99590',30161,222,NULL,2,42986,0);
INSERT INTO "django_geo_db_location" VALUES(73441,NULL,'Saint George Island, AK',30162,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73442,NULL,'Saint George Island, AK 99591',30162,222,NULL,2,42987,0);
INSERT INTO "django_geo_db_location" VALUES(73443,NULL,'Anchorage, AK 99599',30117,222,NULL,2,42988,0);
INSERT INTO "django_geo_db_location" VALUES(73444,NULL,'Holy Cross, AK',30163,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73445,NULL,'Holy Cross, AK 99602',30163,222,NULL,2,42989,0);
INSERT INTO "django_geo_db_location" VALUES(73446,NULL,'Homer, AK',30164,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73447,NULL,'Homer, AK 99603',30164,222,NULL,2,42990,0);
INSERT INTO "django_geo_db_location" VALUES(73448,NULL,'Hooper Bay, AK',30165,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73449,NULL,'Hooper Bay, AK 99604',30165,222,NULL,2,42991,0);
INSERT INTO "django_geo_db_location" VALUES(73450,NULL,'Hope, AK',30166,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73451,NULL,'Hope, AK 99605',30166,222,NULL,2,42992,0);
INSERT INTO "django_geo_db_location" VALUES(73452,NULL,'Iliamna, AK',30167,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73453,NULL,'Iliamna, AK 99606',30167,222,NULL,2,42993,0);
INSERT INTO "django_geo_db_location" VALUES(73454,NULL,'Kalskag, AK',30168,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73455,NULL,'Kalskag, AK 99607',30168,222,NULL,2,42994,0);
INSERT INTO "django_geo_db_location" VALUES(73456,NULL,'Karluk, AK',30169,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73457,NULL,'Karluk, AK 99608',30169,222,NULL,2,42995,0);
INSERT INTO "django_geo_db_location" VALUES(73458,NULL,'Kasigluk, AK',30170,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73459,NULL,'Kasigluk, AK 99609',30170,222,NULL,2,42996,0);
INSERT INTO "django_geo_db_location" VALUES(73460,NULL,'Kasilof, AK',30171,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73461,NULL,'Kasilof, AK 99610',30171,222,NULL,2,42997,0);
INSERT INTO "django_geo_db_location" VALUES(73462,NULL,'Kenai, AK',30172,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73463,NULL,'Kenai, AK 99611',30172,222,NULL,2,42998,0);
INSERT INTO "django_geo_db_location" VALUES(73464,NULL,'King Cove, AK',30173,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73465,NULL,'King Cove, AK 99612',30173,222,NULL,2,42999,0);
INSERT INTO "django_geo_db_location" VALUES(73466,NULL,'King Salmon, AK',30174,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73467,NULL,'King Salmon, AK 99613',30174,222,NULL,2,43000,0);
INSERT INTO "django_geo_db_location" VALUES(73468,NULL,'Kipnuk, AK',30175,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73469,NULL,'Kipnuk, AK 99614',30175,222,NULL,2,43001,0);
INSERT INTO "django_geo_db_location" VALUES(73470,NULL,'Kodiak, AK',30176,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73471,NULL,'Kodiak, AK 99615',30176,222,NULL,2,43002,0);
INSERT INTO "django_geo_db_location" VALUES(73472,NULL,'Kodiak, AK 99619',30176,222,NULL,2,43003,0);
INSERT INTO "django_geo_db_location" VALUES(73473,NULL,'Kotlik, AK',30177,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73474,NULL,'Kotlik, AK 99620',30177,222,NULL,2,43004,0);
INSERT INTO "django_geo_db_location" VALUES(73475,NULL,'Kwethluk, AK',30178,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73476,NULL,'Kwethluk, AK 99621',30178,222,NULL,2,43005,0);
INSERT INTO "django_geo_db_location" VALUES(73477,NULL,'Kwigillingok, AK',30179,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73478,NULL,'Kwigillingok, AK 99622',30179,222,NULL,2,43006,0);
INSERT INTO "django_geo_db_location" VALUES(73479,NULL,'Larsen Bay, AK',30180,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73480,NULL,'Larsen Bay, AK 99624',30180,222,NULL,2,43007,0);
INSERT INTO "django_geo_db_location" VALUES(73481,NULL,'Levelock, AK',30181,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73482,NULL,'Levelock, AK 99625',30181,222,NULL,2,43008,0);
INSERT INTO "django_geo_db_location" VALUES(73483,NULL,'Lower Kalskag, AK',30182,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73484,NULL,'Lower Kalskag, AK 99626',30182,222,NULL,2,43009,0);
INSERT INTO "django_geo_db_location" VALUES(73485,NULL,'McGrath, AK',30183,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73486,NULL,'McGrath, AK 99627',30183,222,NULL,2,43010,0);
INSERT INTO "django_geo_db_location" VALUES(73487,NULL,'Manokotak, AK',30184,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73488,NULL,'Manokotak, AK 99628',30184,222,NULL,2,43011,0);
INSERT INTO "django_geo_db_location" VALUES(73489,NULL,'Mekoryuk, AK',30185,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73490,NULL,'Mekoryuk, AK 99630',30185,222,NULL,2,43012,0);
INSERT INTO "django_geo_db_location" VALUES(73491,NULL,'Moose Pass, AK',30186,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73492,NULL,'Moose Pass, AK 99631',30186,222,NULL,2,43013,0);
INSERT INTO "django_geo_db_location" VALUES(73493,NULL,'Mountain Village, AK',30187,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73494,NULL,'Mountain Village, AK 99632',30187,222,NULL,2,43014,0);
INSERT INTO "django_geo_db_location" VALUES(73495,NULL,'Naknek, AK',30188,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73496,NULL,'Naknek, AK 99633',30188,222,NULL,2,43015,0);
INSERT INTO "django_geo_db_location" VALUES(73497,NULL,'Napakiak, AK',30189,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73498,NULL,'Napakiak, AK 99634',30189,222,NULL,2,43016,0);
INSERT INTO "django_geo_db_location" VALUES(73499,NULL,'Nikiski, AK',30190,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73500,NULL,'Nikiski, AK 99635',30190,222,NULL,2,43017,0);
INSERT INTO "django_geo_db_location" VALUES(73501,NULL,'New Stuyahok, AK',30191,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73502,NULL,'New Stuyahok, AK 99636',30191,222,NULL,2,43018,0);
INSERT INTO "django_geo_db_location" VALUES(73503,NULL,'Toksook Bay, AK',30192,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73504,NULL,'Toksook Bay, AK 99637',30192,222,NULL,2,43019,0);
INSERT INTO "django_geo_db_location" VALUES(73505,NULL,'Nikolski, AK',30193,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73506,NULL,'Nikolski, AK 99638',30193,222,NULL,2,43020,0);
INSERT INTO "django_geo_db_location" VALUES(73507,NULL,'Ninilchik, AK',30194,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73508,NULL,'Ninilchik, AK 99639',30194,222,NULL,2,43021,0);
INSERT INTO "django_geo_db_location" VALUES(73509,NULL,'Nondalton, AK',30195,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73510,NULL,'Nondalton, AK 99640',30195,222,NULL,2,43022,0);
INSERT INTO "django_geo_db_location" VALUES(73511,NULL,'Nunapitchuk, AK',30196,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73512,NULL,'Nunapitchuk, AK 99641',30196,222,NULL,2,43023,0);
INSERT INTO "django_geo_db_location" VALUES(73513,NULL,'Old Harbor, AK',30197,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73514,NULL,'Old Harbor, AK 99643',30197,222,NULL,2,43024,0);
INSERT INTO "django_geo_db_location" VALUES(73515,NULL,'Ouzinkie, AK',30198,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73516,NULL,'Ouzinkie, AK 99644',30198,222,NULL,2,43025,0);
INSERT INTO "django_geo_db_location" VALUES(73517,NULL,'Palmer, AK',30199,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73518,NULL,'Palmer, AK 99645',30199,222,NULL,2,43026,0);
INSERT INTO "django_geo_db_location" VALUES(73519,NULL,'Palmer, AK 99646',30199,222,NULL,2,43027,0);
INSERT INTO "django_geo_db_location" VALUES(73520,NULL,'Pedro Bay, AK',30200,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73521,NULL,'Pedro Bay, AK 99647',30200,222,NULL,2,43028,0);
INSERT INTO "django_geo_db_location" VALUES(73522,NULL,'Perryville, AK',30201,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73523,NULL,'Perryville, AK 99648',30201,222,NULL,2,43029,0);
INSERT INTO "django_geo_db_location" VALUES(73524,NULL,'Pilot Point, AK',30202,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73525,NULL,'Pilot Point, AK 99649',30202,222,NULL,2,43030,0);
INSERT INTO "django_geo_db_location" VALUES(73526,NULL,'Pilot Station, AK',30203,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73527,NULL,'Pilot Station, AK 99650',30203,222,NULL,2,43031,0);
INSERT INTO "django_geo_db_location" VALUES(73528,NULL,'Platinum, AK',30204,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73529,NULL,'Platinum, AK 99651',30204,222,NULL,2,43032,0);
INSERT INTO "django_geo_db_location" VALUES(73530,NULL,'Big Lake, AK',30205,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73531,NULL,'Big Lake, AK 99652',30205,222,NULL,2,43033,0);
INSERT INTO "django_geo_db_location" VALUES(73532,NULL,'Port Alsworth, AK',30206,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73533,NULL,'Port Alsworth, AK 99653',30206,222,NULL,2,43034,0);
INSERT INTO "django_geo_db_location" VALUES(73534,NULL,'Wasilla, AK',30207,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73535,NULL,'Wasilla, AK 99654',30207,222,NULL,2,43035,0);
INSERT INTO "django_geo_db_location" VALUES(73536,NULL,'Quinhagak, AK',30208,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73537,NULL,'Quinhagak, AK 99655',30208,222,NULL,2,43036,0);
INSERT INTO "django_geo_db_location" VALUES(73538,NULL,'Red Devil, AK',30209,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73539,NULL,'Red Devil, AK 99656',30209,222,NULL,2,43037,0);
INSERT INTO "django_geo_db_location" VALUES(73540,NULL,'Russian Mission, AK',30210,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73541,NULL,'Russian Mission, AK 99657',30210,222,NULL,2,43038,0);
INSERT INTO "django_geo_db_location" VALUES(73542,NULL,'Saint Marys, AK',30211,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73543,NULL,'Saint Marys, AK 99658',30211,222,NULL,2,43039,0);
INSERT INTO "django_geo_db_location" VALUES(73544,NULL,'Saint Michael, AK',30212,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73545,NULL,'Saint Michael, AK 99659',30212,222,NULL,2,43040,0);
INSERT INTO "django_geo_db_location" VALUES(73546,NULL,'Saint Paul Island, AK',30213,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73547,NULL,'Saint Paul Island, AK 99660',30213,222,NULL,2,43041,0);
INSERT INTO "django_geo_db_location" VALUES(73548,NULL,'Sand Point, AK',30214,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73549,NULL,'Sand Point, AK 99661',30214,222,NULL,2,43042,0);
INSERT INTO "django_geo_db_location" VALUES(73550,NULL,'Scammon Bay, AK',30215,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73551,NULL,'Scammon Bay, AK 99662',30215,222,NULL,2,43043,0);
INSERT INTO "django_geo_db_location" VALUES(73552,NULL,'Seldovia, AK',30216,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73553,NULL,'Seldovia, AK 99663',30216,222,NULL,2,43044,0);
INSERT INTO "django_geo_db_location" VALUES(73554,NULL,'Seward, AK',30217,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73555,NULL,'Seward, AK 99664',30217,222,NULL,2,43045,0);
INSERT INTO "django_geo_db_location" VALUES(73556,NULL,'Shageluk, AK',30218,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73557,NULL,'Shageluk, AK 99665',30218,222,NULL,2,43046,0);
INSERT INTO "django_geo_db_location" VALUES(73558,NULL,'Sheldon Point, AK',30219,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73559,NULL,'Sheldon Point, AK 99666',30219,222,NULL,2,43047,0);
INSERT INTO "django_geo_db_location" VALUES(73560,NULL,'Skwentna, AK',30220,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73561,NULL,'Skwentna, AK 99667',30220,222,NULL,2,43048,0);
INSERT INTO "django_geo_db_location" VALUES(73562,NULL,'Sleetmute, AK',30221,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73563,NULL,'Sleetmute, AK 99668',30221,222,NULL,2,43049,0);
INSERT INTO "django_geo_db_location" VALUES(73564,NULL,'Soldotna, AK',30222,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73565,NULL,'Soldotna, AK 99669',30222,222,NULL,2,43050,0);
INSERT INTO "django_geo_db_location" VALUES(73566,NULL,'South Naknek, AK',30223,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73567,NULL,'South Naknek, AK 99670',30223,222,NULL,2,43051,0);
INSERT INTO "django_geo_db_location" VALUES(73568,NULL,'Stebbins, AK',30224,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73569,NULL,'Stebbins, AK 99671',30224,222,NULL,2,43052,0);
INSERT INTO "django_geo_db_location" VALUES(73570,NULL,'Sterling, AK',30225,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73571,NULL,'Sterling, AK 99672',30225,222,NULL,2,43053,0);
INSERT INTO "django_geo_db_location" VALUES(73572,NULL,'Sutton, AK',30226,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73573,NULL,'Sutton, AK 99674',30226,222,NULL,2,43054,0);
INSERT INTO "django_geo_db_location" VALUES(73574,NULL,'Takotna, AK',30227,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73575,NULL,'Takotna, AK 99675',30227,222,NULL,2,43055,0);
INSERT INTO "django_geo_db_location" VALUES(73576,NULL,'Talkeetna, AK',30228,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73577,NULL,'Talkeetna, AK 99676',30228,222,NULL,2,43056,0);
INSERT INTO "django_geo_db_location" VALUES(73578,NULL,'Tatitlek, AK',30229,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73579,NULL,'Tatitlek, AK 99677',30229,222,NULL,2,43057,0);
INSERT INTO "django_geo_db_location" VALUES(73580,NULL,'Togiak, AK',30230,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73581,NULL,'Togiak, AK 99678',30230,222,NULL,2,43058,0);
INSERT INTO "django_geo_db_location" VALUES(73582,NULL,'Tuluksak, AK',30231,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73583,NULL,'Tuluksak, AK 99679',30231,222,NULL,2,43059,0);
INSERT INTO "django_geo_db_location" VALUES(73584,NULL,'Tuntutuliak, AK',30232,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73585,NULL,'Tuntutuliak, AK 99680',30232,222,NULL,2,43060,0);
INSERT INTO "django_geo_db_location" VALUES(73586,NULL,'Tununak, AK',30233,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73587,NULL,'Tununak, AK 99681',30233,222,NULL,2,43061,0);
INSERT INTO "django_geo_db_location" VALUES(73588,NULL,'Tyonek, AK',30234,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73589,NULL,'Tyonek, AK 99682',30234,222,NULL,2,43062,0);
INSERT INTO "django_geo_db_location" VALUES(73590,NULL,'Trapper Creek, AK',30235,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73591,NULL,'Trapper Creek, AK 99683',30235,222,NULL,2,43063,0);
INSERT INTO "django_geo_db_location" VALUES(73592,NULL,'Unalakleet, AK',30236,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73593,NULL,'Unalakleet, AK 99684',30236,222,NULL,2,43064,0);
INSERT INTO "django_geo_db_location" VALUES(73594,NULL,'Unalaska, AK',30237,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73595,NULL,'Unalaska, AK 99685',30237,222,NULL,2,43065,0);
INSERT INTO "django_geo_db_location" VALUES(73596,NULL,'Valdez, AK',30238,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73597,NULL,'Valdez, AK 99686',30238,222,NULL,2,43066,0);
INSERT INTO "django_geo_db_location" VALUES(73598,NULL,'Wasilla, AK 99687',30207,222,NULL,2,43067,0);
INSERT INTO "django_geo_db_location" VALUES(73599,NULL,'Willow, AK',30239,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73600,NULL,'Willow, AK 99688',30239,222,NULL,2,43068,0);
INSERT INTO "django_geo_db_location" VALUES(73601,NULL,'Yakutat, AK',30240,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73602,NULL,'Yakutat, AK 99689',30240,222,NULL,2,43069,0);
INSERT INTO "django_geo_db_location" VALUES(73603,NULL,'Nightmute, AK',30241,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73604,NULL,'Nightmute, AK 99690',30241,222,NULL,2,43070,0);
INSERT INTO "django_geo_db_location" VALUES(73605,NULL,'Nikolai, AK',30242,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73606,NULL,'Nikolai, AK 99691',30242,222,NULL,2,43071,0);
INSERT INTO "django_geo_db_location" VALUES(73607,NULL,'Dutch Harbor, AK',30243,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73608,NULL,'Dutch Harbor, AK 99692',30243,222,NULL,2,43072,0);
INSERT INTO "django_geo_db_location" VALUES(73609,NULL,'Whittier, AK',30244,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73610,NULL,'Whittier, AK 99693',30244,222,NULL,2,43073,0);
INSERT INTO "django_geo_db_location" VALUES(73611,NULL,'Houston, AK',30245,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73612,NULL,'Houston, AK 99694',30245,222,NULL,2,43074,0);
INSERT INTO "django_geo_db_location" VALUES(73613,NULL,'Anchorage, AK 99695',30117,222,NULL,2,43075,0);
INSERT INTO "django_geo_db_location" VALUES(73614,NULL,'Kodiak, AK 99697',30176,222,NULL,2,43076,0);
INSERT INTO "django_geo_db_location" VALUES(73615,NULL,'Funny River, AK',30246,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73616,NULL,'Funny River, AK 99699',30246,222,NULL,2,43077,0);
INSERT INTO "django_geo_db_location" VALUES(73617,NULL,'Fairbanks, AK',30247,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73618,NULL,'Fairbanks, AK 99701',30247,222,NULL,2,43078,0);
INSERT INTO "django_geo_db_location" VALUES(73619,NULL,'Eielson AFB, AK',30248,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73620,NULL,'Eielson AFB, AK 99702',30248,222,NULL,2,43079,0);
INSERT INTO "django_geo_db_location" VALUES(73621,NULL,'Fort Wainwright, AK',30249,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73622,NULL,'Fort Wainwright, AK 99703',30249,222,NULL,2,43080,0);
INSERT INTO "django_geo_db_location" VALUES(73623,NULL,'Clear, AK',30250,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73624,NULL,'Clear, AK 99704',30250,222,NULL,2,43081,0);
INSERT INTO "django_geo_db_location" VALUES(73625,NULL,'North Pole, AK',30251,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73626,NULL,'North Pole, AK 99705',30251,222,NULL,2,43082,0);
INSERT INTO "django_geo_db_location" VALUES(73627,NULL,'Fairbanks, AK 99706',30247,222,NULL,2,43083,0);
INSERT INTO "django_geo_db_location" VALUES(73628,NULL,'Fairbanks, AK 99707',30247,222,NULL,2,43084,0);
INSERT INTO "django_geo_db_location" VALUES(73629,NULL,'Fairbanks, AK 99708',30247,222,NULL,2,43085,0);
INSERT INTO "django_geo_db_location" VALUES(73630,NULL,'Fairbanks, AK 99709',30247,222,NULL,2,43086,0);
INSERT INTO "django_geo_db_location" VALUES(73631,NULL,'Fairbanks, AK 99710',30247,222,NULL,2,43087,0);
INSERT INTO "django_geo_db_location" VALUES(73632,NULL,'Fairbanks, AK 99711',30247,222,NULL,2,43088,0);
INSERT INTO "django_geo_db_location" VALUES(73633,NULL,'Fairbanks, AK 99712',30247,222,NULL,2,43089,0);
INSERT INTO "django_geo_db_location" VALUES(73634,NULL,'Salcha, AK',30252,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73635,NULL,'Salcha, AK 99714',30252,222,NULL,2,43090,0);
INSERT INTO "django_geo_db_location" VALUES(73636,NULL,'Two Rivers, AK',30253,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73637,NULL,'Two Rivers, AK 99716',30253,222,NULL,2,43091,0);
INSERT INTO "django_geo_db_location" VALUES(73638,NULL,'Allakaket, AK',30254,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73639,NULL,'Allakaket, AK 99720',30254,222,NULL,2,43092,0);
INSERT INTO "django_geo_db_location" VALUES(73640,NULL,'Anaktuvuk Pass, AK',30255,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73641,NULL,'Anaktuvuk Pass, AK 99721',30255,222,NULL,2,43093,0);
INSERT INTO "django_geo_db_location" VALUES(73642,NULL,'Arctic Village, AK',30256,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73643,NULL,'Arctic Village, AK 99722',30256,222,NULL,2,43094,0);
INSERT INTO "django_geo_db_location" VALUES(73644,NULL,'Barrow, AK',30257,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73645,NULL,'Barrow, AK 99723',30257,222,NULL,2,43095,0);
INSERT INTO "django_geo_db_location" VALUES(73646,NULL,'Beaver, AK',30258,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73647,NULL,'Beaver, AK 99724',30258,222,NULL,2,43096,0);
INSERT INTO "django_geo_db_location" VALUES(73648,NULL,'Ester, AK',30259,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73649,NULL,'Ester, AK 99725',30259,222,NULL,2,43097,0);
INSERT INTO "django_geo_db_location" VALUES(73650,NULL,'Bettles Field, AK',30260,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73651,NULL,'Bettles Field, AK 99726',30260,222,NULL,2,43098,0);
INSERT INTO "django_geo_db_location" VALUES(73652,NULL,'Buckland, AK',30261,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73653,NULL,'Buckland, AK 99727',30261,222,NULL,2,43099,0);
INSERT INTO "django_geo_db_location" VALUES(73654,NULL,'Cantwell, AK',30262,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73655,NULL,'Cantwell, AK 99729',30262,222,NULL,2,43100,0);
INSERT INTO "django_geo_db_location" VALUES(73656,NULL,'Central, AK',30263,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73657,NULL,'Central, AK 99730',30263,222,NULL,2,43101,0);
INSERT INTO "django_geo_db_location" VALUES(73658,NULL,'Chicken, AK',30264,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73659,NULL,'Chicken, AK 99732',30264,222,NULL,2,43102,0);
INSERT INTO "django_geo_db_location" VALUES(73660,NULL,'Circle, AK',30265,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73661,NULL,'Circle, AK 99733',30265,222,NULL,2,43103,0);
INSERT INTO "django_geo_db_location" VALUES(73662,NULL,'Prudhoe Bay, AK',30266,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73663,NULL,'Prudhoe Bay, AK 99734',30266,222,NULL,2,43104,0);
INSERT INTO "django_geo_db_location" VALUES(73664,NULL,'Deering, AK',30267,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73665,NULL,'Deering, AK 99736',30267,222,NULL,2,43105,0);
INSERT INTO "django_geo_db_location" VALUES(73666,NULL,'Delta Junction, AK',30268,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73667,NULL,'Delta Junction, AK 99737',30268,222,NULL,2,43106,0);
INSERT INTO "django_geo_db_location" VALUES(73668,NULL,'Eagle, AK',30269,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73669,NULL,'Eagle, AK 99738',30269,222,NULL,2,43107,0);
INSERT INTO "django_geo_db_location" VALUES(73670,NULL,'Elim, AK',30270,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73671,NULL,'Elim, AK 99739',30270,222,NULL,2,43108,0);
INSERT INTO "django_geo_db_location" VALUES(73672,NULL,'Fort Yukon, AK',30271,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73673,NULL,'Fort Yukon, AK 99740',30271,222,NULL,2,43109,0);
INSERT INTO "django_geo_db_location" VALUES(73674,NULL,'Galena, AK',30272,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73675,NULL,'Galena, AK 99741',30272,222,NULL,2,43110,0);
INSERT INTO "django_geo_db_location" VALUES(73676,NULL,'Gambell, AK',30273,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73677,NULL,'Gambell, AK 99742',30273,222,NULL,2,43111,0);
INSERT INTO "django_geo_db_location" VALUES(73678,NULL,'Healy, AK',30274,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73679,NULL,'Healy, AK 99743',30274,222,NULL,2,43112,0);
INSERT INTO "django_geo_db_location" VALUES(73680,NULL,'Anderson, AK',30275,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73681,NULL,'Anderson, AK 99744',30275,222,NULL,2,43113,0);
INSERT INTO "django_geo_db_location" VALUES(73682,NULL,'Hughes, AK',30276,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73683,NULL,'Hughes, AK 99745',30276,222,NULL,2,43114,0);
INSERT INTO "django_geo_db_location" VALUES(73684,NULL,'Huslia, AK',30277,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73685,NULL,'Huslia, AK 99746',30277,222,NULL,2,43115,0);
INSERT INTO "django_geo_db_location" VALUES(73686,NULL,'Kaktovik, AK',30278,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73687,NULL,'Kaktovik, AK 99747',30278,222,NULL,2,43116,0);
INSERT INTO "django_geo_db_location" VALUES(73688,NULL,'Kaltag, AK',30279,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73689,NULL,'Kaltag, AK 99748',30279,222,NULL,2,43117,0);
INSERT INTO "django_geo_db_location" VALUES(73690,NULL,'Kiana, AK',30280,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73691,NULL,'Kiana, AK 99749',30280,222,NULL,2,43118,0);
INSERT INTO "django_geo_db_location" VALUES(73692,NULL,'Kivalina, AK',30281,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73693,NULL,'Kivalina, AK 99750',30281,222,NULL,2,43119,0);
INSERT INTO "django_geo_db_location" VALUES(73694,NULL,'Kobuk, AK',30282,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73695,NULL,'Kobuk, AK 99751',30282,222,NULL,2,43120,0);
INSERT INTO "django_geo_db_location" VALUES(73696,NULL,'Kotzebue, AK',30283,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73697,NULL,'Kotzebue, AK 99752',30283,222,NULL,2,43121,0);
INSERT INTO "django_geo_db_location" VALUES(73698,NULL,'Koyuk, AK',30284,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73699,NULL,'Koyuk, AK 99753',30284,222,NULL,2,43122,0);
INSERT INTO "django_geo_db_location" VALUES(73700,NULL,'Koyukuk, AK',30285,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73701,NULL,'Koyukuk, AK 99754',30285,222,NULL,2,43123,0);
INSERT INTO "django_geo_db_location" VALUES(73702,NULL,'Denali National Park, AK',30286,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73703,NULL,'Denali National Park, AK 99755',30286,222,NULL,2,43124,0);
INSERT INTO "django_geo_db_location" VALUES(73704,NULL,'Manley Hot Springs, AK',30287,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73705,NULL,'Manley Hot Springs, AK 99756',30287,222,NULL,2,43125,0);
INSERT INTO "django_geo_db_location" VALUES(73706,NULL,'Lake Minchumina, AK',30288,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73707,NULL,'Lake Minchumina, AK 99757',30288,222,NULL,2,43126,0);
INSERT INTO "django_geo_db_location" VALUES(73708,NULL,'Minto, AK',30289,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73709,NULL,'Minto, AK 99758',30289,222,NULL,2,43127,0);
INSERT INTO "django_geo_db_location" VALUES(73710,NULL,'Point Lay, AK',30290,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73711,NULL,'Point Lay, AK 99759',30290,222,NULL,2,43128,0);
INSERT INTO "django_geo_db_location" VALUES(73712,NULL,'Nenana, AK',30291,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73713,NULL,'Nenana, AK 99760',30291,222,NULL,2,43129,0);
INSERT INTO "django_geo_db_location" VALUES(73714,NULL,'Noatak, AK',30292,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73715,NULL,'Noatak, AK 99761',30292,222,NULL,2,43130,0);
INSERT INTO "django_geo_db_location" VALUES(73716,NULL,'Nome, AK',30293,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73717,NULL,'Nome, AK 99762',30293,222,NULL,2,43131,0);
INSERT INTO "django_geo_db_location" VALUES(73718,NULL,'Noorvik, AK',30294,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73719,NULL,'Noorvik, AK 99763',30294,222,NULL,2,43132,0);
INSERT INTO "django_geo_db_location" VALUES(73720,NULL,'Northway, AK',30295,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73721,NULL,'Northway, AK 99764',30295,222,NULL,2,43133,0);
INSERT INTO "django_geo_db_location" VALUES(73722,NULL,'Nulato, AK',30296,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73723,NULL,'Nulato, AK 99765',30296,222,NULL,2,43134,0);
INSERT INTO "django_geo_db_location" VALUES(73724,NULL,'Point Hope, AK',30297,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73725,NULL,'Point Hope, AK 99766',30297,222,NULL,2,43135,0);
INSERT INTO "django_geo_db_location" VALUES(73726,NULL,'Rampart, AK',30298,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73727,NULL,'Rampart, AK 99767',30298,222,NULL,2,43136,0);
INSERT INTO "django_geo_db_location" VALUES(73728,NULL,'Ruby, AK',30299,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73729,NULL,'Ruby, AK 99768',30299,222,NULL,2,43137,0);
INSERT INTO "django_geo_db_location" VALUES(73730,NULL,'Savoonga, AK',30300,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73731,NULL,'Savoonga, AK 99769',30300,222,NULL,2,43138,0);
INSERT INTO "django_geo_db_location" VALUES(73732,NULL,'Selawik, AK',30301,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73733,NULL,'Selawik, AK 99770',30301,222,NULL,2,43139,0);
INSERT INTO "django_geo_db_location" VALUES(73734,NULL,'Shaktoolik, AK',30302,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73735,NULL,'Shaktoolik, AK 99771',30302,222,NULL,2,43140,0);
INSERT INTO "django_geo_db_location" VALUES(73736,NULL,'Shishmaref, AK',30303,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73737,NULL,'Shishmaref, AK 99772',30303,222,NULL,2,43141,0);
INSERT INTO "django_geo_db_location" VALUES(73738,NULL,'Shungnak, AK',30304,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73739,NULL,'Shungnak, AK 99773',30304,222,NULL,2,43142,0);
INSERT INTO "django_geo_db_location" VALUES(73740,NULL,'Stevens Village, AK',30305,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73741,NULL,'Stevens Village, AK 99774',30305,222,NULL,2,43143,0);
INSERT INTO "django_geo_db_location" VALUES(73742,NULL,'Fairbanks, AK 99775',30247,222,NULL,2,43144,0);
INSERT INTO "django_geo_db_location" VALUES(73743,NULL,'Tanacross, AK',30306,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73744,NULL,'Tanacross, AK 99776',30306,222,NULL,2,43145,0);
INSERT INTO "django_geo_db_location" VALUES(73745,NULL,'Tanana, AK',30307,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73746,NULL,'Tanana, AK 99777',30307,222,NULL,2,43146,0);
INSERT INTO "django_geo_db_location" VALUES(73747,NULL,'Teller, AK',30308,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73748,NULL,'Teller, AK 99778',30308,222,NULL,2,43147,0);
INSERT INTO "django_geo_db_location" VALUES(73749,NULL,'Tetlin, AK',30309,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73750,NULL,'Tetlin, AK 99779',30309,222,NULL,2,43148,0);
INSERT INTO "django_geo_db_location" VALUES(73751,NULL,'Tok, AK',30310,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73752,NULL,'Tok, AK 99780',30310,222,NULL,2,43149,0);
INSERT INTO "django_geo_db_location" VALUES(73753,NULL,'Venetie, AK',30311,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73754,NULL,'Venetie, AK 99781',30311,222,NULL,2,43150,0);
INSERT INTO "django_geo_db_location" VALUES(73755,NULL,'Wainwright, AK',30312,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73756,NULL,'Wainwright, AK 99782',30312,222,NULL,2,43151,0);
INSERT INTO "django_geo_db_location" VALUES(73757,NULL,'Wales, AK',30313,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73758,NULL,'Wales, AK 99783',30313,222,NULL,2,43152,0);
INSERT INTO "django_geo_db_location" VALUES(73759,NULL,'White Mountain, AK',30314,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73760,NULL,'White Mountain, AK 99784',30314,222,NULL,2,43153,0);
INSERT INTO "django_geo_db_location" VALUES(73761,NULL,'Brevig Mission, AK',30315,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73762,NULL,'Brevig Mission, AK 99785',30315,222,NULL,2,43154,0);
INSERT INTO "django_geo_db_location" VALUES(73763,NULL,'Ambler, AK',30316,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73764,NULL,'Ambler, AK 99786',30316,222,NULL,2,43155,0);
INSERT INTO "django_geo_db_location" VALUES(73765,NULL,'Chalkyitsik, AK',30317,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73766,NULL,'Chalkyitsik, AK 99788',30317,222,NULL,2,43156,0);
INSERT INTO "django_geo_db_location" VALUES(73767,NULL,'Nuiqsut, AK',30318,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73768,NULL,'Nuiqsut, AK 99789',30318,222,NULL,2,43157,0);
INSERT INTO "django_geo_db_location" VALUES(73769,NULL,'Fairbanks, AK 99790',30247,222,NULL,2,43158,0);
INSERT INTO "django_geo_db_location" VALUES(73770,NULL,'Atqasuk, AK',30319,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73771,NULL,'Atqasuk, AK 99791',30319,222,NULL,2,43159,0);
INSERT INTO "django_geo_db_location" VALUES(73772,NULL,'Juneau, AK',30320,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73773,NULL,'Juneau, AK 99801',30320,222,NULL,2,43160,0);
INSERT INTO "django_geo_db_location" VALUES(73774,NULL,'Juneau, AK 99802',30320,222,NULL,2,43161,0);
INSERT INTO "django_geo_db_location" VALUES(73775,NULL,'Juneau, AK 99803',30320,222,NULL,2,43162,0);
INSERT INTO "django_geo_db_location" VALUES(73776,NULL,'Juneau, AK 99811',30320,222,NULL,2,43163,0);
INSERT INTO "django_geo_db_location" VALUES(73777,NULL,'Angoon, AK',30321,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73778,NULL,'Angoon, AK 99820',30321,222,NULL,2,43164,0);
INSERT INTO "django_geo_db_location" VALUES(73779,NULL,'Auke Bay, AK',30322,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73780,NULL,'Auke Bay, AK 99821',30322,222,NULL,2,43165,0);
INSERT INTO "django_geo_db_location" VALUES(73781,NULL,'Douglas, AK',30323,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73782,NULL,'Douglas, AK 99824',30323,222,NULL,2,43166,0);
INSERT INTO "django_geo_db_location" VALUES(73783,NULL,'Elfin Cove, AK',30324,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73784,NULL,'Elfin Cove, AK 99825',30324,222,NULL,2,43167,0);
INSERT INTO "django_geo_db_location" VALUES(73785,NULL,'Gustavus, AK',30325,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73786,NULL,'Gustavus, AK 99826',30325,222,NULL,2,43168,0);
INSERT INTO "django_geo_db_location" VALUES(73787,NULL,'Haines, AK',30326,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73788,NULL,'Haines, AK 99827',30326,222,NULL,2,43169,0);
INSERT INTO "django_geo_db_location" VALUES(73789,NULL,'Hoonah, AK',30327,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73790,NULL,'Hoonah, AK 99829',30327,222,NULL,2,43170,0);
INSERT INTO "django_geo_db_location" VALUES(73791,NULL,'Kake, AK',30328,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73792,NULL,'Kake, AK 99830',30328,222,NULL,2,43171,0);
INSERT INTO "django_geo_db_location" VALUES(73793,NULL,'Pelican, AK',30329,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73794,NULL,'Pelican, AK 99832',30329,222,NULL,2,43172,0);
INSERT INTO "django_geo_db_location" VALUES(73795,NULL,'Petersburg, AK',30330,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73796,NULL,'Petersburg, AK 99833',30330,222,NULL,2,43173,0);
INSERT INTO "django_geo_db_location" VALUES(73797,NULL,'Sitka, AK',30331,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73798,NULL,'Sitka, AK 99835',30331,222,NULL,2,43174,0);
INSERT INTO "django_geo_db_location" VALUES(73799,NULL,'Port Alexander, AK',30332,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73800,NULL,'Port Alexander, AK 99836',30332,222,NULL,2,43175,0);
INSERT INTO "django_geo_db_location" VALUES(73801,NULL,'Skagway, AK',30333,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73802,NULL,'Skagway, AK 99840',30333,222,NULL,2,43176,0);
INSERT INTO "django_geo_db_location" VALUES(73803,NULL,'Tenakee Springs, AK',30334,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73804,NULL,'Tenakee Springs, AK 99841',30334,222,NULL,2,43177,0);
INSERT INTO "django_geo_db_location" VALUES(73805,NULL,'Juneau, AK 99850',30320,222,NULL,2,43178,0);
INSERT INTO "django_geo_db_location" VALUES(73806,NULL,'Ketchikan, AK',30335,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73807,NULL,'Ketchikan, AK 99901',30335,222,NULL,2,43179,0);
INSERT INTO "django_geo_db_location" VALUES(73808,NULL,'Meyers Chuck, AK',30336,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73809,NULL,'Meyers Chuck, AK 99903',30336,222,NULL,2,43180,0);
INSERT INTO "django_geo_db_location" VALUES(73810,NULL,'Coffman Cove, AK',30337,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73811,NULL,'Coffman Cove, AK 99918',30337,222,NULL,2,43181,0);
INSERT INTO "django_geo_db_location" VALUES(73812,NULL,'Thorne Bay, AK',30338,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73813,NULL,'Thorne Bay, AK 99919',30338,222,NULL,2,43182,0);
INSERT INTO "django_geo_db_location" VALUES(73814,NULL,'Craig, AK',30339,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73815,NULL,'Craig, AK 99921',30339,222,NULL,2,43183,0);
INSERT INTO "django_geo_db_location" VALUES(73816,NULL,'Hydaburg, AK',30340,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73817,NULL,'Hydaburg, AK 99922',30340,222,NULL,2,43184,0);
INSERT INTO "django_geo_db_location" VALUES(73818,NULL,'Hyder, AK',30341,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73819,NULL,'Hyder, AK 99923',30341,222,NULL,2,43185,0);
INSERT INTO "django_geo_db_location" VALUES(73820,NULL,'Klawock, AK',30342,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73821,NULL,'Klawock, AK 99925',30342,222,NULL,2,43186,0);
INSERT INTO "django_geo_db_location" VALUES(73822,NULL,'Metlakatla, AK',30343,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73823,NULL,'Metlakatla, AK 99926',30343,222,NULL,2,43187,0);
INSERT INTO "django_geo_db_location" VALUES(73824,NULL,'Point Baker, AK',30344,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73825,NULL,'Point Baker, AK 99927',30344,222,NULL,2,43188,0);
INSERT INTO "django_geo_db_location" VALUES(73826,NULL,'Ward Cove, AK',30345,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73827,NULL,'Ward Cove, AK 99928',30345,222,NULL,2,43189,0);
INSERT INTO "django_geo_db_location" VALUES(73828,NULL,'Wrangell, AK',30346,222,NULL,2,NULL,0);
INSERT INTO "django_geo_db_location" VALUES(73829,NULL,'Wrangell, AK 99929',30346,222,NULL,2,43190,0);
INSERT INTO "django_geo_db_location" VALUES(73830,NULL,'Ketchikan, AK 99950',30335,222,NULL,2,43191,0);
CREATE INDEX "django_geo_db_location_c7141997" ON "django_geo_db_location" ("city_id",0);
CREATE INDEX "django_geo_db_location_93bfec8a" ON "django_geo_db_location" ("country_id",0);
CREATE INDEX "django_geo_db_location_c2ff64a1" ON "django_geo_db_location" ("geocoordinate_id",0);
CREATE INDEX "django_geo_db_location_d5582625" ON "django_geo_db_location" ("state_id",0);
CREATE INDEX "django_geo_db_location_f26703ee" ON "django_geo_db_location" ("zipcode_id",0);
COMMIT;
